(self["webpackChunk_elyra_pipeline_editor_extension"] = self["webpackChunk_elyra_pipeline_editor_extension"] || []).push([["vendors-node_modules_elyra_pipeline-editor_dist_index_js"],{

/***/ "../../node_modules/@babel/runtime/helpers/esm/objectSpread2.js":
/*!**********************************************************************!*\
  !*** ../../node_modules/@babel/runtime/helpers/esm/objectSpread2.js ***!
  \**********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ _objectSpread2)
/* harmony export */ });
/* harmony import */ var _defineProperty_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./defineProperty.js */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");


function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    enumerableOnly && (symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    })), keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = null != arguments[i] ? arguments[i] : {};
    i % 2 ? ownKeys(Object(source), !0).forEach(function (key) {
      (0,_defineProperty_js__WEBPACK_IMPORTED_MODULE_0__["default"])(target, key, source[key]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) {
      Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
    });
  }

  return target;
}

/***/ }),

/***/ "../../node_modules/@carbon/feature-flags/es/index.js":
/*!************************************************************!*\
  !*** ../../node_modules/@carbon/feature-flags/es/index.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "FeatureFlags": () => (/* binding */ FeatureFlags),
/* harmony export */   "add": () => (/* binding */ add),
/* harmony export */   "createScope": () => (/* binding */ createScope),
/* harmony export */   "disable": () => (/* binding */ disable),
/* harmony export */   "enable": () => (/* binding */ enable),
/* harmony export */   "enabled": () => (/* binding */ enabled),
/* harmony export */   "merge": () => (/* binding */ merge)
/* harmony export */ });
/* provided dependency */ var process = __webpack_require__(/*! process/browser */ "../../node_modules/process/browser.js");
/**
 * Copyright IBM Corp. 2015, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

var enabled$1 = {};

try {
  if (process.env.CARBON_ENABLE_CSS_CUSTOM_PROPERTIES) {
    if (process.env.CARBON_ENABLE_CSS_CUSTOM_PROPERTIES === 'true') {
      enabled$1.enableCssCustomProperties = true;
    } else {
      enabled$1.enableCssCustomProperties = false;
    }
  } else {
    enabled$1.enableCssCustomProperties = false;
  }

  if (process.env.CARBON_ENABLE_USE_CONTROLLED_STATE_WITH_VALUE) {
    if (process.env.CARBON_ENABLE_USE_CONTROLLED_STATE_WITH_VALUE === 'true') {
      enabled$1.enableUseControlledStateWithValue = true;
    } else {
      enabled$1.enableUseControlledStateWithValue = false;
    }
  } else {
    enabled$1.enableUseControlledStateWithValue = false;
  }

  if (process.env.CARBON_ENABLE_CSS_GRID) {
    if (process.env.CARBON_ENABLE_CSS_GRID === 'true') {
      enabled$1.enableCssGrid = true;
    } else {
      enabled$1.enableCssGrid = false;
    }
  } else {
    enabled$1.enableCssGrid = false;
  }

  if (process.env.CARBON_ENABLE_V11_RELEASE) {
    if (process.env.CARBON_ENABLE_V11_RELEASE === 'true') {
      enabled$1.enableV11Release = true;
    } else {
      enabled$1.enableV11Release = false;
    }
  } else {
    enabled$1.enableV11Release = false;
  }
} catch (error) {
  enabled$1.enableCssCustomProperties = false;
  enabled$1.enableUseControlledStateWithValue = false;
  enabled$1.enableCssGrid = false;
  enabled$1.enableV11Release = false;
}

var featureFlagInfo = [{
  name: "enable-css-custom-properties",
  description: "Describe what the flag does",
  enabled: enabled$1.enableCssCustomProperties
}, {
  name: "enable-use-controlled-state-with-value",
  description: "Enable components to be created in either a controlled or uncontrolled mode\n",
  enabled: enabled$1.enableUseControlledStateWithValue
}, {
  name: "enable-css-grid",
  description: "Enable CSS Grid Layout in the Grid and Column React components\n",
  enabled: enabled$1.enableCssGrid
}, {
  name: "enable-v11-release",
  description: "Enable the features and functionality for the v11 Release\n",
  enabled: enabled$1.enableV11Release
}];

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  Object.defineProperty(Constructor, "prototype", {
    writable: false
  });
  return Constructor;
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"];

  if (_i == null) return;
  var _arr = [];
  var _n = true;
  var _d = false;

  var _s, _e;

  try {
    for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

function _createForOfIteratorHelper(o, allowArrayLike) {
  var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];

  if (!it) {
    if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
      if (it) o = it;
      var i = 0;

      var F = function () {};

      return {
        s: F,
        n: function () {
          if (i >= o.length) return {
            done: true
          };
          return {
            done: false,
            value: o[i++]
          };
        },
        e: function (e) {
          throw e;
        },
        f: F
      };
    }

    throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }

  var normalCompletion = true,
      didErr = false,
      err;
  return {
    s: function () {
      it = it.call(o);
    },
    n: function () {
      var step = it.next();
      normalCompletion = step.done;
      return step;
    },
    e: function (e) {
      didErr = true;
      err = e;
    },
    f: function () {
      try {
        if (!normalCompletion && it.return != null) it.return();
      } finally {
        if (didErr) throw err;
      }
    }
  };
}

/**
 * Copyright IBM Corp. 2015, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
var FeatureFlagScope = /*#__PURE__*/function () {
  function FeatureFlagScope(flags) {
    var _this = this;

    _classCallCheck(this, FeatureFlagScope);

    this.flags = new Map();

    if (flags) {
      Object.keys(flags).forEach(function (key) {
        _this.flags.set(key, flags[key]);
      });
    }
  }
  /**
   * Check to see if a flag exists
   * @param {string} name
   */


  _createClass(FeatureFlagScope, [{
    key: "checkForFlag",
    value: function checkForFlag(name) {
      if (!this.flags.has(name)) {
        throw new Error("Unable to find a feature flag with the name: `".concat(name, "`"));
      }
    }
    /**
     * Add a feature flag
     * @param {string} name
     * @param {boolean} enabled
     */

  }, {
    key: "add",
    value: function add(name, enabled) {
      if (this.flags.has(name)) {
        throw new Error("The feature flag: ".concat(name, " already exists"));
      }

      this.flags.set(name, enabled);
    }
    /**
     * Enable a feature flag
     * @param {string} name
     */

  }, {
    key: "enable",
    value: function enable(name) {
      this.checkForFlag(name);
      this.flags.set(name, true);
    }
    /**
     * Disable a feature flag
     * @param {string} name
     */

  }, {
    key: "disable",
    value: function disable(name) {
      this.checkForFlag(name);
      this.flags.set(name, false);
    }
    /**
     * Merge the given feature flags with the current set of feature flags.
     * Duplicate keys will be set to the value in the given feature flags.
     * @param {object} flags
     */

  }, {
    key: "merge",
    value: function merge(flags) {
      var _this2 = this;

      Object.keys(flags).forEach(function (key) {
        _this2.flags.set(key, flags[key]);
      });
    }
    /**
     * @param {FeatureFlagScope} scope
     */

  }, {
    key: "mergeWithScope",
    value: function mergeWithScope(scope) {
      var _iterator = _createForOfIteratorHelper(scope.flags),
          _step;

      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          var _step$value = _slicedToArray(_step.value, 2),
              key = _step$value[0],
              value = _step$value[1];

          if (this.flags.has(key)) {
            continue;
          }

          this.flags.set(key, value);
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
    }
    /**
     * Check if a feature flag is enabled
     * @param {string} name
     * @returns {boolean}
     */

  }, {
    key: "enabled",
    value: function enabled(name) {
      this.checkForFlag(name);
      return this.flags.get(name);
    }
  }]);

  return FeatureFlagScope;
}();

var FeatureFlags = createScope();

for (var i = 0; i < featureFlagInfo.length; i++) {
  var featureFlag = featureFlagInfo[i];
  FeatureFlags.add(featureFlag.name, featureFlag.enabled);
}
function createScope(flags) {
  return new FeatureFlagScope(flags);
}
function add() {
  return FeatureFlags.add.apply(FeatureFlags, arguments);
}
function enable() {
  return FeatureFlags.enable.apply(FeatureFlags, arguments);
}
function disable() {
  return FeatureFlags.disable.apply(FeatureFlags, arguments);
}
function enabled() {
  return FeatureFlags.enabled.apply(FeatureFlags, arguments);
}
function merge() {
  return FeatureFlags.merge.apply(FeatureFlags, arguments);
}




/***/ }),

/***/ "../../node_modules/@carbon/icon-helpers/es/index.js":
/*!***********************************************************!*\
  !*** ../../node_modules/@carbon/icon-helpers/es/index.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "defaultAttributes": () => (/* binding */ defaultAttributes),
/* harmony export */   "formatAttributes": () => (/* binding */ formatAttributes),
/* harmony export */   "getAttributes": () => (/* binding */ getAttributes),
/* harmony export */   "toSVG": () => (/* binding */ toSVG),
/* harmony export */   "toString": () => (/* binding */ toString)
/* harmony export */ });
function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    enumerableOnly && (symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    })), keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = null != arguments[i] ? arguments[i] : {};
    i % 2 ? ownKeys(Object(source), !0).forEach(function (key) {
      _defineProperty(target, key, source[key]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) {
      Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
    });
  }

  return target;
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _objectWithoutProperties(source, excluded) {
  if (source == null) return {};

  var target = _objectWithoutPropertiesLoose(source, excluded);

  var key, i;

  if (Object.getOwnPropertySymbols) {
    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);

    for (i = 0; i < sourceSymbolKeys.length; i++) {
      key = sourceSymbolKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
      target[key] = source[key];
    }
  }

  return target;
}

var _excluded = ["width", "height", "viewBox"],
    _excluded2 = ["tabindex"];

/**
 * Copyright IBM Corp. 2018, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
var defaultAttributes = {
  // Reference:
  // https://github.com/IBM/carbon-components-react/issues/1392
  // https://github.com/PolymerElements/iron-iconset-svg/pull/47
  // `focusable` is a string attribute which is why we do not use a boolean here
  focusable: 'false',
  preserveAspectRatio: 'xMidYMid meet'
};
/**
 * Get supplementary HTML attributes for a given <svg> element based on existing
 * attributes.
 */

function getAttributes() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      width = _ref.width,
      height = _ref.height,
      _ref$viewBox = _ref.viewBox,
      viewBox = _ref$viewBox === void 0 ? "0 0 ".concat(width, " ").concat(height) : _ref$viewBox,
      attributes = _objectWithoutProperties(_ref, _excluded);

  var tabindex = attributes.tabindex,
      rest = _objectWithoutProperties(attributes, _excluded2);

  var iconAttributes = _objectSpread2(_objectSpread2(_objectSpread2({}, defaultAttributes), rest), {}, {
    width: width,
    height: height,
    viewBox: viewBox
  }); // TODO: attributes.title assumes that the consumer will implement <title> and
  // correctly set `aria-labelledby`.


  if (iconAttributes['aria-label'] || iconAttributes['aria-labelledby'] || iconAttributes.title) {
    iconAttributes.role = 'img'; // Reference:
    // https://allyjs.io/tutorials/focusing-in-svg.html

    if (tabindex !== undefined && tabindex !== null) {
      iconAttributes.focusable = 'true';
      iconAttributes.tabindex = tabindex;
    }
  } else {
    iconAttributes['aria-hidden'] = true;
  }

  return iconAttributes;
}

/**
 * Copyright IBM Corp. 2018, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
/**
 * Convert an icon descriptor to a String
 */

function toString(descriptor) {
  var _descriptor$elem = descriptor.elem,
      elem = _descriptor$elem === void 0 ? 'svg' : _descriptor$elem,
      _descriptor$attrs = descriptor.attrs,
      attrs = _descriptor$attrs === void 0 ? {} : _descriptor$attrs,
      _descriptor$content = descriptor.content,
      content = _descriptor$content === void 0 ? [] : _descriptor$content;
  var children = content.map(toString).join('');

  if (elem !== 'svg') {
    return "<".concat(elem, " ").concat(formatAttributes(attrs), ">").concat(children, "</").concat(elem, ">");
  }

  return "<".concat(elem, " ").concat(formatAttributes(getAttributes(attrs)), ">").concat(children, "</").concat(elem, ">");
}
function formatAttributes(attrs) {
  return Object.keys(attrs).reduce(function (acc, key, index) {
    var attribute = "".concat(key, "=\"").concat(attrs[key], "\"");

    if (index === 0) {
      return attribute;
    }

    return acc + ' ' + attribute;
  }, '');
}

/**
 * Copyright IBM Corp. 2018, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
/**
 * Convert an icon descriptor to a DOM node.
 */

function toSVG(descriptor) {
  var _descriptor$elem = descriptor.elem,
      elem = _descriptor$elem === void 0 ? 'svg' : _descriptor$elem,
      _descriptor$attrs = descriptor.attrs,
      attrs = _descriptor$attrs === void 0 ? {} : _descriptor$attrs,
      _descriptor$content = descriptor.content,
      content = _descriptor$content === void 0 ? [] : _descriptor$content;
  var node = document.createElementNS('http://www.w3.org/2000/svg', elem);
  var attributes = elem !== 'svg' ? attrs : getAttributes(attrs);
  Object.keys(attributes).forEach(function (key) {
    node.setAttribute(key, attrs[key]);
  });

  for (var i = 0; i < content.length; i++) {
    node.appendChild(toSVG(content[i]));
  }

  return node;
}




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js":
/*!******************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "I": () => (/* binding */ Icon),
/* harmony export */   "_": () => (/* binding */ _objectWithoutProperties),
/* harmony export */   "a": () => (/* binding */ _extends)
/* harmony export */ });
/* harmony import */ var _carbon_icon_helpers__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @carbon/icon-helpers */ "../../node_modules/@carbon/icon-helpers/es/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */




function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    enumerableOnly && (symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    })), keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = null != arguments[i] ? arguments[i] : {};
    i % 2 ? ownKeys(Object(source), !0).forEach(function (key) {
      _defineProperty(target, key, source[key]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) {
      Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
    });
  }

  return target;
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _objectWithoutProperties(source, excluded) {
  if (source == null) return {};

  var target = _objectWithoutPropertiesLoose(source, excluded);

  var key, i;

  if (Object.getOwnPropertySymbols) {
    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);

    for (i = 0; i < sourceSymbolKeys.length; i++) {
      key = sourceSymbolKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
      target[key] = source[key];
    }
  }

  return target;
}

var _excluded = ["className", "children", "tabIndex"],
    _excluded2 = ["tabindex"];
var Icon = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Icon(_ref, ref) {
  var className = _ref.className,
      children = _ref.children,
      tabIndex = _ref.tabIndex,
      rest = _objectWithoutProperties(_ref, _excluded);

  var _getAttributes = (0,_carbon_icon_helpers__WEBPACK_IMPORTED_MODULE_1__.getAttributes)(_objectSpread2(_objectSpread2({}, rest), {}, {
    tabindex: tabIndex
  })),
      tabindex = _getAttributes.tabindex,
      props = _objectWithoutProperties(_getAttributes, _excluded2);

  if (className) {
    props.className = className;
  }

  if (tabindex !== undefined && tabindex !== null) {
    props.tabIndex = tabindex;
  }

  if (ref) {
    props.ref = ref;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement('svg', props, children);
});
Icon.displayName = 'Icon';
Icon.propTypes = {
  'aria-hidden': (prop_types__WEBPACK_IMPORTED_MODULE_2___default().string),
  'aria-label': (prop_types__WEBPACK_IMPORTED_MODULE_2___default().string),
  'aria-labelledby': (prop_types__WEBPACK_IMPORTED_MODULE_2___default().string),
  children: (prop_types__WEBPACK_IMPORTED_MODULE_2___default().node),
  className: (prop_types__WEBPACK_IMPORTED_MODULE_2___default().string),
  height: prop_types__WEBPACK_IMPORTED_MODULE_2___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_2___default().number), (prop_types__WEBPACK_IMPORTED_MODULE_2___default().string)]),
  preserveAspectRatio: (prop_types__WEBPACK_IMPORTED_MODULE_2___default().string),
  tabIndex: (prop_types__WEBPACK_IMPORTED_MODULE_2___default().string),
  viewBox: (prop_types__WEBPACK_IMPORTED_MODULE_2___default().string),
  width: prop_types__WEBPACK_IMPORTED_MODULE_2___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_2___default().number), (prop_types__WEBPACK_IMPORTED_MODULE_2___default().string)]),
  xmlns: (prop_types__WEBPACK_IMPORTED_MODULE_2___default().string)
};
Icon.defaultProps = {
  xmlns: 'http://www.w3.org/2000/svg',
  preserveAspectRatio: 'xMidYMid meet'
};




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-0.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-0.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Accessibility16": () => (/* binding */ Accessibility16),
/* harmony export */   "Accessibility20": () => (/* binding */ Accessibility20),
/* harmony export */   "Accessibility24": () => (/* binding */ Accessibility24),
/* harmony export */   "Accessibility32": () => (/* binding */ Accessibility32),
/* harmony export */   "AccessibilityAlt16": () => (/* binding */ AccessibilityAlt16),
/* harmony export */   "AccessibilityAlt20": () => (/* binding */ AccessibilityAlt20),
/* harmony export */   "AccessibilityAlt24": () => (/* binding */ AccessibilityAlt24),
/* harmony export */   "AccessibilityAlt32": () => (/* binding */ AccessibilityAlt32),
/* harmony export */   "AccessibilityColor16": () => (/* binding */ AccessibilityColor16),
/* harmony export */   "AccessibilityColor20": () => (/* binding */ AccessibilityColor20),
/* harmony export */   "AccessibilityColor24": () => (/* binding */ AccessibilityColor24),
/* harmony export */   "AccessibilityColor32": () => (/* binding */ AccessibilityColor32),
/* harmony export */   "AccessibilityColorFilled16": () => (/* binding */ AccessibilityColorFilled16),
/* harmony export */   "AccessibilityColorFilled20": () => (/* binding */ AccessibilityColorFilled20),
/* harmony export */   "AccessibilityColorFilled24": () => (/* binding */ AccessibilityColorFilled24),
/* harmony export */   "AccessibilityColorFilled32": () => (/* binding */ AccessibilityColorFilled32),
/* harmony export */   "Account16": () => (/* binding */ Account16),
/* harmony export */   "Account20": () => (/* binding */ Account20),
/* harmony export */   "Account24": () => (/* binding */ Account24),
/* harmony export */   "Account32": () => (/* binding */ Account32),
/* harmony export */   "AccumulationIce16": () => (/* binding */ AccumulationIce16),
/* harmony export */   "AccumulationIce20": () => (/* binding */ AccumulationIce20),
/* harmony export */   "AccumulationIce24": () => (/* binding */ AccumulationIce24),
/* harmony export */   "AccumulationIce32": () => (/* binding */ AccumulationIce32),
/* harmony export */   "AccumulationPrecipitation16": () => (/* binding */ AccumulationPrecipitation16),
/* harmony export */   "AccumulationPrecipitation20": () => (/* binding */ AccumulationPrecipitation20),
/* harmony export */   "AccumulationPrecipitation24": () => (/* binding */ AccumulationPrecipitation24),
/* harmony export */   "AccumulationPrecipitation32": () => (/* binding */ AccumulationPrecipitation32),
/* harmony export */   "AccumulationRain16": () => (/* binding */ AccumulationRain16),
/* harmony export */   "AccumulationRain20": () => (/* binding */ AccumulationRain20),
/* harmony export */   "AccumulationRain24": () => (/* binding */ AccumulationRain24),
/* harmony export */   "AccumulationRain32": () => (/* binding */ AccumulationRain32),
/* harmony export */   "AccumulationSnow16": () => (/* binding */ AccumulationSnow16),
/* harmony export */   "AccumulationSnow20": () => (/* binding */ AccumulationSnow20),
/* harmony export */   "AccumulationSnow24": () => (/* binding */ AccumulationSnow24),
/* harmony export */   "AccumulationSnow32": () => (/* binding */ AccumulationSnow32),
/* harmony export */   "Activity16": () => (/* binding */ Activity16),
/* harmony export */   "Activity20": () => (/* binding */ Activity20),
/* harmony export */   "Activity24": () => (/* binding */ Activity24),
/* harmony export */   "Activity32": () => (/* binding */ Activity32),
/* harmony export */   "Add16": () => (/* binding */ Add16),
/* harmony export */   "Add20": () => (/* binding */ Add20),
/* harmony export */   "Add24": () => (/* binding */ Add24),
/* harmony export */   "Add32": () => (/* binding */ Add32),
/* harmony export */   "AddAlt16": () => (/* binding */ AddAlt16),
/* harmony export */   "AddAlt20": () => (/* binding */ AddAlt20),
/* harmony export */   "AddAlt24": () => (/* binding */ AddAlt24),
/* harmony export */   "AddAlt32": () => (/* binding */ AddAlt32),
/* harmony export */   "AddComment16": () => (/* binding */ AddComment16),
/* harmony export */   "AddComment20": () => (/* binding */ AddComment20),
/* harmony export */   "AddComment24": () => (/* binding */ AddComment24),
/* harmony export */   "AddComment32": () => (/* binding */ AddComment32),
/* harmony export */   "AddFilled16": () => (/* binding */ AddFilled16),
/* harmony export */   "AddFilled20": () => (/* binding */ AddFilled20),
/* harmony export */   "AddFilled24": () => (/* binding */ AddFilled24),
/* harmony export */   "AddFilled32": () => (/* binding */ AddFilled32),
/* harmony export */   "AgricultureAnalytics16": () => (/* binding */ AgricultureAnalytics16),
/* harmony export */   "AgricultureAnalytics20": () => (/* binding */ AgricultureAnalytics20),
/* harmony export */   "AgricultureAnalytics24": () => (/* binding */ AgricultureAnalytics24),
/* harmony export */   "AgricultureAnalytics32": () => (/* binding */ AgricultureAnalytics32),
/* harmony export */   "AirlineDigitalGate16": () => (/* binding */ AirlineDigitalGate16),
/* harmony export */   "AirlineDigitalGate20": () => (/* binding */ AirlineDigitalGate20),
/* harmony export */   "AirlineDigitalGate24": () => (/* binding */ AirlineDigitalGate24),
/* harmony export */   "AirlineDigitalGate32": () => (/* binding */ AirlineDigitalGate32),
/* harmony export */   "AirlineManageGates16": () => (/* binding */ AirlineManageGates16),
/* harmony export */   "AirlineManageGates20": () => (/* binding */ AirlineManageGates20),
/* harmony export */   "AirlineManageGates24": () => (/* binding */ AirlineManageGates24),
/* harmony export */   "AirlineManageGates32": () => (/* binding */ AirlineManageGates32),
/* harmony export */   "AirlinePassengerCare16": () => (/* binding */ AirlinePassengerCare16),
/* harmony export */   "AirlinePassengerCare20": () => (/* binding */ AirlinePassengerCare20),
/* harmony export */   "AirlinePassengerCare24": () => (/* binding */ AirlinePassengerCare24),
/* harmony export */   "AirlinePassengerCare32": () => (/* binding */ AirlinePassengerCare32),
/* harmony export */   "AirlineRapidBoard16": () => (/* binding */ AirlineRapidBoard16),
/* harmony export */   "AirlineRapidBoard20": () => (/* binding */ AirlineRapidBoard20),
/* harmony export */   "AirlineRapidBoard24": () => (/* binding */ AirlineRapidBoard24),
/* harmony export */   "AirlineRapidBoard32": () => (/* binding */ AirlineRapidBoard32),
/* harmony export */   "Airplay16": () => (/* binding */ Airplay16),
/* harmony export */   "Airplay20": () => (/* binding */ Airplay20),
/* harmony export */   "Airplay24": () => (/* binding */ Airplay24),
/* harmony export */   "Airplay32": () => (/* binding */ Airplay32),
/* harmony export */   "AirplayFilled16": () => (/* binding */ AirplayFilled16),
/* harmony export */   "AirplayFilled20": () => (/* binding */ AirplayFilled20),
/* harmony export */   "AirplayFilled24": () => (/* binding */ AirplayFilled24),
/* harmony export */   "AirplayFilled32": () => (/* binding */ AirplayFilled32),
/* harmony export */   "AirportLocation16": () => (/* binding */ AirportLocation16),
/* harmony export */   "AirportLocation20": () => (/* binding */ AirportLocation20),
/* harmony export */   "AirportLocation24": () => (/* binding */ AirportLocation24),
/* harmony export */   "AirportLocation32": () => (/* binding */ AirportLocation32),
/* harmony export */   "Airport_0116": () => (/* binding */ Airport_0116),
/* harmony export */   "Airport_0120": () => (/* binding */ Airport_0120),
/* harmony export */   "Airport_0124": () => (/* binding */ Airport_0124),
/* harmony export */   "Airport_0132": () => (/* binding */ Airport_0132),
/* harmony export */   "Airport_0216": () => (/* binding */ Airport_0216),
/* harmony export */   "Airport_0220": () => (/* binding */ Airport_0220),
/* harmony export */   "Airport_0224": () => (/* binding */ Airport_0224),
/* harmony export */   "Airport_0232": () => (/* binding */ Airport_0232),
/* harmony export */   "Alarm16": () => (/* binding */ Alarm16),
/* harmony export */   "Alarm20": () => (/* binding */ Alarm20),
/* harmony export */   "Alarm24": () => (/* binding */ Alarm24),
/* harmony export */   "Alarm32": () => (/* binding */ Alarm32),
/* harmony export */   "AlarmAdd16": () => (/* binding */ AlarmAdd16),
/* harmony export */   "AlarmAdd20": () => (/* binding */ AlarmAdd20),
/* harmony export */   "AlarmAdd24": () => (/* binding */ AlarmAdd24),
/* harmony export */   "AlarmAdd32": () => (/* binding */ AlarmAdd32),
/* harmony export */   "AlarmSubtract16": () => (/* binding */ AlarmSubtract16),
/* harmony export */   "AlarmSubtract20": () => (/* binding */ AlarmSubtract20),
/* harmony export */   "AlarmSubtract24": () => (/* binding */ AlarmSubtract24),
/* harmony export */   "AlarmSubtract32": () => (/* binding */ AlarmSubtract32),
/* harmony export */   "AlignBoxBottomCenter16": () => (/* binding */ AlignBoxBottomCenter16),
/* harmony export */   "AlignBoxBottomCenter20": () => (/* binding */ AlignBoxBottomCenter20),
/* harmony export */   "AlignBoxBottomCenter24": () => (/* binding */ AlignBoxBottomCenter24),
/* harmony export */   "AlignBoxBottomCenter32": () => (/* binding */ AlignBoxBottomCenter32),
/* harmony export */   "AlignBoxBottomLeft16": () => (/* binding */ AlignBoxBottomLeft16),
/* harmony export */   "AlignBoxBottomLeft20": () => (/* binding */ AlignBoxBottomLeft20),
/* harmony export */   "AlignBoxBottomLeft24": () => (/* binding */ AlignBoxBottomLeft24),
/* harmony export */   "AlignBoxBottomLeft32": () => (/* binding */ AlignBoxBottomLeft32),
/* harmony export */   "AlignBoxBottomRight16": () => (/* binding */ AlignBoxBottomRight16),
/* harmony export */   "AlignBoxBottomRight20": () => (/* binding */ AlignBoxBottomRight20),
/* harmony export */   "AlignBoxBottomRight24": () => (/* binding */ AlignBoxBottomRight24),
/* harmony export */   "AlignBoxBottomRight32": () => (/* binding */ AlignBoxBottomRight32),
/* harmony export */   "AlignBoxMiddleCenter16": () => (/* binding */ AlignBoxMiddleCenter16),
/* harmony export */   "AlignBoxMiddleCenter20": () => (/* binding */ AlignBoxMiddleCenter20),
/* harmony export */   "AlignBoxMiddleCenter24": () => (/* binding */ AlignBoxMiddleCenter24),
/* harmony export */   "AlignBoxMiddleCenter32": () => (/* binding */ AlignBoxMiddleCenter32),
/* harmony export */   "AlignBoxMiddleLeft16": () => (/* binding */ AlignBoxMiddleLeft16),
/* harmony export */   "AlignBoxMiddleLeft20": () => (/* binding */ AlignBoxMiddleLeft20),
/* harmony export */   "AlignBoxMiddleLeft24": () => (/* binding */ AlignBoxMiddleLeft24),
/* harmony export */   "AlignBoxMiddleLeft32": () => (/* binding */ AlignBoxMiddleLeft32),
/* harmony export */   "AlignBoxMiddleRight24": () => (/* binding */ AlignBoxMiddleRight24),
/* harmony export */   "AlignBoxMiddleRight32": () => (/* binding */ AlignBoxMiddleRight32),
/* harmony export */   "AlignHorizontalCenter16": () => (/* binding */ AlignHorizontalCenter16),
/* harmony export */   "AlignHorizontalCenter20": () => (/* binding */ AlignHorizontalCenter20),
/* harmony export */   "AlignHorizontalCenter24": () => (/* binding */ AlignHorizontalCenter24),
/* harmony export */   "AlignHorizontalCenter32": () => (/* binding */ AlignHorizontalCenter32),
/* harmony export */   "AlignHorizontalLeft16": () => (/* binding */ AlignHorizontalLeft16),
/* harmony export */   "AlignHorizontalLeft20": () => (/* binding */ AlignHorizontalLeft20),
/* harmony export */   "AlignHorizontalLeft24": () => (/* binding */ AlignHorizontalLeft24),
/* harmony export */   "AlignHorizontalLeft32": () => (/* binding */ AlignHorizontalLeft32),
/* harmony export */   "AlignHorizontalRight16": () => (/* binding */ AlignHorizontalRight16),
/* harmony export */   "AlignHorizontalRight20": () => (/* binding */ AlignHorizontalRight20),
/* harmony export */   "AlignHorizontalRight24": () => (/* binding */ AlignHorizontalRight24),
/* harmony export */   "AlignHorizontalRight32": () => (/* binding */ AlignHorizontalRight32),
/* harmony export */   "AlignVerticalBottom16": () => (/* binding */ AlignVerticalBottom16),
/* harmony export */   "AlignVerticalBottom20": () => (/* binding */ AlignVerticalBottom20),
/* harmony export */   "AlignVerticalBottom24": () => (/* binding */ AlignVerticalBottom24),
/* harmony export */   "AlignVerticalBottom32": () => (/* binding */ AlignVerticalBottom32),
/* harmony export */   "AlignVerticalCenter16": () => (/* binding */ AlignVerticalCenter16),
/* harmony export */   "AlignVerticalCenter20": () => (/* binding */ AlignVerticalCenter20),
/* harmony export */   "AlignVerticalCenter24": () => (/* binding */ AlignVerticalCenter24),
/* harmony export */   "AlignVerticalCenter32": () => (/* binding */ AlignVerticalCenter32),
/* harmony export */   "AlignVerticalTop16": () => (/* binding */ AlignVerticalTop16),
/* harmony export */   "AlignVerticalTop20": () => (/* binding */ AlignVerticalTop20),
/* harmony export */   "AlignVerticalTop24": () => (/* binding */ AlignVerticalTop24),
/* harmony export */   "AlignVerticalTop32": () => (/* binding */ AlignVerticalTop32),
/* harmony export */   "WatsonHealth3DCursor16": () => (/* binding */ WatsonHealth3DCursor16),
/* harmony export */   "WatsonHealth3DCursor20": () => (/* binding */ WatsonHealth3DCursor20),
/* harmony export */   "WatsonHealth3DCursor24": () => (/* binding */ WatsonHealth3DCursor24),
/* harmony export */   "WatsonHealth3DCursor32": () => (/* binding */ WatsonHealth3DCursor32),
/* harmony export */   "WatsonHealth3DCursorAlt16": () => (/* binding */ WatsonHealth3DCursorAlt16),
/* harmony export */   "WatsonHealth3DCursorAlt20": () => (/* binding */ WatsonHealth3DCursorAlt20),
/* harmony export */   "WatsonHealth3DCursorAlt24": () => (/* binding */ WatsonHealth3DCursorAlt24),
/* harmony export */   "WatsonHealth3DCursorAlt32": () => (/* binding */ WatsonHealth3DCursorAlt32),
/* harmony export */   "WatsonHealth3DCurveAutoColon16": () => (/* binding */ WatsonHealth3DCurveAutoColon16),
/* harmony export */   "WatsonHealth3DCurveAutoColon20": () => (/* binding */ WatsonHealth3DCurveAutoColon20),
/* harmony export */   "WatsonHealth3DCurveAutoColon24": () => (/* binding */ WatsonHealth3DCurveAutoColon24),
/* harmony export */   "WatsonHealth3DCurveAutoColon32": () => (/* binding */ WatsonHealth3DCurveAutoColon32),
/* harmony export */   "WatsonHealth3DCurveAutoVessels16": () => (/* binding */ WatsonHealth3DCurveAutoVessels16),
/* harmony export */   "WatsonHealth3DCurveAutoVessels20": () => (/* binding */ WatsonHealth3DCurveAutoVessels20),
/* harmony export */   "WatsonHealth3DCurveAutoVessels24": () => (/* binding */ WatsonHealth3DCurveAutoVessels24),
/* harmony export */   "WatsonHealth3DCurveAutoVessels32": () => (/* binding */ WatsonHealth3DCurveAutoVessels32),
/* harmony export */   "WatsonHealth3DCurveManual16": () => (/* binding */ WatsonHealth3DCurveManual16),
/* harmony export */   "WatsonHealth3DCurveManual20": () => (/* binding */ WatsonHealth3DCurveManual20),
/* harmony export */   "WatsonHealth3DCurveManual24": () => (/* binding */ WatsonHealth3DCurveManual24),
/* harmony export */   "WatsonHealth3DCurveManual32": () => (/* binding */ WatsonHealth3DCurveManual32),
/* harmony export */   "WatsonHealth3DICa16": () => (/* binding */ WatsonHealth3DICa16),
/* harmony export */   "WatsonHealth3DICa20": () => (/* binding */ WatsonHealth3DICa20),
/* harmony export */   "WatsonHealth3DICa24": () => (/* binding */ WatsonHealth3DICa24),
/* harmony export */   "WatsonHealth3DICa32": () => (/* binding */ WatsonHealth3DICa32),
/* harmony export */   "WatsonHealth3DMprToggle16": () => (/* binding */ WatsonHealth3DMprToggle16),
/* harmony export */   "WatsonHealth3DMprToggle20": () => (/* binding */ WatsonHealth3DMprToggle20),
/* harmony export */   "WatsonHealth3DMprToggle24": () => (/* binding */ WatsonHealth3DMprToggle24),
/* harmony export */   "WatsonHealth3DMprToggle32": () => (/* binding */ WatsonHealth3DMprToggle32),
/* harmony export */   "WatsonHealth3DPrintMesh16": () => (/* binding */ WatsonHealth3DPrintMesh16),
/* harmony export */   "WatsonHealth3DPrintMesh20": () => (/* binding */ WatsonHealth3DPrintMesh20),
/* harmony export */   "WatsonHealth3DPrintMesh24": () => (/* binding */ WatsonHealth3DPrintMesh24),
/* harmony export */   "WatsonHealth3DPrintMesh32": () => (/* binding */ WatsonHealth3DPrintMesh32),
/* harmony export */   "WatsonHealth3DSoftware16": () => (/* binding */ WatsonHealth3DSoftware16),
/* harmony export */   "WatsonHealth3DSoftware20": () => (/* binding */ WatsonHealth3DSoftware20),
/* harmony export */   "WatsonHealth3DSoftware24": () => (/* binding */ WatsonHealth3DSoftware24),
/* harmony export */   "WatsonHealth3DSoftware32": () => (/* binding */ WatsonHealth3DSoftware32),
/* harmony export */   "WatsonHealth3rdPartyConnected16": () => (/* binding */ WatsonHealth3rdPartyConnected16),
/* harmony export */   "WatsonHealth3rdPartyConnected20": () => (/* binding */ WatsonHealth3rdPartyConnected20),
/* harmony export */   "WatsonHealth3rdPartyConnected24": () => (/* binding */ WatsonHealth3rdPartyConnected24),
/* harmony export */   "WatsonHealth3rdPartyConnected32": () => (/* binding */ WatsonHealth3rdPartyConnected32),
/* harmony export */   "WatsonHealthAiResults16": () => (/* binding */ WatsonHealthAiResults16),
/* harmony export */   "WatsonHealthAiResults20": () => (/* binding */ WatsonHealthAiResults20),
/* harmony export */   "WatsonHealthAiResults24": () => (/* binding */ WatsonHealthAiResults24),
/* harmony export */   "WatsonHealthAiResults32": () => (/* binding */ WatsonHealthAiResults32),
/* harmony export */   "WatsonHealthAiResultsHigh16": () => (/* binding */ WatsonHealthAiResultsHigh16),
/* harmony export */   "WatsonHealthAiResultsHigh20": () => (/* binding */ WatsonHealthAiResultsHigh20),
/* harmony export */   "WatsonHealthAiResultsHigh24": () => (/* binding */ WatsonHealthAiResultsHigh24),
/* harmony export */   "WatsonHealthAiResultsHigh32": () => (/* binding */ WatsonHealthAiResultsHigh32),
/* harmony export */   "WatsonHealthAiResultsLow16": () => (/* binding */ WatsonHealthAiResultsLow16),
/* harmony export */   "WatsonHealthAiResultsLow20": () => (/* binding */ WatsonHealthAiResultsLow20),
/* harmony export */   "WatsonHealthAiResultsLow24": () => (/* binding */ WatsonHealthAiResultsLow24),
/* harmony export */   "WatsonHealthAiResultsLow32": () => (/* binding */ WatsonHealthAiResultsLow32),
/* harmony export */   "WatsonHealthAiResultsMedium16": () => (/* binding */ WatsonHealthAiResultsMedium16),
/* harmony export */   "WatsonHealthAiResultsMedium20": () => (/* binding */ WatsonHealthAiResultsMedium20),
/* harmony export */   "WatsonHealthAiResultsMedium24": () => (/* binding */ WatsonHealthAiResultsMedium24),
/* harmony export */   "WatsonHealthAiResultsMedium32": () => (/* binding */ WatsonHealthAiResultsMedium32),
/* harmony export */   "WatsonHealthAiResultsUrgent16": () => (/* binding */ WatsonHealthAiResultsUrgent16),
/* harmony export */   "WatsonHealthAiResultsUrgent20": () => (/* binding */ WatsonHealthAiResultsUrgent20),
/* harmony export */   "WatsonHealthAiResultsUrgent24": () => (/* binding */ WatsonHealthAiResultsUrgent24),
/* harmony export */   "WatsonHealthAiResultsUrgent32": () => (/* binding */ WatsonHealthAiResultsUrgent32),
/* harmony export */   "WatsonHealthAiResultsVeryHigh16": () => (/* binding */ WatsonHealthAiResultsVeryHigh16),
/* harmony export */   "WatsonHealthAiResultsVeryHigh20": () => (/* binding */ WatsonHealthAiResultsVeryHigh20),
/* harmony export */   "WatsonHealthAiResultsVeryHigh24": () => (/* binding */ WatsonHealthAiResultsVeryHigh24),
/* harmony export */   "WatsonHealthAiResultsVeryHigh32": () => (/* binding */ WatsonHealthAiResultsVeryHigh32),
/* harmony export */   "WatsonHealthAiStatus16": () => (/* binding */ WatsonHealthAiStatus16),
/* harmony export */   "WatsonHealthAiStatus20": () => (/* binding */ WatsonHealthAiStatus20),
/* harmony export */   "WatsonHealthAiStatus24": () => (/* binding */ WatsonHealthAiStatus24),
/* harmony export */   "WatsonHealthAiStatus32": () => (/* binding */ WatsonHealthAiStatus32),
/* harmony export */   "WatsonHealthAiStatusComplete16": () => (/* binding */ WatsonHealthAiStatusComplete16),
/* harmony export */   "WatsonHealthAiStatusComplete20": () => (/* binding */ WatsonHealthAiStatusComplete20),
/* harmony export */   "WatsonHealthAiStatusComplete24": () => (/* binding */ WatsonHealthAiStatusComplete24),
/* harmony export */   "WatsonHealthAiStatusComplete32": () => (/* binding */ WatsonHealthAiStatusComplete32),
/* harmony export */   "WatsonHealthAiStatusFailed16": () => (/* binding */ WatsonHealthAiStatusFailed16),
/* harmony export */   "WatsonHealthAiStatusFailed20": () => (/* binding */ WatsonHealthAiStatusFailed20),
/* harmony export */   "WatsonHealthAiStatusFailed24": () => (/* binding */ WatsonHealthAiStatusFailed24),
/* harmony export */   "WatsonHealthAiStatusFailed32": () => (/* binding */ WatsonHealthAiStatusFailed32),
/* harmony export */   "WatsonHealthAiStatusInProgress16": () => (/* binding */ WatsonHealthAiStatusInProgress16),
/* harmony export */   "WatsonHealthAiStatusInProgress20": () => (/* binding */ WatsonHealthAiStatusInProgress20),
/* harmony export */   "WatsonHealthAiStatusInProgress24": () => (/* binding */ WatsonHealthAiStatusInProgress24),
/* harmony export */   "WatsonHealthAiStatusInProgress32": () => (/* binding */ WatsonHealthAiStatusInProgress32),
/* harmony export */   "WatsonHealthAiStatusQueued16": () => (/* binding */ WatsonHealthAiStatusQueued16),
/* harmony export */   "WatsonHealthAiStatusQueued20": () => (/* binding */ WatsonHealthAiStatusQueued20),
/* harmony export */   "WatsonHealthAiStatusQueued24": () => (/* binding */ WatsonHealthAiStatusQueued24),
/* harmony export */   "WatsonHealthAiStatusQueued32": () => (/* binding */ WatsonHealthAiStatusQueued32),
/* harmony export */   "WatsonHealthAiStatusRejected16": () => (/* binding */ WatsonHealthAiStatusRejected16),
/* harmony export */   "WatsonHealthAiStatusRejected20": () => (/* binding */ WatsonHealthAiStatusRejected20),
/* harmony export */   "WatsonHealthAiStatusRejected24": () => (/* binding */ WatsonHealthAiStatusRejected24),
/* harmony export */   "WatsonHealthAiStatusRejected32": () => (/* binding */ WatsonHealthAiStatusRejected32),
/* harmony export */   "_4K16": () => (/* binding */ _4K16),
/* harmony export */   "_4K20": () => (/* binding */ _4K20),
/* harmony export */   "_4K24": () => (/* binding */ _4K24),
/* harmony export */   "_4K32": () => (/* binding */ _4K32),
/* harmony export */   "_4KFilled16": () => (/* binding */ _4KFilled16),
/* harmony export */   "_4KFilled20": () => (/* binding */ _4KFilled20),
/* harmony export */   "_4KFilled24": () => (/* binding */ _4KFilled24),
/* harmony export */   "_4KFilled32": () => (/* binding */ _4KFilled32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _circle, _path62, _path63, _circle2, _path64, _path65, _circle3, _path66, _path67, _circle4, _path68, _path69, _path70, _path71, _path72, _path73, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _circle5, _path83, _path84, _path85, _path86, _circle6, _path87, _path88, _path89, _path90, _circle7, _path91, _path92, _path93, _path94, _circle8, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _circle9, _circle10, _circle11, _path210, _circle12, _circle13, _circle14, _path211, _circle15, _circle16, _circle17, _path212, _circle18, _circle19, _circle20, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _path224, _path225, _path226, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388, _path389, _path390, _path391, _path392, _path393, _path394, _path395, _path396, _path397, _path398, _path399, _path400, _path401, _path402, _path403, _path404, _path405, _path406;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var WatsonHealth3DCursor32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCursor32(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 4L4 4 4 13.01 6 13.01 6 6 13 6 13 4zM29.49 13.12l-9-5a1 1 0 00-1 0l-9 5A1 1 0 0010 14V24a1 1 0 00.52.87l9 5A1 1 0 0020 30a1.05 1.05 0 00.49-.13l9-5A1 1 0 0030 24V14A1 1 0 0029.49 13.12zM19 27.3l-7-3.89V15.69l7 3.89zm1-9.45L13.06 14 20 10.14 26.94 14zm8 5.56L21 27.3V19.58l7-3.89z"
  })), children);
});
var WatsonHealth3DCursor24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCursor24(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 4L4 4 4 13.01 6 13.01 6 6 13 6 13 4zM29.49 13.12l-9-5a1 1 0 00-1 0l-9 5A1 1 0 0010 14V24a1 1 0 00.52.87l9 5A1 1 0 0020 30a1.05 1.05 0 00.49-.13l9-5A1 1 0 0030 24V14A1 1 0 0029.49 13.12zM19 27.3l-7-3.89V15.69l7 3.89zm1-9.45L13.06 14 20 10.14 26.94 14zm8 5.56L21 27.3V19.58l7-3.89z"
  })), children);
});
var WatsonHealth3DCursor20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCursor20(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 4L4 4 4 13.01 6 13.01 6 6 13 6 13 4zM29.49 13.12l-9-5a1 1 0 00-1 0l-9 5A1 1 0 0010 14V24a1 1 0 00.52.87l9 5A1 1 0 0020 30a1.05 1.05 0 00.49-.13l9-5A1 1 0 0030 24V14A1 1 0 0029.49 13.12zM19 27.3l-7-3.89V15.69l7 3.89zm1-9.45L13.06 14 20 10.14 26.94 14zm8 5.56L21 27.3V19.58l7-3.89z"
  })), children);
});
var WatsonHealth3DCursor16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCursor16(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 4L4 4 4 13.01 6 13.01 6 6 13 6 13 4zM29.49 13.12l-9-5a1 1 0 00-1 0l-9 5A1 1 0 0010 14V24a1 1 0 00.52.87l9 5A1 1 0 0020 30a1.05 1.05 0 00.49-.13l9-5A1 1 0 0030 24V14A1 1 0 0029.49 13.12zM19 27.3l-7-3.89V15.69l7 3.89zm1-9.45L13.06 14 20 10.14 26.94 14zm8 5.56L21 27.3V19.58l7-3.89z"
  })), children);
});
var WatsonHealth3DCursorAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCursorAlt32(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 7H17V14H15zM7 15H14V17H7zM15 18H17V25H15zM18 15H25V17H18z"
  })), children);
});
var WatsonHealth3DCursorAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCursorAlt24(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 7H17V14H15zM7 15H14V17H7zM15 18H17V25H15zM18 15H25V17H18z"
  })), children);
});
var WatsonHealth3DCursorAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCursorAlt20(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 7H17V14H15zM7 15H14V17H7zM15 18H17V25H15zM18 15H25V17H18z"
  })), children);
});
var WatsonHealth3DCursorAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCursorAlt16(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 7H17V14H15zM7 15H14V17H7zM15 18H17V25H15zM18 15H25V17H18z"
  })), children);
});
var WatsonHealth3DCurveAutoColon32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCurveAutoColon32(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.5,8H20.1a5,5,0,1,0,0-2H9.5a5.5,5.5,0,0,0,0,11h11a3.5,3.5,0,0,1,0,7H11.9a5,5,0,1,0,0,2h8.6a5.5,5.5,0,0,0,0-11H9.5a3.5,3.5,0,0,1,0-7ZM25,4a3,3,0,1,1-3,3A3,3,0,0,1,25,4ZM7,28a3,3,0,1,1,3-3A3,3,0,0,1,7,28Z"
  })), children);
});
var WatsonHealth3DCurveAutoColon24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCurveAutoColon24(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.5,8H20.1a5,5,0,1,0,0-2H9.5a5.5,5.5,0,0,0,0,11h11a3.5,3.5,0,0,1,0,7H11.9a5,5,0,1,0,0,2h8.6a5.5,5.5,0,0,0,0-11H9.5a3.5,3.5,0,0,1,0-7ZM25,4a3,3,0,1,1-3,3A3,3,0,0,1,25,4ZM7,28a3,3,0,1,1,3-3A3,3,0,0,1,7,28Z"
  })), children);
});
var WatsonHealth3DCurveAutoColon20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCurveAutoColon20(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.5,8H20.1a5,5,0,1,0,0-2H9.5a5.5,5.5,0,0,0,0,11h11a3.5,3.5,0,0,1,0,7H11.9a5,5,0,1,0,0,2h8.6a5.5,5.5,0,0,0,0-11H9.5a3.5,3.5,0,0,1,0-7ZM25,4a3,3,0,1,1-3,3A3,3,0,0,1,25,4ZM7,28a3,3,0,1,1,3-3A3,3,0,0,1,7,28Z"
  })), children);
});
var WatsonHealth3DCurveAutoColon16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCurveAutoColon16(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.5,8H20.1a5,5,0,1,0,0-2H9.5a5.5,5.5,0,0,0,0,11h11a3.5,3.5,0,0,1,0,7H11.9a5,5,0,1,0,0,2h8.6a5.5,5.5,0,0,0,0-11H9.5a3.5,3.5,0,0,1,0-7ZM25,4a3,3,0,1,1-3,3A3,3,0,0,1,25,4ZM7,28a3,3,0,1,1,3-3A3,3,0,0,1,7,28Z"
  })), children);
});
var WatsonHealth3DCurveAutoVessels32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCurveAutoVessels32(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,11a3,3,0,0,1,3-3h.1a5,5,0,1,0,0-2H20a5,5,0,0,0-5,5v1H13a3,3,0,0,1-3-3V7A5,5,0,0,0,5,2H4V4H5A3,3,0,0,1,8,7V9a5,5,0,0,0,5,5h2v7a3,3,0,0,1-3,3h-.1a5,5,0,1,0,0,2H12a5,5,0,0,0,5-5h2.5A2.5,2.5,0,0,1,22,23.5,4.51,4.51,0,0,0,26.5,28H28V26H26.5A2.5,2.5,0,0,1,24,23.5,4.51,4.51,0,0,0,19.5,19H17Zm8-7a3,3,0,1,1-3,3A3,3,0,0,1,25,4ZM7,28a3,3,0,1,1,3-3A3,3,0,0,1,7,28Z"
  })), children);
});
var WatsonHealth3DCurveAutoVessels24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCurveAutoVessels24(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,11a3,3,0,0,1,3-3h.1a5,5,0,1,0,0-2H20a5,5,0,0,0-5,5v1H13a3,3,0,0,1-3-3V7A5,5,0,0,0,5,2H4V4H5A3,3,0,0,1,8,7V9a5,5,0,0,0,5,5h2v7a3,3,0,0,1-3,3h-.1a5,5,0,1,0,0,2H12a5,5,0,0,0,5-5h2.5A2.5,2.5,0,0,1,22,23.5,4.51,4.51,0,0,0,26.5,28H28V26H26.5A2.5,2.5,0,0,1,24,23.5,4.51,4.51,0,0,0,19.5,19H17Zm8-7a3,3,0,1,1-3,3A3,3,0,0,1,25,4ZM7,28a3,3,0,1,1,3-3A3,3,0,0,1,7,28Z"
  })), children);
});
var WatsonHealth3DCurveAutoVessels20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCurveAutoVessels20(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,11a3,3,0,0,1,3-3h.1a5,5,0,1,0,0-2H20a5,5,0,0,0-5,5v1H13a3,3,0,0,1-3-3V7A5,5,0,0,0,5,2H4V4H5A3,3,0,0,1,8,7V9a5,5,0,0,0,5,5h2v7a3,3,0,0,1-3,3h-.1a5,5,0,1,0,0,2H12a5,5,0,0,0,5-5h2.5A2.5,2.5,0,0,1,22,23.5,4.51,4.51,0,0,0,26.5,28H28V26H26.5A2.5,2.5,0,0,1,24,23.5,4.51,4.51,0,0,0,19.5,19H17Zm8-7a3,3,0,1,1-3,3A3,3,0,0,1,25,4ZM7,28a3,3,0,1,1,3-3A3,3,0,0,1,7,28Z"
  })), children);
});
var WatsonHealth3DCurveAutoVessels16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCurveAutoVessels16(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,11a3,3,0,0,1,3-3h.1a5,5,0,1,0,0-2H20a5,5,0,0,0-5,5v1H13a3,3,0,0,1-3-3V7A5,5,0,0,0,5,2H4V4H5A3,3,0,0,1,8,7V9a5,5,0,0,0,5,5h2v7a3,3,0,0,1-3,3h-.1a5,5,0,1,0,0,2H12a5,5,0,0,0,5-5h2.5A2.5,2.5,0,0,1,22,23.5,4.51,4.51,0,0,0,26.5,28H28V26H26.5A2.5,2.5,0,0,1,24,23.5,4.51,4.51,0,0,0,19.5,19H17Zm8-7a3,3,0,1,1-3,3A3,3,0,0,1,25,4ZM7,28a3,3,0,1,1,3-3A3,3,0,0,1,7,28Z"
  })), children);
});
var WatsonHealth3DCurveManual32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCurveManual32(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 21a3 3 0 01-3 3h-.1a5 5 0 100 2H12a5 5 0 005-5zM7 28a3 3 0 113-3A3 3 0 017 28zM15 13H17V19H15zM25 2a5 5 0 00-4.9 4H20a5 5 0 00-5 5h2a3 3 0 013-3h.1A5 5 0 1025 2zm0 8a3 3 0 113-3A3 3 0 0125 10z"
  })), children);
});
var WatsonHealth3DCurveManual24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCurveManual24(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 21a3 3 0 01-3 3h-.1a5 5 0 100 2H12a5 5 0 005-5zM7 28a3 3 0 113-3A3 3 0 017 28zM15 13H17V19H15zM25 2a5 5 0 00-4.9 4H20a5 5 0 00-5 5h2a3 3 0 013-3h.1A5 5 0 1025 2zm0 8a3 3 0 113-3A3 3 0 0125 10z"
  })), children);
});
var WatsonHealth3DCurveManual20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCurveManual20(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 21a3 3 0 01-3 3h-.1a5 5 0 100 2H12a5 5 0 005-5zM7 28a3 3 0 113-3A3 3 0 017 28zM15 13H17V19H15zM25 2a5 5 0 00-4.9 4H20a5 5 0 00-5 5h2a3 3 0 013-3h.1A5 5 0 1025 2zm0 8a3 3 0 113-3A3 3 0 0125 10z"
  })), children);
});
var WatsonHealth3DCurveManual16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DCurveManual16(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 21a3 3 0 01-3 3h-.1a5 5 0 100 2H12a5 5 0 005-5zM7 28a3 3 0 113-3A3 3 0 017 28zM15 13H17V19H15zM25 2a5 5 0 00-4.9 4H20a5 5 0 00-5 5h2a3 3 0 013-3h.1A5 5 0 1025 2zm0 8a3 3 0 113-3A3 3 0 0125 10z"
  })), children);
});
var WatsonHealth3DICa32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DICa32(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 14H10a2 2 0 01-2-2V4a2 2 0 01.59-1.42A3.57 3.57 0 0110 2h5V4H10v8h5zM4 6H6V14H4zM4 2H6V4H4zM27.45 19.11l-6-3a1 1 0 00-.9 0l-6 3A1 1 0 0014 20v7a1 1 0 00.55.89l6 3a1 1 0 00.9 0l6-3A1 1 0 0028 27V20A1 1 0 0027.45 19.11zm-6.45-1L24.76 20 21 21.88 17.24 20zm-5 3.5l4 2v4.76l-4-2zm6 6.76V23.62l4-2v4.76zM23 2H19a2 2 0 00-2 2V14h2V10h4v4h2V4A2 2 0 0023 2zM19 8V4h4V8z"
  })), children);
});
var WatsonHealth3DICa24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DICa24(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 14H10a2 2 0 01-2-2V4a2 2 0 01.59-1.42A3.57 3.57 0 0110 2h5V4H10v8h5zM4 6H6V14H4zM4 2H6V4H4zM27.45 19.11l-6-3a1 1 0 00-.9 0l-6 3A1 1 0 0014 20v7a1 1 0 00.55.89l6 3a1 1 0 00.9 0l6-3A1 1 0 0028 27V20A1 1 0 0027.45 19.11zm-6.45-1L24.76 20 21 21.88 17.24 20zm-5 3.5l4 2v4.76l-4-2zm6 6.76V23.62l4-2v4.76zM23 2H19a2 2 0 00-2 2V14h2V10h4v4h2V4A2 2 0 0023 2zM19 8V4h4V8z"
  })), children);
});
var WatsonHealth3DICa20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DICa20(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 14H10a2 2 0 01-2-2V4a2 2 0 01.59-1.42A3.57 3.57 0 0110 2h5V4H10v8h5zM4 6H6V14H4zM4 2H6V4H4zM27.45 19.11l-6-3a1 1 0 00-.9 0l-6 3A1 1 0 0014 20v7a1 1 0 00.55.89l6 3a1 1 0 00.9 0l6-3A1 1 0 0028 27V20A1 1 0 0027.45 19.11zm-6.45-1L24.76 20 21 21.88 17.24 20zm-5 3.5l4 2v4.76l-4-2zm6 6.76V23.62l4-2v4.76zM23 2H19a2 2 0 00-2 2V14h2V10h4v4h2V4A2 2 0 0023 2zM19 8V4h4V8z"
  })), children);
});
var WatsonHealth3DICa16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DICa16(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 14H10a2 2 0 01-2-2V4a2 2 0 01.59-1.42A3.57 3.57 0 0110 2h5V4H10v8h5zM4 6H6V14H4zM4 2H6V4H4zM27.45 19.11l-6-3a1 1 0 00-.9 0l-6 3A1 1 0 0014 20v7a1 1 0 00.55.89l6 3a1 1 0 00.9 0l6-3A1 1 0 0028 27V20A1 1 0 0027.45 19.11zm-6.45-1L24.76 20 21 21.88 17.24 20zm-5 3.5l4 2v4.76l-4-2zm6 6.76V23.62l4-2v4.76zM23 2H19a2 2 0 00-2 2V14h2V10h4v4h2V4A2 2 0 0023 2zM19 8V4h4V8z"
  })), children);
});
var WatsonHealth3DMprToggle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DMprToggle32(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 2L2 2 2 11 4 11 4 4 11 4 11 2zM2 21L2 30 11 30 11 28 4 28 4 21 2 21zM30 11L30 2 21 2 21 4 28 4 28 11 30 11zM21 30L30 30 30 21 28 21 28 28 21 28 21 30zM25.49 10.13l-9-5a1 1 0 00-1 0l-9 5A1 1 0 006 11V21a1 1 0 00.51.87l9 5a1 1 0 001 0l9-5A1 1 0 0026 21V11A1 1 0 0025.49 10.13zM16 7.14L22.94 11 16 14.86 9.06 11zM8 12.7l7 3.89V24.3L8 20.41zm9 11.6V16.59l7-3.89v7.71z"
  })), children);
});
var WatsonHealth3DMprToggle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DMprToggle24(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 2L2 2 2 11 4 11 4 4 11 4 11 2zM2 21L2 30 11 30 11 28 4 28 4 21 2 21zM30 11L30 2 21 2 21 4 28 4 28 11 30 11zM21 30L30 30 30 21 28 21 28 28 21 28 21 30zM25.49 10.13l-9-5a1 1 0 00-1 0l-9 5A1 1 0 006 11V21a1 1 0 00.51.87l9 5a1 1 0 001 0l9-5A1 1 0 0026 21V11A1 1 0 0025.49 10.13zM16 7.14L22.94 11 16 14.86 9.06 11zM8 12.7l7 3.89V24.3L8 20.41zm9 11.6V16.59l7-3.89v7.71z"
  })), children);
});
var WatsonHealth3DMprToggle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DMprToggle20(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 2L2 2 2 11 4 11 4 4 11 4 11 2zM2 21L2 30 11 30 11 28 4 28 4 21 2 21zM30 11L30 2 21 2 21 4 28 4 28 11 30 11zM21 30L30 30 30 21 28 21 28 28 21 28 21 30zM25.49 10.13l-9-5a1 1 0 00-1 0l-9 5A1 1 0 006 11V21a1 1 0 00.51.87l9 5a1 1 0 001 0l9-5A1 1 0 0026 21V11A1 1 0 0025.49 10.13zM16 7.14L22.94 11 16 14.86 9.06 11zM8 12.7l7 3.89V24.3L8 20.41zm9 11.6V16.59l7-3.89v7.71z"
  })), children);
});
var WatsonHealth3DMprToggle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DMprToggle16(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 2L2 2 2 11 4 11 4 4 11 4 11 2zM2 21L2 30 11 30 11 28 4 28 4 21 2 21zM30 11L30 2 21 2 21 4 28 4 28 11 30 11zM21 30L30 30 30 21 28 21 28 28 21 28 21 30zM25.49 10.13l-9-5a1 1 0 00-1 0l-9 5A1 1 0 006 11V21a1 1 0 00.51.87l9 5a1 1 0 001 0l9-5A1 1 0 0026 21V11A1 1 0 0025.49 10.13zM16 7.14L22.94 11 16 14.86 9.06 11zM8 12.7l7 3.89V24.3L8 20.41zm9 11.6V16.59l7-3.89v7.71z"
  })), children);
});
var WatsonHealth3DPrintMesh32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DPrintMesh32(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9761,15.7832l-2-9a.9992.9992,0,0,0-.4214-.6152l-6-4A1.0008,1.0008,0,0,0,21,2H11a1.0008,1.0008,0,0,0-.5547.168l-6,4a.9992.9992,0,0,0-.4214.6152l-2,9a1.0019,1.0019,0,0,0,.0181.5039l3,10a1,1,0,0,0,.6709.6709l10,3,.0051.0005a.9789.9789,0,0,0,.564,0l.0051-.0005,10-3a1,1,0,0,0,.6709-.6709l3-10A1.0019,1.0019,0,0,0,29.9761,15.7832Zm-19.05.833L7.0168,8.7974l7.2815,2.6479ZM16,12.4971,19.5889,18H12.4111ZM19.3818,20,16,26.7637,12.6182,20Zm-1.68-8.5547,7.2815-2.6479-3.91,7.8188ZM18.19,9.14l3.0961-4.747,3.5152,2.3432ZM16,8.8364,12.8459,4h6.3082Zm-2.19.3032L7.1992,6.7358l3.5152-2.3432Zm-4.8439,8.03-4.802-1.8007L5.3652,9.9668ZM14.07,27.377,7.5679,25.4263l3.1284-4.7969Zm7.2334-6.7476,3.1284,4.7969L17.93,27.377ZM26.6348,9.9668l1.2006,5.4019-4.802,1.8007ZM4.5374,17.6445l4.5944,1.7227L6.3391,23.65ZM25.6609,23.65l-2.7927-4.2827,4.5944-1.7227Z"
  })), children);
});
var WatsonHealth3DPrintMesh24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DPrintMesh24(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9761,15.7832l-2-9a.9992.9992,0,0,0-.4214-.6152l-6-4A1.0008,1.0008,0,0,0,21,2H11a1.0008,1.0008,0,0,0-.5547.168l-6,4a.9992.9992,0,0,0-.4214.6152l-2,9a1.0019,1.0019,0,0,0,.0181.5039l3,10a1,1,0,0,0,.6709.6709l10,3,.0051.0005a.9789.9789,0,0,0,.564,0l.0051-.0005,10-3a1,1,0,0,0,.6709-.6709l3-10A1.0019,1.0019,0,0,0,29.9761,15.7832Zm-19.05.833L7.0168,8.7974l7.2815,2.6479ZM16,12.4971,19.5889,18H12.4111ZM19.3818,20,16,26.7637,12.6182,20Zm-1.68-8.5547,7.2815-2.6479-3.91,7.8188ZM18.19,9.14l3.0961-4.747,3.5152,2.3432ZM16,8.8364,12.8459,4h6.3082Zm-2.19.3032L7.1992,6.7358l3.5152-2.3432Zm-4.8439,8.03-4.802-1.8007L5.3652,9.9668ZM14.07,27.377,7.5679,25.4263l3.1284-4.7969Zm7.2334-6.7476,3.1284,4.7969L17.93,27.377ZM26.6348,9.9668l1.2006,5.4019-4.802,1.8007ZM4.5374,17.6445l4.5944,1.7227L6.3391,23.65ZM25.6609,23.65l-2.7927-4.2827,4.5944-1.7227Z"
  })), children);
});
var WatsonHealth3DPrintMesh20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DPrintMesh20(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9761,15.7832l-2-9a.9992.9992,0,0,0-.4214-.6152l-6-4A1.0008,1.0008,0,0,0,21,2H11a1.0008,1.0008,0,0,0-.5547.168l-6,4a.9992.9992,0,0,0-.4214.6152l-2,9a1.0019,1.0019,0,0,0,.0181.5039l3,10a1,1,0,0,0,.6709.6709l10,3,.0051.0005a.9789.9789,0,0,0,.564,0l.0051-.0005,10-3a1,1,0,0,0,.6709-.6709l3-10A1.0019,1.0019,0,0,0,29.9761,15.7832Zm-19.05.833L7.0168,8.7974l7.2815,2.6479ZM16,12.4971,19.5889,18H12.4111ZM19.3818,20,16,26.7637,12.6182,20Zm-1.68-8.5547,7.2815-2.6479-3.91,7.8188ZM18.19,9.14l3.0961-4.747,3.5152,2.3432ZM16,8.8364,12.8459,4h6.3082Zm-2.19.3032L7.1992,6.7358l3.5152-2.3432Zm-4.8439,8.03-4.802-1.8007L5.3652,9.9668ZM14.07,27.377,7.5679,25.4263l3.1284-4.7969Zm7.2334-6.7476,3.1284,4.7969L17.93,27.377ZM26.6348,9.9668l1.2006,5.4019-4.802,1.8007ZM4.5374,17.6445l4.5944,1.7227L6.3391,23.65ZM25.6609,23.65l-2.7927-4.2827,4.5944-1.7227Z"
  })), children);
});
var WatsonHealth3DPrintMesh16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DPrintMesh16(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9761,15.7832l-2-9a.9992.9992,0,0,0-.4214-.6152l-6-4A1.0008,1.0008,0,0,0,21,2H11a1.0008,1.0008,0,0,0-.5547.168l-6,4a.9992.9992,0,0,0-.4214.6152l-2,9a1.0019,1.0019,0,0,0,.0181.5039l3,10a1,1,0,0,0,.6709.6709l10,3,.0051.0005a.9789.9789,0,0,0,.564,0l.0051-.0005,10-3a1,1,0,0,0,.6709-.6709l3-10A1.0019,1.0019,0,0,0,29.9761,15.7832Zm-19.05.833L7.0168,8.7974l7.2815,2.6479ZM16,12.4971,19.5889,18H12.4111ZM19.3818,20,16,26.7637,12.6182,20Zm-1.68-8.5547,7.2815-2.6479-3.91,7.8188ZM18.19,9.14l3.0961-4.747,3.5152,2.3432ZM16,8.8364,12.8459,4h6.3082Zm-2.19.3032L7.1992,6.7358l3.5152-2.3432Zm-4.8439,8.03-4.802-1.8007L5.3652,9.9668ZM14.07,27.377,7.5679,25.4263l3.1284-4.7969Zm7.2334-6.7476,3.1284,4.7969L17.93,27.377ZM26.6348,9.9668l1.2006,5.4019-4.802,1.8007ZM4.5374,17.6445l4.5944,1.7227L6.3391,23.65ZM25.6609,23.65l-2.7927-4.2827,4.5944-1.7227Z"
  })), children);
});
var WatsonHealth3DSoftware32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DSoftware32(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.49 13.1151l-9-5a1 1 0 00-1 0l-9 5A1.0078 1.0078 0 002 14v9.9951a1 1 0 00.52.87l9 5A1.0045 1.0045 0 0012 30a1.0559 1.0559 0 00.49-.1349l9-5A.9923.9923 0 0022 24V14A1.0079 1.0079 0 0021.49 13.1151zM11 27.2951l-7-3.89v-7.72l7 3.89zm1-9.45L5.06 14 12 10.1351l6.94 3.86zm8 5.56l-7 3.89v-7.72l7-3.89zM30 6L26 6 26 2 24 2 24 6 20 6 20 8 24 8 24 12 26 12 26 8 30 8 30 6z"
  })), children);
});
var WatsonHealth3DSoftware24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DSoftware24(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.49 13.1151l-9-5a1 1 0 00-1 0l-9 5A1.0078 1.0078 0 002 14v9.9951a1 1 0 00.52.87l9 5A1.0045 1.0045 0 0012 30a1.0559 1.0559 0 00.49-.1349l9-5A.9923.9923 0 0022 24V14A1.0079 1.0079 0 0021.49 13.1151zM11 27.2951l-7-3.89v-7.72l7 3.89zm1-9.45L5.06 14 12 10.1351l6.94 3.86zm8 5.56l-7 3.89v-7.72l7-3.89zM30 6L26 6 26 2 24 2 24 6 20 6 20 8 24 8 24 12 26 12 26 8 30 8 30 6z"
  })), children);
});
var WatsonHealth3DSoftware20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DSoftware20(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.49 13.1151l-9-5a1 1 0 00-1 0l-9 5A1.0078 1.0078 0 002 14v9.9951a1 1 0 00.52.87l9 5A1.0045 1.0045 0 0012 30a1.0559 1.0559 0 00.49-.1349l9-5A.9923.9923 0 0022 24V14A1.0079 1.0079 0 0021.49 13.1151zM11 27.2951l-7-3.89v-7.72l7 3.89zm1-9.45L5.06 14 12 10.1351l6.94 3.86zm8 5.56l-7 3.89v-7.72l7-3.89zM30 6L26 6 26 2 24 2 24 6 20 6 20 8 24 8 24 12 26 12 26 8 30 8 30 6z"
  })), children);
});
var WatsonHealth3DSoftware16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3DSoftware16(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.49 13.1151l-9-5a1 1 0 00-1 0l-9 5A1.0078 1.0078 0 002 14v9.9951a1 1 0 00.52.87l9 5A1.0045 1.0045 0 0012 30a1.0559 1.0559 0 00.49-.1349l9-5A.9923.9923 0 0022 24V14A1.0079 1.0079 0 0021.49 13.1151zM11 27.2951l-7-3.89v-7.72l7 3.89zm1-9.45L5.06 14 12 10.1351l6.94 3.86zm8 5.56l-7 3.89v-7.72l7-3.89zM30 6L26 6 26 2 24 2 24 6 20 6 20 8 24 8 24 12 26 12 26 8 30 8 30 6z"
  })), children);
});
var WatsonHealth3rdPartyConnected32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3rdPartyConnected32(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,22a3.86,3.86,0,0,0-2,.57l-3.09-3.1a6,6,0,0,0,0-6.94L24,9.43A3.86,3.86,0,0,0,26,10a4,4,0,1,0-4-4,3.86,3.86,0,0,0,.57,2l-3.1,3.09a6,6,0,0,0-6.94,0L9.43,8A3.86,3.86,0,0,0,10,6a4,4,0,1,0-4,4,3.86,3.86,0,0,0,2-.57l3.09,3.1a6,6,0,0,0,0,6.94L8,22.57A3.86,3.86,0,0,0,6,22a4,4,0,1,0,4,4,3.86,3.86,0,0,0-.57-2l3.1-3.09a6,6,0,0,0,6.94,0L22.57,24A3.86,3.86,0,0,0,22,26a4,4,0,1,0,4-4ZM16,20a4,4,0,1,1,4-4A4,4,0,0,1,16,20Z"
  })), children);
});
var WatsonHealth3rdPartyConnected24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3rdPartyConnected24(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,22a3.86,3.86,0,0,0-2,.57l-3.09-3.1a6,6,0,0,0,0-6.94L24,9.43A3.86,3.86,0,0,0,26,10a4,4,0,1,0-4-4,3.86,3.86,0,0,0,.57,2l-3.1,3.09a6,6,0,0,0-6.94,0L9.43,8A3.86,3.86,0,0,0,10,6a4,4,0,1,0-4,4,3.86,3.86,0,0,0,2-.57l3.09,3.1a6,6,0,0,0,0,6.94L8,22.57A3.86,3.86,0,0,0,6,22a4,4,0,1,0,4,4,3.86,3.86,0,0,0-.57-2l3.1-3.09a6,6,0,0,0,6.94,0L22.57,24A3.86,3.86,0,0,0,22,26a4,4,0,1,0,4-4ZM16,20a4,4,0,1,1,4-4A4,4,0,0,1,16,20Z"
  })), children);
});
var WatsonHealth3rdPartyConnected20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3rdPartyConnected20(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,22a3.86,3.86,0,0,0-2,.57l-3.09-3.1a6,6,0,0,0,0-6.94L24,9.43A3.86,3.86,0,0,0,26,10a4,4,0,1,0-4-4,3.86,3.86,0,0,0,.57,2l-3.1,3.09a6,6,0,0,0-6.94,0L9.43,8A3.86,3.86,0,0,0,10,6a4,4,0,1,0-4,4,3.86,3.86,0,0,0,2-.57l3.09,3.1a6,6,0,0,0,0,6.94L8,22.57A3.86,3.86,0,0,0,6,22a4,4,0,1,0,4,4,3.86,3.86,0,0,0-.57-2l3.1-3.09a6,6,0,0,0,6.94,0L22.57,24A3.86,3.86,0,0,0,22,26a4,4,0,1,0,4-4ZM16,20a4,4,0,1,1,4-4A4,4,0,0,1,16,20Z"
  })), children);
});
var WatsonHealth3rdPartyConnected16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealth3rdPartyConnected16(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,22a3.86,3.86,0,0,0-2,.57l-3.09-3.1a6,6,0,0,0,0-6.94L24,9.43A3.86,3.86,0,0,0,26,10a4,4,0,1,0-4-4,3.86,3.86,0,0,0,.57,2l-3.1,3.09a6,6,0,0,0-6.94,0L9.43,8A3.86,3.86,0,0,0,10,6a4,4,0,1,0-4,4,3.86,3.86,0,0,0,2-.57l3.09,3.1a6,6,0,0,0,0,6.94L8,22.57A3.86,3.86,0,0,0,6,22a4,4,0,1,0,4,4,3.86,3.86,0,0,0-.57-2l3.1-3.09a6,6,0,0,0,6.94,0L22.57,24A3.86,3.86,0,0,0,22,26a4,4,0,1,0,4-4ZM16,20a4,4,0,1,1,4-4A4,4,0,0,1,16,20Z"
  })), children);
});
var _4K32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function _4K32(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 11.03L12 15.03 10 15.03 10 11.03 8 11.03 8 17.03 12 17.03 12 21.03 14 21.03 14 11.03 12 11.03zM24.19 11.03L22 11.03 19 15.42 19 11.03 17 11.03 17 21.03 19 21.03 19 18.3 19.91 16.97 22 21.03 24.19 21.03 21.2 15.41 24.19 11.03z"
  })), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H4a2,2,0,0,1-2-2V8A2,2,0,0,1,4,6H28a2,2,0,0,1,2,2V24A2,2,0,0,1,28,26ZM4,8V24H28V8Z"
  })), children);
});
var _4K24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function _4K24(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 11.03L12 15.03 10 15.03 10 11.03 8 11.03 8 17.03 12 17.03 12 21.03 14 21.03 14 11.03 12 11.03zM24.19 11.03L22 11.03 19 15.42 19 11.03 17 11.03 17 21.03 19 21.03 19 18.3 19.91 16.97 22 21.03 24.19 21.03 21.2 15.41 24.19 11.03z"
  })), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H4a2,2,0,0,1-2-2V8A2,2,0,0,1,4,6H28a2,2,0,0,1,2,2V24A2,2,0,0,1,28,26ZM4,8V24H28V8Z"
  })), children);
});
var _4K20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function _4K20(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 11.03L12 15.03 10 15.03 10 11.03 8 11.03 8 17.03 12 17.03 12 21.03 14 21.03 14 11.03 12 11.03zM24.19 11.03L22 11.03 19 15.42 19 11.03 17 11.03 17 21.03 19 21.03 19 18.3 19.91 16.97 22 21.03 24.19 21.03 21.2 15.41 24.19 11.03z"
  })), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H4a2,2,0,0,1-2-2V8A2,2,0,0,1,4,6H28a2,2,0,0,1,2,2V24A2,2,0,0,1,28,26ZM4,8V24H28V8Z"
  })), children);
});
var _4K16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function _4K16(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 11.03L12 15.03 10 15.03 10 11.03 8 11.03 8 17.03 12 17.03 12 21.03 14 21.03 14 11.03 12 11.03zM24.19 11.03L22 11.03 19 15.42 19 11.03 17 11.03 17 21.03 19 21.03 19 18.3 19.91 16.97 22 21.03 24.19 21.03 21.2 15.41 24.19 11.03z"
  })), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H4a2,2,0,0,1-2-2V8A2,2,0,0,1,4,6H28a2,2,0,0,1,2,2V24A2,2,0,0,1,28,26ZM4,8V24H28V8Z"
  })), children);
});
var _4KFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function _4KFilled32(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM14,21H12V17H8V11h2v4h2V11h2Zm10.19,0H22l-2.09-4.06L19,18.27V21H17V11h2v4.39L22,11h2.19l-3,4.38Z"
  })), children);
});
var _4KFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function _4KFilled24(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM14,21H12V17H8V11h2v4h2V11h2Zm10.19,0H22l-2.09-4.06L19,18.27V21H17V11h2v4.39L22,11h2.19l-3,4.38Z"
  })), children);
});
var _4KFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function _4KFilled20(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM14,21H12V17H8V11h2v4h2V11h2Zm10.19,0H22l-2.09-4.06L19,18.27V21H17V11h2v4.39L22,11h2.19l-3,4.38Z"
  })), children);
});
var _4KFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function _4KFilled16(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM14,21H12V17H8V11h2v4h2V11h2Zm10.19,0H22l-2.09-4.06L19,18.27V21H17V11h2v4.39L22,11h2.19l-3,4.38Z"
  })), children);
});
var Accessibility32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Accessibility32(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.55 26.11L26.5 27.63 23.66 21H15a2 2 0 01-2-2V13a2 2 0 014 0v4h7V15H19V13a4 4 0 00-8 0v1a9 9 0 108.77 11H17.71A7 7 0 1111 16v3a4 4 0 004 4h7.34l3.16 7.37 4.95-2.48zM15.5 8A3.5 3.5 0 1119 4.5 3.5 3.5 0 0115.5 8zm0-5A1.5 1.5 0 1017 4.5 1.5 1.5 0 0015.5 3z"
  })), children);
});
var Accessibility24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Accessibility24(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.55 26.11L26.5 27.63 23.66 21H15a2 2 0 01-2-2V13a2 2 0 014 0v4h7V15H19V13a4 4 0 00-8 0v1a9 9 0 108.77 11H17.71A7 7 0 1111 16v3a4 4 0 004 4h7.34l3.16 7.37 4.95-2.48zM15.5 8A3.5 3.5 0 1119 4.5 3.5 3.5 0 0115.5 8zm0-5A1.5 1.5 0 1017 4.5 1.5 1.5 0 0015.5 3z"
  })), children);
});
var Accessibility20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Accessibility20(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.55 26.11L26.5 27.63 23.66 21H15a2 2 0 01-2-2V13a2 2 0 014 0v4h7V15H19V13a4 4 0 00-8 0v1a9 9 0 108.77 11H17.71A7 7 0 1111 16v3a4 4 0 004 4h7.34l3.16 7.37 4.95-2.48zM15.5 8A3.5 3.5 0 1119 4.5 3.5 3.5 0 0115.5 8zm0-5A1.5 1.5 0 1017 4.5 1.5 1.5 0 0015.5 3z"
  })), children);
});
var Accessibility16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Accessibility16(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.55 26.11L26.5 27.63 23.66 21H15a2 2 0 01-2-2V13a2 2 0 014 0v4h7V15H19V13a4 4 0 00-8 0v1a9 9 0 108.77 11H17.71A7 7 0 1111 16v3a4 4 0 004 4h7.34l3.16 7.37 4.95-2.48zM15.5 8A3.5 3.5 0 1119 4.5 3.5 3.5 0 0115.5 8zm0-5A1.5 1.5 0 1017 4.5 1.5 1.5 0 0015.5 3z"
  })), children);
});
var AccessibilityAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccessibilityAlt32(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 14L23 12 9 12 9 14 14 14 14 16.734 10.132 23.504 11.868 24.496 15.58 18 16.42 18 20.132 24.496 21.868 23.504 18 16.734 18 14 23 14z"
  })), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "9",
    r: "2"
  })), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var AccessibilityAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccessibilityAlt24(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 14L23 12 9 12 9 14 14 14 14 16.734 10.132 23.504 11.868 24.496 15.58 18 16.42 18 20.132 24.496 21.868 23.504 18 16.734 18 14 23 14z"
  })), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "9",
    r: "2"
  })), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var AccessibilityAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccessibilityAlt20(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 14L23 12 9 12 9 14 14 14 14 16.734 10.132 23.504 11.868 24.496 15.58 18 16.42 18 20.132 24.496 21.868 23.504 18 16.734 18 14 23 14z"
  })), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "9",
    r: "2"
  })), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var AccessibilityAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccessibilityAlt16(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 14L23 12 9 12 9 14 14 14 14 16.734 10.132 23.504 11.868 24.496 15.58 18 16.42 18 20.132 24.496 21.868 23.504 18 16.734 18 14 23 14z"
  })), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "9",
    r: "2"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var AccessibilityColor32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccessibilityColor32(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,16,14Z"
  })), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24a10.6547,10.6547,0,0,1-9.97-7.7576L5.9692,16l.0606-.2424A10.6547,10.6547,0,0,1,16,8a10.6547,10.6547,0,0,1,9.97,7.7576L26.0308,16l-.0606.2424A10.6547,10.6547,0,0,1,16,24ZM8.0352,16A8.5975,8.5975,0,0,0,16,22a8.5975,8.5975,0,0,0,7.9648-6A8.5975,8.5975,0,0,0,16,10,8.5975,8.5975,0,0,0,8.0352,16Z"
  })), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var AccessibilityColor24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccessibilityColor24(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,16,14Z"
  })), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24a10.6547,10.6547,0,0,1-9.97-7.7576L5.9692,16l.0606-.2424A10.6547,10.6547,0,0,1,16,8a10.6547,10.6547,0,0,1,9.97,7.7576L26.0308,16l-.0606.2424A10.6547,10.6547,0,0,1,16,24ZM8.0352,16A8.5975,8.5975,0,0,0,16,22a8.5975,8.5975,0,0,0,7.9648-6A8.5975,8.5975,0,0,0,16,10,8.5975,8.5975,0,0,0,8.0352,16Z"
  })), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var AccessibilityColor20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccessibilityColor20(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,16,14Z"
  })), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24a10.6547,10.6547,0,0,1-9.97-7.7576L5.9692,16l.0606-.2424A10.6547,10.6547,0,0,1,16,8a10.6547,10.6547,0,0,1,9.97,7.7576L26.0308,16l-.0606.2424A10.6547,10.6547,0,0,1,16,24ZM8.0352,16A8.5975,8.5975,0,0,0,16,22a8.5975,8.5975,0,0,0,7.9648-6A8.5975,8.5975,0,0,0,16,10,8.5975,8.5975,0,0,0,8.0352,16Z"
  })), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var AccessibilityColor16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccessibilityColor16(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,16,14Z"
  })), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24a10.6547,10.6547,0,0,1-9.97-7.7576L5.9692,16l.0606-.2424A10.6547,10.6547,0,0,1,16,8a10.6547,10.6547,0,0,1,9.97,7.7576L26.0308,16l-.0606.2424A10.6547,10.6547,0,0,1,16,24ZM8.0352,16A8.5975,8.5975,0,0,0,16,22a8.5975,8.5975,0,0,0,7.9648-6A8.5975,8.5975,0,0,0,16,10,8.5975,8.5975,0,0,0,8.0352,16Z"
  })), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var AccessibilityColorFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccessibilityColorFilled32(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a8.5975,8.5975,0,0,0-7.9648,6A8.5975,8.5975,0,0,0,16,22a8.5975,8.5975,0,0,0,7.9648-6A8.5975,8.5975,0,0,0,16,10Zm0,10a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Z"
  })), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,22a10.6543,10.6543,0,0,1-9.97-7.7578L5.9692,16l.0606-.2422A10.6543,10.6543,0,0,1,16,8a10.6543,10.6543,0,0,1,9.97,7.7578L26.0308,16l-.0606.2422A10.6543,10.6543,0,0,1,16,24Z"
  })), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,16,14Z"
  })), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,24a10.6547,10.6547,0,0,1-9.97-7.7576L5.9692,16l.0606-.2424A10.6547,10.6547,0,0,1,16,8a10.6547,10.6547,0,0,1,9.97,7.7576L26.0308,16l-.0606.2424A10.6547,10.6547,0,0,1,16,24ZM8.0352,16A8.5975,8.5975,0,0,0,16,22a8.5975,8.5975,0,0,0,7.9648-6A8.5975,8.5975,0,0,0,16,10,8.5975,8.5975,0,0,0,8.0352,16Z"
  })), children);
});
var AccessibilityColorFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccessibilityColorFilled24(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a8.5975,8.5975,0,0,0-7.9648,6A8.5975,8.5975,0,0,0,16,22a8.5975,8.5975,0,0,0,7.9648-6A8.5975,8.5975,0,0,0,16,10Zm0,10a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Z"
  })), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,22a10.6543,10.6543,0,0,1-9.97-7.7578L5.9692,16l.0606-.2422A10.6543,10.6543,0,0,1,16,8a10.6543,10.6543,0,0,1,9.97,7.7578L26.0308,16l-.0606.2422A10.6543,10.6543,0,0,1,16,24Z"
  })), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,16,14Z"
  })), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,24a10.6547,10.6547,0,0,1-9.97-7.7576L5.9692,16l.0606-.2424A10.6547,10.6547,0,0,1,16,8a10.6547,10.6547,0,0,1,9.97,7.7576L26.0308,16l-.0606.2424A10.6547,10.6547,0,0,1,16,24ZM8.0352,16A8.5975,8.5975,0,0,0,16,22a8.5975,8.5975,0,0,0,7.9648-6A8.5975,8.5975,0,0,0,16,10,8.5975,8.5975,0,0,0,8.0352,16Z"
  })), children);
});
var AccessibilityColorFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccessibilityColorFilled20(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a8.5975,8.5975,0,0,0-7.9648,6A8.5975,8.5975,0,0,0,16,22a8.5975,8.5975,0,0,0,7.9648-6A8.5975,8.5975,0,0,0,16,10Zm0,10a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Z"
  })), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,22a10.6543,10.6543,0,0,1-9.97-7.7578L5.9692,16l.0606-.2422A10.6543,10.6543,0,0,1,16,8a10.6543,10.6543,0,0,1,9.97,7.7578L26.0308,16l-.0606.2422A10.6543,10.6543,0,0,1,16,24Z"
  })), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,16,14Z"
  })), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,24a10.6547,10.6547,0,0,1-9.97-7.7576L5.9692,16l.0606-.2424A10.6547,10.6547,0,0,1,16,8a10.6547,10.6547,0,0,1,9.97,7.7576L26.0308,16l-.0606.2424A10.6547,10.6547,0,0,1,16,24ZM8.0352,16A8.5975,8.5975,0,0,0,16,22a8.5975,8.5975,0,0,0,7.9648-6A8.5975,8.5975,0,0,0,16,10,8.5975,8.5975,0,0,0,8.0352,16Z"
  })), children);
});
var AccessibilityColorFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccessibilityColorFilled16(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a8.5975,8.5975,0,0,0-7.9648,6A8.5975,8.5975,0,0,0,16,22a8.5975,8.5975,0,0,0,7.9648-6A8.5975,8.5975,0,0,0,16,10Zm0,10a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Z"
  })), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,22a10.6543,10.6543,0,0,1-9.97-7.7578L5.9692,16l.0606-.2422A10.6543,10.6543,0,0,1,16,8a10.6543,10.6543,0,0,1,9.97,7.7578L26.0308,16l-.0606.2422A10.6543,10.6543,0,0,1,16,24Z"
  })), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,16,14Z"
  })), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,24a10.6547,10.6547,0,0,1-9.97-7.7576L5.9692,16l.0606-.2424A10.6547,10.6547,0,0,1,16,8a10.6547,10.6547,0,0,1,9.97,7.7576L26.0308,16l-.0606.2424A10.6547,10.6547,0,0,1,16,24ZM8.0352,16A8.5975,8.5975,0,0,0,16,22a8.5975,8.5975,0,0,0,7.9648-6A8.5975,8.5975,0,0,0,16,10,8.5975,8.5975,0,0,0,8.0352,16Z"
  })), children);
});
var Account32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Account32(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,14H19v2H8Zm0,5H21v2H8Z"
  })), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,2V8H4V6ZM4,26V10H28V26Z"
  })), children);
});
var Account24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Account24(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,14H19v2H8Zm0,5H21v2H8Z"
  })), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,2V8H4V6ZM4,26V10H28V26Z"
  })), children);
});
var Account20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Account20(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,14H19v2H8Zm0,5H21v2H8Z"
  })), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,2V8H4V6ZM4,26V10H28V26Z"
  })), children);
});
var Account16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Account16(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,14H19v2H8Zm0,5H21v2H8Z"
  })), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,2V8H4V6ZM4,26V10H28V26Z"
  })), children);
});
var AccumulationIce32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccumulationIce32(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 8L22 16 23 18 24 16 24 8 22 8zM18 8L18 18 19 20 20 18 20 8 18 8z"
  })), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4a2.0023,2.0023,0,0,0-2,2V26H6V22h4V20H6V16h4V14H6V10h8v4l1,2,1-2V8H6V6A2.0023,2.0023,0,0,0,4,4H2V6H4V26a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6h2V4Z"
  })), children);
});
var AccumulationIce24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccumulationIce24(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 8L22 16 23 18 24 16 24 8 22 8zM18 8L18 18 19 20 20 18 20 8 18 8z"
  })), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4a2.0023,2.0023,0,0,0-2,2V26H6V22h4V20H6V16h4V14H6V10h8v4l1,2,1-2V8H6V6A2.0023,2.0023,0,0,0,4,4H2V6H4V26a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6h2V4Z"
  })), children);
});
var AccumulationIce20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccumulationIce20(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 8L22 16 23 18 24 16 24 8 22 8zM18 8L18 18 19 20 20 18 20 8 18 8z"
  })), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4a2.0023,2.0023,0,0,0-2,2V26H6V22h4V20H6V16h4V14H6V10h8v4l1,2,1-2V8H6V6A2.0023,2.0023,0,0,0,4,4H2V6H4V26a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6h2V4Z"
  })), children);
});
var AccumulationIce16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccumulationIce16(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 8L22 16 23 18 24 16 24 8 22 8zM18 8L18 18 19 20 20 18 20 8 18 8z"
  })), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4a2.0023,2.0023,0,0,0-2,2V26H6V22h4V20H6V16h4V14H6V10h8v4l1,2,1-2V8H6V6A2.0023,2.0023,0,0,0,4,4H2V6H4V26a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6h2V4Z"
  })), children);
});
var AccumulationPrecipitation32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccumulationPrecipitation32(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 16H18V18H16zM18 18H20V20H18zM20 20H22V22H20zM20 16H22V18H20zM16 20H18V22H16zM20 12a3.8978 3.8978 0 01-4-3.777 3.9017 3.9017 0 01.6533-2.0639L19.17 2.4141a1.0381 1.0381 0 011.6592 0L23.3154 6.11A3.9693 3.9693 0 0124 8.223 3.8978 3.8978 0 0120 12zm0-7.2368L18.3438 7.2257A1.89 1.89 0 0018 8.223 1.9 1.9 0 0020 10a1.9 1.9 0 002-1.777 1.98 1.98 0 00-.375-1.0466z"
  })), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4a2.0023,2.0023,0,0,0-2,2V26H6V10H8v8l1,2,1-2V10h2v4l1,2,1-2V8H6V6A2.0023,2.0023,0,0,0,4,4H2V6H4V26a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6h2V4Z"
  })), children);
});
var AccumulationPrecipitation24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccumulationPrecipitation24(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 16H18V18H16zM18 18H20V20H18zM20 20H22V22H20zM20 16H22V18H20zM16 20H18V22H16zM20 12a3.8978 3.8978 0 01-4-3.777 3.9017 3.9017 0 01.6533-2.0639L19.17 2.4141a1.0381 1.0381 0 011.6592 0L23.3154 6.11A3.9693 3.9693 0 0124 8.223 3.8978 3.8978 0 0120 12zm0-7.2368L18.3438 7.2257A1.89 1.89 0 0018 8.223 1.9 1.9 0 0020 10a1.9 1.9 0 002-1.777 1.98 1.98 0 00-.375-1.0466z"
  })), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4a2.0023,2.0023,0,0,0-2,2V26H6V10H8v8l1,2,1-2V10h2v4l1,2,1-2V8H6V6A2.0023,2.0023,0,0,0,4,4H2V6H4V26a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6h2V4Z"
  })), children);
});
var AccumulationPrecipitation20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccumulationPrecipitation20(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 16H18V18H16zM18 18H20V20H18zM20 20H22V22H20zM20 16H22V18H20zM16 20H18V22H16zM20 12a3.8978 3.8978 0 01-4-3.777 3.9017 3.9017 0 01.6533-2.0639L19.17 2.4141a1.0381 1.0381 0 011.6592 0L23.3154 6.11A3.9693 3.9693 0 0124 8.223 3.8978 3.8978 0 0120 12zm0-7.2368L18.3438 7.2257A1.89 1.89 0 0018 8.223 1.9 1.9 0 0020 10a1.9 1.9 0 002-1.777 1.98 1.98 0 00-.375-1.0466z"
  })), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4a2.0023,2.0023,0,0,0-2,2V26H6V10H8v8l1,2,1-2V10h2v4l1,2,1-2V8H6V6A2.0023,2.0023,0,0,0,4,4H2V6H4V26a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6h2V4Z"
  })), children);
});
var AccumulationPrecipitation16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccumulationPrecipitation16(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 16H18V18H16zM18 18H20V20H18zM20 20H22V22H20zM20 16H22V18H20zM16 20H18V22H16zM20 12a3.8978 3.8978 0 01-4-3.777 3.9017 3.9017 0 01.6533-2.0639L19.17 2.4141a1.0381 1.0381 0 011.6592 0L23.3154 6.11A3.9693 3.9693 0 0124 8.223 3.8978 3.8978 0 0120 12zm0-7.2368L18.3438 7.2257A1.89 1.89 0 0018 8.223 1.9 1.9 0 0020 10a1.9 1.9 0 002-1.777 1.98 1.98 0 00-.375-1.0466z"
  })), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4a2.0023,2.0023,0,0,0-2,2V26H6V10H8v8l1,2,1-2V10h2v4l1,2,1-2V8H6V6A2.0023,2.0023,0,0,0,4,4H2V6H4V26a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6h2V4Z"
  })), children);
});
var AccumulationRain32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccumulationRain32(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4a2.0023,2.0023,0,0,0-2,2V8H24a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,20,5a.9894.9894,0,0,0-.9468.6787A3.44,3.44,0,0,1,16,8a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,12,5a.971.971,0,0,0-.9468.6787A3.44,3.44,0,0,1,8,8H6V6A2.0023,2.0023,0,0,0,4,4H2V6H4V26a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6h2V4ZM6,26V22h4V20H6V16h4V14H6V10H8a4.9316,4.9316,0,0,0,4-1.9873,5.0192,5.0192,0,0,0,8,0A4.9316,4.9316,0,0,0,24,10h2V26Z"
  })), children);
});
var AccumulationRain24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccumulationRain24(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4a2.0023,2.0023,0,0,0-2,2V8H24a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,20,5a.9894.9894,0,0,0-.9468.6787A3.44,3.44,0,0,1,16,8a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,12,5a.971.971,0,0,0-.9468.6787A3.44,3.44,0,0,1,8,8H6V6A2.0023,2.0023,0,0,0,4,4H2V6H4V26a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6h2V4ZM6,26V22h4V20H6V16h4V14H6V10H8a4.9316,4.9316,0,0,0,4-1.9873,5.0192,5.0192,0,0,0,8,0A4.9316,4.9316,0,0,0,24,10h2V26Z"
  })), children);
});
var AccumulationRain20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccumulationRain20(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4a2.0023,2.0023,0,0,0-2,2V8H24a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,20,5a.9894.9894,0,0,0-.9468.6787A3.44,3.44,0,0,1,16,8a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,12,5a.971.971,0,0,0-.9468.6787A3.44,3.44,0,0,1,8,8H6V6A2.0023,2.0023,0,0,0,4,4H2V6H4V26a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6h2V4ZM6,26V22h4V20H6V16h4V14H6V10H8a4.9316,4.9316,0,0,0,4-1.9873,5.0192,5.0192,0,0,0,8,0A4.9316,4.9316,0,0,0,24,10h2V26Z"
  })), children);
});
var AccumulationRain16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccumulationRain16(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4a2.0023,2.0023,0,0,0-2,2V8H24a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,20,5a.9894.9894,0,0,0-.9468.6787A3.44,3.44,0,0,1,16,8a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,12,5a.971.971,0,0,0-.9468.6787A3.44,3.44,0,0,1,8,8H6V6A2.0023,2.0023,0,0,0,4,4H2V6H4V26a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6h2V4ZM6,26V22h4V20H6V16h4V14H6V10H8a4.9316,4.9316,0,0,0,4-1.9873,5.0192,5.0192,0,0,0,8,0A4.9316,4.9316,0,0,0,24,10h2V26Z"
  })), children);
});
var AccumulationSnow32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccumulationSnow32(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 2H14V4H12zM14 4H16V6H14zM16 6H18V8H16zM16 2H18V4H16zM12 6H14V8H12zM14 18H16V20H14zM16 20H18V22H16zM18 22H20V24H18zM18 18H20V20H18zM14 22H16V24H14zM18 10H20V12H18zM20 12H22V14H20zM22 14H24V16H22zM22 10H24V12H22zM18 14H20V16H18z"
  })), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4a2.0023,2.0023,0,0,0-2,2V26H6V22h4V20H6V16h4V14H6V10h4V8H6V6A2.0023,2.0023,0,0,0,4,4H2V6H4V26a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6h2V4Z"
  })), children);
});
var AccumulationSnow24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccumulationSnow24(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 2H14V4H12zM14 4H16V6H14zM16 6H18V8H16zM16 2H18V4H16zM12 6H14V8H12zM14 18H16V20H14zM16 20H18V22H16zM18 22H20V24H18zM18 18H20V20H18zM14 22H16V24H14zM18 10H20V12H18zM20 12H22V14H20zM22 14H24V16H22zM22 10H24V12H22zM18 14H20V16H18z"
  })), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4a2.0023,2.0023,0,0,0-2,2V26H6V22h4V20H6V16h4V14H6V10h4V8H6V6A2.0023,2.0023,0,0,0,4,4H2V6H4V26a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6h2V4Z"
  })), children);
});
var AccumulationSnow20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccumulationSnow20(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 2H14V4H12zM14 4H16V6H14zM16 6H18V8H16zM16 2H18V4H16zM12 6H14V8H12zM14 18H16V20H14zM16 20H18V22H16zM18 22H20V24H18zM18 18H20V20H18zM14 22H16V24H14zM18 10H20V12H18zM20 12H22V14H20zM22 14H24V16H22zM22 10H24V12H22zM18 14H20V16H18z"
  })), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4a2.0023,2.0023,0,0,0-2,2V26H6V22h4V20H6V16h4V14H6V10h4V8H6V6A2.0023,2.0023,0,0,0,4,4H2V6H4V26a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6h2V4Z"
  })), children);
});
var AccumulationSnow16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AccumulationSnow16(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 2H14V4H12zM14 4H16V6H14zM16 6H18V8H16zM16 2H18V4H16zM12 6H14V8H12zM14 18H16V20H14zM16 20H18V22H16zM18 22H20V24H18zM18 18H20V20H18zM14 22H16V24H14zM18 10H20V12H18zM20 12H22V14H20zM22 14H24V16H22zM22 10H24V12H22zM18 14H20V16H18z"
  })), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4a2.0023,2.0023,0,0,0-2,2V26H6V22h4V20H6V16h4V14H6V10h4V8H6V6A2.0023,2.0023,0,0,0,4,4H2V6H4V26a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6h2V4Z"
  })), children);
});
var Activity32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Activity32(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,29a1,1,0,0,1-.92-.62L6.33,17H2V15H7a1,1,0,0,1,.92.62L12,25.28,20.06,3.65A1,1,0,0,1,21,3a1,1,0,0,1,.93.68L25.72,15H30v2H25a1,1,0,0,1-.95-.68L21,7,12.94,28.35A1,1,0,0,1,12,29Z"
  })), children);
});
var Activity24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Activity24(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,29a1,1,0,0,1-.92-.62L6.33,17H2V15H7a1,1,0,0,1,.92.62L12,25.28,20.06,3.65A1,1,0,0,1,21,3a1,1,0,0,1,.93.68L25.72,15H30v2H25a1,1,0,0,1-.95-.68L21,7,12.94,28.35A1,1,0,0,1,12,29Z"
  })), children);
});
var Activity20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Activity20(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,29a1,1,0,0,1-.92-.62L6.33,17H2V15H7a1,1,0,0,1,.92.62L12,25.28,20.06,3.65A1,1,0,0,1,21,3a1,1,0,0,1,.93.68L25.72,15H30v2H25a1,1,0,0,1-.95-.68L21,7,12.94,28.35A1,1,0,0,1,12,29Z"
  })), children);
});
var Activity16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Activity16(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,29a1,1,0,0,1-.92-.62L6.33,17H2V15H7a1,1,0,0,1,.92.62L12,25.28,20.06,3.65A1,1,0,0,1,21,3a1,1,0,0,1,.93.68L25.72,15H30v2H25a1,1,0,0,1-.95-.68L21,7,12.94,28.35A1,1,0,0,1,12,29Z"
  })), children);
});
var Add32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Add32(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 15L17 8 15 8 15 15 8 15 8 17 15 17 15 24 17 24 17 17 24 17 24 15z"
  })), children);
});
var Add24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Add24(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 15L17 8 15 8 15 15 8 15 8 17 15 17 15 24 17 24 17 17 24 17 24 15z"
  })), children);
});
var Add20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Add20(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 15L17 8 15 8 15 15 8 15 8 17 15 17 15 24 17 24 17 17 24 17 24 15z"
  })), children);
});
var Add16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Add16(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 15L17 8 15 8 15 15 8 15 8 17 15 17 15 24 17 24 17 17 24 17 24 15z"
  })), children);
});
var AddAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AddAlt32(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4c6.6,0,12,5.4,12,12s-5.4,12-12,12S4,22.6,4,16S9.4,4,16,4 M16,2C8.3,2,2,8.3,2,16s6.3,14,14,14s14-6.3,14-14\tS23.7,2,16,2z"
  })), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 15L17 15 17 8 15 8 15 15 8 15 8 17 15 17 15 24 17 24 17 17 24 17z"
  })), children);
});
var AddAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AddAlt24(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4c6.6,0,12,5.4,12,12s-5.4,12-12,12S4,22.6,4,16S9.4,4,16,4 M16,2C8.3,2,2,8.3,2,16s6.3,14,14,14s14-6.3,14-14\tS23.7,2,16,2z"
  })), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 15L17 15 17 8 15 8 15 15 8 15 8 17 15 17 15 24 17 24 17 17 24 17z"
  })), children);
});
var AddAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AddAlt20(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4c6.6,0,12,5.4,12,12s-5.4,12-12,12S4,22.6,4,16S9.4,4,16,4 M16,2C8.3,2,2,8.3,2,16s6.3,14,14,14s14-6.3,14-14\tS23.7,2,16,2z"
  })), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 15L17 15 17 8 15 8 15 15 8 15 8 17 15 17 15 24 17 24 17 17 24 17z"
  })), children);
});
var AddAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AddAlt16(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4c6.6,0,12,5.4,12,12s-5.4,12-12,12S4,22.6,4,16S9.4,4,16,4 M16,2C8.3,2,2,8.3,2,16s6.3,14,14,14s14-6.3,14-14\tS23.7,2,16,2z"
  })), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 15L17 15 17 8 15 8 15 15 8 15 8 17 15 17 15 24 17 24 17 17 24 17z"
  })), children);
});
var AddFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AddFilled32(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14.1725,14.1725,0,0,0,2,16,14.1725,14.1725,0,0,0,16,30,14.1725,14.1725,0,0,0,30,16,14.1725,14.1725,0,0,0,16,2Zm8,15H17v7H15V17H8V15h7V8h2v7h7Z"
  })), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M24 17L17 17 17 24 15 24 15 17 8 17 8 15 15 15 15 8 17 8 17 15 24 15 24 17z",
    "data-icon-path": "inner-path"
  })), children);
});
var AddFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AddFilled24(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14.1725,14.1725,0,0,0,2,16,14.1725,14.1725,0,0,0,16,30,14.1725,14.1725,0,0,0,30,16,14.1725,14.1725,0,0,0,16,2Zm8,15H17v7H15V17H8V15h7V8h2v7h7Z"
  })), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M24 17L17 17 17 24 15 24 15 17 8 17 8 15 15 15 15 8 17 8 17 15 24 15 24 17z",
    "data-icon-path": "inner-path"
  })), children);
});
var AddFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AddFilled20(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14.1725,14.1725,0,0,0,2,16,14.1725,14.1725,0,0,0,16,30,14.1725,14.1725,0,0,0,30,16,14.1725,14.1725,0,0,0,16,2Zm8,15H17v7H15V17H8V15h7V8h2v7h7Z"
  })), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M24 17L17 17 17 24 15 24 15 17 8 17 8 15 15 15 15 8 17 8 17 15 24 15 24 17z",
    "data-icon-path": "inner-path"
  })), children);
});
var AddFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AddFilled16(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14.1725,14.1725,0,0,0,2,16,14.1725,14.1725,0,0,0,16,30,14.1725,14.1725,0,0,0,30,16,14.1725,14.1725,0,0,0,16,2Zm8,15H17v7H15V17H8V15h7V8h2v7h7Z"
  })), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M24 17L17 17 17 24 15 24 15 17 8 17 8 15 15 15 15 8 17 8 17 15 24 15 24 17z",
    "data-icon-path": "inner-path"
  })), children);
});
var AddComment32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AddComment32(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.74,30,16,29l4-7h6a2,2,0,0,0,2-2V8a2,2,0,0,0-2-2H6A2,2,0,0,0,4,8V20a2,2,0,0,0,2,2h9v2H6a4,4,0,0,1-4-4V8A4,4,0,0,1,6,4H26a4,4,0,0,1,4,4V20a4,4,0,0,1-4,4H21.16Z"
  })), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 9L15 9 15 13 11 13 11 15 15 15 15 19 17 19 17 15 21 15 21 13 17 13 17 9z"
  })), children);
});
var AddComment24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AddComment24(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.74,30,16,29l4-7h6a2,2,0,0,0,2-2V8a2,2,0,0,0-2-2H6A2,2,0,0,0,4,8V20a2,2,0,0,0,2,2h9v2H6a4,4,0,0,1-4-4V8A4,4,0,0,1,6,4H26a4,4,0,0,1,4,4V20a4,4,0,0,1-4,4H21.16Z"
  })), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 9L15 9 15 13 11 13 11 15 15 15 15 19 17 19 17 15 21 15 21 13 17 13 17 9z"
  })), children);
});
var AddComment20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AddComment20(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.74,30,16,29l4-7h6a2,2,0,0,0,2-2V8a2,2,0,0,0-2-2H6A2,2,0,0,0,4,8V20a2,2,0,0,0,2,2h9v2H6a4,4,0,0,1-4-4V8A4,4,0,0,1,6,4H26a4,4,0,0,1,4,4V20a4,4,0,0,1-4,4H21.16Z"
  })), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 9L15 9 15 13 11 13 11 15 15 15 15 19 17 19 17 15 21 15 21 13 17 13 17 9z"
  })), children);
});
var AddComment16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AddComment16(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.74,30,16,29l4-7h6a2,2,0,0,0,2-2V8a2,2,0,0,0-2-2H6A2,2,0,0,0,4,8V20a2,2,0,0,0,2,2h9v2H6a4,4,0,0,1-4-4V8A4,4,0,0,1,6,4H26a4,4,0,0,1,4,4V20a4,4,0,0,1-4,4H21.16Z"
  })), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 9L15 9 15 13 11 13 11 15 15 15 15 19 17 19 17 15 21 15 21 13 17 13 17 9z"
  })), children);
});
var AgricultureAnalytics32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AgricultureAnalytics32(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.251 21.3691l2.1943 1.4629A1 1 0 0027.8 22.6l3-4-1.6-1.2-2.4326 3.2437L24.5547 19.168a1 1 0 00-1.3687.2509L20 23.8789V16H18V26a2.0023 2.0023 0 002 2H30V26H20.9434zM2 21H16V23H2zM2 26H16V28H2zM11 16V11h1a4.0046 4.0046 0 004-4V4H13a3.9782 3.9782 0 00-2.7468 1.1066A6.0033 6.0033 0 005 2H2V5a6.0066 6.0066 0 006 6H9v5H2v2H16V16zM13 6h1V7a2.002 2.002 0 01-2 2H11V8A2.0019 2.0019 0 0113 6zM8 9A4.0046 4.0046 0 014 5V4H5A4.0045 4.0045 0 019 8V9z"
  })), children);
});
var AgricultureAnalytics24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AgricultureAnalytics24(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.251 21.3691l2.1943 1.4629A1 1 0 0027.8 22.6l3-4-1.6-1.2-2.4326 3.2437L24.5547 19.168a1 1 0 00-1.3687.2509L20 23.8789V16H18V26a2.0023 2.0023 0 002 2H30V26H20.9434zM2 21H16V23H2zM2 26H16V28H2zM11 16V11h1a4.0046 4.0046 0 004-4V4H13a3.9782 3.9782 0 00-2.7468 1.1066A6.0033 6.0033 0 005 2H2V5a6.0066 6.0066 0 006 6H9v5H2v2H16V16zM13 6h1V7a2.002 2.002 0 01-2 2H11V8A2.0019 2.0019 0 0113 6zM8 9A4.0046 4.0046 0 014 5V4H5A4.0045 4.0045 0 019 8V9z"
  })), children);
});
var AgricultureAnalytics20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AgricultureAnalytics20(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.251 21.3691l2.1943 1.4629A1 1 0 0027.8 22.6l3-4-1.6-1.2-2.4326 3.2437L24.5547 19.168a1 1 0 00-1.3687.2509L20 23.8789V16H18V26a2.0023 2.0023 0 002 2H30V26H20.9434zM2 21H16V23H2zM2 26H16V28H2zM11 16V11h1a4.0046 4.0046 0 004-4V4H13a3.9782 3.9782 0 00-2.7468 1.1066A6.0033 6.0033 0 005 2H2V5a6.0066 6.0066 0 006 6H9v5H2v2H16V16zM13 6h1V7a2.002 2.002 0 01-2 2H11V8A2.0019 2.0019 0 0113 6zM8 9A4.0046 4.0046 0 014 5V4H5A4.0045 4.0045 0 019 8V9z"
  })), children);
});
var AgricultureAnalytics16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AgricultureAnalytics16(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.251 21.3691l2.1943 1.4629A1 1 0 0027.8 22.6l3-4-1.6-1.2-2.4326 3.2437L24.5547 19.168a1 1 0 00-1.3687.2509L20 23.8789V16H18V26a2.0023 2.0023 0 002 2H30V26H20.9434zM2 21H16V23H2zM2 26H16V28H2zM11 16V11h1a4.0046 4.0046 0 004-4V4H13a3.9782 3.9782 0 00-2.7468 1.1066A6.0033 6.0033 0 005 2H2V5a6.0066 6.0066 0 006 6H9v5H2v2H16V16zM13 6h1V7a2.002 2.002 0 01-2 2H11V8A2.0019 2.0019 0 0113 6zM8 9A4.0046 4.0046 0 014 5V4H5A4.0045 4.0045 0 019 8V9z"
  })), children);
});
var WatsonHealthAiResults32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResults32(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8a5.9908 5.9908 0 009.4712 4.8853L28.586 16 30 14.586l-3.115-3.1148A5.997 5.997 0 1016 8zm2 0a4 4 0 114 4A4.0045 4.0045 0 0118 8zM11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0055 8.0055 0 016-7.7373L13.6138 2.3A10.0088 10.0088 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM23.0493 16a9.5991 9.5991 0 01-1.8716 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857a10.9664 10.9664 0 002.3686-2.8331z"
  })), children);
});
var WatsonHealthAiResults24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResults24(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8a5.9908 5.9908 0 009.4712 4.8853L28.586 16 30 14.586l-3.115-3.1148A5.997 5.997 0 1016 8zm2 0a4 4 0 114 4A4.0045 4.0045 0 0118 8zM11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0055 8.0055 0 016-7.7373L13.6138 2.3A10.0088 10.0088 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM23.0493 16a9.5991 9.5991 0 01-1.8716 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857a10.9664 10.9664 0 002.3686-2.8331z"
  })), children);
});
var WatsonHealthAiResults20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResults20(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8a5.9908 5.9908 0 009.4712 4.8853L28.586 16 30 14.586l-3.115-3.1148A5.997 5.997 0 1016 8zm2 0a4 4 0 114 4A4.0045 4.0045 0 0118 8zM11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0055 8.0055 0 016-7.7373L13.6138 2.3A10.0088 10.0088 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM23.0493 16a9.5991 9.5991 0 01-1.8716 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857a10.9664 10.9664 0 002.3686-2.8331z"
  })), children);
});
var WatsonHealthAiResults16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResults16(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8a5.9908 5.9908 0 009.4712 4.8853L28.586 16 30 14.586l-3.115-3.1148A5.997 5.997 0 1016 8zm2 0a4 4 0 114 4A4.0045 4.0045 0 0118 8zM11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0055 8.0055 0 016-7.7373L13.6138 2.3A10.0088 10.0088 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM23.0493 16a9.5991 9.5991 0 01-1.8716 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857a10.9664 10.9664 0 002.3686-2.8331z"
  })), children);
});
var WatsonHealthAiResultsHigh32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsHigh32(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM23.0488 16a9.6136 9.6136 0 01-1.8711 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9886 9.9886 0 0025.2815 16zM16 4a7.9279 7.9279 0 013.69.9106l.8958-1.791A9.99 9.99 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2c0-1.84-1.1108-2.8662-2.1855-3.8594A7.1851 7.1851 0 018 12 8.0092 8.0092 0 0116 4zM29 14H19a1 1 0 01-.8945-1.4473l5-10a1 1 0 011.7888 0l5 10A1 1 0 0129 14zm-8.3818-2h6.7636L24 5.2361z"
  })), children);
});
var WatsonHealthAiResultsHigh24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsHigh24(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM23.0488 16a9.6136 9.6136 0 01-1.8711 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9886 9.9886 0 0025.2815 16zM16 4a7.9279 7.9279 0 013.69.9106l.8958-1.791A9.99 9.99 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2c0-1.84-1.1108-2.8662-2.1855-3.8594A7.1851 7.1851 0 018 12 8.0092 8.0092 0 0116 4zM29 14H19a1 1 0 01-.8945-1.4473l5-10a1 1 0 011.7888 0l5 10A1 1 0 0129 14zm-8.3818-2h6.7636L24 5.2361z"
  })), children);
});
var WatsonHealthAiResultsHigh20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsHigh20(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM23.0488 16a9.6136 9.6136 0 01-1.8711 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9886 9.9886 0 0025.2815 16zM16 4a7.9279 7.9279 0 013.69.9106l.8958-1.791A9.99 9.99 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2c0-1.84-1.1108-2.8662-2.1855-3.8594A7.1851 7.1851 0 018 12 8.0092 8.0092 0 0116 4zM29 14H19a1 1 0 01-.8945-1.4473l5-10a1 1 0 011.7888 0l5 10A1 1 0 0129 14zm-8.3818-2h6.7636L24 5.2361z"
  })), children);
});
var WatsonHealthAiResultsHigh16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsHigh16(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM23.0488 16a9.6136 9.6136 0 01-1.8711 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9886 9.9886 0 0025.2815 16zM16 4a7.9279 7.9279 0 013.69.9106l.8958-1.791A9.99 9.99 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2c0-1.84-1.1108-2.8662-2.1855-3.8594A7.1851 7.1851 0 018 12 8.0092 8.0092 0 0116 4zM29 14H19a1 1 0 01-.8945-1.4473l5-10a1 1 0 011.7888 0l5 10A1 1 0 0129 14zm-8.3818-2h6.7636L24 5.2361z"
  })), children);
});
var WatsonHealthAiResultsLow32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsLow32(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM24 14a6 6 0 116-6A6.0067 6.0067 0 0124 14zM24 4a4 4 0 104 4A4.0045 4.0045 0 0024 4zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16z"
  })), children);
});
var WatsonHealthAiResultsLow24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsLow24(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM24 14a6 6 0 116-6A6.0067 6.0067 0 0124 14zM24 4a4 4 0 104 4A4.0045 4.0045 0 0024 4zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16z"
  })), children);
});
var WatsonHealthAiResultsLow20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsLow20(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM24 14a6 6 0 116-6A6.0067 6.0067 0 0124 14zM24 4a4 4 0 104 4A4.0045 4.0045 0 0024 4zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16z"
  })), children);
});
var WatsonHealthAiResultsLow16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsLow16(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM24 14a6 6 0 116-6A6.0067 6.0067 0 0124 14zM24 4a4 4 0 104 4A4.0045 4.0045 0 0024 4zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16z"
  })), children);
});
var WatsonHealthAiResultsMedium32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsMedium32(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM28 14H20a2.0021 2.0021 0 01-2-2V4a2.0021 2.0021 0 012-2h8a2.0021 2.0021 0 012 2v8A2.0021 2.0021 0 0128 14zM20 4v8h8V4zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16z"
  })), children);
});
var WatsonHealthAiResultsMedium24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsMedium24(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM28 14H20a2.0021 2.0021 0 01-2-2V4a2.0021 2.0021 0 012-2h8a2.0021 2.0021 0 012 2v8A2.0021 2.0021 0 0128 14zM20 4v8h8V4zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16z"
  })), children);
});
var WatsonHealthAiResultsMedium20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsMedium20(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM28 14H20a2.0021 2.0021 0 01-2-2V4a2.0021 2.0021 0 012-2h8a2.0021 2.0021 0 012 2v8A2.0021 2.0021 0 0128 14zM20 4v8h8V4zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16z"
  })), children);
});
var WatsonHealthAiResultsMedium16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsMedium16(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM28 14H20a2.0021 2.0021 0 01-2-2V4a2.0021 2.0021 0 012-2h8a2.0021 2.0021 0 012 2v8A2.0021 2.0021 0 0128 14zM20 4v8h8V4zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16z"
  })), children);
});
var WatsonHealthAiResultsUrgent32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsUrgent32(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM20 2H22V9H20zM21 11a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0021 11zM26 2H28V9H26zM27 11a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0027 11zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16z"
  })), children);
});
var WatsonHealthAiResultsUrgent24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsUrgent24(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM20 2H22V9H20zM21 11a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0021 11zM26 2H28V9H26zM27 11a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0027 11zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16z"
  })), children);
});
var WatsonHealthAiResultsUrgent20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsUrgent20(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM20 2H22V9H20zM21 11a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0021 11zM26 2H28V9H26zM27 11a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0027 11zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16z"
  })), children);
});
var WatsonHealthAiResultsUrgent16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsUrgent16(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM20 2H22V9H20zM21 11a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0021 11zM26 2H28V9H26zM27 11a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0027 11zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16z"
  })), children);
});
var WatsonHealthAiResultsVeryHigh32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsVeryHigh32(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 2H26V9H24zM25 11a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0025 11zM11 24H21V26H11zM13 28H19V30H13zM23.0488 16a9.6136 9.6136 0 01-1.8711 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9886 9.9886 0 0025.2815 16zM16 4a7.94 7.94 0 014 1.0825V2.8408A9.9887 9.9887 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2c0-1.84-1.1108-2.8662-2.1855-3.8594A7.1851 7.1851 0 018 12 8.0092 8.0092 0 0116 4z"
  })), children);
});
var WatsonHealthAiResultsVeryHigh24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsVeryHigh24(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 2H26V9H24zM25 11a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0025 11zM11 24H21V26H11zM13 28H19V30H13zM23.0488 16a9.6136 9.6136 0 01-1.8711 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9886 9.9886 0 0025.2815 16zM16 4a7.94 7.94 0 014 1.0825V2.8408A9.9887 9.9887 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2c0-1.84-1.1108-2.8662-2.1855-3.8594A7.1851 7.1851 0 018 12 8.0092 8.0092 0 0116 4z"
  })), children);
});
var WatsonHealthAiResultsVeryHigh20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsVeryHigh20(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 2H26V9H24zM25 11a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0025 11zM11 24H21V26H11zM13 28H19V30H13zM23.0488 16a9.6136 9.6136 0 01-1.8711 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9886 9.9886 0 0025.2815 16zM16 4a7.94 7.94 0 014 1.0825V2.8408A9.9887 9.9887 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2c0-1.84-1.1108-2.8662-2.1855-3.8594A7.1851 7.1851 0 018 12 8.0092 8.0092 0 0116 4z"
  })), children);
});
var WatsonHealthAiResultsVeryHigh16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiResultsVeryHigh16(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 2H26V9H24zM25 11a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0025 11zM11 24H21V26H11zM13 28H19V30H13zM23.0488 16a9.6136 9.6136 0 01-1.8711 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9886 9.9886 0 0025.2815 16zM16 4a7.94 7.94 0 014 1.0825V2.8408A9.9887 9.9887 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2c0-1.84-1.1108-2.8662-2.1855-3.8594A7.1851 7.1851 0 018 12 8.0092 8.0092 0 0116 4z"
  })), children);
});
var WatsonHealthAiStatus32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatus32(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16zM20 14a1 1 0 01-.8945-.5527L17.3818 10H14V8h4a1 1 0 01.8945.5527L20 10.7639l3.1055-6.2112a1.0416 1.0416 0 011.789 0L26.6182 8H30v2H26a1 1 0 01-.8945-.5527L24 7.2361l-3.1055 6.2112A1 1 0 0120 14z"
  })), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.8145,18.1406A7.1851,7.1851,0,0,1,8,12a8.0092,8.0092,0,0,1,8-8V2A10.0111,10.0111,0,0,0,6,12a9.1793,9.1793,0,0,0,3.46,7.6162C10.4717,20.5508,11,21.0815,11,22h2C13,20.16,11.8892,19.1338,10.8145,18.1406Z"
  })), children);
});
var WatsonHealthAiStatus24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatus24(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16zM20 14a1 1 0 01-.8945-.5527L17.3818 10H14V8h4a1 1 0 01.8945.5527L20 10.7639l3.1055-6.2112a1.0416 1.0416 0 011.789 0L26.6182 8H30v2H26a1 1 0 01-.8945-.5527L24 7.2361l-3.1055 6.2112A1 1 0 0120 14z"
  })), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.8145,18.1406A7.1851,7.1851,0,0,1,8,12a8.0092,8.0092,0,0,1,8-8V2A10.0111,10.0111,0,0,0,6,12a9.1793,9.1793,0,0,0,3.46,7.6162C10.4717,20.5508,11,21.0815,11,22h2C13,20.16,11.8892,19.1338,10.8145,18.1406Z"
  })), children);
});
var WatsonHealthAiStatus20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatus20(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16zM20 14a1 1 0 01-.8945-.5527L17.3818 10H14V8h4a1 1 0 01.8945.5527L20 10.7639l3.1055-6.2112a1.0416 1.0416 0 011.789 0L26.6182 8H30v2H26a1 1 0 01-.8945-.5527L24 7.2361l-3.1055 6.2112A1 1 0 0120 14z"
  })), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.8145,18.1406A7.1851,7.1851,0,0,1,8,12a8.0092,8.0092,0,0,1,8-8V2A10.0111,10.0111,0,0,0,6,12a9.1793,9.1793,0,0,0,3.46,7.6162C10.4717,20.5508,11,21.0815,11,22h2C13,20.16,11.8892,19.1338,10.8145,18.1406Z"
  })), children);
});
var WatsonHealthAiStatus16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatus16(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16zM20 14a1 1 0 01-.8945-.5527L17.3818 10H14V8h4a1 1 0 01.8945.5527L20 10.7639l3.1055-6.2112a1.0416 1.0416 0 011.789 0L26.6182 8H30v2H26a1 1 0 01-.8945-.5527L24 7.2361l-3.1055 6.2112A1 1 0 0120 14z"
  })), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.8145,18.1406A7.1851,7.1851,0,0,1,8,12a8.0092,8.0092,0,0,1,8-8V2A10.0111,10.0111,0,0,0,6,12a9.1793,9.1793,0,0,0,3.46,7.6162C10.4717,20.5508,11,21.0815,11,22h2C13,20.16,11.8892,19.1338,10.8145,18.1406Z"
  })), children);
});
var WatsonHealthAiStatusComplete32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusComplete32(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM21 9.59L17.41 6 16 7.41 21 12.41 30 3.41 28.59 2 21 9.59zM23.8 14a7.28 7.28 0 01-2.6219 4.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.1426 9.1426 0 0025.8389 14z"
  })), children);
});
var WatsonHealthAiStatusComplete24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusComplete24(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM21 9.59L17.41 6 16 7.41 21 12.41 30 3.41 28.59 2 21 9.59zM23.8 14a7.28 7.28 0 01-2.6219 4.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.1426 9.1426 0 0025.8389 14z"
  })), children);
});
var WatsonHealthAiStatusComplete20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusComplete20(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM21 9.59L17.41 6 16 7.41 21 12.41 30 3.41 28.59 2 21 9.59zM23.8 14a7.28 7.28 0 01-2.6219 4.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.1426 9.1426 0 0025.8389 14z"
  })), children);
});
var WatsonHealthAiStatusComplete16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusComplete16(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM21 9.59L17.41 6 16 7.41 21 12.41 30 3.41 28.59 2 21 9.59zM23.8 14a7.28 7.28 0 01-2.6219 4.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.1426 9.1426 0 0025.8389 14z"
  })), children);
});
var WatsonHealthAiStatusFailed32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusFailed32(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM23.8 14a7.28 7.28 0 01-2.6219 4.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.1426 9.1426 0 0025.8389 14zM30 3.41L28.59 2 25 5.59 21.41 2 20 3.41 23.59 7 20 10.59 21.41 12 25 8.41 28.59 12 30 10.59 26.41 7 30 3.41z"
  })), children);
});
var WatsonHealthAiStatusFailed24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusFailed24(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM23.8 14a7.28 7.28 0 01-2.6219 4.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.1426 9.1426 0 0025.8389 14zM30 3.41L28.59 2 25 5.59 21.41 2 20 3.41 23.59 7 20 10.59 21.41 12 25 8.41 28.59 12 30 10.59 26.41 7 30 3.41z"
  })), children);
});
var WatsonHealthAiStatusFailed20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusFailed20(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM23.8 14a7.28 7.28 0 01-2.6219 4.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.1426 9.1426 0 0025.8389 14zM30 3.41L28.59 2 25 5.59 21.41 2 20 3.41 23.59 7 20 10.59 21.41 12 25 8.41 28.59 12 30 10.59 26.41 7 30 3.41z"
  })), children);
});
var WatsonHealthAiStatusFailed16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusFailed16(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM23.8 14a7.28 7.28 0 01-2.6219 4.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.1426 9.1426 0 0025.8389 14zM30 3.41L28.59 2 25 5.59 21.41 2 20 3.41 23.59 7 20 10.59 21.41 12 25 8.41 28.59 12 30 10.59 26.41 7 30 3.41z"
  })), children);
});
var WatsonHealthAiStatusInProgress32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusInProgress32(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM21.1777 18.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.193 9.193 0 0026 12H24A7.2032 7.2032 0 0121.1777 18.1426z"
  })), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18.5",
    cy: "7.5",
    r: "1.5"
  })), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28.5",
    cy: "7.5",
    r: "1.5"
  })), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23.5",
    cy: "7.5",
    r: "1.5"
  })), children);
});
var WatsonHealthAiStatusInProgress24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusInProgress24(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM21.1777 18.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.193 9.193 0 0026 12H24A7.2032 7.2032 0 0121.1777 18.1426z"
  })), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18.5",
    cy: "7.5",
    r: "1.5"
  })), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28.5",
    cy: "7.5",
    r: "1.5"
  })), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23.5",
    cy: "7.5",
    r: "1.5"
  })), children);
});
var WatsonHealthAiStatusInProgress20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusInProgress20(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM21.1777 18.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.193 9.193 0 0026 12H24A7.2032 7.2032 0 0121.1777 18.1426z"
  })), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18.5",
    cy: "7.5",
    r: "1.5"
  })), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28.5",
    cy: "7.5",
    r: "1.5"
  })), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23.5",
    cy: "7.5",
    r: "1.5"
  })), children);
});
var WatsonHealthAiStatusInProgress16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusInProgress16(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM21.1777 18.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.193 9.193 0 0026 12H24A7.2032 7.2032 0 0121.1777 18.1426z"
  })), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18.5",
    cy: "7.5",
    r: "1.5"
  })), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28.5",
    cy: "7.5",
    r: "1.5"
  })), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23.5",
    cy: "7.5",
    r: "1.5"
  })), children);
});
var WatsonHealthAiStatusQueued32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusQueued32(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM21.1777 18.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.193 9.193 0 0026 12H24A7.2032 7.2032 0 0121.1777 18.1426zM18 6H28V8H18z"
  })), children);
});
var WatsonHealthAiStatusQueued24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusQueued24(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM21.1777 18.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.193 9.193 0 0026 12H24A7.2032 7.2032 0 0121.1777 18.1426zM18 6H28V8H18z"
  })), children);
});
var WatsonHealthAiStatusQueued20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusQueued20(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM21.1777 18.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.193 9.193 0 0026 12H24A7.2032 7.2032 0 0121.1777 18.1426zM18 6H28V8H18z"
  })), children);
});
var WatsonHealthAiStatusQueued16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusQueued16(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM21.1777 18.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.193 9.193 0 0026 12H24A7.2032 7.2032 0 0121.1777 18.1426zM18 6H28V8H18z"
  })), children);
});
var WatsonHealthAiStatusRejected32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusRejected32(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16zM30 8a6 6 0 10-6 6A6.0066 6.0066 0 0030 8zM28 8a3.9521 3.9521 0 01-.5669 2.019L21.981 4.5669A3.9529 3.9529 0 0124 4 4.0045 4.0045 0 0128 8zM20 8a3.9521 3.9521 0 01.5669-2.019l5.4521 5.4521A3.9529 3.9529 0 0124 12 4.0045 4.0045 0 0120 8z"
  })), children);
});
var WatsonHealthAiStatusRejected24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusRejected24(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16zM30 8a6 6 0 10-6 6A6.0066 6.0066 0 0030 8zM28 8a3.9521 3.9521 0 01-.5669 2.019L21.981 4.5669A3.9529 3.9529 0 0124 4 4.0045 4.0045 0 0128 8zM20 8a3.9521 3.9521 0 01.5669-2.019l5.4521 5.4521A3.9529 3.9529 0 0124 12 4.0045 4.0045 0 0120 8z"
  })), children);
});
var WatsonHealthAiStatusRejected20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusRejected20(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16zM30 8a6 6 0 10-6 6A6.0066 6.0066 0 0030 8zM28 8a3.9521 3.9521 0 01-.5669 2.019L21.981 4.5669A3.9529 3.9529 0 0124 4 4.0045 4.0045 0 0128 8zM20 8a3.9521 3.9521 0 01.5669-2.019l5.4521 5.4521A3.9529 3.9529 0 0124 12 4.0045 4.0045 0 0120 8z"
  })), children);
});
var WatsonHealthAiStatusRejected16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAiStatusRejected16(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM10.8145 18.1406A7.1851 7.1851 0 018 12a8.0092 8.0092 0 018-8V2A10.0111 10.0111 0 006 12a9.1793 9.1793 0 003.46 7.6162C10.4717 20.5508 11 21.0815 11 22h2C13 20.16 11.8892 19.1338 10.8145 18.1406zM23.04 16a9.4858 9.4858 0 01-1.8623 2.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.9838 9.9838 0 0025.2756 16zM30 8a6 6 0 10-6 6A6.0066 6.0066 0 0030 8zM28 8a3.9521 3.9521 0 01-.5669 2.019L21.981 4.5669A3.9529 3.9529 0 0124 4 4.0045 4.0045 0 0128 8zM20 8a3.9521 3.9521 0 01.5669-2.019l5.4521 5.4521A3.9529 3.9529 0 0124 12 4.0045 4.0045 0 0120 8z"
  })), children);
});
var AirlineDigitalGate32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirlineDigitalGate32(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 23H16V21a3.0033 3.0033 0 00-3-3H9a3.0033 3.0033 0 00-3 3v2H4V21a5.0058 5.0058 0 015-5h4a5.0059 5.0059 0 015 5zM11 6A3 3 0 118 9a3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0011 4zM2 26H30V28H2zM31.9658 11.7413a1.0007 1.0007 0 00-1.2246-.707l-3.0861.826L24 7l-1 .2676 1.4584 5.4483-2.7663.7405L20 11.2066l-1 .2676.9337 3.4883a.9993.9993 0 001.2246.707l10.1005-2.7036A1 1 0 0031.9658 11.7413z"
  })), children);
});
var AirlineDigitalGate24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirlineDigitalGate24(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 23H16V21a3.0033 3.0033 0 00-3-3H9a3.0033 3.0033 0 00-3 3v2H4V21a5.0058 5.0058 0 015-5h4a5.0059 5.0059 0 015 5zM11 6A3 3 0 118 9a3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0011 4zM2 26H30V28H2zM31.9658 11.7413a1.0007 1.0007 0 00-1.2246-.707l-3.0861.826L24 7l-1 .2676 1.4584 5.4483-2.7663.7405L20 11.2066l-1 .2676.9337 3.4883a.9993.9993 0 001.2246.707l10.1005-2.7036A1 1 0 0031.9658 11.7413z"
  })), children);
});
var AirlineDigitalGate20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirlineDigitalGate20(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 23H16V21a3.0033 3.0033 0 00-3-3H9a3.0033 3.0033 0 00-3 3v2H4V21a5.0058 5.0058 0 015-5h4a5.0059 5.0059 0 015 5zM11 6A3 3 0 118 9a3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0011 4zM2 26H30V28H2zM31.9658 11.7413a1.0007 1.0007 0 00-1.2246-.707l-3.0861.826L24 7l-1 .2676 1.4584 5.4483-2.7663.7405L20 11.2066l-1 .2676.9337 3.4883a.9993.9993 0 001.2246.707l10.1005-2.7036A1 1 0 0031.9658 11.7413z"
  })), children);
});
var AirlineDigitalGate16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirlineDigitalGate16(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 23H16V21a3.0033 3.0033 0 00-3-3H9a3.0033 3.0033 0 00-3 3v2H4V21a5.0058 5.0058 0 015-5h4a5.0059 5.0059 0 015 5zM11 6A3 3 0 118 9a3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0011 4zM2 26H30V28H2zM31.9658 11.7413a1.0007 1.0007 0 00-1.2246-.707l-3.0861.826L24 7l-1 .2676 1.4584 5.4483-2.7663.7405L20 11.2066l-1 .2676.9337 3.4883a.9993.9993 0 001.2246.707l10.1005-2.7036A1 1 0 0031.9658 11.7413z"
  })), children);
});
var AirlineManageGates32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirlineManageGates32(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 23H16V21a3.0033 3.0033 0 00-3-3H9a3.0033 3.0033 0 00-3 3v2H4V21a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM11 6A3 3 0 118 9a3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0011 4zM2 26H30V28H2zM22 4L22 6 26.586 6 20 12.586 21.414 14 28 7.414 28 12 30 12 30 4 22 4z"
  })), children);
});
var AirlineManageGates24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirlineManageGates24(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 23H16V21a3.0033 3.0033 0 00-3-3H9a3.0033 3.0033 0 00-3 3v2H4V21a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM11 6A3 3 0 118 9a3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0011 4zM2 26H30V28H2zM22 4L22 6 26.586 6 20 12.586 21.414 14 28 7.414 28 12 30 12 30 4 22 4z"
  })), children);
});
var AirlineManageGates20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirlineManageGates20(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 23H16V21a3.0033 3.0033 0 00-3-3H9a3.0033 3.0033 0 00-3 3v2H4V21a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM11 6A3 3 0 118 9a3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0011 4zM2 26H30V28H2zM22 4L22 6 26.586 6 20 12.586 21.414 14 28 7.414 28 12 30 12 30 4 22 4z"
  })), children);
});
var AirlineManageGates16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirlineManageGates16(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 23H16V21a3.0033 3.0033 0 00-3-3H9a3.0033 3.0033 0 00-3 3v2H4V21a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM11 6A3 3 0 118 9a3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0011 4zM2 26H30V28H2zM22 4L22 6 26.586 6 20 12.586 21.414 14 28 7.414 28 12 30 12 30 4 22 4z"
  })), children);
});
var AirlinePassengerCare32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirlinePassengerCare32(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 23H16V21a3.0033 3.0033 0 00-3-3H9a3.0033 3.0033 0 00-3 3v2H4V21a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM11 6A3 3 0 118 9a3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0011 4zM2 26H30V28H2zM27.303 8a2.6616 2.6616 0 00-1.9079.8058L25 9.2112l-.3951-.4054a2.6615 2.6615 0 00-3.8157 0 2.7992 2.7992 0 000 3.8964L25 17l4.2108-4.2978a2.7992 2.7992 0 000-3.8964A2.6616 2.6616 0 0027.303 8z"
  })), children);
});
var AirlinePassengerCare24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirlinePassengerCare24(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 23H16V21a3.0033 3.0033 0 00-3-3H9a3.0033 3.0033 0 00-3 3v2H4V21a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM11 6A3 3 0 118 9a3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0011 4zM2 26H30V28H2zM27.303 8a2.6616 2.6616 0 00-1.9079.8058L25 9.2112l-.3951-.4054a2.6615 2.6615 0 00-3.8157 0 2.7992 2.7992 0 000 3.8964L25 17l4.2108-4.2978a2.7992 2.7992 0 000-3.8964A2.6616 2.6616 0 0027.303 8z"
  })), children);
});
var AirlinePassengerCare20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirlinePassengerCare20(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 23H16V21a3.0033 3.0033 0 00-3-3H9a3.0033 3.0033 0 00-3 3v2H4V21a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM11 6A3 3 0 118 9a3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0011 4zM2 26H30V28H2zM27.303 8a2.6616 2.6616 0 00-1.9079.8058L25 9.2112l-.3951-.4054a2.6615 2.6615 0 00-3.8157 0 2.7992 2.7992 0 000 3.8964L25 17l4.2108-4.2978a2.7992 2.7992 0 000-3.8964A2.6616 2.6616 0 0027.303 8z"
  })), children);
});
var AirlinePassengerCare16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirlinePassengerCare16(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 23H16V21a3.0033 3.0033 0 00-3-3H9a3.0033 3.0033 0 00-3 3v2H4V21a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM11 6A3 3 0 118 9a3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0011 4zM2 26H30V28H2zM27.303 8a2.6616 2.6616 0 00-1.9079.8058L25 9.2112l-.3951-.4054a2.6615 2.6615 0 00-3.8157 0 2.7992 2.7992 0 000 3.8964L25 17l4.2108-4.2978a2.7992 2.7992 0 000-3.8964A2.6616 2.6616 0 0027.303 8z"
  })), children);
});
var AirlineRapidBoard32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirlineRapidBoard32(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 23H16V21a3.0033 3.0033 0 00-3-3H9a3.0033 3.0033 0 00-3 3v2H4V21a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM11 6A3 3 0 118 9a3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0011 4zM2 26H30V28H2zM30 8L28 8 28 6 26 6 26 4 30 4 30 8zM19 4L23 4 23 6 21 6 21 8 19 8 19 4zM28 13H30V15H28zM26 11H28V13H26zM19 11L21 11 21 13 23 13 23 15 19 15 19 11z"
  })), children);
});
var AirlineRapidBoard24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirlineRapidBoard24(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 23H16V21a3.0033 3.0033 0 00-3-3H9a3.0033 3.0033 0 00-3 3v2H4V21a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM11 6A3 3 0 118 9a3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0011 4zM2 26H30V28H2zM30 8L28 8 28 6 26 6 26 4 30 4 30 8zM19 4L23 4 23 6 21 6 21 8 19 8 19 4zM28 13H30V15H28zM26 11H28V13H26zM19 11L21 11 21 13 23 13 23 15 19 15 19 11z"
  })), children);
});
var AirlineRapidBoard20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirlineRapidBoard20(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 23H16V21a3.0033 3.0033 0 00-3-3H9a3.0033 3.0033 0 00-3 3v2H4V21a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM11 6A3 3 0 118 9a3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0011 4zM2 26H30V28H2zM30 8L28 8 28 6 26 6 26 4 30 4 30 8zM19 4L23 4 23 6 21 6 21 8 19 8 19 4zM28 13H30V15H28zM26 11H28V13H26zM19 11L21 11 21 13 23 13 23 15 19 15 19 11z"
  })), children);
});
var AirlineRapidBoard16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirlineRapidBoard16(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 23H16V21a3.0033 3.0033 0 00-3-3H9a3.0033 3.0033 0 00-3 3v2H4V21a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM11 6A3 3 0 118 9a3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0011 4zM2 26H30V28H2zM30 8L28 8 28 6 26 6 26 4 30 4 30 8zM19 4L23 4 23 6 21 6 21 8 19 8 19 4zM28 13H30V15H28zM26 11H28V13H26zM19 11L21 11 21 13 23 13 23 15 19 15 19 11z"
  })), children);
});
var Airplay32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Airplay32(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.9961,30H9.0039a1.0022,1.0022,0,0,1-.821-1.5769l6.9977-9.9965a1,1,0,0,1,1.6388,0l6.9977,9.9965A1.0022,1.0022,0,0,1,22.9961,30ZM10.92,28H21.08L16,20.7439Z"
  })), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24H24V22h4V6H4V22H8v2H4a2.0021,2.0021,0,0,1-2-2V6A2.0021,2.0021,0,0,1,4,4H28a2.0021,2.0021,0,0,1,2,2V22A2.0021,2.0021,0,0,1,28,24Z"
  })), children);
});
var Airplay24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Airplay24(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.9961,30H9.0039a1.0022,1.0022,0,0,1-.821-1.5769l6.9977-9.9965a1,1,0,0,1,1.6388,0l6.9977,9.9965A1.0022,1.0022,0,0,1,22.9961,30ZM10.92,28H21.08L16,20.7439Z"
  })), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24H24V22h4V6H4V22H8v2H4a2.0021,2.0021,0,0,1-2-2V6A2.0021,2.0021,0,0,1,4,4H28a2.0021,2.0021,0,0,1,2,2V22A2.0021,2.0021,0,0,1,28,24Z"
  })), children);
});
var Airplay20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Airplay20(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.9961,30H9.0039a1.0022,1.0022,0,0,1-.821-1.5769l6.9977-9.9965a1,1,0,0,1,1.6388,0l6.9977,9.9965A1.0022,1.0022,0,0,1,22.9961,30ZM10.92,28H21.08L16,20.7439Z"
  })), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24H24V22h4V6H4V22H8v2H4a2.0021,2.0021,0,0,1-2-2V6A2.0021,2.0021,0,0,1,4,4H28a2.0021,2.0021,0,0,1,2,2V22A2.0021,2.0021,0,0,1,28,24Z"
  })), children);
});
var Airplay16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Airplay16(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.9961,30H9.0039a1.0022,1.0022,0,0,1-.821-1.5769l6.9977-9.9965a1,1,0,0,1,1.6388,0l6.9977,9.9965A1.0022,1.0022,0,0,1,22.9961,30ZM10.92,28H21.08L16,20.7439Z"
  })), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24H24V22h4V6H4V22H8v2H4a2.0021,2.0021,0,0,1-2-2V6A2.0021,2.0021,0,0,1,4,4H28a2.0021,2.0021,0,0,1,2,2V22A2.0021,2.0021,0,0,1,28,24Z"
  })), children);
});
var AirplayFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirplayFilled32(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.9961,30H9.0039a1.0022,1.0022,0,0,1-.821-1.5769l6.9977-9.9965a1,1,0,0,1,1.6388,0l6.9977,9.9965A1.0022,1.0022,0,0,1,22.9961,30Z"
  })), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24H24V22h4V6H4V22H8v2H4a2.0021,2.0021,0,0,1-2-2V6A2.0021,2.0021,0,0,1,4,4H28a2.0021,2.0021,0,0,1,2,2V22A2.0021,2.0021,0,0,1,28,24Z"
  })), children);
});
var AirplayFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirplayFilled24(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.9961,30H9.0039a1.0022,1.0022,0,0,1-.821-1.5769l6.9977-9.9965a1,1,0,0,1,1.6388,0l6.9977,9.9965A1.0022,1.0022,0,0,1,22.9961,30Z"
  })), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24H24V22h4V6H4V22H8v2H4a2.0021,2.0021,0,0,1-2-2V6A2.0021,2.0021,0,0,1,4,4H28a2.0021,2.0021,0,0,1,2,2V22A2.0021,2.0021,0,0,1,28,24Z"
  })), children);
});
var AirplayFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirplayFilled20(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.9961,30H9.0039a1.0022,1.0022,0,0,1-.821-1.5769l6.9977-9.9965a1,1,0,0,1,1.6388,0l6.9977,9.9965A1.0022,1.0022,0,0,1,22.9961,30Z"
  })), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24H24V22h4V6H4V22H8v2H4a2.0021,2.0021,0,0,1-2-2V6A2.0021,2.0021,0,0,1,4,4H28a2.0021,2.0021,0,0,1,2,2V22A2.0021,2.0021,0,0,1,28,24Z"
  })), children);
});
var AirplayFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirplayFilled16(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.9961,30H9.0039a1.0022,1.0022,0,0,1-.821-1.5769l6.9977-9.9965a1,1,0,0,1,1.6388,0l6.9977,9.9965A1.0022,1.0022,0,0,1,22.9961,30Z"
  })), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24H24V22h4V6H4V22H8v2H4a2.0021,2.0021,0,0,1-2-2V6A2.0021,2.0021,0,0,1,4,4H28a2.0021,2.0021,0,0,1,2,2V22A2.0021,2.0021,0,0,1,28,24Z"
  })), children);
});
var Airport_0132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Airport_0132(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M17,14.5,23,17V15l-6-3V9a1,1,0,0,0-2,0v3L9,15v2l6-2.5V20l-3,2v1l4-1,4,1V22l-3-2Z"
  })), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var Airport_0124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Airport_0124(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M17,14.5,23,17V15l-6-3V9a1,1,0,0,0-2,0v3L9,15v2l6-2.5V20l-3,2v1l4-1,4,1V22l-3-2Z"
  })), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var Airport_0120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Airport_0120(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M17,14.5,23,17V15l-6-3V9a1,1,0,0,0-2,0v3L9,15v2l6-2.5V20l-3,2v1l4-1,4,1V22l-3-2Z"
  })), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var Airport_0116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Airport_0116(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M17,14.5,23,17V15l-6-3V9a1,1,0,0,0-2,0v3L9,15v2l6-2.5V20l-3,2v1l4-1,4,1V22l-3-2Z"
  })), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var Airport_0232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Airport_0232(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,17H19.4141L16,13H14l2.5859,4H10.7207L9.5,15H8l1.0569,3.3046A1,1,0,0,0,10.0094,19H23a1,1,0,0,0,0-2Z"
  })), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var Airport_0224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Airport_0224(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,17H19.4141L16,13H14l2.5859,4H10.7207L9.5,15H8l1.0569,3.3046A1,1,0,0,0,10.0094,19H23a1,1,0,0,0,0-2Z"
  })), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var Airport_0220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Airport_0220(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,17H19.4141L16,13H14l2.5859,4H10.7207L9.5,15H8l1.0569,3.3046A1,1,0,0,0,10.0094,19H23a1,1,0,0,0,0-2Z"
  })), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var Airport_0216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Airport_0216(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,17H19.4141L16,13H14l2.5859,4H10.7207L9.5,15H8l1.0569,3.3046A1,1,0,0,0,10.0094,19H23a1,1,0,0,0,0-2Z"
  })), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var AirportLocation32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirportLocation32(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15h-6.07A8.0076,8.0076,0,0,0,17,8.0693V2H15V8.0693A8.0076,8.0076,0,0,0,8.07,15H2v2H8.07A8.0076,8.0076,0,0,0,15,23.9307V30h2V23.9307A8.0076,8.0076,0,0,0,23.9305,17H30ZM16,22a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,16,22Z"
  })), children);
});
var AirportLocation24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirportLocation24(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15h-6.07A8.0076,8.0076,0,0,0,17,8.0693V2H15V8.0693A8.0076,8.0076,0,0,0,8.07,15H2v2H8.07A8.0076,8.0076,0,0,0,15,23.9307V30h2V23.9307A8.0076,8.0076,0,0,0,23.9305,17H30ZM16,22a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,16,22Z"
  })), children);
});
var AirportLocation20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirportLocation20(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15h-6.07A8.0076,8.0076,0,0,0,17,8.0693V2H15V8.0693A8.0076,8.0076,0,0,0,8.07,15H2v2H8.07A8.0076,8.0076,0,0,0,15,23.9307V30h2V23.9307A8.0076,8.0076,0,0,0,23.9305,17H30ZM16,22a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,16,22Z"
  })), children);
});
var AirportLocation16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AirportLocation16(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15h-6.07A8.0076,8.0076,0,0,0,17,8.0693V2H15V8.0693A8.0076,8.0076,0,0,0,8.07,15H2v2H8.07A8.0076,8.0076,0,0,0,15,23.9307V30h2V23.9307A8.0076,8.0076,0,0,0,23.9305,17H30ZM16,22a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,16,22Z"
  })), children);
});
var Alarm32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Alarm32(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A11,11,0,1,1,27,17,11,11,0,0,1,16,28ZM16,8a9,9,0,1,0,9,9A9,9,0,0,0,16,8Z"
  })), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.59 21L15 17.41 15 11 17 11 17 16.58 20 19.59 18.59 21z"
  })), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.96 5.5H9.030000000000001V7.5H3.96z",
    transform: "rotate(-45.06 6.502 6.497)"
  })), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 3.96H26.5V9.030000000000001H24.5z",
    transform: "rotate(-44.94 25.5 6.498)"
  })), children);
});
var Alarm24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Alarm24(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A11,11,0,1,1,27,17,11,11,0,0,1,16,28ZM16,8a9,9,0,1,0,9,9A9,9,0,0,0,16,8Z"
  })), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.59 21L15 17.41 15 11 17 11 17 16.58 20 19.59 18.59 21z"
  })), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.96 5.5H9.030000000000001V7.5H3.96z",
    transform: "rotate(-45.06 6.502 6.497)"
  })), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 3.96H26.5V9.030000000000001H24.5z",
    transform: "rotate(-44.94 25.5 6.498)"
  })), children);
});
var Alarm20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Alarm20(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A11,11,0,1,1,27,17,11,11,0,0,1,16,28ZM16,8a9,9,0,1,0,9,9A9,9,0,0,0,16,8Z"
  })), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.59 21L15 17.41 15 11 17 11 17 16.58 20 19.59 18.59 21z"
  })), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.96 5.5H9.030000000000001V7.5H3.96z",
    transform: "rotate(-45.06 6.502 6.497)"
  })), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 3.96H26.5V9.030000000000001H24.5z",
    transform: "rotate(-44.94 25.5 6.498)"
  })), children);
});
var Alarm16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Alarm16(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A11,11,0,1,1,27,17,11,11,0,0,1,16,28ZM16,8a9,9,0,1,0,9,9A9,9,0,0,0,16,8Z"
  })), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.59 21L15 17.41 15 11 17 11 17 16.58 20 19.59 18.59 21z"
  })), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.96 5.5H9.030000000000001V7.5H3.96z",
    transform: "rotate(-45.06 6.502 6.497)"
  })), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 3.96H26.5V9.030000000000001H24.5z",
    transform: "rotate(-44.94 25.5 6.498)"
  })), children);
});
var AlarmAdd32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlarmAdd32(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A11,11,0,1,1,27,17,11,11,0,0,1,16,28ZM16,8a9,9,0,1,0,9,9A9,9,0,0,0,16,8Z"
  })), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.96 5.5H9.030000000000001V7.5H3.96z",
    transform: "rotate(-45.06 6.502 6.497)"
  })), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 3.96H26.5V9.030000000000001H24.5z",
    transform: "rotate(-44.94 25.5 6.498)"
  })), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 16L17 16 17 12 15 12 15 16 11 16 11 18 15 18 15 22 17 22 17 18 21 18 21 16z"
  })), children);
});
var AlarmAdd24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlarmAdd24(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A11,11,0,1,1,27,17,11,11,0,0,1,16,28ZM16,8a9,9,0,1,0,9,9A9,9,0,0,0,16,8Z"
  })), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.96 5.5H9.030000000000001V7.5H3.96z",
    transform: "rotate(-45.06 6.502 6.497)"
  })), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 3.96H26.5V9.030000000000001H24.5z",
    transform: "rotate(-44.94 25.5 6.498)"
  })), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 16L17 16 17 12 15 12 15 16 11 16 11 18 15 18 15 22 17 22 17 18 21 18 21 16z"
  })), children);
});
var AlarmAdd20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlarmAdd20(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A11,11,0,1,1,27,17,11,11,0,0,1,16,28ZM16,8a9,9,0,1,0,9,9A9,9,0,0,0,16,8Z"
  })), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.96 5.5H9.030000000000001V7.5H3.96z",
    transform: "rotate(-45.06 6.502 6.497)"
  })), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 3.96H26.5V9.030000000000001H24.5z",
    transform: "rotate(-44.94 25.5 6.498)"
  })), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 16L17 16 17 12 15 12 15 16 11 16 11 18 15 18 15 22 17 22 17 18 21 18 21 16z"
  })), children);
});
var AlarmAdd16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlarmAdd16(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A11,11,0,1,1,27,17,11,11,0,0,1,16,28ZM16,8a9,9,0,1,0,9,9A9,9,0,0,0,16,8Z"
  })), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.96 5.5H9.030000000000001V7.5H3.96z",
    transform: "rotate(-45.06 6.502 6.497)"
  })), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 3.96H26.5V9.030000000000001H24.5z",
    transform: "rotate(-44.94 25.5 6.498)"
  })), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 16L17 16 17 12 15 12 15 16 11 16 11 18 15 18 15 22 17 22 17 18 21 18 21 16z"
  })), children);
});
var AlarmSubtract32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlarmSubtract32(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A11,11,0,1,1,27,17,11,11,0,0,1,16,28ZM16,8a9,9,0,1,0,9,9A9,9,0,0,0,16,8Z"
  })), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.96 5.5H9.030000000000001V7.5H3.96z",
    transform: "rotate(-45.06 6.502 6.497)"
  })), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 3.96H26.5V9.030000000000001H24.5z",
    transform: "rotate(-44.94 25.5 6.498)"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 16H21V18H11z"
  })), children);
});
var AlarmSubtract24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlarmSubtract24(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A11,11,0,1,1,27,17,11,11,0,0,1,16,28ZM16,8a9,9,0,1,0,9,9A9,9,0,0,0,16,8Z"
  })), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.96 5.5H9.030000000000001V7.5H3.96z",
    transform: "rotate(-45.06 6.502 6.497)"
  })), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 3.96H26.5V9.030000000000001H24.5z",
    transform: "rotate(-44.94 25.5 6.498)"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 16H21V18H11z"
  })), children);
});
var AlarmSubtract20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlarmSubtract20(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A11,11,0,1,1,27,17,11,11,0,0,1,16,28ZM16,8a9,9,0,1,0,9,9A9,9,0,0,0,16,8Z"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.96 5.5H9.030000000000001V7.5H3.96z",
    transform: "rotate(-45.06 6.502 6.497)"
  })), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 3.96H26.5V9.030000000000001H24.5z",
    transform: "rotate(-44.94 25.5 6.498)"
  })), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 16H21V18H11z"
  })), children);
});
var AlarmSubtract16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlarmSubtract16(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A11,11,0,1,1,27,17,11,11,0,0,1,16,28ZM16,8a9,9,0,1,0,9,9A9,9,0,0,0,16,8Z"
  })), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.96 5.5H9.030000000000001V7.5H3.96z",
    transform: "rotate(-45.06 6.502 6.497)"
  })), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 3.96H26.5V9.030000000000001H24.5z",
    transform: "rotate(-44.94 25.5 6.498)"
  })), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 16H21V18H11z"
  })), children);
});
var AlignHorizontalCenter32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignHorizontalCenter32(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,18H17V14h3a2.0025,2.0025,0,0,0,2-2V8a2.0025,2.0025,0,0,0-2-2H17V2H15V6H12a2.0025,2.0025,0,0,0-2,2v4a2.0025,2.0025,0,0,0,2,2h3v4H8a2.0025,2.0025,0,0,0-2,2v4a2.0025,2.0025,0,0,0,2,2h7v4h2V26h7a2.0025,2.0025,0,0,0,2-2V20A2.0025,2.0025,0,0,0,24,18ZM12,8h8v4H12ZM24,24H8V20H24Z"
  })), children);
});
var AlignHorizontalCenter24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignHorizontalCenter24(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,18H17V14h3a2.0025,2.0025,0,0,0,2-2V8a2.0025,2.0025,0,0,0-2-2H17V2H15V6H12a2.0025,2.0025,0,0,0-2,2v4a2.0025,2.0025,0,0,0,2,2h3v4H8a2.0025,2.0025,0,0,0-2,2v4a2.0025,2.0025,0,0,0,2,2h7v4h2V26h7a2.0025,2.0025,0,0,0,2-2V20A2.0025,2.0025,0,0,0,24,18ZM12,8h8v4H12ZM24,24H8V20H24Z"
  })), children);
});
var AlignHorizontalCenter20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignHorizontalCenter20(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,18H17V14h3a2.0025,2.0025,0,0,0,2-2V8a2.0025,2.0025,0,0,0-2-2H17V2H15V6H12a2.0025,2.0025,0,0,0-2,2v4a2.0025,2.0025,0,0,0,2,2h3v4H8a2.0025,2.0025,0,0,0-2,2v4a2.0025,2.0025,0,0,0,2,2h7v4h2V26h7a2.0025,2.0025,0,0,0,2-2V20A2.0025,2.0025,0,0,0,24,18ZM12,8h8v4H12ZM24,24H8V20H24Z"
  })), children);
});
var AlignHorizontalCenter16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignHorizontalCenter16(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,18H17V14h3a2.0025,2.0025,0,0,0,2-2V8a2.0025,2.0025,0,0,0-2-2H17V2H15V6H12a2.0025,2.0025,0,0,0-2,2v4a2.0025,2.0025,0,0,0,2,2h3v4H8a2.0025,2.0025,0,0,0-2,2v4a2.0025,2.0025,0,0,0,2,2h7v4h2V26h7a2.0025,2.0025,0,0,0,2-2V20A2.0025,2.0025,0,0,0,24,18ZM12,8h8v4H12ZM24,24H8V20H24Z"
  })), children);
});
var AlignHorizontalLeft32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignHorizontalLeft32(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 26H11a2.0023 2.0023 0 01-2-2V20a2.0023 2.0023 0 012-2H26a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0126 26zm0-6.0012L11 20v4H26zM18 14H11a2.0023 2.0023 0 01-2-2V8a2.0023 2.0023 0 012-2h7a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0118 14zm0-6.0012L11 8v4h7zM4 2H6V30H4z"
  })), children);
});
var AlignHorizontalLeft24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignHorizontalLeft24(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 26H11a2.0023 2.0023 0 01-2-2V20a2.0023 2.0023 0 012-2H26a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0126 26zm0-6.0012L11 20v4H26zM18 14H11a2.0023 2.0023 0 01-2-2V8a2.0023 2.0023 0 012-2h7a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0118 14zm0-6.0012L11 8v4h7zM4 2H6V30H4z"
  })), children);
});
var AlignHorizontalLeft20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignHorizontalLeft20(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 26H11a2.0023 2.0023 0 01-2-2V20a2.0023 2.0023 0 012-2H26a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0126 26zm0-6.0012L11 20v4H26zM18 14H11a2.0023 2.0023 0 01-2-2V8a2.0023 2.0023 0 012-2h7a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0118 14zm0-6.0012L11 8v4h7zM4 2H6V30H4z"
  })), children);
});
var AlignHorizontalLeft16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignHorizontalLeft16(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 26H11a2.0023 2.0023 0 01-2-2V20a2.0023 2.0023 0 012-2H26a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0126 26zm0-6.0012L11 20v4H26zM18 14H11a2.0023 2.0023 0 01-2-2V8a2.0023 2.0023 0 012-2h7a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0118 14zm0-6.0012L11 8v4h7zM4 2H6V30H4z"
  })), children);
});
var AlignHorizontalRight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignHorizontalRight32(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 24V20a2.0023 2.0023 0 012-2H21a2.0023 2.0023 0 012 2v4a2.0023 2.0023 0 01-2 2H6A2.0023 2.0023 0 014 24zm2 0H21V20L6 19.9988zM12 12V8a2.0023 2.0023 0 012-2h7a2.0023 2.0023 0 012 2v4a2.0023 2.0023 0 01-2 2H14A2.0023 2.0023 0 0112 12zm2 0h7V8l-7-.0012z"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 2H28V30H26z",
    transform: "rotate(-180 27 16)"
  })), children);
});
var AlignHorizontalRight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignHorizontalRight24(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 24V20a2.0023 2.0023 0 012-2H21a2.0023 2.0023 0 012 2v4a2.0023 2.0023 0 01-2 2H6A2.0023 2.0023 0 014 24zm2 0H21V20L6 19.9988zM12 12V8a2.0023 2.0023 0 012-2h7a2.0023 2.0023 0 012 2v4a2.0023 2.0023 0 01-2 2H14A2.0023 2.0023 0 0112 12zm2 0h7V8l-7-.0012z"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 2H28V30H26z",
    transform: "rotate(-180 27 16)"
  })), children);
});
var AlignHorizontalRight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignHorizontalRight20(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 24V20a2.0023 2.0023 0 012-2H21a2.0023 2.0023 0 012 2v4a2.0023 2.0023 0 01-2 2H6A2.0023 2.0023 0 014 24zm2 0H21V20L6 19.9988zM12 12V8a2.0023 2.0023 0 012-2h7a2.0023 2.0023 0 012 2v4a2.0023 2.0023 0 01-2 2H14A2.0023 2.0023 0 0112 12zm2 0h7V8l-7-.0012z"
  })), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 2H28V30H26z",
    transform: "rotate(-180 27 16)"
  })), children);
});
var AlignHorizontalRight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignHorizontalRight16(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 24V20a2.0023 2.0023 0 012-2H21a2.0023 2.0023 0 012 2v4a2.0023 2.0023 0 01-2 2H6A2.0023 2.0023 0 014 24zm2 0H21V20L6 19.9988zM12 12V8a2.0023 2.0023 0 012-2h7a2.0023 2.0023 0 012 2v4a2.0023 2.0023 0 01-2 2H14A2.0023 2.0023 0 0112 12zm2 0h7V8l-7-.0012z"
  })), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 2H28V30H26z",
    transform: "rotate(-180 27 16)"
  })), children);
});
var AlignVerticalBottom32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignVerticalBottom32(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26H30V28H2zM24 23H20a2.0023 2.0023 0 01-2-2V14a2.0023 2.0023 0 012-2h4a2.0023 2.0023 0 012 2v7A2.0023 2.0023 0 0124 23zm-4-9v7h4.0012L24 14zM12 23H8a2.0023 2.0023 0 01-2-2V6A2.0023 2.0023 0 018 4h4a2.0023 2.0023 0 012 2V21A2.0023 2.0023 0 0112 23zM8 6V21h4.0012L12 6z"
  })), children);
});
var AlignVerticalBottom24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignVerticalBottom24(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26H30V28H2zM24 23H20a2.0023 2.0023 0 01-2-2V14a2.0023 2.0023 0 012-2h4a2.0023 2.0023 0 012 2v7A2.0023 2.0023 0 0124 23zm-4-9v7h4.0012L24 14zM12 23H8a2.0023 2.0023 0 01-2-2V6A2.0023 2.0023 0 018 4h4a2.0023 2.0023 0 012 2V21A2.0023 2.0023 0 0112 23zM8 6V21h4.0012L12 6z"
  })), children);
});
var AlignVerticalBottom20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignVerticalBottom20(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26H30V28H2zM24 23H20a2.0023 2.0023 0 01-2-2V14a2.0023 2.0023 0 012-2h4a2.0023 2.0023 0 012 2v7A2.0023 2.0023 0 0124 23zm-4-9v7h4.0012L24 14zM12 23H8a2.0023 2.0023 0 01-2-2V6A2.0023 2.0023 0 018 4h4a2.0023 2.0023 0 012 2V21A2.0023 2.0023 0 0112 23zM8 6V21h4.0012L12 6z"
  })), children);
});
var AlignVerticalBottom16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignVerticalBottom16(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26H30V28H2zM24 23H20a2.0023 2.0023 0 01-2-2V14a2.0023 2.0023 0 012-2h4a2.0023 2.0023 0 012 2v7A2.0023 2.0023 0 0124 23zm-4-9v7h4.0012L24 14zM12 23H8a2.0023 2.0023 0 01-2-2V6A2.0023 2.0023 0 018 4h4a2.0023 2.0023 0 012 2V21A2.0023 2.0023 0 0112 23zM8 6V21h4.0012L12 6z"
  })), children);
});
var AlignVerticalCenter32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignVerticalCenter32(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H26V12a2.0025,2.0025,0,0,0-2-2H20a2.0025,2.0025,0,0,0-2,2v3H14V8a2.0025,2.0025,0,0,0-2-2H8A2.0025,2.0025,0,0,0,6,8v7H2v2H6v7a2.0025,2.0025,0,0,0,2,2h4a2.0025,2.0025,0,0,0,2-2V17h4v3a2.0025,2.0025,0,0,0,2,2h4a2.0025,2.0025,0,0,0,2-2V17h4ZM8,24V8h4l.0012,16Zm12-4V12h4l.0012,8Z"
  })), children);
});
var AlignVerticalCenter24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignVerticalCenter24(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H26V12a2.0025,2.0025,0,0,0-2-2H20a2.0025,2.0025,0,0,0-2,2v3H14V8a2.0025,2.0025,0,0,0-2-2H8A2.0025,2.0025,0,0,0,6,8v7H2v2H6v7a2.0025,2.0025,0,0,0,2,2h4a2.0025,2.0025,0,0,0,2-2V17h4v3a2.0025,2.0025,0,0,0,2,2h4a2.0025,2.0025,0,0,0,2-2V17h4ZM8,24V8h4l.0012,16Zm12-4V12h4l.0012,8Z"
  })), children);
});
var AlignVerticalCenter20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignVerticalCenter20(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H26V12a2.0025,2.0025,0,0,0-2-2H20a2.0025,2.0025,0,0,0-2,2v3H14V8a2.0025,2.0025,0,0,0-2-2H8A2.0025,2.0025,0,0,0,6,8v7H2v2H6v7a2.0025,2.0025,0,0,0,2,2h4a2.0025,2.0025,0,0,0,2-2V17h4v3a2.0025,2.0025,0,0,0,2,2h4a2.0025,2.0025,0,0,0,2-2V17h4ZM8,24V8h4l.0012,16Zm12-4V12h4l.0012,8Z"
  })), children);
});
var AlignVerticalCenter16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignVerticalCenter16(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H26V12a2.0025,2.0025,0,0,0-2-2H20a2.0025,2.0025,0,0,0-2,2v3H14V8a2.0025,2.0025,0,0,0-2-2H8A2.0025,2.0025,0,0,0,6,8v7H2v2H6v7a2.0025,2.0025,0,0,0,2,2h4a2.0025,2.0025,0,0,0,2-2V17h4v3a2.0025,2.0025,0,0,0,2,2h4a2.0025,2.0025,0,0,0,2-2V17h4ZM8,24V8h4l.0012,16Zm12-4V12h4l.0012,8Z"
  })), children);
});
var AlignVerticalTop32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignVerticalTop32(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 20H20a2.0023 2.0023 0 01-2-2V11a2.0023 2.0023 0 012-2h4a2.0023 2.0023 0 012 2v7A2.0023 2.0023 0 0124 20zm-4-9v7h4.0012L24 11zM12 28H8a2.0023 2.0023 0 01-2-2V11A2.0023 2.0023 0 018 9h4a2.0023 2.0023 0 012 2V26A2.0023 2.0023 0 0112 28zM8 11V26h4.0012L12 11zM2 4H30V6H2z"
  })), children);
});
var AlignVerticalTop24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignVerticalTop24(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 20H20a2.0023 2.0023 0 01-2-2V11a2.0023 2.0023 0 012-2h4a2.0023 2.0023 0 012 2v7A2.0023 2.0023 0 0124 20zm-4-9v7h4.0012L24 11zM12 28H8a2.0023 2.0023 0 01-2-2V11A2.0023 2.0023 0 018 9h4a2.0023 2.0023 0 012 2V26A2.0023 2.0023 0 0112 28zM8 11V26h4.0012L12 11zM2 4H30V6H2z"
  })), children);
});
var AlignVerticalTop20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignVerticalTop20(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 20H20a2.0023 2.0023 0 01-2-2V11a2.0023 2.0023 0 012-2h4a2.0023 2.0023 0 012 2v7A2.0023 2.0023 0 0124 20zm-4-9v7h4.0012L24 11zM12 28H8a2.0023 2.0023 0 01-2-2V11A2.0023 2.0023 0 018 9h4a2.0023 2.0023 0 012 2V26A2.0023 2.0023 0 0112 28zM8 11V26h4.0012L12 11zM2 4H30V6H2z"
  })), children);
});
var AlignVerticalTop16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignVerticalTop16(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 20H20a2.0023 2.0023 0 01-2-2V11a2.0023 2.0023 0 012-2h4a2.0023 2.0023 0 012 2v7A2.0023 2.0023 0 0124 20zm-4-9v7h4.0012L24 11zM12 28H8a2.0023 2.0023 0 01-2-2V11A2.0023 2.0023 0 018 9h4a2.0023 2.0023 0 012 2V26A2.0023 2.0023 0 0112 28zM8 11V26h4.0012L12 11zM2 4H30V6H2z"
  })), children);
});
var AlignBoxBottomCenter32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxBottomCenter32(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 18H22V20H10z",
    transform: "rotate(-180 16 19)"
  })), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 23H20V25H12z",
    transform: "rotate(-180 16 24)"
  })), children);
});
var AlignBoxBottomCenter24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxBottomCenter24(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 18H22V20H10z",
    transform: "rotate(-180 16 19)"
  })), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 23H20V25H12z",
    transform: "rotate(-180 16 24)"
  })), children);
});
var AlignBoxBottomCenter20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxBottomCenter20(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 18H22V20H10z",
    transform: "rotate(-180 16 19)"
  })), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 23H20V25H12z",
    transform: "rotate(-180 16 24)"
  })), children);
});
var AlignBoxBottomCenter16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxBottomCenter16(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 18H22V20H10z",
    transform: "rotate(-180 16 19)"
  })), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 23H20V25H12z",
    transform: "rotate(-180 16 24)"
  })), children);
});
var AlignBoxBottomLeft32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxBottomLeft32(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 18H20V20H9zM9 23H16V25H9z"
  })), children);
});
var AlignBoxBottomLeft24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxBottomLeft24(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 18H20V20H9zM9 23H16V25H9z"
  })), children);
});
var AlignBoxBottomLeft20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxBottomLeft20(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 18H20V20H9zM9 23H16V25H9z"
  })), children);
});
var AlignBoxBottomLeft16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxBottomLeft16(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 18H20V20H9zM9 23H16V25H9z"
  })), children);
});
var AlignBoxBottomRight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxBottomRight32(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 18H23V20H12z",
    transform: "rotate(-180 17.5 19)"
  })), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 23H23V25H16z",
    transform: "rotate(-180 19.5 24)"
  })), children);
});
var AlignBoxBottomRight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxBottomRight24(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 18H23V20H12z",
    transform: "rotate(-180 17.5 19)"
  })), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 23H23V25H16z",
    transform: "rotate(-180 19.5 24)"
  })), children);
});
var AlignBoxBottomRight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxBottomRight20(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 18H23V20H12z",
    transform: "rotate(-180 17.5 19)"
  })), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 23H23V25H16z",
    transform: "rotate(-180 19.5 24)"
  })), children);
});
var AlignBoxBottomRight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxBottomRight16(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 18H23V20H12z",
    transform: "rotate(-180 17.5 19)"
  })), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 23H23V25H16z",
    transform: "rotate(-180 19.5 24)"
  })), children);
});
var AlignBoxMiddleCenter32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxMiddleCenter32(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 13H22V15H10z",
    transform: "rotate(-180 16 14)"
  })), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 18H20V20H12z",
    transform: "rotate(-180 16 19)"
  })), children);
});
var AlignBoxMiddleCenter24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxMiddleCenter24(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 13H22V15H10z",
    transform: "rotate(-180 16 14)"
  })), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 18H20V20H12z",
    transform: "rotate(-180 16 19)"
  })), children);
});
var AlignBoxMiddleCenter20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxMiddleCenter20(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 13H22V15H10z",
    transform: "rotate(-180 16 14)"
  })), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 18H20V20H12z",
    transform: "rotate(-180 16 19)"
  })), children);
});
var AlignBoxMiddleCenter16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxMiddleCenter16(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path390 || (_path390 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path391 || (_path391 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 13H22V15H10z",
    transform: "rotate(-180 16 14)"
  })), _path392 || (_path392 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 18H20V20H12z",
    transform: "rotate(-180 16 19)"
  })), children);
});
var AlignBoxMiddleLeft32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxMiddleLeft32(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path393 || (_path393 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path394 || (_path394 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 13H20V15H9zM9 18H16V20H9z"
  })), children);
});
var AlignBoxMiddleLeft24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxMiddleLeft24(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path395 || (_path395 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path396 || (_path396 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 13H20V15H9zM9 18H16V20H9z"
  })), children);
});
var AlignBoxMiddleLeft20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxMiddleLeft20(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path397 || (_path397 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path398 || (_path398 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 13H20V15H9zM9 18H16V20H9z"
  })), children);
});
var AlignBoxMiddleLeft16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxMiddleLeft16(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path399 || (_path399 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path400 || (_path400 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 13H20V15H9zM9 18H16V20H9z"
  })), children);
});
var AlignBoxMiddleRight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxMiddleRight32(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path401 || (_path401 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path402 || (_path402 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 13H23V15H12z",
    transform: "rotate(-180 17.5 14)"
  })), _path403 || (_path403 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 18H23V20H16z",
    transform: "rotate(-180 19.5 19)"
  })), children);
});
var AlignBoxMiddleRight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxMiddleRight24(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path404 || (_path404 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path405 || (_path405 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 13H23V15H12z",
    transform: "rotate(-180 17.5 14)"
  })), _path406 || (_path406 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 18H23V20H16z",
    transform: "rotate(-180 19.5 19)"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-1.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-1.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "AlignBoxMiddleRight16": () => (/* binding */ AlignBoxMiddleRight16),
/* harmony export */   "AlignBoxMiddleRight20": () => (/* binding */ AlignBoxMiddleRight20),
/* harmony export */   "AlignBoxTopCenter16": () => (/* binding */ AlignBoxTopCenter16),
/* harmony export */   "AlignBoxTopCenter20": () => (/* binding */ AlignBoxTopCenter20),
/* harmony export */   "AlignBoxTopCenter24": () => (/* binding */ AlignBoxTopCenter24),
/* harmony export */   "AlignBoxTopCenter32": () => (/* binding */ AlignBoxTopCenter32),
/* harmony export */   "AlignBoxTopLeft16": () => (/* binding */ AlignBoxTopLeft16),
/* harmony export */   "AlignBoxTopLeft20": () => (/* binding */ AlignBoxTopLeft20),
/* harmony export */   "AlignBoxTopLeft24": () => (/* binding */ AlignBoxTopLeft24),
/* harmony export */   "AlignBoxTopLeft32": () => (/* binding */ AlignBoxTopLeft32),
/* harmony export */   "AlignBoxTopRight16": () => (/* binding */ AlignBoxTopRight16),
/* harmony export */   "AlignBoxTopRight20": () => (/* binding */ AlignBoxTopRight20),
/* harmony export */   "AlignBoxTopRight24": () => (/* binding */ AlignBoxTopRight24),
/* harmony export */   "AlignBoxTopRight32": () => (/* binding */ AlignBoxTopRight32),
/* harmony export */   "Analytics16": () => (/* binding */ Analytics16),
/* harmony export */   "Analytics20": () => (/* binding */ Analytics20),
/* harmony export */   "Analytics24": () => (/* binding */ Analytics24),
/* harmony export */   "Analytics32": () => (/* binding */ Analytics32),
/* harmony export */   "AnalyticsCustom16": () => (/* binding */ AnalyticsCustom16),
/* harmony export */   "AnalyticsCustom20": () => (/* binding */ AnalyticsCustom20),
/* harmony export */   "AnalyticsCustom24": () => (/* binding */ AnalyticsCustom24),
/* harmony export */   "AnalyticsCustom32": () => (/* binding */ AnalyticsCustom32),
/* harmony export */   "AnalyticsReference16": () => (/* binding */ AnalyticsReference16),
/* harmony export */   "AnalyticsReference20": () => (/* binding */ AnalyticsReference20),
/* harmony export */   "AnalyticsReference24": () => (/* binding */ AnalyticsReference24),
/* harmony export */   "AnalyticsReference32": () => (/* binding */ AnalyticsReference32),
/* harmony export */   "Aperture16": () => (/* binding */ Aperture16),
/* harmony export */   "Aperture20": () => (/* binding */ Aperture20),
/* harmony export */   "Aperture24": () => (/* binding */ Aperture24),
/* harmony export */   "Aperture32": () => (/* binding */ Aperture32),
/* harmony export */   "Api16": () => (/* binding */ Api16),
/* harmony export */   "Api20": () => (/* binding */ Api20),
/* harmony export */   "Api24": () => (/* binding */ Api24),
/* harmony export */   "Api32": () => (/* binding */ Api32),
/* harmony export */   "Api_116": () => (/* binding */ Api_116),
/* harmony export */   "Api_120": () => (/* binding */ Api_120),
/* harmony export */   "Api_124": () => (/* binding */ Api_124),
/* harmony export */   "Api_132": () => (/* binding */ Api_132),
/* harmony export */   "App16": () => (/* binding */ App16),
/* harmony export */   "App20": () => (/* binding */ App20),
/* harmony export */   "App24": () => (/* binding */ App24),
/* harmony export */   "App32": () => (/* binding */ App32),
/* harmony export */   "AppConnectivity16": () => (/* binding */ AppConnectivity16),
/* harmony export */   "AppConnectivity20": () => (/* binding */ AppConnectivity20),
/* harmony export */   "AppConnectivity24": () => (/* binding */ AppConnectivity24),
/* harmony export */   "AppConnectivity32": () => (/* binding */ AppConnectivity32),
/* harmony export */   "AppSwitcher16": () => (/* binding */ AppSwitcher16),
/* harmony export */   "AppSwitcher20": () => (/* binding */ AppSwitcher20),
/* harmony export */   "AppSwitcher24": () => (/* binding */ AppSwitcher24),
/* harmony export */   "AppSwitcher32": () => (/* binding */ AppSwitcher32),
/* harmony export */   "Apple16": () => (/* binding */ Apple16),
/* harmony export */   "Apple20": () => (/* binding */ Apple20),
/* harmony export */   "Apple24": () => (/* binding */ Apple24),
/* harmony export */   "Apple32": () => (/* binding */ Apple32),
/* harmony export */   "Application16": () => (/* binding */ Application16),
/* harmony export */   "Application20": () => (/* binding */ Application20),
/* harmony export */   "Application24": () => (/* binding */ Application24),
/* harmony export */   "Application32": () => (/* binding */ Application32),
/* harmony export */   "ApplicationMobile16": () => (/* binding */ ApplicationMobile16),
/* harmony export */   "ApplicationMobile20": () => (/* binding */ ApplicationMobile20),
/* harmony export */   "ApplicationMobile24": () => (/* binding */ ApplicationMobile24),
/* harmony export */   "ApplicationMobile32": () => (/* binding */ ApplicationMobile32),
/* harmony export */   "ApplicationVirtual16": () => (/* binding */ ApplicationVirtual16),
/* harmony export */   "ApplicationVirtual20": () => (/* binding */ ApplicationVirtual20),
/* harmony export */   "ApplicationVirtual24": () => (/* binding */ ApplicationVirtual24),
/* harmony export */   "ApplicationVirtual32": () => (/* binding */ ApplicationVirtual32),
/* harmony export */   "ApplicationWeb16": () => (/* binding */ ApplicationWeb16),
/* harmony export */   "ApplicationWeb20": () => (/* binding */ ApplicationWeb20),
/* harmony export */   "ApplicationWeb24": () => (/* binding */ ApplicationWeb24),
/* harmony export */   "ApplicationWeb32": () => (/* binding */ ApplicationWeb32),
/* harmony export */   "Apps16": () => (/* binding */ Apps16),
/* harmony export */   "Apps20": () => (/* binding */ Apps20),
/* harmony export */   "Apps24": () => (/* binding */ Apps24),
/* harmony export */   "Apps32": () => (/* binding */ Apps32),
/* harmony export */   "Archive16": () => (/* binding */ Archive16),
/* harmony export */   "Archive20": () => (/* binding */ Archive20),
/* harmony export */   "Archive24": () => (/* binding */ Archive24),
/* harmony export */   "Archive32": () => (/* binding */ Archive32),
/* harmony export */   "Area16": () => (/* binding */ Area16),
/* harmony export */   "Area20": () => (/* binding */ Area20),
/* harmony export */   "Area24": () => (/* binding */ Area24),
/* harmony export */   "Area32": () => (/* binding */ Area32),
/* harmony export */   "AreaCustom16": () => (/* binding */ AreaCustom16),
/* harmony export */   "AreaCustom20": () => (/* binding */ AreaCustom20),
/* harmony export */   "AreaCustom24": () => (/* binding */ AreaCustom24),
/* harmony export */   "AreaCustom32": () => (/* binding */ AreaCustom32),
/* harmony export */   "Arrival16": () => (/* binding */ Arrival16),
/* harmony export */   "Arrival20": () => (/* binding */ Arrival20),
/* harmony export */   "Arrival24": () => (/* binding */ Arrival24),
/* harmony export */   "Arrival32": () => (/* binding */ Arrival32),
/* harmony export */   "ArrowDown16": () => (/* binding */ ArrowDown16),
/* harmony export */   "ArrowDown20": () => (/* binding */ ArrowDown20),
/* harmony export */   "ArrowDown24": () => (/* binding */ ArrowDown24),
/* harmony export */   "ArrowDown32": () => (/* binding */ ArrowDown32),
/* harmony export */   "ArrowDownLeft16": () => (/* binding */ ArrowDownLeft16),
/* harmony export */   "ArrowDownLeft20": () => (/* binding */ ArrowDownLeft20),
/* harmony export */   "ArrowDownLeft24": () => (/* binding */ ArrowDownLeft24),
/* harmony export */   "ArrowDownLeft32": () => (/* binding */ ArrowDownLeft32),
/* harmony export */   "ArrowDownRight16": () => (/* binding */ ArrowDownRight16),
/* harmony export */   "ArrowDownRight20": () => (/* binding */ ArrowDownRight20),
/* harmony export */   "ArrowDownRight24": () => (/* binding */ ArrowDownRight24),
/* harmony export */   "ArrowDownRight32": () => (/* binding */ ArrowDownRight32),
/* harmony export */   "ArrowLeft16": () => (/* binding */ ArrowLeft16),
/* harmony export */   "ArrowLeft20": () => (/* binding */ ArrowLeft20),
/* harmony export */   "ArrowLeft24": () => (/* binding */ ArrowLeft24),
/* harmony export */   "ArrowLeft32": () => (/* binding */ ArrowLeft32),
/* harmony export */   "ArrowRight16": () => (/* binding */ ArrowRight16),
/* harmony export */   "ArrowRight20": () => (/* binding */ ArrowRight20),
/* harmony export */   "ArrowRight24": () => (/* binding */ ArrowRight24),
/* harmony export */   "ArrowRight32": () => (/* binding */ ArrowRight32),
/* harmony export */   "ArrowShiftDown16": () => (/* binding */ ArrowShiftDown16),
/* harmony export */   "ArrowShiftDown20": () => (/* binding */ ArrowShiftDown20),
/* harmony export */   "ArrowShiftDown24": () => (/* binding */ ArrowShiftDown24),
/* harmony export */   "ArrowShiftDown32": () => (/* binding */ ArrowShiftDown32),
/* harmony export */   "ArrowUp16": () => (/* binding */ ArrowUp16),
/* harmony export */   "ArrowUp20": () => (/* binding */ ArrowUp20),
/* harmony export */   "ArrowUp24": () => (/* binding */ ArrowUp24),
/* harmony export */   "ArrowUp32": () => (/* binding */ ArrowUp32),
/* harmony export */   "ArrowUpLeft16": () => (/* binding */ ArrowUpLeft16),
/* harmony export */   "ArrowUpLeft20": () => (/* binding */ ArrowUpLeft20),
/* harmony export */   "ArrowUpLeft24": () => (/* binding */ ArrowUpLeft24),
/* harmony export */   "ArrowUpLeft32": () => (/* binding */ ArrowUpLeft32),
/* harmony export */   "ArrowUpRight16": () => (/* binding */ ArrowUpRight16),
/* harmony export */   "ArrowUpRight20": () => (/* binding */ ArrowUpRight20),
/* harmony export */   "ArrowUpRight24": () => (/* binding */ ArrowUpRight24),
/* harmony export */   "ArrowUpRight32": () => (/* binding */ ArrowUpRight32),
/* harmony export */   "Arrows16": () => (/* binding */ Arrows16),
/* harmony export */   "Arrows20": () => (/* binding */ Arrows20),
/* harmony export */   "Arrows24": () => (/* binding */ Arrows24),
/* harmony export */   "Arrows32": () => (/* binding */ Arrows32),
/* harmony export */   "ArrowsHorizontal16": () => (/* binding */ ArrowsHorizontal16),
/* harmony export */   "ArrowsHorizontal20": () => (/* binding */ ArrowsHorizontal20),
/* harmony export */   "ArrowsHorizontal24": () => (/* binding */ ArrowsHorizontal24),
/* harmony export */   "ArrowsHorizontal32": () => (/* binding */ ArrowsHorizontal32),
/* harmony export */   "ArrowsVertical16": () => (/* binding */ ArrowsVertical16),
/* harmony export */   "ArrowsVertical20": () => (/* binding */ ArrowsVertical20),
/* harmony export */   "ArrowsVertical24": () => (/* binding */ ArrowsVertical24),
/* harmony export */   "ArrowsVertical32": () => (/* binding */ ArrowsVertical32),
/* harmony export */   "Asleep16": () => (/* binding */ Asleep16),
/* harmony export */   "Asleep20": () => (/* binding */ Asleep20),
/* harmony export */   "Asleep24": () => (/* binding */ Asleep24),
/* harmony export */   "Asleep32": () => (/* binding */ Asleep32),
/* harmony export */   "AsleepFilled16": () => (/* binding */ AsleepFilled16),
/* harmony export */   "AsleepFilled20": () => (/* binding */ AsleepFilled20),
/* harmony export */   "AsleepFilled24": () => (/* binding */ AsleepFilled24),
/* harmony export */   "AsleepFilled32": () => (/* binding */ AsleepFilled32),
/* harmony export */   "Assembly16": () => (/* binding */ Assembly16),
/* harmony export */   "Assembly20": () => (/* binding */ Assembly20),
/* harmony export */   "Assembly24": () => (/* binding */ Assembly24),
/* harmony export */   "Assembly32": () => (/* binding */ Assembly32),
/* harmony export */   "AssemblyCluster16": () => (/* binding */ AssemblyCluster16),
/* harmony export */   "AssemblyCluster20": () => (/* binding */ AssemblyCluster20),
/* harmony export */   "AssemblyCluster24": () => (/* binding */ AssemblyCluster24),
/* harmony export */   "AssemblyCluster32": () => (/* binding */ AssemblyCluster32),
/* harmony export */   "AssemblyReference16": () => (/* binding */ AssemblyReference16),
/* harmony export */   "AssemblyReference20": () => (/* binding */ AssemblyReference20),
/* harmony export */   "AssemblyReference24": () => (/* binding */ AssemblyReference24),
/* harmony export */   "AssemblyReference32": () => (/* binding */ AssemblyReference32),
/* harmony export */   "Asset16": () => (/* binding */ Asset16),
/* harmony export */   "Asset20": () => (/* binding */ Asset20),
/* harmony export */   "Asset24": () => (/* binding */ Asset24),
/* harmony export */   "Asset32": () => (/* binding */ Asset32),
/* harmony export */   "AssetConfirm16": () => (/* binding */ AssetConfirm16),
/* harmony export */   "AssetConfirm20": () => (/* binding */ AssetConfirm20),
/* harmony export */   "AssetConfirm24": () => (/* binding */ AssetConfirm24),
/* harmony export */   "AssetConfirm32": () => (/* binding */ AssetConfirm32),
/* harmony export */   "AssetDigitalTwin16": () => (/* binding */ AssetDigitalTwin16),
/* harmony export */   "AssetDigitalTwin20": () => (/* binding */ AssetDigitalTwin20),
/* harmony export */   "AssetDigitalTwin24": () => (/* binding */ AssetDigitalTwin24),
/* harmony export */   "AssetDigitalTwin32": () => (/* binding */ AssetDigitalTwin32),
/* harmony export */   "AssetView16": () => (/* binding */ AssetView16),
/* harmony export */   "AssetView20": () => (/* binding */ AssetView20),
/* harmony export */   "AssetView24": () => (/* binding */ AssetView24),
/* harmony export */   "AssetView32": () => (/* binding */ AssetView32),
/* harmony export */   "Asterisk16": () => (/* binding */ Asterisk16),
/* harmony export */   "Asterisk20": () => (/* binding */ Asterisk20),
/* harmony export */   "Asterisk24": () => (/* binding */ Asterisk24),
/* harmony export */   "Asterisk32": () => (/* binding */ Asterisk32),
/* harmony export */   "At16": () => (/* binding */ At16),
/* harmony export */   "At20": () => (/* binding */ At20),
/* harmony export */   "At24": () => (/* binding */ At24),
/* harmony export */   "At32": () => (/* binding */ At32),
/* harmony export */   "Attachment16": () => (/* binding */ Attachment16),
/* harmony export */   "Attachment20": () => (/* binding */ Attachment20),
/* harmony export */   "Attachment24": () => (/* binding */ Attachment24),
/* harmony export */   "Attachment32": () => (/* binding */ Attachment32),
/* harmony export */   "AudioConsole16": () => (/* binding */ AudioConsole16),
/* harmony export */   "AudioConsole20": () => (/* binding */ AudioConsole20),
/* harmony export */   "AudioConsole24": () => (/* binding */ AudioConsole24),
/* harmony export */   "AudioConsole32": () => (/* binding */ AudioConsole32),
/* harmony export */   "AugmentedReality16": () => (/* binding */ AugmentedReality16),
/* harmony export */   "AugmentedReality20": () => (/* binding */ AugmentedReality20),
/* harmony export */   "AugmentedReality24": () => (/* binding */ AugmentedReality24),
/* harmony export */   "AugmentedReality32": () => (/* binding */ AugmentedReality32),
/* harmony export */   "Automatic16": () => (/* binding */ Automatic16),
/* harmony export */   "Automatic20": () => (/* binding */ Automatic20),
/* harmony export */   "Automatic24": () => (/* binding */ Automatic24),
/* harmony export */   "Automatic32": () => (/* binding */ Automatic32),
/* harmony export */   "Autoscaling16": () => (/* binding */ Autoscaling16),
/* harmony export */   "Autoscaling20": () => (/* binding */ Autoscaling20),
/* harmony export */   "Autoscaling24": () => (/* binding */ Autoscaling24),
/* harmony export */   "Autoscaling32": () => (/* binding */ Autoscaling32),
/* harmony export */   "Awake16": () => (/* binding */ Awake16),
/* harmony export */   "Awake20": () => (/* binding */ Awake20),
/* harmony export */   "Awake24": () => (/* binding */ Awake24),
/* harmony export */   "Awake32": () => (/* binding */ Awake32),
/* harmony export */   "BackToTop16": () => (/* binding */ BackToTop16),
/* harmony export */   "BackToTop20": () => (/* binding */ BackToTop20),
/* harmony export */   "BackToTop24": () => (/* binding */ BackToTop24),
/* harmony export */   "BackToTop32": () => (/* binding */ BackToTop32),
/* harmony export */   "Badge16": () => (/* binding */ Badge16),
/* harmony export */   "Badge20": () => (/* binding */ Badge20),
/* harmony export */   "Badge24": () => (/* binding */ Badge24),
/* harmony export */   "Badge32": () => (/* binding */ Badge32),
/* harmony export */   "BaggageClaim16": () => (/* binding */ BaggageClaim16),
/* harmony export */   "BaggageClaim20": () => (/* binding */ BaggageClaim20),
/* harmony export */   "BaggageClaim24": () => (/* binding */ BaggageClaim24),
/* harmony export */   "BaggageClaim32": () => (/* binding */ BaggageClaim32),
/* harmony export */   "Bar16": () => (/* binding */ Bar16),
/* harmony export */   "Bar20": () => (/* binding */ Bar20),
/* harmony export */   "Bar24": () => (/* binding */ Bar24),
/* harmony export */   "Bar32": () => (/* binding */ Bar32),
/* harmony export */   "Barcode16": () => (/* binding */ Barcode16),
/* harmony export */   "Barcode20": () => (/* binding */ Barcode20),
/* harmony export */   "Barcode24": () => (/* binding */ Barcode24),
/* harmony export */   "Barcode32": () => (/* binding */ Barcode32),
/* harmony export */   "BareMetalServer16": () => (/* binding */ BareMetalServer16),
/* harmony export */   "BareMetalServer20": () => (/* binding */ BareMetalServer20),
/* harmony export */   "BareMetalServer24": () => (/* binding */ BareMetalServer24),
/* harmony export */   "BareMetalServer32": () => (/* binding */ BareMetalServer32),
/* harmony export */   "BareMetalServer_0116": () => (/* binding */ BareMetalServer_0116),
/* harmony export */   "BareMetalServer_0120": () => (/* binding */ BareMetalServer_0120),
/* harmony export */   "BareMetalServer_0124": () => (/* binding */ BareMetalServer_0124),
/* harmony export */   "BareMetalServer_0132": () => (/* binding */ BareMetalServer_0132),
/* harmony export */   "WatsonHealthAngle16": () => (/* binding */ WatsonHealthAngle16),
/* harmony export */   "WatsonHealthAngle20": () => (/* binding */ WatsonHealthAngle20),
/* harmony export */   "WatsonHealthAngle24": () => (/* binding */ WatsonHealthAngle24),
/* harmony export */   "WatsonHealthAngle32": () => (/* binding */ WatsonHealthAngle32),
/* harmony export */   "WatsonHealthAnnotationVisibility16": () => (/* binding */ WatsonHealthAnnotationVisibility16),
/* harmony export */   "WatsonHealthAnnotationVisibility20": () => (/* binding */ WatsonHealthAnnotationVisibility20),
/* harmony export */   "WatsonHealthAnnotationVisibility24": () => (/* binding */ WatsonHealthAnnotationVisibility24),
/* harmony export */   "WatsonHealthAnnotationVisibility32": () => (/* binding */ WatsonHealthAnnotationVisibility32),
/* harmony export */   "WatsonHealthArrowAnnotation16": () => (/* binding */ WatsonHealthArrowAnnotation16),
/* harmony export */   "WatsonHealthArrowAnnotation20": () => (/* binding */ WatsonHealthArrowAnnotation20),
/* harmony export */   "WatsonHealthArrowAnnotation24": () => (/* binding */ WatsonHealthArrowAnnotation24),
/* harmony export */   "WatsonHealthArrowAnnotation32": () => (/* binding */ WatsonHealthArrowAnnotation32),
/* harmony export */   "WatsonHealthAutoScroll16": () => (/* binding */ WatsonHealthAutoScroll16),
/* harmony export */   "WatsonHealthAutoScroll20": () => (/* binding */ WatsonHealthAutoScroll20),
/* harmony export */   "WatsonHealthAutoScroll24": () => (/* binding */ WatsonHealthAutoScroll24),
/* harmony export */   "WatsonHealthAutoScroll32": () => (/* binding */ WatsonHealthAutoScroll32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _path65, _path66, _path67, _path68, _path69, _path70, _path71, _path72, _path73, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _circle, _path112, _path113, _circle2, _path114, _path115, _circle3, _path116, _path117, _circle4, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _path224, _path225, _path226, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _circle5, _path283, _circle6, _circle7, _circle8, _circle9, _circle10, _circle11, _circle12, _circle13, _circle14, _circle15, _circle16, _circle17, _circle18, _circle19, _circle20, _circle21, _circle22, _circle23, _circle24, _circle25, _circle26, _circle27, _circle28, _circle29, _circle30, _circle31, _circle32, _circle33, _circle34, _circle35, _circle36, _circle37, _circle38, _circle39, _circle40, _circle41, _circle42, _circle43, _circle44, _circle45, _circle46, _path284, _circle47, _circle48, _circle49, _circle50, _circle51, _circle52, _circle53, _circle54, _circle55, _circle56, _circle57, _circle58, _circle59, _circle60, _circle61, _circle62, _circle63, _circle64, _circle65, _circle66, _circle67, _circle68, _circle69, _circle70, _circle71, _circle72, _circle73, _circle74, _circle75, _circle76, _circle77, _circle78, _circle79, _circle80, _circle81, _circle82, _circle83, _circle84, _circle85, _circle86, _circle87, _path285, _circle88, _circle89, _circle90, _circle91, _circle92, _circle93, _circle94, _circle95, _circle96, _circle97, _circle98, _circle99, _circle100, _circle101, _circle102, _circle103, _circle104, _circle105, _circle106, _circle107, _circle108, _circle109, _circle110, _circle111, _circle112, _circle113, _circle114, _circle115, _circle116, _circle117, _circle118, _circle119, _circle120, _circle121, _circle122, _circle123, _circle124, _circle125, _circle126, _circle127, _circle128, _path286, _circle129, _circle130, _circle131, _circle132, _circle133, _circle134, _circle135, _circle136, _circle137, _circle138, _circle139, _circle140, _circle141, _circle142, _circle143, _circle144, _circle145, _circle146, _circle147, _circle148, _circle149, _circle150, _circle151, _circle152, _circle153, _circle154, _circle155, _circle156, _circle157, _circle158, _circle159, _circle160, _circle161, _circle162, _circle163, _circle164, _circle165, _circle166, _circle167, _circle168, _circle169, _path287, _path288, _circle170, _path289, _path290, _circle171, _path291, _path292, _circle172, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _circle173, _path312, _path313, _circle174, _path314, _path315, _circle175, _path316, _path317, _circle176, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _circle177, _path387, _path388, _circle178, _path389, _path390, _circle179, _path391, _path392, _circle180, _path393, _path394, _path395, _path396, _path397, _path398, _path399, _path400, _path401, _path402, _path403, _path404, _path405, _path406, _circle181, _path407, _circle182, _path408, _circle183, _path409, _circle184, _path410, _circle185, _path411, _circle186, _path412, _circle187, _path413, _circle188, _path414, _circle189, _path415, _circle190, _path416, _circle191, _path417, _circle192, _path418, _path419, _circle193, _path420, _path421, _circle194, _path422, _path423, _circle195, _path424, _path425, _circle196, _path426;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var didWarnAboutDeprecation = {};
var AlignBoxMiddleRight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxMiddleRight20(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 13H23V15H12z",
    transform: "rotate(-180 17.5 14)"
  })), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 18H23V20H16z",
    transform: "rotate(-180 19.5 19)"
  })), children);
});
var AlignBoxMiddleRight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxMiddleRight16(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 13H23V15H12z",
    transform: "rotate(-180 17.5 14)"
  })), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 18H23V20H16z",
    transform: "rotate(-180 19.5 19)"
  })), children);
});
var AlignBoxTopCenter32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxTopCenter32(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 7H22V9H10z",
    transform: "rotate(-180 16 8)"
  })), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 12H20V14H12z",
    transform: "rotate(-180 16 13)"
  })), children);
});
var AlignBoxTopCenter24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxTopCenter24(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 7H22V9H10z",
    transform: "rotate(-180 16 8)"
  })), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 12H20V14H12z",
    transform: "rotate(-180 16 13)"
  })), children);
});
var AlignBoxTopCenter20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxTopCenter20(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 7H22V9H10z",
    transform: "rotate(-180 16 8)"
  })), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 12H20V14H12z",
    transform: "rotate(-180 16 13)"
  })), children);
});
var AlignBoxTopCenter16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxTopCenter16(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 7H22V9H10z",
    transform: "rotate(-180 16 8)"
  })), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 12H20V14H12z",
    transform: "rotate(-180 16 13)"
  })), children);
});
var AlignBoxTopLeft32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxTopLeft32(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 7H20V9H9zM9 12H16V14H9z"
  })), children);
});
var AlignBoxTopLeft24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxTopLeft24(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 7H20V9H9zM9 12H16V14H9z"
  })), children);
});
var AlignBoxTopLeft20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxTopLeft20(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 7H20V9H9zM9 12H16V14H9z"
  })), children);
});
var AlignBoxTopLeft16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxTopLeft16(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 7H20V9H9zM9 12H16V14H9z"
  })), children);
});
var AlignBoxTopRight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxTopRight32(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 7H23V9H12z",
    transform: "rotate(-180 17.5 8)"
  })), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 12H23V14H16z",
    transform: "rotate(-180 19.5 13)"
  })), children);
});
var AlignBoxTopRight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxTopRight24(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 7H23V9H12z",
    transform: "rotate(-180 17.5 8)"
  })), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 12H23V14H16z",
    transform: "rotate(-180 19.5 13)"
  })), children);
});
var AlignBoxTopRight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxTopRight20(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 7H23V9H12z",
    transform: "rotate(-180 17.5 8)"
  })), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 12H23V14H16z",
    transform: "rotate(-180 19.5 13)"
  })), children);
});
var AlignBoxTopRight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AlignBoxTopRight16(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,6,2H26a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30ZM6,4V28H26V4Z"
  })), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 7H23V9H12z",
    transform: "rotate(-180 17.5 8)"
  })), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 12H23V14H16z",
    transform: "rotate(-180 19.5 13)"
  })), children);
});
var Analytics32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Analytics32(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2H2V28a2,2,0,0,0,2,2H30V28H4Z"
  })), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,9H23v2h3.59L19,18.59l-4.29-4.3a1,1,0,0,0-1.42,0L6,21.59,7.41,23,14,16.41l4.29,4.3a1,1,0,0,0,1.42,0L28,12.41V16h2Z"
  })), children);
});
var Analytics24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Analytics24(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2H2V28a2,2,0,0,0,2,2H30V28H4Z"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,9H23v2h3.59L19,18.59l-4.29-4.3a1,1,0,0,0-1.42,0L6,21.59,7.41,23,14,16.41l4.29,4.3a1,1,0,0,0,1.42,0L28,12.41V16h2Z"
  })), children);
});
var Analytics20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Analytics20(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2H2V28a2,2,0,0,0,2,2H30V28H4Z"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,9H23v2h3.59L19,18.59l-4.29-4.3a1,1,0,0,0-1.42,0L6,21.59,7.41,23,14,16.41l4.29,4.3a1,1,0,0,0,1.42,0L28,12.41V16h2Z"
  })), children);
});
var Analytics16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Analytics16(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2H2V28a2,2,0,0,0,2,2H30V28H4Z"
  })), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,9H23v2h3.59L19,18.59l-4.29-4.3a1,1,0,0,0-1.42,0L6,21.59,7.41,23,14,16.41l4.29,4.3a1,1,0,0,0,1.42,0L28,12.41V16h2Z"
  })), children);
});
var AnalyticsCustom32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AnalyticsCustom32(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM30 4H23V6h3.5859L19 13.5859 14.707 9.293a1 1 0 00-1.414 0L6 16.5859 7.4141 18 14 11.4141l4.293 4.2929a1 1 0 001.414 0L28 7.4141V11h2z"
  })), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2H2V28a2,2,0,0,0,2,2h8V28H4Z"
  })), children);
});
var AnalyticsCustom24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AnalyticsCustom24(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM30 4H23V6h3.5859L19 13.5859 14.707 9.293a1 1 0 00-1.414 0L6 16.5859 7.4141 18 14 11.4141l4.293 4.2929a1 1 0 001.414 0L28 7.4141V11h2z"
  })), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2H2V28a2,2,0,0,0,2,2h8V28H4Z"
  })), children);
});
var AnalyticsCustom20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AnalyticsCustom20(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM30 4H23V6h3.5859L19 13.5859 14.707 9.293a1 1 0 00-1.414 0L6 16.5859 7.4141 18 14 11.4141l4.293 4.2929a1 1 0 001.414 0L28 7.4141V11h2z"
  })), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2H2V28a2,2,0,0,0,2,2h8V28H4Z"
  })), children);
});
var AnalyticsCustom16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AnalyticsCustom16(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM30 4H23V6h3.5859L19 13.5859 14.707 9.293a1 1 0 00-1.414 0L6 16.5859 7.4141 18 14 11.4141l4.293 4.2929a1 1 0 001.414 0L28 7.4141V11h2z"
  })), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2H2V28a2,2,0,0,0,2,2h8V28H4Z"
  })), children);
});
var AnalyticsReference32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AnalyticsReference32(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM30 4H23V6h3.5859L19 13.5859 14.707 9.293a1 1 0 00-1.414 0L8 14.5858 9.4142 16 14 11.4141l4.293 4.2929a1 1 0 001.414 0L28 7.4141V11h2zM16 28H30V30H16zM2 2H4V16H2z"
  })), children);
});
var AnalyticsReference24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AnalyticsReference24(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM30 4H23V6h3.5859L19 13.5859 14.707 9.293a1 1 0 00-1.414 0L8 14.5858 9.4142 16 14 11.4141l4.293 4.2929a1 1 0 001.414 0L28 7.4141V11h2zM16 28H30V30H16zM2 2H4V16H2z"
  })), children);
});
var AnalyticsReference20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AnalyticsReference20(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM30 4H23V6h3.5859L19 13.5859 14.707 9.293a1 1 0 00-1.414 0L8 14.5858 9.4142 16 14 11.4141l4.293 4.2929a1 1 0 001.414 0L28 7.4141V11h2zM16 28H30V30H16zM2 2H4V16H2z"
  })), children);
});
var AnalyticsReference16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AnalyticsReference16(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM30 4H23V6h3.5859L19 13.5859 14.707 9.293a1 1 0 00-1.414 0L8 14.5858 9.4142 16 14 11.4141l4.293 4.2929a1 1 0 001.414 0L28 7.4141V11h2zM16 28H30V30H16zM2 2H4V16H2z"
  })), children);
});
var WatsonHealthAngle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAngle32(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,24a3.51,3.51,0,0,0-.88-1.86L17.65,5.56l-1.73-1L6.35,21.12A3.06,3.06,0,0,0,5.5,21a3.5,3.5,0,1,0,3.15,5H28V24ZM5.5,26A1.5,1.5,0,1,1,7,24.5,1.5,1.5,0,0,1,5.5,26Z"
  })), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,21h2a13,13,0,0,0-5.42-10.56l-1.16,1.62A11,11,0,0,1,22,21Z"
  })), children);
});
var WatsonHealthAngle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAngle24(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,24a3.51,3.51,0,0,0-.88-1.86L17.65,5.56l-1.73-1L6.35,21.12A3.06,3.06,0,0,0,5.5,21a3.5,3.5,0,1,0,3.15,5H28V24ZM5.5,26A1.5,1.5,0,1,1,7,24.5,1.5,1.5,0,0,1,5.5,26Z"
  })), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,21h2a13,13,0,0,0-5.42-10.56l-1.16,1.62A11,11,0,0,1,22,21Z"
  })), children);
});
var WatsonHealthAngle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAngle20(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,24a3.51,3.51,0,0,0-.88-1.86L17.65,5.56l-1.73-1L6.35,21.12A3.06,3.06,0,0,0,5.5,21a3.5,3.5,0,1,0,3.15,5H28V24ZM5.5,26A1.5,1.5,0,1,1,7,24.5,1.5,1.5,0,0,1,5.5,26Z"
  })), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,21h2a13,13,0,0,0-5.42-10.56l-1.16,1.62A11,11,0,0,1,22,21Z"
  })), children);
});
var WatsonHealthAngle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAngle16(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,24a3.51,3.51,0,0,0-.88-1.86L17.65,5.56l-1.73-1L6.35,21.12A3.06,3.06,0,0,0,5.5,21a3.5,3.5,0,1,0,3.15,5H28V24ZM5.5,26A1.5,1.5,0,1,1,7,24.5,1.5,1.5,0,0,1,5.5,26Z"
  })), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,21h2a13,13,0,0,0-5.42-10.56l-1.16,1.62A11,11,0,0,1,22,21Z"
  })), children);
});
var WatsonHealthAnnotationVisibility32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAnnotationVisibility32(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,22H4V6H28Z"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 20H13a3.51 3.51 0 00-.88-1.86l3.8-6.64-1.74-1-3.78 6.62A3.35 3.35 0 009.5 17a3.5 3.5 0 103.15 5H21zM9.5 22A1.5 1.5 0 1111 20.5 1.5 1.5 0 019.5 22zM19 8H26V10H19zM19 12H23V14H19z"
  })), children);
});
var WatsonHealthAnnotationVisibility24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAnnotationVisibility24(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,22H4V6H28Z"
  })), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 20H13a3.51 3.51 0 00-.88-1.86l3.8-6.64-1.74-1-3.78 6.62A3.35 3.35 0 009.5 17a3.5 3.5 0 103.15 5H21zM9.5 22A1.5 1.5 0 1111 20.5 1.5 1.5 0 019.5 22zM19 8H26V10H19zM19 12H23V14H19z"
  })), children);
});
var WatsonHealthAnnotationVisibility20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAnnotationVisibility20(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,22H4V6H28Z"
  })), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 20H13a3.51 3.51 0 00-.88-1.86l3.8-6.64-1.74-1-3.78 6.62A3.35 3.35 0 009.5 17a3.5 3.5 0 103.15 5H21zM9.5 22A1.5 1.5 0 1111 20.5 1.5 1.5 0 019.5 22zM19 8H26V10H19zM19 12H23V14H19z"
  })), children);
});
var WatsonHealthAnnotationVisibility16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAnnotationVisibility16(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,22H4V6H28Z"
  })), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 20H13a3.51 3.51 0 00-.88-1.86l3.8-6.64-1.74-1-3.78 6.62A3.35 3.35 0 009.5 17a3.5 3.5 0 103.15 5H21zM9.5 22A1.5 1.5 0 1111 20.5 1.5 1.5 0 019.5 22zM19 8H26V10H19zM19 12H23V14H19z"
  })), children);
});
var Aperture32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Aperture32(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM27.84,14.14,22,17.52V5.62A12,12,0,0,1,27.84,14.14ZM12,18.68V13.32L16,11l4,2.31v5.36L16,21Zm8-14V11L10.34,5.42A11.9,11.9,0,0,1,20,4.7Zm-11.52,2L14,9.85,4,15.62A12,12,0,0,1,8.48,6.66ZM4.16,17.85,10,14.47V26.38A12,12,0,0,1,4.16,17.85ZM12,27.3V21l9.67,5.58A11.92,11.92,0,0,1,16,28,12.05,12.05,0,0,1,12,27.3Zm11.52-2L18,22.14l10-5.77A12,12,0,0,1,23.52,25.34Z"
  })), children);
});
var Aperture24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Aperture24(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM27.84,14.14,22,17.52V5.62A12,12,0,0,1,27.84,14.14ZM12,18.68V13.32L16,11l4,2.31v5.36L16,21Zm8-14V11L10.34,5.42A11.9,11.9,0,0,1,20,4.7Zm-11.52,2L14,9.85,4,15.62A12,12,0,0,1,8.48,6.66ZM4.16,17.85,10,14.47V26.38A12,12,0,0,1,4.16,17.85ZM12,27.3V21l9.67,5.58A11.92,11.92,0,0,1,16,28,12.05,12.05,0,0,1,12,27.3Zm11.52-2L18,22.14l10-5.77A12,12,0,0,1,23.52,25.34Z"
  })), children);
});
var Aperture20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Aperture20(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM27.84,14.14,22,17.52V5.62A12,12,0,0,1,27.84,14.14ZM12,18.68V13.32L16,11l4,2.31v5.36L16,21Zm8-14V11L10.34,5.42A11.9,11.9,0,0,1,20,4.7Zm-11.52,2L14,9.85,4,15.62A12,12,0,0,1,8.48,6.66ZM4.16,17.85,10,14.47V26.38A12,12,0,0,1,4.16,17.85ZM12,27.3V21l9.67,5.58A11.92,11.92,0,0,1,16,28,12.05,12.05,0,0,1,12,27.3Zm11.52-2L18,22.14l10-5.77A12,12,0,0,1,23.52,25.34Z"
  })), children);
});
var Aperture16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Aperture16(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM27.84,14.14,22,17.52V5.62A12,12,0,0,1,27.84,14.14ZM12,18.68V13.32L16,11l4,2.31v5.36L16,21Zm8-14V11L10.34,5.42A11.9,11.9,0,0,1,20,4.7Zm-11.52,2L14,9.85,4,15.62A12,12,0,0,1,8.48,6.66ZM4.16,17.85,10,14.47V26.38A12,12,0,0,1,4.16,17.85ZM12,27.3V21l9.67,5.58A11.92,11.92,0,0,1,16,28,12.05,12.05,0,0,1,12,27.3Zm11.52-2L18,22.14l10-5.77A12,12,0,0,1,23.52,25.34Z"
  })), children);
});
var Api32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Api32(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,22a3.86,3.86,0,0,0-2,.57l-3.09-3.1a6,6,0,0,0,0-6.94L24,9.43A3.86,3.86,0,0,0,26,10a4,4,0,1,0-4-4,3.86,3.86,0,0,0,.57,2l-3.1,3.09a6,6,0,0,0-6.94,0L9.43,8A3.86,3.86,0,0,0,10,6a4,4,0,1,0-4,4,3.86,3.86,0,0,0,2-.57l3.09,3.1a6,6,0,0,0,0,6.94L8,22.57A3.86,3.86,0,0,0,6,22a4,4,0,1,0,4,4,3.86,3.86,0,0,0-.57-2l3.1-3.09a6,6,0,0,0,6.94,0L22.57,24A3.86,3.86,0,0,0,22,26a4,4,0,1,0,4-4ZM26,4a2,2,0,1,1-2,2A2,2,0,0,1,26,4ZM4,6A2,2,0,1,1,6,8,2,2,0,0,1,4,6ZM6,28a2,2,0,1,1,2-2A2,2,0,0,1,6,28Zm10-8a4,4,0,1,1,4-4A4,4,0,0,1,16,20Zm10,8a2,2,0,1,1,2-2A2,2,0,0,1,26,28Z"
  })), children);
});
var Api24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Api24(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,22a3.86,3.86,0,0,0-2,.57l-3.09-3.1a6,6,0,0,0,0-6.94L24,9.43A3.86,3.86,0,0,0,26,10a4,4,0,1,0-4-4,3.86,3.86,0,0,0,.57,2l-3.1,3.09a6,6,0,0,0-6.94,0L9.43,8A3.86,3.86,0,0,0,10,6a4,4,0,1,0-4,4,3.86,3.86,0,0,0,2-.57l3.09,3.1a6,6,0,0,0,0,6.94L8,22.57A3.86,3.86,0,0,0,6,22a4,4,0,1,0,4,4,3.86,3.86,0,0,0-.57-2l3.1-3.09a6,6,0,0,0,6.94,0L22.57,24A3.86,3.86,0,0,0,22,26a4,4,0,1,0,4-4ZM26,4a2,2,0,1,1-2,2A2,2,0,0,1,26,4ZM4,6A2,2,0,1,1,6,8,2,2,0,0,1,4,6ZM6,28a2,2,0,1,1,2-2A2,2,0,0,1,6,28Zm10-8a4,4,0,1,1,4-4A4,4,0,0,1,16,20Zm10,8a2,2,0,1,1,2-2A2,2,0,0,1,26,28Z"
  })), children);
});
var Api20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Api20(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,22a3.86,3.86,0,0,0-2,.57l-3.09-3.1a6,6,0,0,0,0-6.94L24,9.43A3.86,3.86,0,0,0,26,10a4,4,0,1,0-4-4,3.86,3.86,0,0,0,.57,2l-3.1,3.09a6,6,0,0,0-6.94,0L9.43,8A3.86,3.86,0,0,0,10,6a4,4,0,1,0-4,4,3.86,3.86,0,0,0,2-.57l3.09,3.1a6,6,0,0,0,0,6.94L8,22.57A3.86,3.86,0,0,0,6,22a4,4,0,1,0,4,4,3.86,3.86,0,0,0-.57-2l3.1-3.09a6,6,0,0,0,6.94,0L22.57,24A3.86,3.86,0,0,0,22,26a4,4,0,1,0,4-4ZM26,4a2,2,0,1,1-2,2A2,2,0,0,1,26,4ZM4,6A2,2,0,1,1,6,8,2,2,0,0,1,4,6ZM6,28a2,2,0,1,1,2-2A2,2,0,0,1,6,28Zm10-8a4,4,0,1,1,4-4A4,4,0,0,1,16,20Zm10,8a2,2,0,1,1,2-2A2,2,0,0,1,26,28Z"
  })), children);
});
var Api16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Api16(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,22a3.86,3.86,0,0,0-2,.57l-3.09-3.1a6,6,0,0,0,0-6.94L24,9.43A3.86,3.86,0,0,0,26,10a4,4,0,1,0-4-4,3.86,3.86,0,0,0,.57,2l-3.1,3.09a6,6,0,0,0-6.94,0L9.43,8A3.86,3.86,0,0,0,10,6a4,4,0,1,0-4,4,3.86,3.86,0,0,0,2-.57l3.09,3.1a6,6,0,0,0,0,6.94L8,22.57A3.86,3.86,0,0,0,6,22a4,4,0,1,0,4,4,3.86,3.86,0,0,0-.57-2l3.1-3.09a6,6,0,0,0,6.94,0L22.57,24A3.86,3.86,0,0,0,22,26a4,4,0,1,0,4-4ZM26,4a2,2,0,1,1-2,2A2,2,0,0,1,26,4ZM4,6A2,2,0,1,1,6,8,2,2,0,0,1,4,6ZM6,28a2,2,0,1,1,2-2A2,2,0,0,1,6,28Zm10-8a4,4,0,1,1,4-4A4,4,0,0,1,16,20Zm10,8a2,2,0,1,1,2-2A2,2,0,0,1,26,28Z"
  })), children);
});
var Api_132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Api_132(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 9H4a2 2 0 00-2 2V23H4V18H8v5h2V11A2 2 0 008 9zM4 16V11H8v5zM22 11L25 11 25 21 22 21 22 23 30 23 30 21 27 21 27 11 30 11 30 9 22 9 22 11zM14 23H12V9h6a2 2 0 012 2v5a2 2 0 01-2 2H14zm0-7h4V11H14z"
  })), children);
});
var Api_124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Api_124(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 9H4a2 2 0 00-2 2V23H4V18H8v5h2V11A2 2 0 008 9zM4 16V11H8v5zM22 11L25 11 25 21 22 21 22 23 30 23 30 21 27 21 27 11 30 11 30 9 22 9 22 11zM14 23H12V9h6a2 2 0 012 2v5a2 2 0 01-2 2H14zm0-7h4V11H14z"
  })), children);
});
var Api_120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Api_120(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 9H4a2 2 0 00-2 2V23H4V18H8v5h2V11A2 2 0 008 9zM4 16V11H8v5zM22 11L25 11 25 21 22 21 22 23 30 23 30 21 27 21 27 11 30 11 30 9 22 9 22 11zM14 23H12V9h6a2 2 0 012 2v5a2 2 0 01-2 2H14zm0-7h4V11H14z"
  })), children);
});
var Api_116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Api_116(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 9H4a2 2 0 00-2 2V23H4V18H8v5h2V11A2 2 0 008 9zM4 16V11H8v5zM22 11L25 11 25 21 22 21 22 23 30 23 30 21 27 21 27 11 30 11 30 9 22 9 22 11zM14 23H12V9h6a2 2 0 012 2v5a2 2 0 01-2 2H14zm0-7h4V11H14z"
  })), children);
});
var App32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function App32(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 10H22V24h2V20h4a2.0027 2.0027 0 002-2V12A2.0023 2.0023 0 0028 10zm-4 8V12h4v6zM18 10H12V24h2V20h4a2.0027 2.0027 0 002-2V12A2.0023 2.0023 0 0018 10zm-4 8V12h4v6zM8 10H3v2H8v2H4a2 2 0 00-2 2v2a2 2 0 002 2h6V12A2.0023 2.0023 0 008 10zm0 8H4V16H8z"
  })), children);
});
var App24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function App24(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 10H22V24h2V20h4a2.0027 2.0027 0 002-2V12A2.0023 2.0023 0 0028 10zm-4 8V12h4v6zM18 10H12V24h2V20h4a2.0027 2.0027 0 002-2V12A2.0023 2.0023 0 0018 10zm-4 8V12h4v6zM8 10H3v2H8v2H4a2 2 0 00-2 2v2a2 2 0 002 2h6V12A2.0023 2.0023 0 008 10zm0 8H4V16H8z"
  })), children);
});
var App20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function App20(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 10H22V24h2V20h4a2.0027 2.0027 0 002-2V12A2.0023 2.0023 0 0028 10zm-4 8V12h4v6zM18 10H12V24h2V20h4a2.0027 2.0027 0 002-2V12A2.0023 2.0023 0 0018 10zm-4 8V12h4v6zM8 10H3v2H8v2H4a2 2 0 00-2 2v2a2 2 0 002 2h6V12A2.0023 2.0023 0 008 10zm0 8H4V16H8z"
  })), children);
});
var App16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function App16(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 10H22V24h2V20h4a2.0027 2.0027 0 002-2V12A2.0023 2.0023 0 0028 10zm-4 8V12h4v6zM18 10H12V24h2V20h4a2.0027 2.0027 0 002-2V12A2.0023 2.0023 0 0018 10zm-4 8V12h4v6zM8 10H3v2H8v2H4a2 2 0 00-2 2v2a2 2 0 002 2h6V12A2.0023 2.0023 0 008 10zm0 8H4V16H8z"
  })), children);
});
var AppConnectivity32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AppConnectivity32(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,14h8a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H20a2.0023,2.0023,0,0,0-2,2H9A2.0023,2.0023,0,0,0,7,6v4H4a2.0023,2.0023,0,0,0-2,2v8a2.0023,2.0023,0,0,0,2,2H6v4a2.0023,2.0023,0,0,0,2,2H18a2.0023,2.0023,0,0,0,2,2h8a2.0023,2.0023,0,0,0,2-2V20a2.0023,2.0023,0,0,0-2-2H20a2.0023,2.0023,0,0,0-2,2v6H8V22h4a2.0023,2.0023,0,0,0,2-2V12a2.0023,2.0023,0,0,0-2-2H9V6h9v6A2.0023,2.0023,0,0,0,20,14Zm0,14V24h8v4Zm8-8,0,2H20V20ZM4,20V16h8v4Zm8.0005-6H4V12h8ZM20,12V8h8v4Zm8-8,0,2H20V4Z"
  })), children);
});
var AppConnectivity24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AppConnectivity24(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,14h8a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H20a2.0023,2.0023,0,0,0-2,2H9A2.0023,2.0023,0,0,0,7,6v4H4a2.0023,2.0023,0,0,0-2,2v8a2.0023,2.0023,0,0,0,2,2H6v4a2.0023,2.0023,0,0,0,2,2H18a2.0023,2.0023,0,0,0,2,2h8a2.0023,2.0023,0,0,0,2-2V20a2.0023,2.0023,0,0,0-2-2H20a2.0023,2.0023,0,0,0-2,2v6H8V22h4a2.0023,2.0023,0,0,0,2-2V12a2.0023,2.0023,0,0,0-2-2H9V6h9v6A2.0023,2.0023,0,0,0,20,14Zm0,14V24h8v4Zm8-8,0,2H20V20ZM4,20V16h8v4Zm8.0005-6H4V12h8ZM20,12V8h8v4Zm8-8,0,2H20V4Z"
  })), children);
});
var AppConnectivity20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AppConnectivity20(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,14h8a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H20a2.0023,2.0023,0,0,0-2,2H9A2.0023,2.0023,0,0,0,7,6v4H4a2.0023,2.0023,0,0,0-2,2v8a2.0023,2.0023,0,0,0,2,2H6v4a2.0023,2.0023,0,0,0,2,2H18a2.0023,2.0023,0,0,0,2,2h8a2.0023,2.0023,0,0,0,2-2V20a2.0023,2.0023,0,0,0-2-2H20a2.0023,2.0023,0,0,0-2,2v6H8V22h4a2.0023,2.0023,0,0,0,2-2V12a2.0023,2.0023,0,0,0-2-2H9V6h9v6A2.0023,2.0023,0,0,0,20,14Zm0,14V24h8v4Zm8-8,0,2H20V20ZM4,20V16h8v4Zm8.0005-6H4V12h8ZM20,12V8h8v4Zm8-8,0,2H20V4Z"
  })), children);
});
var AppConnectivity16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AppConnectivity16(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,14h8a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H20a2.0023,2.0023,0,0,0-2,2H9A2.0023,2.0023,0,0,0,7,6v4H4a2.0023,2.0023,0,0,0-2,2v8a2.0023,2.0023,0,0,0,2,2H6v4a2.0023,2.0023,0,0,0,2,2H18a2.0023,2.0023,0,0,0,2,2h8a2.0023,2.0023,0,0,0,2-2V20a2.0023,2.0023,0,0,0-2-2H20a2.0023,2.0023,0,0,0-2,2v6H8V22h4a2.0023,2.0023,0,0,0,2-2V12a2.0023,2.0023,0,0,0-2-2H9V6h9v6A2.0023,2.0023,0,0,0,20,14Zm0,14V24h8v4Zm8-8,0,2H20V20ZM4,20V16h8v4Zm8.0005-6H4V12h8ZM20,12V8h8v4Zm8-8,0,2H20V4Z"
  })), children);
});
var AppSwitcher32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AppSwitcher32(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  if (true) {
    if (!didWarnAboutDeprecation['AppSwitcher32']) {
      didWarnAboutDeprecation['AppSwitcher32'] = true;
      console.warn("The AppSwitcher32 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 4H18V8H14zM4 4H8V8H4zM24 4H28V8H24zM14 14H18V18H14zM4 14H8V18H4zM24 14H28V18H24zM14 24H18V28H14zM4 24H8V28H4zM24 24H28V28H24z"
  })), children);
});
var AppSwitcher24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AppSwitcher24(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  if (true) {
    if (!didWarnAboutDeprecation['AppSwitcher24']) {
      didWarnAboutDeprecation['AppSwitcher24'] = true;
      console.warn("The AppSwitcher24 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 4H18V8H14zM4 4H8V8H4zM24 4H28V8H24zM14 14H18V18H14zM4 14H8V18H4zM24 14H28V18H24zM14 24H18V28H14zM4 24H8V28H4zM24 24H28V28H24z"
  })), children);
});
var AppSwitcher20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AppSwitcher20(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  if (true) {
    if (!didWarnAboutDeprecation['AppSwitcher20']) {
      didWarnAboutDeprecation['AppSwitcher20'] = true;
      console.warn("The AppSwitcher20 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 4H18V8H14zM4 4H8V8H4zM24 4H28V8H24zM14 14H18V18H14zM4 14H8V18H4zM24 14H28V18H24zM14 24H18V28H14zM4 24H8V28H4zM24 24H28V28H24z"
  })), children);
});
var AppSwitcher16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AppSwitcher16(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  if (true) {
    if (!didWarnAboutDeprecation['AppSwitcher16']) {
      didWarnAboutDeprecation['AppSwitcher16'] = true;
      console.warn("The AppSwitcher16 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 4H18V8H14zM4 4H8V8H4zM24 4H28V8H24zM14 14H18V18H14zM4 14H8V18H4zM24 14H28V18H24zM14 24H18V28H14zM4 24H8V28H4zM24 24H28V28H24z"
  })), children);
});
var Apple32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Apple32(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.7788,8a11.4843,11.4843,0,0,0-3.0547.5342,14.5665,14.5665,0,0,1-1.8225.4126A6.0054,6.0054,0,0,0,11,4V6a3.9933,3.9933,0,0,1,3.8267,2.9c-.5181-.0879-1.0569-.2207-1.6172-.3648A12.89,12.89,0,0,0,10.0317,8C6.311,8,4,11.0652,4,16c0,7.51,4.0679,11.999,8.0005,12h.0015a7.1576,7.1576,0,0,0,2.49-.59A5.0128,5.0128,0,0,1,16,27a5.0266,5.0266,0,0,1,1.5112.41A7.15,7.15,0,0,0,20,28h0c3.9307-.001,8-4.49,8-12C28,12.3094,26.3706,8,21.7788,8ZM20,26h0a5.5038,5.5038,0,0,1-1.7905-.4639A6.4168,6.4168,0,0,0,16,25a6.4043,6.4043,0,0,0-2.2061.5361A5.5343,5.5343,0,0,1,12,26h.0015C9.0513,25.9988,6,22.2586,6,16c0-1.8037.3931-6,4.0317-6a11.2363,11.2363,0,0,1,2.6807.4726A12.9819,12.9819,0,0,0,15.7612,11h.4922a11.7955,11.7955,0,0,0,2.9956-.5361A9.8483,9.8483,0,0,1,21.7788,10C25.7964,10,26,14.9978,26,16,26,22.2586,22.9482,25.9988,20,26Z"
  })), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,7H17V6a2.0021,2.0021,0,0,1,2-2h1V5A2.0021,2.0021,0,0,1,18,7Z"
  })), children);
});
var Apple24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Apple24(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.7788,8a11.4843,11.4843,0,0,0-3.0547.5342,14.5665,14.5665,0,0,1-1.8225.4126A6.0054,6.0054,0,0,0,11,4V6a3.9933,3.9933,0,0,1,3.8267,2.9c-.5181-.0879-1.0569-.2207-1.6172-.3648A12.89,12.89,0,0,0,10.0317,8C6.311,8,4,11.0652,4,16c0,7.51,4.0679,11.999,8.0005,12h.0015a7.1576,7.1576,0,0,0,2.49-.59A5.0128,5.0128,0,0,1,16,27a5.0266,5.0266,0,0,1,1.5112.41A7.15,7.15,0,0,0,20,28h0c3.9307-.001,8-4.49,8-12C28,12.3094,26.3706,8,21.7788,8ZM20,26h0a5.5038,5.5038,0,0,1-1.7905-.4639A6.4168,6.4168,0,0,0,16,25a6.4043,6.4043,0,0,0-2.2061.5361A5.5343,5.5343,0,0,1,12,26h.0015C9.0513,25.9988,6,22.2586,6,16c0-1.8037.3931-6,4.0317-6a11.2363,11.2363,0,0,1,2.6807.4726A12.9819,12.9819,0,0,0,15.7612,11h.4922a11.7955,11.7955,0,0,0,2.9956-.5361A9.8483,9.8483,0,0,1,21.7788,10C25.7964,10,26,14.9978,26,16,26,22.2586,22.9482,25.9988,20,26Z"
  })), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,7H17V6a2.0021,2.0021,0,0,1,2-2h1V5A2.0021,2.0021,0,0,1,18,7Z"
  })), children);
});
var Apple20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Apple20(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.7788,8a11.4843,11.4843,0,0,0-3.0547.5342,14.5665,14.5665,0,0,1-1.8225.4126A6.0054,6.0054,0,0,0,11,4V6a3.9933,3.9933,0,0,1,3.8267,2.9c-.5181-.0879-1.0569-.2207-1.6172-.3648A12.89,12.89,0,0,0,10.0317,8C6.311,8,4,11.0652,4,16c0,7.51,4.0679,11.999,8.0005,12h.0015a7.1576,7.1576,0,0,0,2.49-.59A5.0128,5.0128,0,0,1,16,27a5.0266,5.0266,0,0,1,1.5112.41A7.15,7.15,0,0,0,20,28h0c3.9307-.001,8-4.49,8-12C28,12.3094,26.3706,8,21.7788,8ZM20,26h0a5.5038,5.5038,0,0,1-1.7905-.4639A6.4168,6.4168,0,0,0,16,25a6.4043,6.4043,0,0,0-2.2061.5361A5.5343,5.5343,0,0,1,12,26h.0015C9.0513,25.9988,6,22.2586,6,16c0-1.8037.3931-6,4.0317-6a11.2363,11.2363,0,0,1,2.6807.4726A12.9819,12.9819,0,0,0,15.7612,11h.4922a11.7955,11.7955,0,0,0,2.9956-.5361A9.8483,9.8483,0,0,1,21.7788,10C25.7964,10,26,14.9978,26,16,26,22.2586,22.9482,25.9988,20,26Z"
  })), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,7H17V6a2.0021,2.0021,0,0,1,2-2h1V5A2.0021,2.0021,0,0,1,18,7Z"
  })), children);
});
var Apple16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Apple16(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.7788,8a11.4843,11.4843,0,0,0-3.0547.5342,14.5665,14.5665,0,0,1-1.8225.4126A6.0054,6.0054,0,0,0,11,4V6a3.9933,3.9933,0,0,1,3.8267,2.9c-.5181-.0879-1.0569-.2207-1.6172-.3648A12.89,12.89,0,0,0,10.0317,8C6.311,8,4,11.0652,4,16c0,7.51,4.0679,11.999,8.0005,12h.0015a7.1576,7.1576,0,0,0,2.49-.59A5.0128,5.0128,0,0,1,16,27a5.0266,5.0266,0,0,1,1.5112.41A7.15,7.15,0,0,0,20,28h0c3.9307-.001,8-4.49,8-12C28,12.3094,26.3706,8,21.7788,8ZM20,26h0a5.5038,5.5038,0,0,1-1.7905-.4639A6.4168,6.4168,0,0,0,16,25a6.4043,6.4043,0,0,0-2.2061.5361A5.5343,5.5343,0,0,1,12,26h.0015C9.0513,25.9988,6,22.2586,6,16c0-1.8037.3931-6,4.0317-6a11.2363,11.2363,0,0,1,2.6807.4726A12.9819,12.9819,0,0,0,15.7612,11h.4922a11.7955,11.7955,0,0,0,2.9956-.5361A9.8483,9.8483,0,0,1,21.7788,10C25.7964,10,26,14.9978,26,16,26,22.2586,22.9482,25.9988,20,26Z"
  })), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,7H17V6a2.0021,2.0021,0,0,1,2-2h1V5A2.0021,2.0021,0,0,1,18,7Z"
  })), children);
});
var Application32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Application32(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 18H6a2 2 0 01-2-2V6A2 2 0 016 4H16a2 2 0 012 2V16A2 2 0 0116 18zM6 6V16H16V6zM26 12v4H22V12h4m0-2H22a2 2 0 00-2 2v4a2 2 0 002 2h4a2 2 0 002-2V12a2 2 0 00-2-2zM26 22v4H22V22h4m0-2H22a2 2 0 00-2 2v4a2 2 0 002 2h4a2 2 0 002-2V22a2 2 0 00-2-2zM16 22v4H12V22h4m0-2H12a2 2 0 00-2 2v4a2 2 0 002 2h4a2 2 0 002-2V22a2 2 0 00-2-2z"
  })), children);
});
var Application24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Application24(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 18H6a2 2 0 01-2-2V6A2 2 0 016 4H16a2 2 0 012 2V16A2 2 0 0116 18zM6 6V16H16V6zM26 12v4H22V12h4m0-2H22a2 2 0 00-2 2v4a2 2 0 002 2h4a2 2 0 002-2V12a2 2 0 00-2-2zM26 22v4H22V22h4m0-2H22a2 2 0 00-2 2v4a2 2 0 002 2h4a2 2 0 002-2V22a2 2 0 00-2-2zM16 22v4H12V22h4m0-2H12a2 2 0 00-2 2v4a2 2 0 002 2h4a2 2 0 002-2V22a2 2 0 00-2-2z"
  })), children);
});
var Application20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Application20(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 18H6a2 2 0 01-2-2V6A2 2 0 016 4H16a2 2 0 012 2V16A2 2 0 0116 18zM6 6V16H16V6zM26 12v4H22V12h4m0-2H22a2 2 0 00-2 2v4a2 2 0 002 2h4a2 2 0 002-2V12a2 2 0 00-2-2zM26 22v4H22V22h4m0-2H22a2 2 0 00-2 2v4a2 2 0 002 2h4a2 2 0 002-2V22a2 2 0 00-2-2zM16 22v4H12V22h4m0-2H12a2 2 0 00-2 2v4a2 2 0 002 2h4a2 2 0 002-2V22a2 2 0 00-2-2z"
  })), children);
});
var Application16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Application16(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 18H6a2 2 0 01-2-2V6A2 2 0 016 4H16a2 2 0 012 2V16A2 2 0 0116 18zM6 6V16H16V6zM26 12v4H22V12h4m0-2H22a2 2 0 00-2 2v4a2 2 0 002 2h4a2 2 0 002-2V12a2 2 0 00-2-2zM26 22v4H22V22h4m0-2H22a2 2 0 00-2 2v4a2 2 0 002 2h4a2 2 0 002-2V22a2 2 0 00-2-2zM16 22v4H12V22h4m0-2H12a2 2 0 00-2 2v4a2 2 0 002 2h4a2 2 0 002-2V22a2 2 0 00-2-2z"
  })), children);
});
var ApplicationMobile32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ApplicationMobile32(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 7H27V11H23zM23 13H27V17H23zM17 7H21V11H17zM17 13H21V17H17z"
  })), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14.5",
    cy: "24.5",
    r: "1.5"
  })), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,30H8a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,8,2H21V4H8V28H21V20h2v8A2.0023,2.0023,0,0,1,21,30Z"
  })), children);
});
var ApplicationMobile24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ApplicationMobile24(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 7H27V11H23zM23 13H27V17H23zM17 7H21V11H17zM17 13H21V17H17z"
  })), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14.5",
    cy: "24.5",
    r: "1.5"
  })), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,30H8a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,8,2H21V4H8V28H21V20h2v8A2.0023,2.0023,0,0,1,21,30Z"
  })), children);
});
var ApplicationMobile20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ApplicationMobile20(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 7H27V11H23zM23 13H27V17H23zM17 7H21V11H17zM17 13H21V17H17z"
  })), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14.5",
    cy: "24.5",
    r: "1.5"
  })), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,30H8a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,8,2H21V4H8V28H21V20h2v8A2.0023,2.0023,0,0,1,21,30Z"
  })), children);
});
var ApplicationMobile16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ApplicationMobile16(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 7H27V11H23zM23 13H27V17H23zM17 7H21V11H17zM17 13H21V17H17z"
  })), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14.5",
    cy: "24.5",
    r: "1.5"
  })), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,30H8a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,8,2H21V4H8V28H21V20h2v8A2.0023,2.0023,0,0,1,21,30Z"
  })), children);
});
var ApplicationVirtual32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ApplicationVirtual32(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 19H21V23H17zM11 19H15V23H11zM17 25H21V29H17zM11 25H15V29H11z"
  })), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5,25H24V23h.5a5.4961,5.4961,0,0,0,.377-10.9795l-.8365-.0566-.09-.834a7.9979,7.9979,0,0,0-15.9014,0l-.09.834-.8365.0566A5.4961,5.4961,0,0,0,7.5,23H8v2H7.5A7.4964,7.4964,0,0,1,6.1782,10.124a9.9992,9.9992,0,0,1,19.6436,0A7.4964,7.4964,0,0,1,24.5,25Z"
  })), children);
});
var ApplicationVirtual24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ApplicationVirtual24(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 19H21V23H17zM11 19H15V23H11zM17 25H21V29H17zM11 25H15V29H11z"
  })), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5,25H24V23h.5a5.4961,5.4961,0,0,0,.377-10.9795l-.8365-.0566-.09-.834a7.9979,7.9979,0,0,0-15.9014,0l-.09.834-.8365.0566A5.4961,5.4961,0,0,0,7.5,23H8v2H7.5A7.4964,7.4964,0,0,1,6.1782,10.124a9.9992,9.9992,0,0,1,19.6436,0A7.4964,7.4964,0,0,1,24.5,25Z"
  })), children);
});
var ApplicationVirtual20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ApplicationVirtual20(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 19H21V23H17zM11 19H15V23H11zM17 25H21V29H17zM11 25H15V29H11z"
  })), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5,25H24V23h.5a5.4961,5.4961,0,0,0,.377-10.9795l-.8365-.0566-.09-.834a7.9979,7.9979,0,0,0-15.9014,0l-.09.834-.8365.0566A5.4961,5.4961,0,0,0,7.5,23H8v2H7.5A7.4964,7.4964,0,0,1,6.1782,10.124a9.9992,9.9992,0,0,1,19.6436,0A7.4964,7.4964,0,0,1,24.5,25Z"
  })), children);
});
var ApplicationVirtual16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ApplicationVirtual16(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 19H21V23H17zM11 19H15V23H11zM17 25H21V29H17zM11 25H15V29H11z"
  })), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5,25H24V23h.5a5.4961,5.4961,0,0,0,.377-10.9795l-.8365-.0566-.09-.834a7.9979,7.9979,0,0,0-15.9014,0l-.09.834-.8365.0566A5.4961,5.4961,0,0,0,7.5,23H8v2H7.5A7.4964,7.4964,0,0,1,6.1782,10.124a9.9992,9.9992,0,0,1,19.6436,0A7.4964,7.4964,0,0,1,24.5,25Z"
  })), children);
});
var ApplicationWeb32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ApplicationWeb32(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 2H30V6H26zM26 8H30V12H26zM20 2H24V6H20zM20 8H24V12H20z"
  })), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16v6H4V6H16V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V16ZM18,28H14V24h4Z"
  })), children);
});
var ApplicationWeb24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ApplicationWeb24(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 2H30V6H26zM26 8H30V12H26zM20 2H24V6H20zM20 8H24V12H20z"
  })), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16v6H4V6H16V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V16ZM18,28H14V24h4Z"
  })), children);
});
var ApplicationWeb20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ApplicationWeb20(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 2H30V6H26zM26 8H30V12H26zM20 2H24V6H20zM20 8H24V12H20z"
  })), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16v6H4V6H16V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V16ZM18,28H14V24h4Z"
  })), children);
});
var ApplicationWeb16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ApplicationWeb16(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 2H30V6H26zM26 8H30V12H26zM20 2H24V6H20zM20 8H24V12H20z"
  })), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16v6H4V6H16V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V16ZM18,28H14V24h4Z"
  })), children);
});
var Apps32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Apps32(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,4V8H4V4Zm2-2H2v8h8Zm8,2V8H14V4Zm2-2H12v8h8Zm8,2V8H24V4Zm2-2H22v8h8ZM8,14v4H4V14Zm2-2H2v8h8Zm8,2v4H14V14Zm2-2H12v8h8Zm8,2v4H24V14Zm2-2H22v8h8ZM8,24v4H4V24Zm2-2H2v8h8Zm8,2v4H14V24Zm2-2H12v8h8Zm8,2v4H24V24Zm2-2H22v8h8Z"
  })), children);
});
var Apps24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Apps24(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,4V8H4V4Zm2-2H2v8h8Zm8,2V8H14V4Zm2-2H12v8h8Zm8,2V8H24V4Zm2-2H22v8h8ZM8,14v4H4V14Zm2-2H2v8h8Zm8,2v4H14V14Zm2-2H12v8h8Zm8,2v4H24V14Zm2-2H22v8h8ZM8,24v4H4V24Zm2-2H2v8h8Zm8,2v4H14V24Zm2-2H12v8h8Zm8,2v4H24V24Zm2-2H22v8h8Z"
  })), children);
});
var Apps20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Apps20(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,4V8H4V4Zm2-2H2v8h8Zm8,2V8H14V4Zm2-2H12v8h8Zm8,2V8H24V4Zm2-2H22v8h8ZM8,14v4H4V14Zm2-2H2v8h8Zm8,2v4H14V14Zm2-2H12v8h8Zm8,2v4H24V14Zm2-2H22v8h8ZM8,24v4H4V24Zm2-2H2v8h8Zm8,2v4H14V24Zm2-2H12v8h8Zm8,2v4H24V24Zm2-2H22v8h8Z"
  })), children);
});
var Apps16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Apps16(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 2v2H2V2h2zm1-1H1v4h4V1zM9 2v2H7V2h2zm1-1H6v4h4V1zM14 2v2h-2V2h2zm1-1h-4v4h4V1zM4 7v2H2V7h2zm1-1H1v4h4V6zM9 7v2H7V7h2zm1-1H6v4h4V6zM14 7v2h-2V7h2zm1-1h-4v4h4V6zM4 12v2H2v-2h2zm1-1H1v4h4v-4zM9 12v2H7v-2h2zm1-1H6v4h4v-4zM14 12v2h-2v-2h2zm1-1h-4v4h4v-4z"
  })), children);
});
var Archive32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Archive32(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 19H18V21H14z"
  })), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V2ZM24,28H8V16H24Zm0-14H8V10H24ZM8,8V4H24V8Z"
  })), children);
});
var Archive24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Archive24(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 19H18V21H14z"
  })), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V2ZM24,28H8V16H24Zm0-14H8V10H24ZM8,8V4H24V8Z"
  })), children);
});
var Archive20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Archive20(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 19H18V21H14z"
  })), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V2ZM24,28H8V16H24Zm0-14H8V10H24ZM8,8V4H24V8Z"
  })), children);
});
var Archive16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Archive16(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 19H18V21H14z"
  })), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V2ZM24,28H8V16H24Zm0-14H8V10H24ZM8,8V4H24V8Z"
  })), children);
});
var Area32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Area32(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.142V9.858A3.9916,3.9916,0,1,0,22.142,5H9.858A3.9916,3.9916,0,1,0,5,9.858V22.142A3.9916,3.9916,0,1,0,9.858,27H22.142A3.9916,3.9916,0,1,0,27,22.142ZM26,4a2,2,0,1,1-2,2A2.0023,2.0023,0,0,1,26,4ZM4,6A2,2,0,1,1,6,8,2.002,2.002,0,0,1,4,6ZM6,28a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,6,28Zm16.142-3H9.858A3.9937,3.9937,0,0,0,7,22.142V9.858A3.9947,3.9947,0,0,0,9.858,7H22.142A3.9937,3.9937,0,0,0,25,9.858V22.142A3.9931,3.9931,0,0,0,22.142,25ZM26,28a2,2,0,1,1,2-2A2.0027,2.0027,0,0,1,26,28Z"
  })), children);
});
var Area24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Area24(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.142V9.858A3.9916,3.9916,0,1,0,22.142,5H9.858A3.9916,3.9916,0,1,0,5,9.858V22.142A3.9916,3.9916,0,1,0,9.858,27H22.142A3.9916,3.9916,0,1,0,27,22.142ZM26,4a2,2,0,1,1-2,2A2.0023,2.0023,0,0,1,26,4ZM4,6A2,2,0,1,1,6,8,2.002,2.002,0,0,1,4,6ZM6,28a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,6,28Zm16.142-3H9.858A3.9937,3.9937,0,0,0,7,22.142V9.858A3.9947,3.9947,0,0,0,9.858,7H22.142A3.9937,3.9937,0,0,0,25,9.858V22.142A3.9931,3.9931,0,0,0,22.142,25ZM26,28a2,2,0,1,1,2-2A2.0027,2.0027,0,0,1,26,28Z"
  })), children);
});
var Area20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Area20(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.142V9.858A3.9916,3.9916,0,1,0,22.142,5H9.858A3.9916,3.9916,0,1,0,5,9.858V22.142A3.9916,3.9916,0,1,0,9.858,27H22.142A3.9916,3.9916,0,1,0,27,22.142ZM26,4a2,2,0,1,1-2,2A2.0023,2.0023,0,0,1,26,4ZM4,6A2,2,0,1,1,6,8,2.002,2.002,0,0,1,4,6ZM6,28a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,6,28Zm16.142-3H9.858A3.9937,3.9937,0,0,0,7,22.142V9.858A3.9947,3.9947,0,0,0,9.858,7H22.142A3.9937,3.9937,0,0,0,25,9.858V22.142A3.9931,3.9931,0,0,0,22.142,25ZM26,28a2,2,0,1,1,2-2A2.0027,2.0027,0,0,1,26,28Z"
  })), children);
});
var Area16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Area16(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.142V9.858A3.9916,3.9916,0,1,0,22.142,5H9.858A3.9916,3.9916,0,1,0,5,9.858V22.142A3.9916,3.9916,0,1,0,9.858,27H22.142A3.9916,3.9916,0,1,0,27,22.142ZM26,4a2,2,0,1,1-2,2A2.0023,2.0023,0,0,1,26,4ZM4,6A2,2,0,1,1,6,8,2.002,2.002,0,0,1,4,6ZM6,28a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,6,28Zm16.142-3H9.858A3.9937,3.9937,0,0,0,7,22.142V9.858A3.9947,3.9947,0,0,0,9.858,7H22.142A3.9937,3.9937,0,0,0,25,9.858V22.142A3.9931,3.9931,0,0,0,22.142,25ZM26,28a2,2,0,1,1,2-2A2.0027,2.0027,0,0,1,26,28Z"
  })), children);
});
var AreaCustom32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AreaCustom32(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6a3.9916,3.9916,0,0,0-7.9773-.2241L9.5864,8.2627A3.99,3.99,0,1,0,5,13.8579v8.2842A3.9915,3.9915,0,1,0,9.8579,27h8.2842a3.9912,3.9912,0,1,0,5.595-4.5864l2.487-12.4361A3.9945,3.9945,0,0,0,30,6ZM26,4a2,2,0,1,1-2,2A2.0023,2.0023,0,0,1,26,4ZM4,10a2,2,0,1,1,2,2A2.0023,2.0023,0,0,1,4,10ZM6,28a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,6,28Zm12.1421-3H9.8579A3.9942,3.9942,0,0,0,7,22.1421V13.8579a3.9871,3.9871,0,0,0,2.9773-3.6338L22.4136,7.7373a4.0053,4.0053,0,0,0,1.8493,1.8491l-2.487,12.4361A3.9874,3.9874,0,0,0,18.1421,25ZM22,28a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,22,28Z"
  })), children);
});
var AreaCustom24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AreaCustom24(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6a3.9916,3.9916,0,0,0-7.9773-.2241L9.5864,8.2627A3.99,3.99,0,1,0,5,13.8579v8.2842A3.9915,3.9915,0,1,0,9.8579,27h8.2842a3.9912,3.9912,0,1,0,5.595-4.5864l2.487-12.4361A3.9945,3.9945,0,0,0,30,6ZM26,4a2,2,0,1,1-2,2A2.0023,2.0023,0,0,1,26,4ZM4,10a2,2,0,1,1,2,2A2.0023,2.0023,0,0,1,4,10ZM6,28a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,6,28Zm12.1421-3H9.8579A3.9942,3.9942,0,0,0,7,22.1421V13.8579a3.9871,3.9871,0,0,0,2.9773-3.6338L22.4136,7.7373a4.0053,4.0053,0,0,0,1.8493,1.8491l-2.487,12.4361A3.9874,3.9874,0,0,0,18.1421,25ZM22,28a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,22,28Z"
  })), children);
});
var AreaCustom20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AreaCustom20(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6a3.9916,3.9916,0,0,0-7.9773-.2241L9.5864,8.2627A3.99,3.99,0,1,0,5,13.8579v8.2842A3.9915,3.9915,0,1,0,9.8579,27h8.2842a3.9912,3.9912,0,1,0,5.595-4.5864l2.487-12.4361A3.9945,3.9945,0,0,0,30,6ZM26,4a2,2,0,1,1-2,2A2.0023,2.0023,0,0,1,26,4ZM4,10a2,2,0,1,1,2,2A2.0023,2.0023,0,0,1,4,10ZM6,28a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,6,28Zm12.1421-3H9.8579A3.9942,3.9942,0,0,0,7,22.1421V13.8579a3.9871,3.9871,0,0,0,2.9773-3.6338L22.4136,7.7373a4.0053,4.0053,0,0,0,1.8493,1.8491l-2.487,12.4361A3.9874,3.9874,0,0,0,18.1421,25ZM22,28a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,22,28Z"
  })), children);
});
var AreaCustom16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AreaCustom16(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6a3.9916,3.9916,0,0,0-7.9773-.2241L9.5864,8.2627A3.99,3.99,0,1,0,5,13.8579v8.2842A3.9915,3.9915,0,1,0,9.8579,27h8.2842a3.9912,3.9912,0,1,0,5.595-4.5864l2.487-12.4361A3.9945,3.9945,0,0,0,30,6ZM26,4a2,2,0,1,1-2,2A2.0023,2.0023,0,0,1,26,4ZM4,10a2,2,0,1,1,2,2A2.0023,2.0023,0,0,1,4,10ZM6,28a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,6,28Zm12.1421-3H9.8579A3.9942,3.9942,0,0,0,7,22.1421V13.8579a3.9871,3.9871,0,0,0,2.9773-3.6338L22.4136,7.7373a4.0053,4.0053,0,0,0,1.8493,1.8491l-2.487,12.4361A3.9874,3.9874,0,0,0,18.1421,25ZM22,28a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,22,28Z"
  })), children);
});
var Arrival32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Arrival32(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM17.21 5.23l1.39.38 1 11.29 5.87 1.57A2 2 0 0127 20.62a1.88 1.88 0 01-1.37 1.52 2 2 0 01-1 0l-18.7-5a1.89 1.89 0 01-1.33-2.3L6.35 8.34l1.44.38L8.4 13.9l6 1.62L17.21 5.23m-1-2.2a1 1 0 00-.68.69L13 13.07l-2.81-.75L9.69 7.79A1 1 0 009 7L5.87 6.14a.94.94 0 00-.5 0 1 1 0 00-.68.68l-2 7.49a3.87 3.87 0 002.74 4.74l18.71 5A3.87 3.87 0 0029 21a4 4 0 00-3-4.42l-4.52-1.21L20.53 4.71a1 1 0 00-.72-.85L16.73 3a1.06 1.06 0 00-.5 0z"
  })), children);
});
var Arrival24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Arrival24(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM17.21 5.23l1.39.38 1 11.29 5.87 1.57A2 2 0 0127 20.62a1.88 1.88 0 01-1.37 1.52 2 2 0 01-1 0l-18.7-5a1.89 1.89 0 01-1.33-2.3L6.35 8.34l1.44.38L8.4 13.9l6 1.62L17.21 5.23m-1-2.2a1 1 0 00-.68.69L13 13.07l-2.81-.75L9.69 7.79A1 1 0 009 7L5.87 6.14a.94.94 0 00-.5 0 1 1 0 00-.68.68l-2 7.49a3.87 3.87 0 002.74 4.74l18.71 5A3.87 3.87 0 0029 21a4 4 0 00-3-4.42l-4.52-1.21L20.53 4.71a1 1 0 00-.72-.85L16.73 3a1.06 1.06 0 00-.5 0z"
  })), children);
});
var Arrival20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Arrival20(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM17.21 5.23l1.39.38 1 11.29 5.87 1.57A2 2 0 0127 20.62a1.88 1.88 0 01-1.37 1.52 2 2 0 01-1 0l-18.7-5a1.89 1.89 0 01-1.33-2.3L6.35 8.34l1.44.38L8.4 13.9l6 1.62L17.21 5.23m-1-2.2a1 1 0 00-.68.69L13 13.07l-2.81-.75L9.69 7.79A1 1 0 009 7L5.87 6.14a.94.94 0 00-.5 0 1 1 0 00-.68.68l-2 7.49a3.87 3.87 0 002.74 4.74l18.71 5A3.87 3.87 0 0029 21a4 4 0 00-3-4.42l-4.52-1.21L20.53 4.71a1 1 0 00-.72-.85L16.73 3a1.06 1.06 0 00-.5 0z"
  })), children);
});
var Arrival16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Arrival16(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM17.21 5.23l1.39.38 1 11.29 5.87 1.57A2 2 0 0127 20.62a1.88 1.88 0 01-1.37 1.52 2 2 0 01-1 0l-18.7-5a1.89 1.89 0 01-1.33-2.3L6.35 8.34l1.44.38L8.4 13.9l6 1.62L17.21 5.23m-1-2.2a1 1 0 00-.68.69L13 13.07l-2.81-.75L9.69 7.79A1 1 0 009 7L5.87 6.14a.94.94 0 00-.5 0 1 1 0 00-.68.68l-2 7.49a3.87 3.87 0 002.74 4.74l18.71 5A3.87 3.87 0 0029 21a4 4 0 00-3-4.42l-4.52-1.21L20.53 4.71a1 1 0 00-.72-.85L16.73 3a1.06 1.06 0 00-.5 0z"
  })), children);
});
var WatsonHealthArrowAnnotation32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthArrowAnnotation32(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.71 12.29L7.42 6 14 6 14 4 4 4 4 13.99 6 14.01 6 7.41 12.29 13.7 13.71 12.29zM28 10H18v2H28V28H12V18H10V28a2 2 0 002 2H28a2 2 0 002-2V12A2 2 0 0028 10z"
  })), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 25L21 25 21 18 24 18 24 16 16 16 16 18 19 18 19 25z"
  })), children);
});
var WatsonHealthArrowAnnotation24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthArrowAnnotation24(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.71 12.29L7.42 6 14 6 14 4 4 4 4 13.99 6 14.01 6 7.41 12.29 13.7 13.71 12.29zM28 10H18v2H28V28H12V18H10V28a2 2 0 002 2H28a2 2 0 002-2V12A2 2 0 0028 10z"
  })), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 25L21 25 21 18 24 18 24 16 16 16 16 18 19 18 19 25z"
  })), children);
});
var WatsonHealthArrowAnnotation20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthArrowAnnotation20(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.71 12.29L7.42 6 14 6 14 4 4 4 4 13.99 6 14.01 6 7.41 12.29 13.7 13.71 12.29zM28 10H18v2H28V28H12V18H10V28a2 2 0 002 2H28a2 2 0 002-2V12A2 2 0 0028 10z"
  })), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 25L21 25 21 18 24 18 24 16 16 16 16 18 19 18 19 25z"
  })), children);
});
var WatsonHealthArrowAnnotation16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthArrowAnnotation16(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.71 12.29L7.42 6 14 6 14 4 4 4 4 13.99 6 14.01 6 7.41 12.29 13.7 13.71 12.29zM28 10H18v2H28V28H12V18H10V28a2 2 0 002 2H28a2 2 0 002-2V12A2 2 0 0028 10z"
  })), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 25L21 25 21 18 24 18 24 16 16 16 16 18 19 18 19 25z"
  })), children);
});
var ArrowDown32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowDown32(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.59 16.59L17 24.17 17 4 15 4 15 24.17 7.41 16.59 6 18 16 28 26 18 24.59 16.59z"
  })), children);
});
var ArrowDown24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowDown24(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.59 16.59L17 24.17 17 4 15 4 15 24.17 7.41 16.59 6 18 16 28 26 18 24.59 16.59z"
  })), children);
});
var ArrowDown20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowDown20(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.59 16.59L17 24.17 17 4 15 4 15 24.17 7.41 16.59 6 18 16 28 26 18 24.59 16.59z"
  })), children);
});
var ArrowDown16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowDown16(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.3 9.3L8.5 13.1 8.5 1 7.5 1 7.5 13.1 3.7 9.3 3 10 8 15 13 10z"
  })), children);
});
var ArrowDownLeft32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowDownLeft32(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26L22 24 9.41 24 26 7.41 24.59 6 8 22.59 8 10 6 10 6 26 22 26z"
  })), children);
});
var ArrowDownLeft24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowDownLeft24(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26L22 24 9.41 24 26 7.41 24.59 6 8 22.59 8 10 6 10 6 26 22 26z"
  })), children);
});
var ArrowDownLeft20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowDownLeft20(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26L22 24 9.41 24 26 7.41 24.59 6 8 22.59 8 10 6 10 6 26 22 26z"
  })), children);
});
var ArrowDownLeft16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowDownLeft16(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26L22 24 9.41 24 26 7.41 24.59 6 8 22.59 8 10 6 10 6 26 22 26z"
  })), children);
});
var ArrowDownRight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowDownRight32(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 26L10 24 22.59 24 6 7.41 7.41 6 24 22.59 24 10 26 10 26 26 10 26z"
  })), children);
});
var ArrowDownRight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowDownRight24(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 26L10 24 22.59 24 6 7.41 7.41 6 24 22.59 24 10 26 10 26 26 10 26z"
  })), children);
});
var ArrowDownRight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowDownRight20(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 26L10 24 22.59 24 6 7.41 7.41 6 24 22.59 24 10 26 10 26 26 10 26z"
  })), children);
});
var ArrowDownRight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowDownRight16(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 26L10 24 22.59 24 6 7.41 7.41 6 24 22.59 24 10 26 10 26 26 10 26z"
  })), children);
});
var ArrowLeft32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowLeft32(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 26L15.41 24.59 7.83 17 28 17 28 15 7.83 15 15.41 7.41 14 6 4 16 14 26z"
  })), children);
});
var ArrowLeft24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowLeft24(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 26L15.41 24.59 7.83 17 28 17 28 15 7.83 15 15.41 7.41 14 6 4 16 14 26z"
  })), children);
});
var ArrowLeft20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowLeft20(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 26L15.41 24.59 7.83 17 28 17 28 15 7.83 15 15.41 7.41 14 6 4 16 14 26z"
  })), children);
});
var ArrowLeft16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowLeft16(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.7 12.3L2.9 8.5 15 8.5 15 7.5 2.9 7.5 6.7 3.7 6 3 1 8 6 13z"
  })), children);
});
var ArrowRight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowRight32(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 6L16.57 7.393 24.15 15 4 15 4 17 24.15 17 16.57 24.573 18 26 28 16 18 6z"
  })), children);
});
var ArrowRight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowRight24(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 24 24",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 4L12.9 5.1 18.9 11.2 2 11.2 2 12.8 18.9 12.8 12.9 18.9 14 20 22 12z"
  })), children);
});
var ArrowRight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowRight20(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 20 20",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.8 2.8L10.8 3.8 16.2 9.3 1 9.3 1 10.7 16.2 10.7 10.8 16.2 11.8 17.2 19 10z"
  })), children);
});
var ArrowRight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowRight16(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.3 3.7L13.1 7.5 1 7.5 1 8.5 13.1 8.5 9.3 12.3 10 13 15 8 10 3z"
  })), children);
});
var ArrowUp32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowUp32(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 4L6 14 7.41 15.41 15 7.83 15 28 17 28 17 7.83 24.59 15.41 26 14 16 4z"
  })), children);
});
var ArrowUp24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowUp24(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 4L6 14 7.41 15.41 15 7.83 15 28 17 28 17 7.83 24.59 15.41 26 14 16 4z"
  })), children);
});
var ArrowUp20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowUp20(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 4L6 14 7.41 15.41 15 7.83 15 28 17 28 17 7.83 24.59 15.41 26 14 16 4z"
  })), children);
});
var ArrowUp16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowUp16(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.7 6.7L7.5 2.9 7.5 15 8.5 15 8.5 2.9 12.3 6.7 13 6 8 1 3 6z"
  })), children);
});
var ArrowUpLeft32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowUpLeft32(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 6L22 8 9.41 8 26 24.59 24.59 26 8 9.41 8 22 6 22 6 6 22 6z"
  })), children);
});
var ArrowUpLeft24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowUpLeft24(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 6L22 8 9.41 8 26 24.59 24.59 26 8 9.41 8 22 6 22 6 6 22 6z"
  })), children);
});
var ArrowUpLeft20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowUpLeft20(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 6L22 8 9.41 8 26 24.59 24.59 26 8 9.41 8 22 6 22 6 6 22 6z"
  })), children);
});
var ArrowUpLeft16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowUpLeft16(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 6L22 8 9.41 8 26 24.59 24.59 26 8 9.41 8 22 6 22 6 6 22 6z"
  })), children);
});
var ArrowUpRight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowUpRight32(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6L10 8 22.59 8 6 24.59 7.41 26 24 9.41 24 22 26 22 26 6 10 6z"
  })), children);
});
var ArrowUpRight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowUpRight24(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6L10 8 22.59 8 6 24.59 7.41 26 24 9.41 24 22 26 22 26 6 10 6z"
  })), children);
});
var ArrowUpRight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowUpRight20(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6L10 8 22.59 8 6 24.59 7.41 26 24 9.41 24 22 26 22 26 6 10 6z"
  })), children);
});
var ArrowUpRight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowUpRight16(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6L10 8 22.59 8 6 24.59 7.41 26 24 9.41 24 22 26 22 26 6 10 6z"
  })), children);
});
var ArrowShiftDown32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowShiftDown32(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,6V16h5a1,1,0,0,1,.707,1.707l-12,12a.9994.9994,0,0,1-1.414,0l-12-12A1,1,0,0,1,4,16H9V6a2.0023,2.0023,0,0,1,2-2H21A2.0027,2.0027,0,0,1,23,6ZM16,27.5859,25.5859,18H21V6H11V18H6.4141Z"
  })), children);
});
var ArrowShiftDown24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowShiftDown24(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,6V16h5a1,1,0,0,1,.707,1.707l-12,12a.9994.9994,0,0,1-1.414,0l-12-12A1,1,0,0,1,4,16H9V6a2.0023,2.0023,0,0,1,2-2H21A2.0027,2.0027,0,0,1,23,6ZM16,27.5859,25.5859,18H21V6H11V18H6.4141Z"
  })), children);
});
var ArrowShiftDown20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowShiftDown20(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,6V16h5a1,1,0,0,1,.707,1.707l-12,12a.9994.9994,0,0,1-1.414,0l-12-12A1,1,0,0,1,4,16H9V6a2.0023,2.0023,0,0,1,2-2H21A2.0027,2.0027,0,0,1,23,6ZM16,27.5859,25.5859,18H21V6H11V18H6.4141Z"
  })), children);
});
var ArrowShiftDown16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowShiftDown16(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,6V16h5a1,1,0,0,1,.707,1.707l-12,12a.9994.9994,0,0,1-1.414,0l-12-12A1,1,0,0,1,4,16H9V6a2.0023,2.0023,0,0,1,2-2H21A2.0027,2.0027,0,0,1,23,6ZM16,27.5859,25.5859,18H21V6H11V18H6.4141Z"
  })), children);
});
var Arrows32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Arrows32(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  if (true) {
    if (!didWarnAboutDeprecation['Arrows32']) {
      didWarnAboutDeprecation['Arrows32'] = true;
      console.warn("The Arrows32 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.6 20.6L24 24.2 24 4 22 4 22 24.2 18.4 20.6 17 22 23 28 29 22zM9 4L3 10 4.4 11.4 8 7.8 8 28 10 28 10 7.8 13.6 11.4 15 10z"
  })), children);
});
var Arrows24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Arrows24(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  if (true) {
    if (!didWarnAboutDeprecation['Arrows24']) {
      didWarnAboutDeprecation['Arrows24'] = true;
      console.warn("The Arrows24 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.6 20.6L24 24.2 24 4 22 4 22 24.2 18.4 20.6 17 22 23 28 29 22zM9 4L3 10 4.4 11.4 8 7.8 8 28 10 28 10 7.8 13.6 11.4 15 10z"
  })), children);
});
var Arrows20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Arrows20(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  if (true) {
    if (!didWarnAboutDeprecation['Arrows20']) {
      didWarnAboutDeprecation['Arrows20'] = true;
      console.warn("The Arrows20 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.6 20.6L24 24.2 24 4 22 4 22 24.2 18.4 20.6 17 22 23 28 29 22zM9 4L3 10 4.4 11.4 8 7.8 8 28 10 28 10 7.8 13.6 11.4 15 10z"
  })), children);
});
var Arrows16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Arrows16(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  if (true) {
    if (!didWarnAboutDeprecation['Arrows16']) {
      didWarnAboutDeprecation['Arrows16'] = true;
      console.warn("The Arrows16 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.6 20.6L24 24.2 24 4 22 4 22 24.2 18.4 20.6 17 22 23 28 29 22zM9 4L3 10 4.4 11.4 8 7.8 8 28 10 28 10 7.8 13.6 11.4 15 10z"
  })), children);
});
var ArrowsHorizontal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowsHorizontal32(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.41 26.59L7.83 23 28 23 28 21 7.83 21 11.41 17.41 10 16 4 22 10 28 11.41 26.59zM28 10L22 4 20.59 5.41 24.17 9 4 9 4 11 24.17 11 20.59 14.59 22 16 28 10z"
  })), children);
});
var ArrowsHorizontal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowsHorizontal24(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.41 26.59L7.83 23 28 23 28 21 7.83 21 11.41 17.41 10 16 4 22 10 28 11.41 26.59zM28 10L22 4 20.59 5.41 24.17 9 4 9 4 11 24.17 11 20.59 14.59 22 16 28 10z"
  })), children);
});
var ArrowsHorizontal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowsHorizontal20(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.41 26.59L7.83 23 28 23 28 21 7.83 21 11.41 17.41 10 16 4 22 10 28 11.41 26.59zM28 10L22 4 20.59 5.41 24.17 9 4 9 4 11 24.17 11 20.59 14.59 22 16 28 10z"
  })), children);
});
var ArrowsHorizontal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowsHorizontal16(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.41 26.59L7.83 23 28 23 28 21 7.83 21 11.41 17.41 10 16 4 22 10 28 11.41 26.59zM28 10L22 4 20.59 5.41 24.17 9 4 9 4 11 24.17 11 20.59 14.59 22 16 28 10z"
  })), children);
});
var ArrowsVertical32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowsVertical32(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.6 20.6L24 24.2 24 4 22 4 22 24.2 18.4 20.6 17 22 23 28 29 22zM9 4L3 10 4.4 11.4 8 7.8 8 28 10 28 10 7.8 13.6 11.4 15 10z"
  })), children);
});
var ArrowsVertical24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowsVertical24(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.6 20.6L24 24.2 24 4 22 4 22 24.2 18.4 20.6 17 22 23 28 29 22zM9 4L3 10 4.4 11.4 8 7.8 8 28 10 28 10 7.8 13.6 11.4 15 10z"
  })), children);
});
var ArrowsVertical20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowsVertical20(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.6 20.6L24 24.2 24 4 22 4 22 24.2 18.4 20.6 17 22 23 28 29 22zM9 4L3 10 4.4 11.4 8 7.8 8 28 10 28 10 7.8 13.6 11.4 15 10z"
  })), children);
});
var ArrowsVertical16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ArrowsVertical16(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.6 20.6L24 24.2 24 4 22 4 22 24.2 18.4 20.6 17 22 23 28 29 22zM9 4L3 10 4.4 11.4 8 7.8 8 28 10 28 10 7.8 13.6 11.4 15 10z"
  })), children);
});
var Asleep32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Asleep32(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.5025,5.4136A15.0755,15.0755,0,0,0,25.096,23.6082a11.1134,11.1134,0,0,1-7.9749,3.3893c-.1385,0-.2782.0051-.4178,0A11.0944,11.0944,0,0,1,13.5025,5.4136M14.98,3a1.0024,1.0024,0,0,0-.1746.0156A13.0959,13.0959,0,0,0,16.63,28.9973c.1641.006.3282,0,.4909,0a13.0724,13.0724,0,0,0,10.702-5.5556,1.0094,1.0094,0,0,0-.7833-1.5644A13.08,13.08,0,0,1,15.8892,4.38,1.0149,1.0149,0,0,0,14.98,3Z"
  })), children);
});
var Asleep24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Asleep24(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.5025,5.4136A15.0755,15.0755,0,0,0,25.096,23.6082a11.1134,11.1134,0,0,1-7.9749,3.3893c-.1385,0-.2782.0051-.4178,0A11.0944,11.0944,0,0,1,13.5025,5.4136M14.98,3a1.0024,1.0024,0,0,0-.1746.0156A13.0959,13.0959,0,0,0,16.63,28.9973c.1641.006.3282,0,.4909,0a13.0724,13.0724,0,0,0,10.702-5.5556,1.0094,1.0094,0,0,0-.7833-1.5644A13.08,13.08,0,0,1,15.8892,4.38,1.0149,1.0149,0,0,0,14.98,3Z"
  })), children);
});
var Asleep20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Asleep20(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.5025,5.4136A15.0755,15.0755,0,0,0,25.096,23.6082a11.1134,11.1134,0,0,1-7.9749,3.3893c-.1385,0-.2782.0051-.4178,0A11.0944,11.0944,0,0,1,13.5025,5.4136M14.98,3a1.0024,1.0024,0,0,0-.1746.0156A13.0959,13.0959,0,0,0,16.63,28.9973c.1641.006.3282,0,.4909,0a13.0724,13.0724,0,0,0,10.702-5.5556,1.0094,1.0094,0,0,0-.7833-1.5644A13.08,13.08,0,0,1,15.8892,4.38,1.0149,1.0149,0,0,0,14.98,3Z"
  })), children);
});
var Asleep16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Asleep16(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.2,2.3c-1,4.4,1.7,8.7,6.1,9.8c0.1,0,0.1,0,0.2,0c-1.1,1.2-2.7,1.8-4.3,1.8c-0.1,0-0.2,0-0.2,0C5.6,13.8,3,11,3.2,7.7\tC3.2,5.3,4.8,3.1,7.2,2.3 M8,1L8,1C4.1,1.6,1.5,5.3,2.1,9.1c0.6,3.3,3.4,5.8,6.8,5.9c0.1,0,0.2,0,0.3,0c2.3,0,4.4-1.1,5.8-3\tc0.2-0.2,0.1-0.6-0.1-0.7c-0.1-0.1-0.2-0.1-0.3-0.1c-3.9-0.3-6.7-3.8-6.4-7.6C8.3,3,8.4,2.4,8.6,1.8c0.1-0.3,0-0.6-0.3-0.7\tC8.1,1,8.1,1,8,1z"
  })), children);
});
var AsleepFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AsleepFilled32(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.98,3a1.0024,1.0024,0,0,0-.1746.0156A13.0959,13.0959,0,0,0,16.63,28.9973c.1641.006.3282,0,.4909,0a13.0724,13.0724,0,0,0,10.702-5.5556,1.0094,1.0094,0,0,0-.7833-1.5644A13.08,13.08,0,0,1,15.8892,4.38,1.0149,1.0149,0,0,0,14.98,3Z"
  })), children);
});
var AsleepFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AsleepFilled24(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.98,3a1.0024,1.0024,0,0,0-.1746.0156A13.0959,13.0959,0,0,0,16.63,28.9973c.1641.006.3282,0,.4909,0a13.0724,13.0724,0,0,0,10.702-5.5556,1.0094,1.0094,0,0,0-.7833-1.5644A13.08,13.08,0,0,1,15.8892,4.38,1.0149,1.0149,0,0,0,14.98,3Z"
  })), children);
});
var AsleepFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AsleepFilled20(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.98,3a1.0024,1.0024,0,0,0-.1746.0156A13.0959,13.0959,0,0,0,16.63,28.9973c.1641.006.3282,0,.4909,0a13.0724,13.0724,0,0,0,10.702-5.5556,1.0094,1.0094,0,0,0-.7833-1.5644A13.08,13.08,0,0,1,15.8892,4.38,1.0149,1.0149,0,0,0,14.98,3Z"
  })), children);
});
var AsleepFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AsleepFilled16(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.98,3a1.0024,1.0024,0,0,0-.1746.0156A13.0959,13.0959,0,0,0,16.63,28.9973c.1641.006.3282,0,.4909,0a13.0724,13.0724,0,0,0,10.702-5.5556,1.0094,1.0094,0,0,0-.7833-1.5644A13.08,13.08,0,0,1,15.8892,4.38,1.0149,1.0149,0,0,0,14.98,3Z"
  })), children);
});
var Assembly32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Assembly32(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,25.4l-8-4.7v-9.4l8-4.7l8,4.7v9.4L16,25.4z M10,19.6l6,3.5l6-3.5v-7.1l-6-3.5l-6,3.5V19.6z"
  })), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,8.2L17,2.3C16.7,2.1,16.4,2,16,2s-0.7,0.1-1,0.3L5,8.2c-0.6,0.4-1,1-1,1.7v12.2c0,0.7,0.4,1.4,1,1.7l10,5.9\tc0.3,0.2,0.7,0.3,1,0.3s0.7-0.1,1-0.3l10-5.9c0.6-0.4,1-1,1-1.7V9.9C28,9.2,27.6,8.5,27,8.2z M26,22.1L16,28L6,22.1V9.9L16,4l10,5.9\tV22.1z"
  })), children);
});
var Assembly24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Assembly24(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,25.4l-8-4.7v-9.4l8-4.7l8,4.7v9.4L16,25.4z M10,19.6l6,3.5l6-3.5v-7.1l-6-3.5l-6,3.5V19.6z"
  })), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,8.2L17,2.3C16.7,2.1,16.4,2,16,2s-0.7,0.1-1,0.3L5,8.2c-0.6,0.4-1,1-1,1.7v12.2c0,0.7,0.4,1.4,1,1.7l10,5.9\tc0.3,0.2,0.7,0.3,1,0.3s0.7-0.1,1-0.3l10-5.9c0.6-0.4,1-1,1-1.7V9.9C28,9.2,27.6,8.5,27,8.2z M26,22.1L16,28L6,22.1V9.9L16,4l10,5.9\tV22.1z"
  })), children);
});
var Assembly20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Assembly20(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,25.4l-8-4.7v-9.4l8-4.7l8,4.7v9.4L16,25.4z M10,19.6l6,3.5l6-3.5v-7.1l-6-3.5l-6,3.5V19.6z"
  })), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,8.2L17,2.3C16.7,2.1,16.4,2,16,2s-0.7,0.1-1,0.3L5,8.2c-0.6,0.4-1,1-1,1.7v12.2c0,0.7,0.4,1.4,1,1.7l10,5.9\tc0.3,0.2,0.7,0.3,1,0.3s0.7-0.1,1-0.3l10-5.9c0.6-0.4,1-1,1-1.7V9.9C28,9.2,27.6,8.5,27,8.2z M26,22.1L16,28L6,22.1V9.9L16,4l10,5.9\tV22.1z"
  })), children);
});
var Assembly16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Assembly16(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,25.4l-8-4.7v-9.4l8-4.7l8,4.7v9.4L16,25.4z M10,19.6l6,3.5l6-3.5v-7.1l-6-3.5l-6,3.5V19.6z"
  })), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,8.2L17,2.3C16.7,2.1,16.4,2,16,2s-0.7,0.1-1,0.3L5,8.2c-0.6,0.4-1,1-1,1.7v12.2c0,0.7,0.4,1.4,1,1.7l10,5.9\tc0.3,0.2,0.7,0.3,1,0.3s0.7-0.1,1-0.3l10-5.9c0.6-0.4,1-1,1-1.7V9.9C28,9.2,27.6,8.5,27,8.2z M26,22.1L16,28L6,22.1V9.9L16,4l10,5.9\tV22.1z"
  })), children);
});
var AssemblyCluster32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssemblyCluster32(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.3 4.9l-4.5-2.7C16.5 2.1 16.3 2 16 2s-.5.1-.7.2l-4.5 2.7C10.3 5.2 10 5.7 10 6.2v5.6c0 .5.3 1 .7 1.3l4.5 2.7c.2.1.5.2.7.2s.5-.1.7-.2l4.5-2.7c.4-.3.7-.7.7-1.3V6.2C22 5.7 21.7 5.2 21.3 4.9zM20 11.5l-4 2.4-4-2.4v-5l4-2.4 4 2.4V11.5zM29.3 18.9l-4.5-2.7C24.5 16.1 24.3 16 24 16s-.5.1-.7.2l-4.5 2.7c-.4.3-.7.7-.7 1.3v5.6c0 .5.3 1 .7 1.3l4.5 2.7c.2.1.5.2.7.2s.5-.1.7-.2l4.5-2.7c.4-.3.7-.7.7-1.3v-5.6C30 19.7 29.7 19.2 29.3 18.9zM28 25.5l-4 2.4-4-2.4v-5l4-2.4 4 2.4V25.5zM13.3 18.9l-4.5-2.7C8.5 16.1 8.3 16 8 16s-.5.1-.7.2l-4.5 2.7C2.3 19.2 2 19.7 2 20.2v5.6c0 .5.3 1 .7 1.3l4.5 2.7C7.5 29.9 7.7 30 8 30s.5-.1.7-.2l4.5-2.7c.4-.3.7-.7.7-1.3v-5.6C14 19.7 13.7 19.2 13.3 18.9zM12 25.5l-4 2.4-4-2.4v-5l4-2.4 4 2.4V25.5z"
  })), children);
});
var AssemblyCluster24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssemblyCluster24(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.3 4.9l-4.5-2.7C16.5 2.1 16.3 2 16 2s-.5.1-.7.2l-4.5 2.7C10.3 5.2 10 5.7 10 6.2v5.6c0 .5.3 1 .7 1.3l4.5 2.7c.2.1.5.2.7.2s.5-.1.7-.2l4.5-2.7c.4-.3.7-.7.7-1.3V6.2C22 5.7 21.7 5.2 21.3 4.9zM20 11.5l-4 2.4-4-2.4v-5l4-2.4 4 2.4V11.5zM29.3 18.9l-4.5-2.7C24.5 16.1 24.3 16 24 16s-.5.1-.7.2l-4.5 2.7c-.4.3-.7.7-.7 1.3v5.6c0 .5.3 1 .7 1.3l4.5 2.7c.2.1.5.2.7.2s.5-.1.7-.2l4.5-2.7c.4-.3.7-.7.7-1.3v-5.6C30 19.7 29.7 19.2 29.3 18.9zM28 25.5l-4 2.4-4-2.4v-5l4-2.4 4 2.4V25.5zM13.3 18.9l-4.5-2.7C8.5 16.1 8.3 16 8 16s-.5.1-.7.2l-4.5 2.7C2.3 19.2 2 19.7 2 20.2v5.6c0 .5.3 1 .7 1.3l4.5 2.7C7.5 29.9 7.7 30 8 30s.5-.1.7-.2l4.5-2.7c.4-.3.7-.7.7-1.3v-5.6C14 19.7 13.7 19.2 13.3 18.9zM12 25.5l-4 2.4-4-2.4v-5l4-2.4 4 2.4V25.5z"
  })), children);
});
var AssemblyCluster20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssemblyCluster20(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.3 4.9l-4.5-2.7C16.5 2.1 16.3 2 16 2s-.5.1-.7.2l-4.5 2.7C10.3 5.2 10 5.7 10 6.2v5.6c0 .5.3 1 .7 1.3l4.5 2.7c.2.1.5.2.7.2s.5-.1.7-.2l4.5-2.7c.4-.3.7-.7.7-1.3V6.2C22 5.7 21.7 5.2 21.3 4.9zM20 11.5l-4 2.4-4-2.4v-5l4-2.4 4 2.4V11.5zM29.3 18.9l-4.5-2.7C24.5 16.1 24.3 16 24 16s-.5.1-.7.2l-4.5 2.7c-.4.3-.7.7-.7 1.3v5.6c0 .5.3 1 .7 1.3l4.5 2.7c.2.1.5.2.7.2s.5-.1.7-.2l4.5-2.7c.4-.3.7-.7.7-1.3v-5.6C30 19.7 29.7 19.2 29.3 18.9zM28 25.5l-4 2.4-4-2.4v-5l4-2.4 4 2.4V25.5zM13.3 18.9l-4.5-2.7C8.5 16.1 8.3 16 8 16s-.5.1-.7.2l-4.5 2.7C2.3 19.2 2 19.7 2 20.2v5.6c0 .5.3 1 .7 1.3l4.5 2.7C7.5 29.9 7.7 30 8 30s.5-.1.7-.2l4.5-2.7c.4-.3.7-.7.7-1.3v-5.6C14 19.7 13.7 19.2 13.3 18.9zM12 25.5l-4 2.4-4-2.4v-5l4-2.4 4 2.4V25.5z"
  })), children);
});
var AssemblyCluster16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssemblyCluster16(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.3 4.9l-4.5-2.7C16.5 2.1 16.3 2 16 2s-.5.1-.7.2l-4.5 2.7C10.3 5.2 10 5.7 10 6.2v5.6c0 .5.3 1 .7 1.3l4.5 2.7c.2.1.5.2.7.2s.5-.1.7-.2l4.5-2.7c.4-.3.7-.7.7-1.3V6.2C22 5.7 21.7 5.2 21.3 4.9zM20 11.5l-4 2.4-4-2.4v-5l4-2.4 4 2.4V11.5zM29.3 18.9l-4.5-2.7C24.5 16.1 24.3 16 24 16s-.5.1-.7.2l-4.5 2.7c-.4.3-.7.7-.7 1.3v5.6c0 .5.3 1 .7 1.3l4.5 2.7c.2.1.5.2.7.2s.5-.1.7-.2l4.5-2.7c.4-.3.7-.7.7-1.3v-5.6C30 19.7 29.7 19.2 29.3 18.9zM28 25.5l-4 2.4-4-2.4v-5l4-2.4 4 2.4V25.5zM13.3 18.9l-4.5-2.7C8.5 16.1 8.3 16 8 16s-.5.1-.7.2l-4.5 2.7C2.3 19.2 2 19.7 2 20.2v5.6c0 .5.3 1 .7 1.3l4.5 2.7C7.5 29.9 7.7 30 8 30s.5-.1.7-.2l4.5-2.7c.4-.3.7-.7.7-1.3v-5.6C14 19.7 13.7 19.2 13.3 18.9zM12 25.5l-4 2.4-4-2.4v-5l4-2.4 4 2.4V25.5z"
  })), children);
});
var AssemblyReference32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssemblyReference32(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.7 5.1H12.2V7.1H8.7z",
    transform: "rotate(-30.582 10.48 6.101)"
  })), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 12H4V9.9c0-.7.4-1.4 1-1.7l1.5-.9 1 1.7L6 9.9V12zM4 14H6V18H4zM6.5 24.7L5 23.8c-.6-.4-1-1-1-1.7V20h2v2.1L7.5 23 6.5 24.7z"
  })), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.5 24.1H11.5V27.6H9.5z",
    transform: "rotate(-59.421 10.48 25.9)"
  })), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.5,27.1L16,28l-1.5-0.9l-1,1.7l1.5,0.9c0.3,0.2,0.7,0.3,1,0.3c0.4,0,0.7-0.1,1-0.3l1.5-0.9L17.5,27.1z"
  })), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.8 24.9H23.3V26.9H19.8z",
    transform: "rotate(-30.582 21.502 25.912)"
  })), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.2 24.9l-1-1.7 1.8-1V20h2v2.1c0 .7-.4 1.4-1 1.7L25.2 24.9zM26 14H28V18H26zM28 12h-2V9.9l-1.8-1 1-1.7 1.8 1c.6.4 1 1 1 1.7V12z"
  })), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.5 4.3H22.5V7.8H20.5z",
    transform: "rotate(-59.421 21.501 6.089)"
  })), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.5,4.9L16,4l-1.5,0.9l-1-1.7L15,2.3C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l1.5,0.9L17.5,4.9z"
  })), children);
});
var AssemblyReference24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssemblyReference24(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.7 5.1H12.2V7.1H8.7z",
    transform: "rotate(-30.582 10.48 6.101)"
  })), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 12H4V9.9c0-.7.4-1.4 1-1.7l1.5-.9 1 1.7L6 9.9V12zM4 14H6V18H4zM6.5 24.7L5 23.8c-.6-.4-1-1-1-1.7V20h2v2.1L7.5 23 6.5 24.7z"
  })), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.5 24.1H11.5V27.6H9.5z",
    transform: "rotate(-59.421 10.48 25.9)"
  })), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.5,27.1L16,28l-1.5-0.9l-1,1.7l1.5,0.9c0.3,0.2,0.7,0.3,1,0.3c0.4,0,0.7-0.1,1-0.3l1.5-0.9L17.5,27.1z"
  })), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.8 24.9H23.3V26.9H19.8z",
    transform: "rotate(-30.582 21.502 25.912)"
  })), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.2 24.9l-1-1.7 1.8-1V20h2v2.1c0 .7-.4 1.4-1 1.7L25.2 24.9zM26 14H28V18H26zM28 12h-2V9.9l-1.8-1 1-1.7 1.8 1c.6.4 1 1 1 1.7V12z"
  })), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.5 4.3H22.5V7.8H20.5z",
    transform: "rotate(-59.421 21.501 6.089)"
  })), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.5,4.9L16,4l-1.5,0.9l-1-1.7L15,2.3C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l1.5,0.9L17.5,4.9z"
  })), children);
});
var AssemblyReference20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssemblyReference20(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.7 5.1H12.2V7.1H8.7z",
    transform: "rotate(-30.582 10.48 6.101)"
  })), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 12H4V9.9c0-.7.4-1.4 1-1.7l1.5-.9 1 1.7L6 9.9V12zM4 14H6V18H4zM6.5 24.7L5 23.8c-.6-.4-1-1-1-1.7V20h2v2.1L7.5 23 6.5 24.7z"
  })), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.5 24.1H11.5V27.6H9.5z",
    transform: "rotate(-59.421 10.48 25.9)"
  })), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.5,27.1L16,28l-1.5-0.9l-1,1.7l1.5,0.9c0.3,0.2,0.7,0.3,1,0.3c0.4,0,0.7-0.1,1-0.3l1.5-0.9L17.5,27.1z"
  })), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.8 24.9H23.3V26.9H19.8z",
    transform: "rotate(-30.582 21.502 25.912)"
  })), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.2 24.9l-1-1.7 1.8-1V20h2v2.1c0 .7-.4 1.4-1 1.7L25.2 24.9zM26 14H28V18H26zM28 12h-2V9.9l-1.8-1 1-1.7 1.8 1c.6.4 1 1 1 1.7V12z"
  })), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.5 4.3H22.5V7.8H20.5z",
    transform: "rotate(-59.421 21.501 6.089)"
  })), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.5,4.9L16,4l-1.5,0.9l-1-1.7L15,2.3C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l1.5,0.9L17.5,4.9z"
  })), children);
});
var AssemblyReference16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssemblyReference16(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.7 5.1H12.2V7.1H8.7z",
    transform: "rotate(-30.582 10.48 6.101)"
  })), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 12H4V9.9c0-.7.4-1.4 1-1.7l1.5-.9 1 1.7L6 9.9V12zM4 14H6V18H4zM6.5 24.7L5 23.8c-.6-.4-1-1-1-1.7V20h2v2.1L7.5 23 6.5 24.7z"
  })), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.5 24.1H11.5V27.6H9.5z",
    transform: "rotate(-59.421 10.48 25.9)"
  })), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.5,27.1L16,28l-1.5-0.9l-1,1.7l1.5,0.9c0.3,0.2,0.7,0.3,1,0.3c0.4,0,0.7-0.1,1-0.3l1.5-0.9L17.5,27.1z"
  })), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.8 24.9H23.3V26.9H19.8z",
    transform: "rotate(-30.582 21.502 25.912)"
  })), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.2 24.9l-1-1.7 1.8-1V20h2v2.1c0 .7-.4 1.4-1 1.7L25.2 24.9zM26 14H28V18H26zM28 12h-2V9.9l-1.8-1 1-1.7 1.8 1c.6.4 1 1 1 1.7V12z"
  })), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.5 4.3H22.5V7.8H20.5z",
    transform: "rotate(-59.421 21.501 6.089)"
  })), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.5,4.9L16,4l-1.5,0.9l-1-1.7L15,2.3C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l1.5,0.9L17.5,4.9z"
  })), children);
});
var Asset32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Asset32(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,24a4,4,0,1,1,4-4A4.0042,4.0042,0,0,1,12,24Zm0-6a2,2,0,1,0,2,2A2.0023,2.0023,0,0,0,12,18Z"
  })), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6a4.0042,4.0042,0,0,0-4-4,3.949,3.949,0,0,0-1.8537.4768L7.7571,10.9579A9.9921,9.9921,0,1,0,21.066,24.1929l8.49-16.3994A3.9491,3.9491,0,0,0,30,6ZM26,4a2,2,0,1,1-2,2A2.0023,2.0023,0,0,1,26,4ZM22.0194,5.8083C22.0163,5.8732,22,5.9343,22,6a4.0042,4.0042,0,0,0,4,4c.0645,0,.1245-.016.1882-.019l-4.3318,8.3617a10.0168,10.0168,0,0,0-8.2158-8.1962ZM12,28a8,8,0,1,1,8-8A8.0092,8.0092,0,0,1,12,28Z"
  })), children);
});
var Asset24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Asset24(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,24a4,4,0,1,1,4-4A4.0042,4.0042,0,0,1,12,24Zm0-6a2,2,0,1,0,2,2A2.0023,2.0023,0,0,0,12,18Z"
  })), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6a4.0042,4.0042,0,0,0-4-4,3.949,3.949,0,0,0-1.8537.4768L7.7571,10.9579A9.9921,9.9921,0,1,0,21.066,24.1929l8.49-16.3994A3.9491,3.9491,0,0,0,30,6ZM26,4a2,2,0,1,1-2,2A2.0023,2.0023,0,0,1,26,4ZM22.0194,5.8083C22.0163,5.8732,22,5.9343,22,6a4.0042,4.0042,0,0,0,4,4c.0645,0,.1245-.016.1882-.019l-4.3318,8.3617a10.0168,10.0168,0,0,0-8.2158-8.1962ZM12,28a8,8,0,1,1,8-8A8.0092,8.0092,0,0,1,12,28Z"
  })), children);
});
var Asset20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Asset20(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,24a4,4,0,1,1,4-4A4.0042,4.0042,0,0,1,12,24Zm0-6a2,2,0,1,0,2,2A2.0023,2.0023,0,0,0,12,18Z"
  })), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6a4.0042,4.0042,0,0,0-4-4,3.949,3.949,0,0,0-1.8537.4768L7.7571,10.9579A9.9921,9.9921,0,1,0,21.066,24.1929l8.49-16.3994A3.9491,3.9491,0,0,0,30,6ZM26,4a2,2,0,1,1-2,2A2.0023,2.0023,0,0,1,26,4ZM22.0194,5.8083C22.0163,5.8732,22,5.9343,22,6a4.0042,4.0042,0,0,0,4,4c.0645,0,.1245-.016.1882-.019l-4.3318,8.3617a10.0168,10.0168,0,0,0-8.2158-8.1962ZM12,28a8,8,0,1,1,8-8A8.0092,8.0092,0,0,1,12,28Z"
  })), children);
});
var Asset16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Asset16(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,24a4,4,0,1,1,4-4A4.0042,4.0042,0,0,1,12,24Zm0-6a2,2,0,1,0,2,2A2.0023,2.0023,0,0,0,12,18Z"
  })), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6a4.0042,4.0042,0,0,0-4-4,3.949,3.949,0,0,0-1.8537.4768L7.7571,10.9579A9.9921,9.9921,0,1,0,21.066,24.1929l8.49-16.3994A3.9491,3.9491,0,0,0,30,6ZM26,4a2,2,0,1,1-2,2A2.0023,2.0023,0,0,1,26,4ZM22.0194,5.8083C22.0163,5.8732,22,5.9343,22,6a4.0042,4.0042,0,0,0,4,4c.0645,0,.1245-.016.1882-.019l-4.3318,8.3617a10.0168,10.0168,0,0,0-8.2158-8.1962ZM12,28a8,8,0,1,1,8-8A8.0092,8.0092,0,0,1,12,28Z"
  })), children);
});
var AssetConfirm32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssetConfirm32(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 27.18L18.41 24.59 17 26 21 30 28 23 26.59 21.59 21 27.18zM12 24a4 4 0 114-4A4.0042 4.0042 0 0112 24zm0-6a2 2 0 102 2A2.0023 2.0023 0 0012 18z"
  })), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2a3.86,3.86,0,0,0-1.85.48L7.76,10.96A9.99,9.99,0,0,0,12,30a9.3445,9.3445,0,0,0,2-.21V27.75A8.2289,8.2289,0,0,1,12,28a8,8,0,1,1,8-8,8.2656,8.2656,0,0,1-.06,1h2.78L29.56,7.79A3.9727,3.9727,0,0,0,26,2ZM21.86,18.34a10.0187,10.0187,0,0,0-8.22-8.19l8.38-4.34c0,.06-.02.12-.02.19a3.9989,3.9989,0,0,0,4,4c.06,0,.12-.02.19-.02ZM26,8a2,2,0,1,1,2-2A2.0058,2.0058,0,0,1,26,8Z"
  })), children);
});
var AssetConfirm24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssetConfirm24(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 27.18L18.41 24.59 17 26 21 30 28 23 26.59 21.59 21 27.18zM12 24a4 4 0 114-4A4.0042 4.0042 0 0112 24zm0-6a2 2 0 102 2A2.0023 2.0023 0 0012 18z"
  })), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2a3.86,3.86,0,0,0-1.85.48L7.76,10.96A9.99,9.99,0,0,0,12,30a9.3445,9.3445,0,0,0,2-.21V27.75A8.2289,8.2289,0,0,1,12,28a8,8,0,1,1,8-8,8.2656,8.2656,0,0,1-.06,1h2.78L29.56,7.79A3.9727,3.9727,0,0,0,26,2ZM21.86,18.34a10.0187,10.0187,0,0,0-8.22-8.19l8.38-4.34c0,.06-.02.12-.02.19a3.9989,3.9989,0,0,0,4,4c.06,0,.12-.02.19-.02ZM26,8a2,2,0,1,1,2-2A2.0058,2.0058,0,0,1,26,8Z"
  })), children);
});
var AssetConfirm20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssetConfirm20(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 27.18L18.41 24.59 17 26 21 30 28 23 26.59 21.59 21 27.18zM12 24a4 4 0 114-4A4.0042 4.0042 0 0112 24zm0-6a2 2 0 102 2A2.0023 2.0023 0 0012 18z"
  })), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2a3.86,3.86,0,0,0-1.85.48L7.76,10.96A9.99,9.99,0,0,0,12,30a9.3445,9.3445,0,0,0,2-.21V27.75A8.2289,8.2289,0,0,1,12,28a8,8,0,1,1,8-8,8.2656,8.2656,0,0,1-.06,1h2.78L29.56,7.79A3.9727,3.9727,0,0,0,26,2ZM21.86,18.34a10.0187,10.0187,0,0,0-8.22-8.19l8.38-4.34c0,.06-.02.12-.02.19a3.9989,3.9989,0,0,0,4,4c.06,0,.12-.02.19-.02ZM26,8a2,2,0,1,1,2-2A2.0058,2.0058,0,0,1,26,8Z"
  })), children);
});
var AssetConfirm16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssetConfirm16(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 27.18L18.41 24.59 17 26 21 30 28 23 26.59 21.59 21 27.18zM12 24a4 4 0 114-4A4.0042 4.0042 0 0112 24zm0-6a2 2 0 102 2A2.0023 2.0023 0 0012 18z"
  })), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2a3.86,3.86,0,0,0-1.85.48L7.76,10.96A9.99,9.99,0,0,0,12,30a9.3445,9.3445,0,0,0,2-.21V27.75A8.2289,8.2289,0,0,1,12,28a8,8,0,1,1,8-8,8.2656,8.2656,0,0,1-.06,1h2.78L29.56,7.79A3.9727,3.9727,0,0,0,26,2ZM21.86,18.34a10.0187,10.0187,0,0,0-8.22-8.19l8.38-4.34c0,.06-.02.12-.02.19a3.9989,3.9989,0,0,0,4,4c.06,0,.12-.02.19-.02ZM26,8a2,2,0,1,1,2-2A2.0058,2.0058,0,0,1,26,8Z"
  })), children);
});
var AssetDigitalTwin32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssetDigitalTwin32(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "7",
    r: "2"
  })), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,23a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,12,23Zm0-4a1,1,0,1,0,1,1A1.001,1.001,0,0,0,12,19Z"
  })), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "12",
    cy: "14",
    r: "1"
  })), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17.909",
    cy: "5.705",
    r: "1"
  })), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9.787",
    cy: "9.907",
    r: "1"
  })), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "12.495",
    cy: "8.506",
    r: "1"
  })), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15.201",
    cy: "7.105",
    r: "1"
  })), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4.696",
    cy: "13.187",
    r: "1"
  })), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "2.133",
    cy: "21.631",
    r: "1"
  })), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3.079",
    cy: "24.516",
    r: "1"
  })), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4.848",
    cy: "26.982",
    r: "1"
  })), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7.272",
    cy: "28.81",
    r: "1"
  })), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "2.098",
    cy: "18.596",
    r: "1"
  })), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "2.979",
    cy: "15.691",
    r: "1"
  })), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7.081",
    cy: "11.308",
    r: "1"
  })), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20.616",
    cy: "4.304",
    r: "1"
  })), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23.323",
    cy: "2.903",
    r: "1"
  })), _circle21 || (_circle21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28.988",
    cy: "8.89",
    r: "1"
  })), _circle22 || (_circle22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "27.587",
    cy: "11.596",
    r: "1"
  })), _circle23 || (_circle23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26.186",
    cy: "14.303",
    r: "1"
  })), _circle24 || (_circle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24.784",
    cy: "17.01",
    r: "1"
  })), _circle25 || (_circle25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23.383",
    cy: "19.717",
    r: "1"
  })), _circle26 || (_circle26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21.982",
    cy: "22.424",
    r: "1"
  })), _circle27 || (_circle27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18.637",
    cy: "27.464",
    r: "1"
  })), _circle28 || (_circle28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16.092",
    cy: "29.122",
    r: "1"
  })), _circle29 || (_circle29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13.166",
    cy: "29.932",
    r: "1"
  })), _circle30 || (_circle30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10.133",
    cy: "29.825",
    r: "1"
  })), _circle31 || (_circle31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20.572",
    cy: "25.125",
    r: "1"
  })), _circle32 || (_circle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28.893",
    cy: "3.24",
    r: "1"
  })), _circle33 || (_circle33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26.188",
    cy: "2.004",
    r: "1"
  })), _circle34 || (_circle34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "12",
    cy: "26",
    r: "1"
  })), _circle35 || (_circle35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "20",
    r: "1"
  })), _circle36 || (_circle36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18",
    cy: "20",
    r: "1"
  })), _circle37 || (_circle37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6.804",
    cy: "17",
    r: "1"
  })), _circle38 || (_circle38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17.196",
    cy: "23",
    r: "1"
  })), _circle39 || (_circle39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "25.196",
    r: "1"
  })), _circle40 || (_circle40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "14.804",
    r: "1"
  })), _circle41 || (_circle41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "14.804",
    r: "1"
  })), _circle42 || (_circle42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "25.196",
    r: "1"
  })), _circle43 || (_circle43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6.804",
    cy: "23",
    r: "1"
  })), _circle44 || (_circle44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17.196",
    cy: "17",
    r: "1"
  })), _circle45 || (_circle45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "30",
    cy: "6.026",
    r: "1"
  })), children);
});
var AssetDigitalTwin24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssetDigitalTwin24(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle46 || (_circle46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "7",
    r: "2"
  })), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,23a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,12,23Zm0-4a1,1,0,1,0,1,1A1.001,1.001,0,0,0,12,19Z"
  })), _circle47 || (_circle47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "12",
    cy: "14",
    r: "1"
  })), _circle48 || (_circle48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17.909",
    cy: "5.705",
    r: "1"
  })), _circle49 || (_circle49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9.787",
    cy: "9.907",
    r: "1"
  })), _circle50 || (_circle50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "12.495",
    cy: "8.506",
    r: "1"
  })), _circle51 || (_circle51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15.201",
    cy: "7.105",
    r: "1"
  })), _circle52 || (_circle52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4.696",
    cy: "13.187",
    r: "1"
  })), _circle53 || (_circle53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "2.133",
    cy: "21.631",
    r: "1"
  })), _circle54 || (_circle54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3.079",
    cy: "24.516",
    r: "1"
  })), _circle55 || (_circle55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4.848",
    cy: "26.982",
    r: "1"
  })), _circle56 || (_circle56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7.272",
    cy: "28.81",
    r: "1"
  })), _circle57 || (_circle57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "2.098",
    cy: "18.596",
    r: "1"
  })), _circle58 || (_circle58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "2.979",
    cy: "15.691",
    r: "1"
  })), _circle59 || (_circle59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7.081",
    cy: "11.308",
    r: "1"
  })), _circle60 || (_circle60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20.616",
    cy: "4.304",
    r: "1"
  })), _circle61 || (_circle61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23.323",
    cy: "2.903",
    r: "1"
  })), _circle62 || (_circle62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28.988",
    cy: "8.89",
    r: "1"
  })), _circle63 || (_circle63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "27.587",
    cy: "11.596",
    r: "1"
  })), _circle64 || (_circle64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26.186",
    cy: "14.303",
    r: "1"
  })), _circle65 || (_circle65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24.784",
    cy: "17.01",
    r: "1"
  })), _circle66 || (_circle66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23.383",
    cy: "19.717",
    r: "1"
  })), _circle67 || (_circle67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21.982",
    cy: "22.424",
    r: "1"
  })), _circle68 || (_circle68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18.637",
    cy: "27.464",
    r: "1"
  })), _circle69 || (_circle69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16.092",
    cy: "29.122",
    r: "1"
  })), _circle70 || (_circle70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13.166",
    cy: "29.932",
    r: "1"
  })), _circle71 || (_circle71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10.133",
    cy: "29.825",
    r: "1"
  })), _circle72 || (_circle72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20.572",
    cy: "25.125",
    r: "1"
  })), _circle73 || (_circle73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28.893",
    cy: "3.24",
    r: "1"
  })), _circle74 || (_circle74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26.188",
    cy: "2.004",
    r: "1"
  })), _circle75 || (_circle75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "12",
    cy: "26",
    r: "1"
  })), _circle76 || (_circle76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "20",
    r: "1"
  })), _circle77 || (_circle77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18",
    cy: "20",
    r: "1"
  })), _circle78 || (_circle78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6.804",
    cy: "17",
    r: "1"
  })), _circle79 || (_circle79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17.196",
    cy: "23",
    r: "1"
  })), _circle80 || (_circle80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "25.196",
    r: "1"
  })), _circle81 || (_circle81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "14.804",
    r: "1"
  })), _circle82 || (_circle82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "14.804",
    r: "1"
  })), _circle83 || (_circle83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "25.196",
    r: "1"
  })), _circle84 || (_circle84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6.804",
    cy: "23",
    r: "1"
  })), _circle85 || (_circle85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17.196",
    cy: "17",
    r: "1"
  })), _circle86 || (_circle86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "30",
    cy: "6.026",
    r: "1"
  })), children);
});
var AssetDigitalTwin20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssetDigitalTwin20(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle87 || (_circle87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "7",
    r: "2"
  })), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,23a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,12,23Zm0-4a1,1,0,1,0,1,1A1.001,1.001,0,0,0,12,19Z"
  })), _circle88 || (_circle88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "12",
    cy: "14",
    r: "1"
  })), _circle89 || (_circle89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17.909",
    cy: "5.705",
    r: "1"
  })), _circle90 || (_circle90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9.787",
    cy: "9.907",
    r: "1"
  })), _circle91 || (_circle91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "12.495",
    cy: "8.506",
    r: "1"
  })), _circle92 || (_circle92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15.201",
    cy: "7.105",
    r: "1"
  })), _circle93 || (_circle93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4.696",
    cy: "13.187",
    r: "1"
  })), _circle94 || (_circle94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "2.133",
    cy: "21.631",
    r: "1"
  })), _circle95 || (_circle95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3.079",
    cy: "24.516",
    r: "1"
  })), _circle96 || (_circle96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4.848",
    cy: "26.982",
    r: "1"
  })), _circle97 || (_circle97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7.272",
    cy: "28.81",
    r: "1"
  })), _circle98 || (_circle98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "2.098",
    cy: "18.596",
    r: "1"
  })), _circle99 || (_circle99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "2.979",
    cy: "15.691",
    r: "1"
  })), _circle100 || (_circle100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7.081",
    cy: "11.308",
    r: "1"
  })), _circle101 || (_circle101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20.616",
    cy: "4.304",
    r: "1"
  })), _circle102 || (_circle102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23.323",
    cy: "2.903",
    r: "1"
  })), _circle103 || (_circle103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28.988",
    cy: "8.89",
    r: "1"
  })), _circle104 || (_circle104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "27.587",
    cy: "11.596",
    r: "1"
  })), _circle105 || (_circle105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26.186",
    cy: "14.303",
    r: "1"
  })), _circle106 || (_circle106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24.784",
    cy: "17.01",
    r: "1"
  })), _circle107 || (_circle107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23.383",
    cy: "19.717",
    r: "1"
  })), _circle108 || (_circle108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21.982",
    cy: "22.424",
    r: "1"
  })), _circle109 || (_circle109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18.637",
    cy: "27.464",
    r: "1"
  })), _circle110 || (_circle110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16.092",
    cy: "29.122",
    r: "1"
  })), _circle111 || (_circle111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13.166",
    cy: "29.932",
    r: "1"
  })), _circle112 || (_circle112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10.133",
    cy: "29.825",
    r: "1"
  })), _circle113 || (_circle113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20.572",
    cy: "25.125",
    r: "1"
  })), _circle114 || (_circle114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28.893",
    cy: "3.24",
    r: "1"
  })), _circle115 || (_circle115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26.188",
    cy: "2.004",
    r: "1"
  })), _circle116 || (_circle116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "12",
    cy: "26",
    r: "1"
  })), _circle117 || (_circle117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "20",
    r: "1"
  })), _circle118 || (_circle118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18",
    cy: "20",
    r: "1"
  })), _circle119 || (_circle119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6.804",
    cy: "17",
    r: "1"
  })), _circle120 || (_circle120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17.196",
    cy: "23",
    r: "1"
  })), _circle121 || (_circle121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "25.196",
    r: "1"
  })), _circle122 || (_circle122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "14.804",
    r: "1"
  })), _circle123 || (_circle123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "14.804",
    r: "1"
  })), _circle124 || (_circle124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "25.196",
    r: "1"
  })), _circle125 || (_circle125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6.804",
    cy: "23",
    r: "1"
  })), _circle126 || (_circle126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17.196",
    cy: "17",
    r: "1"
  })), _circle127 || (_circle127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "30",
    cy: "6.026",
    r: "1"
  })), children);
});
var AssetDigitalTwin16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssetDigitalTwin16(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle128 || (_circle128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "7",
    r: "2"
  })), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,23a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,12,23Zm0-4a1,1,0,1,0,1,1A1.001,1.001,0,0,0,12,19Z"
  })), _circle129 || (_circle129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "12",
    cy: "14",
    r: "1"
  })), _circle130 || (_circle130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17.909",
    cy: "5.705",
    r: "1"
  })), _circle131 || (_circle131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9.787",
    cy: "9.907",
    r: "1"
  })), _circle132 || (_circle132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "12.495",
    cy: "8.506",
    r: "1"
  })), _circle133 || (_circle133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15.201",
    cy: "7.105",
    r: "1"
  })), _circle134 || (_circle134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4.696",
    cy: "13.187",
    r: "1"
  })), _circle135 || (_circle135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "2.133",
    cy: "21.631",
    r: "1"
  })), _circle136 || (_circle136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3.079",
    cy: "24.516",
    r: "1"
  })), _circle137 || (_circle137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4.848",
    cy: "26.982",
    r: "1"
  })), _circle138 || (_circle138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7.272",
    cy: "28.81",
    r: "1"
  })), _circle139 || (_circle139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "2.098",
    cy: "18.596",
    r: "1"
  })), _circle140 || (_circle140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "2.979",
    cy: "15.691",
    r: "1"
  })), _circle141 || (_circle141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7.081",
    cy: "11.308",
    r: "1"
  })), _circle142 || (_circle142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20.616",
    cy: "4.304",
    r: "1"
  })), _circle143 || (_circle143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23.323",
    cy: "2.903",
    r: "1"
  })), _circle144 || (_circle144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28.988",
    cy: "8.89",
    r: "1"
  })), _circle145 || (_circle145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "27.587",
    cy: "11.596",
    r: "1"
  })), _circle146 || (_circle146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26.186",
    cy: "14.303",
    r: "1"
  })), _circle147 || (_circle147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24.784",
    cy: "17.01",
    r: "1"
  })), _circle148 || (_circle148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23.383",
    cy: "19.717",
    r: "1"
  })), _circle149 || (_circle149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21.982",
    cy: "22.424",
    r: "1"
  })), _circle150 || (_circle150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18.637",
    cy: "27.464",
    r: "1"
  })), _circle151 || (_circle151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16.092",
    cy: "29.122",
    r: "1"
  })), _circle152 || (_circle152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13.166",
    cy: "29.932",
    r: "1"
  })), _circle153 || (_circle153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10.133",
    cy: "29.825",
    r: "1"
  })), _circle154 || (_circle154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20.572",
    cy: "25.125",
    r: "1"
  })), _circle155 || (_circle155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28.893",
    cy: "3.24",
    r: "1"
  })), _circle156 || (_circle156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26.188",
    cy: "2.004",
    r: "1"
  })), _circle157 || (_circle157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "12",
    cy: "26",
    r: "1"
  })), _circle158 || (_circle158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "20",
    r: "1"
  })), _circle159 || (_circle159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18",
    cy: "20",
    r: "1"
  })), _circle160 || (_circle160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6.804",
    cy: "17",
    r: "1"
  })), _circle161 || (_circle161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17.196",
    cy: "23",
    r: "1"
  })), _circle162 || (_circle162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "25.196",
    r: "1"
  })), _circle163 || (_circle163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "14.804",
    r: "1"
  })), _circle164 || (_circle164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "14.804",
    r: "1"
  })), _circle165 || (_circle165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "25.196",
    r: "1"
  })), _circle166 || (_circle166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6.804",
    cy: "23",
    r: "1"
  })), _circle167 || (_circle167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17.196",
    cy: "17",
    r: "1"
  })), _circle168 || (_circle168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "30",
    cy: "6.026",
    r: "1"
  })), children);
});
var AssetView32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssetView32(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle169 || (_circle169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "24",
    r: "2"
  })), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769 23.4785A8.64 8.64 0 0022 18a8.64 8.64 0 00-7.7769 5.4785L14 24l.2231.5215A8.64 8.64 0 0022 30a8.64 8.64 0 007.7769-5.4785L30 24zM22 28a4 4 0 114-4A4.0045 4.0045 0 0122 28zM12 24a4 4 0 112.981-6.667l-1.49 1.334A2 2 0 1012 22z"
  })), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2a3.86,3.86,0,0,0-1.85.48L7.76,10.96A9.99,9.99,0,0,0,12,30V28a8,8,0,1,1,5.63-13.68l1.4-1.4a10.0059,10.0059,0,0,0-5.39-2.77l8.38-4.34c0,.06-.02.12-.02.19a3.9989,3.9989,0,0,0,4,4c.06,0,.12-.02.19-.02L23.07,16h2.24l4.25-8.21A3.9727,3.9727,0,0,0,26,2Zm0,6a2,2,0,1,1,2-2A2.0058,2.0058,0,0,1,26,8Z"
  })), children);
});
var AssetView24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssetView24(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle170 || (_circle170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "24",
    r: "2"
  })), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769 23.4785A8.64 8.64 0 0022 18a8.64 8.64 0 00-7.7769 5.4785L14 24l.2231.5215A8.64 8.64 0 0022 30a8.64 8.64 0 007.7769-5.4785L30 24zM22 28a4 4 0 114-4A4.0045 4.0045 0 0122 28zM12 24a4 4 0 112.981-6.667l-1.49 1.334A2 2 0 1012 22z"
  })), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2a3.86,3.86,0,0,0-1.85.48L7.76,10.96A9.99,9.99,0,0,0,12,30V28a8,8,0,1,1,5.63-13.68l1.4-1.4a10.0059,10.0059,0,0,0-5.39-2.77l8.38-4.34c0,.06-.02.12-.02.19a3.9989,3.9989,0,0,0,4,4c.06,0,.12-.02.19-.02L23.07,16h2.24l4.25-8.21A3.9727,3.9727,0,0,0,26,2Zm0,6a2,2,0,1,1,2-2A2.0058,2.0058,0,0,1,26,8Z"
  })), children);
});
var AssetView20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssetView20(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle171 || (_circle171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "24",
    r: "2"
  })), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769 23.4785A8.64 8.64 0 0022 18a8.64 8.64 0 00-7.7769 5.4785L14 24l.2231.5215A8.64 8.64 0 0022 30a8.64 8.64 0 007.7769-5.4785L30 24zM22 28a4 4 0 114-4A4.0045 4.0045 0 0122 28zM12 24a4 4 0 112.981-6.667l-1.49 1.334A2 2 0 1012 22z"
  })), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2a3.86,3.86,0,0,0-1.85.48L7.76,10.96A9.99,9.99,0,0,0,12,30V28a8,8,0,1,1,5.63-13.68l1.4-1.4a10.0059,10.0059,0,0,0-5.39-2.77l8.38-4.34c0,.06-.02.12-.02.19a3.9989,3.9989,0,0,0,4,4c.06,0,.12-.02.19-.02L23.07,16h2.24l4.25-8.21A3.9727,3.9727,0,0,0,26,2Zm0,6a2,2,0,1,1,2-2A2.0058,2.0058,0,0,1,26,8Z"
  })), children);
});
var AssetView16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AssetView16(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle172 || (_circle172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "24",
    r: "2"
  })), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769 23.4785A8.64 8.64 0 0022 18a8.64 8.64 0 00-7.7769 5.4785L14 24l.2231.5215A8.64 8.64 0 0022 30a8.64 8.64 0 007.7769-5.4785L30 24zM22 28a4 4 0 114-4A4.0045 4.0045 0 0122 28zM12 24a4 4 0 112.981-6.667l-1.49 1.334A2 2 0 1012 22z"
  })), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2a3.86,3.86,0,0,0-1.85.48L7.76,10.96A9.99,9.99,0,0,0,12,30V28a8,8,0,1,1,5.63-13.68l1.4-1.4a10.0059,10.0059,0,0,0-5.39-2.77l8.38-4.34c0,.06-.02.12-.02.19a3.9989,3.9989,0,0,0,4,4c.06,0,.12-.02.19-.02L23.07,16h2.24l4.25-8.21A3.9727,3.9727,0,0,0,26,2Zm0,6a2,2,0,1,1,2-2A2.0058,2.0058,0,0,1,26,8Z"
  })), children);
});
var Asterisk32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Asterisk32(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.316 13.949L27.684 12.051 17 15.612 17 4 15 4 15 15.612 4.316 12.051 3.684 13.949 14.368 17.51 7.2 27.066 8.8 28.267 16 18.667 23.2 28.267 24.8 27.066 17.632 17.51 28.316 13.949z"
  })), children);
});
var Asterisk24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Asterisk24(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.316 13.949L27.684 12.051 17 15.612 17 4 15 4 15 15.612 4.316 12.051 3.684 13.949 14.368 17.51 7.2 27.066 8.8 28.267 16 18.667 23.2 28.267 24.8 27.066 17.632 17.51 28.316 13.949z"
  })), children);
});
var Asterisk20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Asterisk20(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.316 13.949L27.684 12.051 17 15.612 17 4 15 4 15 15.612 4.316 12.051 3.684 13.949 14.368 17.51 7.2 27.066 8.8 28.267 16 18.667 23.2 28.267 24.8 27.066 17.632 17.51 28.316 13.949z"
  })), children);
});
var Asterisk16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Asterisk16(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.316 13.949L27.684 12.051 17 15.612 17 4 15 4 15 15.612 4.316 12.051 3.684 13.949 14.368 17.51 7.2 27.066 8.8 28.267 16 18.667 23.2 28.267 24.8 27.066 17.632 17.51 28.316 13.949z"
  })), children);
});
var At32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function At32(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,3A12.92,12.92,0,0,0,3,16v1A13,13,0,0,0,16,30h7V28H16A11,11,0,0,1,5,17V16A10.94,10.94,0,0,1,16,5,10.64,10.64,0,0,1,27,16c0,3.59-1.4,5-3.66,5C21.76,21,21,19.71,21,18V10H19v1.94A3.84,3.84,0,0,0,15.5,10,5.48,5.48,0,0,0,10,15.44v2.12A5.48,5.48,0,0,0,15.5,23a4.28,4.28,0,0,0,4-2.46A4.35,4.35,0,0,0,23.41,23C26.48,23,29,21,29,16A12.72,12.72,0,0,0,16,3Zm3,14.56a3.5,3.5,0,0,1-7,0V15.44a3.5,3.5,0,0,1,7,0Z"
  })), children);
});
var At24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function At24(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,3A12.92,12.92,0,0,0,3,16v1A13,13,0,0,0,16,30h7V28H16A11,11,0,0,1,5,17V16A10.94,10.94,0,0,1,16,5,10.64,10.64,0,0,1,27,16c0,3.59-1.4,5-3.66,5C21.76,21,21,19.71,21,18V10H19v1.94A3.84,3.84,0,0,0,15.5,10,5.48,5.48,0,0,0,10,15.44v2.12A5.48,5.48,0,0,0,15.5,23a4.28,4.28,0,0,0,4-2.46A4.35,4.35,0,0,0,23.41,23C26.48,23,29,21,29,16A12.72,12.72,0,0,0,16,3Zm3,14.56a3.5,3.5,0,0,1-7,0V15.44a3.5,3.5,0,0,1,7,0Z"
  })), children);
});
var At20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function At20(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,3A12.92,12.92,0,0,0,3,16v1A13,13,0,0,0,16,30h7V28H16A11,11,0,0,1,5,17V16A10.94,10.94,0,0,1,16,5,10.64,10.64,0,0,1,27,16c0,3.59-1.4,5-3.66,5C21.76,21,21,19.71,21,18V10H19v1.94A3.84,3.84,0,0,0,15.5,10,5.48,5.48,0,0,0,10,15.44v2.12A5.48,5.48,0,0,0,15.5,23a4.28,4.28,0,0,0,4-2.46A4.35,4.35,0,0,0,23.41,23C26.48,23,29,21,29,16A12.72,12.72,0,0,0,16,3Zm3,14.56a3.5,3.5,0,0,1-7,0V15.44a3.5,3.5,0,0,1,7,0Z"
  })), children);
});
var At16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function At16(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,3A12.92,12.92,0,0,0,3,16v1A13,13,0,0,0,16,30h7V28H16A11,11,0,0,1,5,17V16A10.94,10.94,0,0,1,16,5,10.64,10.64,0,0,1,27,16c0,3.59-1.4,5-3.66,5C21.76,21,21,19.71,21,18V10H19v1.94A3.84,3.84,0,0,0,15.5,10,5.48,5.48,0,0,0,10,15.44v2.12A5.48,5.48,0,0,0,15.5,23a4.28,4.28,0,0,0,4-2.46A4.35,4.35,0,0,0,23.41,23C26.48,23,29,21,29,16A12.72,12.72,0,0,0,16,3Zm3,14.56a3.5,3.5,0,0,1-7,0V15.44a3.5,3.5,0,0,1,7,0Z"
  })), children);
});
var Attachment32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Attachment32(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.1,18.9L13.1,3.9c-2.5-2.6-6.6-2.6-9.2-0.1S1.3,10.5,3.9,13c0,0,0.1,0.1,0.1,0.1L6.8,16l1.4-1.4l-2.9-2.9\tC3.6,10,3.6,7.1,5.3,5.4s4.6-1.8,6.3-0.1c0,0,0,0,0.1,0.1l14.9,14.9c1.8,1.7,1.8,4.6,0.1,6.3c-1.7,1.8-4.6,1.8-6.3,0.1\tc0,0,0,0-0.1-0.1l-7.4-7.4c-1-1-0.9-2.6,0-3.5c1-0.9,2.5-0.9,3.5,0l4.1,4.1l1.4-1.4c0,0-4.2-4.2-4.2-4.2c-1.8-1.7-4.6-1.6-6.3,0.2\tc-1.6,1.7-1.6,4.4,0,6.2l7.5,7.5c2.5,2.6,6.6,2.6,9.2,0.1S30.7,21.5,28.1,18.9C28.1,19,28.1,18.9,28.1,18.9L28.1,18.9z"
  })), children);
});
var Attachment24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Attachment24(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.1,18.9L13.1,3.9c-2.5-2.6-6.6-2.6-9.2-0.1S1.3,10.5,3.9,13c0,0,0.1,0.1,0.1,0.1L6.8,16l1.4-1.4l-2.9-2.9\tC3.6,10,3.6,7.1,5.3,5.4s4.6-1.8,6.3-0.1c0,0,0,0,0.1,0.1l14.9,14.9c1.8,1.7,1.8,4.6,0.1,6.3c-1.7,1.8-4.6,1.8-6.3,0.1\tc0,0,0,0-0.1-0.1l-7.4-7.4c-1-1-0.9-2.6,0-3.5c1-0.9,2.5-0.9,3.5,0l4.1,4.1l1.4-1.4c0,0-4.2-4.2-4.2-4.2c-1.8-1.7-4.6-1.6-6.3,0.2\tc-1.6,1.7-1.6,4.4,0,6.2l7.5,7.5c2.5,2.6,6.6,2.6,9.2,0.1S30.7,21.5,28.1,18.9C28.1,19,28.1,18.9,28.1,18.9L28.1,18.9z"
  })), children);
});
var Attachment20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Attachment20(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.1,18.9L13.1,3.9c-2.5-2.6-6.6-2.6-9.2-0.1S1.3,10.5,3.9,13c0,0,0.1,0.1,0.1,0.1L6.8,16l1.4-1.4l-2.9-2.9\tC3.6,10,3.6,7.1,5.3,5.4s4.6-1.8,6.3-0.1c0,0,0,0,0.1,0.1l14.9,14.9c1.8,1.7,1.8,4.6,0.1,6.3c-1.7,1.8-4.6,1.8-6.3,0.1\tc0,0,0,0-0.1-0.1l-7.4-7.4c-1-1-0.9-2.6,0-3.5c1-0.9,2.5-0.9,3.5,0l4.1,4.1l1.4-1.4c0,0-4.2-4.2-4.2-4.2c-1.8-1.7-4.6-1.6-6.3,0.2\tc-1.6,1.7-1.6,4.4,0,6.2l7.5,7.5c2.5,2.6,6.6,2.6,9.2,0.1S30.7,21.5,28.1,18.9C28.1,19,28.1,18.9,28.1,18.9L28.1,18.9z"
  })), children);
});
var Attachment16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Attachment16(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.1,18.9L13.1,3.9c-2.5-2.6-6.6-2.6-9.2-0.1S1.3,10.5,3.9,13c0,0,0.1,0.1,0.1,0.1L6.8,16l1.4-1.4l-2.9-2.9\tC3.6,10,3.6,7.1,5.3,5.4s4.6-1.8,6.3-0.1c0,0,0,0,0.1,0.1l14.9,14.9c1.8,1.7,1.8,4.6,0.1,6.3c-1.7,1.8-4.6,1.8-6.3,0.1\tc0,0,0,0-0.1-0.1l-7.4-7.4c-1-1-0.9-2.6,0-3.5c1-0.9,2.5-0.9,3.5,0l4.1,4.1l1.4-1.4c0,0-4.2-4.2-4.2-4.2c-1.8-1.7-4.6-1.6-6.3,0.2\tc-1.6,1.7-1.6,4.4,0,6.2l7.5,7.5c2.5,2.6,6.6,2.6,9.2,0.1S30.7,21.5,28.1,18.9C28.1,19,28.1,18.9,28.1,18.9L28.1,18.9z"
  })), children);
});
var AudioConsole32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AudioConsole32(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 14H27V2H25V14H24a2.0019 2.0019 0 00-2 2v2a2.0023 2.0023 0 002 2h1V30h2V20h1a2.0027 2.0027 0 002-2V16A2.0023 2.0023 0 0028 14zm0 4H24V16h4zM18 6H17V2H15V6H14a2.0019 2.0019 0 00-2 2v2a2.0019 2.0019 0 002 2h1V30h2V12h1a2.002 2.002 0 002-2V8A2.002 2.002 0 0018 6zm0 4H14V8h4zM8 20H7V2H5V20H4a2.0023 2.0023 0 00-2 2v2a2.0023 2.0023 0 002 2H5v4H7V26H8a2.0023 2.0023 0 002-2V22A2.0023 2.0023 0 008 20zm0 4H4V22H8z",
    transform: "translate(0 .005)"
  })), children);
});
var AudioConsole24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AudioConsole24(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 14H27V2H25V14H24a2.0019 2.0019 0 00-2 2v2a2.0023 2.0023 0 002 2h1V30h2V20h1a2.0027 2.0027 0 002-2V16A2.0023 2.0023 0 0028 14zm0 4H24V16h4zM18 6H17V2H15V6H14a2.0019 2.0019 0 00-2 2v2a2.0019 2.0019 0 002 2h1V30h2V12h1a2.002 2.002 0 002-2V8A2.002 2.002 0 0018 6zm0 4H14V8h4zM8 20H7V2H5V20H4a2.0023 2.0023 0 00-2 2v2a2.0023 2.0023 0 002 2H5v4H7V26H8a2.0023 2.0023 0 002-2V22A2.0023 2.0023 0 008 20zm0 4H4V22H8z",
    transform: "translate(0 .005)"
  })), children);
});
var AudioConsole20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AudioConsole20(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 14H27V2H25V14H24a2.0019 2.0019 0 00-2 2v2a2.0023 2.0023 0 002 2h1V30h2V20h1a2.0027 2.0027 0 002-2V16A2.0023 2.0023 0 0028 14zm0 4H24V16h4zM18 6H17V2H15V6H14a2.0019 2.0019 0 00-2 2v2a2.0019 2.0019 0 002 2h1V30h2V12h1a2.002 2.002 0 002-2V8A2.002 2.002 0 0018 6zm0 4H14V8h4zM8 20H7V2H5V20H4a2.0023 2.0023 0 00-2 2v2a2.0023 2.0023 0 002 2H5v4H7V26H8a2.0023 2.0023 0 002-2V22A2.0023 2.0023 0 008 20zm0 4H4V22H8z",
    transform: "translate(0 .005)"
  })), children);
});
var AudioConsole16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AudioConsole16(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 14H27V2H25V14H24a2.0019 2.0019 0 00-2 2v2a2.0023 2.0023 0 002 2h1V30h2V20h1a2.0027 2.0027 0 002-2V16A2.0023 2.0023 0 0028 14zm0 4H24V16h4zM18 6H17V2H15V6H14a2.0019 2.0019 0 00-2 2v2a2.0019 2.0019 0 002 2h1V30h2V12h1a2.002 2.002 0 002-2V8A2.002 2.002 0 0018 6zm0 4H14V8h4zM8 20H7V2H5V20H4a2.0023 2.0023 0 00-2 2v2a2.0023 2.0023 0 002 2H5v4H7V26H8a2.0023 2.0023 0 002-2V22A2.0023 2.0023 0 008 20zm0 4H4V22H8z",
    transform: "translate(0 .005)"
  })), children);
});
var AugmentedReality32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AugmentedReality32(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.4473,9.1055l-6-3a1.0008,1.0008,0,0,0-.8946,0l-6,3A1,1,0,0,0,14,10v7a1,1,0,0,0,.5527.8945l6,3a1.001,1.001,0,0,0,.8946,0l6-3A1,1,0,0,0,28,17V10A1,1,0,0,0,27.4473,9.1055ZM21,8.1182,24.7637,10,21,11.8818,17.2363,10Zm-5,3.5,4,2v4.7636l-4-2Zm6,6.7636V13.6182l4-2v4.7636Z"
  })), _circle173 || (_circle173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13.5",
    cy: "24.5",
    r: "1.5"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,30H7a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,7,2H20V4H7V28H20V24h2v4A2.0023,2.0023,0,0,1,20,30Z"
  })), children);
});
var AugmentedReality24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AugmentedReality24(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.4473,9.1055l-6-3a1.0008,1.0008,0,0,0-.8946,0l-6,3A1,1,0,0,0,14,10v7a1,1,0,0,0,.5527.8945l6,3a1.001,1.001,0,0,0,.8946,0l6-3A1,1,0,0,0,28,17V10A1,1,0,0,0,27.4473,9.1055ZM21,8.1182,24.7637,10,21,11.8818,17.2363,10Zm-5,3.5,4,2v4.7636l-4-2Zm6,6.7636V13.6182l4-2v4.7636Z"
  })), _circle174 || (_circle174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13.5",
    cy: "24.5",
    r: "1.5"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,30H7a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,7,2H20V4H7V28H20V24h2v4A2.0023,2.0023,0,0,1,20,30Z"
  })), children);
});
var AugmentedReality20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AugmentedReality20(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.4473,9.1055l-6-3a1.0008,1.0008,0,0,0-.8946,0l-6,3A1,1,0,0,0,14,10v7a1,1,0,0,0,.5527.8945l6,3a1.001,1.001,0,0,0,.8946,0l6-3A1,1,0,0,0,28,17V10A1,1,0,0,0,27.4473,9.1055ZM21,8.1182,24.7637,10,21,11.8818,17.2363,10Zm-5,3.5,4,2v4.7636l-4-2Zm6,6.7636V13.6182l4-2v4.7636Z"
  })), _circle175 || (_circle175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13.5",
    cy: "24.5",
    r: "1.5"
  })), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,30H7a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,7,2H20V4H7V28H20V24h2v4A2.0023,2.0023,0,0,1,20,30Z"
  })), children);
});
var AugmentedReality16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function AugmentedReality16(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.4473,9.1055l-6-3a1.0008,1.0008,0,0,0-.8946,0l-6,3A1,1,0,0,0,14,10v7a1,1,0,0,0,.5527.8945l6,3a1.001,1.001,0,0,0,.8946,0l6-3A1,1,0,0,0,28,17V10A1,1,0,0,0,27.4473,9.1055ZM21,8.1182,24.7637,10,21,11.8818,17.2363,10Zm-5,3.5,4,2v4.7636l-4-2Zm6,6.7636V13.6182l4-2v4.7636Z"
  })), _circle176 || (_circle176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13.5",
    cy: "24.5",
    r: "1.5"
  })), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,30H7a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,7,2H20V4H7V28H20V24h2v4A2.0023,2.0023,0,0,1,20,30Z"
  })), children);
});
var WatsonHealthAutoScroll32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAutoScroll32(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 16a4 4 0 104-4A4 4 0 0012 16zm6 0a2 2 0 11-2-2A2 2 0 0118 16zM16 27.17L10.4 21.58 9 23 16 30 23 23 21.59 21.59 16 27.17zM16 4.83L21.58 10.4 23 9 16 2 9 9 10.41 10.41 16 4.83z"
  })), children);
});
var WatsonHealthAutoScroll24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAutoScroll24(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 16a4 4 0 104-4A4 4 0 0012 16zm6 0a2 2 0 11-2-2A2 2 0 0118 16zM16 27.17L10.4 21.58 9 23 16 30 23 23 21.59 21.59 16 27.17zM16 4.83L21.58 10.4 23 9 16 2 9 9 10.41 10.41 16 4.83z"
  })), children);
});
var WatsonHealthAutoScroll20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAutoScroll20(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 16a4 4 0 104-4A4 4 0 0012 16zm6 0a2 2 0 11-2-2A2 2 0 0118 16zM16 27.17L10.4 21.58 9 23 16 30 23 23 21.59 21.59 16 27.17zM16 4.83L21.58 10.4 23 9 16 2 9 9 10.41 10.41 16 4.83z"
  })), children);
});
var WatsonHealthAutoScroll16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthAutoScroll16(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 16a4 4 0 104-4A4 4 0 0012 16zm6 0a2 2 0 11-2-2A2 2 0 0118 16zM16 27.17L10.4 21.58 9 23 16 30 23 23 21.59 21.59 16 27.17zM16 4.83L21.58 10.4 23 9 16 2 9 9 10.41 10.41 16 4.83z"
  })), children);
});
var Automatic32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Automatic32(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 16H22a2.002 2.002 0 00-2 2V30h2V25h4v5h2V18A2.002 2.002 0 0026 16zm-4 7V18h4v5zM16 27a10.9862 10.9862 0 01-9.2156-5H12V20H4v8H6V24.3149A13.0239 13.0239 0 0016 29zM20 10h5.2155A10.9973 10.9973 0 005 16H3A13.0048 13.0048 0 0126 7.6849V4h2v8H20z"
  })), children);
});
var Automatic24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Automatic24(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 16H22a2.002 2.002 0 00-2 2V30h2V25h4v5h2V18A2.002 2.002 0 0026 16zm-4 7V18h4v5zM16 27a10.9862 10.9862 0 01-9.2156-5H12V20H4v8H6V24.3149A13.0239 13.0239 0 0016 29zM20 10h5.2155A10.9973 10.9973 0 005 16H3A13.0048 13.0048 0 0126 7.6849V4h2v8H20z"
  })), children);
});
var Automatic20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Automatic20(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 16H22a2.002 2.002 0 00-2 2V30h2V25h4v5h2V18A2.002 2.002 0 0026 16zm-4 7V18h4v5zM16 27a10.9862 10.9862 0 01-9.2156-5H12V20H4v8H6V24.3149A13.0239 13.0239 0 0016 29zM20 10h5.2155A10.9973 10.9973 0 005 16H3A13.0048 13.0048 0 0126 7.6849V4h2v8H20z"
  })), children);
});
var Automatic16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Automatic16(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 16H22a2.002 2.002 0 00-2 2V30h2V25h4v5h2V18A2.002 2.002 0 0026 16zm-4 7V18h4v5zM16 27a10.9862 10.9862 0 01-9.2156-5H12V20H4v8H6V24.3149A13.0239 13.0239 0 0016 29zM20 10h5.2155A10.9973 10.9973 0 005 16H3A13.0048 13.0048 0 0126 7.6849V4h2v8H20z"
  })), children);
});
var Autoscaling32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Autoscaling32(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,28H12V26H22V10H6V20H4V10A2.0021,2.0021,0,0,1,6,8H22a2.0021,2.0021,0,0,1,2,2V26A2.0021,2.0021,0,0,1,22,28Z"
  })), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,22H26V20h2V4H12V6H10V4a2.0021,2.0021,0,0,1,2-2H28a2.0021,2.0021,0,0,1,2,2V20A2.0021,2.0021,0,0,1,28,22Z"
  })), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 14L10 16 14.586 16 3 27.586 4.414 29 16 17.414 16 22 18 22 18 14 10 14z"
  })), children);
});
var Autoscaling24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Autoscaling24(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,28H12V26H22V10H6V20H4V10A2.0021,2.0021,0,0,1,6,8H22a2.0021,2.0021,0,0,1,2,2V26A2.0021,2.0021,0,0,1,22,28Z"
  })), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,22H26V20h2V4H12V6H10V4a2.0021,2.0021,0,0,1,2-2H28a2.0021,2.0021,0,0,1,2,2V20A2.0021,2.0021,0,0,1,28,22Z"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 14L10 16 14.586 16 3 27.586 4.414 29 16 17.414 16 22 18 22 18 14 10 14z"
  })), children);
});
var Autoscaling20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Autoscaling20(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,28H12V26H22V10H6V20H4V10A2.0021,2.0021,0,0,1,6,8H22a2.0021,2.0021,0,0,1,2,2V26A2.0021,2.0021,0,0,1,22,28Z"
  })), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,22H26V20h2V4H12V6H10V4a2.0021,2.0021,0,0,1,2-2H28a2.0021,2.0021,0,0,1,2,2V20A2.0021,2.0021,0,0,1,28,22Z"
  })), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 14L10 16 14.586 16 3 27.586 4.414 29 16 17.414 16 22 18 22 18 14 10 14z"
  })), children);
});
var Autoscaling16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Autoscaling16(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,28H12V26H22V10H6V20H4V10A2.0021,2.0021,0,0,1,6,8H22a2.0021,2.0021,0,0,1,2,2V26A2.0021,2.0021,0,0,1,22,28Z"
  })), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,22H26V20h2V4H12V6H10V4a2.0021,2.0021,0,0,1,2-2H28a2.0021,2.0021,0,0,1,2,2V20A2.0021,2.0021,0,0,1,28,22Z"
  })), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 14L10 16 14.586 16 3 27.586 4.414 29 16 17.414 16 22 18 22 18 14 10 14z"
  })), children);
});
var Awake32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Awake32(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V6.96H15z"
  })), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.67 6.85H26.630000000000003V8.85H21.67z",
    transform: "rotate(-45 24.142 7.85)"
  })), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.04 15H30V17H25.04z"
  })), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.15 21.67H25.15V26.630000000000003H23.15z",
    transform: "rotate(-45 24.152 24.146)"
  })), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25.04H17V30H15z"
  })), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.37 23.15H10.33V25.15H5.37z",
    transform: "rotate(-45 7.86 24.144)"
  })), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15H6.96V17H2z"
  })), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.85 5.37H8.85V10.33H6.85z",
    transform: "rotate(-45 7.85 7.848)"
  })), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4,4,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z"
  })), children);
});
var Awake24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Awake24(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V6.96H15z"
  })), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.67 6.85H26.630000000000003V8.85H21.67z",
    transform: "rotate(-45 24.142 7.85)"
  })), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.04 15H30V17H25.04z"
  })), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.15 21.67H25.15V26.630000000000003H23.15z",
    transform: "rotate(-45 24.152 24.146)"
  })), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25.04H17V30H15z"
  })), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.37 23.15H10.33V25.15H5.37z",
    transform: "rotate(-45 7.86 24.144)"
  })), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15H6.96V17H2z"
  })), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.85 5.37H8.85V10.33H6.85z",
    transform: "rotate(-45 7.85 7.848)"
  })), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4,4,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z"
  })), children);
});
var Awake20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Awake20(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V6.96H15z"
  })), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.67 6.85H26.630000000000003V8.85H21.67z",
    transform: "rotate(-45 24.142 7.85)"
  })), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.04 15H30V17H25.04z"
  })), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.15 21.67H25.15V26.630000000000003H23.15z",
    transform: "rotate(-45 24.152 24.146)"
  })), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25.04H17V30H15z"
  })), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.37 23.15H10.33V25.15H5.37z",
    transform: "rotate(-45 7.86 24.144)"
  })), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15H6.96V17H2z"
  })), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.85 5.37H8.85V10.33H6.85z",
    transform: "rotate(-45 7.85 7.848)"
  })), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4,4,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z"
  })), children);
});
var Awake16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Awake16(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.5 1H8.5V3.5H7.5z"
  })), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.8 3.4H13.3V4.4H10.8z",
    transform: "rotate(-45.001 12.074 3.922)"
  })), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.5 7.5H15V8.5H12.5z"
  })), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.6 10.8H12.6V13.3H11.6z",
    transform: "rotate(-45.001 12.077 12.075)"
  })), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.5 12.5H8.5V15H7.5z"
  })), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.7 11.6H5.2V12.6H2.7z",
    transform: "rotate(-45.001 3.929 12.078)"
  })), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M1 7.5H3.5V8.5H1z"
  })), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.4 2.7H4.4V5.2H3.4z",
    transform: "rotate(-45.001 3.926 3.925)"
  })), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,6c1.1,0,2,0.9,2,2s-0.9,2-2,2S6,9.1,6,8S6.9,6,8,6 M8,5C6.3,5,5,6.3,5,8s1.3,3,3,3s3-1.3,3-3S9.7,5,8,5z"
  })), children);
});
var BackToTop32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function BackToTop32(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  if (true) {
    if (!didWarnAboutDeprecation['BackToTop32']) {
      didWarnAboutDeprecation['BackToTop32'] = true;
      console.warn("The BackToTop32 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 14L6 24 7.4 25.4 16 16.8 24.6 25.4 26 24zM4 8H28V10H4z"
  })), children);
});
var BackToTop24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function BackToTop24(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  if (true) {
    if (!didWarnAboutDeprecation['BackToTop24']) {
      didWarnAboutDeprecation['BackToTop24'] = true;
      console.warn("The BackToTop24 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 14L6 24 7.4 25.4 16 16.8 24.6 25.4 26 24zM4 8H28V10H4z"
  })), children);
});
var BackToTop20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function BackToTop20(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  if (true) {
    if (!didWarnAboutDeprecation['BackToTop20']) {
      didWarnAboutDeprecation['BackToTop20'] = true;
      console.warn("The BackToTop20 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 14L6 24 7.4 25.4 16 16.8 24.6 25.4 26 24zM4 8H28V10H4z"
  })), children);
});
var BackToTop16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function BackToTop16(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  if (true) {
    if (!didWarnAboutDeprecation['BackToTop16']) {
      didWarnAboutDeprecation['BackToTop16'] = true;
      console.warn("The BackToTop16 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 14L6 24 7.4 25.4 16 16.8 24.6 25.4 26 24zM4 8H28V10H4z"
  })), children);
});
var Badge32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Badge32(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 2L24.593 5 28 5.414 25.5 7.667 26 11 23 9.125 20 11 20.5 7.667 18 5.414 21.5 5 23 2z"
  })), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.7168,13.249l-1.9375-.498A6.9942,6.9942,0,1,1,15.7505,4.22l.499-1.9365A8.99,8.99,0,0,0,8,17.689V30l6-4,6,4V17.7078A8.9627,8.9627,0,0,0,22.7168,13.249ZM18,26.2627l-4-2.6665-4,2.6665V19.05a8.9238,8.9238,0,0,0,8,.0062Z"
  })), children);
});
var Badge24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Badge24(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 2L24.593 5 28 5.414 25.5 7.667 26 11 23 9.125 20 11 20.5 7.667 18 5.414 21.5 5 23 2z"
  })), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.7168,13.249l-1.9375-.498A6.9942,6.9942,0,1,1,15.7505,4.22l.499-1.9365A8.99,8.99,0,0,0,8,17.689V30l6-4,6,4V17.7078A8.9627,8.9627,0,0,0,22.7168,13.249ZM18,26.2627l-4-2.6665-4,2.6665V19.05a8.9238,8.9238,0,0,0,8,.0062Z"
  })), children);
});
var Badge20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Badge20(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 2L24.593 5 28 5.414 25.5 7.667 26 11 23 9.125 20 11 20.5 7.667 18 5.414 21.5 5 23 2z"
  })), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.7168,13.249l-1.9375-.498A6.9942,6.9942,0,1,1,15.7505,4.22l.499-1.9365A8.99,8.99,0,0,0,8,17.689V30l6-4,6,4V17.7078A8.9627,8.9627,0,0,0,22.7168,13.249ZM18,26.2627l-4-2.6665-4,2.6665V19.05a8.9238,8.9238,0,0,0,8,.0062Z"
  })), children);
});
var Badge16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Badge16(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 2L24.593 5 28 5.414 25.5 7.667 26 11 23 9.125 20 11 20.5 7.667 18 5.414 21.5 5 23 2z"
  })), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.7168,13.249l-1.9375-.498A6.9942,6.9942,0,1,1,15.7505,4.22l.499-1.9365A8.99,8.99,0,0,0,8,17.689V30l6-4,6,4V17.7078A8.9627,8.9627,0,0,0,22.7168,13.249ZM18,26.2627l-4-2.6665-4,2.6665V19.05a8.9238,8.9238,0,0,0,8,.0062Z"
  })), children);
});
var BaggageClaim32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function BaggageClaim32(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle177 || (_circle177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "26",
    r: "2"
  })), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,18H25V16a2.0023,2.0023,0,0,0-2-2H19a2.0023,2.0023,0,0,0-2,2v2H14a2.0023,2.0023,0,0,0-2,2v8a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V20A2.0023,2.0023,0,0,0,28,18Zm-9-2h4v2H19Zm9,12H14V20H28Z"
  })), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,6h4v6h2V6h4v6h2V6h4v6h2V6.0049A2.0047,2.0047,0,0,0,25.9951,4H4.0049A2.0047,2.0047,0,0,0,2,6.0049v13.99A2.0047,2.0047,0,0,0,4.0049,22H10ZM8,20H4V6H8Z"
  })), children);
});
var BaggageClaim24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function BaggageClaim24(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle178 || (_circle178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "26",
    r: "2"
  })), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,18H25V16a2.0023,2.0023,0,0,0-2-2H19a2.0023,2.0023,0,0,0-2,2v2H14a2.0023,2.0023,0,0,0-2,2v8a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V20A2.0023,2.0023,0,0,0,28,18Zm-9-2h4v2H19Zm9,12H14V20H28Z"
  })), _path390 || (_path390 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,6h4v6h2V6h4v6h2V6h4v6h2V6.0049A2.0047,2.0047,0,0,0,25.9951,4H4.0049A2.0047,2.0047,0,0,0,2,6.0049v13.99A2.0047,2.0047,0,0,0,4.0049,22H10ZM8,20H4V6H8Z"
  })), children);
});
var BaggageClaim20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function BaggageClaim20(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle179 || (_circle179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "26",
    r: "2"
  })), _path391 || (_path391 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,18H25V16a2.0023,2.0023,0,0,0-2-2H19a2.0023,2.0023,0,0,0-2,2v2H14a2.0023,2.0023,0,0,0-2,2v8a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V20A2.0023,2.0023,0,0,0,28,18Zm-9-2h4v2H19Zm9,12H14V20H28Z"
  })), _path392 || (_path392 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,6h4v6h2V6h4v6h2V6h4v6h2V6.0049A2.0047,2.0047,0,0,0,25.9951,4H4.0049A2.0047,2.0047,0,0,0,2,6.0049v13.99A2.0047,2.0047,0,0,0,4.0049,22H10ZM8,20H4V6H8Z"
  })), children);
});
var BaggageClaim16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function BaggageClaim16(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle180 || (_circle180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "26",
    r: "2"
  })), _path393 || (_path393 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,18H25V16a2.0023,2.0023,0,0,0-2-2H19a2.0023,2.0023,0,0,0-2,2v2H14a2.0023,2.0023,0,0,0-2,2v8a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V20A2.0023,2.0023,0,0,0,28,18Zm-9-2h4v2H19Zm9,12H14V20H28Z"
  })), _path394 || (_path394 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,6h4v6h2V6h4v6h2V6h4v6h2V6.0049A2.0047,2.0047,0,0,0,25.9951,4H4.0049A2.0047,2.0047,0,0,0,2,6.0049v13.99A2.0047,2.0047,0,0,0,4.0049,22H10ZM8,20H4V6H8Z"
  })), children);
});
var Bar32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Bar32(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path395 || (_path395 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,11H15a1,1,0,0,0-1,1v4a6.0046,6.0046,0,0,0,5,5.91V28H16v2h8V28H21V21.91A6.0046,6.0046,0,0,0,26,16V12A1,1,0,0,0,25,11Zm-1,5a4,4,0,0,1-8,0V13h8Z"
  })), _path396 || (_path396 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,1H10A1,1,0,0,0,9,2V9.3706A6.09,6.09,0,0,0,6,15V29a1,1,0,0,0,1,1h5V28H8V15c0-3.1875,2.231-4.02,2.3164-4.0513L11,10.7207V3h3V8h2V2A1,1,0,0,0,15,1Z"
  })), children);
});
var Bar24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Bar24(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path397 || (_path397 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,11H15a1,1,0,0,0-1,1v4a6.0046,6.0046,0,0,0,5,5.91V28H16v2h8V28H21V21.91A6.0046,6.0046,0,0,0,26,16V12A1,1,0,0,0,25,11Zm-1,5a4,4,0,0,1-8,0V13h8Z"
  })), _path398 || (_path398 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,1H10A1,1,0,0,0,9,2V9.3706A6.09,6.09,0,0,0,6,15V29a1,1,0,0,0,1,1h5V28H8V15c0-3.1875,2.231-4.02,2.3164-4.0513L11,10.7207V3h3V8h2V2A1,1,0,0,0,15,1Z"
  })), children);
});
var Bar20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Bar20(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path399 || (_path399 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,11H15a1,1,0,0,0-1,1v4a6.0046,6.0046,0,0,0,5,5.91V28H16v2h8V28H21V21.91A6.0046,6.0046,0,0,0,26,16V12A1,1,0,0,0,25,11Zm-1,5a4,4,0,0,1-8,0V13h8Z"
  })), _path400 || (_path400 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,1H10A1,1,0,0,0,9,2V9.3706A6.09,6.09,0,0,0,6,15V29a1,1,0,0,0,1,1h5V28H8V15c0-3.1875,2.231-4.02,2.3164-4.0513L11,10.7207V3h3V8h2V2A1,1,0,0,0,15,1Z"
  })), children);
});
var Bar16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Bar16(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path401 || (_path401 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,11H15a1,1,0,0,0-1,1v4a6.0046,6.0046,0,0,0,5,5.91V28H16v2h8V28H21V21.91A6.0046,6.0046,0,0,0,26,16V12A1,1,0,0,0,25,11Zm-1,5a4,4,0,0,1-8,0V13h8Z"
  })), _path402 || (_path402 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,1H10A1,1,0,0,0,9,2V9.3706A6.09,6.09,0,0,0,6,15V29a1,1,0,0,0,1,1h5V28H8V15c0-3.1875,2.231-4.02,2.3164-4.0513L11,10.7207V3h3V8h2V2A1,1,0,0,0,15,1Z"
  })), children);
});
var Barcode32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Barcode32(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path403 || (_path403 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 6H4V28H2zM12 6H14V26H12zM6 6H10V26H6zM16 6H20V26H16zM22 6H26V26H22zM28 6H30V28H28z"
  })), children);
});
var Barcode24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Barcode24(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path404 || (_path404 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 6H4V28H2zM12 6H14V26H12zM6 6H10V26H6zM16 6H20V26H16zM22 6H26V26H22zM28 6H30V28H28z"
  })), children);
});
var Barcode20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Barcode20(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path405 || (_path405 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 6H4V28H2zM12 6H14V26H12zM6 6H10V26H6zM16 6H20V26H16zM22 6H26V26H22zM28 6H30V28H28z"
  })), children);
});
var Barcode16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Barcode16(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path406 || (_path406 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 6H4V28H2zM12 6H14V26H12zM6 6H10V26H6zM16 6H20V26H16zM22 6H26V26H22zM28 6H30V28H28z"
  })), children);
});
var BareMetalServer32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function BareMetalServer32(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle181 || (_circle181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "6",
    r: "1"
  })), _path407 || (_path407 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,10H6A2.0021,2.0021,0,0,1,4,8V4A2.0021,2.0021,0,0,1,6,2H26a2.0021,2.0021,0,0,1,2,2V8A2.0021,2.0021,0,0,1,26,10ZM6,4V8H26V4Z"
  })), _circle182 || (_circle182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "16",
    r: "1"
  })), _path408 || (_path408 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20H6a2.0021,2.0021,0,0,1-2-2V14a2.0021,2.0021,0,0,1,2-2H26a2.0021,2.0021,0,0,1,2,2v4A2.0021,2.0021,0,0,1,26,20ZM6,14v4H26V14Z"
  })), _circle183 || (_circle183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "26",
    r: "1"
  })), _path409 || (_path409 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0021,2.0021,0,0,1-2-2V24a2.0021,2.0021,0,0,1,2-2H26a2.0021,2.0021,0,0,1,2,2v4A2.0021,2.0021,0,0,1,26,30ZM6,24v4H26V24Z"
  })), children);
});
var BareMetalServer24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function BareMetalServer24(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle184 || (_circle184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "6",
    r: "1"
  })), _path410 || (_path410 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,10H6A2.0021,2.0021,0,0,1,4,8V4A2.0021,2.0021,0,0,1,6,2H26a2.0021,2.0021,0,0,1,2,2V8A2.0021,2.0021,0,0,1,26,10ZM6,4V8H26V4Z"
  })), _circle185 || (_circle185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "16",
    r: "1"
  })), _path411 || (_path411 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20H6a2.0021,2.0021,0,0,1-2-2V14a2.0021,2.0021,0,0,1,2-2H26a2.0021,2.0021,0,0,1,2,2v4A2.0021,2.0021,0,0,1,26,20ZM6,14v4H26V14Z"
  })), _circle186 || (_circle186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "26",
    r: "1"
  })), _path412 || (_path412 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0021,2.0021,0,0,1-2-2V24a2.0021,2.0021,0,0,1,2-2H26a2.0021,2.0021,0,0,1,2,2v4A2.0021,2.0021,0,0,1,26,30ZM6,24v4H26V24Z"
  })), children);
});
var BareMetalServer20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function BareMetalServer20(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle187 || (_circle187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "6",
    r: "1"
  })), _path413 || (_path413 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,10H6A2.0021,2.0021,0,0,1,4,8V4A2.0021,2.0021,0,0,1,6,2H26a2.0021,2.0021,0,0,1,2,2V8A2.0021,2.0021,0,0,1,26,10ZM6,4V8H26V4Z"
  })), _circle188 || (_circle188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "16",
    r: "1"
  })), _path414 || (_path414 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20H6a2.0021,2.0021,0,0,1-2-2V14a2.0021,2.0021,0,0,1,2-2H26a2.0021,2.0021,0,0,1,2,2v4A2.0021,2.0021,0,0,1,26,20ZM6,14v4H26V14Z"
  })), _circle189 || (_circle189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "26",
    r: "1"
  })), _path415 || (_path415 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0021,2.0021,0,0,1-2-2V24a2.0021,2.0021,0,0,1,2-2H26a2.0021,2.0021,0,0,1,2,2v4A2.0021,2.0021,0,0,1,26,30ZM6,24v4H26V24Z"
  })), children);
});
var BareMetalServer16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function BareMetalServer16(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle190 || (_circle190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "6",
    r: "1"
  })), _path416 || (_path416 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,10H6A2.0021,2.0021,0,0,1,4,8V4A2.0021,2.0021,0,0,1,6,2H26a2.0021,2.0021,0,0,1,2,2V8A2.0021,2.0021,0,0,1,26,10ZM6,4V8H26V4Z"
  })), _circle191 || (_circle191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "16",
    r: "1"
  })), _path417 || (_path417 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20H6a2.0021,2.0021,0,0,1-2-2V14a2.0021,2.0021,0,0,1,2-2H26a2.0021,2.0021,0,0,1,2,2v4A2.0021,2.0021,0,0,1,26,20ZM6,14v4H26V14Z"
  })), _circle192 || (_circle192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "26",
    r: "1"
  })), _path418 || (_path418 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2.0021,2.0021,0,0,1-2-2V24a2.0021,2.0021,0,0,1,2-2H26a2.0021,2.0021,0,0,1,2,2v4A2.0021,2.0021,0,0,1,26,30ZM6,24v4H26V24Z"
  })), children);
});
var BareMetalServer_0132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function BareMetalServer_0132(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path419 || (_path419 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 28L17 22 15 22 15 28 5 28 5 30 27 30 27 28 17 28z"
  })), _circle193 || (_circle193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "16",
    r: "1"
  })), _path420 || (_path420 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20H6a2.0023,2.0023,0,0,1-2-2V14a2.0023,2.0023,0,0,1,2-2H26a2.0023,2.0023,0,0,1,2,2v4A2.0023,2.0023,0,0,1,26,20ZM6,14v4H26V14Z"
  })), children);
});
var BareMetalServer_0124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function BareMetalServer_0124(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path421 || (_path421 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 28L17 22 15 22 15 28 5 28 5 30 27 30 27 28 17 28z"
  })), _circle194 || (_circle194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "16",
    r: "1"
  })), _path422 || (_path422 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20H6a2.0023,2.0023,0,0,1-2-2V14a2.0023,2.0023,0,0,1,2-2H26a2.0023,2.0023,0,0,1,2,2v4A2.0023,2.0023,0,0,1,26,20ZM6,14v4H26V14Z"
  })), children);
});
var BareMetalServer_0120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function BareMetalServer_0120(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path423 || (_path423 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 28L17 22 15 22 15 28 5 28 5 30 27 30 27 28 17 28z"
  })), _circle195 || (_circle195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "16",
    r: "1"
  })), _path424 || (_path424 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20H6a2.0023,2.0023,0,0,1-2-2V14a2.0023,2.0023,0,0,1,2-2H26a2.0023,2.0023,0,0,1,2,2v4A2.0023,2.0023,0,0,1,26,20ZM6,14v4H26V14Z"
  })), children);
});
var BareMetalServer_0116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function BareMetalServer_0116(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path425 || (_path425 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 28L17 22 15 22 15 28 5 28 5 30 27 30 27 28 17 28z"
  })), _circle196 || (_circle196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "16",
    r: "1"
  })), _path426 || (_path426 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20H6a2.0023,2.0023,0,0,1-2-2V14a2.0023,2.0023,0,0,1,2-2H26a2.0023,2.0023,0,0,1,2,2v4A2.0023,2.0023,0,0,1,26,20ZM6,14v4H26V14Z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-10.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-10.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "DragHorizontal16": () => (/* binding */ DragHorizontal16),
/* harmony export */   "DragHorizontal20": () => (/* binding */ DragHorizontal20),
/* harmony export */   "DragHorizontal24": () => (/* binding */ DragHorizontal24),
/* harmony export */   "DragHorizontal32": () => (/* binding */ DragHorizontal32),
/* harmony export */   "DragVertical16": () => (/* binding */ DragVertical16),
/* harmony export */   "DragVertical20": () => (/* binding */ DragVertical20),
/* harmony export */   "DragVertical24": () => (/* binding */ DragVertical24),
/* harmony export */   "DragVertical32": () => (/* binding */ DragVertical32),
/* harmony export */   "Draggable16": () => (/* binding */ Draggable16),
/* harmony export */   "Draggable20": () => (/* binding */ Draggable20),
/* harmony export */   "Draggable24": () => (/* binding */ Draggable24),
/* harmony export */   "Draggable32": () => (/* binding */ Draggable32),
/* harmony export */   "Draw16": () => (/* binding */ Draw16),
/* harmony export */   "Draw20": () => (/* binding */ Draw20),
/* harmony export */   "Draw24": () => (/* binding */ Draw24),
/* harmony export */   "Draw32": () => (/* binding */ Draw32),
/* harmony export */   "DrillBack16": () => (/* binding */ DrillBack16),
/* harmony export */   "DrillBack20": () => (/* binding */ DrillBack20),
/* harmony export */   "DrillBack24": () => (/* binding */ DrillBack24),
/* harmony export */   "DrillBack32": () => (/* binding */ DrillBack32),
/* harmony export */   "DrillDown16": () => (/* binding */ DrillDown16),
/* harmony export */   "DrillDown20": () => (/* binding */ DrillDown20),
/* harmony export */   "DrillDown24": () => (/* binding */ DrillDown24),
/* harmony export */   "DrillDown32": () => (/* binding */ DrillDown32),
/* harmony export */   "DrillThrough16": () => (/* binding */ DrillThrough16),
/* harmony export */   "DrillThrough20": () => (/* binding */ DrillThrough20),
/* harmony export */   "DrillThrough24": () => (/* binding */ DrillThrough24),
/* harmony export */   "DrillThrough32": () => (/* binding */ DrillThrough32),
/* harmony export */   "DriverAnalysis16": () => (/* binding */ DriverAnalysis16),
/* harmony export */   "DriverAnalysis20": () => (/* binding */ DriverAnalysis20),
/* harmony export */   "DriverAnalysis24": () => (/* binding */ DriverAnalysis24),
/* harmony export */   "DriverAnalysis32": () => (/* binding */ DriverAnalysis32),
/* harmony export */   "Drone16": () => (/* binding */ Drone16),
/* harmony export */   "Drone20": () => (/* binding */ Drone20),
/* harmony export */   "Drone24": () => (/* binding */ Drone24),
/* harmony export */   "Drone32": () => (/* binding */ Drone32),
/* harmony export */   "DroneDelivery16": () => (/* binding */ DroneDelivery16),
/* harmony export */   "DroneDelivery20": () => (/* binding */ DroneDelivery20),
/* harmony export */   "DroneDelivery24": () => (/* binding */ DroneDelivery24),
/* harmony export */   "DroneDelivery32": () => (/* binding */ DroneDelivery32),
/* harmony export */   "DroneFront16": () => (/* binding */ DroneFront16),
/* harmony export */   "DroneFront20": () => (/* binding */ DroneFront20),
/* harmony export */   "DroneFront24": () => (/* binding */ DroneFront24),
/* harmony export */   "DroneFront32": () => (/* binding */ DroneFront32),
/* harmony export */   "DroneVideo16": () => (/* binding */ DroneVideo16),
/* harmony export */   "DroneVideo20": () => (/* binding */ DroneVideo20),
/* harmony export */   "DroneVideo24": () => (/* binding */ DroneVideo24),
/* harmony export */   "DroneVideo32": () => (/* binding */ DroneVideo32),
/* harmony export */   "DropPhoto16": () => (/* binding */ DropPhoto16),
/* harmony export */   "DropPhoto20": () => (/* binding */ DropPhoto20),
/* harmony export */   "DropPhoto24": () => (/* binding */ DropPhoto24),
/* harmony export */   "DropPhoto32": () => (/* binding */ DropPhoto32),
/* harmony export */   "DropPhotoFilled16": () => (/* binding */ DropPhotoFilled16),
/* harmony export */   "DropPhotoFilled20": () => (/* binding */ DropPhotoFilled20),
/* harmony export */   "DropPhotoFilled24": () => (/* binding */ DropPhotoFilled24),
/* harmony export */   "DropPhotoFilled32": () => (/* binding */ DropPhotoFilled32),
/* harmony export */   "Drought16": () => (/* binding */ Drought16),
/* harmony export */   "Drought20": () => (/* binding */ Drought20),
/* harmony export */   "Drought24": () => (/* binding */ Drought24),
/* harmony export */   "Drought32": () => (/* binding */ Drought32),
/* harmony export */   "Dvr16": () => (/* binding */ Dvr16),
/* harmony export */   "Dvr20": () => (/* binding */ Dvr20),
/* harmony export */   "Dvr24": () => (/* binding */ Dvr24),
/* harmony export */   "Dvr32": () => (/* binding */ Dvr32),
/* harmony export */   "Earth16": () => (/* binding */ Earth16),
/* harmony export */   "Earth20": () => (/* binding */ Earth20),
/* harmony export */   "Earth24": () => (/* binding */ Earth24),
/* harmony export */   "Earth32": () => (/* binding */ Earth32),
/* harmony export */   "EarthAmericas16": () => (/* binding */ EarthAmericas16),
/* harmony export */   "EarthAmericas20": () => (/* binding */ EarthAmericas20),
/* harmony export */   "EarthAmericas24": () => (/* binding */ EarthAmericas24),
/* harmony export */   "EarthAmericas32": () => (/* binding */ EarthAmericas32),
/* harmony export */   "EarthAmericasFilled16": () => (/* binding */ EarthAmericasFilled16),
/* harmony export */   "EarthAmericasFilled20": () => (/* binding */ EarthAmericasFilled20),
/* harmony export */   "EarthAmericasFilled24": () => (/* binding */ EarthAmericasFilled24),
/* harmony export */   "EarthAmericasFilled32": () => (/* binding */ EarthAmericasFilled32),
/* harmony export */   "EarthEuropeAfrica16": () => (/* binding */ EarthEuropeAfrica16),
/* harmony export */   "EarthEuropeAfrica20": () => (/* binding */ EarthEuropeAfrica20),
/* harmony export */   "EarthEuropeAfrica24": () => (/* binding */ EarthEuropeAfrica24),
/* harmony export */   "EarthEuropeAfrica32": () => (/* binding */ EarthEuropeAfrica32),
/* harmony export */   "EarthEuropeAfricaFilled16": () => (/* binding */ EarthEuropeAfricaFilled16),
/* harmony export */   "EarthEuropeAfricaFilled20": () => (/* binding */ EarthEuropeAfricaFilled20),
/* harmony export */   "EarthEuropeAfricaFilled24": () => (/* binding */ EarthEuropeAfricaFilled24),
/* harmony export */   "EarthEuropeAfricaFilled32": () => (/* binding */ EarthEuropeAfricaFilled32),
/* harmony export */   "EarthFilled16": () => (/* binding */ EarthFilled16),
/* harmony export */   "EarthFilled20": () => (/* binding */ EarthFilled20),
/* harmony export */   "EarthFilled24": () => (/* binding */ EarthFilled24),
/* harmony export */   "EarthFilled32": () => (/* binding */ EarthFilled32),
/* harmony export */   "EarthSoutheastAsia16": () => (/* binding */ EarthSoutheastAsia16),
/* harmony export */   "EarthSoutheastAsia20": () => (/* binding */ EarthSoutheastAsia20),
/* harmony export */   "EarthSoutheastAsia24": () => (/* binding */ EarthSoutheastAsia24),
/* harmony export */   "EarthSoutheastAsia32": () => (/* binding */ EarthSoutheastAsia32),
/* harmony export */   "EarthSoutheastAsiaFilled16": () => (/* binding */ EarthSoutheastAsiaFilled16),
/* harmony export */   "EarthSoutheastAsiaFilled20": () => (/* binding */ EarthSoutheastAsiaFilled20),
/* harmony export */   "EarthSoutheastAsiaFilled24": () => (/* binding */ EarthSoutheastAsiaFilled24),
/* harmony export */   "EarthSoutheastAsiaFilled32": () => (/* binding */ EarthSoutheastAsiaFilled32),
/* harmony export */   "Earthquake16": () => (/* binding */ Earthquake16),
/* harmony export */   "Earthquake20": () => (/* binding */ Earthquake20),
/* harmony export */   "Earthquake24": () => (/* binding */ Earthquake24),
/* harmony export */   "Earthquake32": () => (/* binding */ Earthquake32),
/* harmony export */   "EdgeCluster16": () => (/* binding */ EdgeCluster16),
/* harmony export */   "EdgeCluster20": () => (/* binding */ EdgeCluster20),
/* harmony export */   "EdgeCluster24": () => (/* binding */ EdgeCluster24),
/* harmony export */   "EdgeCluster32": () => (/* binding */ EdgeCluster32),
/* harmony export */   "EdgeDevice16": () => (/* binding */ EdgeDevice16),
/* harmony export */   "EdgeDevice20": () => (/* binding */ EdgeDevice20),
/* harmony export */   "EdgeDevice24": () => (/* binding */ EdgeDevice24),
/* harmony export */   "EdgeDevice32": () => (/* binding */ EdgeDevice32),
/* harmony export */   "EdgeNode16": () => (/* binding */ EdgeNode16),
/* harmony export */   "EdgeNode20": () => (/* binding */ EdgeNode20),
/* harmony export */   "EdgeNode24": () => (/* binding */ EdgeNode24),
/* harmony export */   "EdgeNode32": () => (/* binding */ EdgeNode32),
/* harmony export */   "EdgeNodeAlt16": () => (/* binding */ EdgeNodeAlt16),
/* harmony export */   "EdgeNodeAlt20": () => (/* binding */ EdgeNodeAlt20),
/* harmony export */   "EdgeNodeAlt24": () => (/* binding */ EdgeNodeAlt24),
/* harmony export */   "EdgeNodeAlt32": () => (/* binding */ EdgeNodeAlt32),
/* harmony export */   "EdgeService16": () => (/* binding */ EdgeService16),
/* harmony export */   "EdgeService20": () => (/* binding */ EdgeService20),
/* harmony export */   "EdgeService24": () => (/* binding */ EdgeService24),
/* harmony export */   "EdgeService32": () => (/* binding */ EdgeService32),
/* harmony export */   "Edit16": () => (/* binding */ Edit16),
/* harmony export */   "Edit20": () => (/* binding */ Edit20),
/* harmony export */   "Edit24": () => (/* binding */ Edit24),
/* harmony export */   "Edit32": () => (/* binding */ Edit32),
/* harmony export */   "EditOff16": () => (/* binding */ EditOff16),
/* harmony export */   "EditOff20": () => (/* binding */ EditOff20),
/* harmony export */   "EditOff24": () => (/* binding */ EditOff24),
/* harmony export */   "EditOff32": () => (/* binding */ EditOff32),
/* harmony export */   "EdtLoop16": () => (/* binding */ EdtLoop16),
/* harmony export */   "EdtLoop20": () => (/* binding */ EdtLoop20),
/* harmony export */   "EdtLoop24": () => (/* binding */ EdtLoop24),
/* harmony export */   "EdtLoop32": () => (/* binding */ EdtLoop32),
/* harmony export */   "Education16": () => (/* binding */ Education16),
/* harmony export */   "Education20": () => (/* binding */ Education20),
/* harmony export */   "Education24": () => (/* binding */ Education24),
/* harmony export */   "Education32": () => (/* binding */ Education32),
/* harmony export */   "Email16": () => (/* binding */ Email16),
/* harmony export */   "Email20": () => (/* binding */ Email20),
/* harmony export */   "Email24": () => (/* binding */ Email24),
/* harmony export */   "Email32": () => (/* binding */ Email32),
/* harmony export */   "EmailNew16": () => (/* binding */ EmailNew16),
/* harmony export */   "EmailNew20": () => (/* binding */ EmailNew20),
/* harmony export */   "EmailNew24": () => (/* binding */ EmailNew24),
/* harmony export */   "EmailNew32": () => (/* binding */ EmailNew32),
/* harmony export */   "Encryption16": () => (/* binding */ Encryption16),
/* harmony export */   "Encryption20": () => (/* binding */ Encryption20),
/* harmony export */   "Encryption24": () => (/* binding */ Encryption24),
/* harmony export */   "Encryption32": () => (/* binding */ Encryption32),
/* harmony export */   "EnergyRenewable16": () => (/* binding */ EnergyRenewable16),
/* harmony export */   "EnergyRenewable20": () => (/* binding */ EnergyRenewable20),
/* harmony export */   "EnergyRenewable24": () => (/* binding */ EnergyRenewable24),
/* harmony export */   "EnergyRenewable32": () => (/* binding */ EnergyRenewable32),
/* harmony export */   "Enterprise16": () => (/* binding */ Enterprise16),
/* harmony export */   "Enterprise20": () => (/* binding */ Enterprise20),
/* harmony export */   "Enterprise24": () => (/* binding */ Enterprise24),
/* harmony export */   "Enterprise32": () => (/* binding */ Enterprise32),
/* harmony export */   "Equalizer16": () => (/* binding */ Equalizer16),
/* harmony export */   "Equalizer20": () => (/* binding */ Equalizer20),
/* harmony export */   "Equalizer24": () => (/* binding */ Equalizer24),
/* harmony export */   "Equalizer32": () => (/* binding */ Equalizer32),
/* harmony export */   "Erase16": () => (/* binding */ Erase16),
/* harmony export */   "Erase20": () => (/* binding */ Erase20),
/* harmony export */   "Erase24": () => (/* binding */ Erase24),
/* harmony export */   "Erase32": () => (/* binding */ Erase32),
/* harmony export */   "Error16": () => (/* binding */ Error16),
/* harmony export */   "Error20": () => (/* binding */ Error20),
/* harmony export */   "Error24": () => (/* binding */ Error24),
/* harmony export */   "Error32": () => (/* binding */ Error32),
/* harmony export */   "ErrorFilled16": () => (/* binding */ ErrorFilled16),
/* harmony export */   "ErrorFilled20": () => (/* binding */ ErrorFilled20),
/* harmony export */   "ErrorFilled24": () => (/* binding */ ErrorFilled24),
/* harmony export */   "ErrorFilled32": () => (/* binding */ ErrorFilled32),
/* harmony export */   "ErrorOutline16": () => (/* binding */ ErrorOutline16),
/* harmony export */   "ErrorOutline20": () => (/* binding */ ErrorOutline20),
/* harmony export */   "ErrorOutline24": () => (/* binding */ ErrorOutline24),
/* harmony export */   "ErrorOutline32": () => (/* binding */ ErrorOutline32),
/* harmony export */   "Event16": () => (/* binding */ Event16),
/* harmony export */   "Event20": () => (/* binding */ Event20),
/* harmony export */   "Event24": () => (/* binding */ Event24),
/* harmony export */   "Event32": () => (/* binding */ Event32),
/* harmony export */   "EventSchedule16": () => (/* binding */ EventSchedule16),
/* harmony export */   "EventSchedule20": () => (/* binding */ EventSchedule20),
/* harmony export */   "EventSchedule24": () => (/* binding */ EventSchedule24),
/* harmony export */   "EventSchedule32": () => (/* binding */ EventSchedule32),
/* harmony export */   "Events16": () => (/* binding */ Events16),
/* harmony export */   "Events20": () => (/* binding */ Events20),
/* harmony export */   "Events24": () => (/* binding */ Events24),
/* harmony export */   "Events32": () => (/* binding */ Events32),
/* harmony export */   "EventsAlt16": () => (/* binding */ EventsAlt16),
/* harmony export */   "EventsAlt20": () => (/* binding */ EventsAlt20),
/* harmony export */   "EventsAlt24": () => (/* binding */ EventsAlt24),
/* harmony export */   "EventsAlt32": () => (/* binding */ EventsAlt32),
/* harmony export */   "ExamMode16": () => (/* binding */ ExamMode16),
/* harmony export */   "ExamMode20": () => (/* binding */ ExamMode20),
/* harmony export */   "ExamMode24": () => (/* binding */ ExamMode24),
/* harmony export */   "ExamMode32": () => (/* binding */ ExamMode32),
/* harmony export */   "Exit16": () => (/* binding */ Exit16),
/* harmony export */   "Exit20": () => (/* binding */ Exit20),
/* harmony export */   "Exit24": () => (/* binding */ Exit24),
/* harmony export */   "Exit32": () => (/* binding */ Exit32),
/* harmony export */   "ExpandAll16": () => (/* binding */ ExpandAll16),
/* harmony export */   "ExpandAll20": () => (/* binding */ ExpandAll20),
/* harmony export */   "ExpandAll24": () => (/* binding */ ExpandAll24),
/* harmony export */   "ExpandAll32": () => (/* binding */ ExpandAll32),
/* harmony export */   "ExpandCategories16": () => (/* binding */ ExpandCategories16),
/* harmony export */   "ExpandCategories20": () => (/* binding */ ExpandCategories20),
/* harmony export */   "ExpandCategories24": () => (/* binding */ ExpandCategories24),
/* harmony export */   "ExpandCategories32": () => (/* binding */ ExpandCategories32),
/* harmony export */   "Explore16": () => (/* binding */ Explore16),
/* harmony export */   "Explore20": () => (/* binding */ Explore20),
/* harmony export */   "Explore24": () => (/* binding */ Explore24),
/* harmony export */   "Explore32": () => (/* binding */ Explore32),
/* harmony export */   "Export16": () => (/* binding */ Export16),
/* harmony export */   "Export20": () => (/* binding */ Export20),
/* harmony export */   "Export24": () => (/* binding */ Export24),
/* harmony export */   "Export32": () => (/* binding */ Export32),
/* harmony export */   "Eyedropper16": () => (/* binding */ Eyedropper16),
/* harmony export */   "Eyedropper20": () => (/* binding */ Eyedropper20),
/* harmony export */   "Eyedropper24": () => (/* binding */ Eyedropper24),
/* harmony export */   "Eyedropper32": () => (/* binding */ Eyedropper32),
/* harmony export */   "FaceActivated16": () => (/* binding */ FaceActivated16),
/* harmony export */   "FaceActivated20": () => (/* binding */ FaceActivated20),
/* harmony export */   "FaceActivated24": () => (/* binding */ FaceActivated24),
/* harmony export */   "FaceActivated32": () => (/* binding */ FaceActivated32),
/* harmony export */   "WatsonHealthDownloadStudy16": () => (/* binding */ WatsonHealthDownloadStudy16),
/* harmony export */   "WatsonHealthDownloadStudy20": () => (/* binding */ WatsonHealthDownloadStudy20),
/* harmony export */   "WatsonHealthEdgeEnhancement16": () => (/* binding */ WatsonHealthEdgeEnhancement16),
/* harmony export */   "WatsonHealthEdgeEnhancement20": () => (/* binding */ WatsonHealthEdgeEnhancement20),
/* harmony export */   "WatsonHealthEdgeEnhancement24": () => (/* binding */ WatsonHealthEdgeEnhancement24),
/* harmony export */   "WatsonHealthEdgeEnhancement32": () => (/* binding */ WatsonHealthEdgeEnhancement32),
/* harmony export */   "WatsonHealthEdgeEnhancement_0116": () => (/* binding */ WatsonHealthEdgeEnhancement_0116),
/* harmony export */   "WatsonHealthEdgeEnhancement_0120": () => (/* binding */ WatsonHealthEdgeEnhancement_0120),
/* harmony export */   "WatsonHealthEdgeEnhancement_0124": () => (/* binding */ WatsonHealthEdgeEnhancement_0124),
/* harmony export */   "WatsonHealthEdgeEnhancement_0132": () => (/* binding */ WatsonHealthEdgeEnhancement_0132),
/* harmony export */   "WatsonHealthEdgeEnhancement_0216": () => (/* binding */ WatsonHealthEdgeEnhancement_0216),
/* harmony export */   "WatsonHealthEdgeEnhancement_0220": () => (/* binding */ WatsonHealthEdgeEnhancement_0220),
/* harmony export */   "WatsonHealthEdgeEnhancement_0224": () => (/* binding */ WatsonHealthEdgeEnhancement_0224),
/* harmony export */   "WatsonHealthEdgeEnhancement_0232": () => (/* binding */ WatsonHealthEdgeEnhancement_0232),
/* harmony export */   "WatsonHealthEdgeEnhancement_0316": () => (/* binding */ WatsonHealthEdgeEnhancement_0316),
/* harmony export */   "WatsonHealthEdgeEnhancement_0320": () => (/* binding */ WatsonHealthEdgeEnhancement_0320),
/* harmony export */   "WatsonHealthEdgeEnhancement_0324": () => (/* binding */ WatsonHealthEdgeEnhancement_0324),
/* harmony export */   "WatsonHealthEdgeEnhancement_0332": () => (/* binding */ WatsonHealthEdgeEnhancement_0332),
/* harmony export */   "WatsonHealthEditFilter16": () => (/* binding */ WatsonHealthEditFilter16),
/* harmony export */   "WatsonHealthEditFilter20": () => (/* binding */ WatsonHealthEditFilter20),
/* harmony export */   "WatsonHealthEditFilter24": () => (/* binding */ WatsonHealthEditFilter24),
/* harmony export */   "WatsonHealthEditFilter32": () => (/* binding */ WatsonHealthEditFilter32),
/* harmony export */   "WatsonHealthErase_3D16": () => (/* binding */ WatsonHealthErase_3D16),
/* harmony export */   "WatsonHealthErase_3D20": () => (/* binding */ WatsonHealthErase_3D20),
/* harmony export */   "WatsonHealthErase_3D24": () => (/* binding */ WatsonHealthErase_3D24),
/* harmony export */   "WatsonHealthErase_3D32": () => (/* binding */ WatsonHealthErase_3D32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _circle, _path53, _circle2, _path54, _circle3, _path55, _circle4, _path56, _path57, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _path65, _path66, _path67, _path68, _path69, _path70, _path71, _path72, _path73, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _circle5, _path85, _path86, _circle6, _path87, _path88, _circle7, _path89, _path90, _circle8, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _circle9, _path101, _path102, _path103, _circle10, _path104, _path105, _path106, _circle11, _path107, _path108, _path109, _circle12, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _circle13, _circle14, _circle15, _circle16, _path210, _path211, _path212, _circle17, _circle18, _circle19, _circle20, _path213, _path214, _path215, _circle21, _circle22, _circle23, _circle24, _path216, _path217, _path218, _circle25, _circle26, _circle27, _circle28, _path219, _path220, _path221, _circle29, _circle30, _circle31, _path222, _path223, _circle32, _circle33, _circle34, _path224, _path225, _circle35, _circle36, _circle37, _path226, _path227, _circle38, _circle39, _circle40, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _circle41, _path270, _circle42, _path271, _circle43, _path272, _circle44, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var didWarnAboutDeprecation = {};
var WatsonHealthDownloadStudy20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthDownloadStudy20(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 25L28.586 23.586 26 26.172 26 18 24 18 24 26.172 21.414 23.586 20 25 25 30 30 25zM19 14H23V16H19zM19 10H26V12H19zM9 18h6a3 3 0 013 3v2H16V21a1 1 0 00-1-1H9a1 1 0 00-1 1v2H6V21A3 3 0 019 18zM16 13a4 4 0 10-4 4A4 4 0 0016 13zm-2 0a2 2 0 11-2-2A2 2 0 0114 13z"
  })), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,26H4V6H28V16h2V6a2,2,0,0,0-2-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H18Z"
  })), children);
});
var WatsonHealthDownloadStudy16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthDownloadStudy16(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 25L28.586 23.586 26 26.172 26 18 24 18 24 26.172 21.414 23.586 20 25 25 30 30 25zM19 14H23V16H19zM19 10H26V12H19zM9 18h6a3 3 0 013 3v2H16V21a1 1 0 00-1-1H9a1 1 0 00-1 1v2H6V21A3 3 0 019 18zM16 13a4 4 0 10-4 4A4 4 0 0016 13zm-2 0a2 2 0 11-2-2A2 2 0 0114 13z"
  })), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,26H4V6H28V16h2V6a2,2,0,0,0-2-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H18Z"
  })), children);
});
var DragHorizontal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DragHorizontal32(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 4L12 15 5.83 15 8.41 12.41 7 11 2 16 7 21 8.41 19.59 5.83 17 12 17 12 28 14 28 14 4 12 4zM25 11L23.59 12.41 26.17 15 20 15 20 4 18 4 18 28 20 28 20 17 26.17 17 23.59 19.59 25 21 30 16 25 11z"
  })), children);
});
var DragHorizontal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DragHorizontal24(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 4L12 15 5.83 15 8.41 12.41 7 11 2 16 7 21 8.41 19.59 5.83 17 12 17 12 28 14 28 14 4 12 4zM25 11L23.59 12.41 26.17 15 20 15 20 4 18 4 18 28 20 28 20 17 26.17 17 23.59 19.59 25 21 30 16 25 11z"
  })), children);
});
var DragHorizontal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DragHorizontal20(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 4L12 15 5.83 15 8.41 12.41 7 11 2 16 7 21 8.41 19.59 5.83 17 12 17 12 28 14 28 14 4 12 4zM25 11L23.59 12.41 26.17 15 20 15 20 4 18 4 18 28 20 28 20 17 26.17 17 23.59 19.59 25 21 30 16 25 11z"
  })), children);
});
var DragHorizontal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DragHorizontal16(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 4L12 15 5.83 15 8.41 12.41 7 11 2 16 7 21 8.41 19.59 5.83 17 12 17 12 28 14 28 14 4 12 4zM25 11L23.59 12.41 26.17 15 20 15 20 4 18 4 18 28 20 28 20 17 26.17 17 23.59 19.59 25 21 30 16 25 11z"
  })), children);
});
var DragVertical32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DragVertical32(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L15 20 15 26.17 12.41 23.59 11 25 16 30 21 25 19.59 23.59 17 26.17 17 20 28 20 28 18 4 18 4 20zM11 7L12.41 8.41 15 5.83 15 12 4 12 4 14 28 14 28 12 17 12 17 5.83 19.59 8.41 21 7 16 2 11 7z"
  })), children);
});
var DragVertical24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DragVertical24(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L15 20 15 26.17 12.41 23.59 11 25 16 30 21 25 19.59 23.59 17 26.17 17 20 28 20 28 18 4 18 4 20zM11 7L12.41 8.41 15 5.83 15 12 4 12 4 14 28 14 28 12 17 12 17 5.83 19.59 8.41 21 7 16 2 11 7z"
  })), children);
});
var DragVertical20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DragVertical20(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L15 20 15 26.17 12.41 23.59 11 25 16 30 21 25 19.59 23.59 17 26.17 17 20 28 20 28 18 4 18 4 20zM11 7L12.41 8.41 15 5.83 15 12 4 12 4 14 28 14 28 12 17 12 17 5.83 19.59 8.41 21 7 16 2 11 7z"
  })), children);
});
var DragVertical16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DragVertical16(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L15 20 15 26.17 12.41 23.59 11 25 16 30 21 25 19.59 23.59 17 26.17 17 20 28 20 28 18 4 18 4 20zM11 7L12.41 8.41 15 5.83 15 12 4 12 4 14 28 14 28 12 17 12 17 5.83 19.59 8.41 21 7 16 2 11 7z"
  })), children);
});
var Draggable32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Draggable32(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6H14V10H10zM18 6H22V10H18zM10 14H14V18H10zM18 14H22V18H18zM10 22H14V26H10zM18 22H22V26H18z"
  })), children);
});
var Draggable24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Draggable24(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6H14V10H10zM18 6H22V10H18zM10 14H14V18H10zM18 14H22V18H18zM10 22H14V26H10zM18 22H22V26H18z"
  })), children);
});
var Draggable20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Draggable20(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6H14V10H10zM18 6H22V10H18zM10 14H14V18H10zM18 14H22V18H18zM10 22H14V26H10zM18 22H22V26H18z"
  })), children);
});
var Draggable16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Draggable16(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6H14V10H10zM18 6H22V10H18zM10 14H14V18H10zM18 14H22V18H18zM10 22H14V26H10zM18 22H22V26H18z"
  })), children);
});
var Draw32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Draw32(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.14,28a3.42,3.42,0,0,1-2.42-5.85L21.86,17a1.42,1.42,0,1,0-2-2L13,21.85a3.5,3.5,0,0,1-4.85,0,3.43,3.43,0,0,1,0-4.84l8.58-8.58a1.42,1.42,0,1,0-2-2L6.41,14.7,5,13.3,13.29,5a3.43,3.43,0,0,1,4.84,4.85L9.56,18.42a1.42,1.42,0,0,0,0,2,1.45,1.45,0,0,0,2,0l6.86-6.86a3.43,3.43,0,1,1,4.85,4.84l-5.15,5.15a1.42,1.42,0,0,0,2,2l4.44-4.43L26,22.56,21.56,27A3.38,3.38,0,0,1,19.14,28Z"
  })), children);
});
var Draw24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Draw24(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.14,28a3.42,3.42,0,0,1-2.42-5.85L21.86,17a1.42,1.42,0,1,0-2-2L13,21.85a3.5,3.5,0,0,1-4.85,0,3.43,3.43,0,0,1,0-4.84l8.58-8.58a1.42,1.42,0,1,0-2-2L6.41,14.7,5,13.3,13.29,5a3.43,3.43,0,0,1,4.84,4.85L9.56,18.42a1.42,1.42,0,0,0,0,2,1.45,1.45,0,0,0,2,0l6.86-6.86a3.43,3.43,0,1,1,4.85,4.84l-5.15,5.15a1.42,1.42,0,0,0,2,2l4.44-4.43L26,22.56,21.56,27A3.38,3.38,0,0,1,19.14,28Z"
  })), children);
});
var Draw20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Draw20(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.14,28a3.42,3.42,0,0,1-2.42-5.85L21.86,17a1.42,1.42,0,1,0-2-2L13,21.85a3.5,3.5,0,0,1-4.85,0,3.43,3.43,0,0,1,0-4.84l8.58-8.58a1.42,1.42,0,1,0-2-2L6.41,14.7,5,13.3,13.29,5a3.43,3.43,0,0,1,4.84,4.85L9.56,18.42a1.42,1.42,0,0,0,0,2,1.45,1.45,0,0,0,2,0l6.86-6.86a3.43,3.43,0,1,1,4.85,4.84l-5.15,5.15a1.42,1.42,0,0,0,2,2l4.44-4.43L26,22.56,21.56,27A3.38,3.38,0,0,1,19.14,28Z"
  })), children);
});
var Draw16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Draw16(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.14,28a3.42,3.42,0,0,1-2.42-5.85L21.86,17a1.42,1.42,0,1,0-2-2L13,21.85a3.5,3.5,0,0,1-4.85,0,3.43,3.43,0,0,1,0-4.84l8.58-8.58a1.42,1.42,0,1,0-2-2L6.41,14.7,5,13.3,13.29,5a3.43,3.43,0,0,1,4.84,4.85L9.56,18.42a1.42,1.42,0,0,0,0,2,1.45,1.45,0,0,0,2,0l6.86-6.86a3.43,3.43,0,1,1,4.85,4.84l-5.15,5.15a1.42,1.42,0,0,0,2,2l4.44-4.43L26,22.56,21.56,27A3.38,3.38,0,0,1,19.14,28Z"
  })), children);
});
var DrillBack32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DrillBack32(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 22L7.414 20.586 3.828 17 12 17 12 15 3.828 15 7.414 11.414 6 10 0 16 6 22z"
  })), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a5.9815,5.9815,0,0,0-4.2427,1.7573L16,16l-4.2427,4.2427A6,6,0,1,0,16,10Z"
  })), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9581,13.9581,0,0,0,6.105,6.105L7.5188,7.5186a12,12,0,1,1,0,16.9628L6.105,25.895A13.9974,13.9974,0,1,0,16,2Z"
  })), children);
});
var DrillBack24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DrillBack24(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 22L7.414 20.586 3.828 17 12 17 12 15 3.828 15 7.414 11.414 6 10 0 16 6 22z"
  })), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a5.9815,5.9815,0,0,0-4.2427,1.7573L16,16l-4.2427,4.2427A6,6,0,1,0,16,10Z"
  })), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9581,13.9581,0,0,0,6.105,6.105L7.5188,7.5186a12,12,0,1,1,0,16.9628L6.105,25.895A13.9974,13.9974,0,1,0,16,2Z"
  })), children);
});
var DrillBack20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DrillBack20(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 22L7.414 20.586 3.828 17 12 17 12 15 3.828 15 7.414 11.414 6 10 0 16 6 22z"
  })), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a5.9815,5.9815,0,0,0-4.2427,1.7573L16,16l-4.2427,4.2427A6,6,0,1,0,16,10Z"
  })), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9581,13.9581,0,0,0,6.105,6.105L7.5188,7.5186a12,12,0,1,1,0,16.9628L6.105,25.895A13.9974,13.9974,0,1,0,16,2Z"
  })), children);
});
var DrillBack16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DrillBack16(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 22L7.414 20.586 3.828 17 12 17 12 15 3.828 15 7.414 11.414 6 10 0 16 6 22z"
  })), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a5.9815,5.9815,0,0,0-4.2427,1.7573L16,16l-4.2427,4.2427A6,6,0,1,0,16,10Z"
  })), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9581,13.9581,0,0,0,6.105,6.105L7.5188,7.5186a12,12,0,1,1,0,16.9628L6.105,25.895A13.9974,13.9974,0,1,0,16,2Z"
  })), children);
});
var DrillDown32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DrillDown32(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6L11.414 4.586 15 8.172 15 0 17 0 17 8.172 20.586 4.586 22 6 16 12 10 6z"
  })), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,16a5.9815,5.9815,0,0,0-1.7573-4.2427L16,16l-4.2427-4.2427A6,6,0,1,0,22,16Z"
  })), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16a13.9581,13.9581,0,0,0-4.105-9.895L24.4814,7.5188a12,12,0,1,1-16.9628,0L6.105,6.105A13.9974,13.9974,0,1,0,30,16Z"
  })), children);
});
var DrillDown24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DrillDown24(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6L11.414 4.586 15 8.172 15 0 17 0 17 8.172 20.586 4.586 22 6 16 12 10 6z"
  })), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,16a5.9815,5.9815,0,0,0-1.7573-4.2427L16,16l-4.2427-4.2427A6,6,0,1,0,22,16Z"
  })), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16a13.9581,13.9581,0,0,0-4.105-9.895L24.4814,7.5188a12,12,0,1,1-16.9628,0L6.105,6.105A13.9974,13.9974,0,1,0,30,16Z"
  })), children);
});
var DrillDown20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DrillDown20(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6L11.414 4.586 15 8.172 15 0 17 0 17 8.172 20.586 4.586 22 6 16 12 10 6z"
  })), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,16a5.9815,5.9815,0,0,0-1.7573-4.2427L16,16l-4.2427-4.2427A6,6,0,1,0,22,16Z"
  })), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16a13.9581,13.9581,0,0,0-4.105-9.895L24.4814,7.5188a12,12,0,1,1-16.9628,0L6.105,6.105A13.9974,13.9974,0,1,0,30,16Z"
  })), children);
});
var DrillDown16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DrillDown16(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6L11.414 4.586 15 8.172 15 0 17 0 17 8.172 20.586 4.586 22 6 16 12 10 6z"
  })), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,16a5.9815,5.9815,0,0,0-1.7573-4.2427L16,16l-4.2427-4.2427A6,6,0,1,0,22,16Z"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16a13.9581,13.9581,0,0,0-4.105-9.895L24.4814,7.5188a12,12,0,1,1-16.9628,0L6.105,6.105A13.9974,13.9974,0,1,0,30,16Z"
  })), children);
});
var DrillThrough32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DrillThrough32(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14.0158,14.0158,0,0,1,2,16H4A12,12,0,1,0,16,4V2a14,14,0,0,1,0,28Z"
  })), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 12L4 10 8.586 10 2 3.414 3.414 2 10 8.586 10 4 12 4 12 12 4 12zM16 10v6H10a6 6 0 106-6z"
  })), children);
});
var DrillThrough24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DrillThrough24(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14.0158,14.0158,0,0,1,2,16H4A12,12,0,1,0,16,4V2a14,14,0,0,1,0,28Z"
  })), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 12L4 10 8.586 10 2 3.414 3.414 2 10 8.586 10 4 12 4 12 12 4 12zM16 10v6H10a6 6 0 106-6z"
  })), children);
});
var DrillThrough20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DrillThrough20(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14.0158,14.0158,0,0,1,2,16H4A12,12,0,1,0,16,4V2a14,14,0,0,1,0,28Z"
  })), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 12L4 10 8.586 10 2 3.414 3.414 2 10 8.586 10 4 12 4 12 12 4 12zM16 10v6H10a6 6 0 106-6z"
  })), children);
});
var DrillThrough16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DrillThrough16(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14.0158,14.0158,0,0,1,2,16H4A12,12,0,1,0,16,4V2a14,14,0,0,1,0,28Z"
  })), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 12L4 10 8.586 10 2 3.414 3.414 2 10 8.586 10 4 12 4 12 12 4 12zM16 10v6H10a6 6 0 106-6z"
  })), children);
});
var DriverAnalysis32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DriverAnalysis32(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "16",
    r: "2"
  })), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H27.91A6.0048,6.0048,0,0,0,22,10l-.022.001A9.9833,9.9833,0,0,0,4.0508,15H2v2H4.0508A9.9833,9.9833,0,0,0,21.978,21.999L22,22a6.0048,6.0048,0,0,0,5.91-5H30ZM14,8a7.9769,7.9769,0,0,1,5.7383,2.4463A6.0152,6.0152,0,0,0,16.0891,15H6.0693A8.0073,8.0073,0,0,1,14,8Zm0,16a8.0073,8.0073,0,0,1-7.9307-7h10.02a6.0152,6.0152,0,0,0,3.6492,4.5537A7.9769,7.9769,0,0,1,14,24Zm8-4a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,22,20Z"
  })), children);
});
var DriverAnalysis24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DriverAnalysis24(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "16",
    r: "2"
  })), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H27.91A6.0048,6.0048,0,0,0,22,10l-.022.001A9.9833,9.9833,0,0,0,4.0508,15H2v2H4.0508A9.9833,9.9833,0,0,0,21.978,21.999L22,22a6.0048,6.0048,0,0,0,5.91-5H30ZM14,8a7.9769,7.9769,0,0,1,5.7383,2.4463A6.0152,6.0152,0,0,0,16.0891,15H6.0693A8.0073,8.0073,0,0,1,14,8Zm0,16a8.0073,8.0073,0,0,1-7.9307-7h10.02a6.0152,6.0152,0,0,0,3.6492,4.5537A7.9769,7.9769,0,0,1,14,24Zm8-4a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,22,20Z"
  })), children);
});
var DriverAnalysis20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DriverAnalysis20(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "16",
    r: "2"
  })), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H27.91A6.0048,6.0048,0,0,0,22,10l-.022.001A9.9833,9.9833,0,0,0,4.0508,15H2v2H4.0508A9.9833,9.9833,0,0,0,21.978,21.999L22,22a6.0048,6.0048,0,0,0,5.91-5H30ZM14,8a7.9769,7.9769,0,0,1,5.7383,2.4463A6.0152,6.0152,0,0,0,16.0891,15H6.0693A8.0073,8.0073,0,0,1,14,8Zm0,16a8.0073,8.0073,0,0,1-7.9307-7h10.02a6.0152,6.0152,0,0,0,3.6492,4.5537A7.9769,7.9769,0,0,1,14,24Zm8-4a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,22,20Z"
  })), children);
});
var DriverAnalysis16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DriverAnalysis16(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "16",
    r: "2"
  })), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H27.91A6.0048,6.0048,0,0,0,22,10l-.022.001A9.9833,9.9833,0,0,0,4.0508,15H2v2H4.0508A9.9833,9.9833,0,0,0,21.978,21.999L22,22a6.0048,6.0048,0,0,0,5.91-5H30ZM14,8a7.9769,7.9769,0,0,1,5.7383,2.4463A6.0152,6.0152,0,0,0,16.0891,15H6.0693A8.0073,8.0073,0,0,1,14,8Zm0,16a8.0073,8.0073,0,0,1-7.9307-7h10.02a6.0152,6.0152,0,0,0,3.6492,4.5537A7.9769,7.9769,0,0,1,14,24Zm8-4a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,22,20Z"
  })), children);
});
var Drone32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Drone32(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 12a5 5 0 115-5H10a3 3 0 10-3 3zM25 12V10a3 3 0 10-3-3H20a5 5 0 115 5zM7 30A5 5 0 017 20v2a3 3 0 103 3h2A5.0055 5.0055 0 017 30zM25 30a5.0055 5.0055 0 01-5-5h2a3 3 0 103-3V20a5 5 0 010 10z"
  })), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,18.5859V13.4141L25.707,7.707a1,1,0,1,0-1.414-1.414l-4.4995,4.5a3.9729,3.9729,0,0,0-7.587,0L7.707,6.293a.9994.9994,0,0,0-1.414,0h0a.9994.9994,0,0,0,0,1.414L12,13.4141v5.1718L6.293,24.293a.9994.9994,0,0,0,0,1.414h0a.9994.9994,0,0,0,1.414,0l4.5-4.5a3.9729,3.9729,0,0,0,7.587,0l4.4995,4.5a1,1,0,0,0,1.414-1.414ZM18,20a2,2,0,0,1-4,0V12a2,2,0,0,1,4,0Z"
  })), children);
});
var Drone24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Drone24(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 12a5 5 0 115-5H10a3 3 0 10-3 3zM25 12V10a3 3 0 10-3-3H20a5 5 0 115 5zM7 30A5 5 0 017 20v2a3 3 0 103 3h2A5.0055 5.0055 0 017 30zM25 30a5.0055 5.0055 0 01-5-5h2a3 3 0 103-3V20a5 5 0 010 10z"
  })), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,18.5859V13.4141L25.707,7.707a1,1,0,1,0-1.414-1.414l-4.4995,4.5a3.9729,3.9729,0,0,0-7.587,0L7.707,6.293a.9994.9994,0,0,0-1.414,0h0a.9994.9994,0,0,0,0,1.414L12,13.4141v5.1718L6.293,24.293a.9994.9994,0,0,0,0,1.414h0a.9994.9994,0,0,0,1.414,0l4.5-4.5a3.9729,3.9729,0,0,0,7.587,0l4.4995,4.5a1,1,0,0,0,1.414-1.414ZM18,20a2,2,0,0,1-4,0V12a2,2,0,0,1,4,0Z"
  })), children);
});
var Drone20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Drone20(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 12a5 5 0 115-5H10a3 3 0 10-3 3zM25 12V10a3 3 0 10-3-3H20a5 5 0 115 5zM7 30A5 5 0 017 20v2a3 3 0 103 3h2A5.0055 5.0055 0 017 30zM25 30a5.0055 5.0055 0 01-5-5h2a3 3 0 103-3V20a5 5 0 010 10z"
  })), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,18.5859V13.4141L25.707,7.707a1,1,0,1,0-1.414-1.414l-4.4995,4.5a3.9729,3.9729,0,0,0-7.587,0L7.707,6.293a.9994.9994,0,0,0-1.414,0h0a.9994.9994,0,0,0,0,1.414L12,13.4141v5.1718L6.293,24.293a.9994.9994,0,0,0,0,1.414h0a.9994.9994,0,0,0,1.414,0l4.5-4.5a3.9729,3.9729,0,0,0,7.587,0l4.4995,4.5a1,1,0,0,0,1.414-1.414ZM18,20a2,2,0,0,1-4,0V12a2,2,0,0,1,4,0Z"
  })), children);
});
var Drone16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Drone16(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 12a5 5 0 115-5H10a3 3 0 10-3 3zM25 12V10a3 3 0 10-3-3H20a5 5 0 115 5zM7 30A5 5 0 017 20v2a3 3 0 103 3h2A5.0055 5.0055 0 017 30zM25 30a5.0055 5.0055 0 01-5-5h2a3 3 0 103-3V20a5 5 0 010 10z"
  })), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,18.5859V13.4141L25.707,7.707a1,1,0,1,0-1.414-1.414l-4.4995,4.5a3.9729,3.9729,0,0,0-7.587,0L7.707,6.293a.9994.9994,0,0,0-1.414,0h0a.9994.9994,0,0,0,0,1.414L12,13.4141v5.1718L6.293,24.293a.9994.9994,0,0,0,0,1.414h0a.9994.9994,0,0,0,1.414,0l4.5-4.5a3.9729,3.9729,0,0,0,7.587,0l4.4995,4.5a1,1,0,0,0,1.414-1.414ZM18,20a2,2,0,0,1-4,0V12a2,2,0,0,1,4,0Z"
  })), children);
});
var DroneDelivery32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DroneDelivery32(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,30H12V22h8Zm-6-2h4V24H14Z"
  })), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32 11L22 11 22 13 26 13 26 16 6 16 6 13 10 13 10 11 0 11 0 13 4 13 4 18 9.132 18 6 22.697 6 27 8 27 8 23.303 11.535 18 20.465 18 24 23.303 24 27 26 27 26 22.697 22.868 18 28 18 28 13 32 13 32 11zM16 6a5.9817 5.9817 0 00-4.2407 1.7593l1.4136 1.4136a3.9936 3.9936 0 015.6542 0l1.4136-1.4136A5.9814 5.9814 0 0016 6z"
  })), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9324,4.9321l1.4133,1.4136a7.9877,7.9877,0,0,1,11.3086,0l1.4136-1.4136a9.9844,9.9844,0,0,0-14.1355,0Z"
  })), children);
});
var DroneDelivery24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DroneDelivery24(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,30H12V22h8Zm-6-2h4V24H14Z"
  })), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32 11L22 11 22 13 26 13 26 16 6 16 6 13 10 13 10 11 0 11 0 13 4 13 4 18 9.132 18 6 22.697 6 27 8 27 8 23.303 11.535 18 20.465 18 24 23.303 24 27 26 27 26 22.697 22.868 18 28 18 28 13 32 13 32 11zM16 6a5.9817 5.9817 0 00-4.2407 1.7593l1.4136 1.4136a3.9936 3.9936 0 015.6542 0l1.4136-1.4136A5.9814 5.9814 0 0016 6z"
  })), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9324,4.9321l1.4133,1.4136a7.9877,7.9877,0,0,1,11.3086,0l1.4136-1.4136a9.9844,9.9844,0,0,0-14.1355,0Z"
  })), children);
});
var DroneDelivery20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DroneDelivery20(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,30H12V22h8Zm-6-2h4V24H14Z"
  })), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32 11L22 11 22 13 26 13 26 16 6 16 6 13 10 13 10 11 0 11 0 13 4 13 4 18 9.132 18 6 22.697 6 27 8 27 8 23.303 11.535 18 20.465 18 24 23.303 24 27 26 27 26 22.697 22.868 18 28 18 28 13 32 13 32 11zM16 6a5.9817 5.9817 0 00-4.2407 1.7593l1.4136 1.4136a3.9936 3.9936 0 015.6542 0l1.4136-1.4136A5.9814 5.9814 0 0016 6z"
  })), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9324,4.9321l1.4133,1.4136a7.9877,7.9877,0,0,1,11.3086,0l1.4136-1.4136a9.9844,9.9844,0,0,0-14.1355,0Z"
  })), children);
});
var DroneDelivery16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DroneDelivery16(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,30H12V22h8Zm-6-2h4V24H14Z"
  })), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32 11L22 11 22 13 26 13 26 16 6 16 6 13 10 13 10 11 0 11 0 13 4 13 4 18 9.132 18 6 22.697 6 27 8 27 8 23.303 11.535 18 20.465 18 24 23.303 24 27 26 27 26 22.697 22.868 18 28 18 28 13 32 13 32 11zM16 6a5.9817 5.9817 0 00-4.2407 1.7593l1.4136 1.4136a3.9936 3.9936 0 015.6542 0l1.4136-1.4136A5.9814 5.9814 0 0016 6z"
  })), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9324,4.9321l1.4133,1.4136a7.9877,7.9877,0,0,1,11.3086,0l1.4136-1.4136a9.9844,9.9844,0,0,0-14.1355,0Z"
  })), children);
});
var DroneFront32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DroneFront32(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 19V15H26v2H6V15H4v4h7v4.4116L7 25.6367V30H9V26.8125L12.26 25h7.481L23 26.8125V30h2V25.6367l-4-2.2251V19zm-9 4H13V19h6zM0 11H10V13H0zM22 11H32V13H22zM16 6a5.9817 5.9817 0 00-4.2407 1.7593l1.4136 1.4136a3.9936 3.9936 0 015.6542 0l1.4136-1.4136A5.9814 5.9814 0 0016 6z"
  })), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9324,4.9321l1.4133,1.4136a7.9877,7.9877,0,0,1,11.3086,0l1.4136-1.4136a9.9844,9.9844,0,0,0-14.1355,0Z"
  })), children);
});
var DroneFront24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DroneFront24(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 19V15H26v2H6V15H4v4h7v4.4116L7 25.6367V30H9V26.8125L12.26 25h7.481L23 26.8125V30h2V25.6367l-4-2.2251V19zm-9 4H13V19h6zM0 11H10V13H0zM22 11H32V13H22zM16 6a5.9817 5.9817 0 00-4.2407 1.7593l1.4136 1.4136a3.9936 3.9936 0 015.6542 0l1.4136-1.4136A5.9814 5.9814 0 0016 6z"
  })), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9324,4.9321l1.4133,1.4136a7.9877,7.9877,0,0,1,11.3086,0l1.4136-1.4136a9.9844,9.9844,0,0,0-14.1355,0Z"
  })), children);
});
var DroneFront20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DroneFront20(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 19V15H26v2H6V15H4v4h7v4.4116L7 25.6367V30H9V26.8125L12.26 25h7.481L23 26.8125V30h2V25.6367l-4-2.2251V19zm-9 4H13V19h6zM0 11H10V13H0zM22 11H32V13H22zM16 6a5.9817 5.9817 0 00-4.2407 1.7593l1.4136 1.4136a3.9936 3.9936 0 015.6542 0l1.4136-1.4136A5.9814 5.9814 0 0016 6z"
  })), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9324,4.9321l1.4133,1.4136a7.9877,7.9877,0,0,1,11.3086,0l1.4136-1.4136a9.9844,9.9844,0,0,0-14.1355,0Z"
  })), children);
});
var DroneFront16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DroneFront16(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 19V15H26v2H6V15H4v4h7v4.4116L7 25.6367V30H9V26.8125L12.26 25h7.481L23 26.8125V30h2V25.6367l-4-2.2251V19zm-9 4H13V19h6zM0 11H10V13H0zM22 11H32V13H22zM16 6a5.9817 5.9817 0 00-4.2407 1.7593l1.4136 1.4136a3.9936 3.9936 0 015.6542 0l1.4136-1.4136A5.9814 5.9814 0 0016 6z"
  })), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9324,4.9321l1.4133,1.4136a7.9877,7.9877,0,0,1,11.3086,0l1.4136-1.4136a9.9844,9.9844,0,0,0-14.1355,0Z"
  })), children);
});
var DroneVideo32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DroneVideo32(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "21",
    r: "1"
  })), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 19V15H26v2H6V15H4v4h7v4.4116L7 25.6367V30H9V26.8125L12.26 25h7.481L23 26.8125V30h2V25.6367l-4-2.2251V19zm-9 4H13V19h6zM0 11H10V13H0zM22 11H32V13H22zM16 6a5.9817 5.9817 0 00-4.2407 1.7593l1.4136 1.4136a3.9936 3.9936 0 015.6542 0l1.4136-1.4136A5.9814 5.9814 0 0016 6z"
  })), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9324,4.9321l1.4133,1.4136a7.9877,7.9877,0,0,1,11.3086,0l1.4136-1.4136a9.9844,9.9844,0,0,0-14.1355,0Z"
  })), children);
});
var DroneVideo24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DroneVideo24(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "21",
    r: "1"
  })), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 19V15H26v2H6V15H4v4h7v4.4116L7 25.6367V30H9V26.8125L12.26 25h7.481L23 26.8125V30h2V25.6367l-4-2.2251V19zm-9 4H13V19h6zM0 11H10V13H0zM22 11H32V13H22zM16 6a5.9817 5.9817 0 00-4.2407 1.7593l1.4136 1.4136a3.9936 3.9936 0 015.6542 0l1.4136-1.4136A5.9814 5.9814 0 0016 6z"
  })), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9324,4.9321l1.4133,1.4136a7.9877,7.9877,0,0,1,11.3086,0l1.4136-1.4136a9.9844,9.9844,0,0,0-14.1355,0Z"
  })), children);
});
var DroneVideo20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DroneVideo20(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "21",
    r: "1"
  })), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 19V15H26v2H6V15H4v4h7v4.4116L7 25.6367V30H9V26.8125L12.26 25h7.481L23 26.8125V30h2V25.6367l-4-2.2251V19zm-9 4H13V19h6zM0 11H10V13H0zM22 11H32V13H22zM16 6a5.9817 5.9817 0 00-4.2407 1.7593l1.4136 1.4136a3.9936 3.9936 0 015.6542 0l1.4136-1.4136A5.9814 5.9814 0 0016 6z"
  })), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9324,4.9321l1.4133,1.4136a7.9877,7.9877,0,0,1,11.3086,0l1.4136-1.4136a9.9844,9.9844,0,0,0-14.1355,0Z"
  })), children);
});
var DroneVideo16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DroneVideo16(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "21",
    r: "1"
  })), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 19V15H26v2H6V15H4v4h7v4.4116L7 25.6367V30H9V26.8125L12.26 25h7.481L23 26.8125V30h2V25.6367l-4-2.2251V19zm-9 4H13V19h6zM0 11H10V13H0zM22 11H32V13H22zM16 6a5.9817 5.9817 0 00-4.2407 1.7593l1.4136 1.4136a3.9936 3.9936 0 015.6542 0l1.4136-1.4136A5.9814 5.9814 0 0016 6z"
  })), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9324,4.9321l1.4133,1.4136a7.9877,7.9877,0,0,1,11.3086,0l1.4136-1.4136a9.9844,9.9844,0,0,0-14.1355,0Z"
  })), children);
});
var DropPhoto32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DropPhoto32(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,26a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,19,26Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,19,20Z"
  })), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 29H11a2 2 0 01-2-2V18a2 2 0 012-2h3.2793l.5441-1.6324A2 2 0 0116.7208 13h4.5584a2 2 0 011.8974 1.3676L23.7207 16H27a2 2 0 012 2v9A2 2 0 0127 29zM11 27H27V18H22.2792l-1-3H16.7207l-1 3H11zM27 11H29V13H27zM27 7H29V9H27zM27 3H29V5H27zM23 3H25V5H23zM19 3H21V5H19zM15 3H17V5H15zM11 3H13V5H11zM7 3H9V5H7zM3 3H5V5H3zM3 7H5V9H3zM3 11H5V13H3zM3 15H5V17H3zM3 19H5V21H3zM3 23H5V25H3zM3 27H5V29H3z"
  })), children);
});
var DropPhoto24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DropPhoto24(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,26a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,19,26Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,19,20Z"
  })), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 29H11a2 2 0 01-2-2V18a2 2 0 012-2h3.2793l.5441-1.6324A2 2 0 0116.7208 13h4.5584a2 2 0 011.8974 1.3676L23.7207 16H27a2 2 0 012 2v9A2 2 0 0127 29zM11 27H27V18H22.2792l-1-3H16.7207l-1 3H11zM27 11H29V13H27zM27 7H29V9H27zM27 3H29V5H27zM23 3H25V5H23zM19 3H21V5H19zM15 3H17V5H15zM11 3H13V5H11zM7 3H9V5H7zM3 3H5V5H3zM3 7H5V9H3zM3 11H5V13H3zM3 15H5V17H3zM3 19H5V21H3zM3 23H5V25H3zM3 27H5V29H3z"
  })), children);
});
var DropPhoto20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DropPhoto20(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,26a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,19,26Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,19,20Z"
  })), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 29H11a2 2 0 01-2-2V18a2 2 0 012-2h3.2793l.5441-1.6324A2 2 0 0116.7208 13h4.5584a2 2 0 011.8974 1.3676L23.7207 16H27a2 2 0 012 2v9A2 2 0 0127 29zM11 27H27V18H22.2792l-1-3H16.7207l-1 3H11zM27 11H29V13H27zM27 7H29V9H27zM27 3H29V5H27zM23 3H25V5H23zM19 3H21V5H19zM15 3H17V5H15zM11 3H13V5H11zM7 3H9V5H7zM3 3H5V5H3zM3 7H5V9H3zM3 11H5V13H3zM3 15H5V17H3zM3 19H5V21H3zM3 23H5V25H3zM3 27H5V29H3z"
  })), children);
});
var DropPhoto16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DropPhoto16(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,26a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,19,26Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,19,20Z"
  })), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 29H11a2 2 0 01-2-2V18a2 2 0 012-2h3.2793l.5441-1.6324A2 2 0 0116.7208 13h4.5584a2 2 0 011.8974 1.3676L23.7207 16H27a2 2 0 012 2v9A2 2 0 0127 29zM11 27H27V18H22.2792l-1-3H16.7207l-1 3H11zM27 11H29V13H27zM27 7H29V9H27zM27 3H29V5H27zM23 3H25V5H23zM19 3H21V5H19zM15 3H17V5H15zM11 3H13V5H11zM7 3H9V5H7zM3 3H5V5H3zM3 7H5V9H3zM3 11H5V13H3zM3 15H5V17H3zM3 19H5V21H3zM3 23H5V25H3zM3 27H5V29H3z"
  })), children);
});
var DropPhotoFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DropPhotoFilled32(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "19",
    cy: "22",
    r: "2"
  })), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,16H23.7207l-.5439-1.6328A1.9983,1.9983,0,0,0,21.2793,13H16.7207a1.9981,1.9981,0,0,0-1.8975,1.3677L14.2793,16H11a2.0023,2.0023,0,0,0-2,2v9a2.0023,2.0023,0,0,0,2,2H27a2.0023,2.0023,0,0,0,2-2V18A2.0023,2.0023,0,0,0,27,16ZM19,26a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,19,26Z"
  })), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M19,26a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,19,26Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,19,20Z",
    "data-icon-path": "inner-path"
  })), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 11H29V13H27zM27 7H29V9H27zM27 3H29V5H27zM23 3H25V5H23zM19 3H21V5H19zM15 3H17V5H15zM11 3H13V5H11zM7 3H9V5H7zM3 3H5V5H3zM3 7H5V9H3zM3 11H5V13H3zM3 15H5V17H3zM3 19H5V21H3zM3 23H5V25H3zM3 27H5V29H3z"
  })), children);
});
var DropPhotoFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DropPhotoFilled24(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "19",
    cy: "22",
    r: "2"
  })), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,16H23.7207l-.5439-1.6328A1.9983,1.9983,0,0,0,21.2793,13H16.7207a1.9981,1.9981,0,0,0-1.8975,1.3677L14.2793,16H11a2.0023,2.0023,0,0,0-2,2v9a2.0023,2.0023,0,0,0,2,2H27a2.0023,2.0023,0,0,0,2-2V18A2.0023,2.0023,0,0,0,27,16ZM19,26a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,19,26Z"
  })), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M19,26a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,19,26Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,19,20Z",
    "data-icon-path": "inner-path"
  })), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 11H29V13H27zM27 7H29V9H27zM27 3H29V5H27zM23 3H25V5H23zM19 3H21V5H19zM15 3H17V5H15zM11 3H13V5H11zM7 3H9V5H7zM3 3H5V5H3zM3 7H5V9H3zM3 11H5V13H3zM3 15H5V17H3zM3 19H5V21H3zM3 23H5V25H3zM3 27H5V29H3z"
  })), children);
});
var DropPhotoFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DropPhotoFilled20(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "19",
    cy: "22",
    r: "2"
  })), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,16H23.7207l-.5439-1.6328A1.9983,1.9983,0,0,0,21.2793,13H16.7207a1.9981,1.9981,0,0,0-1.8975,1.3677L14.2793,16H11a2.0023,2.0023,0,0,0-2,2v9a2.0023,2.0023,0,0,0,2,2H27a2.0023,2.0023,0,0,0,2-2V18A2.0023,2.0023,0,0,0,27,16ZM19,26a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,19,26Z"
  })), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M19,26a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,19,26Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,19,20Z",
    "data-icon-path": "inner-path"
  })), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 11H29V13H27zM27 7H29V9H27zM27 3H29V5H27zM23 3H25V5H23zM19 3H21V5H19zM15 3H17V5H15zM11 3H13V5H11zM7 3H9V5H7zM3 3H5V5H3zM3 7H5V9H3zM3 11H5V13H3zM3 15H5V17H3zM3 19H5V21H3zM3 23H5V25H3zM3 27H5V29H3z"
  })), children);
});
var DropPhotoFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DropPhotoFilled16(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "19",
    cy: "22",
    r: "2"
  })), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,16H23.7207l-.5439-1.6328A1.9983,1.9983,0,0,0,21.2793,13H16.7207a1.9981,1.9981,0,0,0-1.8975,1.3677L14.2793,16H11a2.0023,2.0023,0,0,0-2,2v9a2.0023,2.0023,0,0,0,2,2H27a2.0023,2.0023,0,0,0,2-2V18A2.0023,2.0023,0,0,0,27,16ZM19,26a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,19,26Z"
  })), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M19,26a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,19,26Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,19,20Z",
    "data-icon-path": "inner-path"
  })), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 11H29V13H27zM27 7H29V9H27zM27 3H29V5H27zM23 3H25V5H23zM19 3H21V5H19zM15 3H17V5H15zM11 3H13V5H11zM7 3H9V5H7zM3 3H5V5H3zM3 7H5V9H3zM3 11H5V13H3zM3 15H5V17H3zM3 19H5V21H3zM3 23H5V25H3zM3 27H5V29H3z"
  })), children);
});
var Drought32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Drought32(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,18h3V15a4.0045,4.0045,0,0,0-4-4H25V9.5A3.5042,3.5042,0,0,0,21.5,6a3.4556,3.4556,0,0,0-1.5.3511V5.41a3.41,3.41,0,0,0-6.5449-1.3433L11.3408,9H9a5.0059,5.0059,0,0,0-5,5v4H8a5.0059,5.0059,0,0,0,5-5V10.2051l2.293-5.35A1.41,1.41,0,0,1,18,5.41V22H14.6123L11,25.2939,7.3877,22H2v2H6.6123L11,28l4.3877-4H30V22H20V9.5a1.5,1.5,0,0,1,3,0V14A4.0045,4.0045,0,0,0,27,18Zm-2-5h1a2.0023,2.0023,0,0,1,2,2v1H27a2.0023,2.0023,0,0,1-2-2ZM11,13a3.0033,3.0033,0,0,1-3,3H6V14a3.0033,3.0033,0,0,1,3-3h2Z"
  })), children);
});
var Drought24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Drought24(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,18h3V15a4.0045,4.0045,0,0,0-4-4H25V9.5A3.5042,3.5042,0,0,0,21.5,6a3.4556,3.4556,0,0,0-1.5.3511V5.41a3.41,3.41,0,0,0-6.5449-1.3433L11.3408,9H9a5.0059,5.0059,0,0,0-5,5v4H8a5.0059,5.0059,0,0,0,5-5V10.2051l2.293-5.35A1.41,1.41,0,0,1,18,5.41V22H14.6123L11,25.2939,7.3877,22H2v2H6.6123L11,28l4.3877-4H30V22H20V9.5a1.5,1.5,0,0,1,3,0V14A4.0045,4.0045,0,0,0,27,18Zm-2-5h1a2.0023,2.0023,0,0,1,2,2v1H27a2.0023,2.0023,0,0,1-2-2ZM11,13a3.0033,3.0033,0,0,1-3,3H6V14a3.0033,3.0033,0,0,1,3-3h2Z"
  })), children);
});
var Drought20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Drought20(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,18h3V15a4.0045,4.0045,0,0,0-4-4H25V9.5A3.5042,3.5042,0,0,0,21.5,6a3.4556,3.4556,0,0,0-1.5.3511V5.41a3.41,3.41,0,0,0-6.5449-1.3433L11.3408,9H9a5.0059,5.0059,0,0,0-5,5v4H8a5.0059,5.0059,0,0,0,5-5V10.2051l2.293-5.35A1.41,1.41,0,0,1,18,5.41V22H14.6123L11,25.2939,7.3877,22H2v2H6.6123L11,28l4.3877-4H30V22H20V9.5a1.5,1.5,0,0,1,3,0V14A4.0045,4.0045,0,0,0,27,18Zm-2-5h1a2.0023,2.0023,0,0,1,2,2v1H27a2.0023,2.0023,0,0,1-2-2ZM11,13a3.0033,3.0033,0,0,1-3,3H6V14a3.0033,3.0033,0,0,1,3-3h2Z"
  })), children);
});
var Drought16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Drought16(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,18h3V15a4.0045,4.0045,0,0,0-4-4H25V9.5A3.5042,3.5042,0,0,0,21.5,6a3.4556,3.4556,0,0,0-1.5.3511V5.41a3.41,3.41,0,0,0-6.5449-1.3433L11.3408,9H9a5.0059,5.0059,0,0,0-5,5v4H8a5.0059,5.0059,0,0,0,5-5V10.2051l2.293-5.35A1.41,1.41,0,0,1,18,5.41V22H14.6123L11,25.2939,7.3877,22H2v2H6.6123L11,28l4.3877-4H30V22H20V9.5a1.5,1.5,0,0,1,3,0V14A4.0045,4.0045,0,0,0,27,18Zm-2-5h1a2.0023,2.0023,0,0,1,2,2v1H27a2.0023,2.0023,0,0,1-2-2ZM11,13a3.0033,3.0033,0,0,1-3,3H6V14a3.0033,3.0033,0,0,1,3-3h2Z"
  })), children);
});
var Dvr32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Dvr32(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 15V11a2 2 0 00-2-2H22V23h2V17h1.48l2.34 6H30l-2.33-6H28A2 2 0 0030 15zm-6-4h4v4H24zM18 9L16 22 14 9 12 9 14.52 23 17.48 23 20 9 18 9zM6 23H2V9H6a4 4 0 014 4v6A4 4 0 016 23zM4 21H6a2 2 0 002-2V13a2 2 0 00-2-2H4z"
  })), children);
});
var Dvr24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Dvr24(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 15V11a2 2 0 00-2-2H22V23h2V17h1.48l2.34 6H30l-2.33-6H28A2 2 0 0030 15zm-6-4h4v4H24zM18 9L16 22 14 9 12 9 14.52 23 17.48 23 20 9 18 9zM6 23H2V9H6a4 4 0 014 4v6A4 4 0 016 23zM4 21H6a2 2 0 002-2V13a2 2 0 00-2-2H4z"
  })), children);
});
var Dvr20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Dvr20(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 15V11a2 2 0 00-2-2H22V23h2V17h1.48l2.34 6H30l-2.33-6H28A2 2 0 0030 15zm-6-4h4v4H24zM18 9L16 22 14 9 12 9 14.52 23 17.48 23 20 9 18 9zM6 23H2V9H6a4 4 0 014 4v6A4 4 0 016 23zM4 21H6a2 2 0 002-2V13a2 2 0 00-2-2H4z"
  })), children);
});
var Dvr16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Dvr16(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 15V11a2 2 0 00-2-2H22V23h2V17h1.48l2.34 6H30l-2.33-6H28A2 2 0 0030 15zm-6-4h4v4H24zM18 9L16 22 14 9 12 9 14.52 23 17.48 23 20 9 18 9zM6 23H2V9H6a4 4 0 014 4v6A4 4 0 016 23zM4 21H6a2 2 0 002-2V13a2 2 0 00-2-2H4z"
  })), children);
});
var Earth32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Earth32(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2Zm5,3.1055a12.0136,12.0136,0,0,1,2.9158,1.8994L23.5034,8H21ZM13.3784,27.7026A11.9761,11.9761,0,0,1,8.1157,6.9761L9.4648,9h3.3423l-1.5,4H7.2793L5.8967,17.1475,8.4648,21h5l1.4319,2.1475ZM16,28c-.2034,0-.4016-.02-.6025-.03l1.3967-4.19a1.9876,1.9876,0,0,0-.2334-1.7412l-1.4319-2.1475A1.9962,1.9962,0,0,0,13.4648,19h-3.93L8.1033,16.8525,8.7207,15H11v2h2V14.1812l2.9363-7.83-1.8726-.7022L13.5571,7H10.5352L9.728,5.7891A11.7941,11.7941,0,0,1,19,4.395V8a2.0025,2.0025,0,0,0,2,2h2.5857A1.9865,1.9865,0,0,0,25,9.4141l.1406-.1407.2818-.68A11.9813,11.9813,0,0,1,27.3,12H22.5986a1.9927,1.9927,0,0,0-1.9719,1.665L20.03,17.1064a1.99,1.99,0,0,0,.991,2.086l2.1647,1.4638,1.4585,3.646A11.9577,11.9577,0,0,1,16,28Zm8.8145-8.6563L22.1,17.5088l-.1-.06L22.5986,14h5.2207a11.743,11.743,0,0,1-1.7441,8.4951Z"
  })), children);
});
var Earth24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Earth24(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2Zm5,3.1055a12.0136,12.0136,0,0,1,2.9158,1.8994L23.5034,8H21ZM13.3784,27.7026A11.9761,11.9761,0,0,1,8.1157,6.9761L9.4648,9h3.3423l-1.5,4H7.2793L5.8967,17.1475,8.4648,21h5l1.4319,2.1475ZM16,28c-.2034,0-.4016-.02-.6025-.03l1.3967-4.19a1.9876,1.9876,0,0,0-.2334-1.7412l-1.4319-2.1475A1.9962,1.9962,0,0,0,13.4648,19h-3.93L8.1033,16.8525,8.7207,15H11v2h2V14.1812l2.9363-7.83-1.8726-.7022L13.5571,7H10.5352L9.728,5.7891A11.7941,11.7941,0,0,1,19,4.395V8a2.0025,2.0025,0,0,0,2,2h2.5857A1.9865,1.9865,0,0,0,25,9.4141l.1406-.1407.2818-.68A11.9813,11.9813,0,0,1,27.3,12H22.5986a1.9927,1.9927,0,0,0-1.9719,1.665L20.03,17.1064a1.99,1.99,0,0,0,.991,2.086l2.1647,1.4638,1.4585,3.646A11.9577,11.9577,0,0,1,16,28Zm8.8145-8.6563L22.1,17.5088l-.1-.06L22.5986,14h5.2207a11.743,11.743,0,0,1-1.7441,8.4951Z"
  })), children);
});
var Earth20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Earth20(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2Zm5,3.1055a12.0136,12.0136,0,0,1,2.9158,1.8994L23.5034,8H21ZM13.3784,27.7026A11.9761,11.9761,0,0,1,8.1157,6.9761L9.4648,9h3.3423l-1.5,4H7.2793L5.8967,17.1475,8.4648,21h5l1.4319,2.1475ZM16,28c-.2034,0-.4016-.02-.6025-.03l1.3967-4.19a1.9876,1.9876,0,0,0-.2334-1.7412l-1.4319-2.1475A1.9962,1.9962,0,0,0,13.4648,19h-3.93L8.1033,16.8525,8.7207,15H11v2h2V14.1812l2.9363-7.83-1.8726-.7022L13.5571,7H10.5352L9.728,5.7891A11.7941,11.7941,0,0,1,19,4.395V8a2.0025,2.0025,0,0,0,2,2h2.5857A1.9865,1.9865,0,0,0,25,9.4141l.1406-.1407.2818-.68A11.9813,11.9813,0,0,1,27.3,12H22.5986a1.9927,1.9927,0,0,0-1.9719,1.665L20.03,17.1064a1.99,1.99,0,0,0,.991,2.086l2.1647,1.4638,1.4585,3.646A11.9577,11.9577,0,0,1,16,28Zm8.8145-8.6563L22.1,17.5088l-.1-.06L22.5986,14h5.2207a11.743,11.743,0,0,1-1.7441,8.4951Z"
  })), children);
});
var Earth16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Earth16(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2Zm5,3.1055a12.0136,12.0136,0,0,1,2.9158,1.8994L23.5034,8H21ZM13.3784,27.7026A11.9761,11.9761,0,0,1,8.1157,6.9761L9.4648,9h3.3423l-1.5,4H7.2793L5.8967,17.1475,8.4648,21h5l1.4319,2.1475ZM16,28c-.2034,0-.4016-.02-.6025-.03l1.3967-4.19a1.9876,1.9876,0,0,0-.2334-1.7412l-1.4319-2.1475A1.9962,1.9962,0,0,0,13.4648,19h-3.93L8.1033,16.8525,8.7207,15H11v2h2V14.1812l2.9363-7.83-1.8726-.7022L13.5571,7H10.5352L9.728,5.7891A11.7941,11.7941,0,0,1,19,4.395V8a2.0025,2.0025,0,0,0,2,2h2.5857A1.9865,1.9865,0,0,0,25,9.4141l.1406-.1407.2818-.68A11.9813,11.9813,0,0,1,27.3,12H22.5986a1.9927,1.9927,0,0,0-1.9719,1.665L20.03,17.1064a1.99,1.99,0,0,0,.991,2.086l2.1647,1.4638,1.4585,3.646A11.9577,11.9577,0,0,1,16,28Zm8.8145-8.6563L22.1,17.5088l-.1-.06L22.5986,14h5.2207a11.743,11.743,0,0,1-1.7441,8.4951Z"
  })), children);
});
var EarthAmericas32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthAmericas32(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16a14.0313,14.0313,0,1,0-7.14,12.1914l.1165.0254.0249-.1113A13.9983,13.9983,0,0,0,30,16ZM4,16a11.9369,11.9369,0,0,1,.395-3H8.6382L13.63,17.16l-1.9092,2.5459a2.0088,2.0088,0,0,0,.1855,2.6142L14,24.4141v3.4052A12.0093,12.0093,0,0,1,4,16Zm9.32,4.9062L16.37,16.84,9.3618,11H5.1055A11.9619,11.9619,0,0,1,22.8838,6.1865L22.2793,8H16.5859L13.543,11.043l9.3535,8.3134L21.248,26.7749A11.9034,11.9034,0,0,1,16,28V23.5859Zm10.315,4.3443,1.2133-5.46a2.0007,2.0007,0,0,0-.6235-1.9277L16.457,10.957,17.4141,10h4.8652a1.9981,1.9981,0,0,0,1.8975-1.3677l.3532-1.06a11.9777,11.9777,0,0,1-.8947,17.6782Z"
  })), children);
});
var EarthAmericas24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthAmericas24(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16a14.0313,14.0313,0,1,0-7.14,12.1914l.1165.0254.0249-.1113A13.9983,13.9983,0,0,0,30,16ZM4,16a11.9369,11.9369,0,0,1,.395-3H8.6382L13.63,17.16l-1.9092,2.5459a2.0088,2.0088,0,0,0,.1855,2.6142L14,24.4141v3.4052A12.0093,12.0093,0,0,1,4,16Zm9.32,4.9062L16.37,16.84,9.3618,11H5.1055A11.9619,11.9619,0,0,1,22.8838,6.1865L22.2793,8H16.5859L13.543,11.043l9.3535,8.3134L21.248,26.7749A11.9034,11.9034,0,0,1,16,28V23.5859Zm10.315,4.3443,1.2133-5.46a2.0007,2.0007,0,0,0-.6235-1.9277L16.457,10.957,17.4141,10h4.8652a1.9981,1.9981,0,0,0,1.8975-1.3677l.3532-1.06a11.9777,11.9777,0,0,1-.8947,17.6782Z"
  })), children);
});
var EarthAmericas20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthAmericas20(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16a14.0313,14.0313,0,1,0-7.14,12.1914l.1165.0254.0249-.1113A13.9983,13.9983,0,0,0,30,16ZM4,16a11.9369,11.9369,0,0,1,.395-3H8.6382L13.63,17.16l-1.9092,2.5459a2.0088,2.0088,0,0,0,.1855,2.6142L14,24.4141v3.4052A12.0093,12.0093,0,0,1,4,16Zm9.32,4.9062L16.37,16.84,9.3618,11H5.1055A11.9619,11.9619,0,0,1,22.8838,6.1865L22.2793,8H16.5859L13.543,11.043l9.3535,8.3134L21.248,26.7749A11.9034,11.9034,0,0,1,16,28V23.5859Zm10.315,4.3443,1.2133-5.46a2.0007,2.0007,0,0,0-.6235-1.9277L16.457,10.957,17.4141,10h4.8652a1.9981,1.9981,0,0,0,1.8975-1.3677l.3532-1.06a11.9777,11.9777,0,0,1-.8947,17.6782Z"
  })), children);
});
var EarthAmericas16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthAmericas16(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16a14.0313,14.0313,0,1,0-7.14,12.1914l.1165.0254.0249-.1113A13.9983,13.9983,0,0,0,30,16ZM4,16a11.9369,11.9369,0,0,1,.395-3H8.6382L13.63,17.16l-1.9092,2.5459a2.0088,2.0088,0,0,0,.1855,2.6142L14,24.4141v3.4052A12.0093,12.0093,0,0,1,4,16Zm9.32,4.9062L16.37,16.84,9.3618,11H5.1055A11.9619,11.9619,0,0,1,22.8838,6.1865L22.2793,8H16.5859L13.543,11.043l9.3535,8.3134L21.248,26.7749A11.9034,11.9034,0,0,1,16,28V23.5859Zm10.315,4.3443,1.2133-5.46a2.0007,2.0007,0,0,0-.6235-1.9277L16.457,10.957,17.4141,10h4.8652a1.9981,1.9981,0,0,0,1.8975-1.3677l.3532-1.06a11.9777,11.9777,0,0,1-.8947,17.6782Z"
  })), children);
});
var EarthAmericasFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthAmericasFilled32(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4,16a11.915,11.915,0,0,1,.7-4H10l5,4-2.8,3.6929A1,1,0,0,0,12.293,21L15,24v3.9492A12.01,12.01,0,0,1,4,16ZM21.4348,26.6846l2.5457-7.6992A1,1,0,0,0,23.614,18L15,11l2-2h5.2793a1,1,0,0,0,.9487-.6836L23.7234,6.83a11.9742,11.9742,0,0,1-2.2886,19.855Z"
  })), children);
});
var EarthAmericasFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthAmericasFilled24(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4,16a11.915,11.915,0,0,1,.7-4H10l5,4-2.8,3.6929A1,1,0,0,0,12.293,21L15,24v3.9492A12.01,12.01,0,0,1,4,16ZM21.4348,26.6846l2.5457-7.6992A1,1,0,0,0,23.614,18L15,11l2-2h5.2793a1,1,0,0,0,.9487-.6836L23.7234,6.83a11.9742,11.9742,0,0,1-2.2886,19.855Z"
  })), children);
});
var EarthAmericasFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthAmericasFilled20(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4,16a11.915,11.915,0,0,1,.7-4H10l5,4-2.8,3.6929A1,1,0,0,0,12.293,21L15,24v3.9492A12.01,12.01,0,0,1,4,16ZM21.4348,26.6846l2.5457-7.6992A1,1,0,0,0,23.614,18L15,11l2-2h5.2793a1,1,0,0,0,.9487-.6836L23.7234,6.83a11.9742,11.9742,0,0,1-2.2886,19.855Z"
  })), children);
});
var EarthAmericasFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthAmericasFilled16(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4,16a11.915,11.915,0,0,1,.7-4H10l5,4-2.8,3.6929A1,1,0,0,0,12.293,21L15,24v3.9492A12.01,12.01,0,0,1,4,16ZM21.4348,26.6846l2.5457-7.6992A1,1,0,0,0,23.614,18L15,11l2-2h5.2793a1,1,0,0,0,.9487-.6836L23.7234,6.83a11.9742,11.9742,0,0,1-2.2886,19.855Z"
  })), children);
});
var EarthEuropeAfrica32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthEuropeAfrica32(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4,16A11.96,11.96,0,0,1,8,7.0811V9a2,2,0,0,0,2,2h3.3818a2,2,0,0,0,1.7893-1.106L15.6182,9H18v4H13.2354a2,2,0,0,0-.8936.2109L9.1055,14.8291A2,2,0,0,0,8,16.6177v3.7055A2,2,0,0,0,9.2573,22.18l3.8487,1.54.6779,4.0664A12.0135,12.0135,0,0,1,4,16ZM15.8457,27.9922,14.894,22.28,10,20.3232v-3.705L13.2358,15H20V7H14.3818l-1,2H10V5.6235A11.9578,11.9578,0,0,1,27.3,12H22v4l.9224,3.8135L21,22.6973v4.1972A11.9083,11.9083,0,0,1,16,28C15.948,28,15.8977,27.9927,15.8457,27.9922ZM23,25.7266V23.3027l1.5859-2.3789a2.0027,2.0027,0,0,0,.2769-1.5957L24,15.877V14h3.8193A11.8409,11.8409,0,0,1,23,25.7266Z"
  })), children);
});
var EarthEuropeAfrica24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthEuropeAfrica24(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4,16A11.96,11.96,0,0,1,8,7.0811V9a2,2,0,0,0,2,2h3.3818a2,2,0,0,0,1.7893-1.106L15.6182,9H18v4H13.2354a2,2,0,0,0-.8936.2109L9.1055,14.8291A2,2,0,0,0,8,16.6177v3.7055A2,2,0,0,0,9.2573,22.18l3.8487,1.54.6779,4.0664A12.0135,12.0135,0,0,1,4,16ZM15.8457,27.9922,14.894,22.28,10,20.3232v-3.705L13.2358,15H20V7H14.3818l-1,2H10V5.6235A11.9578,11.9578,0,0,1,27.3,12H22v4l.9224,3.8135L21,22.6973v4.1972A11.9083,11.9083,0,0,1,16,28C15.948,28,15.8977,27.9927,15.8457,27.9922ZM23,25.7266V23.3027l1.5859-2.3789a2.0027,2.0027,0,0,0,.2769-1.5957L24,15.877V14h3.8193A11.8409,11.8409,0,0,1,23,25.7266Z"
  })), children);
});
var EarthEuropeAfrica20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthEuropeAfrica20(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4,16A11.96,11.96,0,0,1,8,7.0811V9a2,2,0,0,0,2,2h3.3818a2,2,0,0,0,1.7893-1.106L15.6182,9H18v4H13.2354a2,2,0,0,0-.8936.2109L9.1055,14.8291A2,2,0,0,0,8,16.6177v3.7055A2,2,0,0,0,9.2573,22.18l3.8487,1.54.6779,4.0664A12.0135,12.0135,0,0,1,4,16ZM15.8457,27.9922,14.894,22.28,10,20.3232v-3.705L13.2358,15H20V7H14.3818l-1,2H10V5.6235A11.9578,11.9578,0,0,1,27.3,12H22v4l.9224,3.8135L21,22.6973v4.1972A11.9083,11.9083,0,0,1,16,28C15.948,28,15.8977,27.9927,15.8457,27.9922ZM23,25.7266V23.3027l1.5859-2.3789a2.0027,2.0027,0,0,0,.2769-1.5957L24,15.877V14h3.8193A11.8409,11.8409,0,0,1,23,25.7266Z"
  })), children);
});
var EarthEuropeAfrica16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthEuropeAfrica16(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4,16A11.96,11.96,0,0,1,8,7.0811V9a2,2,0,0,0,2,2h3.3818a2,2,0,0,0,1.7893-1.106L15.6182,9H18v4H13.2354a2,2,0,0,0-.8936.2109L9.1055,14.8291A2,2,0,0,0,8,16.6177v3.7055A2,2,0,0,0,9.2573,22.18l3.8487,1.54.6779,4.0664A12.0135,12.0135,0,0,1,4,16ZM15.8457,27.9922,14.894,22.28,10,20.3232v-3.705L13.2358,15H20V7H14.3818l-1,2H10V5.6235A11.9578,11.9578,0,0,1,27.3,12H22v4l.9224,3.8135L21,22.6973v4.1972A11.9083,11.9083,0,0,1,16,28C15.948,28,15.8977,27.9927,15.8457,27.9922ZM23,25.7266V23.3027l1.5859-2.3789a2.0027,2.0027,0,0,0,.2769-1.5957L24,15.877V14h3.8193A11.8409,11.8409,0,0,1,23,25.7266Z"
  })), children);
});
var EarthEuropeAfricaFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthEuropeAfricaFilled32(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4,16A11.9814,11.9814,0,0,1,9,6.2734V9a1,1,0,0,0,1,1h3.3821a1,1,0,0,0,.8943-.5527L15,8h4v6H13.2361a1.0006,1.0006,0,0,0-.4473.1055L9.5527,15.7236A1,1,0,0,0,9,16.6182v3.7046a1,1,0,0,0,.6287.9287L14,23l.8235,4.94A12.0152,12.0152,0,0,1,4,16ZM22,26.376V23l1.7546-2.6318a1.0012,1.0012,0,0,0,.1382-.7974L23,16V13h4.605A11.901,11.901,0,0,1,22,26.376Z"
  })), children);
});
var EarthEuropeAfricaFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthEuropeAfricaFilled24(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4,16A11.9814,11.9814,0,0,1,9,6.2734V9a1,1,0,0,0,1,1h3.3821a1,1,0,0,0,.8943-.5527L15,8h4v6H13.2361a1.0006,1.0006,0,0,0-.4473.1055L9.5527,15.7236A1,1,0,0,0,9,16.6182v3.7046a1,1,0,0,0,.6287.9287L14,23l.8235,4.94A12.0152,12.0152,0,0,1,4,16ZM22,26.376V23l1.7546-2.6318a1.0012,1.0012,0,0,0,.1382-.7974L23,16V13h4.605A11.901,11.901,0,0,1,22,26.376Z"
  })), children);
});
var EarthEuropeAfricaFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthEuropeAfricaFilled20(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4,16A11.9814,11.9814,0,0,1,9,6.2734V9a1,1,0,0,0,1,1h3.3821a1,1,0,0,0,.8943-.5527L15,8h4v6H13.2361a1.0006,1.0006,0,0,0-.4473.1055L9.5527,15.7236A1,1,0,0,0,9,16.6182v3.7046a1,1,0,0,0,.6287.9287L14,23l.8235,4.94A12.0152,12.0152,0,0,1,4,16ZM22,26.376V23l1.7546-2.6318a1.0012,1.0012,0,0,0,.1382-.7974L23,16V13h4.605A11.901,11.901,0,0,1,22,26.376Z"
  })), children);
});
var EarthEuropeAfricaFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthEuropeAfricaFilled16(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4,16A11.9814,11.9814,0,0,1,9,6.2734V9a1,1,0,0,0,1,1h3.3821a1,1,0,0,0,.8943-.5527L15,8h4v6H13.2361a1.0006,1.0006,0,0,0-.4473.1055L9.5527,15.7236A1,1,0,0,0,9,16.6182v3.7046a1,1,0,0,0,.6287.9287L14,23l.8235,4.94A12.0152,12.0152,0,0,1,4,16ZM22,26.376V23l1.7546-2.6318a1.0012,1.0012,0,0,0,.1382-.7974L23,16V13h4.605A11.901,11.901,0,0,1,22,26.376Z"
  })), children);
});
var EarthFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthFilled32(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4.02,16.394l1.3384.4458L7,19.3027v1.2831a1,1,0,0,0,.2929.7071L10,24v2.3765A11.9941,11.9941,0,0,1,4.02,16.394ZM16,28a11.9682,11.9682,0,0,1-2.5718-.2847L14,26l1.8046-4.5116a1,1,0,0,0-.0964-.9261l-1.4113-2.117A1,1,0,0,0,13.4648,18h-4.93L7.2866,16.1274,9.4141,14H11v2h2V13.2656l3.8682-6.7695-1.7364-.9922L14.2769,7H11.5352l-1.086-1.6289A11.861,11.861,0,0,1,20,4.7V8a1,1,0,0,0,1,1h1.4648a1,1,0,0,0,.8321-.4453l.8769-1.3154A12.0331,12.0331,0,0,1,26.8945,11H22.82a1,1,0,0,0-.9806.8039l-.7221,4.4708a1,1,0,0,0,.54,1.0539L25,19l.6851,4.0557A11.9793,11.9793,0,0,1,16,28Z"
  })), children);
});
var EarthFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthFilled24(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4.02,16.394l1.3384.4458L7,19.3027v1.2831a1,1,0,0,0,.2929.7071L10,24v2.3765A11.9941,11.9941,0,0,1,4.02,16.394ZM16,28a11.9682,11.9682,0,0,1-2.5718-.2847L14,26l1.8046-4.5116a1,1,0,0,0-.0964-.9261l-1.4113-2.117A1,1,0,0,0,13.4648,18h-4.93L7.2866,16.1274,9.4141,14H11v2h2V13.2656l3.8682-6.7695-1.7364-.9922L14.2769,7H11.5352l-1.086-1.6289A11.861,11.861,0,0,1,20,4.7V8a1,1,0,0,0,1,1h1.4648a1,1,0,0,0,.8321-.4453l.8769-1.3154A12.0331,12.0331,0,0,1,26.8945,11H22.82a1,1,0,0,0-.9806.8039l-.7221,4.4708a1,1,0,0,0,.54,1.0539L25,19l.6851,4.0557A11.9793,11.9793,0,0,1,16,28Z"
  })), children);
});
var EarthFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthFilled20(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4.02,16.394l1.3384.4458L7,19.3027v1.2831a1,1,0,0,0,.2929.7071L10,24v2.3765A11.9941,11.9941,0,0,1,4.02,16.394ZM16,28a11.9682,11.9682,0,0,1-2.5718-.2847L14,26l1.8046-4.5116a1,1,0,0,0-.0964-.9261l-1.4113-2.117A1,1,0,0,0,13.4648,18h-4.93L7.2866,16.1274,9.4141,14H11v2h2V13.2656l3.8682-6.7695-1.7364-.9922L14.2769,7H11.5352l-1.086-1.6289A11.861,11.861,0,0,1,20,4.7V8a1,1,0,0,0,1,1h1.4648a1,1,0,0,0,.8321-.4453l.8769-1.3154A12.0331,12.0331,0,0,1,26.8945,11H22.82a1,1,0,0,0-.9806.8039l-.7221,4.4708a1,1,0,0,0,.54,1.0539L25,19l.6851,4.0557A11.9793,11.9793,0,0,1,16,28Z"
  })), children);
});
var EarthFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthFilled16(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4.02,16.394l1.3384.4458L7,19.3027v1.2831a1,1,0,0,0,.2929.7071L10,24v2.3765A11.9941,11.9941,0,0,1,4.02,16.394ZM16,28a11.9682,11.9682,0,0,1-2.5718-.2847L14,26l1.8046-4.5116a1,1,0,0,0-.0964-.9261l-1.4113-2.117A1,1,0,0,0,13.4648,18h-4.93L7.2866,16.1274,9.4141,14H11v2h2V13.2656l3.8682-6.7695-1.7364-.9922L14.2769,7H11.5352l-1.086-1.6289A11.861,11.861,0,0,1,20,4.7V8a1,1,0,0,0,1,1h1.4648a1,1,0,0,0,.8321-.4453l.8769-1.3154A12.0331,12.0331,0,0,1,26.8945,11H22.82a1,1,0,0,0-.9806.8039l-.7221,4.4708a1,1,0,0,0,.54,1.0539L25,19l.6851,4.0557A11.9793,11.9793,0,0,1,16,28Z"
  })), children);
});
var EarthSoutheastAsia32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthSoutheastAsia32(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 24H17V26H14zM17 22H19V24H17zM17 18H19V20H17z"
  })), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2Zm-.603,2.03,2.5073,5.0156L16.3228,13H10.271l-1.41,4.3872,2.8521,2.8521L10.7056,21.751,6.2856,19H4.395A11.9363,11.9363,0,0,1,15.397,4.03ZM5.1055,21h.6089l3.9345,2.4487A1.9912,1.9912,0,0,0,12.37,22.86l1.0078-1.5118a2.005,2.005,0,0,0-.25-2.5234l-1.9887-1.9888L11.729,15h4.5938A1.9906,1.9906,0,0,0,18.18,13.7427L19.7612,9.79a2.0019,2.0019,0,0,0-.0674-1.6382L17.6843,4.1323A11.9592,11.9592,0,0,1,26.8945,21H23a2.0023,2.0023,0,0,0-2,2v3.8945A11.9477,11.9477,0,0,1,5.1055,21ZM23,25.7266V23h2.7268A12.0762,12.0762,0,0,1,23,25.7266Z"
  })), children);
});
var EarthSoutheastAsia24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthSoutheastAsia24(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 24H17V26H14zM17 22H19V24H17zM17 18H19V20H17z"
  })), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2Zm-.603,2.03,2.5073,5.0156L16.3228,13H10.271l-1.41,4.3872,2.8521,2.8521L10.7056,21.751,6.2856,19H4.395A11.9363,11.9363,0,0,1,15.397,4.03ZM5.1055,21h.6089l3.9345,2.4487A1.9912,1.9912,0,0,0,12.37,22.86l1.0078-1.5118a2.005,2.005,0,0,0-.25-2.5234l-1.9887-1.9888L11.729,15h4.5938A1.9906,1.9906,0,0,0,18.18,13.7427L19.7612,9.79a2.0019,2.0019,0,0,0-.0674-1.6382L17.6843,4.1323A11.9592,11.9592,0,0,1,26.8945,21H23a2.0023,2.0023,0,0,0-2,2v3.8945A11.9477,11.9477,0,0,1,5.1055,21ZM23,25.7266V23h2.7268A12.0762,12.0762,0,0,1,23,25.7266Z"
  })), children);
});
var EarthSoutheastAsia20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthSoutheastAsia20(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 24H17V26H14zM17 22H19V24H17zM17 18H19V20H17z"
  })), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2Zm-.603,2.03,2.5073,5.0156L16.3228,13H10.271l-1.41,4.3872,2.8521,2.8521L10.7056,21.751,6.2856,19H4.395A11.9363,11.9363,0,0,1,15.397,4.03ZM5.1055,21h.6089l3.9345,2.4487A1.9912,1.9912,0,0,0,12.37,22.86l1.0078-1.5118a2.005,2.005,0,0,0-.25-2.5234l-1.9887-1.9888L11.729,15h4.5938A1.9906,1.9906,0,0,0,18.18,13.7427L19.7612,9.79a2.0019,2.0019,0,0,0-.0674-1.6382L17.6843,4.1323A11.9592,11.9592,0,0,1,26.8945,21H23a2.0023,2.0023,0,0,0-2,2v3.8945A11.9477,11.9477,0,0,1,5.1055,21ZM23,25.7266V23h2.7268A12.0762,12.0762,0,0,1,23,25.7266Z"
  })), children);
});
var EarthSoutheastAsia16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthSoutheastAsia16(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 24H17V26H14zM17 22H19V24H17zM17 18H19V20H17z"
  })), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2Zm-.603,2.03,2.5073,5.0156L16.3228,13H10.271l-1.41,4.3872,2.8521,2.8521L10.7056,21.751,6.2856,19H4.395A11.9363,11.9363,0,0,1,15.397,4.03ZM5.1055,21h.6089l3.9345,2.4487A1.9912,1.9912,0,0,0,12.37,22.86l1.0078-1.5118a2.005,2.005,0,0,0-.25-2.5234l-1.9887-1.9888L11.729,15h4.5938A1.9906,1.9906,0,0,0,18.18,13.7427L19.7612,9.79a2.0019,2.0019,0,0,0-.0674-1.6382L17.6843,4.1323A11.9592,11.9592,0,0,1,26.8945,21H23a2.0023,2.0023,0,0,0-2,2v3.8945A11.9477,11.9477,0,0,1,5.1055,21ZM23,25.7266V23h2.7268A12.0762,12.0762,0,0,1,23,25.7266Z"
  })), children);
});
var EarthSoutheastAsiaFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthSoutheastAsiaFilled32(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 22H19V24H17zM17 18H19V20H17zM14 24H17V26H14z"
  })), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4.7,20H6l4.1772,2.6a1,1,0,0,0,1.36-.2939l1.0078-1.5118a1,1,0,0,0-.125-1.2617L10,17.1118,11,14h5.323a1,1,0,0,0,.9285-.6284L18.8333,9.417a1,1,0,0,0-.034-.8189L16.5129,4.0259A11.9652,11.9652,0,0,1,26.3762,22H23a1,1,0,0,0-1,1v3.3765A11.9578,11.9578,0,0,1,4.7,20Z"
  })), children);
});
var EarthSoutheastAsiaFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthSoutheastAsiaFilled24(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 22H19V24H17zM17 18H19V20H17zM14 24H17V26H14z"
  })), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4.7,20H6l4.1772,2.6a1,1,0,0,0,1.36-.2939l1.0078-1.5118a1,1,0,0,0-.125-1.2617L10,17.1118,11,14h5.323a1,1,0,0,0,.9285-.6284L18.8333,9.417a1,1,0,0,0-.034-.8189L16.5129,4.0259A11.9652,11.9652,0,0,1,26.3762,22H23a1,1,0,0,0-1,1v3.3765A11.9578,11.9578,0,0,1,4.7,20Z"
  })), children);
});
var EarthSoutheastAsiaFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthSoutheastAsiaFilled20(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 22H19V24H17zM17 18H19V20H17zM14 24H17V26H14z"
  })), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4.7,20H6l4.1772,2.6a1,1,0,0,0,1.36-.2939l1.0078-1.5118a1,1,0,0,0-.125-1.2617L10,17.1118,11,14h5.323a1,1,0,0,0,.9285-.6284L18.8333,9.417a1,1,0,0,0-.034-.8189L16.5129,4.0259A11.9652,11.9652,0,0,1,26.3762,22H23a1,1,0,0,0-1,1v3.3765A11.9578,11.9578,0,0,1,4.7,20Z"
  })), children);
});
var EarthSoutheastAsiaFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EarthSoutheastAsiaFilled16(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 22H19V24H17zM17 18H19V20H17zM14 24H17V26H14z"
  })), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM4.7,20H6l4.1772,2.6a1,1,0,0,0,1.36-.2939l1.0078-1.5118a1,1,0,0,0-.125-1.2617L10,17.1118,11,14h5.323a1,1,0,0,0,.9285-.6284L18.8333,9.417a1,1,0,0,0-.034-.8189L16.5129,4.0259A11.9652,11.9652,0,0,1,26.3762,22H23a1,1,0,0,0-1,1v3.3765A11.9578,11.9578,0,0,1,4.7,20Z"
  })), children);
});
var Earthquake32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Earthquake32(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.6123,2.2139a1.0094,1.0094,0,0,0-1.2427,0L1,13.4194l1.2427,1.5718L4,13.6211V26a2.0041,2.0041,0,0,0,2,2H26a2.0037,2.0037,0,0,0,2-2V13.63L29.7573,15,31,13.4282ZM6,12.0615,15,5.05v7.3638l3.458,3.458-6.7344,4.8105L14.3818,26H6ZM26,26H16.6182l-2.3418-4.6826,7.2656-5.1895L17,11.5859V5.0518l9,7.02Z"
  })), children);
});
var Earthquake24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Earthquake24(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.6123,2.2139a1.0094,1.0094,0,0,0-1.2427,0L1,13.4194l1.2427,1.5718L4,13.6211V26a2.0041,2.0041,0,0,0,2,2H26a2.0037,2.0037,0,0,0,2-2V13.63L29.7573,15,31,13.4282ZM6,12.0615,15,5.05v7.3638l3.458,3.458-6.7344,4.8105L14.3818,26H6ZM26,26H16.6182l-2.3418-4.6826,7.2656-5.1895L17,11.5859V5.0518l9,7.02Z"
  })), children);
});
var Earthquake20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Earthquake20(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.6123,2.2139a1.0094,1.0094,0,0,0-1.2427,0L1,13.4194l1.2427,1.5718L4,13.6211V26a2.0041,2.0041,0,0,0,2,2H26a2.0037,2.0037,0,0,0,2-2V13.63L29.7573,15,31,13.4282ZM6,12.0615,15,5.05v7.3638l3.458,3.458-6.7344,4.8105L14.3818,26H6ZM26,26H16.6182l-2.3418-4.6826,7.2656-5.1895L17,11.5859V5.0518l9,7.02Z"
  })), children);
});
var Earthquake16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Earthquake16(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.6123,2.2139a1.0094,1.0094,0,0,0-1.2427,0L1,13.4194l1.2427,1.5718L4,13.6211V26a2.0041,2.0041,0,0,0,2,2H26a2.0037,2.0037,0,0,0,2-2V13.63L29.7573,15,31,13.4282ZM6,12.0615,15,5.05v7.3638l3.458,3.458-6.7344,4.8105L14.3818,26H6ZM26,26H16.6182l-2.3418-4.6826,7.2656-5.1895L17,11.5859V5.0518l9,7.02Z"
  })), children);
});
var EdgeCluster32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeCluster32(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 7a3 3 0 113-3A3.0033 3.0033 0 0116 7zm0-4a1 1 0 101 1A1.001 1.001 0 0016 3zM11 30a3 3 0 113-3A3.0033 3.0033 0 0111 30zm0-4a1 1 0 101 1A1.001 1.001 0 0011 26zM7 11a3 3 0 113-3A3.0033 3.0033 0 017 11zM7 7A1 1 0 108 8 1.001 1.001 0 007 7zM21 30a3 3 0 113-3A3.0033 3.0033 0 0121 30zm0-4a1 1 0 101 1A1.001 1.001 0 0021 26zM25 11a3 3 0 113-3A3.0033 3.0033 0 0125 11zm0-4a1 1 0 101 1A1.001 1.001 0 0025 7zM4 21a3 3 0 113-3A3.0033 3.0033 0 014 21zm0-4a1 1 0 101 1A1.001 1.001 0 004 17zM28 21a3 3 0 113-3A3.0033 3.0033 0 0128 21zm0-4a1 1 0 101 1A1.001 1.001 0 0028 17zM16 22a6 6 0 116-6A6.0069 6.0069 0 0116 22zm0-10a4 4 0 104 4A4.0045 4.0045 0 0016 12z"
  })), children);
});
var EdgeCluster24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeCluster24(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 7a3 3 0 113-3A3.0033 3.0033 0 0116 7zm0-4a1 1 0 101 1A1.001 1.001 0 0016 3zM11 30a3 3 0 113-3A3.0033 3.0033 0 0111 30zm0-4a1 1 0 101 1A1.001 1.001 0 0011 26zM7 11a3 3 0 113-3A3.0033 3.0033 0 017 11zM7 7A1 1 0 108 8 1.001 1.001 0 007 7zM21 30a3 3 0 113-3A3.0033 3.0033 0 0121 30zm0-4a1 1 0 101 1A1.001 1.001 0 0021 26zM25 11a3 3 0 113-3A3.0033 3.0033 0 0125 11zm0-4a1 1 0 101 1A1.001 1.001 0 0025 7zM4 21a3 3 0 113-3A3.0033 3.0033 0 014 21zm0-4a1 1 0 101 1A1.001 1.001 0 004 17zM28 21a3 3 0 113-3A3.0033 3.0033 0 0128 21zm0-4a1 1 0 101 1A1.001 1.001 0 0028 17zM16 22a6 6 0 116-6A6.0069 6.0069 0 0116 22zm0-10a4 4 0 104 4A4.0045 4.0045 0 0016 12z"
  })), children);
});
var EdgeCluster20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeCluster20(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 7a3 3 0 113-3A3.0033 3.0033 0 0116 7zm0-4a1 1 0 101 1A1.001 1.001 0 0016 3zM11 30a3 3 0 113-3A3.0033 3.0033 0 0111 30zm0-4a1 1 0 101 1A1.001 1.001 0 0011 26zM7 11a3 3 0 113-3A3.0033 3.0033 0 017 11zM7 7A1 1 0 108 8 1.001 1.001 0 007 7zM21 30a3 3 0 113-3A3.0033 3.0033 0 0121 30zm0-4a1 1 0 101 1A1.001 1.001 0 0021 26zM25 11a3 3 0 113-3A3.0033 3.0033 0 0125 11zm0-4a1 1 0 101 1A1.001 1.001 0 0025 7zM4 21a3 3 0 113-3A3.0033 3.0033 0 014 21zm0-4a1 1 0 101 1A1.001 1.001 0 004 17zM28 21a3 3 0 113-3A3.0033 3.0033 0 0128 21zm0-4a1 1 0 101 1A1.001 1.001 0 0028 17zM16 22a6 6 0 116-6A6.0069 6.0069 0 0116 22zm0-10a4 4 0 104 4A4.0045 4.0045 0 0016 12z"
  })), children);
});
var EdgeCluster16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeCluster16(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 7a3 3 0 113-3A3.0033 3.0033 0 0116 7zm0-4a1 1 0 101 1A1.001 1.001 0 0016 3zM11 30a3 3 0 113-3A3.0033 3.0033 0 0111 30zm0-4a1 1 0 101 1A1.001 1.001 0 0011 26zM7 11a3 3 0 113-3A3.0033 3.0033 0 017 11zM7 7A1 1 0 108 8 1.001 1.001 0 007 7zM21 30a3 3 0 113-3A3.0033 3.0033 0 0121 30zm0-4a1 1 0 101 1A1.001 1.001 0 0021 26zM25 11a3 3 0 113-3A3.0033 3.0033 0 0125 11zm0-4a1 1 0 101 1A1.001 1.001 0 0025 7zM4 21a3 3 0 113-3A3.0033 3.0033 0 014 21zm0-4a1 1 0 101 1A1.001 1.001 0 004 17zM28 21a3 3 0 113-3A3.0033 3.0033 0 0128 21zm0-4a1 1 0 101 1A1.001 1.001 0 0028 17zM16 22a6 6 0 116-6A6.0069 6.0069 0 0116 22zm0-10a4 4 0 104 4A4.0045 4.0045 0 0016 12z"
  })), children);
});
var EdgeDevice32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeDevice32(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 21H23V23H9zM11 14a2 2 0 102 2A1.9806 1.9806 0 0011 14zM21 14a2 2 0 102 2A1.9806 1.9806 0 0021 14z"
  })), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H18.4141l2.0722-2.0723A2.04,2.04,0,0,0,21,6a2,2,0,1,0-2-2,2.0412,2.0412,0,0,0,.0723.5137L15.5859,8H4a2.0025,2.0025,0,0,0-2,2V26a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V10A2.0025,2.0025,0,0,0,28,8ZM4,26V10H28V26Z"
  })), children);
});
var EdgeDevice24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeDevice24(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 21H23V23H9zM11 14a2 2 0 102 2A1.9806 1.9806 0 0011 14zM21 14a2 2 0 102 2A1.9806 1.9806 0 0021 14z"
  })), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H18.4141l2.0722-2.0723A2.04,2.04,0,0,0,21,6a2,2,0,1,0-2-2,2.0412,2.0412,0,0,0,.0723.5137L15.5859,8H4a2.0025,2.0025,0,0,0-2,2V26a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V10A2.0025,2.0025,0,0,0,28,8ZM4,26V10H28V26Z"
  })), children);
});
var EdgeDevice20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeDevice20(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 21H23V23H9zM11 14a2 2 0 102 2A1.9806 1.9806 0 0011 14zM21 14a2 2 0 102 2A1.9806 1.9806 0 0021 14z"
  })), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H18.4141l2.0722-2.0723A2.04,2.04,0,0,0,21,6a2,2,0,1,0-2-2,2.0412,2.0412,0,0,0,.0723.5137L15.5859,8H4a2.0025,2.0025,0,0,0-2,2V26a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V10A2.0025,2.0025,0,0,0,28,8ZM4,26V10H28V26Z"
  })), children);
});
var EdgeDevice16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeDevice16(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 21H23V23H9zM11 14a2 2 0 102 2A1.9806 1.9806 0 0011 14zM21 14a2 2 0 102 2A1.9806 1.9806 0 0021 14z"
  })), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H18.4141l2.0722-2.0723A2.04,2.04,0,0,0,21,6a2,2,0,1,0-2-2,2.0412,2.0412,0,0,0,.0723.5137L15.5859,8H4a2.0025,2.0025,0,0,0-2,2V26a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V10A2.0025,2.0025,0,0,0,28,8ZM4,26V10H28V26Z"
  })), children);
});
var WatsonHealthEdgeEnhancement32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEdgeEnhancement32(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.8164 4.7646L11.1328 2.887A13.976 13.976 0 006.9507 5.3278L8.2358 6.8593A11.9729 11.9729 0 0111.8164 4.7646zM5.5913 10L3.86 9a14.14 14.14 0 00-1.6382 4.5872l1.9677.3469A12.1519 12.1519 0 015.5913 10zM16 26A10 10 0 0016 6h0z"
  })), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16A14,14,0,0,0,16,2V4a11.9933,11.9933,0,0,1,4.0493,23.2847c-.1682.06-.334.1294-.5044.1821-.2512.0771-.51.1362-.7683.1973-.1262.03-.25.0693-.3772.0952-.2908.0591-.5884.0976-.8862.1352-.1.0122-.1983.0342-.2988.044A12.0015,12.0015,0,0,1,5.416,21.6548c-.0664-.127-.133-.2534-.1953-.3843-.0547-.1123-.106-.227-.1572-.3413A13.1207,13.1207,0,0,1,4.19,18l-1.9677.4131A13.9173,13.9173,0,0,0,2.7,20.2993l-.0251.0083A13.9615,13.9615,0,0,0,16,30q.7134,0,1.415-.0713c.135-.0137.2654-.042.3995-.06.3286-.0424.6574-.0839.9814-.1494.18-.0366.3533-.0908.5308-.1338.2685-.0659.5383-.125.8027-.2065.2463-.0762.4831-.1724.7234-.2612.18-.0664.3635-.1211.5412-.1953l-.0009-.0025A14.0015,14.0015,0,0,0,30,16Z"
  })), children);
});
var WatsonHealthEdgeEnhancement24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEdgeEnhancement24(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.8164 4.7646L11.1328 2.887A13.976 13.976 0 006.9507 5.3278L8.2358 6.8593A11.9729 11.9729 0 0111.8164 4.7646zM5.5913 10L3.86 9a14.14 14.14 0 00-1.6382 4.5872l1.9677.3469A12.1519 12.1519 0 015.5913 10zM16 26A10 10 0 0016 6h0z"
  })), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16A14,14,0,0,0,16,2V4a11.9933,11.9933,0,0,1,4.0493,23.2847c-.1682.06-.334.1294-.5044.1821-.2512.0771-.51.1362-.7683.1973-.1262.03-.25.0693-.3772.0952-.2908.0591-.5884.0976-.8862.1352-.1.0122-.1983.0342-.2988.044A12.0015,12.0015,0,0,1,5.416,21.6548c-.0664-.127-.133-.2534-.1953-.3843-.0547-.1123-.106-.227-.1572-.3413A13.1207,13.1207,0,0,1,4.19,18l-1.9677.4131A13.9173,13.9173,0,0,0,2.7,20.2993l-.0251.0083A13.9615,13.9615,0,0,0,16,30q.7134,0,1.415-.0713c.135-.0137.2654-.042.3995-.06.3286-.0424.6574-.0839.9814-.1494.18-.0366.3533-.0908.5308-.1338.2685-.0659.5383-.125.8027-.2065.2463-.0762.4831-.1724.7234-.2612.18-.0664.3635-.1211.5412-.1953l-.0009-.0025A14.0015,14.0015,0,0,0,30,16Z"
  })), children);
});
var WatsonHealthEdgeEnhancement20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEdgeEnhancement20(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.8164 4.7646L11.1328 2.887A13.976 13.976 0 006.9507 5.3278L8.2358 6.8593A11.9729 11.9729 0 0111.8164 4.7646zM5.5913 10L3.86 9a14.14 14.14 0 00-1.6382 4.5872l1.9677.3469A12.1519 12.1519 0 015.5913 10zM16 26A10 10 0 0016 6h0z"
  })), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16A14,14,0,0,0,16,2V4a11.9933,11.9933,0,0,1,4.0493,23.2847c-.1682.06-.334.1294-.5044.1821-.2512.0771-.51.1362-.7683.1973-.1262.03-.25.0693-.3772.0952-.2908.0591-.5884.0976-.8862.1352-.1.0122-.1983.0342-.2988.044A12.0015,12.0015,0,0,1,5.416,21.6548c-.0664-.127-.133-.2534-.1953-.3843-.0547-.1123-.106-.227-.1572-.3413A13.1207,13.1207,0,0,1,4.19,18l-1.9677.4131A13.9173,13.9173,0,0,0,2.7,20.2993l-.0251.0083A13.9615,13.9615,0,0,0,16,30q.7134,0,1.415-.0713c.135-.0137.2654-.042.3995-.06.3286-.0424.6574-.0839.9814-.1494.18-.0366.3533-.0908.5308-.1338.2685-.0659.5383-.125.8027-.2065.2463-.0762.4831-.1724.7234-.2612.18-.0664.3635-.1211.5412-.1953l-.0009-.0025A14.0015,14.0015,0,0,0,30,16Z"
  })), children);
});
var WatsonHealthEdgeEnhancement16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEdgeEnhancement16(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.8164 4.7646L11.1328 2.887A13.976 13.976 0 006.9507 5.3278L8.2358 6.8593A11.9729 11.9729 0 0111.8164 4.7646zM5.5913 10L3.86 9a14.14 14.14 0 00-1.6382 4.5872l1.9677.3469A12.1519 12.1519 0 015.5913 10zM16 26A10 10 0 0016 6h0z"
  })), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16A14,14,0,0,0,16,2V4a11.9933,11.9933,0,0,1,4.0493,23.2847c-.1682.06-.334.1294-.5044.1821-.2512.0771-.51.1362-.7683.1973-.1262.03-.25.0693-.3772.0952-.2908.0591-.5884.0976-.8862.1352-.1.0122-.1983.0342-.2988.044A12.0015,12.0015,0,0,1,5.416,21.6548c-.0664-.127-.133-.2534-.1953-.3843-.0547-.1123-.106-.227-.1572-.3413A13.1207,13.1207,0,0,1,4.19,18l-1.9677.4131A13.9173,13.9173,0,0,0,2.7,20.2993l-.0251.0083A13.9615,13.9615,0,0,0,16,30q.7134,0,1.415-.0713c.135-.0137.2654-.042.3995-.06.3286-.0424.6574-.0839.9814-.1494.18-.0366.3533-.0908.5308-.1338.2685-.0659.5383-.125.8027-.2065.2463-.0762.4831-.1724.7234-.2612.18-.0664.3635-.1211.5412-.1953l-.0009-.0025A14.0015,14.0015,0,0,0,30,16Z"
  })), children);
});
var WatsonHealthEdgeEnhancement_0132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEdgeEnhancement_0132(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 28L26 20 24 20 24 21 22 21 22 23 24 23 24 28 22 28 22 30 28 30 28 28 26 28zM28 16h2A14 14 0 0016 2V4A12 12 0 0128 16z"
  })), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 16A10 10 0 0016 6V16zM16 28A11.96 11.96 0 015.416 21.6548c-.0664-.127-.133-.2534-.1953-.3843-.0547-.1123-.106-.227-.1572-.3413A13.1207 13.1207 0 014.19 18l-1.9677.4131A13.9173 13.9173 0 002.7 20.2993l-.0251.0083A13.9615 13.9615 0 0016 30zM5.5913 10L3.86 9a14.14 14.14 0 00-1.6382 4.5872l1.9677.3469A12.1519 12.1519 0 015.5913 10zM11.8164 4.7646L11.1328 2.887A13.976 13.976 0 006.9507 5.3278L8.2358 6.8593A11.9729 11.9729 0 0111.8164 4.7646z"
  })), children);
});
var WatsonHealthEdgeEnhancement_0124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEdgeEnhancement_0124(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 28L26 20 24 20 24 21 22 21 22 23 24 23 24 28 22 28 22 30 28 30 28 28 26 28zM28 16h2A14 14 0 0016 2V4A12 12 0 0128 16z"
  })), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 16A10 10 0 0016 6V16zM16 28A11.96 11.96 0 015.416 21.6548c-.0664-.127-.133-.2534-.1953-.3843-.0547-.1123-.106-.227-.1572-.3413A13.1207 13.1207 0 014.19 18l-1.9677.4131A13.9173 13.9173 0 002.7 20.2993l-.0251.0083A13.9615 13.9615 0 0016 30zM5.5913 10L3.86 9a14.14 14.14 0 00-1.6382 4.5872l1.9677.3469A12.1519 12.1519 0 015.5913 10zM11.8164 4.7646L11.1328 2.887A13.976 13.976 0 006.9507 5.3278L8.2358 6.8593A11.9729 11.9729 0 0111.8164 4.7646z"
  })), children);
});
var WatsonHealthEdgeEnhancement_0120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEdgeEnhancement_0120(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 28L26 20 24 20 24 21 22 21 22 23 24 23 24 28 22 28 22 30 28 30 28 28 26 28zM28 16h2A14 14 0 0016 2V4A12 12 0 0128 16z"
  })), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 16A10 10 0 0016 6V16zM16 28A11.96 11.96 0 015.416 21.6548c-.0664-.127-.133-.2534-.1953-.3843-.0547-.1123-.106-.227-.1572-.3413A13.1207 13.1207 0 014.19 18l-1.9677.4131A13.9173 13.9173 0 002.7 20.2993l-.0251.0083A13.9615 13.9615 0 0016 30zM5.5913 10L3.86 9a14.14 14.14 0 00-1.6382 4.5872l1.9677.3469A12.1519 12.1519 0 015.5913 10zM11.8164 4.7646L11.1328 2.887A13.976 13.976 0 006.9507 5.3278L8.2358 6.8593A11.9729 11.9729 0 0111.8164 4.7646z"
  })), children);
});
var WatsonHealthEdgeEnhancement_0116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEdgeEnhancement_0116(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 28L26 20 24 20 24 21 22 21 22 23 24 23 24 28 22 28 22 30 28 30 28 28 26 28zM28 16h2A14 14 0 0016 2V4A12 12 0 0128 16z"
  })), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 16A10 10 0 0016 6V16zM16 28A11.96 11.96 0 015.416 21.6548c-.0664-.127-.133-.2534-.1953-.3843-.0547-.1123-.106-.227-.1572-.3413A13.1207 13.1207 0 014.19 18l-1.9677.4131A13.9173 13.9173 0 002.7 20.2993l-.0251.0083A13.9615 13.9615 0 0016 30zM5.5913 10L3.86 9a14.14 14.14 0 00-1.6382 4.5872l1.9677.3469A12.1519 12.1519 0 015.5913 10zM11.8164 4.7646L11.1328 2.887A13.976 13.976 0 006.9507 5.3278L8.2358 6.8593A11.9729 11.9729 0 0111.8164 4.7646z"
  })), children);
});
var WatsonHealthEdgeEnhancement_0232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEdgeEnhancement_0232(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H22V26a2.002 2.002 0 012-2h2V22H22V20h4a2.0023 2.0023 0 012 2v2a2.0023 2.0023 0 01-2 2H24v2h4zM28 16h2A14 14 0 0016 2V4A12 12 0 0128 16z"
  })), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 16A10 10 0 0016 6V16zM16 28A11.96 11.96 0 015.416 21.6548c-.0664-.127-.133-.2534-.1953-.3843-.0547-.1123-.106-.227-.1572-.3413A13.1207 13.1207 0 014.19 18l-1.9677.4131A13.9173 13.9173 0 002.7 20.2993l-.0251.0083A13.9615 13.9615 0 0016 30zM5.5913 10L3.86 9a14.14 14.14 0 00-1.6382 4.5872l1.9677.3469A12.1519 12.1519 0 015.5913 10zM11.8164 4.7646L11.1328 2.887A13.976 13.976 0 006.9507 5.3278L8.2358 6.8593A11.9729 11.9729 0 0111.8164 4.7646z"
  })), children);
});
var WatsonHealthEdgeEnhancement_0224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEdgeEnhancement_0224(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H22V26a2.002 2.002 0 012-2h2V22H22V20h4a2.0023 2.0023 0 012 2v2a2.0023 2.0023 0 01-2 2H24v2h4zM28 16h2A14 14 0 0016 2V4A12 12 0 0128 16z"
  })), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 16A10 10 0 0016 6V16zM16 28A11.96 11.96 0 015.416 21.6548c-.0664-.127-.133-.2534-.1953-.3843-.0547-.1123-.106-.227-.1572-.3413A13.1207 13.1207 0 014.19 18l-1.9677.4131A13.9173 13.9173 0 002.7 20.2993l-.0251.0083A13.9615 13.9615 0 0016 30zM5.5913 10L3.86 9a14.14 14.14 0 00-1.6382 4.5872l1.9677.3469A12.1519 12.1519 0 015.5913 10zM11.8164 4.7646L11.1328 2.887A13.976 13.976 0 006.9507 5.3278L8.2358 6.8593A11.9729 11.9729 0 0111.8164 4.7646z"
  })), children);
});
var WatsonHealthEdgeEnhancement_0220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEdgeEnhancement_0220(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H22V26a2.002 2.002 0 012-2h2V22H22V20h4a2.0023 2.0023 0 012 2v2a2.0023 2.0023 0 01-2 2H24v2h4zM28 16h2A14 14 0 0016 2V4A12 12 0 0128 16z"
  })), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 16A10 10 0 0016 6V16zM16 28A11.96 11.96 0 015.416 21.6548c-.0664-.127-.133-.2534-.1953-.3843-.0547-.1123-.106-.227-.1572-.3413A13.1207 13.1207 0 014.19 18l-1.9677.4131A13.9173 13.9173 0 002.7 20.2993l-.0251.0083A13.9615 13.9615 0 0016 30zM5.5913 10L3.86 9a14.14 14.14 0 00-1.6382 4.5872l1.9677.3469A12.1519 12.1519 0 015.5913 10zM11.8164 4.7646L11.1328 2.887A13.976 13.976 0 006.9507 5.3278L8.2358 6.8593A11.9729 11.9729 0 0111.8164 4.7646z"
  })), children);
});
var WatsonHealthEdgeEnhancement_0216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEdgeEnhancement_0216(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H22V26a2.002 2.002 0 012-2h2V22H22V20h4a2.0023 2.0023 0 012 2v2a2.0023 2.0023 0 01-2 2H24v2h4zM28 16h2A14 14 0 0016 2V4A12 12 0 0128 16z"
  })), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 16A10 10 0 0016 6V16zM16 28A11.96 11.96 0 015.416 21.6548c-.0664-.127-.133-.2534-.1953-.3843-.0547-.1123-.106-.227-.1572-.3413A13.1207 13.1207 0 014.19 18l-1.9677.4131A13.9173 13.9173 0 002.7 20.2993l-.0251.0083A13.9615 13.9615 0 0016 30zM5.5913 10L3.86 9a14.14 14.14 0 00-1.6382 4.5872l1.9677.3469A12.1519 12.1519 0 015.5913 10zM11.8164 4.7646L11.1328 2.887A13.976 13.976 0 006.9507 5.3278L8.2358 6.8593A11.9729 11.9729 0 0111.8164 4.7646z"
  })), children);
});
var WatsonHealthEdgeEnhancement_0332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEdgeEnhancement_0332(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 20H22v2h4v2H23v2h3v2H22v2h4a2.0027 2.0027 0 002-2V22A2.0023 2.0023 0 0026 20zM28 16h2A14 14 0 0016 2V4A12 12 0 0128 16z"
  })), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 16A10 10 0 0016 6V16zM16 28A11.96 11.96 0 015.416 21.6548c-.0664-.127-.133-.2534-.1953-.3843-.0547-.1123-.106-.227-.1572-.3413A13.1207 13.1207 0 014.19 18l-1.9677.4131A13.9173 13.9173 0 002.7 20.2993l-.0251.0083A13.9615 13.9615 0 0016 30zM5.5913 10L3.86 9a14.14 14.14 0 00-1.6382 4.5872l1.9677.3469A12.1519 12.1519 0 015.5913 10zM11.8164 4.7646L11.1328 2.887A13.976 13.976 0 006.9507 5.3278L8.2358 6.8593A11.9729 11.9729 0 0111.8164 4.7646z"
  })), children);
});
var WatsonHealthEdgeEnhancement_0324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEdgeEnhancement_0324(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 20H22v2h4v2H23v2h3v2H22v2h4a2.0027 2.0027 0 002-2V22A2.0023 2.0023 0 0026 20zM28 16h2A14 14 0 0016 2V4A12 12 0 0128 16z"
  })), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 16A10 10 0 0016 6V16zM16 28A11.96 11.96 0 015.416 21.6548c-.0664-.127-.133-.2534-.1953-.3843-.0547-.1123-.106-.227-.1572-.3413A13.1207 13.1207 0 014.19 18l-1.9677.4131A13.9173 13.9173 0 002.7 20.2993l-.0251.0083A13.9615 13.9615 0 0016 30zM5.5913 10L3.86 9a14.14 14.14 0 00-1.6382 4.5872l1.9677.3469A12.1519 12.1519 0 015.5913 10zM11.8164 4.7646L11.1328 2.887A13.976 13.976 0 006.9507 5.3278L8.2358 6.8593A11.9729 11.9729 0 0111.8164 4.7646z"
  })), children);
});
var WatsonHealthEdgeEnhancement_0320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEdgeEnhancement_0320(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 20H22v2h4v2H23v2h3v2H22v2h4a2.0027 2.0027 0 002-2V22A2.0023 2.0023 0 0026 20zM28 16h2A14 14 0 0016 2V4A12 12 0 0128 16z"
  })), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 16A10 10 0 0016 6V16zM16 28A11.96 11.96 0 015.416 21.6548c-.0664-.127-.133-.2534-.1953-.3843-.0547-.1123-.106-.227-.1572-.3413A13.1207 13.1207 0 014.19 18l-1.9677.4131A13.9173 13.9173 0 002.7 20.2993l-.0251.0083A13.9615 13.9615 0 0016 30zM5.5913 10L3.86 9a14.14 14.14 0 00-1.6382 4.5872l1.9677.3469A12.1519 12.1519 0 015.5913 10zM11.8164 4.7646L11.1328 2.887A13.976 13.976 0 006.9507 5.3278L8.2358 6.8593A11.9729 11.9729 0 0111.8164 4.7646z"
  })), children);
});
var WatsonHealthEdgeEnhancement_0316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEdgeEnhancement_0316(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 20H22v2h4v2H23v2h3v2H22v2h4a2.0027 2.0027 0 002-2V22A2.0023 2.0023 0 0026 20zM28 16h2A14 14 0 0016 2V4A12 12 0 0128 16z"
  })), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 16A10 10 0 0016 6V16zM16 28A11.96 11.96 0 015.416 21.6548c-.0664-.127-.133-.2534-.1953-.3843-.0547-.1123-.106-.227-.1572-.3413A13.1207 13.1207 0 014.19 18l-1.9677.4131A13.9173 13.9173 0 002.7 20.2993l-.0251.0083A13.9615 13.9615 0 0016 30zM5.5913 10L3.86 9a14.14 14.14 0 00-1.6382 4.5872l1.9677.3469A12.1519 12.1519 0 015.5913 10zM11.8164 4.7646L11.1328 2.887A13.976 13.976 0 006.9507 5.3278L8.2358 6.8593A11.9729 11.9729 0 0111.8164 4.7646z"
  })), children);
});
var EdgeNode32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeNode32(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 6H26V10H22z"
  })), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "7",
    r: "1"
  })), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "25",
    r: "1"
  })), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "21",
    r: "1"
  })), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "17",
    r: "1"
  })), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,17V15H20V14a2.0023,2.0023,0,0,0-2-2H17V10H15v2H13V10H11v2H10a2.0023,2.0023,0,0,0-2,2v1H6v2H8v2H6v2H8v1a2.0023,2.0023,0,0,0,2,2h1v2h2V24h2v2h2V24h1a2.0023,2.0023,0,0,0,2-2V21h2V19H20V17Zm-4,5H10V14h8Z"
  })), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var EdgeNode24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeNode24(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 6H26V10H22z"
  })), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "7",
    r: "1"
  })), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "25",
    r: "1"
  })), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "21",
    r: "1"
  })), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "17",
    r: "1"
  })), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,17V15H20V14a2.0023,2.0023,0,0,0-2-2H17V10H15v2H13V10H11v2H10a2.0023,2.0023,0,0,0-2,2v1H6v2H8v2H6v2H8v1a2.0023,2.0023,0,0,0,2,2h1v2h2V24h2v2h2V24h1a2.0023,2.0023,0,0,0,2-2V21h2V19H20V17Zm-4,5H10V14h8Z"
  })), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var EdgeNode20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeNode20(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 6H26V10H22z"
  })), _circle21 || (_circle21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "7",
    r: "1"
  })), _circle22 || (_circle22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "25",
    r: "1"
  })), _circle23 || (_circle23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "21",
    r: "1"
  })), _circle24 || (_circle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "17",
    r: "1"
  })), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,17V15H20V14a2.0023,2.0023,0,0,0-2-2H17V10H15v2H13V10H11v2H10a2.0023,2.0023,0,0,0-2,2v1H6v2H8v2H6v2H8v1a2.0023,2.0023,0,0,0,2,2h1v2h2V24h2v2h2V24h1a2.0023,2.0023,0,0,0,2-2V21h2V19H20V17Zm-4,5H10V14h8Z"
  })), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var EdgeNode16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeNode16(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 6H26V10H22z"
  })), _circle25 || (_circle25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "7",
    r: "1"
  })), _circle26 || (_circle26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "25",
    r: "1"
  })), _circle27 || (_circle27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "21",
    r: "1"
  })), _circle28 || (_circle28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "17",
    r: "1"
  })), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,17V15H20V14a2.0023,2.0023,0,0,0-2-2H17V10H15v2H13V10H11v2H10a2.0023,2.0023,0,0,0-2,2v1H6v2H8v2H6v2H8v1a2.0023,2.0023,0,0,0,2,2h1v2h2V24h2v2h2V24h1a2.0023,2.0023,0,0,0,2-2V21h2V19H20V17Zm-4,5H10V14h8Z"
  })), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var EdgeNodeAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeNodeAlt32(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22a2.981,2.981,0,0,0-2.0374.811l-4.0039-2.4023a2.0429,2.0429,0,0,0,0-.8174l4.0039-2.4023A2.9909,2.9909,0,1,0,24,15a2.9345,2.9345,0,0,0,.0415.4092l-4.0039,2.4023a3,3,0,1,0,0,4.377l4.0039,2.4023A2.9345,2.9345,0,0,0,24,25a3,3,0,1,0,3-3Zm0-8a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,27,14Zm-9,7a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,18,21Zm9,5a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,27,26Z"
  })), _circle29 || (_circle29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "8",
    r: "1"
  })), _circle30 || (_circle30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "16",
    r: "1"
  })), _circle31 || (_circle31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "24",
    r: "1"
  })), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,13V5a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,5V27a2.0023,2.0023,0,0,0,2,2H20V27H4V21h8V19H4V13ZM4,5H20v6H4Z"
  })), children);
});
var EdgeNodeAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeNodeAlt24(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22a2.981,2.981,0,0,0-2.0374.811l-4.0039-2.4023a2.0429,2.0429,0,0,0,0-.8174l4.0039-2.4023A2.9909,2.9909,0,1,0,24,15a2.9345,2.9345,0,0,0,.0415.4092l-4.0039,2.4023a3,3,0,1,0,0,4.377l4.0039,2.4023A2.9345,2.9345,0,0,0,24,25a3,3,0,1,0,3-3Zm0-8a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,27,14Zm-9,7a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,18,21Zm9,5a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,27,26Z"
  })), _circle32 || (_circle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "8",
    r: "1"
  })), _circle33 || (_circle33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "16",
    r: "1"
  })), _circle34 || (_circle34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "24",
    r: "1"
  })), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,13V5a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,5V27a2.0023,2.0023,0,0,0,2,2H20V27H4V21h8V19H4V13ZM4,5H20v6H4Z"
  })), children);
});
var EdgeNodeAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeNodeAlt20(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22a2.981,2.981,0,0,0-2.0374.811l-4.0039-2.4023a2.0429,2.0429,0,0,0,0-.8174l4.0039-2.4023A2.9909,2.9909,0,1,0,24,15a2.9345,2.9345,0,0,0,.0415.4092l-4.0039,2.4023a3,3,0,1,0,0,4.377l4.0039,2.4023A2.9345,2.9345,0,0,0,24,25a3,3,0,1,0,3-3Zm0-8a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,27,14Zm-9,7a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,18,21Zm9,5a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,27,26Z"
  })), _circle35 || (_circle35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "8",
    r: "1"
  })), _circle36 || (_circle36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "16",
    r: "1"
  })), _circle37 || (_circle37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "24",
    r: "1"
  })), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,13V5a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,5V27a2.0023,2.0023,0,0,0,2,2H20V27H4V21h8V19H4V13ZM4,5H20v6H4Z"
  })), children);
});
var EdgeNodeAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeNodeAlt16(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22a2.981,2.981,0,0,0-2.0374.811l-4.0039-2.4023a2.0429,2.0429,0,0,0,0-.8174l4.0039-2.4023A2.9909,2.9909,0,1,0,24,15a2.9345,2.9345,0,0,0,.0415.4092l-4.0039,2.4023a3,3,0,1,0,0,4.377l4.0039,2.4023A2.9345,2.9345,0,0,0,24,25a3,3,0,1,0,3-3Zm0-8a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,27,14Zm-9,7a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,18,21Zm9,5a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,27,26Z"
  })), _circle38 || (_circle38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "8",
    r: "1"
  })), _circle39 || (_circle39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "16",
    r: "1"
  })), _circle40 || (_circle40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "24",
    r: "1"
  })), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,13V5a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,5V27a2.0023,2.0023,0,0,0,2,2H20V27H4V21h8V19H4V13ZM4,5H20v6H4Z"
  })), children);
});
var EdgeService32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeService32(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 11H9V21H7zM11 11H13V21H11zM15 11H17V21H15zM19 11H21V21H19zM23 11H25V21H23z"
  })), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H4a2.0023,2.0023,0,0,1-2-2V8A2.0023,2.0023,0,0,1,4,6H28a2.0023,2.0023,0,0,1,2,2V24A2.0023,2.0023,0,0,1,28,26ZM4,8V24H28V8Z"
  })), children);
});
var EdgeService24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeService24(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 11H9V21H7zM11 11H13V21H11zM15 11H17V21H15zM19 11H21V21H19zM23 11H25V21H23z"
  })), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H4a2.0023,2.0023,0,0,1-2-2V8A2.0023,2.0023,0,0,1,4,6H28a2.0023,2.0023,0,0,1,2,2V24A2.0023,2.0023,0,0,1,28,26ZM4,8V24H28V8Z"
  })), children);
});
var EdgeService20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeService20(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 11H9V21H7zM11 11H13V21H11zM15 11H17V21H15zM19 11H21V21H19zM23 11H25V21H23z"
  })), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H4a2.0023,2.0023,0,0,1-2-2V8A2.0023,2.0023,0,0,1,4,6H28a2.0023,2.0023,0,0,1,2,2V24A2.0023,2.0023,0,0,1,28,26ZM4,8V24H28V8Z"
  })), children);
});
var EdgeService16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdgeService16(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 11H9V21H7zM11 11H13V21H11zM15 11H17V21H15zM19 11H21V21H19zM23 11H25V21H23z"
  })), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H4a2.0023,2.0023,0,0,1-2-2V8A2.0023,2.0023,0,0,1,4,6H28a2.0023,2.0023,0,0,1,2,2V24A2.0023,2.0023,0,0,1,28,26ZM4,8V24H28V8Z"
  })), children);
});
var Edit32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Edit32(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26H30V28H2zM25.4 9c.8-.8.8-2 0-2.8 0 0 0 0 0 0l-3.6-3.6c-.8-.8-2-.8-2.8 0 0 0 0 0 0 0l-15 15V24h6.4L25.4 9zM20.4 4L24 7.6l-3 3L17.4 7 20.4 4zM6 22v-3.6l10-10 3.6 3.6-10 10H6z"
  })), children);
});
var Edit24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Edit24(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26H30V28H2zM25.4 9c.8-.8.8-2 0-2.8 0 0 0 0 0 0l-3.6-3.6c-.8-.8-2-.8-2.8 0 0 0 0 0 0 0l-15 15V24h6.4L25.4 9zM20.4 4L24 7.6l-3 3L17.4 7 20.4 4zM6 22v-3.6l10-10 3.6 3.6-10 10H6z"
  })), children);
});
var Edit20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Edit20(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26H30V28H2zM25.4 9c.8-.8.8-2 0-2.8 0 0 0 0 0 0l-3.6-3.6c-.8-.8-2-.8-2.8 0 0 0 0 0 0 0l-15 15V24h6.4L25.4 9zM20.4 4L24 7.6l-3 3L17.4 7 20.4 4zM6 22v-3.6l10-10 3.6 3.6-10 10H6z"
  })), children);
});
var Edit16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Edit16(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26H30V28H2zM25.4 9c.8-.8.8-2 0-2.8 0 0 0 0 0 0l-3.6-3.6c-.8-.8-2-.8-2.8 0 0 0 0 0 0 0l-15 15V24h6.4L25.4 9zM20.4 4L24 7.6l-3 3L17.4 7 20.4 4zM6 22v-3.6l10-10 3.6 3.6-10 10H6z"
  })), children);
});
var EditOff32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EditOff32(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 28.6L3.4 2 2 3.4l10.1 10.1L4 21.6V28h6.4l8.1-8.1L28.6 30 30 28.6zM9.6 26H6v-3.6l7.5-7.5 3.6 3.6L9.6 26zM29.4 6.2L29.4 6.2l-3.6-3.6c-.8-.8-2-.8-2.8 0l0 0 0 0-8 8 1.4 1.4L20 8.4l3.6 3.6L20 15.6l1.4 1.4 8-8C30.2 8.2 30.2 7 29.4 6.2L29.4 6.2zM25 10.6L21.4 7l3-3L28 7.6 25 10.6z"
  })), children);
});
var EditOff24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EditOff24(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 28.6L3.4 2 2 3.4l10.1 10.1L4 21.6V28h6.4l8.1-8.1L28.6 30 30 28.6zM9.6 26H6v-3.6l7.5-7.5 3.6 3.6L9.6 26zM29.4 6.2L29.4 6.2l-3.6-3.6c-.8-.8-2-.8-2.8 0l0 0 0 0-8 8 1.4 1.4L20 8.4l3.6 3.6L20 15.6l1.4 1.4 8-8C30.2 8.2 30.2 7 29.4 6.2L29.4 6.2zM25 10.6L21.4 7l3-3L28 7.6 25 10.6z"
  })), children);
});
var EditOff20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EditOff20(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 28.6L3.4 2 2 3.4l10.1 10.1L4 21.6V28h6.4l8.1-8.1L28.6 30 30 28.6zM9.6 26H6v-3.6l7.5-7.5 3.6 3.6L9.6 26zM29.4 6.2L29.4 6.2l-3.6-3.6c-.8-.8-2-.8-2.8 0l0 0 0 0-8 8 1.4 1.4L20 8.4l3.6 3.6L20 15.6l1.4 1.4 8-8C30.2 8.2 30.2 7 29.4 6.2L29.4 6.2zM25 10.6L21.4 7l3-3L28 7.6 25 10.6z"
  })), children);
});
var EditOff16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EditOff16(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 28.6L3.4 2 2 3.4l10.1 10.1L4 21.6V28h6.4l8.1-8.1L28.6 30 30 28.6zM9.6 26H6v-3.6l7.5-7.5 3.6 3.6L9.6 26zM29.4 6.2L29.4 6.2l-3.6-3.6c-.8-.8-2-.8-2.8 0l0 0 0 0-8 8 1.4 1.4L20 8.4l3.6 3.6L20 15.6l1.4 1.4 8-8C30.2 8.2 30.2 7 29.4 6.2L29.4 6.2zM25 10.6L21.4 7l3-3L28 7.6 25 10.6z"
  })), children);
});
var WatsonHealthEditFilter32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEditFilter32(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  if (true) {
    if (!didWarnAboutDeprecation['WatsonHealthEditFilter32']) {
      didWarnAboutDeprecation['WatsonHealthEditFilter32'] = true;
      console.warn("The WatsonHealthEditFilter32 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6H4V9.17l7.41,7.42.59.58V26h4V24h2v2a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V18L2.59,10.59A2,2,0,0,1,2,9.17V6A2,2,0,0,1,4,4H26Z"
  })), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.71,11.29l-3-3a1,1,0,0,0-1.42,0L16,17.59V22h4.41l9.3-9.29A1,1,0,0,0,29.71,11.29ZM19.59,20H18V18.41l5-5L24.59,15ZM26,13.59,24.41,12,26,10.41,27.59,12Z"
  })), children);
});
var WatsonHealthEditFilter24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEditFilter24(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  if (true) {
    if (!didWarnAboutDeprecation['WatsonHealthEditFilter24']) {
      didWarnAboutDeprecation['WatsonHealthEditFilter24'] = true;
      console.warn("The WatsonHealthEditFilter24 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6H4V9.17l7.41,7.42.59.58V26h4V24h2v2a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V18L2.59,10.59A2,2,0,0,1,2,9.17V6A2,2,0,0,1,4,4H26Z"
  })), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.71,11.29l-3-3a1,1,0,0,0-1.42,0L16,17.59V22h4.41l9.3-9.29A1,1,0,0,0,29.71,11.29ZM19.59,20H18V18.41l5-5L24.59,15ZM26,13.59,24.41,12,26,10.41,27.59,12Z"
  })), children);
});
var WatsonHealthEditFilter20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEditFilter20(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  if (true) {
    if (!didWarnAboutDeprecation['WatsonHealthEditFilter20']) {
      didWarnAboutDeprecation['WatsonHealthEditFilter20'] = true;
      console.warn("The WatsonHealthEditFilter20 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6H4V9.17l7.41,7.42.59.58V26h4V24h2v2a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V18L2.59,10.59A2,2,0,0,1,2,9.17V6A2,2,0,0,1,4,4H26Z"
  })), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.71,11.29l-3-3a1,1,0,0,0-1.42,0L16,17.59V22h4.41l9.3-9.29A1,1,0,0,0,29.71,11.29ZM19.59,20H18V18.41l5-5L24.59,15ZM26,13.59,24.41,12,26,10.41,27.59,12Z"
  })), children);
});
var WatsonHealthEditFilter16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthEditFilter16(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  if (true) {
    if (!didWarnAboutDeprecation['WatsonHealthEditFilter16']) {
      didWarnAboutDeprecation['WatsonHealthEditFilter16'] = true;
      console.warn("The WatsonHealthEditFilter16 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6H4V9.17l7.41,7.42.59.58V26h4V24h2v2a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V18L2.59,10.59A2,2,0,0,1,2,9.17V6A2,2,0,0,1,4,4H26Z"
  })), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.71,11.29l-3-3a1,1,0,0,0-1.42,0L16,17.59V22h4.41l9.3-9.29A1,1,0,0,0,29.71,11.29ZM19.59,20H18V18.41l5-5L24.59,15ZM26,13.59,24.41,12,26,10.41,27.59,12Z"
  })), children);
});
var EdtLoop32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdtLoop32(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.625,22.5875a6.1287,6.1287,0,0,1-4.5-1.9l-3.1-3.2-3.1,3.2a6.4582,6.4582,0,0,1-9.1,0,7.028,7.028,0,0,1-1.8-4.7,6.6547,6.6547,0,0,1,1.9-4.7,6.3375,6.3375,0,0,1,9,0l3.1,3.2,3.1-3.2a6.3375,6.3375,0,0,1,9,0,6.8282,6.8282,0,0,1,0,9.4A6.5418,6.5418,0,0,1,23.625,22.5875Zm-6.2-6.6,3.1,3.3a4.4061,4.4061,0,0,0,6.2,0,4.9077,4.9077,0,0,0,0-6.6,4.4061,4.4061,0,0,0-6.2,0Zm-9-4.6a4.1582,4.1582,0,0,0-3.1,1.3,4.8385,4.8385,0,0,0,0,6.6,4.4061,4.4061,0,0,0,6.2,0l3.1-3.3-3.1-3.3A4.7706,4.7706,0,0,0,8.425,11.3875Z"
  })), children);
});
var EdtLoop24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdtLoop24(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.625,22.5875a6.1287,6.1287,0,0,1-4.5-1.9l-3.1-3.2-3.1,3.2a6.4582,6.4582,0,0,1-9.1,0,7.028,7.028,0,0,1-1.8-4.7,6.6547,6.6547,0,0,1,1.9-4.7,6.3375,6.3375,0,0,1,9,0l3.1,3.2,3.1-3.2a6.3375,6.3375,0,0,1,9,0,6.8282,6.8282,0,0,1,0,9.4A6.5418,6.5418,0,0,1,23.625,22.5875Zm-6.2-6.6,3.1,3.3a4.4061,4.4061,0,0,0,6.2,0,4.9077,4.9077,0,0,0,0-6.6,4.4061,4.4061,0,0,0-6.2,0Zm-9-4.6a4.1582,4.1582,0,0,0-3.1,1.3,4.8385,4.8385,0,0,0,0,6.6,4.4061,4.4061,0,0,0,6.2,0l3.1-3.3-3.1-3.3A4.7706,4.7706,0,0,0,8.425,11.3875Z"
  })), children);
});
var EdtLoop20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdtLoop20(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.625,22.5875a6.1287,6.1287,0,0,1-4.5-1.9l-3.1-3.2-3.1,3.2a6.4582,6.4582,0,0,1-9.1,0,7.028,7.028,0,0,1-1.8-4.7,6.6547,6.6547,0,0,1,1.9-4.7,6.3375,6.3375,0,0,1,9,0l3.1,3.2,3.1-3.2a6.3375,6.3375,0,0,1,9,0,6.8282,6.8282,0,0,1,0,9.4A6.5418,6.5418,0,0,1,23.625,22.5875Zm-6.2-6.6,3.1,3.3a4.4061,4.4061,0,0,0,6.2,0,4.9077,4.9077,0,0,0,0-6.6,4.4061,4.4061,0,0,0-6.2,0Zm-9-4.6a4.1582,4.1582,0,0,0-3.1,1.3,4.8385,4.8385,0,0,0,0,6.6,4.4061,4.4061,0,0,0,6.2,0l3.1-3.3-3.1-3.3A4.7706,4.7706,0,0,0,8.425,11.3875Z"
  })), children);
});
var EdtLoop16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EdtLoop16(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.625,22.5875a6.1287,6.1287,0,0,1-4.5-1.9l-3.1-3.2-3.1,3.2a6.4582,6.4582,0,0,1-9.1,0,7.028,7.028,0,0,1-1.8-4.7,6.6547,6.6547,0,0,1,1.9-4.7,6.3375,6.3375,0,0,1,9,0l3.1,3.2,3.1-3.2a6.3375,6.3375,0,0,1,9,0,6.8282,6.8282,0,0,1,0,9.4A6.5418,6.5418,0,0,1,23.625,22.5875Zm-6.2-6.6,3.1,3.3a4.4061,4.4061,0,0,0,6.2,0,4.9077,4.9077,0,0,0,0-6.6,4.4061,4.4061,0,0,0-6.2,0Zm-9-4.6a4.1582,4.1582,0,0,0-3.1,1.3,4.8385,4.8385,0,0,0,0,6.6,4.4061,4.4061,0,0,0,6.2,0l3.1-3.3-3.1-3.3A4.7706,4.7706,0,0,0,8.425,11.3875Z"
  })), children);
});
var Education32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Education32(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 30H24V27a5.0059 5.0059 0 00-5-5H13a5.0059 5.0059 0 00-5 5v3H6V27a7.0082 7.0082 0 017-7h6a7.0082 7.0082 0 017 7zM5 6A1 1 0 004 7v9H6V7A1 1 0 005 6z"
  })), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2V4H9v7a7,7,0,0,0,14,0V4h5V2Zm7,2H21V7H11Zm5,12a5,5,0,0,1-5-5V9H21v2A5,5,0,0,1,16,16Z"
  })), children);
});
var Education24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Education24(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 30H24V27a5.0059 5.0059 0 00-5-5H13a5.0059 5.0059 0 00-5 5v3H6V27a7.0082 7.0082 0 017-7h6a7.0082 7.0082 0 017 7zM5 6A1 1 0 004 7v9H6V7A1 1 0 005 6z"
  })), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2V4H9v7a7,7,0,0,0,14,0V4h5V2Zm7,2H21V7H11Zm5,12a5,5,0,0,1-5-5V9H21v2A5,5,0,0,1,16,16Z"
  })), children);
});
var Education20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Education20(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 30H24V27a5.0059 5.0059 0 00-5-5H13a5.0059 5.0059 0 00-5 5v3H6V27a7.0082 7.0082 0 017-7h6a7.0082 7.0082 0 017 7zM5 6A1 1 0 004 7v9H6V7A1 1 0 005 6z"
  })), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2V4H9v7a7,7,0,0,0,14,0V4h5V2Zm7,2H21V7H11Zm5,12a5,5,0,0,1-5-5V9H21v2A5,5,0,0,1,16,16Z"
  })), children);
});
var Education16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Education16(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 30H24V27a5.0059 5.0059 0 00-5-5H13a5.0059 5.0059 0 00-5 5v3H6V27a7.0082 7.0082 0 017-7h6a7.0082 7.0082 0 017 7zM5 6A1 1 0 004 7v9H6V7A1 1 0 005 6z"
  })), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2V4H9v7a7,7,0,0,0,14,0V4h5V2Zm7,2H21V7H11Zm5,12a5,5,0,0,1-5-5V9H21v2A5,5,0,0,1,16,16Z"
  })), children);
});
var Email32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Email32(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM25.8,8,16,14.78,6.2,8ZM4,24V8.91l11.43,7.91a1,1,0,0,0,1.14,0L28,8.91V24Z"
  })), children);
});
var Email24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Email24(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM25.8,8,16,14.78,6.2,8ZM4,24V8.91l11.43,7.91a1,1,0,0,0,1.14,0L28,8.91V24Z"
  })), children);
});
var Email20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Email20(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM25.8,8,16,14.78,6.2,8ZM4,24V8.91l11.43,7.91a1,1,0,0,0,1.14,0L28,8.91V24Z"
  })), children);
});
var Email16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Email16(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM25.8,8,16,14.78,6.2,8ZM4,24V8.91l11.43,7.91a1,1,0,0,0,1.14,0L28,8.91V24Z"
  })), children);
});
var EmailNew32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EmailNew32(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,24H4L3.9966,8.9062l11.4341,7.9161a1.0008,1.0008,0,0,0,1.1386,0L28,8.9087,28,18h2V8a2.0027,2.0027,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,8V24a2.0027,2.0027,0,0,0,2,2H19ZM25.7986,8,16,14.7837,6.2014,8Z"
  })), _circle41 || (_circle41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "24",
    r: "4"
  })), children);
});
var EmailNew24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EmailNew24(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,24H4L3.9966,8.9062l11.4341,7.9161a1.0008,1.0008,0,0,0,1.1386,0L28,8.9087,28,18h2V8a2.0027,2.0027,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,8V24a2.0027,2.0027,0,0,0,2,2H19ZM25.7986,8,16,14.7837,6.2014,8Z"
  })), _circle42 || (_circle42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "24",
    r: "4"
  })), children);
});
var EmailNew20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EmailNew20(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,24H4L3.9966,8.9062l11.4341,7.9161a1.0008,1.0008,0,0,0,1.1386,0L28,8.9087,28,18h2V8a2.0027,2.0027,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,8V24a2.0027,2.0027,0,0,0,2,2H19ZM25.7986,8,16,14.7837,6.2014,8Z"
  })), _circle43 || (_circle43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "24",
    r: "4"
  })), children);
});
var EmailNew16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EmailNew16(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,24H4L3.9966,8.9062l11.4341,7.9161a1.0008,1.0008,0,0,0,1.1386,0L28,8.9087,28,18h2V8a2.0027,2.0027,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,8V24a2.0027,2.0027,0,0,0,2,2H19ZM25.7986,8,16,14.7837,6.2014,8Z"
  })), _circle44 || (_circle44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "24",
    r: "4"
  })), children);
});
var Encryption32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Encryption32(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 21.2783V19a4 4 0 00-8 0v2.2783A1.9935 1.9935 0 0020 23v5a2.0025 2.0025 0 002 2h6a2.0025 2.0025 0 002-2V23A1.9935 1.9935 0 0029 21.2783zM25 17a2.0025 2.0025 0 012 2v2H23V19A2.0025 2.0025 0 0125 17zM22 28V23h6v5zM2 2H4V6H2zM14 2H16V6H14zM18 2H20V6H18zM2 8H4V16H2zM2 18H4V26H2zM14 18H16V26H14zM6 8H8V16H6zM18 8H20V14H18zM10 26H8a2.0023 2.0023 0 01-2-2V20a2.0023 2.0023 0 012-2h2a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0110 26zM8 20v4h2V20zM14 16H12a2.0023 2.0023 0 01-2-2V10a2.0023 2.0023 0 012-2h2a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0114 16zm-2-6v4h2V10zM10 6H8A2.0023 2.0023 0 016 4V2H8V4h2V2h2V4A2.0023 2.0023 0 0110 6z"
  })), children);
});
var Encryption24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Encryption24(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 21.2783V19a4 4 0 00-8 0v2.2783A1.9935 1.9935 0 0020 23v5a2.0025 2.0025 0 002 2h6a2.0025 2.0025 0 002-2V23A1.9935 1.9935 0 0029 21.2783zM25 17a2.0025 2.0025 0 012 2v2H23V19A2.0025 2.0025 0 0125 17zM22 28V23h6v5zM2 2H4V6H2zM14 2H16V6H14zM18 2H20V6H18zM2 8H4V16H2zM2 18H4V26H2zM14 18H16V26H14zM6 8H8V16H6zM18 8H20V14H18zM10 26H8a2.0023 2.0023 0 01-2-2V20a2.0023 2.0023 0 012-2h2a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0110 26zM8 20v4h2V20zM14 16H12a2.0023 2.0023 0 01-2-2V10a2.0023 2.0023 0 012-2h2a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0114 16zm-2-6v4h2V10zM10 6H8A2.0023 2.0023 0 016 4V2H8V4h2V2h2V4A2.0023 2.0023 0 0110 6z"
  })), children);
});
var Encryption20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Encryption20(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 21.2783V19a4 4 0 00-8 0v2.2783A1.9935 1.9935 0 0020 23v5a2.0025 2.0025 0 002 2h6a2.0025 2.0025 0 002-2V23A1.9935 1.9935 0 0029 21.2783zM25 17a2.0025 2.0025 0 012 2v2H23V19A2.0025 2.0025 0 0125 17zM22 28V23h6v5zM2 2H4V6H2zM14 2H16V6H14zM18 2H20V6H18zM2 8H4V16H2zM2 18H4V26H2zM14 18H16V26H14zM6 8H8V16H6zM18 8H20V14H18zM10 26H8a2.0023 2.0023 0 01-2-2V20a2.0023 2.0023 0 012-2h2a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0110 26zM8 20v4h2V20zM14 16H12a2.0023 2.0023 0 01-2-2V10a2.0023 2.0023 0 012-2h2a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0114 16zm-2-6v4h2V10zM10 6H8A2.0023 2.0023 0 016 4V2H8V4h2V2h2V4A2.0023 2.0023 0 0110 6z"
  })), children);
});
var Encryption16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Encryption16(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 21.2783V19a4 4 0 00-8 0v2.2783A1.9935 1.9935 0 0020 23v5a2.0025 2.0025 0 002 2h6a2.0025 2.0025 0 002-2V23A1.9935 1.9935 0 0029 21.2783zM25 17a2.0025 2.0025 0 012 2v2H23V19A2.0025 2.0025 0 0125 17zM22 28V23h6v5zM2 2H4V6H2zM14 2H16V6H14zM18 2H20V6H18zM2 8H4V16H2zM2 18H4V26H2zM14 18H16V26H14zM6 8H8V16H6zM18 8H20V14H18zM10 26H8a2.0023 2.0023 0 01-2-2V20a2.0023 2.0023 0 012-2h2a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0110 26zM8 20v4h2V20zM14 16H12a2.0023 2.0023 0 01-2-2V10a2.0023 2.0023 0 012-2h2a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0114 16zm-2-6v4h2V10zM10 6H8A2.0023 2.0023 0 016 4V2H8V4h2V2h2V4A2.0023 2.0023 0 0110 6z"
  })), children);
});
var EnergyRenewable32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EnergyRenewable32(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,14H28V10H26v4H24V10H22v4H21a1,1,0,0,0-1,1v4a5.0079,5.0079,0,0,0,4,4.8989V27a1.0008,1.0008,0,0,1-1,1H5a1,1,0,0,1,0-2h5a3,3,0,0,0,0-6H5a1,1,0,0,1,0-2h5a3.0033,3.0033,0,0,0,3-3V11h1a4.0045,4.0045,0,0,0,4-4V4H15a3.979,3.979,0,0,0-2.7468,1.1064A6.0041,6.0041,0,0,0,7,2H4V5a6.0066,6.0066,0,0,0,6,6h1v4a1.0008,1.0008,0,0,1-1,1H5a3,3,0,0,0,0,6h5a1,1,0,0,1,0,2H5a3,3,0,0,0,0,6H23a3.0033,3.0033,0,0,0,3-3V23.8989A5.0079,5.0079,0,0,0,30,19V15A1,1,0,0,0,29,14ZM13,8a2.002,2.002,0,0,1,2-2h1V7a2.002,2.002,0,0,1-2,2H13ZM10,9A4.0045,4.0045,0,0,1,6,5V4H7a4.0045,4.0045,0,0,1,4,4V9ZM28,19a3,3,0,0,1-6,0V16h6Z"
  })), children);
});
var EnergyRenewable24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EnergyRenewable24(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,14H28V10H26v4H24V10H22v4H21a1,1,0,0,0-1,1v4a5.0079,5.0079,0,0,0,4,4.8989V27a1.0008,1.0008,0,0,1-1,1H5a1,1,0,0,1,0-2h5a3,3,0,0,0,0-6H5a1,1,0,0,1,0-2h5a3.0033,3.0033,0,0,0,3-3V11h1a4.0045,4.0045,0,0,0,4-4V4H15a3.979,3.979,0,0,0-2.7468,1.1064A6.0041,6.0041,0,0,0,7,2H4V5a6.0066,6.0066,0,0,0,6,6h1v4a1.0008,1.0008,0,0,1-1,1H5a3,3,0,0,0,0,6h5a1,1,0,0,1,0,2H5a3,3,0,0,0,0,6H23a3.0033,3.0033,0,0,0,3-3V23.8989A5.0079,5.0079,0,0,0,30,19V15A1,1,0,0,0,29,14ZM13,8a2.002,2.002,0,0,1,2-2h1V7a2.002,2.002,0,0,1-2,2H13ZM10,9A4.0045,4.0045,0,0,1,6,5V4H7a4.0045,4.0045,0,0,1,4,4V9ZM28,19a3,3,0,0,1-6,0V16h6Z"
  })), children);
});
var EnergyRenewable20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EnergyRenewable20(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,14H28V10H26v4H24V10H22v4H21a1,1,0,0,0-1,1v4a5.0079,5.0079,0,0,0,4,4.8989V27a1.0008,1.0008,0,0,1-1,1H5a1,1,0,0,1,0-2h5a3,3,0,0,0,0-6H5a1,1,0,0,1,0-2h5a3.0033,3.0033,0,0,0,3-3V11h1a4.0045,4.0045,0,0,0,4-4V4H15a3.979,3.979,0,0,0-2.7468,1.1064A6.0041,6.0041,0,0,0,7,2H4V5a6.0066,6.0066,0,0,0,6,6h1v4a1.0008,1.0008,0,0,1-1,1H5a3,3,0,0,0,0,6h5a1,1,0,0,1,0,2H5a3,3,0,0,0,0,6H23a3.0033,3.0033,0,0,0,3-3V23.8989A5.0079,5.0079,0,0,0,30,19V15A1,1,0,0,0,29,14ZM13,8a2.002,2.002,0,0,1,2-2h1V7a2.002,2.002,0,0,1-2,2H13ZM10,9A4.0045,4.0045,0,0,1,6,5V4H7a4.0045,4.0045,0,0,1,4,4V9ZM28,19a3,3,0,0,1-6,0V16h6Z"
  })), children);
});
var EnergyRenewable16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EnergyRenewable16(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,14H28V10H26v4H24V10H22v4H21a1,1,0,0,0-1,1v4a5.0079,5.0079,0,0,0,4,4.8989V27a1.0008,1.0008,0,0,1-1,1H5a1,1,0,0,1,0-2h5a3,3,0,0,0,0-6H5a1,1,0,0,1,0-2h5a3.0033,3.0033,0,0,0,3-3V11h1a4.0045,4.0045,0,0,0,4-4V4H15a3.979,3.979,0,0,0-2.7468,1.1064A6.0041,6.0041,0,0,0,7,2H4V5a6.0066,6.0066,0,0,0,6,6h1v4a1.0008,1.0008,0,0,1-1,1H5a3,3,0,0,0,0,6h5a1,1,0,0,1,0,2H5a3,3,0,0,0,0,6H23a3.0033,3.0033,0,0,0,3-3V23.8989A5.0079,5.0079,0,0,0,30,19V15A1,1,0,0,0,29,14ZM13,8a2.002,2.002,0,0,1,2-2h1V7a2.002,2.002,0,0,1-2,2H13ZM10,9A4.0045,4.0045,0,0,1,6,5V4H7a4.0045,4.0045,0,0,1,4,4V9ZM28,19a3,3,0,0,1-6,0V16h6Z"
  })), children);
});
var Enterprise32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Enterprise32(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8H10V12H8zM8 14H10V18H8zM14 8H16V12H14zM14 14H16V18H14zM8 20H10V24H8zM14 20H16V24H14z"
  })), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,14a2,2,0,0,0-2-2H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V30H30ZM4,4H20V28H4ZM22,28V14h6V28Z"
  })), children);
});
var Enterprise24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Enterprise24(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8H10V12H8zM8 14H10V18H8zM14 8H16V12H14zM14 14H16V18H14zM8 20H10V24H8zM14 20H16V24H14z"
  })), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,14a2,2,0,0,0-2-2H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V30H30ZM4,4H20V28H4ZM22,28V14h6V28Z"
  })), children);
});
var Enterprise20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Enterprise20(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8H10V12H8zM8 14H10V18H8zM14 8H16V12H14zM14 14H16V18H14zM8 20H10V24H8zM14 20H16V24H14z"
  })), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,14a2,2,0,0,0-2-2H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V30H30ZM4,4H20V28H4ZM22,28V14h6V28Z"
  })), children);
});
var Enterprise16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Enterprise16(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8H10V12H8zM8 14H10V18H8zM14 8H16V12H14zM14 14H16V18H14zM8 20H10V24H8zM14 20H16V24H14z"
  })), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,14a2,2,0,0,0-2-2H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V30H30ZM4,4H20V28H4ZM22,28V14h6V28Z"
  })), children);
});
var Equalizer32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Equalizer32(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H10V30H2zM2 24H10V26H2zM12 28H20V30H12zM12 24H20V26H12zM2 20H10V22H2zM12 20H20V22H12zM2 16H10V18H2zM12 16H20V18H12zM12 12H20V14H12zM12 8H20V10H12zM12 4H20V6H12zM22 28H30V30H22zM22 24H30V26H22z"
  })), children);
});
var Equalizer24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Equalizer24(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H10V30H2zM2 24H10V26H2zM12 28H20V30H12zM12 24H20V26H12zM2 20H10V22H2zM12 20H20V22H12zM2 16H10V18H2zM12 16H20V18H12zM12 12H20V14H12zM12 8H20V10H12zM12 4H20V6H12zM22 28H30V30H22zM22 24H30V26H22z"
  })), children);
});
var Equalizer20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Equalizer20(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H10V30H2zM2 24H10V26H2zM12 28H20V30H12zM12 24H20V26H12zM2 20H10V22H2zM12 20H20V22H12zM2 16H10V18H2zM12 16H20V18H12zM12 12H20V14H12zM12 8H20V10H12zM12 4H20V6H12zM22 28H30V30H22zM22 24H30V26H22z"
  })), children);
});
var Equalizer16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Equalizer16(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H10V30H2zM2 24H10V26H2zM12 28H20V30H12zM12 24H20V26H12zM2 20H10V22H2zM12 20H20V22H12zM2 16H10V18H2zM12 16H20V18H12zM12 12H20V14H12zM12 8H20V10H12zM12 4H20V6H12zM22 28H30V30H22zM22 24H30V26H22z"
  })), children);
});
var Erase32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Erase32(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 27H30V29H7zM27.38 10.51L19.45 2.59a2 2 0 00-2.83 0l-14 14a2 2 0 000 2.83L7.13 24h9.59L27.38 13.34A2 2 0 0027.38 10.51zM15.89 22H8L4 18l6.31-6.31 7.93 7.92zm3.76-3.76l-7.92-7.93L18 4 26 11.93z"
  })), children);
});
var Erase24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Erase24(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 27H30V29H7zM27.38 10.51L19.45 2.59a2 2 0 00-2.83 0l-14 14a2 2 0 000 2.83L7.13 24h9.59L27.38 13.34A2 2 0 0027.38 10.51zM15.89 22H8L4 18l6.31-6.31 7.93 7.92zm3.76-3.76l-7.92-7.93L18 4 26 11.93z"
  })), children);
});
var Erase20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Erase20(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 27H30V29H7zM27.38 10.51L19.45 2.59a2 2 0 00-2.83 0l-14 14a2 2 0 000 2.83L7.13 24h9.59L27.38 13.34A2 2 0 0027.38 10.51zM15.89 22H8L4 18l6.31-6.31 7.93 7.92zm3.76-3.76l-7.92-7.93L18 4 26 11.93z"
  })), children);
});
var Erase16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Erase16(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 27H30V29H7zM27.38 10.51L19.45 2.59a2 2 0 00-2.83 0l-14 14a2 2 0 000 2.83L7.13 24h9.59L27.38 13.34A2 2 0 0027.38 10.51zM15.89 22H8L4 18l6.31-6.31 7.93 7.92zm3.76-3.76l-7.92-7.93L18 4 26 11.93z"
  })), children);
});
var WatsonHealthErase_3D32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthErase_3D32(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4148 16.5132L22.488 8.5859a2.0014 2.0014 0 00-2.8291 0L5.6208 22.624a2.0024 2.0024 0 000 2.8291L10.1663 30h9.5908L30.4148 19.3413A2.001 2.001 0 0030.4148 16.5132zM18.929 28H10.9949l-3.96-3.9619 6.3123-6.3118 7.9276 7.9276zm3.76-3.76l-7.9276-7.9276L21.074 10l7.9267 7.9272zM11 12H8V2h3a3.0033 3.0033 0 013 3V9A3.0033 3.0033 0 0111 12zm-1-2h1a1.0009 1.0009 0 001-1V5a1.0009 1.0009 0 00-1-1H10zM4 2H0V4H4V6H1V8H4v2H0v2H4a2.0027 2.0027 0 002-2V4A2.0023 2.0023 0 004 2z"
  })), children);
});
var WatsonHealthErase_3D24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthErase_3D24(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4148 16.5132L22.488 8.5859a2.0014 2.0014 0 00-2.8291 0L5.6208 22.624a2.0024 2.0024 0 000 2.8291L10.1663 30h9.5908L30.4148 19.3413A2.001 2.001 0 0030.4148 16.5132zM18.929 28H10.9949l-3.96-3.9619 6.3123-6.3118 7.9276 7.9276zm3.76-3.76l-7.9276-7.9276L21.074 10l7.9267 7.9272zM11 12H8V2h3a3.0033 3.0033 0 013 3V9A3.0033 3.0033 0 0111 12zm-1-2h1a1.0009 1.0009 0 001-1V5a1.0009 1.0009 0 00-1-1H10zM4 2H0V4H4V6H1V8H4v2H0v2H4a2.0027 2.0027 0 002-2V4A2.0023 2.0023 0 004 2z"
  })), children);
});
var WatsonHealthErase_3D20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthErase_3D20(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4148 16.5132L22.488 8.5859a2.0014 2.0014 0 00-2.8291 0L5.6208 22.624a2.0024 2.0024 0 000 2.8291L10.1663 30h9.5908L30.4148 19.3413A2.001 2.001 0 0030.4148 16.5132zM18.929 28H10.9949l-3.96-3.9619 6.3123-6.3118 7.9276 7.9276zm3.76-3.76l-7.9276-7.9276L21.074 10l7.9267 7.9272zM11 12H8V2h3a3.0033 3.0033 0 013 3V9A3.0033 3.0033 0 0111 12zm-1-2h1a1.0009 1.0009 0 001-1V5a1.0009 1.0009 0 00-1-1H10zM4 2H0V4H4V6H1V8H4v2H0v2H4a2.0027 2.0027 0 002-2V4A2.0023 2.0023 0 004 2z"
  })), children);
});
var WatsonHealthErase_3D16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthErase_3D16(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4148 16.5132L22.488 8.5859a2.0014 2.0014 0 00-2.8291 0L5.6208 22.624a2.0024 2.0024 0 000 2.8291L10.1663 30h9.5908L30.4148 19.3413A2.001 2.001 0 0030.4148 16.5132zM18.929 28H10.9949l-3.96-3.9619 6.3123-6.3118 7.9276 7.9276zm3.76-3.76l-7.9276-7.9276L21.074 10l7.9267 7.9272zM11 12H8V2h3a3.0033 3.0033 0 013 3V9A3.0033 3.0033 0 0111 12zm-1-2h1a1.0009 1.0009 0 001-1V5a1.0009 1.0009 0 00-1-1H10zM4 2H0V4H4V6H1V8H4v2H0v2H4a2.0027 2.0027 0 002-2V4A2.0023 2.0023 0 004 2z"
  })), children);
});
var Error32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Error32(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2,16H2A14,14,0,1,0,16,2,14,14,0,0,0,2,16Zm23.15,7.75L8.25,6.85a12,12,0,0,1,16.9,16.9ZM8.24,25.16A12,12,0,0,1,6.84,8.27L23.73,25.16a12,12,0,0,1-15.49,0Z"
  })), children);
});
var Error24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Error24(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2,16H2A14,14,0,1,0,16,2,14,14,0,0,0,2,16Zm23.15,7.75L8.25,6.85a12,12,0,0,1,16.9,16.9ZM8.24,25.16A12,12,0,0,1,6.84,8.27L23.73,25.16a12,12,0,0,1-15.49,0Z"
  })), children);
});
var Error20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Error20(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2,16H2A14,14,0,1,0,16,2,14,14,0,0,0,2,16Zm23.15,7.75L8.25,6.85a12,12,0,0,1,16.9,16.9ZM8.24,25.16A12,12,0,0,1,6.84,8.27L23.73,25.16a12,12,0,0,1-15.49,0Z"
  })), children);
});
var Error16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Error16(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2,16H2A14,14,0,1,0,16,2,14,14,0,0,0,2,16Zm23.15,7.75L8.25,6.85a12,12,0,0,1,16.9,16.9ZM8.24,25.16A12,12,0,0,1,6.84,8.27L23.73,25.16a12,12,0,0,1-15.49,0Z"
  })), children);
});
var ErrorFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ErrorFilled32(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M14.9 7.2H17.1V24.799H14.9z",
    "data-icon-path": "inner-path",
    transform: "rotate(-45 16 16)"
  })), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.914,13.914,0,0,0,2,16,13.914,13.914,0,0,0,16,30,13.914,13.914,0,0,0,30,16,13.914,13.914,0,0,0,16,2Zm5.4449,21L9,10.5557,10.5557,9,23,21.4448Z"
  })), children);
});
var ErrorFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ErrorFilled24(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 24 24",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,1C5.9,1,1,5.9,1,12s4.9,11,11,11s11-4.9,11-11S18.1,1,12,1z M16.3,17.5L6.5,7.7l1.2-1.2l9.8,9.8L16.3,17.5z"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16.3,17.5L6.5,7.7l1.2-1.2l9.8,9.8L16.3,17.5z",
    "data-icon-path": "inner-path",
    opacity: "0"
  })), children);
});
var ErrorFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ErrorFilled20(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 20 20",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,1c-5,0-9,4-9,9s4,9,9,9s9-4,9-9S15,1,10,1z M13.5,14.5l-8-8l1-1l8,8L13.5,14.5z"
  })), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.5,14.5l-8-8l1-1l8,8L13.5,14.5z",
    "data-icon-path": "inner-path",
    opacity: "0"
  })), children);
});
var ErrorFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ErrorFilled16(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,1C4.1,1,1,4.1,1,8s3.1,7,7,7s7-3.1,7-7S11.9,1,8,1z M10.7,11.5L4.5,5.3l0.8-0.8l6.2,6.2L10.7,11.5z"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M10.7,11.5L4.5,5.3l0.8-0.8l6.2,6.2L10.7,11.5z",
    "data-icon-path": "inner-path",
    opacity: "0"
  })), children);
});
var ErrorOutline32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ErrorOutline32(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.9 7.2H17.1V24.799H14.9z",
    transform: "rotate(-45 16 16)"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9138,13.9138,0,0,0,2,16,13.9138,13.9138,0,0,0,16,30,13.9138,13.9138,0,0,0,30,16,13.9138,13.9138,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12.0353,12.0353,0,0,1,16,28Z"
  })), children);
});
var ErrorOutline24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ErrorOutline24(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.9 7.2H17.1V24.799H14.9z",
    transform: "rotate(-45 16 16)"
  })), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9138,13.9138,0,0,0,2,16,13.9138,13.9138,0,0,0,16,30,13.9138,13.9138,0,0,0,30,16,13.9138,13.9138,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12.0353,12.0353,0,0,1,16,28Z"
  })), children);
});
var ErrorOutline20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ErrorOutline20(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.9 7.2H17.1V24.799H14.9z",
    transform: "rotate(-45 16 16)"
  })), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9138,13.9138,0,0,0,2,16,13.9138,13.9138,0,0,0,16,30,13.9138,13.9138,0,0,0,30,16,13.9138,13.9138,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12.0353,12.0353,0,0,1,16,28Z"
  })), children);
});
var ErrorOutline16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ErrorOutline16(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,1C4.1,1,1,4.1,1,8s3.1,7,7,7s7-3.1,7-7S11.9,1,8,1z M8,14c-3.3,0-6-2.7-6-6s2.7-6,6-6s6,2.7,6,6S11.3,14,8,14z"
  })), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.4 3.6H8.5V12.4H7.4z",
    transform: "rotate(-45.001 8 8)"
  })), children);
});
var Event32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Event32(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6a2,2,0,0,0-2-2H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V6h4V8h2V6h8V8h2V6h4v6h2Z"
  })), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 15L23.549 19.938 29 20.729 25 24.573 26 30 21 27.438 16 30 17 24.573 13 20.729 18.6 19.938 21 15z"
  })), children);
});
var Event24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Event24(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6a2,2,0,0,0-2-2H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V6h4V8h2V6h8V8h2V6h4v6h2Z"
  })), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 15L23.549 19.938 29 20.729 25 24.573 26 30 21 27.438 16 30 17 24.573 13 20.729 18.6 19.938 21 15z"
  })), children);
});
var Event20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Event20(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6a2,2,0,0,0-2-2H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V6h4V8h2V6h8V8h2V6h4v6h2Z"
  })), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 15L23.549 19.938 29 20.729 25 24.573 26 30 21 27.438 16 30 17 24.573 13 20.729 18.6 19.938 21 15z"
  })), children);
});
var Event16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Event16(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6a2,2,0,0,0-2-2H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V6h4V8h2V6h8V8h2V6h4v6h2Z"
  })), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 15L23.549 19.938 29 20.729 25 24.573 26 30 21 27.438 16 30 17 24.573 13 20.729 18.6 19.938 21 15z"
  })), children);
});
var EventSchedule32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EventSchedule32(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,30a8,8,0,1,1,8-8A8,8,0,0,1,21,30Zm0-14a6,6,0,1,0,6,6A6,6,0,0,0,21,16Z"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.59 25L20 22.41 20 18 22 18 22 21.59 24 23.59 22.59 25z"
  })), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6a2,2,0,0,0-2-2H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V6h4V8h2V6h8V8h2V6h4v6h2Z"
  })), children);
});
var EventSchedule24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EventSchedule24(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,30a8,8,0,1,1,8-8A8,8,0,0,1,21,30Zm0-14a6,6,0,1,0,6,6A6,6,0,0,0,21,16Z"
  })), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.59 25L20 22.41 20 18 22 18 22 21.59 24 23.59 22.59 25z"
  })), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6a2,2,0,0,0-2-2H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V6h4V8h2V6h8V8h2V6h4v6h2Z"
  })), children);
});
var EventSchedule20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EventSchedule20(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,30a8,8,0,1,1,8-8A8,8,0,0,1,21,30Zm0-14a6,6,0,1,0,6,6A6,6,0,0,0,21,16Z"
  })), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.59 25L20 22.41 20 18 22 18 22 21.59 24 23.59 22.59 25z"
  })), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6a2,2,0,0,0-2-2H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V6h4V8h2V6h8V8h2V6h4v6h2Z"
  })), children);
});
var EventSchedule16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EventSchedule16(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,30a8,8,0,1,1,8-8A8,8,0,0,1,21,30Zm0-14a6,6,0,1,0,6,6A6,6,0,0,0,21,16Z"
  })), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.59 25L20 22.41 20 18 22 18 22 21.59 24 23.59 22.59 25z"
  })), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6a2,2,0,0,0-2-2H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V6h4V8h2V6h8V8h2V6h4v6h2Z"
  })), children);
});
var Events32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Events32(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 14H24v2h2a3.0033 3.0033 0 013 3v4h2V19A5.0058 5.0058 0 0026 14zM24 4a3 3 0 11-3 3 3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0024 2zM23 30H21V28a3.0033 3.0033 0 00-3-3H14a3.0033 3.0033 0 00-3 3v2H9V28a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM16 13a3 3 0 11-3 3 3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0016 11zM8 14H6a5.0059 5.0059 0 00-5 5v4H3V19a3.0033 3.0033 0 013-3H8zM8 4A3 3 0 115 7 3 3 0 018 4M8 2a5 5 0 105 5A5 5 0 008 2z"
  })), children);
});
var Events24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Events24(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 14H24v2h2a3.0033 3.0033 0 013 3v4h2V19A5.0058 5.0058 0 0026 14zM24 4a3 3 0 11-3 3 3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0024 2zM23 30H21V28a3.0033 3.0033 0 00-3-3H14a3.0033 3.0033 0 00-3 3v2H9V28a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM16 13a3 3 0 11-3 3 3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0016 11zM8 14H6a5.0059 5.0059 0 00-5 5v4H3V19a3.0033 3.0033 0 013-3H8zM8 4A3 3 0 115 7 3 3 0 018 4M8 2a5 5 0 105 5A5 5 0 008 2z"
  })), children);
});
var Events20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Events20(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 14H24v2h2a3.0033 3.0033 0 013 3v4h2V19A5.0058 5.0058 0 0026 14zM24 4a3 3 0 11-3 3 3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0024 2zM23 30H21V28a3.0033 3.0033 0 00-3-3H14a3.0033 3.0033 0 00-3 3v2H9V28a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM16 13a3 3 0 11-3 3 3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0016 11zM8 14H6a5.0059 5.0059 0 00-5 5v4H3V19a3.0033 3.0033 0 013-3H8zM8 4A3 3 0 115 7 3 3 0 018 4M8 2a5 5 0 105 5A5 5 0 008 2z"
  })), children);
});
var Events16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Events16(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 14H24v2h2a3.0033 3.0033 0 013 3v4h2V19A5.0058 5.0058 0 0026 14zM24 4a3 3 0 11-3 3 3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0024 2zM23 30H21V28a3.0033 3.0033 0 00-3-3H14a3.0033 3.0033 0 00-3 3v2H9V28a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM16 13a3 3 0 11-3 3 3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0016 11zM8 14H6a5.0059 5.0059 0 00-5 5v4H3V19a3.0033 3.0033 0 013-3H8zM8 4A3 3 0 115 7 3 3 0 018 4M8 2a5 5 0 105 5A5 5 0 008 2z"
  })), children);
});
var EventsAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EventsAlt32(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 31h2V29a1.0006 1.0006 0 011-1h6a1.0006 1.0006 0 011 1v2h2V29a3.0033 3.0033 0 00-3-3H21a3.0033 3.0033 0 00-3 3zM24 25a4 4 0 114-4A4.0039 4.0039 0 0124 25zm0-6a2 2 0 102 2A2.0027 2.0027 0 0024 19zM2 31H4V29a1.0009 1.0009 0 011-1h6a1.0009 1.0009 0 011 1v2h2V29a3.0033 3.0033 0 00-3-3H5a3.0033 3.0033 0 00-3 3zM8 25a4 4 0 114-4A4.0042 4.0042 0 018 25zm0-6a2 2 0 102 2A2.0023 2.0023 0 008 19zM18 16h2V14a1.0009 1.0009 0 011-1h6a1.0009 1.0009 0 011 1v2h2V14a3.0033 3.0033 0 00-3-3H21a3.0033 3.0033 0 00-3 3zM24 10a4 4 0 114-4A4.0042 4.0042 0 0124 10zm0-6a2 2 0 102 2A2.0023 2.0023 0 0024 4zM2 16H4V14a1.0013 1.0013 0 011-1h6a1.0013 1.0013 0 011 1v2h2V14a3.0033 3.0033 0 00-3-3H5a3.0033 3.0033 0 00-3 3zM8 10a4 4 0 114-4A4.0045 4.0045 0 018 10zM8 4a2 2 0 102 2A2.002 2.002 0 008 4z"
  })), children);
});
var EventsAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EventsAlt24(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 31h2V29a1.0006 1.0006 0 011-1h6a1.0006 1.0006 0 011 1v2h2V29a3.0033 3.0033 0 00-3-3H21a3.0033 3.0033 0 00-3 3zM24 25a4 4 0 114-4A4.0039 4.0039 0 0124 25zm0-6a2 2 0 102 2A2.0027 2.0027 0 0024 19zM2 31H4V29a1.0009 1.0009 0 011-1h6a1.0009 1.0009 0 011 1v2h2V29a3.0033 3.0033 0 00-3-3H5a3.0033 3.0033 0 00-3 3zM8 25a4 4 0 114-4A4.0042 4.0042 0 018 25zm0-6a2 2 0 102 2A2.0023 2.0023 0 008 19zM18 16h2V14a1.0009 1.0009 0 011-1h6a1.0009 1.0009 0 011 1v2h2V14a3.0033 3.0033 0 00-3-3H21a3.0033 3.0033 0 00-3 3zM24 10a4 4 0 114-4A4.0042 4.0042 0 0124 10zm0-6a2 2 0 102 2A2.0023 2.0023 0 0024 4zM2 16H4V14a1.0013 1.0013 0 011-1h6a1.0013 1.0013 0 011 1v2h2V14a3.0033 3.0033 0 00-3-3H5a3.0033 3.0033 0 00-3 3zM8 10a4 4 0 114-4A4.0045 4.0045 0 018 10zM8 4a2 2 0 102 2A2.002 2.002 0 008 4z"
  })), children);
});
var EventsAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EventsAlt20(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 31h2V29a1.0006 1.0006 0 011-1h6a1.0006 1.0006 0 011 1v2h2V29a3.0033 3.0033 0 00-3-3H21a3.0033 3.0033 0 00-3 3zM24 25a4 4 0 114-4A4.0039 4.0039 0 0124 25zm0-6a2 2 0 102 2A2.0027 2.0027 0 0024 19zM2 31H4V29a1.0009 1.0009 0 011-1h6a1.0009 1.0009 0 011 1v2h2V29a3.0033 3.0033 0 00-3-3H5a3.0033 3.0033 0 00-3 3zM8 25a4 4 0 114-4A4.0042 4.0042 0 018 25zm0-6a2 2 0 102 2A2.0023 2.0023 0 008 19zM18 16h2V14a1.0009 1.0009 0 011-1h6a1.0009 1.0009 0 011 1v2h2V14a3.0033 3.0033 0 00-3-3H21a3.0033 3.0033 0 00-3 3zM24 10a4 4 0 114-4A4.0042 4.0042 0 0124 10zm0-6a2 2 0 102 2A2.0023 2.0023 0 0024 4zM2 16H4V14a1.0013 1.0013 0 011-1h6a1.0013 1.0013 0 011 1v2h2V14a3.0033 3.0033 0 00-3-3H5a3.0033 3.0033 0 00-3 3zM8 10a4 4 0 114-4A4.0045 4.0045 0 018 10zM8 4a2 2 0 102 2A2.002 2.002 0 008 4z"
  })), children);
});
var EventsAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function EventsAlt16(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 31h2V29a1.0006 1.0006 0 011-1h6a1.0006 1.0006 0 011 1v2h2V29a3.0033 3.0033 0 00-3-3H21a3.0033 3.0033 0 00-3 3zM24 25a4 4 0 114-4A4.0039 4.0039 0 0124 25zm0-6a2 2 0 102 2A2.0027 2.0027 0 0024 19zM2 31H4V29a1.0009 1.0009 0 011-1h6a1.0009 1.0009 0 011 1v2h2V29a3.0033 3.0033 0 00-3-3H5a3.0033 3.0033 0 00-3 3zM8 25a4 4 0 114-4A4.0042 4.0042 0 018 25zm0-6a2 2 0 102 2A2.0023 2.0023 0 008 19zM18 16h2V14a1.0009 1.0009 0 011-1h6a1.0009 1.0009 0 011 1v2h2V14a3.0033 3.0033 0 00-3-3H21a3.0033 3.0033 0 00-3 3zM24 10a4 4 0 114-4A4.0042 4.0042 0 0124 10zm0-6a2 2 0 102 2A2.0023 2.0023 0 0024 4zM2 16H4V14a1.0013 1.0013 0 011-1h6a1.0013 1.0013 0 011 1v2h2V14a3.0033 3.0033 0 00-3-3H5a3.0033 3.0033 0 00-3 3zM8 10a4 4 0 114-4A4.0045 4.0045 0 018 10zM8 4a2 2 0 102 2A2.002 2.002 0 008 4z"
  })), children);
});
var ExamMode32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ExamMode32(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23v3H7V16.83l3.59 3.58L12 19 6 13 0 19l1.41 1.41L5 16.83V26a2 2 0 002 2H25a2 2 0 002-2V23zM27 7v9.17l3.59-3.58L32 14l-6 6-6-6 1.41-1.41L25 16.17V7H13V5H25A2 2 0 0127 7zM8 10H4A2 2 0 012 8V4A2 2 0 014 2H8a2 2 0 012 2V8A2 2 0 018 10zM4 4V8H8V4z"
  })), children);
});
var ExamMode24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ExamMode24(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23v3H7V16.83l3.59 3.58L12 19 6 13 0 19l1.41 1.41L5 16.83V26a2 2 0 002 2H25a2 2 0 002-2V23zM27 7v9.17l3.59-3.58L32 14l-6 6-6-6 1.41-1.41L25 16.17V7H13V5H25A2 2 0 0127 7zM8 10H4A2 2 0 012 8V4A2 2 0 014 2H8a2 2 0 012 2V8A2 2 0 018 10zM4 4V8H8V4z"
  })), children);
});
var ExamMode20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ExamMode20(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23v3H7V16.83l3.59 3.58L12 19 6 13 0 19l1.41 1.41L5 16.83V26a2 2 0 002 2H25a2 2 0 002-2V23zM27 7v9.17l3.59-3.58L32 14l-6 6-6-6 1.41-1.41L25 16.17V7H13V5H25A2 2 0 0127 7zM8 10H4A2 2 0 012 8V4A2 2 0 014 2H8a2 2 0 012 2V8A2 2 0 018 10zM4 4V8H8V4z"
  })), children);
});
var ExamMode16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ExamMode16(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23v3H7V16.83l3.59 3.58L12 19 6 13 0 19l1.41 1.41L5 16.83V26a2 2 0 002 2H25a2 2 0 002-2V23zM27 7v9.17l3.59-3.58L32 14l-6 6-6-6 1.41-1.41L25 16.17V7H13V5H25A2 2 0 0127 7zM8 10H4A2 2 0 012 8V4A2 2 0 014 2H8a2 2 0 012 2V8A2 2 0 018 10zM4 4V8H8V4z"
  })), children);
});
var Exit32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Exit32(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 4H28V28H26zM11.414 20.586L7.828 17 22 17 22 15 7.828 15 11.414 11.414 10 10 4 16 10 22 11.414 20.586z"
  })), children);
});
var Exit24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Exit24(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 4H28V28H26zM11.414 20.586L7.828 17 22 17 22 15 7.828 15 11.414 11.414 10 10 4 16 10 22 11.414 20.586z"
  })), children);
});
var Exit20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Exit20(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 4H28V28H26zM11.414 20.586L7.828 17 22 17 22 15 7.828 15 11.414 11.414 10 10 4 16 10 22 11.414 20.586z"
  })), children);
});
var Exit16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Exit16(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 4H28V28H26zM11.414 20.586L7.828 17 22 17 22 15 7.828 15 11.414 11.414 10 10 4 16 10 22 11.414 20.586z"
  })), children);
});
var ExpandAll32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ExpandAll32(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,10H26a2.0025,2.0025,0,0,0,2-2V4a2.0025,2.0025,0,0,0-2-2H12a2.0025,2.0025,0,0,0-2,2V5H6V2H4V25a2.0025,2.0025,0,0,0,2,2h4v1a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V24a2.0025,2.0025,0,0,0-2-2H12a2.0025,2.0025,0,0,0-2,2v1H6V17h4v1a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V14a2.0025,2.0025,0,0,0-2-2H12a2.0025,2.0025,0,0,0-2,2v1H6V7h4V8A2.0025,2.0025,0,0,0,12,10Zm0-6H26l.0012,4H12Zm0,20H26l.0012,4H12Zm0-10H26l.0012,4H12Z"
  })), children);
});
var ExpandAll24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ExpandAll24(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,10H26a2.0025,2.0025,0,0,0,2-2V4a2.0025,2.0025,0,0,0-2-2H12a2.0025,2.0025,0,0,0-2,2V5H6V2H4V25a2.0025,2.0025,0,0,0,2,2h4v1a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V24a2.0025,2.0025,0,0,0-2-2H12a2.0025,2.0025,0,0,0-2,2v1H6V17h4v1a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V14a2.0025,2.0025,0,0,0-2-2H12a2.0025,2.0025,0,0,0-2,2v1H6V7h4V8A2.0025,2.0025,0,0,0,12,10Zm0-6H26l.0012,4H12Zm0,20H26l.0012,4H12Zm0-10H26l.0012,4H12Z"
  })), children);
});
var ExpandAll20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ExpandAll20(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,10H26a2.0025,2.0025,0,0,0,2-2V4a2.0025,2.0025,0,0,0-2-2H12a2.0025,2.0025,0,0,0-2,2V5H6V2H4V25a2.0025,2.0025,0,0,0,2,2h4v1a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V24a2.0025,2.0025,0,0,0-2-2H12a2.0025,2.0025,0,0,0-2,2v1H6V17h4v1a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V14a2.0025,2.0025,0,0,0-2-2H12a2.0025,2.0025,0,0,0-2,2v1H6V7h4V8A2.0025,2.0025,0,0,0,12,10Zm0-6H26l.0012,4H12Zm0,20H26l.0012,4H12Zm0-10H26l.0012,4H12Z"
  })), children);
});
var ExpandAll16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ExpandAll16(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,10H26a2.0025,2.0025,0,0,0,2-2V4a2.0025,2.0025,0,0,0-2-2H12a2.0025,2.0025,0,0,0-2,2V5H6V2H4V25a2.0025,2.0025,0,0,0,2,2h4v1a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V24a2.0025,2.0025,0,0,0-2-2H12a2.0025,2.0025,0,0,0-2,2v1H6V17h4v1a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V14a2.0025,2.0025,0,0,0-2-2H12a2.0025,2.0025,0,0,0-2,2v1H6V7h4V8A2.0025,2.0025,0,0,0,12,10Zm0-6H26l.0012,4H12Zm0,20H26l.0012,4H12Zm0-10H26l.0012,4H12Z"
  })), children);
});
var ExpandCategories32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ExpandCategories32(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 26H26V28H20zM20 18H28V20H20zM20 10H30V12H20zM15 4H17V28H15zM10.586 3.959L7 7.249 3.412 3.958 2 5.373 7 10 12 5.373 10.586 3.959z"
  })), children);
});
var ExpandCategories24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ExpandCategories24(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 26H26V28H20zM20 18H28V20H20zM20 10H30V12H20zM15 4H17V28H15zM10.586 3.959L7 7.249 3.412 3.958 2 5.373 7 10 12 5.373 10.586 3.959z"
  })), children);
});
var ExpandCategories20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ExpandCategories20(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 26H26V28H20zM20 18H28V20H20zM20 10H30V12H20zM15 4H17V28H15zM10.586 3.959L7 7.249 3.412 3.958 2 5.373 7 10 12 5.373 10.586 3.959z"
  })), children);
});
var ExpandCategories16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ExpandCategories16(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 26H26V28H20zM20 18H28V20H20zM20 10H30V12H20zM15 4H17V28H15zM10.586 3.959L7 7.249 3.412 3.958 2 5.373 7 10 12 5.373 10.586 3.959z"
  })), children);
});
var Explore32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Explore32(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.707,9.2931a.9992.9992,0,0,0-1.0234-.2417l-9,3a1.001,1.001,0,0,0-.6323.6323l-3,9a1,1,0,0,0,1.2651,1.2651l9-3a1.0013,1.0013,0,0,0,.6323-.6324l3-9A1,1,0,0,0,22.707,9.2931ZM11.5811,20.419l2.2094-6.6284L18.21,18.21Z"
  })), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var Explore24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Explore24(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.707,9.2931a.9992.9992,0,0,0-1.0234-.2417l-9,3a1.001,1.001,0,0,0-.6323.6323l-3,9a1,1,0,0,0,1.2651,1.2651l9-3a1.0013,1.0013,0,0,0,.6323-.6324l3-9A1,1,0,0,0,22.707,9.2931ZM11.5811,20.419l2.2094-6.6284L18.21,18.21Z"
  })), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var Explore20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Explore20(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.707,9.2931a.9992.9992,0,0,0-1.0234-.2417l-9,3a1.001,1.001,0,0,0-.6323.6323l-3,9a1,1,0,0,0,1.2651,1.2651l9-3a1.0013,1.0013,0,0,0,.6323-.6324l3-9A1,1,0,0,0,22.707,9.2931ZM11.5811,20.419l2.2094-6.6284L18.21,18.21Z"
  })), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var Explore16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Explore16(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.707,9.2931a.9992.9992,0,0,0-1.0234-.2417l-9,3a1.001,1.001,0,0,0-.6323.6323l-3,9a1,1,0,0,0,1.2651,1.2651l9-3a1.0013,1.0013,0,0,0,.6323-.6324l3-9A1,1,0,0,0,22.707,9.2931ZM11.5811,20.419l2.2094-6.6284L18.21,18.21Z"
  })), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var Export32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Export32(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 24v4H6V24H4v4l.0076-.0049A1.9977 1.9977 0 006 30H26a2 2 0 002-2h0V24zM6 12L7.411 13.405 15 5.825 15 24 17 24 17 5.825 24.591 13.405 26 12 16 2 6 12z"
  })), children);
});
var Export24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Export24(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 24v4H6V24H4v4l.0076-.0049A1.9977 1.9977 0 006 30H26a2 2 0 002-2h0V24zM6 12L7.411 13.405 15 5.825 15 24 17 24 17 5.825 24.591 13.405 26 12 16 2 6 12z"
  })), children);
});
var Export20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Export20(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 24v4H6V24H4v4l.0076-.0049A1.9977 1.9977 0 006 30H26a2 2 0 002-2h0V24zM6 12L7.411 13.405 15 5.825 15 24 17 24 17 5.825 24.591 13.405 26 12 16 2 6 12z"
  })), children);
});
var Export16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Export16(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 12v2H3v-2H2v2l0 0c0 .6.4 1 1 1h10c.6 0 1-.4 1-1l0 0v-2H13zM3 6L3.7 6.7 7.5 2.9 7.5 12 8.5 12 8.5 2.9 12.3 6.7 13 6 8 1z"
  })), children);
});
var Eyedropper32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Eyedropper32(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 27H5V30H2zM29.71 7.29l-5-5a1 1 0 00-1.41 0h0L20 5.59l-1.29-1.3L17.29 5.71 18.59 7 8.29 17.29A1 1 0 008 18v1.59l-2.71 2.7a1 1 0 000 1.41h0l3 3a1 1 0 001.41 0h0L12.41 24H14a1 1 0 00.71-.29L25 13.41l1.29 1.3 1.42-1.42L26.41 12l3.3-3.29a1 1 0 000-1.41zM13.59 22h-2L9 24.59 7.41 23 10 20.41v-2l10-10L23.59 12zM25 10.59L21.41 7 24 4.41 27.59 8z"
  })), children);
});
var Eyedropper24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Eyedropper24(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 27H5V30H2zM29.71 7.29l-5-5a1 1 0 00-1.41 0h0L20 5.59l-1.29-1.3L17.29 5.71 18.59 7 8.29 17.29A1 1 0 008 18v1.59l-2.71 2.7a1 1 0 000 1.41h0l3 3a1 1 0 001.41 0h0L12.41 24H14a1 1 0 00.71-.29L25 13.41l1.29 1.3 1.42-1.42L26.41 12l3.3-3.29a1 1 0 000-1.41zM13.59 22h-2L9 24.59 7.41 23 10 20.41v-2l10-10L23.59 12zM25 10.59L21.41 7 24 4.41 27.59 8z"
  })), children);
});
var Eyedropper20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Eyedropper20(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 27H5V30H2zM29.71 7.29l-5-5a1 1 0 00-1.41 0h0L20 5.59l-1.29-1.3L17.29 5.71 18.59 7 8.29 17.29A1 1 0 008 18v1.59l-2.71 2.7a1 1 0 000 1.41h0l3 3a1 1 0 001.41 0h0L12.41 24H14a1 1 0 00.71-.29L25 13.41l1.29 1.3 1.42-1.42L26.41 12l3.3-3.29a1 1 0 000-1.41zM13.59 22h-2L9 24.59 7.41 23 10 20.41v-2l10-10L23.59 12zM25 10.59L21.41 7 24 4.41 27.59 8z"
  })), children);
});
var Eyedropper16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Eyedropper16(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 27H5V30H2zM29.71 7.29l-5-5a1 1 0 00-1.41 0h0L20 5.59l-1.29-1.3L17.29 5.71 18.59 7 8.29 17.29A1 1 0 008 18v1.59l-2.71 2.7a1 1 0 000 1.41h0l3 3a1 1 0 001.41 0h0L12.41 24H14a1 1 0 00.71-.29L25 13.41l1.29 1.3 1.42-1.42L26.41 12l3.3-3.29a1 1 0 000-1.41zM13.59 22h-2L9 24.59 7.41 23 10 20.41v-2l10-10L23.59 12zM25 10.59L21.41 7 24 4.41 27.59 8z"
  })), children);
});
var FaceActivated32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceActivated32(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11zM9 20a8.13 8.13 0 0014 0z"
  })), children);
});
var FaceActivated24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceActivated24(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11zM9 20a8.13 8.13 0 0014 0z"
  })), children);
});
var FaceActivated20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceActivated20(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11zM9 20a8.13 8.13 0 0014 0z"
  })), children);
});
var FaceActivated16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceActivated16(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11zM9 20a8.13 8.13 0 0014 0z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-11.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-11.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "FaceActivatedAdd16": () => (/* binding */ FaceActivatedAdd16),
/* harmony export */   "FaceActivatedAdd20": () => (/* binding */ FaceActivatedAdd20),
/* harmony export */   "FaceActivatedAdd24": () => (/* binding */ FaceActivatedAdd24),
/* harmony export */   "FaceActivatedAdd32": () => (/* binding */ FaceActivatedAdd32),
/* harmony export */   "FaceActivatedFilled16": () => (/* binding */ FaceActivatedFilled16),
/* harmony export */   "FaceActivatedFilled20": () => (/* binding */ FaceActivatedFilled20),
/* harmony export */   "FaceActivatedFilled24": () => (/* binding */ FaceActivatedFilled24),
/* harmony export */   "FaceActivatedFilled32": () => (/* binding */ FaceActivatedFilled32),
/* harmony export */   "FaceAdd16": () => (/* binding */ FaceAdd16),
/* harmony export */   "FaceAdd20": () => (/* binding */ FaceAdd20),
/* harmony export */   "FaceAdd24": () => (/* binding */ FaceAdd24),
/* harmony export */   "FaceAdd32": () => (/* binding */ FaceAdd32),
/* harmony export */   "FaceCool16": () => (/* binding */ FaceCool16),
/* harmony export */   "FaceCool20": () => (/* binding */ FaceCool20),
/* harmony export */   "FaceCool24": () => (/* binding */ FaceCool24),
/* harmony export */   "FaceCool32": () => (/* binding */ FaceCool32),
/* harmony export */   "FaceDissatisfied16": () => (/* binding */ FaceDissatisfied16),
/* harmony export */   "FaceDissatisfied20": () => (/* binding */ FaceDissatisfied20),
/* harmony export */   "FaceDissatisfied24": () => (/* binding */ FaceDissatisfied24),
/* harmony export */   "FaceDissatisfied32": () => (/* binding */ FaceDissatisfied32),
/* harmony export */   "FaceDissatisfiedFilled16": () => (/* binding */ FaceDissatisfiedFilled16),
/* harmony export */   "FaceDissatisfiedFilled20": () => (/* binding */ FaceDissatisfiedFilled20),
/* harmony export */   "FaceDissatisfiedFilled24": () => (/* binding */ FaceDissatisfiedFilled24),
/* harmony export */   "FaceDissatisfiedFilled32": () => (/* binding */ FaceDissatisfiedFilled32),
/* harmony export */   "FaceDizzy16": () => (/* binding */ FaceDizzy16),
/* harmony export */   "FaceDizzy20": () => (/* binding */ FaceDizzy20),
/* harmony export */   "FaceDizzy24": () => (/* binding */ FaceDizzy24),
/* harmony export */   "FaceDizzy32": () => (/* binding */ FaceDizzy32),
/* harmony export */   "FaceDizzyFilled16": () => (/* binding */ FaceDizzyFilled16),
/* harmony export */   "FaceDizzyFilled20": () => (/* binding */ FaceDizzyFilled20),
/* harmony export */   "FaceDizzyFilled24": () => (/* binding */ FaceDizzyFilled24),
/* harmony export */   "FaceDizzyFilled32": () => (/* binding */ FaceDizzyFilled32),
/* harmony export */   "FaceMask16": () => (/* binding */ FaceMask16),
/* harmony export */   "FaceMask20": () => (/* binding */ FaceMask20),
/* harmony export */   "FaceMask24": () => (/* binding */ FaceMask24),
/* harmony export */   "FaceMask32": () => (/* binding */ FaceMask32),
/* harmony export */   "FaceNeutral16": () => (/* binding */ FaceNeutral16),
/* harmony export */   "FaceNeutral20": () => (/* binding */ FaceNeutral20),
/* harmony export */   "FaceNeutral24": () => (/* binding */ FaceNeutral24),
/* harmony export */   "FaceNeutral32": () => (/* binding */ FaceNeutral32),
/* harmony export */   "FaceNeutralFilled16": () => (/* binding */ FaceNeutralFilled16),
/* harmony export */   "FaceNeutralFilled20": () => (/* binding */ FaceNeutralFilled20),
/* harmony export */   "FaceNeutralFilled24": () => (/* binding */ FaceNeutralFilled24),
/* harmony export */   "FaceNeutralFilled32": () => (/* binding */ FaceNeutralFilled32),
/* harmony export */   "FacePending16": () => (/* binding */ FacePending16),
/* harmony export */   "FacePending20": () => (/* binding */ FacePending20),
/* harmony export */   "FacePending24": () => (/* binding */ FacePending24),
/* harmony export */   "FacePending32": () => (/* binding */ FacePending32),
/* harmony export */   "FacePendingFilled16": () => (/* binding */ FacePendingFilled16),
/* harmony export */   "FacePendingFilled20": () => (/* binding */ FacePendingFilled20),
/* harmony export */   "FacePendingFilled24": () => (/* binding */ FacePendingFilled24),
/* harmony export */   "FacePendingFilled32": () => (/* binding */ FacePendingFilled32),
/* harmony export */   "FaceSatisfied16": () => (/* binding */ FaceSatisfied16),
/* harmony export */   "FaceSatisfied20": () => (/* binding */ FaceSatisfied20),
/* harmony export */   "FaceSatisfied24": () => (/* binding */ FaceSatisfied24),
/* harmony export */   "FaceSatisfied32": () => (/* binding */ FaceSatisfied32),
/* harmony export */   "FaceSatisfiedFilled16": () => (/* binding */ FaceSatisfiedFilled16),
/* harmony export */   "FaceSatisfiedFilled20": () => (/* binding */ FaceSatisfiedFilled20),
/* harmony export */   "FaceSatisfiedFilled24": () => (/* binding */ FaceSatisfiedFilled24),
/* harmony export */   "FaceSatisfiedFilled32": () => (/* binding */ FaceSatisfiedFilled32),
/* harmony export */   "FaceWink16": () => (/* binding */ FaceWink16),
/* harmony export */   "FaceWink20": () => (/* binding */ FaceWink20),
/* harmony export */   "FaceWink24": () => (/* binding */ FaceWink24),
/* harmony export */   "FaceWink32": () => (/* binding */ FaceWink32),
/* harmony export */   "FaceWinkFilled16": () => (/* binding */ FaceWinkFilled16),
/* harmony export */   "FaceWinkFilled20": () => (/* binding */ FaceWinkFilled20),
/* harmony export */   "FaceWinkFilled24": () => (/* binding */ FaceWinkFilled24),
/* harmony export */   "FaceWinkFilled32": () => (/* binding */ FaceWinkFilled32),
/* harmony export */   "Factor16": () => (/* binding */ Factor16),
/* harmony export */   "Factor20": () => (/* binding */ Factor20),
/* harmony export */   "Factor24": () => (/* binding */ Factor24),
/* harmony export */   "Factor32": () => (/* binding */ Factor32),
/* harmony export */   "Fade16": () => (/* binding */ Fade16),
/* harmony export */   "Fade20": () => (/* binding */ Fade20),
/* harmony export */   "Fade24": () => (/* binding */ Fade24),
/* harmony export */   "Fade32": () => (/* binding */ Fade32),
/* harmony export */   "Favorite16": () => (/* binding */ Favorite16),
/* harmony export */   "Favorite20": () => (/* binding */ Favorite20),
/* harmony export */   "Favorite24": () => (/* binding */ Favorite24),
/* harmony export */   "Favorite32": () => (/* binding */ Favorite32),
/* harmony export */   "FavoriteFilled16": () => (/* binding */ FavoriteFilled16),
/* harmony export */   "FavoriteFilled20": () => (/* binding */ FavoriteFilled20),
/* harmony export */   "FavoriteFilled24": () => (/* binding */ FavoriteFilled24),
/* harmony export */   "FavoriteFilled32": () => (/* binding */ FavoriteFilled32),
/* harmony export */   "FavoriteHalf16": () => (/* binding */ FavoriteHalf16),
/* harmony export */   "FavoriteHalf20": () => (/* binding */ FavoriteHalf20),
/* harmony export */   "FavoriteHalf24": () => (/* binding */ FavoriteHalf24),
/* harmony export */   "FavoriteHalf32": () => (/* binding */ FavoriteHalf32),
/* harmony export */   "FetchUpload16": () => (/* binding */ FetchUpload16),
/* harmony export */   "FetchUpload20": () => (/* binding */ FetchUpload20),
/* harmony export */   "FetchUpload24": () => (/* binding */ FetchUpload24),
/* harmony export */   "FetchUpload32": () => (/* binding */ FetchUpload32),
/* harmony export */   "FetchUploadCloud16": () => (/* binding */ FetchUploadCloud16),
/* harmony export */   "FetchUploadCloud20": () => (/* binding */ FetchUploadCloud20),
/* harmony export */   "FetchUploadCloud24": () => (/* binding */ FetchUploadCloud24),
/* harmony export */   "FetchUploadCloud32": () => (/* binding */ FetchUploadCloud32),
/* harmony export */   "FileStorage16": () => (/* binding */ FileStorage16),
/* harmony export */   "FileStorage20": () => (/* binding */ FileStorage20),
/* harmony export */   "FileStorage24": () => (/* binding */ FileStorage24),
/* harmony export */   "FileStorage32": () => (/* binding */ FileStorage32),
/* harmony export */   "Filter16": () => (/* binding */ Filter16),
/* harmony export */   "Filter20": () => (/* binding */ Filter20),
/* harmony export */   "Filter24": () => (/* binding */ Filter24),
/* harmony export */   "Filter32": () => (/* binding */ Filter32),
/* harmony export */   "FilterEdit16": () => (/* binding */ FilterEdit16),
/* harmony export */   "FilterEdit20": () => (/* binding */ FilterEdit20),
/* harmony export */   "FilterEdit24": () => (/* binding */ FilterEdit24),
/* harmony export */   "FilterEdit32": () => (/* binding */ FilterEdit32),
/* harmony export */   "FilterRemove16": () => (/* binding */ FilterRemove16),
/* harmony export */   "FilterRemove20": () => (/* binding */ FilterRemove20),
/* harmony export */   "FilterRemove24": () => (/* binding */ FilterRemove24),
/* harmony export */   "FilterRemove32": () => (/* binding */ FilterRemove32),
/* harmony export */   "FilterReset16": () => (/* binding */ FilterReset16),
/* harmony export */   "FilterReset20": () => (/* binding */ FilterReset20),
/* harmony export */   "FilterReset24": () => (/* binding */ FilterReset24),
/* harmony export */   "FilterReset32": () => (/* binding */ FilterReset32),
/* harmony export */   "Finance16": () => (/* binding */ Finance16),
/* harmony export */   "Finance20": () => (/* binding */ Finance20),
/* harmony export */   "Finance24": () => (/* binding */ Finance24),
/* harmony export */   "Finance32": () => (/* binding */ Finance32),
/* harmony export */   "FingerprintRecognition16": () => (/* binding */ FingerprintRecognition16),
/* harmony export */   "FingerprintRecognition20": () => (/* binding */ FingerprintRecognition20),
/* harmony export */   "FingerprintRecognition24": () => (/* binding */ FingerprintRecognition24),
/* harmony export */   "FingerprintRecognition32": () => (/* binding */ FingerprintRecognition32),
/* harmony export */   "Fire16": () => (/* binding */ Fire16),
/* harmony export */   "Fire20": () => (/* binding */ Fire20),
/* harmony export */   "Fire24": () => (/* binding */ Fire24),
/* harmony export */   "Fire32": () => (/* binding */ Fire32),
/* harmony export */   "Firewall16": () => (/* binding */ Firewall16),
/* harmony export */   "Firewall20": () => (/* binding */ Firewall20),
/* harmony export */   "Firewall24": () => (/* binding */ Firewall24),
/* harmony export */   "Firewall32": () => (/* binding */ Firewall32),
/* harmony export */   "FirewallClassic16": () => (/* binding */ FirewallClassic16),
/* harmony export */   "FirewallClassic20": () => (/* binding */ FirewallClassic20),
/* harmony export */   "FirewallClassic24": () => (/* binding */ FirewallClassic24),
/* harmony export */   "FirewallClassic32": () => (/* binding */ FirewallClassic32),
/* harmony export */   "Fish16": () => (/* binding */ Fish16),
/* harmony export */   "Fish20": () => (/* binding */ Fish20),
/* harmony export */   "Fish24": () => (/* binding */ Fish24),
/* harmony export */   "Fish32": () => (/* binding */ Fish32),
/* harmony export */   "FishMultiple16": () => (/* binding */ FishMultiple16),
/* harmony export */   "FishMultiple20": () => (/* binding */ FishMultiple20),
/* harmony export */   "FishMultiple24": () => (/* binding */ FishMultiple24),
/* harmony export */   "FishMultiple32": () => (/* binding */ FishMultiple32),
/* harmony export */   "FitToHeight16": () => (/* binding */ FitToHeight16),
/* harmony export */   "FitToHeight20": () => (/* binding */ FitToHeight20),
/* harmony export */   "FitToHeight24": () => (/* binding */ FitToHeight24),
/* harmony export */   "FitToHeight32": () => (/* binding */ FitToHeight32),
/* harmony export */   "FitToScreen16": () => (/* binding */ FitToScreen16),
/* harmony export */   "FitToScreen20": () => (/* binding */ FitToScreen20),
/* harmony export */   "FitToScreen24": () => (/* binding */ FitToScreen24),
/* harmony export */   "FitToScreen32": () => (/* binding */ FitToScreen32),
/* harmony export */   "FitToWidth16": () => (/* binding */ FitToWidth16),
/* harmony export */   "FitToWidth20": () => (/* binding */ FitToWidth20),
/* harmony export */   "FitToWidth24": () => (/* binding */ FitToWidth24),
/* harmony export */   "FitToWidth32": () => (/* binding */ FitToWidth32),
/* harmony export */   "Flag16": () => (/* binding */ Flag16),
/* harmony export */   "Flag20": () => (/* binding */ Flag20),
/* harmony export */   "Flag24": () => (/* binding */ Flag24),
/* harmony export */   "Flag32": () => (/* binding */ Flag32),
/* harmony export */   "FlagFilled16": () => (/* binding */ FlagFilled16),
/* harmony export */   "FlagFilled20": () => (/* binding */ FlagFilled20),
/* harmony export */   "FlagFilled24": () => (/* binding */ FlagFilled24),
/* harmony export */   "FlagFilled32": () => (/* binding */ FlagFilled32),
/* harmony export */   "FlaggingTaxi16": () => (/* binding */ FlaggingTaxi16),
/* harmony export */   "FlaggingTaxi20": () => (/* binding */ FlaggingTaxi20),
/* harmony export */   "FlaggingTaxi24": () => (/* binding */ FlaggingTaxi24),
/* harmony export */   "FlaggingTaxi32": () => (/* binding */ FlaggingTaxi32),
/* harmony export */   "Flash16": () => (/* binding */ Flash16),
/* harmony export */   "Flash20": () => (/* binding */ Flash20),
/* harmony export */   "Flash24": () => (/* binding */ Flash24),
/* harmony export */   "Flash32": () => (/* binding */ Flash32),
/* harmony export */   "FlashFilled16": () => (/* binding */ FlashFilled16),
/* harmony export */   "FlashFilled20": () => (/* binding */ FlashFilled20),
/* harmony export */   "FlashFilled24": () => (/* binding */ FlashFilled24),
/* harmony export */   "FlashFilled32": () => (/* binding */ FlashFilled32),
/* harmony export */   "FlashOff16": () => (/* binding */ FlashOff16),
/* harmony export */   "FlashOff20": () => (/* binding */ FlashOff20),
/* harmony export */   "FlashOff24": () => (/* binding */ FlashOff24),
/* harmony export */   "FlashOff32": () => (/* binding */ FlashOff32),
/* harmony export */   "FlashOffFilled16": () => (/* binding */ FlashOffFilled16),
/* harmony export */   "FlashOffFilled20": () => (/* binding */ FlashOffFilled20),
/* harmony export */   "FlashOffFilled24": () => (/* binding */ FlashOffFilled24),
/* harmony export */   "FlashOffFilled32": () => (/* binding */ FlashOffFilled32),
/* harmony export */   "FlightInternational16": () => (/* binding */ FlightInternational16),
/* harmony export */   "FlightInternational20": () => (/* binding */ FlightInternational20),
/* harmony export */   "FlightInternational24": () => (/* binding */ FlightInternational24),
/* harmony export */   "FlightInternational32": () => (/* binding */ FlightInternational32),
/* harmony export */   "FlightRoster16": () => (/* binding */ FlightRoster16),
/* harmony export */   "FlightRoster20": () => (/* binding */ FlightRoster20),
/* harmony export */   "FlightRoster24": () => (/* binding */ FlightRoster24),
/* harmony export */   "FlightRoster32": () => (/* binding */ FlightRoster32),
/* harmony export */   "FlightSchedule16": () => (/* binding */ FlightSchedule16),
/* harmony export */   "FlightSchedule20": () => (/* binding */ FlightSchedule20),
/* harmony export */   "FlightSchedule24": () => (/* binding */ FlightSchedule24),
/* harmony export */   "FlightSchedule32": () => (/* binding */ FlightSchedule32),
/* harmony export */   "FloatingIp16": () => (/* binding */ FloatingIp16),
/* harmony export */   "FloatingIp20": () => (/* binding */ FloatingIp20),
/* harmony export */   "FloatingIp24": () => (/* binding */ FloatingIp24),
/* harmony export */   "FloatingIp32": () => (/* binding */ FloatingIp32),
/* harmony export */   "Flood16": () => (/* binding */ Flood16),
/* harmony export */   "Flood20": () => (/* binding */ Flood20),
/* harmony export */   "Flood24": () => (/* binding */ Flood24),
/* harmony export */   "Flood32": () => (/* binding */ Flood32),
/* harmony export */   "FloodWarning16": () => (/* binding */ FloodWarning16),
/* harmony export */   "FloodWarning20": () => (/* binding */ FloodWarning20),
/* harmony export */   "FloodWarning24": () => (/* binding */ FloodWarning24),
/* harmony export */   "FloodWarning32": () => (/* binding */ FloodWarning32),
/* harmony export */   "Floorplan16": () => (/* binding */ Floorplan16),
/* harmony export */   "Floorplan20": () => (/* binding */ Floorplan20),
/* harmony export */   "Floorplan24": () => (/* binding */ Floorplan24),
/* harmony export */   "Floorplan32": () => (/* binding */ Floorplan32),
/* harmony export */   "Flow16": () => (/* binding */ Flow16),
/* harmony export */   "Flow20": () => (/* binding */ Flow20),
/* harmony export */   "Flow24": () => (/* binding */ Flow24),
/* harmony export */   "Flow32": () => (/* binding */ Flow32),
/* harmony export */   "FlowConnection16": () => (/* binding */ FlowConnection16),
/* harmony export */   "FlowConnection20": () => (/* binding */ FlowConnection20),
/* harmony export */   "FlowConnection24": () => (/* binding */ FlowConnection24),
/* harmony export */   "FlowConnection32": () => (/* binding */ FlowConnection32),
/* harmony export */   "FlowData16": () => (/* binding */ FlowData16),
/* harmony export */   "FlowData20": () => (/* binding */ FlowData20),
/* harmony export */   "FlowData24": () => (/* binding */ FlowData24),
/* harmony export */   "FlowData32": () => (/* binding */ FlowData32),
/* harmony export */   "FlowLogsVpc16": () => (/* binding */ FlowLogsVpc16),
/* harmony export */   "FlowLogsVpc20": () => (/* binding */ FlowLogsVpc20),
/* harmony export */   "FlowLogsVpc24": () => (/* binding */ FlowLogsVpc24),
/* harmony export */   "FlowLogsVpc32": () => (/* binding */ FlowLogsVpc32),
/* harmony export */   "FlowModeler16": () => (/* binding */ FlowModeler16),
/* harmony export */   "FlowModeler20": () => (/* binding */ FlowModeler20),
/* harmony export */   "FlowModeler24": () => (/* binding */ FlowModeler24),
/* harmony export */   "FlowModeler32": () => (/* binding */ FlowModeler32),
/* harmony export */   "FlowModelerReference16": () => (/* binding */ FlowModelerReference16),
/* harmony export */   "FlowModelerReference20": () => (/* binding */ FlowModelerReference20),
/* harmony export */   "FlowModelerReference24": () => (/* binding */ FlowModelerReference24),
/* harmony export */   "FlowModelerReference32": () => (/* binding */ FlowModelerReference32),
/* harmony export */   "FlowStream16": () => (/* binding */ FlowStream16),
/* harmony export */   "FlowStream20": () => (/* binding */ FlowStream20),
/* harmony export */   "FlowStream24": () => (/* binding */ FlowStream24),
/* harmony export */   "FlowStream32": () => (/* binding */ FlowStream32),
/* harmony export */   "FlowStreamReference16": () => (/* binding */ FlowStreamReference16),
/* harmony export */   "FlowStreamReference20": () => (/* binding */ FlowStreamReference20),
/* harmony export */   "FlowStreamReference24": () => (/* binding */ FlowStreamReference24),
/* harmony export */   "FlowStreamReference32": () => (/* binding */ FlowStreamReference32),
/* harmony export */   "Fog16": () => (/* binding */ Fog16),
/* harmony export */   "Fog20": () => (/* binding */ Fog20),
/* harmony export */   "Fog24": () => (/* binding */ Fog24),
/* harmony export */   "Fog32": () => (/* binding */ Fog32),
/* harmony export */   "Folder24": () => (/* binding */ Folder24),
/* harmony export */   "Folder32": () => (/* binding */ Folder32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _path65, _path66, _path67, _path68, _path69, _path70, _path71, _path72, _path73, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _circle, _path146, _path147, _circle2, _path148, _path149, _circle3, _path150, _path151, _circle4, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _circle5, _path221, _circle6, _path222, _circle7, _path223, _circle8, _path224, _path225, _circle9, _path226, _circle10, _circle11, _path227, _path228, _circle12, _path229, _circle13, _circle14, _path230, _path231, _circle15, _path232, _circle16, _circle17, _path233, _path234, _circle18, _path235, _circle19, _circle20, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388, _path389, _path390, _path391, _path392, _path393, _path394, _path395, _path396, _path397, _path398, _path399, _path400, _path401, _rect, _path402, _rect2, _path403, _rect3, _path404, _rect4, _path405, _path406;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var FaceActivatedAdd32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceActivatedAdd32(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 4L26 4 26 0 24 0 24 4 20 4 20 6 24 6 24 10 26 10 26 6 30 6 30 4zM11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11zM9 20a8.13 8.13 0 0014 0z"
  })), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.82,14A12,12,0,1,1,16,4V2A14,14,0,1,0,30,16a14.71,14.71,0,0,0-.16-2Z"
  })), children);
});
var FaceActivatedAdd24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceActivatedAdd24(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 4L26 4 26 0 24 0 24 4 20 4 20 6 24 6 24 10 26 10 26 6 30 6 30 4zM11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11zM9 20a8.13 8.13 0 0014 0z"
  })), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.82,14A12,12,0,1,1,16,4V2A14,14,0,1,0,30,16a14.71,14.71,0,0,0-.16-2Z"
  })), children);
});
var FaceActivatedAdd20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceActivatedAdd20(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 4L26 4 26 0 24 0 24 4 20 4 20 6 24 6 24 10 26 10 26 6 30 6 30 4zM11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11zM9 20a8.13 8.13 0 0014 0z"
  })), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.82,14A12,12,0,1,1,16,4V2A14,14,0,1,0,30,16a14.71,14.71,0,0,0-.16-2Z"
  })), children);
});
var FaceActivatedAdd16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceActivatedAdd16(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 4L26 4 26 0 24 0 24 4 20 4 20 6 24 6 24 10 26 10 26 6 30 6 30 4zM11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11zM9 20a8.13 8.13 0 0014 0z"
  })), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.82,14A12,12,0,1,1,16,4V2A14,14,0,1,0,30,16a14.71,14.71,0,0,0-.16-2Z"
  })), children);
});
var FaceActivatedFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceActivatedFilled32(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm-4.5,9A2.5,2.5,0,1,1,9,13.5,2.48,2.48,0,0,1,11.5,11ZM16,24a8.11,8.11,0,0,1-7-4H23A8.11,8.11,0,0,1,16,24Zm4.5-8A2.5,2.5,0,1,1,23,13.5,2.48,2.48,0,0,1,20.5,16Z"
  })), children);
});
var FaceActivatedFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceActivatedFilled24(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm-4.5,9A2.5,2.5,0,1,1,9,13.5,2.48,2.48,0,0,1,11.5,11ZM16,24a8.11,8.11,0,0,1-7-4H23A8.11,8.11,0,0,1,16,24Zm4.5-8A2.5,2.5,0,1,1,23,13.5,2.48,2.48,0,0,1,20.5,16Z"
  })), children);
});
var FaceActivatedFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceActivatedFilled20(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm-4.5,9A2.5,2.5,0,1,1,9,13.5,2.48,2.48,0,0,1,11.5,11ZM16,24a8.11,8.11,0,0,1-7-4H23A8.11,8.11,0,0,1,16,24Zm4.5-8A2.5,2.5,0,1,1,23,13.5,2.48,2.48,0,0,1,20.5,16Z"
  })), children);
});
var FaceActivatedFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceActivatedFilled16(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm-4.5,9A2.5,2.5,0,1,1,9,13.5,2.48,2.48,0,0,1,11.5,11ZM16,24a8.11,8.11,0,0,1-7-4H23A8.11,8.11,0,0,1,16,24Zm4.5-8A2.5,2.5,0,1,1,23,13.5,2.48,2.48,0,0,1,20.5,16Z"
  })), children);
});
var FaceAdd32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceAdd32(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22a6 6 0 01-5.14-2.92l-1.71 1a8 8 0 0013.7 0l-1.71-1A6 6 0 0116 22zM30 4L26 4 26 0 24 0 24 4 20 4 20 6 24 6 24 10 26 10 26 6 30 6 30 4zM11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11z"
  })), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.61,13A12.33,12.33,0,0,1,28,16,12,12,0,1,1,16,4V2A14,14,0,1,0,29.67,13Z"
  })), children);
});
var FaceAdd24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceAdd24(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22a6 6 0 01-5.14-2.92l-1.71 1a8 8 0 0013.7 0l-1.71-1A6 6 0 0116 22zM30 4L26 4 26 0 24 0 24 4 20 4 20 6 24 6 24 10 26 10 26 6 30 6 30 4zM11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11z"
  })), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.61,13A12.33,12.33,0,0,1,28,16,12,12,0,1,1,16,4V2A14,14,0,1,0,29.67,13Z"
  })), children);
});
var FaceAdd20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceAdd20(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22a6 6 0 01-5.14-2.92l-1.71 1a8 8 0 0013.7 0l-1.71-1A6 6 0 0116 22zM30 4L26 4 26 0 24 0 24 4 20 4 20 6 24 6 24 10 26 10 26 6 30 6 30 4zM11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11z"
  })), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.61,13A12.33,12.33,0,0,1,28,16,12,12,0,1,1,16,4V2A14,14,0,1,0,29.67,13Z"
  })), children);
});
var FaceAdd16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceAdd16(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22a6 6 0 01-5.14-2.92l-1.71 1a8 8 0 0013.7 0l-1.71-1A6 6 0 0116 22zM30 4L26 4 26 0 24 0 24 4 20 4 20 6 24 6 24 10 26 10 26 6 30 6 30 4zM11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11z"
  })), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.61,13A12.33,12.33,0,0,1,28,16,12,12,0,1,1,16,4V2A14,14,0,1,0,29.67,13Z"
  })), children);
});
var FaceCool32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceCool32(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24a8,8,0,0,0,6.85-3.89l-1.71-1a6,6,0,0,1-10.28,0l-1.71,1A8,8,0,0,0,16,24Z"
  })), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,2a12,12,0,0,1,10.89,7H25a1,1,0,0,0-1-1H8a1,1,0,0,0-1,1H5.11A12,12,0,0,1,16,4Zm0,24A12,12,0,0,1,4,16a11.86,11.86,0,0,1,.4-3H7v2a2,2,0,0,0,2,2h3.31a2,2,0,0,0,2-1.67L14.83,12h2.34l.55,3.33a2,2,0,0,0,2,1.67H23a2,2,0,0,0,2-2V13h2.6a11.86,11.86,0,0,1,.4,3A12,12,0,0,1,16,28Z"
  })), children);
});
var FaceCool24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceCool24(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24a8,8,0,0,0,6.85-3.89l-1.71-1a6,6,0,0,1-10.28,0l-1.71,1A8,8,0,0,0,16,24Z"
  })), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,2a12,12,0,0,1,10.89,7H25a1,1,0,0,0-1-1H8a1,1,0,0,0-1,1H5.11A12,12,0,0,1,16,4Zm0,24A12,12,0,0,1,4,16a11.86,11.86,0,0,1,.4-3H7v2a2,2,0,0,0,2,2h3.31a2,2,0,0,0,2-1.67L14.83,12h2.34l.55,3.33a2,2,0,0,0,2,1.67H23a2,2,0,0,0,2-2V13h2.6a11.86,11.86,0,0,1,.4,3A12,12,0,0,1,16,28Z"
  })), children);
});
var FaceCool20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceCool20(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24a8,8,0,0,0,6.85-3.89l-1.71-1a6,6,0,0,1-10.28,0l-1.71,1A8,8,0,0,0,16,24Z"
  })), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,2a12,12,0,0,1,10.89,7H25a1,1,0,0,0-1-1H8a1,1,0,0,0-1,1H5.11A12,12,0,0,1,16,4Zm0,24A12,12,0,0,1,4,16a11.86,11.86,0,0,1,.4-3H7v2a2,2,0,0,0,2,2h3.31a2,2,0,0,0,2-1.67L14.83,12h2.34l.55,3.33a2,2,0,0,0,2,1.67H23a2,2,0,0,0,2-2V13h2.6a11.86,11.86,0,0,1,.4,3A12,12,0,0,1,16,28Z"
  })), children);
});
var FaceCool16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceCool16(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24a8,8,0,0,0,6.85-3.89l-1.71-1a6,6,0,0,1-10.28,0l-1.71,1A8,8,0,0,0,16,24Z"
  })), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,2a12,12,0,0,1,10.89,7H25a1,1,0,0,0-1-1H8a1,1,0,0,0-1,1H5.11A12,12,0,0,1,16,4Zm0,24A12,12,0,0,1,4,16a11.86,11.86,0,0,1,.4-3H7v2a2,2,0,0,0,2,2h3.31a2,2,0,0,0,2-1.67L14.83,12h2.34l.55,3.33a2,2,0,0,0,2,1.67H23a2,2,0,0,0,2-2V13h2.6a11.86,11.86,0,0,1,.4,3A12,12,0,0,1,16,28Z"
  })), children);
});
var FaceDissatisfied32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceDissatisfied32(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.5 2.5 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.5 2.5 0 0020.5 11zM16 19a8 8 0 00-6.85 3.89l1.71 1a6 6 0 0110.28 0l1.71-1A8 8 0 0016 19z"
  })), children);
});
var FaceDissatisfied24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceDissatisfied24(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.5 2.5 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.5 2.5 0 0020.5 11zM16 19a8 8 0 00-6.85 3.89l1.71 1a6 6 0 0110.28 0l1.71-1A8 8 0 0016 19z"
  })), children);
});
var FaceDissatisfied20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceDissatisfied20(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.5 2.5 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.5 2.5 0 0020.5 11zM16 19a8 8 0 00-6.85 3.89l1.71 1a6 6 0 0110.28 0l1.71-1A8 8 0 0016 19z"
  })), children);
});
var FaceDissatisfied16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceDissatisfied16(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.5 2.5 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.5 2.5 0 0020.5 11zM16 19a8 8 0 00-6.85 3.89l1.71 1a6 6 0 0110.28 0l1.71-1A8 8 0 0016 19z"
  })), children);
});
var FaceDissatisfiedFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceDissatisfiedFilled32(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm-4.5,9h0A2.5,2.5,0,1,1,9,13.5,2.48,2.48,0,0,1,11.54,11Zm9.64,12.92a6,6,0,0,0-10.28,0l-1.71-1a8,8,0,0,1,13.7,0ZM20.5,16a2.5,2.5,0,0,1,0-5h0a2.5,2.5,0,0,1,0,5Z"
  })), children);
});
var FaceDissatisfiedFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceDissatisfiedFilled24(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm-4.5,9h0A2.5,2.5,0,1,1,9,13.5,2.48,2.48,0,0,1,11.54,11Zm9.64,12.92a6,6,0,0,0-10.28,0l-1.71-1a8,8,0,0,1,13.7,0ZM20.5,16a2.5,2.5,0,0,1,0-5h0a2.5,2.5,0,0,1,0,5Z"
  })), children);
});
var FaceDissatisfiedFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceDissatisfiedFilled20(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm-4.5,9h0A2.5,2.5,0,1,1,9,13.5,2.48,2.48,0,0,1,11.54,11Zm9.64,12.92a6,6,0,0,0-10.28,0l-1.71-1a8,8,0,0,1,13.7,0ZM20.5,16a2.5,2.5,0,0,1,0-5h0a2.5,2.5,0,0,1,0,5Z"
  })), children);
});
var FaceDissatisfiedFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceDissatisfiedFilled16(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm-4.5,9h0A2.5,2.5,0,1,1,9,13.5,2.48,2.48,0,0,1,11.54,11Zm9.64,12.92a6,6,0,0,0-10.28,0l-1.71-1a8,8,0,0,1,13.7,0ZM20.5,16a2.5,2.5,0,0,1,0-5h0a2.5,2.5,0,0,1,0,5Z"
  })), children);
});
var FaceDizzy32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceDizzy32(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.41 11L23 9.59 21 11.59 19 9.59 17.59 11 19.59 13 17.59 15 19 16.41 21 14.41 23 16.41 24.41 15 22.41 13 24.41 11zM14.41 11L13 9.59 11 11.59 9 9.59 7.59 11 9.59 13 7.59 15 9 16.41 11 14.41 13 16.41 14.41 15 12.41 13 14.41 11zM16 19a3 3 0 103 3 3 3 0 00-3-3z"
  })), children);
});
var FaceDizzy24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceDizzy24(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.41 11L23 9.59 21 11.59 19 9.59 17.59 11 19.59 13 17.59 15 19 16.41 21 14.41 23 16.41 24.41 15 22.41 13 24.41 11zM14.41 11L13 9.59 11 11.59 9 9.59 7.59 11 9.59 13 7.59 15 9 16.41 11 14.41 13 16.41 14.41 15 12.41 13 14.41 11zM16 19a3 3 0 103 3 3 3 0 00-3-3z"
  })), children);
});
var FaceDizzy20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceDizzy20(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.41 11L23 9.59 21 11.59 19 9.59 17.59 11 19.59 13 17.59 15 19 16.41 21 14.41 23 16.41 24.41 15 22.41 13 24.41 11zM14.41 11L13 9.59 11 11.59 9 9.59 7.59 11 9.59 13 7.59 15 9 16.41 11 14.41 13 16.41 14.41 15 12.41 13 14.41 11zM16 19a3 3 0 103 3 3 3 0 00-3-3z"
  })), children);
});
var FaceDizzy16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceDizzy16(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.41 11L23 9.59 21 11.59 19 9.59 17.59 11 19.59 13 17.59 15 19 16.41 21 14.41 23 16.41 24.41 15 22.41 13 24.41 11zM14.41 11L13 9.59 11 11.59 9 9.59 7.59 11 9.59 13 7.59 15 9 16.41 11 14.41 13 16.41 14.41 15 12.41 13 14.41 11zM16 19a3 3 0 103 3 3 3 0 00-3-3z"
  })), children);
});
var FaceDizzyFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceDizzyFilled32(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM9,16.41,7.59,15l2-2-2-2L9,9.59l2,2,2-2L14.41,11l-2,2,2,2L13,16.41l-2-2ZM16,25a3,3,0,1,1,3-3A3,3,0,0,1,16,25Zm8.41-10L23,16.41l-2-2-2,2L17.59,15l2-2-2-2L19,9.59l2,2,2-2L24.41,11l-2,2Z"
  })), children);
});
var FaceDizzyFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceDizzyFilled24(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM9,16.41,7.59,15l2-2-2-2L9,9.59l2,2,2-2L14.41,11l-2,2,2,2L13,16.41l-2-2ZM16,25a3,3,0,1,1,3-3A3,3,0,0,1,16,25Zm8.41-10L23,16.41l-2-2-2,2L17.59,15l2-2-2-2L19,9.59l2,2,2-2L24.41,11l-2,2Z"
  })), children);
});
var FaceDizzyFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceDizzyFilled20(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM9,16.41,7.59,15l2-2-2-2L9,9.59l2,2,2-2L14.41,11l-2,2,2,2L13,16.41l-2-2ZM16,25a3,3,0,1,1,3-3A3,3,0,0,1,16,25Zm8.41-10L23,16.41l-2-2-2,2L17.59,15l2-2-2-2L19,9.59l2,2,2-2L24.41,11l-2,2Z"
  })), children);
});
var FaceDizzyFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceDizzyFilled16(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM9,16.41,7.59,15l2-2-2-2L9,9.59l2,2,2-2L14.41,11l-2,2,2,2L13,16.41l-2-2ZM16,25a3,3,0,1,1,3-3A3,3,0,0,1,16,25Zm8.41-10L23,16.41l-2-2-2,2L17.59,15l2-2-2-2L19,9.59l2,2,2-2L24.41,11l-2,2Z"
  })), children);
});
var FaceMask32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceMask32(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.5 2.5 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.5 2.5 0 0020.5 11z"
  })), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16A14,14,0,1,0,8.8994,28.042l.0156.1562A1.993,1.993,0,0,0,10.9048,30h10.19a1.9929,1.9929,0,0,0,1.99-1.8008l.0156-.1572A13.9674,13.9674,0,0,0,30,16ZM16,4A11.99,11.99,0,0,1,27.97,15.397L22.7637,18H9.2363L4.0305,15.397A11.99,11.99,0,0,1,16,4ZM4.12,17.6777l3.94,1.97.5813,5.81A11.97,11.97,0,0,1,4.12,17.6777ZM21.0947,28H10.9053l-.8-8h11.79Zm2.2644-2.542.5811-5.81,3.94-1.97A11.9712,11.9712,0,0,1,23.3591,25.458Z"
  })), children);
});
var FaceMask24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceMask24(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.5 2.5 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.5 2.5 0 0020.5 11z"
  })), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16A14,14,0,1,0,8.8994,28.042l.0156.1562A1.993,1.993,0,0,0,10.9048,30h10.19a1.9929,1.9929,0,0,0,1.99-1.8008l.0156-.1572A13.9674,13.9674,0,0,0,30,16ZM16,4A11.99,11.99,0,0,1,27.97,15.397L22.7637,18H9.2363L4.0305,15.397A11.99,11.99,0,0,1,16,4ZM4.12,17.6777l3.94,1.97.5813,5.81A11.97,11.97,0,0,1,4.12,17.6777ZM21.0947,28H10.9053l-.8-8h11.79Zm2.2644-2.542.5811-5.81,3.94-1.97A11.9712,11.9712,0,0,1,23.3591,25.458Z"
  })), children);
});
var FaceMask20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceMask20(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.5 2.5 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.5 2.5 0 0020.5 11z"
  })), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16A14,14,0,1,0,8.8994,28.042l.0156.1562A1.993,1.993,0,0,0,10.9048,30h10.19a1.9929,1.9929,0,0,0,1.99-1.8008l.0156-.1572A13.9674,13.9674,0,0,0,30,16ZM16,4A11.99,11.99,0,0,1,27.97,15.397L22.7637,18H9.2363L4.0305,15.397A11.99,11.99,0,0,1,16,4ZM4.12,17.6777l3.94,1.97.5813,5.81A11.97,11.97,0,0,1,4.12,17.6777ZM21.0947,28H10.9053l-.8-8h11.79Zm2.2644-2.542.5811-5.81,3.94-1.97A11.9712,11.9712,0,0,1,23.3591,25.458Z"
  })), children);
});
var FaceMask16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceMask16(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.5 2.5 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.5 2.5 0 0020.5 11z"
  })), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16A14,14,0,1,0,8.8994,28.042l.0156.1562A1.993,1.993,0,0,0,10.9048,30h10.19a1.9929,1.9929,0,0,0,1.99-1.8008l.0156-.1572A13.9674,13.9674,0,0,0,30,16ZM16,4A11.99,11.99,0,0,1,27.97,15.397L22.7637,18H9.2363L4.0305,15.397A11.99,11.99,0,0,1,16,4ZM4.12,17.6777l3.94,1.97.5813,5.81A11.97,11.97,0,0,1,4.12,17.6777ZM21.0947,28H10.9053l-.8-8h11.79Zm2.2644-2.542.5811-5.81,3.94-1.97A11.9712,11.9712,0,0,1,23.3591,25.458Z"
  })), children);
});
var FaceNeutral32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceNeutral32(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.5 2.5 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.5 2.5 0 0020.5 11zM10 20H22V22H10z"
  })), children);
});
var FaceNeutral24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceNeutral24(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.5 2.5 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.5 2.5 0 0020.5 11zM10 20H22V22H10z"
  })), children);
});
var FaceNeutral20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceNeutral20(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.5 2.5 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.5 2.5 0 0020.5 11zM10 20H22V22H10z"
  })), children);
});
var FaceNeutral16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceNeutral16(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.5 2.5 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.5 2.5 0 0020.5 11zM10 20H22V22H10z"
  })), children);
});
var FaceNeutralFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceNeutralFilled32(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM9,13.5A2.5,2.5,0,1,1,11.5,16,2.5,2.5,0,0,1,9,13.5ZM22,22H10V20H22Zm-1.5-6A2.5,2.5,0,1,1,23,13.5,2.5,2.5,0,0,1,20.5,16Z"
  })), children);
});
var FaceNeutralFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceNeutralFilled24(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM9,13.5A2.5,2.5,0,1,1,11.5,16,2.5,2.5,0,0,1,9,13.5ZM22,22H10V20H22Zm-1.5-6A2.5,2.5,0,1,1,23,13.5,2.5,2.5,0,0,1,20.5,16Z"
  })), children);
});
var FaceNeutralFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceNeutralFilled20(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM9,13.5A2.5,2.5,0,1,1,11.5,16,2.5,2.5,0,0,1,9,13.5ZM22,22H10V20H22Zm-1.5-6A2.5,2.5,0,1,1,23,13.5,2.5,2.5,0,0,1,20.5,16Z"
  })), children);
});
var FaceNeutralFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceNeutralFilled16(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM9,13.5A2.5,2.5,0,1,1,11.5,16,2.5,2.5,0,0,1,9,13.5ZM22,22H10V20H22Zm-1.5-6A2.5,2.5,0,1,1,23,13.5,2.5,2.5,0,0,1,20.5,16Z"
  })), children);
});
var FacePending32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FacePending32(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11z"
  })), children);
});
var FacePending24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FacePending24(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11z"
  })), children);
});
var FacePending20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FacePending20(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11z"
  })), children);
});
var FacePending16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FacePending16(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11z"
  })), children);
});
var FacePendingFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FacePendingFilled32(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM11.5,16A2.5,2.5,0,1,1,14,13.5,2.48,2.48,0,0,1,11.5,16Zm9,0A2.5,2.5,0,1,1,23,13.5,2.48,2.48,0,0,1,20.5,16Z"
  })), children);
});
var FacePendingFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FacePendingFilled24(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM11.5,16A2.5,2.5,0,1,1,14,13.5,2.48,2.48,0,0,1,11.5,16Zm9,0A2.5,2.5,0,1,1,23,13.5,2.48,2.48,0,0,1,20.5,16Z"
  })), children);
});
var FacePendingFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FacePendingFilled20(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM11.5,16A2.5,2.5,0,1,1,14,13.5,2.48,2.48,0,0,1,11.5,16Zm9,0A2.5,2.5,0,1,1,23,13.5,2.48,2.48,0,0,1,20.5,16Z"
  })), children);
});
var FacePendingFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FacePendingFilled16(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM11.5,16A2.5,2.5,0,1,1,14,13.5,2.48,2.48,0,0,1,11.5,16Zm9,0A2.5,2.5,0,1,1,23,13.5,2.48,2.48,0,0,1,20.5,16Z"
  })), children);
});
var FaceSatisfied32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceSatisfied32(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11zM16 24a8 8 0 006.85-3.89l-1.71-1a6 6 0 01-10.28 0l-1.71 1A8 8 0 0016 24z"
  })), children);
});
var FaceSatisfied24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceSatisfied24(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11zM16 24a8 8 0 006.85-3.89l-1.71-1a6 6 0 01-10.28 0l-1.71 1A8 8 0 0016 24z"
  })), children);
});
var FaceSatisfied20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceSatisfied20(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11zM16 24a8 8 0 006.85-3.89l-1.71-1a6 6 0 01-10.28 0l-1.71 1A8 8 0 0016 24z"
  })), children);
});
var FaceSatisfied16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceSatisfied16(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.5 11A2.5 2.5 0 1014 13.5 2.48 2.48 0 0011.5 11zM20.5 11A2.5 2.5 0 1023 13.5 2.48 2.48 0 0020.5 11zM16 24a8 8 0 006.85-3.89l-1.71-1a6 6 0 01-10.28 0l-1.71 1A8 8 0 0016 24z"
  })), children);
});
var FaceSatisfiedFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceSatisfiedFilled32(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm-4.5,9A2.5,2.5,0,1,1,9,13.5,2.48,2.48,0,0,1,11.5,11ZM16,24a8,8,0,0,1-6.85-3.89l1.71-1a6,6,0,0,0,10.28,0l1.71,1A8,8,0,0,1,16,24Zm4.5-8A2.5,2.5,0,1,1,23,13.5,2.48,2.48,0,0,1,20.5,16Z"
  })), children);
});
var FaceSatisfiedFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceSatisfiedFilled24(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm-4.5,9A2.5,2.5,0,1,1,9,13.5,2.48,2.48,0,0,1,11.5,11ZM16,24a8,8,0,0,1-6.85-3.89l1.71-1a6,6,0,0,0,10.28,0l1.71,1A8,8,0,0,1,16,24Zm4.5-8A2.5,2.5,0,1,1,23,13.5,2.48,2.48,0,0,1,20.5,16Z"
  })), children);
});
var FaceSatisfiedFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceSatisfiedFilled20(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm-4.5,9A2.5,2.5,0,1,1,9,13.5,2.48,2.48,0,0,1,11.5,11ZM16,24a8,8,0,0,1-6.85-3.89l1.71-1a6,6,0,0,0,10.28,0l1.71,1A8,8,0,0,1,16,24Zm4.5-8A2.5,2.5,0,1,1,23,13.5,2.48,2.48,0,0,1,20.5,16Z"
  })), children);
});
var FaceSatisfiedFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceSatisfiedFilled16(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm-4.5,9A2.5,2.5,0,1,1,9,13.5,2.48,2.48,0,0,1,11.5,11ZM16,24a8,8,0,0,1-6.85-3.89l1.71-1a6,6,0,0,0,10.28,0l1.71,1A8,8,0,0,1,16,24Zm4.5-8A2.5,2.5,0,1,1,23,13.5,2.48,2.48,0,0,1,20.5,16Z"
  })), children);
});
var FaceWink32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceWink32(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.5 11A2.5 2.5 0 1023 13.5 2.5 2.5 0 0020.5 11zM8 13H14V15H8zM16 24a8 8 0 006.85-3.89l-1.71-1a6 6 0 01-10.28 0l-1.71 1A8 8 0 0016 24z"
  })), children);
});
var FaceWink24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceWink24(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.5 11A2.5 2.5 0 1023 13.5 2.5 2.5 0 0020.5 11zM8 13H14V15H8zM16 24a8 8 0 006.85-3.89l-1.71-1a6 6 0 01-10.28 0l-1.71 1A8 8 0 0016 24z"
  })), children);
});
var FaceWink20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceWink20(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.5 11A2.5 2.5 0 1023 13.5 2.5 2.5 0 0020.5 11zM8 13H14V15H8zM16 24a8 8 0 006.85-3.89l-1.71-1a6 6 0 01-10.28 0l-1.71 1A8 8 0 0016 24z"
  })), children);
});
var FaceWink16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceWink16(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.5 11A2.5 2.5 0 1023 13.5 2.5 2.5 0 0020.5 11zM8 13H14V15H8zM16 24a8 8 0 006.85-3.89l-1.71-1a6 6 0 01-10.28 0l-1.71 1A8 8 0 0016 24z"
  })), children);
});
var FaceWinkFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceWinkFilled32(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM8,13h6v2H8Zm8,11a8,8,0,0,1-6.85-3.89l1.71-1a6,6,0,0,0,10.28,0l1.71,1A8,8,0,0,1,16,24Zm4.5-8a2.5,2.5,0,0,1,0-5h0a2.5,2.5,0,0,1,0,5Z"
  })), children);
});
var FaceWinkFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceWinkFilled24(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM8,13h6v2H8Zm8,11a8,8,0,0,1-6.85-3.89l1.71-1a6,6,0,0,0,10.28,0l1.71,1A8,8,0,0,1,16,24Zm4.5-8a2.5,2.5,0,0,1,0-5h0a2.5,2.5,0,0,1,0,5Z"
  })), children);
});
var FaceWinkFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceWinkFilled20(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM8,13h6v2H8Zm8,11a8,8,0,0,1-6.85-3.89l1.71-1a6,6,0,0,0,10.28,0l1.71,1A8,8,0,0,1,16,24Zm4.5-8a2.5,2.5,0,0,1,0-5h0a2.5,2.5,0,0,1,0,5Z"
  })), children);
});
var FaceWinkFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FaceWinkFilled16(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM8,13h6v2H8Zm8,11a8,8,0,0,1-6.85-3.89l1.71-1a6,6,0,0,0,10.28,0l1.71,1A8,8,0,0,1,16,24Zm4.5-8a2.5,2.5,0,0,1,0-5h0a2.5,2.5,0,0,1,0,5Z"
  })), children);
});
var Factor32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Factor32(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,28V9H24V4h2V2H20V4h2V9H19V28H15V16H12V11h2V9H8v2h2v5H7V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM13,28H9V18h4Zm8-17h4V28H21Z"
  })), children);
});
var Factor24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Factor24(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,28V9H24V4h2V2H20V4h2V9H19V28H15V16H12V11h2V9H8v2h2v5H7V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM13,28H9V18h4Zm8-17h4V28H21Z"
  })), children);
});
var Factor20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Factor20(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,28V9H24V4h2V2H20V4h2V9H19V28H15V16H12V11h2V9H8v2h2v5H7V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM13,28H9V18h4Zm8-17h4V28H21Z"
  })), children);
});
var Factor16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Factor16(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,28V9H24V4h2V2H20V4h2V9H19V28H15V16H12V11h2V9H8v2h2v5H7V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM13,28H9V18h4Zm8-17h4V28H21Z"
  })), children);
});
var Fade32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Fade32(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.24 25.14L7 26.67a13.79 13.79 0 004.18 2.44l.69-1.87A12 12 0 018.24 25.14zM4.19 18l-2 .41A14.09 14.09 0 003.86 23L5.59 22A12.44 12.44 0 014.19 18zM11.82 4.76l-.69-1.87A13.79 13.79 0 007 5.33L8.24 6.86A12 12 0 0111.82 4.76zM5.59 10L3.86 9a14.37 14.37 0 00-1.64 4.59l2 .34A12.05 12.05 0 015.59 10zM16 2V4a12 12 0 010 24v2A14 14 0 0016 2z"
  })), children);
});
var Fade24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Fade24(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.24 25.14L7 26.67a13.79 13.79 0 004.18 2.44l.69-1.87A12 12 0 018.24 25.14zM4.19 18l-2 .41A14.09 14.09 0 003.86 23L5.59 22A12.44 12.44 0 014.19 18zM11.82 4.76l-.69-1.87A13.79 13.79 0 007 5.33L8.24 6.86A12 12 0 0111.82 4.76zM5.59 10L3.86 9a14.37 14.37 0 00-1.64 4.59l2 .34A12.05 12.05 0 015.59 10zM16 2V4a12 12 0 010 24v2A14 14 0 0016 2z"
  })), children);
});
var Fade20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Fade20(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.24 25.14L7 26.67a13.79 13.79 0 004.18 2.44l.69-1.87A12 12 0 018.24 25.14zM4.19 18l-2 .41A14.09 14.09 0 003.86 23L5.59 22A12.44 12.44 0 014.19 18zM11.82 4.76l-.69-1.87A13.79 13.79 0 007 5.33L8.24 6.86A12 12 0 0111.82 4.76zM5.59 10L3.86 9a14.37 14.37 0 00-1.64 4.59l2 .34A12.05 12.05 0 015.59 10zM16 2V4a12 12 0 010 24v2A14 14 0 0016 2z"
  })), children);
});
var Fade16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Fade16(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.1 12.6l-.6.8c.6.5 1.3.9 2.1 1.2l.3-.9C5.3 13.4 4.7 13 4.1 12.6zM2.1 9l-1 .2c.1.8.4 1.6.8 2.3L2.8 11C2.4 10.4 2.2 9.7 2.1 9zM5.9 2.4L5.6 1.4C4.8 1.7 4.1 2.1 3.5 2.7l.6.8C4.7 3 5.3 2.6 5.9 2.4zM2.8 5L1.9 4.5C1.5 5.2 1.3 6 1.1 6.8l1 .2C2.2 6.3 2.5 5.6 2.8 5zM8 1v1c3.3 0 6 2.7 6 6s-2.7 6-6 6v1c3.9 0 7-3.1 7-7S11.9 1 8 1z"
  })), children);
});
var Favorite32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Favorite32(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.45,6a5.47,5.47,0,0,1,3.91,1.64,5.7,5.7,0,0,1,0,8L16,26.13,5.64,15.64a5.7,5.7,0,0,1,0-8,5.48,5.48,0,0,1,7.82,0L16,10.24l2.53-2.58A5.44,5.44,0,0,1,22.45,6m0-2a7.47,7.47,0,0,0-5.34,2.24L16,7.36,14.89,6.24a7.49,7.49,0,0,0-10.68,0,7.72,7.72,0,0,0,0,10.82L16,29,27.79,17.06a7.72,7.72,0,0,0,0-10.82A7.49,7.49,0,0,0,22.45,4Z"
  })), children);
});
var Favorite24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Favorite24(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.45,6a5.47,5.47,0,0,1,3.91,1.64,5.7,5.7,0,0,1,0,8L16,26.13,5.64,15.64a5.7,5.7,0,0,1,0-8,5.48,5.48,0,0,1,7.82,0L16,10.24l2.53-2.58A5.44,5.44,0,0,1,22.45,6m0-2a7.47,7.47,0,0,0-5.34,2.24L16,7.36,14.89,6.24a7.49,7.49,0,0,0-10.68,0,7.72,7.72,0,0,0,0,10.82L16,29,27.79,17.06a7.72,7.72,0,0,0,0-10.82A7.49,7.49,0,0,0,22.45,4Z"
  })), children);
});
var Favorite20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Favorite20(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.45,6a5.47,5.47,0,0,1,3.91,1.64,5.7,5.7,0,0,1,0,8L16,26.13,5.64,15.64a5.7,5.7,0,0,1,0-8,5.48,5.48,0,0,1,7.82,0L16,10.24l2.53-2.58A5.44,5.44,0,0,1,22.45,6m0-2a7.47,7.47,0,0,0-5.34,2.24L16,7.36,14.89,6.24a7.49,7.49,0,0,0-10.68,0,7.72,7.72,0,0,0,0,10.82L16,29,27.79,17.06a7.72,7.72,0,0,0,0-10.82A7.49,7.49,0,0,0,22.45,4Z"
  })), children);
});
var Favorite16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Favorite16(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.45,6a5.47,5.47,0,0,1,3.91,1.64,5.7,5.7,0,0,1,0,8L16,26.13,5.64,15.64a5.7,5.7,0,0,1,0-8,5.48,5.48,0,0,1,7.82,0L16,10.24l2.53-2.58A5.44,5.44,0,0,1,22.45,6m0-2a7.47,7.47,0,0,0-5.34,2.24L16,7.36,14.89,6.24a7.49,7.49,0,0,0-10.68,0,7.72,7.72,0,0,0,0,10.82L16,29,27.79,17.06a7.72,7.72,0,0,0,0-10.82A7.49,7.49,0,0,0,22.45,4Z"
  })), children);
});
var FavoriteFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FavoriteFilled32(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.5,4c-2,0-3.9,0.8-5.3,2.2L16,7.4l-1.1-1.1C12,3.3,7.2,3.3,4.3,6.2c0,0-0.1,0.1-0.1,0.1c-3,3-3,7.8,0,10.8L16,29\tl11.8-11.9c3-3,3-7.8,0-10.8C26.4,4.8,24.5,4,22.5,4z"
  })), children);
});
var FavoriteFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FavoriteFilled24(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.5,4c-2,0-3.9,0.8-5.3,2.2L16,7.4l-1.1-1.1C12,3.3,7.2,3.3,4.3,6.2c0,0-0.1,0.1-0.1,0.1c-3,3-3,7.8,0,10.8L16,29\tl11.8-11.9c3-3,3-7.8,0-10.8C26.4,4.8,24.5,4,22.5,4z"
  })), children);
});
var FavoriteFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FavoriteFilled20(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.5,4c-2,0-3.9,0.8-5.3,2.2L16,7.4l-1.1-1.1C12,3.3,7.2,3.3,4.3,6.2c0,0-0.1,0.1-0.1,0.1c-3,3-3,7.8,0,10.8L16,29\tl11.8-11.9c3-3,3-7.8,0-10.8C26.4,4.8,24.5,4,22.5,4z"
  })), children);
});
var FavoriteFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FavoriteFilled16(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.5,4c-2,0-3.9,0.8-5.3,2.2L16,7.4l-1.1-1.1C12,3.3,7.2,3.3,4.3,6.2c0,0-0.1,0.1-0.1,0.1c-3,3-3,7.8,0,10.8L16,29\tl11.8-11.9c3-3,3-7.8,0-10.8C26.4,4.8,24.5,4,22.5,4z"
  })), children);
});
var FavoriteHalf32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FavoriteHalf32(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.21,17.0615,16,29,27.79,17.0615a7.7313,7.7313,0,0,0,0-10.8232,7.494,7.494,0,0,0-10.6841,0L16,7.3643l-1.1062-1.126a7.494,7.494,0,0,0-10.6841,0A7.7313,7.7313,0,0,0,4.21,17.0615ZM26.3552,15.645,16,26.1255V10.23q1.2708-1.2876,2.5413-2.5742a5.4768,5.4768,0,0,1,7.8139,0A5.708,5.708,0,0,1,26.3552,15.645Z"
  })), children);
});
var FavoriteHalf24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FavoriteHalf24(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.21,17.0615,16,29,27.79,17.0615a7.7313,7.7313,0,0,0,0-10.8232,7.494,7.494,0,0,0-10.6841,0L16,7.3643l-1.1062-1.126a7.494,7.494,0,0,0-10.6841,0A7.7313,7.7313,0,0,0,4.21,17.0615ZM26.3552,15.645,16,26.1255V10.23q1.2708-1.2876,2.5413-2.5742a5.4768,5.4768,0,0,1,7.8139,0A5.708,5.708,0,0,1,26.3552,15.645Z"
  })), children);
});
var FavoriteHalf20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FavoriteHalf20(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.21,17.0615,16,29,27.79,17.0615a7.7313,7.7313,0,0,0,0-10.8232,7.494,7.494,0,0,0-10.6841,0L16,7.3643l-1.1062-1.126a7.494,7.494,0,0,0-10.6841,0A7.7313,7.7313,0,0,0,4.21,17.0615ZM26.3552,15.645,16,26.1255V10.23q1.2708-1.2876,2.5413-2.5742a5.4768,5.4768,0,0,1,7.8139,0A5.708,5.708,0,0,1,26.3552,15.645Z"
  })), children);
});
var FavoriteHalf16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FavoriteHalf16(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.21,17.0615,16,29,27.79,17.0615a7.7313,7.7313,0,0,0,0-10.8232,7.494,7.494,0,0,0-10.6841,0L16,7.3643l-1.1062-1.126a7.494,7.494,0,0,0-10.6841,0A7.7313,7.7313,0,0,0,4.21,17.0615ZM26.3552,15.645,16,26.1255V10.23q1.2708-1.2876,2.5413-2.5742a5.4768,5.4768,0,0,1,7.8139,0A5.708,5.708,0,0,1,26.3552,15.645Z"
  })), children);
});
var FetchUpload32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FetchUpload32(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7,6,17l1.41,1.41L15,10.83V28H2v2H15a2,2,0,0,0,2-2V10.83l7.59,7.58L26,17Z"
  })), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,8V4H26V8h2V4a2,2,0,0,0-2-2H6A2,2,0,0,0,4,4V8Z"
  })), children);
});
var FetchUpload24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FetchUpload24(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7,6,17l1.41,1.41L15,10.83V28H2v2H15a2,2,0,0,0,2-2V10.83l7.59,7.58L26,17Z"
  })), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,8V4H26V8h2V4a2,2,0,0,0-2-2H6A2,2,0,0,0,4,4V8Z"
  })), children);
});
var FetchUpload20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FetchUpload20(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7,6,17l1.41,1.41L15,10.83V28H2v2H15a2,2,0,0,0,2-2V10.83l7.59,7.58L26,17Z"
  })), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,8V4H26V8h2V4a2,2,0,0,0-2-2H6A2,2,0,0,0,4,4V8Z"
  })), children);
});
var FetchUpload16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FetchUpload16(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7,6,17l1.41,1.41L15,10.83V28H2v2H15a2,2,0,0,0,2-2V10.83l7.59,7.58L26,17Z"
  })), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,8V4H26V8h2V4a2,2,0,0,0-2-2H6A2,2,0,0,0,4,4V8Z"
  })), children);
});
var FetchUploadCloud32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FetchUploadCloud32(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,13l-5,5,1.41,1.41L15,16.83V28H6v2h9a2,2,0,0,0,2-2V16.83l2.59,2.58L21,18Z"
  })), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,22H23V20h.5a4.4975,4.4975,0,0,0,.3564-8.981l-.8154-.0639-.0986-.812a6.9938,6.9938,0,0,0-13.8838,0l-.0991.812-.8155.0639A4.4975,4.4975,0,0,0,8.5,20H9v2H8.5A6.4973,6.4973,0,0,1,7.2,9.1362a8.9943,8.9943,0,0,1,17.6006,0A6.4974,6.4974,0,0,1,23.5,22Z"
  })), children);
});
var FetchUploadCloud24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FetchUploadCloud24(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,13l-5,5,1.41,1.41L15,16.83V28H6v2h9a2,2,0,0,0,2-2V16.83l2.59,2.58L21,18Z"
  })), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,22H23V20h.5a4.4975,4.4975,0,0,0,.3564-8.981l-.8154-.0639-.0986-.812a6.9938,6.9938,0,0,0-13.8838,0l-.0991.812-.8155.0639A4.4975,4.4975,0,0,0,8.5,20H9v2H8.5A6.4973,6.4973,0,0,1,7.2,9.1362a8.9943,8.9943,0,0,1,17.6006,0A6.4974,6.4974,0,0,1,23.5,22Z"
  })), children);
});
var FetchUploadCloud20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FetchUploadCloud20(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,13l-5,5,1.41,1.41L15,16.83V28H6v2h9a2,2,0,0,0,2-2V16.83l2.59,2.58L21,18Z"
  })), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,22H23V20h.5a4.4975,4.4975,0,0,0,.3564-8.981l-.8154-.0639-.0986-.812a6.9938,6.9938,0,0,0-13.8838,0l-.0991.812-.8155.0639A4.4975,4.4975,0,0,0,8.5,20H9v2H8.5A6.4973,6.4973,0,0,1,7.2,9.1362a8.9943,8.9943,0,0,1,17.6006,0A6.4974,6.4974,0,0,1,23.5,22Z"
  })), children);
});
var FetchUploadCloud16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FetchUploadCloud16(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,13l-5,5,1.41,1.41L15,16.83V28H6v2h9a2,2,0,0,0,2-2V16.83l2.59,2.58L21,18Z"
  })), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,22H23V20h.5a4.4975,4.4975,0,0,0,.3564-8.981l-.8154-.0639-.0986-.812a6.9938,6.9938,0,0,0-13.8838,0l-.0991.812-.8155.0639A4.4975,4.4975,0,0,0,8.5,20H9v2H8.5A6.4973,6.4973,0,0,1,7.2,9.1362a8.9943,8.9943,0,0,1,17.6006,0A6.4974,6.4974,0,0,1,23.5,22Z"
  })), children);
});
var FileStorage32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FileStorage32(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H6V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.707,7.293l-5-5A1,1,0,0,0,17,2H11A2.0023,2.0023,0,0,0,9,4V20a2.0023,2.0023,0,0,0,2,2H21a2.0023,2.0023,0,0,0,2-2V8A1,1,0,0,0,22.707,7.293ZM20.5857,8H17V4.4141ZM11,20V4h4V8a2.0023,2.0023,0,0,0,2,2h4V20Z"
  })), children);
});
var FileStorage24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FileStorage24(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H6V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.707,7.293l-5-5A1,1,0,0,0,17,2H11A2.0023,2.0023,0,0,0,9,4V20a2.0023,2.0023,0,0,0,2,2H21a2.0023,2.0023,0,0,0,2-2V8A1,1,0,0,0,22.707,7.293ZM20.5857,8H17V4.4141ZM11,20V4h4V8a2.0023,2.0023,0,0,0,2,2h4V20Z"
  })), children);
});
var FileStorage20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FileStorage20(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H6V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.707,7.293l-5-5A1,1,0,0,0,17,2H11A2.0023,2.0023,0,0,0,9,4V20a2.0023,2.0023,0,0,0,2,2H21a2.0023,2.0023,0,0,0,2-2V8A1,1,0,0,0,22.707,7.293ZM20.5857,8H17V4.4141ZM11,20V4h4V8a2.0023,2.0023,0,0,0,2,2h4V20Z"
  })), children);
});
var FileStorage16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FileStorage16(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H6V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.707,7.293l-5-5A1,1,0,0,0,17,2H11A2.0023,2.0023,0,0,0,9,4V20a2.0023,2.0023,0,0,0,2,2H21a2.0023,2.0023,0,0,0,2-2V8A1,1,0,0,0,22.707,7.293ZM20.5857,8H17V4.4141ZM11,20V4h4V8a2.0023,2.0023,0,0,0,2,2h4V20Z"
  })), children);
});
var Filter32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Filter32(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28H14a2,2,0,0,1-2-2V18.41L4.59,11A2,2,0,0,1,4,9.59V6A2,2,0,0,1,6,4H26a2,2,0,0,1,2,2V9.59A2,2,0,0,1,27.41,11L20,18.41V26A2,2,0,0,1,18,28ZM6,6V9.59l8,8V26h4V17.59l8-8V6Z"
  })), children);
});
var Filter24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Filter24(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28H14a2,2,0,0,1-2-2V18.41L4.59,11A2,2,0,0,1,4,9.59V6A2,2,0,0,1,6,4H26a2,2,0,0,1,2,2V9.59A2,2,0,0,1,27.41,11L20,18.41V26A2,2,0,0,1,18,28ZM6,6V9.59l8,8V26h4V17.59l8-8V6Z"
  })), children);
});
var Filter20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Filter20(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28H14a2,2,0,0,1-2-2V18.41L4.59,11A2,2,0,0,1,4,9.59V6A2,2,0,0,1,6,4H26a2,2,0,0,1,2,2V9.59A2,2,0,0,1,27.41,11L20,18.41V26A2,2,0,0,1,18,28ZM6,6V9.59l8,8V26h4V17.59l8-8V6Z"
  })), children);
});
var Filter16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Filter16(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28H14a2,2,0,0,1-2-2V18.41L4.59,11A2,2,0,0,1,4,9.59V6A2,2,0,0,1,6,4H26a2,2,0,0,1,2,2V9.59A2,2,0,0,1,27.41,11L20,18.41V26A2,2,0,0,1,18,28ZM6,6V9.59l8,8V26h4V17.59l8-8V6Z"
  })), children);
});
var FilterEdit32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FilterEdit32(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6H4V9.17l7.41,7.42.59.58V26h4V24h2v2a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V18L2.59,10.59A2,2,0,0,1,2,9.17V6A2,2,0,0,1,4,4H26Z"
  })), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.71,11.29l-3-3a1,1,0,0,0-1.42,0L16,17.59V22h4.41l9.3-9.29A1,1,0,0,0,29.71,11.29ZM19.59,20H18V18.41l5-5L24.59,15ZM26,13.59,24.41,12,26,10.41,27.59,12Z"
  })), children);
});
var FilterEdit24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FilterEdit24(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6H4V9.17l7.41,7.42.59.58V26h4V24h2v2a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V18L2.59,10.59A2,2,0,0,1,2,9.17V6A2,2,0,0,1,4,4H26Z"
  })), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.71,11.29l-3-3a1,1,0,0,0-1.42,0L16,17.59V22h4.41l9.3-9.29A1,1,0,0,0,29.71,11.29ZM19.59,20H18V18.41l5-5L24.59,15ZM26,13.59,24.41,12,26,10.41,27.59,12Z"
  })), children);
});
var FilterEdit20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FilterEdit20(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6H4V9.17l7.41,7.42.59.58V26h4V24h2v2a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V18L2.59,10.59A2,2,0,0,1,2,9.17V6A2,2,0,0,1,4,4H26Z"
  })), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.71,11.29l-3-3a1,1,0,0,0-1.42,0L16,17.59V22h4.41l9.3-9.29A1,1,0,0,0,29.71,11.29ZM19.59,20H18V18.41l5-5L24.59,15ZM26,13.59,24.41,12,26,10.41,27.59,12Z"
  })), children);
});
var FilterEdit16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FilterEdit16(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6H4V9.17l7.41,7.42.59.58V26h4V24h2v2a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V18L2.59,10.59A2,2,0,0,1,2,9.17V6A2,2,0,0,1,4,4H26Z"
  })), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.71,11.29l-3-3a1,1,0,0,0-1.42,0L16,17.59V22h4.41l9.3-9.29A1,1,0,0,0,29.71,11.29ZM19.59,20H18V18.41l5-5L24.59,15ZM26,13.59,24.41,12,26,10.41,27.59,12Z"
  })), children);
});
var FilterRemove32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FilterRemove32(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 11.414L28.586 10 24 14.586 19.414 10 18 11.414 22.586 16 18 20.585 19.415 22 24 17.414 28.587 22 30 20.587 25.414 16 30 11.414z"
  })), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,4A2,2,0,0,0,2,6V9.1709a2,2,0,0,0,.5859,1.4145L10,18v8a2,2,0,0,0,2,2h4a2,2,0,0,0,2-2V24H16v2H12V17.1709l-.5859-.5855L4,9.1709V6H24V8h2V6a2,2,0,0,0-2-2Z"
  })), children);
});
var FilterRemove24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FilterRemove24(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 11.414L28.586 10 24 14.586 19.414 10 18 11.414 22.586 16 18 20.585 19.415 22 24 17.414 28.587 22 30 20.587 25.414 16 30 11.414z"
  })), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,4A2,2,0,0,0,2,6V9.1709a2,2,0,0,0,.5859,1.4145L10,18v8a2,2,0,0,0,2,2h4a2,2,0,0,0,2-2V24H16v2H12V17.1709l-.5859-.5855L4,9.1709V6H24V8h2V6a2,2,0,0,0-2-2Z"
  })), children);
});
var FilterRemove20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FilterRemove20(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 11.414L28.586 10 24 14.586 19.414 10 18 11.414 22.586 16 18 20.585 19.415 22 24 17.414 28.587 22 30 20.587 25.414 16 30 11.414z"
  })), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,4A2,2,0,0,0,2,6V9.1709a2,2,0,0,0,.5859,1.4145L10,18v8a2,2,0,0,0,2,2h4a2,2,0,0,0,2-2V24H16v2H12V17.1709l-.5859-.5855L4,9.1709V6H24V8h2V6a2,2,0,0,0-2-2Z"
  })), children);
});
var FilterRemove16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FilterRemove16(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 11.414L28.586 10 24 14.586 19.414 10 18 11.414 22.586 16 18 20.585 19.415 22 24 17.414 28.587 22 30 20.587 25.414 16 30 11.414z"
  })), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,4A2,2,0,0,0,2,6V9.1709a2,2,0,0,0,.5859,1.4145L10,18v8a2,2,0,0,0,2,2h4a2,2,0,0,0,2-2V24H16v2H12V17.1709l-.5859-.5855L4,9.1709V6H24V8h2V6a2,2,0,0,0-2-2Z"
  })), children);
});
var FilterReset32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FilterReset32(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.5,9A7.4522,7.4522,0,0,0,16,12.792V8H14v8h8V14H17.6167A5.4941,5.4941,0,1,1,22.5,22H22v2h.5a7.5,7.5,0,0,0,0-15Z"
  })), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6H4V9.171l7.4142,7.4143L12,17.171V26h4V24h2v2a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V18L2.5858,10.5853A2,2,0,0,1,2,9.171V6A2,2,0,0,1,4,4H26Z"
  })), children);
});
var FilterReset24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FilterReset24(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.5,9A7.4522,7.4522,0,0,0,16,12.792V8H14v8h8V14H17.6167A5.4941,5.4941,0,1,1,22.5,22H22v2h.5a7.5,7.5,0,0,0,0-15Z"
  })), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6H4V9.171l7.4142,7.4143L12,17.171V26h4V24h2v2a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V18L2.5858,10.5853A2,2,0,0,1,2,9.171V6A2,2,0,0,1,4,4H26Z"
  })), children);
});
var FilterReset20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FilterReset20(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.5,9A7.4522,7.4522,0,0,0,16,12.792V8H14v8h8V14H17.6167A5.4941,5.4941,0,1,1,22.5,22H22v2h.5a7.5,7.5,0,0,0,0-15Z"
  })), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6H4V9.171l7.4142,7.4143L12,17.171V26h4V24h2v2a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V18L2.5858,10.5853A2,2,0,0,1,2,9.171V6A2,2,0,0,1,4,4H26Z"
  })), children);
});
var FilterReset16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FilterReset16(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.5,9A7.4522,7.4522,0,0,0,16,12.792V8H14v8h8V14H17.6167A5.4941,5.4941,0,1,1,22.5,22H22v2h.5a7.5,7.5,0,0,0,0-15Z"
  })), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6H4V9.171l7.4142,7.4143L12,17.171V26h4V24h2v2a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V18L2.5858,10.5853A2,2,0,0,1,2,9.171V6A2,2,0,0,1,4,4H26Z"
  })), children);
});
var Finance32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Finance32(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM27 11a1 1 0 001-1V7a1 1 0 00-.66-.94l-11-4a1 1 0 00-.68 0l-11 4A1 1 0 004 7v3a1 1 0 001 1H6V24H4v2H28V24H26V11zM6 7.7L16 4.06 26 7.7V9H6zM18 24H14V11h4zM8 11h4V24H8zM24 24H20V11h4z"
  })), children);
});
var Finance24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Finance24(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM27 11a1 1 0 001-1V7a1 1 0 00-.66-.94l-11-4a1 1 0 00-.68 0l-11 4A1 1 0 004 7v3a1 1 0 001 1H6V24H4v2H28V24H26V11zM6 7.7L16 4.06 26 7.7V9H6zM18 24H14V11h4zM8 11h4V24H8zM24 24H20V11h4z"
  })), children);
});
var Finance20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Finance20(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM27 11a1 1 0 001-1V7a1 1 0 00-.66-.94l-11-4a1 1 0 00-.68 0l-11 4A1 1 0 004 7v3a1 1 0 001 1H6V24H4v2H28V24H26V11zM6 7.7L16 4.06 26 7.7V9H6zM18 24H14V11h4zM8 11h4V24H8zM24 24H20V11h4z"
  })), children);
});
var Finance16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Finance16(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM27 11a1 1 0 001-1V7a1 1 0 00-.66-.94l-11-4a1 1 0 00-.68 0l-11 4A1 1 0 004 7v3a1 1 0 001 1H6V24H4v2H28V24H26V11zM6 7.7L16 4.06 26 7.7V9H6zM18 24H14V11h4zM8 11h4V24H8zM24 24H20V11h4z"
  })), children);
});
var FingerprintRecognition32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FingerprintRecognition32(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,5.21a.77.77,0,0,1-.46-1.38A15.46,15.46,0,0,1,16,1c2.66,0,6.48.45,9.5,2.62a.77.77,0,0,1,.18,1.07.78.78,0,0,1-1.08.17A15,15,0,0,0,16,2.53,14,14,0,0,0,7.5,5.05.74.74,0,0,1,7,5.21Z"
  })), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.23,12.26a.78.78,0,0,1-.63-.33C25.87,9.49,22.78,6.24,16,6.24a14,14,0,0,0-11.63,5.7.77.77,0,0,1-1.07.17A.76.76,0,0,1,3.15,11,15.54,15.54,0,0,1,16,4.71c5.61,0,9.81,2.08,12.84,6.34a.77.77,0,0,1-.19,1.07A.79.79,0,0,1,28.23,12.26Z"
  })), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.28,31a.78.78,0,0,1-.72-.49.75.75,0,0,1,.44-1c4.37-1.68,7-5.12,7-9.21a2.8,2.8,0,0,0-3-3c-1.86,0-2.76,1-3,3.35a4.27,4.27,0,0,1-4.52,3.83,4.27,4.27,0,0,1-4.32-4.59A11.71,11.71,0,0,1,16,8.39a12,12,0,0,1,12,11.93,18.66,18.66,0,0,1-1.39,6.5.78.78,0,0,1-1,.41.76.76,0,0,1-.41-1,17.25,17.25,0,0,0,1.27-5.91A10.45,10.45,0,0,0,16,9.92a10.18,10.18,0,0,0-10.38,10,2.77,2.77,0,0,0,2.79,3.06,2.74,2.74,0,0,0,3-2.48c.36-3.11,1.89-4.69,4.56-4.69a4.31,4.31,0,0,1,4.52,4.56c0,4.74-3,8.72-8,10.63A.92.92,0,0,1,12.28,31Z"
  })), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.77,30.28a.81.81,0,0,1-.52-.2.76.76,0,0,1,0-1.08,12.63,12.63,0,0,0,3.54-8.68c0-1.56-.48-6.65-6.7-6.65a6.83,6.83,0,0,0-4.94,1.87A6.17,6.17,0,0,0,9.32,20a.77.77,0,0,1-.77.76h0A.76.76,0,0,1,7.78,20,7.73,7.73,0,0,1,10,14.46a8.34,8.34,0,0,1,6-2.32c6.08,0,8.24,4.4,8.24,8.18A14.09,14.09,0,0,1,20.34,30,.75.75,0,0,1,19.77,30.28Z"
  })), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.66,27.74a14.14,14.14,0,0,1-1.56-.09.76.76,0,1,1,.17-1.52c2.49.28,4.45-.16,5.84-1.32a6.37,6.37,0,0,0,2.12-4.53.75.75,0,0,1,.82-.71.78.78,0,0,1,.72.81A7.89,7.89,0,0,1,14.09,26,8.2,8.2,0,0,1,8.66,27.74Z"
  })), children);
});
var FingerprintRecognition24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FingerprintRecognition24(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,5.21a.77.77,0,0,1-.46-1.38A15.46,15.46,0,0,1,16,1c2.66,0,6.48.45,9.5,2.62a.77.77,0,0,1,.18,1.07.78.78,0,0,1-1.08.17A15,15,0,0,0,16,2.53,14,14,0,0,0,7.5,5.05.74.74,0,0,1,7,5.21Z"
  })), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.23,12.26a.78.78,0,0,1-.63-.33C25.87,9.49,22.78,6.24,16,6.24a14,14,0,0,0-11.63,5.7.77.77,0,0,1-1.07.17A.76.76,0,0,1,3.15,11,15.54,15.54,0,0,1,16,4.71c5.61,0,9.81,2.08,12.84,6.34a.77.77,0,0,1-.19,1.07A.79.79,0,0,1,28.23,12.26Z"
  })), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.28,31a.78.78,0,0,1-.72-.49.75.75,0,0,1,.44-1c4.37-1.68,7-5.12,7-9.21a2.8,2.8,0,0,0-3-3c-1.86,0-2.76,1-3,3.35a4.27,4.27,0,0,1-4.52,3.83,4.27,4.27,0,0,1-4.32-4.59A11.71,11.71,0,0,1,16,8.39a12,12,0,0,1,12,11.93,18.66,18.66,0,0,1-1.39,6.5.78.78,0,0,1-1,.41.76.76,0,0,1-.41-1,17.25,17.25,0,0,0,1.27-5.91A10.45,10.45,0,0,0,16,9.92a10.18,10.18,0,0,0-10.38,10,2.77,2.77,0,0,0,2.79,3.06,2.74,2.74,0,0,0,3-2.48c.36-3.11,1.89-4.69,4.56-4.69a4.31,4.31,0,0,1,4.52,4.56c0,4.74-3,8.72-8,10.63A.92.92,0,0,1,12.28,31Z"
  })), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.77,30.28a.81.81,0,0,1-.52-.2.76.76,0,0,1,0-1.08,12.63,12.63,0,0,0,3.54-8.68c0-1.56-.48-6.65-6.7-6.65a6.83,6.83,0,0,0-4.94,1.87A6.17,6.17,0,0,0,9.32,20a.77.77,0,0,1-.77.76h0A.76.76,0,0,1,7.78,20,7.73,7.73,0,0,1,10,14.46a8.34,8.34,0,0,1,6-2.32c6.08,0,8.24,4.4,8.24,8.18A14.09,14.09,0,0,1,20.34,30,.75.75,0,0,1,19.77,30.28Z"
  })), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.66,27.74a14.14,14.14,0,0,1-1.56-.09.76.76,0,1,1,.17-1.52c2.49.28,4.45-.16,5.84-1.32a6.37,6.37,0,0,0,2.12-4.53.75.75,0,0,1,.82-.71.78.78,0,0,1,.72.81A7.89,7.89,0,0,1,14.09,26,8.2,8.2,0,0,1,8.66,27.74Z"
  })), children);
});
var FingerprintRecognition20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FingerprintRecognition20(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,5.21a.77.77,0,0,1-.46-1.38A15.46,15.46,0,0,1,16,1c2.66,0,6.48.45,9.5,2.62a.77.77,0,0,1,.18,1.07.78.78,0,0,1-1.08.17A15,15,0,0,0,16,2.53,14,14,0,0,0,7.5,5.05.74.74,0,0,1,7,5.21Z"
  })), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.23,12.26a.78.78,0,0,1-.63-.33C25.87,9.49,22.78,6.24,16,6.24a14,14,0,0,0-11.63,5.7.77.77,0,0,1-1.07.17A.76.76,0,0,1,3.15,11,15.54,15.54,0,0,1,16,4.71c5.61,0,9.81,2.08,12.84,6.34a.77.77,0,0,1-.19,1.07A.79.79,0,0,1,28.23,12.26Z"
  })), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.28,31a.78.78,0,0,1-.72-.49.75.75,0,0,1,.44-1c4.37-1.68,7-5.12,7-9.21a2.8,2.8,0,0,0-3-3c-1.86,0-2.76,1-3,3.35a4.27,4.27,0,0,1-4.52,3.83,4.27,4.27,0,0,1-4.32-4.59A11.71,11.71,0,0,1,16,8.39a12,12,0,0,1,12,11.93,18.66,18.66,0,0,1-1.39,6.5.78.78,0,0,1-1,.41.76.76,0,0,1-.41-1,17.25,17.25,0,0,0,1.27-5.91A10.45,10.45,0,0,0,16,9.92a10.18,10.18,0,0,0-10.38,10,2.77,2.77,0,0,0,2.79,3.06,2.74,2.74,0,0,0,3-2.48c.36-3.11,1.89-4.69,4.56-4.69a4.31,4.31,0,0,1,4.52,4.56c0,4.74-3,8.72-8,10.63A.92.92,0,0,1,12.28,31Z"
  })), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.77,30.28a.81.81,0,0,1-.52-.2.76.76,0,0,1,0-1.08,12.63,12.63,0,0,0,3.54-8.68c0-1.56-.48-6.65-6.7-6.65a6.83,6.83,0,0,0-4.94,1.87A6.17,6.17,0,0,0,9.32,20a.77.77,0,0,1-.77.76h0A.76.76,0,0,1,7.78,20,7.73,7.73,0,0,1,10,14.46a8.34,8.34,0,0,1,6-2.32c6.08,0,8.24,4.4,8.24,8.18A14.09,14.09,0,0,1,20.34,30,.75.75,0,0,1,19.77,30.28Z"
  })), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.66,27.74a14.14,14.14,0,0,1-1.56-.09.76.76,0,1,1,.17-1.52c2.49.28,4.45-.16,5.84-1.32a6.37,6.37,0,0,0,2.12-4.53.75.75,0,0,1,.82-.71.78.78,0,0,1,.72.81A7.89,7.89,0,0,1,14.09,26,8.2,8.2,0,0,1,8.66,27.74Z"
  })), children);
});
var FingerprintRecognition16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FingerprintRecognition16(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,5.21a.77.77,0,0,1-.46-1.38A15.46,15.46,0,0,1,16,1c2.66,0,6.48.45,9.5,2.62a.77.77,0,0,1,.18,1.07.78.78,0,0,1-1.08.17A15,15,0,0,0,16,2.53,14,14,0,0,0,7.5,5.05.74.74,0,0,1,7,5.21Z"
  })), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.23,12.26a.78.78,0,0,1-.63-.33C25.87,9.49,22.78,6.24,16,6.24a14,14,0,0,0-11.63,5.7.77.77,0,0,1-1.07.17A.76.76,0,0,1,3.15,11,15.54,15.54,0,0,1,16,4.71c5.61,0,9.81,2.08,12.84,6.34a.77.77,0,0,1-.19,1.07A.79.79,0,0,1,28.23,12.26Z"
  })), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.28,31a.78.78,0,0,1-.72-.49.75.75,0,0,1,.44-1c4.37-1.68,7-5.12,7-9.21a2.8,2.8,0,0,0-3-3c-1.86,0-2.76,1-3,3.35a4.27,4.27,0,0,1-4.52,3.83,4.27,4.27,0,0,1-4.32-4.59A11.71,11.71,0,0,1,16,8.39a12,12,0,0,1,12,11.93,18.66,18.66,0,0,1-1.39,6.5.78.78,0,0,1-1,.41.76.76,0,0,1-.41-1,17.25,17.25,0,0,0,1.27-5.91A10.45,10.45,0,0,0,16,9.92a10.18,10.18,0,0,0-10.38,10,2.77,2.77,0,0,0,2.79,3.06,2.74,2.74,0,0,0,3-2.48c.36-3.11,1.89-4.69,4.56-4.69a4.31,4.31,0,0,1,4.52,4.56c0,4.74-3,8.72-8,10.63A.92.92,0,0,1,12.28,31Z"
  })), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.77,30.28a.81.81,0,0,1-.52-.2.76.76,0,0,1,0-1.08,12.63,12.63,0,0,0,3.54-8.68c0-1.56-.48-6.65-6.7-6.65a6.83,6.83,0,0,0-4.94,1.87A6.17,6.17,0,0,0,9.32,20a.77.77,0,0,1-.77.76h0A.76.76,0,0,1,7.78,20,7.73,7.73,0,0,1,10,14.46a8.34,8.34,0,0,1,6-2.32c6.08,0,8.24,4.4,8.24,8.18A14.09,14.09,0,0,1,20.34,30,.75.75,0,0,1,19.77,30.28Z"
  })), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.66,27.74a14.14,14.14,0,0,1-1.56-.09.76.76,0,1,1,.17-1.52c2.49.28,4.45-.16,5.84-1.32a6.37,6.37,0,0,0,2.12-4.53.75.75,0,0,1,.82-.71.78.78,0,0,1,.72.81A7.89,7.89,0,0,1,14.09,26,8.2,8.2,0,0,1,8.66,27.74Z"
  })), children);
});
var Fire32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Fire32(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.832,16.9688c-.2724-.6465-.5815-1.38-.8833-2.2852-.79-2.3682,1.7344-4.9522,1.7583-4.9766L24.293,8.293c-.1407.1406-3.4234,3.4775-2.2417,7.0234.3261.978.6513,1.749.938,2.43A9.3812,9.3812,0,0,1,24,22a6.24,6.24,0,0,1-4.1892,5.293,8.52,8.52,0,0,0-2.1038-8l-1.0444-1.0445-.5815,1.3575C14.2449,23.89,12.06,25.76,10.7747,26.54A5.8437,5.8437,0,0,1,8,22a9.6239,9.6239,0,0,1,.9287-3.6289A11.3329,11.3329,0,0,0,10,14V12.2217c.8735.36,2,1.3037,2,3.7783v2.6035l1.7432-1.9341c3.1118-3.4546,2.4624-7.5678,1.206-10.3081A4.4859,4.4859,0,0,1,18,11h2c0-5.5371-4.5786-7-7-7H11l1.1992,1.5986c.1377.1856,2.8628,3.9278,1.3535,7.688A4.9426,4.9426,0,0,0,9,10H8v4a9.6239,9.6239,0,0,1-.9287,3.6289A11.3329,11.3329,0,0,0,6,22c0,3.8477,3.8232,8,10,8s10-4.1523,10-8A11.3771,11.3771,0,0,0,24.832,16.9688ZM12.8352,27.5264a16.4987,16.4987,0,0,0,4.3665-5.5987,6.1053,6.1053,0,0,1,.2573,5.9717A11.3213,11.3213,0,0,1,16,28,10.3278,10.3278,0,0,1,12.8352,27.5264Z"
  })), children);
});
var Fire24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Fire24(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.832,16.9688c-.2724-.6465-.5815-1.38-.8833-2.2852-.79-2.3682,1.7344-4.9522,1.7583-4.9766L24.293,8.293c-.1407.1406-3.4234,3.4775-2.2417,7.0234.3261.978.6513,1.749.938,2.43A9.3812,9.3812,0,0,1,24,22a6.24,6.24,0,0,1-4.1892,5.293,8.52,8.52,0,0,0-2.1038-8l-1.0444-1.0445-.5815,1.3575C14.2449,23.89,12.06,25.76,10.7747,26.54A5.8437,5.8437,0,0,1,8,22a9.6239,9.6239,0,0,1,.9287-3.6289A11.3329,11.3329,0,0,0,10,14V12.2217c.8735.36,2,1.3037,2,3.7783v2.6035l1.7432-1.9341c3.1118-3.4546,2.4624-7.5678,1.206-10.3081A4.4859,4.4859,0,0,1,18,11h2c0-5.5371-4.5786-7-7-7H11l1.1992,1.5986c.1377.1856,2.8628,3.9278,1.3535,7.688A4.9426,4.9426,0,0,0,9,10H8v4a9.6239,9.6239,0,0,1-.9287,3.6289A11.3329,11.3329,0,0,0,6,22c0,3.8477,3.8232,8,10,8s10-4.1523,10-8A11.3771,11.3771,0,0,0,24.832,16.9688ZM12.8352,27.5264a16.4987,16.4987,0,0,0,4.3665-5.5987,6.1053,6.1053,0,0,1,.2573,5.9717A11.3213,11.3213,0,0,1,16,28,10.3278,10.3278,0,0,1,12.8352,27.5264Z"
  })), children);
});
var Fire20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Fire20(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.832,16.9688c-.2724-.6465-.5815-1.38-.8833-2.2852-.79-2.3682,1.7344-4.9522,1.7583-4.9766L24.293,8.293c-.1407.1406-3.4234,3.4775-2.2417,7.0234.3261.978.6513,1.749.938,2.43A9.3812,9.3812,0,0,1,24,22a6.24,6.24,0,0,1-4.1892,5.293,8.52,8.52,0,0,0-2.1038-8l-1.0444-1.0445-.5815,1.3575C14.2449,23.89,12.06,25.76,10.7747,26.54A5.8437,5.8437,0,0,1,8,22a9.6239,9.6239,0,0,1,.9287-3.6289A11.3329,11.3329,0,0,0,10,14V12.2217c.8735.36,2,1.3037,2,3.7783v2.6035l1.7432-1.9341c3.1118-3.4546,2.4624-7.5678,1.206-10.3081A4.4859,4.4859,0,0,1,18,11h2c0-5.5371-4.5786-7-7-7H11l1.1992,1.5986c.1377.1856,2.8628,3.9278,1.3535,7.688A4.9426,4.9426,0,0,0,9,10H8v4a9.6239,9.6239,0,0,1-.9287,3.6289A11.3329,11.3329,0,0,0,6,22c0,3.8477,3.8232,8,10,8s10-4.1523,10-8A11.3771,11.3771,0,0,0,24.832,16.9688ZM12.8352,27.5264a16.4987,16.4987,0,0,0,4.3665-5.5987,6.1053,6.1053,0,0,1,.2573,5.9717A11.3213,11.3213,0,0,1,16,28,10.3278,10.3278,0,0,1,12.8352,27.5264Z"
  })), children);
});
var Fire16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Fire16(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.832,16.9688c-.2724-.6465-.5815-1.38-.8833-2.2852-.79-2.3682,1.7344-4.9522,1.7583-4.9766L24.293,8.293c-.1407.1406-3.4234,3.4775-2.2417,7.0234.3261.978.6513,1.749.938,2.43A9.3812,9.3812,0,0,1,24,22a6.24,6.24,0,0,1-4.1892,5.293,8.52,8.52,0,0,0-2.1038-8l-1.0444-1.0445-.5815,1.3575C14.2449,23.89,12.06,25.76,10.7747,26.54A5.8437,5.8437,0,0,1,8,22a9.6239,9.6239,0,0,1,.9287-3.6289A11.3329,11.3329,0,0,0,10,14V12.2217c.8735.36,2,1.3037,2,3.7783v2.6035l1.7432-1.9341c3.1118-3.4546,2.4624-7.5678,1.206-10.3081A4.4859,4.4859,0,0,1,18,11h2c0-5.5371-4.5786-7-7-7H11l1.1992,1.5986c.1377.1856,2.8628,3.9278,1.3535,7.688A4.9426,4.9426,0,0,0,9,10H8v4a9.6239,9.6239,0,0,1-.9287,3.6289A11.3329,11.3329,0,0,0,6,22c0,3.8477,3.8232,8,10,8s10-4.1523,10-8A11.3771,11.3771,0,0,0,24.832,16.9688ZM12.8352,27.5264a16.4987,16.4987,0,0,0,4.3665-5.5987,6.1053,6.1053,0,0,1,.2573,5.9717A11.3213,11.3213,0,0,1,16,28,10.3278,10.3278,0,0,1,12.8352,27.5264Z"
  })), children);
});
var Firewall32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Firewall32(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 20.3972v3c-1 0-2-1.5-2-4v-3c-4 5-5 7-5 9A5.0008 5.0008 0 0023.0458 30 7.5281 7.5281 0 0125 26.3972 7.5281 7.5281 0 0126.9542 30 5.0008 5.0008 0 0030 25.3972C30 23.3972 28.875 21.8258 27 20.3972zM17 28H4V24H17V22H4a2.0023 2.0023 0 00-2 2v4a2.0023 2.0023 0 002 2H17z"
  })), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 12H7a2.0023 2.0023 0 00-2 2v4a2.0023 2.0023 0 002 2H17V18H7V14H28l.0011 2H30V14A2.0023 2.0023 0 0028 12zM25 10H4A2.0021 2.0021 0 012 8V4A2.0021 2.0021 0 014 2H25a2.0021 2.0021 0 012 2V8A2.0021 2.0021 0 0125 10zM4 4V8H25V4z"
  })), children);
});
var Firewall24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Firewall24(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 20.3972v3c-1 0-2-1.5-2-4v-3c-4 5-5 7-5 9A5.0008 5.0008 0 0023.0458 30 7.5281 7.5281 0 0125 26.3972 7.5281 7.5281 0 0126.9542 30 5.0008 5.0008 0 0030 25.3972C30 23.3972 28.875 21.8258 27 20.3972zM17 28H4V24H17V22H4a2.0023 2.0023 0 00-2 2v4a2.0023 2.0023 0 002 2H17z"
  })), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 12H7a2.0023 2.0023 0 00-2 2v4a2.0023 2.0023 0 002 2H17V18H7V14H28l.0011 2H30V14A2.0023 2.0023 0 0028 12zM25 10H4A2.0021 2.0021 0 012 8V4A2.0021 2.0021 0 014 2H25a2.0021 2.0021 0 012 2V8A2.0021 2.0021 0 0125 10zM4 4V8H25V4z"
  })), children);
});
var Firewall20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Firewall20(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 20.3972v3c-1 0-2-1.5-2-4v-3c-4 5-5 7-5 9A5.0008 5.0008 0 0023.0458 30 7.5281 7.5281 0 0125 26.3972 7.5281 7.5281 0 0126.9542 30 5.0008 5.0008 0 0030 25.3972C30 23.3972 28.875 21.8258 27 20.3972zM17 28H4V24H17V22H4a2.0023 2.0023 0 00-2 2v4a2.0023 2.0023 0 002 2H17z"
  })), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 12H7a2.0023 2.0023 0 00-2 2v4a2.0023 2.0023 0 002 2H17V18H7V14H28l.0011 2H30V14A2.0023 2.0023 0 0028 12zM25 10H4A2.0021 2.0021 0 012 8V4A2.0021 2.0021 0 014 2H25a2.0021 2.0021 0 012 2V8A2.0021 2.0021 0 0125 10zM4 4V8H25V4z"
  })), children);
});
var Firewall16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Firewall16(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 20.3972v3c-1 0-2-1.5-2-4v-3c-4 5-5 7-5 9A5.0008 5.0008 0 0023.0458 30 7.5281 7.5281 0 0125 26.3972 7.5281 7.5281 0 0126.9542 30 5.0008 5.0008 0 0030 25.3972C30 23.3972 28.875 21.8258 27 20.3972zM17 28H4V24H17V22H4a2.0023 2.0023 0 00-2 2v4a2.0023 2.0023 0 002 2H17z"
  })), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 12H7a2.0023 2.0023 0 00-2 2v4a2.0023 2.0023 0 002 2H17V18H7V14H28l.0011 2H30V14A2.0023 2.0023 0 0028 12zM25 10H4A2.0021 2.0021 0 012 8V4A2.0021 2.0021 0 014 2H25a2.0021 2.0021 0 012 2V8A2.0021 2.0021 0 0125 10zM4 4V8H25V4z"
  })), children);
});
var FirewallClassic32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FirewallClassic32(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 20V17a4 4 0 00-8 0v3a2.0023 2.0023 0 00-2 2v6a2.0023 2.0023 0 002 2h8a2.0023 2.0023 0 002-2V22A2.0023 2.0023 0 0028 20zm-6-3a2 2 0 014 0v3H22zm6 11H20V22h8zM15 27H4a2 2 0 01-2-2V22a2 2 0 012-2H15v2H4v3H15zM17 18H8a2 2 0 01-2-2V13a2 2 0 012-2H19v2H8v3h9zM22 9H4A2 2 0 012 7V4A2 2 0 014 2H22a2 2 0 012 2V7A2 2 0 0122 9zM4 7H22V4H4z"
  })), children);
});
var FirewallClassic24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FirewallClassic24(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 20V17a4 4 0 00-8 0v3a2.0023 2.0023 0 00-2 2v6a2.0023 2.0023 0 002 2h8a2.0023 2.0023 0 002-2V22A2.0023 2.0023 0 0028 20zm-6-3a2 2 0 014 0v3H22zm6 11H20V22h8zM15 27H4a2 2 0 01-2-2V22a2 2 0 012-2H15v2H4v3H15zM17 18H8a2 2 0 01-2-2V13a2 2 0 012-2H19v2H8v3h9zM22 9H4A2 2 0 012 7V4A2 2 0 014 2H22a2 2 0 012 2V7A2 2 0 0122 9zM4 7H22V4H4z"
  })), children);
});
var FirewallClassic20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FirewallClassic20(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 20V17a4 4 0 00-8 0v3a2.0023 2.0023 0 00-2 2v6a2.0023 2.0023 0 002 2h8a2.0023 2.0023 0 002-2V22A2.0023 2.0023 0 0028 20zm-6-3a2 2 0 014 0v3H22zm6 11H20V22h8zM15 27H4a2 2 0 01-2-2V22a2 2 0 012-2H15v2H4v3H15zM17 18H8a2 2 0 01-2-2V13a2 2 0 012-2H19v2H8v3h9zM22 9H4A2 2 0 012 7V4A2 2 0 014 2H22a2 2 0 012 2V7A2 2 0 0122 9zM4 7H22V4H4z"
  })), children);
});
var FirewallClassic16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FirewallClassic16(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 20V17a4 4 0 00-8 0v3a2.0023 2.0023 0 00-2 2v6a2.0023 2.0023 0 002 2h8a2.0023 2.0023 0 002-2V22A2.0023 2.0023 0 0028 20zm-6-3a2 2 0 014 0v3H22zm6 11H20V22h8zM15 27H4a2 2 0 01-2-2V22a2 2 0 012-2H15v2H4v3H15zM17 18H8a2 2 0 01-2-2V13a2 2 0 012-2H19v2H8v3h9zM22 9H4A2 2 0 012 7V4A2 2 0 014 2H22a2 2 0 012 2V7A2 2 0 0122 9zM4 7H22V4H4z"
  })), children);
});
var Fish32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Fish32(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "7",
    r: "1"
  })), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2A16.0183,16.0183,0,0,0,10,18v2H3a1,1,0,0,0-.707,1.707l8,8A1,1,0,0,0,12,29V22h2A16.0183,16.0183,0,0,0,30,6V2ZM10,26.5857,5.4141,22H10ZM12,20V18a13.9394,13.9394,0,0,1,3.908-9.6777l7.77,7.7695A13.94,13.94,0,0,1,14,20ZM28,6a13.9163,13.9163,0,0,1-2.98,8.6055L17.3945,6.98A13.9163,13.9163,0,0,1,26,4h2Z"
  })), children);
});
var Fish24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Fish24(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "7",
    r: "1"
  })), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2A16.0183,16.0183,0,0,0,10,18v2H3a1,1,0,0,0-.707,1.707l8,8A1,1,0,0,0,12,29V22h2A16.0183,16.0183,0,0,0,30,6V2ZM10,26.5857,5.4141,22H10ZM12,20V18a13.9394,13.9394,0,0,1,3.908-9.6777l7.77,7.7695A13.94,13.94,0,0,1,14,20ZM28,6a13.9163,13.9163,0,0,1-2.98,8.6055L17.3945,6.98A13.9163,13.9163,0,0,1,26,4h2Z"
  })), children);
});
var Fish20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Fish20(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "7",
    r: "1"
  })), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2A16.0183,16.0183,0,0,0,10,18v2H3a1,1,0,0,0-.707,1.707l8,8A1,1,0,0,0,12,29V22h2A16.0183,16.0183,0,0,0,30,6V2ZM10,26.5857,5.4141,22H10ZM12,20V18a13.9394,13.9394,0,0,1,3.908-9.6777l7.77,7.7695A13.94,13.94,0,0,1,14,20ZM28,6a13.9163,13.9163,0,0,1-2.98,8.6055L17.3945,6.98A13.9163,13.9163,0,0,1,26,4h2Z"
  })), children);
});
var Fish16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Fish16(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "7",
    r: "1"
  })), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2A16.0183,16.0183,0,0,0,10,18v2H3a1,1,0,0,0-.707,1.707l8,8A1,1,0,0,0,12,29V22h2A16.0183,16.0183,0,0,0,30,6V2ZM10,26.5857,5.4141,22H10ZM12,20V18a13.9394,13.9394,0,0,1,3.908-9.6777l7.77,7.7695A13.94,13.94,0,0,1,14,20ZM28,6a13.9163,13.9163,0,0,1-2.98,8.6055L17.3945,6.98A13.9163,13.9163,0,0,1,26,4h2Z"
  })), children);
});
var FishMultiple32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FishMultiple32(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,14a12.9845,12.9845,0,0,0-3.8286-9.2427L24.4143,3,23,4.4138l1.7573,1.7574a11.0713,11.0713,0,0,1,0,15.6572L22,24.5857,23.4143,26l2.7571-2.7573A12.9845,12.9845,0,0,0,30,14Z"
  })), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17",
    cy: "11",
    r: "1"
  })), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14a12.9845,12.9845,0,0,0-3.8286-9.2427L16.4143,3,15,4.4138l1.7573,1.7574a11.0713,11.0713,0,0,1,0,15.6572L14,24.5857,15.4143,26l2.7571-2.7573A12.9845,12.9845,0,0,0,22,14Z"
  })), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "11",
    r: "1"
  })), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "11",
    r: "1"
  })), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.4141,24l.7573-.7573a13.0708,13.0708,0,0,0,0-18.4854L8,2.5857,5.8286,4.7571a13.0708,13.0708,0,0,0,0,18.4854L6.5859,24,2.293,28.2928A1,1,0,0,0,3,30H13a1,1,0,0,0,.707-1.707ZM4,14A10.9988,10.9988,0,0,1,7.2427,6.1712L8,5.4138l.7573.7574a11.0713,11.0713,0,0,1,0,15.6572L8,22.5857l-.7573-.7573A10.9988,10.9988,0,0,1,4,14ZM5.4141,28,8,25.4138,10.5859,28Z"
  })), children);
});
var FishMultiple24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FishMultiple24(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,14a12.9845,12.9845,0,0,0-3.8286-9.2427L24.4143,3,23,4.4138l1.7573,1.7574a11.0713,11.0713,0,0,1,0,15.6572L22,24.5857,23.4143,26l2.7571-2.7573A12.9845,12.9845,0,0,0,30,14Z"
  })), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17",
    cy: "11",
    r: "1"
  })), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14a12.9845,12.9845,0,0,0-3.8286-9.2427L16.4143,3,15,4.4138l1.7573,1.7574a11.0713,11.0713,0,0,1,0,15.6572L14,24.5857,15.4143,26l2.7571-2.7573A12.9845,12.9845,0,0,0,22,14Z"
  })), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "11",
    r: "1"
  })), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "11",
    r: "1"
  })), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.4141,24l.7573-.7573a13.0708,13.0708,0,0,0,0-18.4854L8,2.5857,5.8286,4.7571a13.0708,13.0708,0,0,0,0,18.4854L6.5859,24,2.293,28.2928A1,1,0,0,0,3,30H13a1,1,0,0,0,.707-1.707ZM4,14A10.9988,10.9988,0,0,1,7.2427,6.1712L8,5.4138l.7573.7574a11.0713,11.0713,0,0,1,0,15.6572L8,22.5857l-.7573-.7573A10.9988,10.9988,0,0,1,4,14ZM5.4141,28,8,25.4138,10.5859,28Z"
  })), children);
});
var FishMultiple20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FishMultiple20(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,14a12.9845,12.9845,0,0,0-3.8286-9.2427L24.4143,3,23,4.4138l1.7573,1.7574a11.0713,11.0713,0,0,1,0,15.6572L22,24.5857,23.4143,26l2.7571-2.7573A12.9845,12.9845,0,0,0,30,14Z"
  })), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17",
    cy: "11",
    r: "1"
  })), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14a12.9845,12.9845,0,0,0-3.8286-9.2427L16.4143,3,15,4.4138l1.7573,1.7574a11.0713,11.0713,0,0,1,0,15.6572L14,24.5857,15.4143,26l2.7571-2.7573A12.9845,12.9845,0,0,0,22,14Z"
  })), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "11",
    r: "1"
  })), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "11",
    r: "1"
  })), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.4141,24l.7573-.7573a13.0708,13.0708,0,0,0,0-18.4854L8,2.5857,5.8286,4.7571a13.0708,13.0708,0,0,0,0,18.4854L6.5859,24,2.293,28.2928A1,1,0,0,0,3,30H13a1,1,0,0,0,.707-1.707ZM4,14A10.9988,10.9988,0,0,1,7.2427,6.1712L8,5.4138l.7573.7574a11.0713,11.0713,0,0,1,0,15.6572L8,22.5857l-.7573-.7573A10.9988,10.9988,0,0,1,4,14ZM5.4141,28,8,25.4138,10.5859,28Z"
  })), children);
});
var FishMultiple16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FishMultiple16(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,14a12.9845,12.9845,0,0,0-3.8286-9.2427L24.4143,3,23,4.4138l1.7573,1.7574a11.0713,11.0713,0,0,1,0,15.6572L22,24.5857,23.4143,26l2.7571-2.7573A12.9845,12.9845,0,0,0,30,14Z"
  })), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17",
    cy: "11",
    r: "1"
  })), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14a12.9845,12.9845,0,0,0-3.8286-9.2427L16.4143,3,15,4.4138l1.7573,1.7574a11.0713,11.0713,0,0,1,0,15.6572L14,24.5857,15.4143,26l2.7571-2.7573A12.9845,12.9845,0,0,0,22,14Z"
  })), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "11",
    r: "1"
  })), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "11",
    r: "1"
  })), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.4141,24l.7573-.7573a13.0708,13.0708,0,0,0,0-18.4854L8,2.5857,5.8286,4.7571a13.0708,13.0708,0,0,0,0,18.4854L6.5859,24,2.293,28.2928A1,1,0,0,0,3,30H13a1,1,0,0,0,.707-1.707ZM4,14A10.9988,10.9988,0,0,1,7.2427,6.1712L8,5.4138l.7573.7574a11.0713,11.0713,0,0,1,0,15.6572L8,22.5857l-.7573-.7573A10.9988,10.9988,0,0,1,4,14ZM5.4141,28,8,25.4138,10.5859,28Z"
  })), children);
});
var FitToHeight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FitToHeight32(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 10L12.41 11.41 15 8.83 15 23.17 12.41 20.59 11 22 16 27 21 22 19.59 20.59 17 23.17 17 8.83 19.59 11.41 21 10 16 5 11 10z"
  })), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var FitToHeight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FitToHeight24(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 10L12.41 11.41 15 8.83 15 23.17 12.41 20.59 11 22 16 27 21 22 19.59 20.59 17 23.17 17 8.83 19.59 11.41 21 10 16 5 11 10z"
  })), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var FitToHeight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FitToHeight20(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 10L12.41 11.41 15 8.83 15 23.17 12.41 20.59 11 22 16 27 21 22 19.59 20.59 17 23.17 17 8.83 19.59 11.41 21 10 16 5 11 10z"
  })), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var FitToHeight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FitToHeight16(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 10L12.41 11.41 15 8.83 15 23.17 12.41 20.59 11 22 16 27 21 22 19.59 20.59 17 23.17 17 8.83 19.59 11.41 21 10 16 5 11 10z"
  })), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var FitToScreen32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FitToScreen32(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 16L24 16 24 8 16 8 16 10 22 10 22 16zM8 24L16 24 16 22 10 22 10 16 8 16 8 24z"
  })), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,6,4H26a2.0023,2.0023,0,0,1,2,2V26A2.0023,2.0023,0,0,1,26,28ZM6,6V26H26.0012L26,6Z"
  })), children);
});
var FitToScreen24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FitToScreen24(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 16L24 16 24 8 16 8 16 10 22 10 22 16zM8 24L16 24 16 22 10 22 10 16 8 16 8 24z"
  })), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,6,4H26a2.0023,2.0023,0,0,1,2,2V26A2.0023,2.0023,0,0,1,26,28ZM6,6V26H26.0012L26,6Z"
  })), children);
});
var FitToScreen20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FitToScreen20(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 16L24 16 24 8 16 8 16 10 22 10 22 16zM8 24L16 24 16 22 10 22 10 16 8 16 8 24z"
  })), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,6,4H26a2.0023,2.0023,0,0,1,2,2V26A2.0023,2.0023,0,0,1,26,28ZM6,6V26H26.0012L26,6Z"
  })), children);
});
var FitToScreen16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FitToScreen16(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 16L24 16 24 8 16 8 16 10 22 10 22 16zM8 24L16 24 16 22 10 22 10 16 8 16 8 24z"
  })), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,6,4H26a2.0023,2.0023,0,0,1,2,2V26A2.0023,2.0023,0,0,1,26,28ZM6,6V26H26.0012L26,6Z"
  })), children);
});
var FitToWidth32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FitToWidth32(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 11L20.59 12.41 23.17 15 8.83 15 11.41 12.41 10 11 5 16 10 21 11.41 19.59 8.83 17 23.17 17 20.59 19.59 22 21 27 16 22 11z"
  })), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var FitToWidth24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FitToWidth24(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 11L20.59 12.41 23.17 15 8.83 15 11.41 12.41 10 11 5 16 10 21 11.41 19.59 8.83 17 23.17 17 20.59 19.59 22 21 27 16 22 11z"
  })), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var FitToWidth20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FitToWidth20(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 11L20.59 12.41 23.17 15 8.83 15 11.41 12.41 10 11 5 16 10 21 11.41 19.59 8.83 17 23.17 17 20.59 19.59 22 21 27 16 22 11z"
  })), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var FitToWidth16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FitToWidth16(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 11L20.59 12.41 23.17 15 8.83 15 11.41 12.41 10 11 5 16 10 21 11.41 19.59 8.83 17 23.17 17 20.59 19.59 22 21 27 16 22 11z"
  })), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var Flag32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Flag32(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H4V2H28l-5.8,9L28,20H6ZM6,18H24.33L19.8,11l4.53-7H6Z"
  })), children);
});
var Flag24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Flag24(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H4V2H28l-5.8,9L28,20H6ZM6,18H24.33L19.8,11l4.53-7H6Z"
  })), children);
});
var Flag20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Flag20(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H4V2H28l-5.8,9L28,20H6ZM6,18H24.33L19.8,11l4.53-7H6Z"
  })), children);
});
var Flag16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Flag16(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H4V2H28l-5.8,9L28,20H6ZM6,18H24.33L19.8,11l4.53-7H6Z"
  })), children);
});
var FlagFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlagFilled32(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H4V2H28l-5.8,9L28,20H6Z"
  })), children);
});
var FlagFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlagFilled24(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H4V2H28l-5.8,9L28,20H6Z"
  })), children);
});
var FlagFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlagFilled20(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H4V2H28l-5.8,9L28,20H6Z"
  })), children);
});
var FlagFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlagFilled16(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H4V2H28l-5.8,9L28,20H6Z"
  })), children);
});
var FlaggingTaxi32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlaggingTaxi32(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.7976,2,20.3555,8.6641A2.9941,2.9941,0,0,1,17.8594,10H12a3.0033,3.0033,0,0,0-3,3v6a2.0023,2.0023,0,0,0,2,2v7a2.0023,2.0023,0,0,0,2,2h4a2.0023,2.0023,0,0,0,2-2V16H17V28H13V19H11V13a1.0009,1.0009,0,0,1,1-1h5.8594a4.9881,4.9881,0,0,0,4.16-2.2266l4.4422-6.664Z"
  })), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,5a4,4,0,1,1,4,4A4.0042,4.0042,0,0,1,11,5Zm2,0a2,2,0,1,0,2-2A2.0023,2.0023,0,0,0,13,5Z"
  })), children);
});
var FlaggingTaxi24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlaggingTaxi24(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.7976,2,20.3555,8.6641A2.9941,2.9941,0,0,1,17.8594,10H12a3.0033,3.0033,0,0,0-3,3v6a2.0023,2.0023,0,0,0,2,2v7a2.0023,2.0023,0,0,0,2,2h4a2.0023,2.0023,0,0,0,2-2V16H17V28H13V19H11V13a1.0009,1.0009,0,0,1,1-1h5.8594a4.9881,4.9881,0,0,0,4.16-2.2266l4.4422-6.664Z"
  })), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,5a4,4,0,1,1,4,4A4.0042,4.0042,0,0,1,11,5Zm2,0a2,2,0,1,0,2-2A2.0023,2.0023,0,0,0,13,5Z"
  })), children);
});
var FlaggingTaxi20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlaggingTaxi20(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.7976,2,20.3555,8.6641A2.9941,2.9941,0,0,1,17.8594,10H12a3.0033,3.0033,0,0,0-3,3v6a2.0023,2.0023,0,0,0,2,2v7a2.0023,2.0023,0,0,0,2,2h4a2.0023,2.0023,0,0,0,2-2V16H17V28H13V19H11V13a1.0009,1.0009,0,0,1,1-1h5.8594a4.9881,4.9881,0,0,0,4.16-2.2266l4.4422-6.664Z"
  })), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,5a4,4,0,1,1,4,4A4.0042,4.0042,0,0,1,11,5Zm2,0a2,2,0,1,0,2-2A2.0023,2.0023,0,0,0,13,5Z"
  })), children);
});
var FlaggingTaxi16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlaggingTaxi16(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.7976,2,20.3555,8.6641A2.9941,2.9941,0,0,1,17.8594,10H12a3.0033,3.0033,0,0,0-3,3v6a2.0023,2.0023,0,0,0,2,2v7a2.0023,2.0023,0,0,0,2,2h4a2.0023,2.0023,0,0,0,2-2V16H17V28H13V19H11V13a1.0009,1.0009,0,0,1,1-1h5.8594a4.9881,4.9881,0,0,0,4.16-2.2266l4.4422-6.664Z"
  })), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,5a4,4,0,1,1,4,4A4.0042,4.0042,0,0,1,11,5Zm2,0a2,2,0,1,0,2-2A2.0023,2.0023,0,0,0,13,5Z"
  })), children);
});
var Flash32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Flash32(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.61,29.92a1,1,0,0,1-.6-1.07L12.83,17H8a1,1,0,0,1-1-1.23l3-13A1,1,0,0,1,11,2H21a1,1,0,0,1,.78.37,1,1,0,0,1,.2.85L20.25,11H25a1,1,0,0,1,.9.56,1,1,0,0,1-.11,1l-13,17A1,1,0,0,1,12,30,1.09,1.09,0,0,1,11.61,29.92ZM17.75,13l2-9H11.8L9.26,15h5.91L13.58,25.28,23,13Z"
  })), children);
});
var Flash24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Flash24(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.61,29.92a1,1,0,0,1-.6-1.07L12.83,17H8a1,1,0,0,1-1-1.23l3-13A1,1,0,0,1,11,2H21a1,1,0,0,1,.78.37,1,1,0,0,1,.2.85L20.25,11H25a1,1,0,0,1,.9.56,1,1,0,0,1-.11,1l-13,17A1,1,0,0,1,12,30,1.09,1.09,0,0,1,11.61,29.92ZM17.75,13l2-9H11.8L9.26,15h5.91L13.58,25.28,23,13Z"
  })), children);
});
var Flash20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Flash20(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.61,29.92a1,1,0,0,1-.6-1.07L12.83,17H8a1,1,0,0,1-1-1.23l3-13A1,1,0,0,1,11,2H21a1,1,0,0,1,.78.37,1,1,0,0,1,.2.85L20.25,11H25a1,1,0,0,1,.9.56,1,1,0,0,1-.11,1l-13,17A1,1,0,0,1,12,30,1.09,1.09,0,0,1,11.61,29.92ZM17.75,13l2-9H11.8L9.26,15h5.91L13.58,25.28,23,13Z"
  })), children);
});
var Flash16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Flash16(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.61,29.92a1,1,0,0,1-.6-1.07L12.83,17H8a1,1,0,0,1-1-1.23l3-13A1,1,0,0,1,11,2H21a1,1,0,0,1,.78.37,1,1,0,0,1,.2.85L20.25,11H25a1,1,0,0,1,.9.56,1,1,0,0,1-.11,1l-13,17A1,1,0,0,1,12,30,1.09,1.09,0,0,1,11.61,29.92ZM17.75,13l2-9H11.8L9.26,15h5.91L13.58,25.28,23,13Z"
  })), children);
});
var FlashFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlashFilled32(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.61,29.92a1,1,0,0,1-.6-1.07L12.83,17H8a1,1,0,0,1-1-1.23l3-13A1,1,0,0,1,11,2H21a1,1,0,0,1,.78.37,1,1,0,0,1,.2.85L20.25,11H25a1,1,0,0,1,.9.56,1,1,0,0,1-.11,1l-13,17A1,1,0,0,1,12,30,1.09,1.09,0,0,1,11.61,29.92Z"
  })), children);
});
var FlashFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlashFilled24(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.61,29.92a1,1,0,0,1-.6-1.07L12.83,17H8a1,1,0,0,1-1-1.23l3-13A1,1,0,0,1,11,2H21a1,1,0,0,1,.78.37,1,1,0,0,1,.2.85L20.25,11H25a1,1,0,0,1,.9.56,1,1,0,0,1-.11,1l-13,17A1,1,0,0,1,12,30,1.09,1.09,0,0,1,11.61,29.92Z"
  })), children);
});
var FlashFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlashFilled20(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.61,29.92a1,1,0,0,1-.6-1.07L12.83,17H8a1,1,0,0,1-1-1.23l3-13A1,1,0,0,1,11,2H21a1,1,0,0,1,.78.37,1,1,0,0,1,.2.85L20.25,11H25a1,1,0,0,1,.9.56,1,1,0,0,1-.11,1l-13,17A1,1,0,0,1,12,30,1.09,1.09,0,0,1,11.61,29.92Z"
  })), children);
});
var FlashFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlashFilled16(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.61,29.92a1,1,0,0,1-.6-1.07L12.83,17H8a1,1,0,0,1-1-1.23l3-13A1,1,0,0,1,11,2H21a1,1,0,0,1,.78.37,1,1,0,0,1,.2.85L20.25,11H25a1,1,0,0,1,.9.56,1,1,0,0,1-.11,1l-13,17A1,1,0,0,1,12,30,1.09,1.09,0,0,1,11.61,29.92Z"
  })), children);
});
var FlashOff32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlashOff32(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.13 6.89L11.8 4h8l-2 9H23l-2.49 3.25 1.43 1.43 3.87-5.07a1 1 0 00.11-1A1 1 0 0025 11H20.25L22 3.22a1 1 0 00-.2-.85A1 1 0 0021 2H11a1 1 0 00-1 .77L9.46 5.22zM30 28.59l-9.31-9.31h0l-1.42-1.43h0L10.6 9.19h0L8.93 7.52h0L3.41 2 2 3.41 8.4 9.82 7 15.77A1 1 0 008 17h4.83L11 28.85a1 1 0 00.6 1.07A1.09 1.09 0 0012 30a1 1 0 00.79-.39l6.68-8.73L28.59 30zM9.26 15l.81-3.52L13.59 15zm4.32 10.28L15 16.37 18 19.45z"
  })), children);
});
var FlashOff24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlashOff24(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.13 6.89L11.8 4h8l-2 9H23l-2.49 3.25 1.43 1.43 3.87-5.07a1 1 0 00.11-1A1 1 0 0025 11H20.25L22 3.22a1 1 0 00-.2-.85A1 1 0 0021 2H11a1 1 0 00-1 .77L9.46 5.22zM30 28.59l-9.31-9.31h0l-1.42-1.43h0L10.6 9.19h0L8.93 7.52h0L3.41 2 2 3.41 8.4 9.82 7 15.77A1 1 0 008 17h4.83L11 28.85a1 1 0 00.6 1.07A1.09 1.09 0 0012 30a1 1 0 00.79-.39l6.68-8.73L28.59 30zM9.26 15l.81-3.52L13.59 15zm4.32 10.28L15 16.37 18 19.45z"
  })), children);
});
var FlashOff20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlashOff20(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.13 6.89L11.8 4h8l-2 9H23l-2.49 3.25 1.43 1.43 3.87-5.07a1 1 0 00.11-1A1 1 0 0025 11H20.25L22 3.22a1 1 0 00-.2-.85A1 1 0 0021 2H11a1 1 0 00-1 .77L9.46 5.22zM30 28.59l-9.31-9.31h0l-1.42-1.43h0L10.6 9.19h0L8.93 7.52h0L3.41 2 2 3.41 8.4 9.82 7 15.77A1 1 0 008 17h4.83L11 28.85a1 1 0 00.6 1.07A1.09 1.09 0 0012 30a1 1 0 00.79-.39l6.68-8.73L28.59 30zM9.26 15l.81-3.52L13.59 15zm4.32 10.28L15 16.37 18 19.45z"
  })), children);
});
var FlashOff16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlashOff16(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.13 6.89L11.8 4h8l-2 9H23l-2.49 3.25 1.43 1.43 3.87-5.07a1 1 0 00.11-1A1 1 0 0025 11H20.25L22 3.22a1 1 0 00-.2-.85A1 1 0 0021 2H11a1 1 0 00-1 .77L9.46 5.22zM30 28.59l-9.31-9.31h0l-1.42-1.43h0L10.6 9.19h0L8.93 7.52h0L3.41 2 2 3.41 8.4 9.82 7 15.77A1 1 0 008 17h4.83L11 28.85a1 1 0 00.6 1.07A1.09 1.09 0 0012 30a1 1 0 00.79-.39l6.68-8.73L28.59 30zM9.26 15l.81-3.52L13.59 15zm4.32 10.28L15 16.37 18 19.45z"
  })), children);
});
var FlashOffFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlashOffFilled32(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 28.59L3.41 2 2 3.41 8.4 9.82 7 15.77A1 1 0 008 17h4.83L11 28.85a1 1 0 00.6 1.07A1.09 1.09 0 0012 30a1 1 0 00.79-.39l6.68-8.73L28.59 30zM22.53 16.87l3.26-4.26a1 1 0 00.11-1A1 1 0 0025 11H20.25L22 3.22a1 1 0 00-.2-.85A1 1 0 0021 2H11a1 1 0 00-1 .77l-.3 1.3z"
  })), children);
});
var FlashOffFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlashOffFilled24(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 28.59L3.41 2 2 3.41 8.4 9.82 7 15.77A1 1 0 008 17h4.83L11 28.85a1 1 0 00.6 1.07A1.09 1.09 0 0012 30a1 1 0 00.79-.39l6.68-8.73L28.59 30zM22.53 16.87l3.26-4.26a1 1 0 00.11-1A1 1 0 0025 11H20.25L22 3.22a1 1 0 00-.2-.85A1 1 0 0021 2H11a1 1 0 00-1 .77l-.3 1.3z"
  })), children);
});
var FlashOffFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlashOffFilled20(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 28.59L3.41 2 2 3.41 8.4 9.82 7 15.77A1 1 0 008 17h4.83L11 28.85a1 1 0 00.6 1.07A1.09 1.09 0 0012 30a1 1 0 00.79-.39l6.68-8.73L28.59 30zM22.53 16.87l3.26-4.26a1 1 0 00.11-1A1 1 0 0025 11H20.25L22 3.22a1 1 0 00-.2-.85A1 1 0 0021 2H11a1 1 0 00-1 .77l-.3 1.3z"
  })), children);
});
var FlashOffFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlashOffFilled16(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 28.59L3.41 2 2 3.41 8.4 9.82 7 15.77A1 1 0 008 17h4.83L11 28.85a1 1 0 00.6 1.07A1.09 1.09 0 0012 30a1 1 0 00.79-.39l6.68-8.73L28.59 30zM22.53 16.87l3.26-4.26a1 1 0 00.11-1A1 1 0 0025 11H20.25L22 3.22a1 1 0 00-.2-.85A1 1 0 0021 2H11a1 1 0 00-1 .77l-.3 1.3z"
  })), children);
});
var FlightInternational32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlightInternational32(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28a5.3257,5.3257,0,0,1-.6714-.044A21.7855,21.7855,0,0,1,12.0332,17H29.95c.0236-.3315.05-.6626.05-1A14,14,0,1,0,16,30ZM27.9492,15H21.9631A24.3247,24.3247,0,0,0,19.21,4.4492,12.0123,12.0123,0,0,1,27.9492,15ZM16.6714,4.0439A21.7855,21.7855,0,0,1,19.9668,15H12.0332A21.7855,21.7855,0,0,1,15.3286,4.0439,5.159,5.159,0,0,1,16.6714,4.0439ZM12.79,4.4492A24.3275,24.3275,0,0,0,10.0369,15H4.0508A12.0126,12.0126,0,0,1,12.79,4.4492ZM4.0508,17h5.9861A24.3275,24.3275,0,0,0,12.79,27.5508,12.0126,12.0126,0,0,1,4.0508,17Z"
  })), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M25,25l5,2V25l-5-2.5V20a1,1,0,0,0-2,0v2.5L18,25v2l5-2v3.5L21,30v1l3-1,3,1V30l-2-1.5Z"
  })), children);
});
var FlightInternational24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlightInternational24(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28a5.3257,5.3257,0,0,1-.6714-.044A21.7855,21.7855,0,0,1,12.0332,17H29.95c.0236-.3315.05-.6626.05-1A14,14,0,1,0,16,30ZM27.9492,15H21.9631A24.3247,24.3247,0,0,0,19.21,4.4492,12.0123,12.0123,0,0,1,27.9492,15ZM16.6714,4.0439A21.7855,21.7855,0,0,1,19.9668,15H12.0332A21.7855,21.7855,0,0,1,15.3286,4.0439,5.159,5.159,0,0,1,16.6714,4.0439ZM12.79,4.4492A24.3275,24.3275,0,0,0,10.0369,15H4.0508A12.0126,12.0126,0,0,1,12.79,4.4492ZM4.0508,17h5.9861A24.3275,24.3275,0,0,0,12.79,27.5508,12.0126,12.0126,0,0,1,4.0508,17Z"
  })), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M25,25l5,2V25l-5-2.5V20a1,1,0,0,0-2,0v2.5L18,25v2l5-2v3.5L21,30v1l3-1,3,1V30l-2-1.5Z"
  })), children);
});
var FlightInternational20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlightInternational20(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28a5.3257,5.3257,0,0,1-.6714-.044A21.7855,21.7855,0,0,1,12.0332,17H29.95c.0236-.3315.05-.6626.05-1A14,14,0,1,0,16,30ZM27.9492,15H21.9631A24.3247,24.3247,0,0,0,19.21,4.4492,12.0123,12.0123,0,0,1,27.9492,15ZM16.6714,4.0439A21.7855,21.7855,0,0,1,19.9668,15H12.0332A21.7855,21.7855,0,0,1,15.3286,4.0439,5.159,5.159,0,0,1,16.6714,4.0439ZM12.79,4.4492A24.3275,24.3275,0,0,0,10.0369,15H4.0508A12.0126,12.0126,0,0,1,12.79,4.4492ZM4.0508,17h5.9861A24.3275,24.3275,0,0,0,12.79,27.5508,12.0126,12.0126,0,0,1,4.0508,17Z"
  })), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M25,25l5,2V25l-5-2.5V20a1,1,0,0,0-2,0v2.5L18,25v2l5-2v3.5L21,30v1l3-1,3,1V30l-2-1.5Z"
  })), children);
});
var FlightInternational16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlightInternational16(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28a5.3257,5.3257,0,0,1-.6714-.044A21.7855,21.7855,0,0,1,12.0332,17H29.95c.0236-.3315.05-.6626.05-1A14,14,0,1,0,16,30ZM27.9492,15H21.9631A24.3247,24.3247,0,0,0,19.21,4.4492,12.0123,12.0123,0,0,1,27.9492,15ZM16.6714,4.0439A21.7855,21.7855,0,0,1,19.9668,15H12.0332A21.7855,21.7855,0,0,1,15.3286,4.0439,5.159,5.159,0,0,1,16.6714,4.0439ZM12.79,4.4492A24.3275,24.3275,0,0,0,10.0369,15H4.0508A12.0126,12.0126,0,0,1,12.79,4.4492ZM4.0508,17h5.9861A24.3275,24.3275,0,0,0,12.79,27.5508,12.0126,12.0126,0,0,1,4.0508,17Z"
  })), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M25,25l5,2V25l-5-2.5V20a1,1,0,0,0-2,0v2.5L18,25v2l5-2v3.5L21,30v1l3-1,3,1V30l-2-1.5Z"
  })), children);
});
var FlightRoster32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlightRoster32(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M26,6a2,2,0,0,0-2-2H8A2,2,0,0,0,6,6V26a2,2,0,0,0,2,2h8V26H8V6H24v6h2Z"
  })), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 18H16V20H10zM10 14H22V16H10z"
  })), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M22 10v2H10V10zM25 23l5 2V23l-5-2.5V18a1 1 0 00-2 0v2.5L18 23v2l5-2v3.5L21 28v1l3-1 3 1V28l-2-1.5z"
  })), children);
});
var FlightRoster24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlightRoster24(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M26,6a2,2,0,0,0-2-2H8A2,2,0,0,0,6,6V26a2,2,0,0,0,2,2h8V26H8V6H24v6h2Z"
  })), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 18H16V20H10zM10 14H22V16H10z"
  })), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M22 10v2H10V10zM25 23l5 2V23l-5-2.5V18a1 1 0 00-2 0v2.5L18 23v2l5-2v3.5L21 28v1l3-1 3 1V28l-2-1.5z"
  })), children);
});
var FlightRoster20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlightRoster20(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M26,6a2,2,0,0,0-2-2H8A2,2,0,0,0,6,6V26a2,2,0,0,0,2,2h8V26H8V6H24v6h2Z"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 18H16V20H10zM10 14H22V16H10z"
  })), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M22 10v2H10V10zM25 23l5 2V23l-5-2.5V18a1 1 0 00-2 0v2.5L18 23v2l5-2v3.5L21 28v1l3-1 3 1V28l-2-1.5z"
  })), children);
});
var FlightRoster16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlightRoster16(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M26,6a2,2,0,0,0-2-2H8A2,2,0,0,0,6,6V26a2,2,0,0,0,2,2h8V26H8V6H24v6h2Z"
  })), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 18H16V20H10zM10 14H22V16H10z"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M22 10v2H10V10zM25 23l5 2V23l-5-2.5V18a1 1 0 00-2 0v2.5L18 23v2l5-2v3.5L21 28v1l3-1 3 1V28l-2-1.5z"
  })), children);
});
var FlightSchedule32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlightSchedule32(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M25,23l5,2V23l-5-2.5V18a1,1,0,0,0-2,0v2.5L18,23v2l5-2v3.5L21,28v1l3-1,3,1V28l-2-1.5Z"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M26,4H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H16V26H6V6h4V8h2V6h8V8h2V6h4v7h2V6A2,2,0,0,0,26,4Z"
  })), children);
});
var FlightSchedule24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlightSchedule24(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M25,23l5,2V23l-5-2.5V18a1,1,0,0,0-2,0v2.5L18,23v2l5-2v3.5L21,28v1l3-1,3,1V28l-2-1.5Z"
  })), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M26,4H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H16V26H6V6h4V8h2V6h8V8h2V6h4v7h2V6A2,2,0,0,0,26,4Z"
  })), children);
});
var FlightSchedule20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlightSchedule20(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M25,23l5,2V23l-5-2.5V18a1,1,0,0,0-2,0v2.5L18,23v2l5-2v3.5L21,28v1l3-1,3,1V28l-2-1.5Z"
  })), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M26,4H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H16V26H6V6h4V8h2V6h8V8h2V6h4v7h2V6A2,2,0,0,0,26,4Z"
  })), children);
});
var FlightSchedule16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlightSchedule16(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M25,23l5,2V23l-5-2.5V18a1,1,0,0,0-2,0v2.5L18,23v2l5-2v3.5L21,28v1l3-1,3,1V28l-2-1.5Z"
  })), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M26,4H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H16V26H6V6h4V8h2V6h8V8h2V6h4v7h2V6A2,2,0,0,0,26,4Z"
  })), children);
});
var FloatingIp32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FloatingIp32(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,11a5.0083,5.0083,0,0,0-4.8989,4H11.8989a5,5,0,1,0,0,2h8.2022A5,5,0,1,0,25,11Zm0,8a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,25,19Z"
  })), children);
});
var FloatingIp24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FloatingIp24(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,11a5.0083,5.0083,0,0,0-4.8989,4H11.8989a5,5,0,1,0,0,2h8.2022A5,5,0,1,0,25,11Zm0,8a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,25,19Z"
  })), children);
});
var FloatingIp20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FloatingIp20(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,11a5.0083,5.0083,0,0,0-4.8989,4H11.8989a5,5,0,1,0,0,2h8.2022A5,5,0,1,0,25,11Zm0,8a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,25,19Z"
  })), children);
});
var FloatingIp16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FloatingIp16(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,11a5.0083,5.0083,0,0,0-4.8989,4H11.8989a5,5,0,1,0,0,2h8.2022A5,5,0,1,0,25,11Zm0,8a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,25,19Z"
  })), children);
});
var Flood32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Flood32(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 28a2.8828 2.8828 0 01-1-.1816v-.0059a3.7662 3.7662 0 01-2.0532-2.1338A.971.971 0 0025 25a1.007 1.007 0 00-.9487.6836A3.4376 3.4376 0 0121 28a3.44 3.44 0 01-3.0532-2.3213A.9894.9894 0 0017 25a1.007 1.007 0 00-.9487.6836A3.4376 3.4376 0 0113 28a3.44 3.44 0 01-3.0532-2.3213 1 1 0 00-1.8955.0049A3.4376 3.4376 0 015 28H2v2H5a4.9316 4.9316 0 004-1.9873 5.0192 5.0192 0 008 0 5.0192 5.0192 0 008 0 5.1433 5.1433 0 002.1379 1.62A4.8374 4.8374 0 0029 30h1V28zM28 13.63L29.7573 15 31 13.4282 16.6123 2.2139a1.0094 1.0094 0 00-1.2427 0L1 13.4194l1.2427 1.5718L4 13.6211v5.1875a3.6907 3.6907 0 01-2 2.0039V22.896a4.9958 4.9958 0 003-1.8833 5.0192 5.0192 0 008 0 5.0192 5.0192 0 008 0A4.9316 4.9316 0 0025 23h5V21H28zm-6.0513 5.0532a1 1 0 00-1.8955-.0049A3.44 3.44 0 0117 21a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 0013 18a.9894.9894 0 00-.9468.6787A3.44 3.44 0 019 21a3.37 3.37 0 01-3.0021-2.19L6 12.0615l9.991-7.79L26 12.0718 26.0017 21H25A3.4376 3.4376 0 0121.9487 18.6836z"
  })), children);
});
var Flood24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Flood24(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 28a2.8828 2.8828 0 01-1-.1816v-.0059a3.7662 3.7662 0 01-2.0532-2.1338A.971.971 0 0025 25a1.007 1.007 0 00-.9487.6836A3.4376 3.4376 0 0121 28a3.44 3.44 0 01-3.0532-2.3213A.9894.9894 0 0017 25a1.007 1.007 0 00-.9487.6836A3.4376 3.4376 0 0113 28a3.44 3.44 0 01-3.0532-2.3213 1 1 0 00-1.8955.0049A3.4376 3.4376 0 015 28H2v2H5a4.9316 4.9316 0 004-1.9873 5.0192 5.0192 0 008 0 5.0192 5.0192 0 008 0 5.1433 5.1433 0 002.1379 1.62A4.8374 4.8374 0 0029 30h1V28zM28 13.63L29.7573 15 31 13.4282 16.6123 2.2139a1.0094 1.0094 0 00-1.2427 0L1 13.4194l1.2427 1.5718L4 13.6211v5.1875a3.6907 3.6907 0 01-2 2.0039V22.896a4.9958 4.9958 0 003-1.8833 5.0192 5.0192 0 008 0 5.0192 5.0192 0 008 0A4.9316 4.9316 0 0025 23h5V21H28zm-6.0513 5.0532a1 1 0 00-1.8955-.0049A3.44 3.44 0 0117 21a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 0013 18a.9894.9894 0 00-.9468.6787A3.44 3.44 0 019 21a3.37 3.37 0 01-3.0021-2.19L6 12.0615l9.991-7.79L26 12.0718 26.0017 21H25A3.4376 3.4376 0 0121.9487 18.6836z"
  })), children);
});
var Flood20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Flood20(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 28a2.8828 2.8828 0 01-1-.1816v-.0059a3.7662 3.7662 0 01-2.0532-2.1338A.971.971 0 0025 25a1.007 1.007 0 00-.9487.6836A3.4376 3.4376 0 0121 28a3.44 3.44 0 01-3.0532-2.3213A.9894.9894 0 0017 25a1.007 1.007 0 00-.9487.6836A3.4376 3.4376 0 0113 28a3.44 3.44 0 01-3.0532-2.3213 1 1 0 00-1.8955.0049A3.4376 3.4376 0 015 28H2v2H5a4.9316 4.9316 0 004-1.9873 5.0192 5.0192 0 008 0 5.0192 5.0192 0 008 0 5.1433 5.1433 0 002.1379 1.62A4.8374 4.8374 0 0029 30h1V28zM28 13.63L29.7573 15 31 13.4282 16.6123 2.2139a1.0094 1.0094 0 00-1.2427 0L1 13.4194l1.2427 1.5718L4 13.6211v5.1875a3.6907 3.6907 0 01-2 2.0039V22.896a4.9958 4.9958 0 003-1.8833 5.0192 5.0192 0 008 0 5.0192 5.0192 0 008 0A4.9316 4.9316 0 0025 23h5V21H28zm-6.0513 5.0532a1 1 0 00-1.8955-.0049A3.44 3.44 0 0117 21a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 0013 18a.9894.9894 0 00-.9468.6787A3.44 3.44 0 019 21a3.37 3.37 0 01-3.0021-2.19L6 12.0615l9.991-7.79L26 12.0718 26.0017 21H25A3.4376 3.4376 0 0121.9487 18.6836z"
  })), children);
});
var Flood16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Flood16(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 28a2.8828 2.8828 0 01-1-.1816v-.0059a3.7662 3.7662 0 01-2.0532-2.1338A.971.971 0 0025 25a1.007 1.007 0 00-.9487.6836A3.4376 3.4376 0 0121 28a3.44 3.44 0 01-3.0532-2.3213A.9894.9894 0 0017 25a1.007 1.007 0 00-.9487.6836A3.4376 3.4376 0 0113 28a3.44 3.44 0 01-3.0532-2.3213 1 1 0 00-1.8955.0049A3.4376 3.4376 0 015 28H2v2H5a4.9316 4.9316 0 004-1.9873 5.0192 5.0192 0 008 0 5.0192 5.0192 0 008 0 5.1433 5.1433 0 002.1379 1.62A4.8374 4.8374 0 0029 30h1V28zM28 13.63L29.7573 15 31 13.4282 16.6123 2.2139a1.0094 1.0094 0 00-1.2427 0L1 13.4194l1.2427 1.5718L4 13.6211v5.1875a3.6907 3.6907 0 01-2 2.0039V22.896a4.9958 4.9958 0 003-1.8833 5.0192 5.0192 0 008 0 5.0192 5.0192 0 008 0A4.9316 4.9316 0 0025 23h5V21H28zm-6.0513 5.0532a1 1 0 00-1.8955-.0049A3.44 3.44 0 0117 21a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 0013 18a.9894.9894 0 00-.9468.6787A3.44 3.44 0 019 21a3.37 3.37 0 01-3.0021-2.19L6 12.0615l9.991-7.79L26 12.0718 26.0017 21H25A3.4376 3.4376 0 0121.9487 18.6836z"
  })), children);
});
var FloodWarning32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FloodWarning32(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,28a2.8828,2.8828,0,0,1-1-.1816v-.0059a3.7662,3.7662,0,0,1-2.0532-2.1338A.971.971,0,0,0,25,25a1.007,1.007,0,0,0-.9487.6836A3.4376,3.4376,0,0,1,21,28a3.44,3.44,0,0,1-3.0532-2.3213A.9894.9894,0,0,0,17,25a1.007,1.007,0,0,0-.9487.6836A3.4376,3.4376,0,0,1,13,28a3.44,3.44,0,0,1-3.0532-2.3213,1,1,0,0,0-1.8955.0049A3.4376,3.4376,0,0,1,5,28H2v2H5a4.9316,4.9316,0,0,0,4-1.9873,5.0192,5.0192,0,0,0,8,0,5.0192,5.0192,0,0,0,8,0,5.1433,5.1433,0,0,0,2.1379,1.62A4.8374,4.8374,0,0,0,29,30h1V28Z"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,11h-1.5V7h1.5ZM23,12a1,1,0,1,0,1,1A1,1,0,0,0,23,12Z"
  })), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115,14.9355,23.6284,3.3706a.7181.7181,0,0,0-1.2568,0L16.0885,14.9355A.72.72,0,0,0,16.72,16H29.28A.72.72,0,0,0,29.9115,14.9355ZM22.25,7h1.5v4h-1.5ZM23,14a1,1,0,1,1,1-1A1,1,0,0,1,23,14Z"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,21V18H26v3H25a3.4376,3.4376,0,0,1-3.0513-2.3164,1,1,0,0,0-1.8955-.0049A3.44,3.44,0,0,1,17,21a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,13,18a.9894.9894,0,0,0-.9468.6787A3.44,3.44,0,0,1,9,21a3.3663,3.3663,0,0,1-3-2.1855v-6.753l10-7.79,2.5327,1.9756.9682-1.7818L16.6123,2.2139a1.0094,1.0094,0,0,0-1.2427,0L1,13.4194l1.2427,1.5718L4,13.6211v5.1875a3.6892,3.6892,0,0,1-2,2.0039V22.896a4.9958,4.9958,0,0,0,3-1.8833,5.0192,5.0192,0,0,0,8,0,5.0192,5.0192,0,0,0,8,0A4.9316,4.9316,0,0,0,25,23h5V21Z"
  })), children);
});
var FloodWarning24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FloodWarning24(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,28a2.8828,2.8828,0,0,1-1-.1816v-.0059a3.7662,3.7662,0,0,1-2.0532-2.1338A.971.971,0,0,0,25,25a1.007,1.007,0,0,0-.9487.6836A3.4376,3.4376,0,0,1,21,28a3.44,3.44,0,0,1-3.0532-2.3213A.9894.9894,0,0,0,17,25a1.007,1.007,0,0,0-.9487.6836A3.4376,3.4376,0,0,1,13,28a3.44,3.44,0,0,1-3.0532-2.3213,1,1,0,0,0-1.8955.0049A3.4376,3.4376,0,0,1,5,28H2v2H5a4.9316,4.9316,0,0,0,4-1.9873,5.0192,5.0192,0,0,0,8,0,5.0192,5.0192,0,0,0,8,0,5.1433,5.1433,0,0,0,2.1379,1.62A4.8374,4.8374,0,0,0,29,30h1V28Z"
  })), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,11h-1.5V7h1.5ZM23,12a1,1,0,1,0,1,1A1,1,0,0,0,23,12Z"
  })), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115,14.9355,23.6284,3.3706a.7181.7181,0,0,0-1.2568,0L16.0885,14.9355A.72.72,0,0,0,16.72,16H29.28A.72.72,0,0,0,29.9115,14.9355ZM22.25,7h1.5v4h-1.5ZM23,14a1,1,0,1,1,1-1A1,1,0,0,1,23,14Z"
  })), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,21V18H26v3H25a3.4376,3.4376,0,0,1-3.0513-2.3164,1,1,0,0,0-1.8955-.0049A3.44,3.44,0,0,1,17,21a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,13,18a.9894.9894,0,0,0-.9468.6787A3.44,3.44,0,0,1,9,21a3.3663,3.3663,0,0,1-3-2.1855v-6.753l10-7.79,2.5327,1.9756.9682-1.7818L16.6123,2.2139a1.0094,1.0094,0,0,0-1.2427,0L1,13.4194l1.2427,1.5718L4,13.6211v5.1875a3.6892,3.6892,0,0,1-2,2.0039V22.896a4.9958,4.9958,0,0,0,3-1.8833,5.0192,5.0192,0,0,0,8,0,5.0192,5.0192,0,0,0,8,0A4.9316,4.9316,0,0,0,25,23h5V21Z"
  })), children);
});
var FloodWarning20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FloodWarning20(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,28a2.8828,2.8828,0,0,1-1-.1816v-.0059a3.7662,3.7662,0,0,1-2.0532-2.1338A.971.971,0,0,0,25,25a1.007,1.007,0,0,0-.9487.6836A3.4376,3.4376,0,0,1,21,28a3.44,3.44,0,0,1-3.0532-2.3213A.9894.9894,0,0,0,17,25a1.007,1.007,0,0,0-.9487.6836A3.4376,3.4376,0,0,1,13,28a3.44,3.44,0,0,1-3.0532-2.3213,1,1,0,0,0-1.8955.0049A3.4376,3.4376,0,0,1,5,28H2v2H5a4.9316,4.9316,0,0,0,4-1.9873,5.0192,5.0192,0,0,0,8,0,5.0192,5.0192,0,0,0,8,0,5.1433,5.1433,0,0,0,2.1379,1.62A4.8374,4.8374,0,0,0,29,30h1V28Z"
  })), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,11h-1.5V7h1.5ZM23,12a1,1,0,1,0,1,1A1,1,0,0,0,23,12Z"
  })), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115,14.9355,23.6284,3.3706a.7181.7181,0,0,0-1.2568,0L16.0885,14.9355A.72.72,0,0,0,16.72,16H29.28A.72.72,0,0,0,29.9115,14.9355ZM22.25,7h1.5v4h-1.5ZM23,14a1,1,0,1,1,1-1A1,1,0,0,1,23,14Z"
  })), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,21V18H26v3H25a3.4376,3.4376,0,0,1-3.0513-2.3164,1,1,0,0,0-1.8955-.0049A3.44,3.44,0,0,1,17,21a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,13,18a.9894.9894,0,0,0-.9468.6787A3.44,3.44,0,0,1,9,21a3.3663,3.3663,0,0,1-3-2.1855v-6.753l10-7.79,2.5327,1.9756.9682-1.7818L16.6123,2.2139a1.0094,1.0094,0,0,0-1.2427,0L1,13.4194l1.2427,1.5718L4,13.6211v5.1875a3.6892,3.6892,0,0,1-2,2.0039V22.896a4.9958,4.9958,0,0,0,3-1.8833,5.0192,5.0192,0,0,0,8,0,5.0192,5.0192,0,0,0,8,0A4.9316,4.9316,0,0,0,25,23h5V21Z"
  })), children);
});
var FloodWarning16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FloodWarning16(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,28a2.8828,2.8828,0,0,1-1-.1816v-.0059a3.7662,3.7662,0,0,1-2.0532-2.1338A.971.971,0,0,0,25,25a1.007,1.007,0,0,0-.9487.6836A3.4376,3.4376,0,0,1,21,28a3.44,3.44,0,0,1-3.0532-2.3213A.9894.9894,0,0,0,17,25a1.007,1.007,0,0,0-.9487.6836A3.4376,3.4376,0,0,1,13,28a3.44,3.44,0,0,1-3.0532-2.3213,1,1,0,0,0-1.8955.0049A3.4376,3.4376,0,0,1,5,28H2v2H5a4.9316,4.9316,0,0,0,4-1.9873,5.0192,5.0192,0,0,0,8,0,5.0192,5.0192,0,0,0,8,0,5.1433,5.1433,0,0,0,2.1379,1.62A4.8374,4.8374,0,0,0,29,30h1V28Z"
  })), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,11h-1.5V7h1.5ZM23,12a1,1,0,1,0,1,1A1,1,0,0,0,23,12Z"
  })), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115,14.9355,23.6284,3.3706a.7181.7181,0,0,0-1.2568,0L16.0885,14.9355A.72.72,0,0,0,16.72,16H29.28A.72.72,0,0,0,29.9115,14.9355ZM22.25,7h1.5v4h-1.5ZM23,14a1,1,0,1,1,1-1A1,1,0,0,1,23,14Z"
  })), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,21V18H26v3H25a3.4376,3.4376,0,0,1-3.0513-2.3164,1,1,0,0,0-1.8955-.0049A3.44,3.44,0,0,1,17,21a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,13,18a.9894.9894,0,0,0-.9468.6787A3.44,3.44,0,0,1,9,21a3.3663,3.3663,0,0,1-3-2.1855v-6.753l10-7.79,2.5327,1.9756.9682-1.7818L16.6123,2.2139a1.0094,1.0094,0,0,0-1.2427,0L1,13.4194l1.2427,1.5718L4,13.6211v5.1875a3.6892,3.6892,0,0,1-2,2.0039V22.896a4.9958,4.9958,0,0,0,3-1.8833,5.0192,5.0192,0,0,0,8,0,5.0192,5.0192,0,0,0,8,0A4.9316,4.9316,0,0,0,25,23h5V21Z"
  })), children);
});
var Floorplan32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Floorplan32(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4C2.9,2,2,2.9,2,4v24c0,1.1,0.9,2,2,2h15v-2c0-2.8,2.2-5,5-5v-2c-3.9,0-7,3.1-7,7h-3v-4h-2v4H4V4h8v14h2v-5h4v-2h-4V4\th14v7h-4v2h4v15h-4v2h4c1.1,0,2-0.9,2-2V4C30,2.9,29.1,2,28,2z"
  })), children);
});
var Floorplan24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Floorplan24(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4C2.9,2,2,2.9,2,4v24c0,1.1,0.9,2,2,2h15v-2c0-2.8,2.2-5,5-5v-2c-3.9,0-7,3.1-7,7h-3v-4h-2v4H4V4h8v14h2v-5h4v-2h-4V4\th14v7h-4v2h4v15h-4v2h4c1.1,0,2-0.9,2-2V4C30,2.9,29.1,2,28,2z"
  })), children);
});
var Floorplan20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Floorplan20(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4C2.9,2,2,2.9,2,4v24c0,1.1,0.9,2,2,2h15v-2c0-2.8,2.2-5,5-5v-2c-3.9,0-7,3.1-7,7h-3v-4h-2v4H4V4h8v14h2v-5h4v-2h-4V4\th14v7h-4v2h4v15h-4v2h4c1.1,0,2-0.9,2-2V4C30,2.9,29.1,2,28,2z"
  })), children);
});
var Floorplan16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Floorplan16(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4C2.9,2,2,2.9,2,4v24c0,1.1,0.9,2,2,2h15v-2c0-2.8,2.2-5,5-5v-2c-3.9,0-7,3.1-7,7h-3v-4h-2v4H4V4h8v14h2v-5h4v-2h-4V4\th14v7h-4v2h4v15h-4v2h4c1.1,0,2-0.9,2-2V4C30,2.9,29.1,2,28,2z"
  })), children);
});
var Flow32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Flow32(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.14V17a2,2,0,0,0-2-2H17V9.86a4,4,0,1,0-2,0V15H7a2,2,0,0,0-2,2v5.14a4,4,0,1,0,2,0V17H25v5.14a4,4,0,1,0,2,0ZM8,26a2,2,0,1,1-2-2A2,2,0,0,1,8,26ZM14,6a2,2,0,1,1,2,2A2,2,0,0,1,14,6ZM26,28a2,2,0,1,1,2-2A2,2,0,0,1,26,28Z"
  })), children);
});
var Flow24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Flow24(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.14V17a2,2,0,0,0-2-2H17V9.86a4,4,0,1,0-2,0V15H7a2,2,0,0,0-2,2v5.14a4,4,0,1,0,2,0V17H25v5.14a4,4,0,1,0,2,0ZM8,26a2,2,0,1,1-2-2A2,2,0,0,1,8,26ZM14,6a2,2,0,1,1,2,2A2,2,0,0,1,14,6ZM26,28a2,2,0,1,1,2-2A2,2,0,0,1,26,28Z"
  })), children);
});
var Flow20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Flow20(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.14V17a2,2,0,0,0-2-2H17V9.86a4,4,0,1,0-2,0V15H7a2,2,0,0,0-2,2v5.14a4,4,0,1,0,2,0V17H25v5.14a4,4,0,1,0,2,0ZM8,26a2,2,0,1,1-2-2A2,2,0,0,1,8,26ZM14,6a2,2,0,1,1,2,2A2,2,0,0,1,14,6ZM26,28a2,2,0,1,1,2-2A2,2,0,0,1,26,28Z"
  })), children);
});
var Flow16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Flow16(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.14V17a2,2,0,0,0-2-2H17V9.86a4,4,0,1,0-2,0V15H7a2,2,0,0,0-2,2v5.14a4,4,0,1,0,2,0V17H25v5.14a4,4,0,1,0,2,0ZM8,26a2,2,0,1,1-2-2A2,2,0,0,1,8,26ZM14,6a2,2,0,1,1,2,2A2,2,0,0,1,14,6ZM26,28a2,2,0,1,1,2-2A2,2,0,0,1,26,28Z"
  })), children);
});
var FlowConnection32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowConnection32(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,18H22a2.0023,2.0023,0,0,0-2,2v2H14.4141L10,17.5859V12h2a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H6A2.0023,2.0023,0,0,0,4,4v6a2.0023,2.0023,0,0,0,2,2H8v5.5859L3.293,22.293a.9994.9994,0,0,0,0,1.414l5,5a.9995.9995,0,0,0,1.414,0L14.4141,24H20v2a2.0023,2.0023,0,0,0,2,2h6a2.0023,2.0023,0,0,0,2-2V20A2.0023,2.0023,0,0,0,28,18ZM6,4h6v6H6ZM9,26.5859,5.4141,23,9,19.4141,12.5859,23ZM22,26V20h6v6Z"
  })), children);
});
var FlowConnection24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowConnection24(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,18H22a2.0023,2.0023,0,0,0-2,2v2H14.4141L10,17.5859V12h2a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H6A2.0023,2.0023,0,0,0,4,4v6a2.0023,2.0023,0,0,0,2,2H8v5.5859L3.293,22.293a.9994.9994,0,0,0,0,1.414l5,5a.9995.9995,0,0,0,1.414,0L14.4141,24H20v2a2.0023,2.0023,0,0,0,2,2h6a2.0023,2.0023,0,0,0,2-2V20A2.0023,2.0023,0,0,0,28,18ZM6,4h6v6H6ZM9,26.5859,5.4141,23,9,19.4141,12.5859,23ZM22,26V20h6v6Z"
  })), children);
});
var FlowConnection20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowConnection20(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,18H22a2.0023,2.0023,0,0,0-2,2v2H14.4141L10,17.5859V12h2a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H6A2.0023,2.0023,0,0,0,4,4v6a2.0023,2.0023,0,0,0,2,2H8v5.5859L3.293,22.293a.9994.9994,0,0,0,0,1.414l5,5a.9995.9995,0,0,0,1.414,0L14.4141,24H20v2a2.0023,2.0023,0,0,0,2,2h6a2.0023,2.0023,0,0,0,2-2V20A2.0023,2.0023,0,0,0,28,18ZM6,4h6v6H6ZM9,26.5859,5.4141,23,9,19.4141,12.5859,23ZM22,26V20h6v6Z"
  })), children);
});
var FlowConnection16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowConnection16(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,18H22a2.0023,2.0023,0,0,0-2,2v2H14.4141L10,17.5859V12h2a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H6A2.0023,2.0023,0,0,0,4,4v6a2.0023,2.0023,0,0,0,2,2H8v5.5859L3.293,22.293a.9994.9994,0,0,0,0,1.414l5,5a.9995.9995,0,0,0,1.414,0L14.4141,24H20v2a2.0023,2.0023,0,0,0,2,2h6a2.0023,2.0023,0,0,0,2-2V20A2.0023,2.0023,0,0,0,28,18ZM6,4h6v6H6ZM9,26.5859,5.4141,23,9,19.4141,12.5859,23ZM22,26V20h6v6Z"
  })), children);
});
var FlowData32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowData32(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,23H11.86a4.17,4.17,0,0,0-.43-1L22,11.43A3.86,3.86,0,0,0,24,12a4,4,0,1,0-3.86-5H11.86a4,4,0,1,0,0,2h8.28a4.17,4.17,0,0,0,.43,1L10,20.57A3.86,3.86,0,0,0,8,20a4,4,0,1,0,3.86,5H20v3h8V20H20ZM8,10a2,2,0,1,1,2-2A2,2,0,0,1,8,10ZM24,6a2,2,0,1,1-2,2A2,2,0,0,1,24,6ZM8,26a2,2,0,1,1,2-2A2,2,0,0,1,8,26Zm14-4h4v4H22Z"
  })), children);
});
var FlowData24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowData24(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,23H11.86a4.17,4.17,0,0,0-.43-1L22,11.43A3.86,3.86,0,0,0,24,12a4,4,0,1,0-3.86-5H11.86a4,4,0,1,0,0,2h8.28a4.17,4.17,0,0,0,.43,1L10,20.57A3.86,3.86,0,0,0,8,20a4,4,0,1,0,3.86,5H20v3h8V20H20ZM8,10a2,2,0,1,1,2-2A2,2,0,0,1,8,10ZM24,6a2,2,0,1,1-2,2A2,2,0,0,1,24,6ZM8,26a2,2,0,1,1,2-2A2,2,0,0,1,8,26Zm14-4h4v4H22Z"
  })), children);
});
var FlowData20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowData20(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,23H11.86a4.17,4.17,0,0,0-.43-1L22,11.43A3.86,3.86,0,0,0,24,12a4,4,0,1,0-3.86-5H11.86a4,4,0,1,0,0,2h8.28a4.17,4.17,0,0,0,.43,1L10,20.57A3.86,3.86,0,0,0,8,20a4,4,0,1,0,3.86,5H20v3h8V20H20ZM8,10a2,2,0,1,1,2-2A2,2,0,0,1,8,10ZM24,6a2,2,0,1,1-2,2A2,2,0,0,1,24,6ZM8,26a2,2,0,1,1,2-2A2,2,0,0,1,8,26Zm14-4h4v4H22Z"
  })), children);
});
var FlowData16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowData16(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,23H11.86a4.17,4.17,0,0,0-.43-1L22,11.43A3.86,3.86,0,0,0,24,12a4,4,0,1,0-3.86-5H11.86a4,4,0,1,0,0,2h8.28a4.17,4.17,0,0,0,.43,1L10,20.57A3.86,3.86,0,0,0,8,20a4,4,0,1,0,3.86,5H20v3h8V20H20ZM8,10a2,2,0,1,1,2-2A2,2,0,0,1,8,10ZM24,6a2,2,0,1,1-2,2A2,2,0,0,1,24,6ZM8,26a2,2,0,1,1,2-2A2,2,0,0,1,8,26Zm14-4h4v4H22Z"
  })), children);
});
var FlowModeler32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowModeler32(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 10H2V2h8zM4 8H8V4H4zM30 30H22V22h8zm-6-2h4V24H24zM20 27H8A6 6 0 018 15v2a4 4 0 000 8H20zM24 17V15a4 4 0 000-8H12V5H24a6 6 0 010 12z"
  })), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,11H13l-3,4,6,6,6-6Z"
  })), children);
});
var FlowModeler24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowModeler24(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 10H2V2h8zM4 8H8V4H4zM30 30H22V22h8zm-6-2h4V24H24zM20 27H8A6 6 0 018 15v2a4 4 0 000 8H20zM24 17V15a4 4 0 000-8H12V5H24a6 6 0 010 12z"
  })), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,11H13l-3,4,6,6,6-6Z"
  })), children);
});
var FlowModeler20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowModeler20(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 10H2V2h8zM4 8H8V4H4zM30 30H22V22h8zm-6-2h4V24H24zM20 27H8A6 6 0 018 15v2a4 4 0 000 8H20zM24 17V15a4 4 0 000-8H12V5H24a6 6 0 010 12z"
  })), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,11H13l-3,4,6,6,6-6Z"
  })), children);
});
var FlowModeler16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowModeler16(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 10H2V2h8zM4 8H8V4H4zM30 30H22V22h8zm-6-2h4V24H24zM20 27H8A6 6 0 018 15v2a4 4 0 000 8H20zM24 17V15a4 4 0 000-8H12V5H24a6 6 0 010 12z"
  })), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,11H13l-3,4,6,6,6-6Z"
  })), children);
});
var FlowModelerReference32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowModelerReference32(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V22h8zm-6-2h4V24H24zM4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM19 11H13l-3 4 6 6 6-6z"
  })), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 17V15a4 4 0 000-8H12V5H24a6 6 0 010 12zM10 10H2V2h8zM4 8H8V4H4z"
  })), children);
});
var FlowModelerReference24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowModelerReference24(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V22h8zm-6-2h4V24H24zM4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM19 11H13l-3 4 6 6 6-6z"
  })), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 17V15a4 4 0 000-8H12V5H24a6 6 0 010 12zM10 10H2V2h8zM4 8H8V4H4z"
  })), children);
});
var FlowModelerReference20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowModelerReference20(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V22h8zm-6-2h4V24H24zM4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM19 11H13l-3 4 6 6 6-6z"
  })), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 17V15a4 4 0 000-8H12V5H24a6 6 0 010 12zM10 10H2V2h8zM4 8H8V4H4z"
  })), children);
});
var FlowModelerReference16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowModelerReference16(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V22h8zm-6-2h4V24H24zM4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM19 11H13l-3 4 6 6 6-6z"
  })), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 17V15a4 4 0 000-8H12V5H24a6 6 0 010 12zM10 10H2V2h8zM4 8H8V4H4z"
  })), children);
});
var FlowStream32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowStream32(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 24H11.8625a4.13 4.13 0 00-.4284-1.02L21.98 12.4343A3.9943 3.9943 0 1020.1414 8H14v2h6.1414a3.96 3.96 0 00.4243 1.02L10.02 21.5656A3.9943 3.9943 0 1011.8587 26H20v3h8V21H20zM24 7a2 2 0 11-2 2A2.0023 2.0023 0 0124 7zM8 27a2 2 0 112-2A2.0023 2.0023 0 018 27zm14-4h4v4H22zM9.6929 12.7505a5 5 0 01-.0005-7.5L11.0166 6.75a3 3 0 00-.0005 4.501z"
  })), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.0474,15.751a9,9,0,0,1,0-13.501l1.3232,1.5a7,7,0,0,0,0,10.501Z"
  })), children);
});
var FlowStream24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowStream24(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 24H11.8625a4.13 4.13 0 00-.4284-1.02L21.98 12.4343A3.9943 3.9943 0 1020.1414 8H14v2h6.1414a3.96 3.96 0 00.4243 1.02L10.02 21.5656A3.9943 3.9943 0 1011.8587 26H20v3h8V21H20zM24 7a2 2 0 11-2 2A2.0023 2.0023 0 0124 7zM8 27a2 2 0 112-2A2.0023 2.0023 0 018 27zm14-4h4v4H22zM9.6929 12.7505a5 5 0 01-.0005-7.5L11.0166 6.75a3 3 0 00-.0005 4.501z"
  })), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.0474,15.751a9,9,0,0,1,0-13.501l1.3232,1.5a7,7,0,0,0,0,10.501Z"
  })), children);
});
var FlowStream20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowStream20(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 24H11.8625a4.13 4.13 0 00-.4284-1.02L21.98 12.4343A3.9943 3.9943 0 1020.1414 8H14v2h6.1414a3.96 3.96 0 00.4243 1.02L10.02 21.5656A3.9943 3.9943 0 1011.8587 26H20v3h8V21H20zM24 7a2 2 0 11-2 2A2.0023 2.0023 0 0124 7zM8 27a2 2 0 112-2A2.0023 2.0023 0 018 27zm14-4h4v4H22zM9.6929 12.7505a5 5 0 01-.0005-7.5L11.0166 6.75a3 3 0 00-.0005 4.501z"
  })), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.0474,15.751a9,9,0,0,1,0-13.501l1.3232,1.5a7,7,0,0,0,0,10.501Z"
  })), children);
});
var FlowStream16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowStream16(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 24H11.8625a4.13 4.13 0 00-.4284-1.02L21.98 12.4343A3.9943 3.9943 0 1020.1414 8H14v2h6.1414a3.96 3.96 0 00.4243 1.02L10.02 21.5656A3.9943 3.9943 0 1011.8587 26H20v3h8V21H20zM24 7a2 2 0 11-2 2A2.0023 2.0023 0 0124 7zM8 27a2 2 0 112-2A2.0023 2.0023 0 018 27zm14-4h4v4H22zM9.6929 12.7505a5 5 0 01-.0005-7.5L11.0166 6.75a3 3 0 00-.0005 4.501z"
  })), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.0474,15.751a9,9,0,0,1,0-13.501l1.3232,1.5a7,7,0,0,0,0,10.501Z"
  })), children);
});
var FlowStreamReference32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowStreamReference32(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 24H16v2h4v3h8V21H20zm2-1h4v4H22zM4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM24 5a3.9962 3.9962 0 00-3.8579 3H14v2h6.1421a3.94 3.94 0 00.4248 1.019L14 17.5862 15.4138 19l6.5672-6.5669A3.9521 3.9521 0 0024 13a4 4 0 000-8zm0 6a2 2 0 112-2A2.0023 2.0023 0 0124 11zM9.6929 12.7505a5 5 0 01-.0005-7.5L11.0166 6.75a3 3 0 00-.0005 4.501z"
  })), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.0474,15.751a9,9,0,0,1,0-13.501l1.3232,1.5a7,7,0,0,0,0,10.501Z"
  })), children);
});
var FlowStreamReference24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowStreamReference24(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 24H16v2h4v3h8V21H20zm2-1h4v4H22zM4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM24 5a3.9962 3.9962 0 00-3.8579 3H14v2h6.1421a3.94 3.94 0 00.4248 1.019L14 17.5862 15.4138 19l6.5672-6.5669A3.9521 3.9521 0 0024 13a4 4 0 000-8zm0 6a2 2 0 112-2A2.0023 2.0023 0 0124 11zM9.6929 12.7505a5 5 0 01-.0005-7.5L11.0166 6.75a3 3 0 00-.0005 4.501z"
  })), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.0474,15.751a9,9,0,0,1,0-13.501l1.3232,1.5a7,7,0,0,0,0,10.501Z"
  })), children);
});
var FlowStreamReference20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowStreamReference20(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 24H16v2h4v3h8V21H20zm2-1h4v4H22zM4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM24 5a3.9962 3.9962 0 00-3.8579 3H14v2h6.1421a3.94 3.94 0 00.4248 1.019L14 17.5862 15.4138 19l6.5672-6.5669A3.9521 3.9521 0 0024 13a4 4 0 000-8zm0 6a2 2 0 112-2A2.0023 2.0023 0 0124 11zM9.6929 12.7505a5 5 0 01-.0005-7.5L11.0166 6.75a3 3 0 00-.0005 4.501z"
  })), _path390 || (_path390 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.0474,15.751a9,9,0,0,1,0-13.501l1.3232,1.5a7,7,0,0,0,0,10.501Z"
  })), children);
});
var FlowStreamReference16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowStreamReference16(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path391 || (_path391 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 24H16v2h4v3h8V21H20zm2-1h4v4H22zM4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM24 5a3.9962 3.9962 0 00-3.8579 3H14v2h6.1421a3.94 3.94 0 00.4248 1.019L14 17.5862 15.4138 19l6.5672-6.5669A3.9521 3.9521 0 0024 13a4 4 0 000-8zm0 6a2 2 0 112-2A2.0023 2.0023 0 0124 11zM9.6929 12.7505a5 5 0 01-.0005-7.5L11.0166 6.75a3 3 0 00-.0005 4.501z"
  })), _path392 || (_path392 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.0474,15.751a9,9,0,0,1,0-13.501l1.3232,1.5a7,7,0,0,0,0,10.501Z"
  })), children);
});
var FlowLogsVpc32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowLogsVpc32(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path393 || (_path393 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 19H30V21H18zM18 23H30V25H18zM18 27H26V29H18z"
  })), _path394 || (_path394 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,4a3.9962,3.9962,0,0,0-3.8579,3H12V4H4v8h8V9h8.1421a3.94,3.94,0,0,0,.4248,1.019L10.019,20.5669A3.9521,3.9521,0,0,0,8,20a4,4,0,1,0,3.8579,5H16V23H11.8579a3.94,3.94,0,0,0-.4248-1.019L21.981,11.4331A3.9521,3.9521,0,0,0,24,12a4,4,0,0,0,0-8ZM10,10H6V6h4ZM8,26a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,8,26ZM24,10a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,24,10Z"
  })), children);
});
var FlowLogsVpc24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowLogsVpc24(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path395 || (_path395 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 19H30V21H18zM18 23H30V25H18zM18 27H26V29H18z"
  })), _path396 || (_path396 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,4a3.9962,3.9962,0,0,0-3.8579,3H12V4H4v8h8V9h8.1421a3.94,3.94,0,0,0,.4248,1.019L10.019,20.5669A3.9521,3.9521,0,0,0,8,20a4,4,0,1,0,3.8579,5H16V23H11.8579a3.94,3.94,0,0,0-.4248-1.019L21.981,11.4331A3.9521,3.9521,0,0,0,24,12a4,4,0,0,0,0-8ZM10,10H6V6h4ZM8,26a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,8,26ZM24,10a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,24,10Z"
  })), children);
});
var FlowLogsVpc20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowLogsVpc20(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path397 || (_path397 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 19H30V21H18zM18 23H30V25H18zM18 27H26V29H18z"
  })), _path398 || (_path398 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,4a3.9962,3.9962,0,0,0-3.8579,3H12V4H4v8h8V9h8.1421a3.94,3.94,0,0,0,.4248,1.019L10.019,20.5669A3.9521,3.9521,0,0,0,8,20a4,4,0,1,0,3.8579,5H16V23H11.8579a3.94,3.94,0,0,0-.4248-1.019L21.981,11.4331A3.9521,3.9521,0,0,0,24,12a4,4,0,0,0,0-8ZM10,10H6V6h4ZM8,26a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,8,26ZM24,10a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,24,10Z"
  })), children);
});
var FlowLogsVpc16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function FlowLogsVpc16(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path399 || (_path399 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 19H30V21H18zM18 23H30V25H18zM18 27H26V29H18z"
  })), _path400 || (_path400 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,4a3.9962,3.9962,0,0,0-3.8579,3H12V4H4v8h8V9h8.1421a3.94,3.94,0,0,0,.4248,1.019L10.019,20.5669A3.9521,3.9521,0,0,0,8,20a4,4,0,1,0,3.8579,5H16V23H11.8579a3.94,3.94,0,0,0-.4248-1.019L21.981,11.4331A3.9521,3.9521,0,0,0,24,12a4,4,0,0,0,0-8ZM10,10H6V6h4ZM8,26a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,8,26ZM24,10a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,24,10Z"
  })), children);
});
var Fog32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Fog32(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path401 || (_path401 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,11.1382a8.9938,8.9938,0,0,0-17.6006,0A6.533,6.533,0,0,0,2,17.5H2V19a1,1,0,0,0,1,1H15a1,1,0,0,0,0-2H4v-.4966H4a4.5176,4.5176,0,0,1,4.144-4.4819l.8155-.064.0991-.812a6.9936,6.9936,0,0,1,13.8838,0l.0986.812.8154.064A4.4962,4.4962,0,0,1,23.5,22H7a1,1,0,0,0,0,2H23.5a6.4963,6.4963,0,0,0,1.3008-12.8618Z"
  })), _rect || (_rect = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("rect", {
    width: "18",
    height: "2",
    x: "2",
    y: "26",
    rx: "1"
  })), children);
});
var Fog24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Fog24(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path402 || (_path402 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,11.1382a8.9938,8.9938,0,0,0-17.6006,0A6.533,6.533,0,0,0,2,17.5H2V19a1,1,0,0,0,1,1H15a1,1,0,0,0,0-2H4v-.4966H4a4.5176,4.5176,0,0,1,4.144-4.4819l.8155-.064.0991-.812a6.9936,6.9936,0,0,1,13.8838,0l.0986.812.8154.064A4.4962,4.4962,0,0,1,23.5,22H7a1,1,0,0,0,0,2H23.5a6.4963,6.4963,0,0,0,1.3008-12.8618Z"
  })), _rect2 || (_rect2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("rect", {
    width: "18",
    height: "2",
    x: "2",
    y: "26",
    rx: "1"
  })), children);
});
var Fog20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Fog20(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path403 || (_path403 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,11.1382a8.9938,8.9938,0,0,0-17.6006,0A6.533,6.533,0,0,0,2,17.5H2V19a1,1,0,0,0,1,1H15a1,1,0,0,0,0-2H4v-.4966H4a4.5176,4.5176,0,0,1,4.144-4.4819l.8155-.064.0991-.812a6.9936,6.9936,0,0,1,13.8838,0l.0986.812.8154.064A4.4962,4.4962,0,0,1,23.5,22H7a1,1,0,0,0,0,2H23.5a6.4963,6.4963,0,0,0,1.3008-12.8618Z"
  })), _rect3 || (_rect3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("rect", {
    width: "18",
    height: "2",
    x: "2",
    y: "26",
    rx: "1"
  })), children);
});
var Fog16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Fog16(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path404 || (_path404 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,11.1382a8.9938,8.9938,0,0,0-17.6006,0A6.533,6.533,0,0,0,2,17.5H2V19a1,1,0,0,0,1,1H15a1,1,0,0,0,0-2H4v-.4966H4a4.5176,4.5176,0,0,1,4.144-4.4819l.8155-.064.0991-.812a6.9936,6.9936,0,0,1,13.8838,0l.0986.812.8154.064A4.4962,4.4962,0,0,1,23.5,22H7a1,1,0,0,0,0,2H23.5a6.4963,6.4963,0,0,0,1.3008-12.8618Z"
  })), _rect4 || (_rect4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("rect", {
    width: "18",
    height: "2",
    x: "2",
    y: "26",
    rx: "1"
  })), children);
});
var Folder32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Folder32(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path405 || (_path405 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.17,6l3.42,3.41.58.59H28V26H4V6h7.17m0-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V10a2,2,0,0,0-2-2H16L12.59,4.59A2,2,0,0,0,11.17,4Z"
  })), children);
});
var Folder24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Folder24(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path406 || (_path406 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.17,6l3.42,3.41.58.59H28V26H4V6h7.17m0-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V10a2,2,0,0,0-2-2H16L12.59,4.59A2,2,0,0,0,11.17,4Z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-14.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-14.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "IdManagement16": () => (/* binding */ IdManagement16),
/* harmony export */   "IdManagement20": () => (/* binding */ IdManagement20),
/* harmony export */   "Idea16": () => (/* binding */ Idea16),
/* harmony export */   "Idea20": () => (/* binding */ Idea20),
/* harmony export */   "Idea24": () => (/* binding */ Idea24),
/* harmony export */   "Idea32": () => (/* binding */ Idea32),
/* harmony export */   "Identification16": () => (/* binding */ Identification16),
/* harmony export */   "Identification20": () => (/* binding */ Identification20),
/* harmony export */   "Identification24": () => (/* binding */ Identification24),
/* harmony export */   "Identification32": () => (/* binding */ Identification32),
/* harmony export */   "Image16": () => (/* binding */ Image16),
/* harmony export */   "Image20": () => (/* binding */ Image20),
/* harmony export */   "Image24": () => (/* binding */ Image24),
/* harmony export */   "Image32": () => (/* binding */ Image32),
/* harmony export */   "ImageCopy16": () => (/* binding */ ImageCopy16),
/* harmony export */   "ImageCopy20": () => (/* binding */ ImageCopy20),
/* harmony export */   "ImageCopy24": () => (/* binding */ ImageCopy24),
/* harmony export */   "ImageCopy32": () => (/* binding */ ImageCopy32),
/* harmony export */   "ImageMedical16": () => (/* binding */ ImageMedical16),
/* harmony export */   "ImageMedical20": () => (/* binding */ ImageMedical20),
/* harmony export */   "ImageMedical24": () => (/* binding */ ImageMedical24),
/* harmony export */   "ImageMedical32": () => (/* binding */ ImageMedical32),
/* harmony export */   "ImageReference16": () => (/* binding */ ImageReference16),
/* harmony export */   "ImageReference20": () => (/* binding */ ImageReference20),
/* harmony export */   "ImageReference24": () => (/* binding */ ImageReference24),
/* harmony export */   "ImageReference32": () => (/* binding */ ImageReference32),
/* harmony export */   "ImageSearch16": () => (/* binding */ ImageSearch16),
/* harmony export */   "ImageSearch20": () => (/* binding */ ImageSearch20),
/* harmony export */   "ImageSearch24": () => (/* binding */ ImageSearch24),
/* harmony export */   "ImageSearch32": () => (/* binding */ ImageSearch32),
/* harmony export */   "ImageSearchAlt16": () => (/* binding */ ImageSearchAlt16),
/* harmony export */   "ImageSearchAlt20": () => (/* binding */ ImageSearchAlt20),
/* harmony export */   "ImageSearchAlt24": () => (/* binding */ ImageSearchAlt24),
/* harmony export */   "ImageSearchAlt32": () => (/* binding */ ImageSearchAlt32),
/* harmony export */   "ImageService16": () => (/* binding */ ImageService16),
/* harmony export */   "ImageService20": () => (/* binding */ ImageService20),
/* harmony export */   "ImageService24": () => (/* binding */ ImageService24),
/* harmony export */   "ImageService32": () => (/* binding */ ImageService32),
/* harmony export */   "ImportExport16": () => (/* binding */ ImportExport16),
/* harmony export */   "ImportExport20": () => (/* binding */ ImportExport20),
/* harmony export */   "ImportExport24": () => (/* binding */ ImportExport24),
/* harmony export */   "ImportExport32": () => (/* binding */ ImportExport32),
/* harmony export */   "ImproveRelevance16": () => (/* binding */ ImproveRelevance16),
/* harmony export */   "ImproveRelevance20": () => (/* binding */ ImproveRelevance20),
/* harmony export */   "ImproveRelevance24": () => (/* binding */ ImproveRelevance24),
/* harmony export */   "ImproveRelevance32": () => (/* binding */ ImproveRelevance32),
/* harmony export */   "InProgress16": () => (/* binding */ InProgress16),
/* harmony export */   "InProgress20": () => (/* binding */ InProgress20),
/* harmony export */   "InProgress24": () => (/* binding */ InProgress24),
/* harmony export */   "InProgress32": () => (/* binding */ InProgress32),
/* harmony export */   "InProgressError16": () => (/* binding */ InProgressError16),
/* harmony export */   "InProgressError20": () => (/* binding */ InProgressError20),
/* harmony export */   "InProgressError24": () => (/* binding */ InProgressError24),
/* harmony export */   "InProgressError32": () => (/* binding */ InProgressError32),
/* harmony export */   "InProgressWarning16": () => (/* binding */ InProgressWarning16),
/* harmony export */   "InProgressWarning20": () => (/* binding */ InProgressWarning20),
/* harmony export */   "InProgressWarning24": () => (/* binding */ InProgressWarning24),
/* harmony export */   "InProgressWarning32": () => (/* binding */ InProgressWarning32),
/* harmony export */   "Incomplete16": () => (/* binding */ Incomplete16),
/* harmony export */   "Incomplete20": () => (/* binding */ Incomplete20),
/* harmony export */   "Incomplete24": () => (/* binding */ Incomplete24),
/* harmony export */   "Incomplete32": () => (/* binding */ Incomplete32),
/* harmony export */   "IncompleteCancel16": () => (/* binding */ IncompleteCancel16),
/* harmony export */   "IncompleteCancel20": () => (/* binding */ IncompleteCancel20),
/* harmony export */   "IncompleteCancel24": () => (/* binding */ IncompleteCancel24),
/* harmony export */   "IncompleteCancel32": () => (/* binding */ IncompleteCancel32),
/* harmony export */   "IncompleteError16": () => (/* binding */ IncompleteError16),
/* harmony export */   "IncompleteError20": () => (/* binding */ IncompleteError20),
/* harmony export */   "IncompleteError24": () => (/* binding */ IncompleteError24),
/* harmony export */   "IncompleteError32": () => (/* binding */ IncompleteError32),
/* harmony export */   "IncompleteGlyph": () => (/* binding */ IncompleteGlyph),
/* harmony export */   "IncompleteWarning16": () => (/* binding */ IncompleteWarning16),
/* harmony export */   "IncompleteWarning20": () => (/* binding */ IncompleteWarning20),
/* harmony export */   "IncompleteWarning24": () => (/* binding */ IncompleteWarning24),
/* harmony export */   "IncompleteWarning32": () => (/* binding */ IncompleteWarning32),
/* harmony export */   "IncreaseLevel16": () => (/* binding */ IncreaseLevel16),
/* harmony export */   "IncreaseLevel20": () => (/* binding */ IncreaseLevel20),
/* harmony export */   "IncreaseLevel24": () => (/* binding */ IncreaseLevel24),
/* harmony export */   "IncreaseLevel32": () => (/* binding */ IncreaseLevel32),
/* harmony export */   "Industry16": () => (/* binding */ Industry16),
/* harmony export */   "Industry20": () => (/* binding */ Industry20),
/* harmony export */   "Industry24": () => (/* binding */ Industry24),
/* harmony export */   "Industry32": () => (/* binding */ Industry32),
/* harmony export */   "Information16": () => (/* binding */ Information16),
/* harmony export */   "Information20": () => (/* binding */ Information20),
/* harmony export */   "Information24": () => (/* binding */ Information24),
/* harmony export */   "Information32": () => (/* binding */ Information32),
/* harmony export */   "InformationDisabled16": () => (/* binding */ InformationDisabled16),
/* harmony export */   "InformationDisabled20": () => (/* binding */ InformationDisabled20),
/* harmony export */   "InformationDisabled24": () => (/* binding */ InformationDisabled24),
/* harmony export */   "InformationDisabled32": () => (/* binding */ InformationDisabled32),
/* harmony export */   "InformationFilled16": () => (/* binding */ InformationFilled16),
/* harmony export */   "InformationFilled20": () => (/* binding */ InformationFilled20),
/* harmony export */   "InformationFilled24": () => (/* binding */ InformationFilled24),
/* harmony export */   "InformationFilled32": () => (/* binding */ InformationFilled32),
/* harmony export */   "InformationSquare16": () => (/* binding */ InformationSquare16),
/* harmony export */   "InformationSquare20": () => (/* binding */ InformationSquare20),
/* harmony export */   "InformationSquare24": () => (/* binding */ InformationSquare24),
/* harmony export */   "InformationSquare32": () => (/* binding */ InformationSquare32),
/* harmony export */   "InformationSquareFilled16": () => (/* binding */ InformationSquareFilled16),
/* harmony export */   "InformationSquareFilled20": () => (/* binding */ InformationSquareFilled20),
/* harmony export */   "InformationSquareFilled24": () => (/* binding */ InformationSquareFilled24),
/* harmony export */   "InformationSquareFilled32": () => (/* binding */ InformationSquareFilled32),
/* harmony export */   "InfrastructureClassic16": () => (/* binding */ InfrastructureClassic16),
/* harmony export */   "InfrastructureClassic20": () => (/* binding */ InfrastructureClassic20),
/* harmony export */   "InfrastructureClassic24": () => (/* binding */ InfrastructureClassic24),
/* harmony export */   "InfrastructureClassic32": () => (/* binding */ InfrastructureClassic32),
/* harmony export */   "Insert16": () => (/* binding */ Insert16),
/* harmony export */   "Insert20": () => (/* binding */ Insert20),
/* harmony export */   "Insert24": () => (/* binding */ Insert24),
/* harmony export */   "Insert32": () => (/* binding */ Insert32),
/* harmony export */   "InsertPage16": () => (/* binding */ InsertPage16),
/* harmony export */   "InsertPage20": () => (/* binding */ InsertPage20),
/* harmony export */   "InsertPage24": () => (/* binding */ InsertPage24),
/* harmony export */   "InsertPage32": () => (/* binding */ InsertPage32),
/* harmony export */   "InsertSyntax16": () => (/* binding */ InsertSyntax16),
/* harmony export */   "InsertSyntax20": () => (/* binding */ InsertSyntax20),
/* harmony export */   "InsertSyntax24": () => (/* binding */ InsertSyntax24),
/* harmony export */   "InsertSyntax32": () => (/* binding */ InsertSyntax32),
/* harmony export */   "Inspection16": () => (/* binding */ Inspection16),
/* harmony export */   "Inspection20": () => (/* binding */ Inspection20),
/* harmony export */   "Inspection24": () => (/* binding */ Inspection24),
/* harmony export */   "Inspection32": () => (/* binding */ Inspection32),
/* harmony export */   "InstanceBx16": () => (/* binding */ InstanceBx16),
/* harmony export */   "InstanceBx20": () => (/* binding */ InstanceBx20),
/* harmony export */   "InstanceBx24": () => (/* binding */ InstanceBx24),
/* harmony export */   "InstanceBx32": () => (/* binding */ InstanceBx32),
/* harmony export */   "InstanceClassic16": () => (/* binding */ InstanceClassic16),
/* harmony export */   "InstanceClassic20": () => (/* binding */ InstanceClassic20),
/* harmony export */   "InstanceClassic24": () => (/* binding */ InstanceClassic24),
/* harmony export */   "InstanceClassic32": () => (/* binding */ InstanceClassic32),
/* harmony export */   "InstanceCx16": () => (/* binding */ InstanceCx16),
/* harmony export */   "InstanceCx20": () => (/* binding */ InstanceCx20),
/* harmony export */   "InstanceCx24": () => (/* binding */ InstanceCx24),
/* harmony export */   "InstanceCx32": () => (/* binding */ InstanceCx32),
/* harmony export */   "InstanceMx16": () => (/* binding */ InstanceMx16),
/* harmony export */   "InstanceMx20": () => (/* binding */ InstanceMx20),
/* harmony export */   "InstanceMx24": () => (/* binding */ InstanceMx24),
/* harmony export */   "InstanceMx32": () => (/* binding */ InstanceMx32),
/* harmony export */   "InstanceVirtual16": () => (/* binding */ InstanceVirtual16),
/* harmony export */   "InstanceVirtual20": () => (/* binding */ InstanceVirtual20),
/* harmony export */   "InstanceVirtual24": () => (/* binding */ InstanceVirtual24),
/* harmony export */   "InstanceVirtual32": () => (/* binding */ InstanceVirtual32),
/* harmony export */   "Integration16": () => (/* binding */ Integration16),
/* harmony export */   "Integration20": () => (/* binding */ Integration20),
/* harmony export */   "Integration24": () => (/* binding */ Integration24),
/* harmony export */   "Integration32": () => (/* binding */ Integration32),
/* harmony export */   "IntentRequestActive16": () => (/* binding */ IntentRequestActive16),
/* harmony export */   "IntentRequestActive20": () => (/* binding */ IntentRequestActive20),
/* harmony export */   "IntentRequestActive24": () => (/* binding */ IntentRequestActive24),
/* harmony export */   "IntentRequestActive32": () => (/* binding */ IntentRequestActive32),
/* harmony export */   "IntentRequestCreate16": () => (/* binding */ IntentRequestCreate16),
/* harmony export */   "IntentRequestCreate20": () => (/* binding */ IntentRequestCreate20),
/* harmony export */   "IntentRequestCreate24": () => (/* binding */ IntentRequestCreate24),
/* harmony export */   "IntentRequestCreate32": () => (/* binding */ IntentRequestCreate32),
/* harmony export */   "IntentRequestHeal16": () => (/* binding */ IntentRequestHeal16),
/* harmony export */   "IntentRequestHeal20": () => (/* binding */ IntentRequestHeal20),
/* harmony export */   "IntentRequestHeal24": () => (/* binding */ IntentRequestHeal24),
/* harmony export */   "IntentRequestHeal32": () => (/* binding */ IntentRequestHeal32),
/* harmony export */   "IntentRequestInactive16": () => (/* binding */ IntentRequestInactive16),
/* harmony export */   "IntentRequestInactive20": () => (/* binding */ IntentRequestInactive20),
/* harmony export */   "IntentRequestInactive24": () => (/* binding */ IntentRequestInactive24),
/* harmony export */   "IntentRequestInactive32": () => (/* binding */ IntentRequestInactive32),
/* harmony export */   "IntentRequestScaleIn16": () => (/* binding */ IntentRequestScaleIn16),
/* harmony export */   "IntentRequestScaleIn20": () => (/* binding */ IntentRequestScaleIn20),
/* harmony export */   "IntentRequestScaleIn24": () => (/* binding */ IntentRequestScaleIn24),
/* harmony export */   "IntentRequestScaleIn32": () => (/* binding */ IntentRequestScaleIn32),
/* harmony export */   "IntentRequestScaleOut16": () => (/* binding */ IntentRequestScaleOut16),
/* harmony export */   "IntentRequestScaleOut20": () => (/* binding */ IntentRequestScaleOut20),
/* harmony export */   "IntentRequestScaleOut24": () => (/* binding */ IntentRequestScaleOut24),
/* harmony export */   "IntentRequestScaleOut32": () => (/* binding */ IntentRequestScaleOut32),
/* harmony export */   "IntentRequestUninstall16": () => (/* binding */ IntentRequestUninstall16),
/* harmony export */   "IntentRequestUninstall20": () => (/* binding */ IntentRequestUninstall20),
/* harmony export */   "IntentRequestUninstall24": () => (/* binding */ IntentRequestUninstall24),
/* harmony export */   "IntentRequestUninstall32": () => (/* binding */ IntentRequestUninstall32),
/* harmony export */   "IntentRequestUpgrade16": () => (/* binding */ IntentRequestUpgrade16),
/* harmony export */   "IntentRequestUpgrade20": () => (/* binding */ IntentRequestUpgrade20),
/* harmony export */   "IntentRequestUpgrade24": () => (/* binding */ IntentRequestUpgrade24),
/* harmony export */   "IntentRequestUpgrade32": () => (/* binding */ IntentRequestUpgrade32),
/* harmony export */   "Interactions16": () => (/* binding */ Interactions16),
/* harmony export */   "Interactions20": () => (/* binding */ Interactions20),
/* harmony export */   "Interactions24": () => (/* binding */ Interactions24),
/* harmony export */   "Interactions32": () => (/* binding */ Interactions32),
/* harmony export */   "Intersect16": () => (/* binding */ Intersect16),
/* harmony export */   "Intersect20": () => (/* binding */ Intersect20),
/* harmony export */   "Intersect24": () => (/* binding */ Intersect24),
/* harmony export */   "Intersect32": () => (/* binding */ Intersect32),
/* harmony export */   "IntrusionPrevention16": () => (/* binding */ IntrusionPrevention16),
/* harmony export */   "IntrusionPrevention20": () => (/* binding */ IntrusionPrevention20),
/* harmony export */   "IntrusionPrevention24": () => (/* binding */ IntrusionPrevention24),
/* harmony export */   "IntrusionPrevention32": () => (/* binding */ IntrusionPrevention32),
/* harmony export */   "InventoryManagement16": () => (/* binding */ InventoryManagement16),
/* harmony export */   "InventoryManagement20": () => (/* binding */ InventoryManagement20),
/* harmony export */   "InventoryManagement24": () => (/* binding */ InventoryManagement24),
/* harmony export */   "InventoryManagement32": () => (/* binding */ InventoryManagement32),
/* harmony export */   "IotConnect16": () => (/* binding */ IotConnect16),
/* harmony export */   "IotConnect20": () => (/* binding */ IotConnect20),
/* harmony export */   "IotConnect24": () => (/* binding */ IotConnect24),
/* harmony export */   "IotConnect32": () => (/* binding */ IotConnect32),
/* harmony export */   "IotPlatform16": () => (/* binding */ IotPlatform16),
/* harmony export */   "IotPlatform20": () => (/* binding */ IotPlatform20),
/* harmony export */   "IotPlatform24": () => (/* binding */ IotPlatform24),
/* harmony export */   "IotPlatform32": () => (/* binding */ IotPlatform32),
/* harmony export */   "Iso16": () => (/* binding */ Iso16),
/* harmony export */   "Iso20": () => (/* binding */ Iso20),
/* harmony export */   "Iso24": () => (/* binding */ Iso24),
/* harmony export */   "Iso32": () => (/* binding */ Iso32),
/* harmony export */   "IsoFilled16": () => (/* binding */ IsoFilled16),
/* harmony export */   "IsoFilled20": () => (/* binding */ IsoFilled20),
/* harmony export */   "IsoFilled24": () => (/* binding */ IsoFilled24),
/* harmony export */   "IsoFilled32": () => (/* binding */ IsoFilled32),
/* harmony export */   "IsoOutline16": () => (/* binding */ IsoOutline16),
/* harmony export */   "IsoOutline20": () => (/* binding */ IsoOutline20),
/* harmony export */   "IsoOutline24": () => (/* binding */ IsoOutline24),
/* harmony export */   "IsoOutline32": () => (/* binding */ IsoOutline32),
/* harmony export */   "JoinFull16": () => (/* binding */ JoinFull16),
/* harmony export */   "JoinFull20": () => (/* binding */ JoinFull20),
/* harmony export */   "JoinFull24": () => (/* binding */ JoinFull24),
/* harmony export */   "JoinFull32": () => (/* binding */ JoinFull32),
/* harmony export */   "JoinInner16": () => (/* binding */ JoinInner16),
/* harmony export */   "JoinInner20": () => (/* binding */ JoinInner20),
/* harmony export */   "JoinInner24": () => (/* binding */ JoinInner24),
/* harmony export */   "JoinInner32": () => (/* binding */ JoinInner32),
/* harmony export */   "JoinLeft16": () => (/* binding */ JoinLeft16),
/* harmony export */   "JoinLeft20": () => (/* binding */ JoinLeft20),
/* harmony export */   "JoinLeft24": () => (/* binding */ JoinLeft24),
/* harmony export */   "JoinLeft32": () => (/* binding */ JoinLeft32),
/* harmony export */   "JoinOuter16": () => (/* binding */ JoinOuter16),
/* harmony export */   "JoinOuter20": () => (/* binding */ JoinOuter20),
/* harmony export */   "JoinOuter24": () => (/* binding */ JoinOuter24),
/* harmony export */   "JoinOuter32": () => (/* binding */ JoinOuter32),
/* harmony export */   "JoinRight16": () => (/* binding */ JoinRight16),
/* harmony export */   "JoinRight20": () => (/* binding */ JoinRight20),
/* harmony export */   "JoinRight24": () => (/* binding */ JoinRight24),
/* harmony export */   "JoinRight32": () => (/* binding */ JoinRight32),
/* harmony export */   "Jpg16": () => (/* binding */ Jpg16),
/* harmony export */   "Jpg20": () => (/* binding */ Jpg20),
/* harmony export */   "Jpg24": () => (/* binding */ Jpg24),
/* harmony export */   "Jpg32": () => (/* binding */ Jpg32),
/* harmony export */   "Json16": () => (/* binding */ Json16),
/* harmony export */   "Json20": () => (/* binding */ Json20),
/* harmony export */   "Json24": () => (/* binding */ Json24),
/* harmony export */   "Json32": () => (/* binding */ Json32),
/* harmony export */   "JsonReference20": () => (/* binding */ JsonReference20),
/* harmony export */   "JsonReference24": () => (/* binding */ JsonReference24),
/* harmony export */   "JsonReference32": () => (/* binding */ JsonReference32),
/* harmony export */   "WatsonHealthInteractiveSegmentationCursor16": () => (/* binding */ WatsonHealthInteractiveSegmentationCursor16),
/* harmony export */   "WatsonHealthInteractiveSegmentationCursor20": () => (/* binding */ WatsonHealthInteractiveSegmentationCursor20),
/* harmony export */   "WatsonHealthInteractiveSegmentationCursor24": () => (/* binding */ WatsonHealthInteractiveSegmentationCursor24),
/* harmony export */   "WatsonHealthInteractiveSegmentationCursor32": () => (/* binding */ WatsonHealthInteractiveSegmentationCursor32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _path65, _path66, _path67, _circle, _path68, _path69, _circle2, _path70, _path71, _circle3, _path72, _path73, _circle4, _path74, _path75, _path76, _path77, _path78, _path79, _circle5, _path80, _path81, _path82, _circle6, _path83, _path84, _path85, _circle7, _path86, _path87, _path88, _circle8, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _circle9, _path209, _path210, _circle10, _path211, _path212, _circle11, _path213, _path214, _circle12, _path215, _path216, _circle13, _path217, _path218, _circle14, _path219, _path220, _circle15, _path221, _path222, _circle16, _path223, _circle17, _path224, _circle18, _path225, _circle19, _path226, _circle20, _path227, _path228, _circle21, _path229, _path230, _circle22, _path231, _path232, _circle23, _path233, _path234, _circle24, _path235, _circle25, _path236, _circle26, _path237, _circle27, _path238, _circle28, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _circle29, _circle30, _circle31, _path268, _circle32, _circle33, _circle34, _path269, _circle35, _circle36, _circle37, _path270, _circle38, _circle39, _circle40, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _circle41, _path328, _path329, _circle42, _path330, _path331, _circle43, _path332, _path333, _circle44, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388, _path389, _path390, _path391, _path392, _path393, _path394, _path395, _path396, _path397, _path398, _path399, _path400, _path401, _path402, _path403, _path404, _path405, _path406, _path407, _path408, _path409, _path410, _path411, _path412, _path413, _path414, _path415, _path416, _path417, _path418, _path419, _path420, _path421, _path422, _path423, _path424, _path425, _path426, _path427, _path428, _path429, _path430, _path431, _path432, _path433, _path434, _path435, _path436, _path437, _path438, _path439, _path440, _path441, _path442, _path443, _path444, _path445, _path446, _path447, _path448, _path449, _path450;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var IdManagement20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IdManagement20(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 20H9a3 3 0 00-3 3v2H8V23a1 1 0 011-1h6a1 1 0 011 1v2h2V23A3 3 0 0015 20zM12 19a4 4 0 10-4-4A4 4 0 0012 19zm0-6a2 2 0 11-2 2A2 2 0 0112 13z"
  })), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,19v9H4V8H16V6H4A2,2,0,0,0,2,8V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V19Z"
  })), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 19H26V21H20zM22 23H26V25H22zM32 10V8H29.8989a4.9678 4.9678 0 00-.7319-1.7529l1.49-1.49-1.414-1.414-1.49 1.49A4.9678 4.9678 0 0026 4.1011V2H24V4.1011a4.9678 4.9678 0 00-1.7529.7319l-1.49-1.49-1.414 1.414 1.49 1.49A4.9678 4.9678 0 0020.1011 8H18v2h2.1011a4.9678 4.9678 0 00.7319 1.7529l-1.49 1.49 1.414 1.414 1.49-1.49A4.9678 4.9678 0 0024 13.8989V16h2V13.8989a4.9678 4.9678 0 001.7529-.7319l1.49 1.49 1.414-1.414-1.49-1.49A4.9678 4.9678 0 0029.8989 10zm-7 2a3 3 0 113-3A3.0033 3.0033 0 0125 12z"
  })), children);
});
var IdManagement16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IdManagement16(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 20H9a3 3 0 00-3 3v2H8V23a1 1 0 011-1h6a1 1 0 011 1v2h2V23A3 3 0 0015 20zM12 19a4 4 0 10-4-4A4 4 0 0012 19zm0-6a2 2 0 11-2 2A2 2 0 0112 13z"
  })), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,19v9H4V8H16V6H4A2,2,0,0,0,2,8V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V19Z"
  })), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 19H26V21H20zM22 23H26V25H22zM32 10V8H29.8989a4.9678 4.9678 0 00-.7319-1.7529l1.49-1.49-1.414-1.414-1.49 1.49A4.9678 4.9678 0 0026 4.1011V2H24V4.1011a4.9678 4.9678 0 00-1.7529.7319l-1.49-1.49-1.414 1.414 1.49 1.49A4.9678 4.9678 0 0020.1011 8H18v2h2.1011a4.9678 4.9678 0 00.7319 1.7529l-1.49 1.49 1.414 1.414 1.49-1.49A4.9678 4.9678 0 0024 13.8989V16h2V13.8989a4.9678 4.9678 0 001.7529-.7319l1.49 1.49 1.414-1.414-1.49-1.49A4.9678 4.9678 0 0029.8989 10zm-7 2a3 3 0 113-3A3.0033 3.0033 0 0125 12z"
  })), children);
});
var Idea32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Idea32(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM16 2A10 10 0 006 12a9.19 9.19 0 003.46 7.62c1 .93 1.54 1.46 1.54 2.38h2c0-1.84-1.11-2.87-2.19-3.86A7.2 7.2 0 018 12a8 8 0 0116 0 7.2 7.2 0 01-2.82 6.14c-1.07 1-2.18 2-2.18 3.86h2c0-.92.53-1.45 1.54-2.39A9.18 9.18 0 0026 12 10 10 0 0016 2z"
  })), children);
});
var Idea24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Idea24(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM16 2A10 10 0 006 12a9.19 9.19 0 003.46 7.62c1 .93 1.54 1.46 1.54 2.38h2c0-1.84-1.11-2.87-2.19-3.86A7.2 7.2 0 018 12a8 8 0 0116 0 7.2 7.2 0 01-2.82 6.14c-1.07 1-2.18 2-2.18 3.86h2c0-.92.53-1.45 1.54-2.39A9.18 9.18 0 0026 12 10 10 0 0016 2z"
  })), children);
});
var Idea20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Idea20(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM16 2A10 10 0 006 12a9.19 9.19 0 003.46 7.62c1 .93 1.54 1.46 1.54 2.38h2c0-1.84-1.11-2.87-2.19-3.86A7.2 7.2 0 018 12a8 8 0 0116 0 7.2 7.2 0 01-2.82 6.14c-1.07 1-2.18 2-2.18 3.86h2c0-.92.53-1.45 1.54-2.39A9.18 9.18 0 0026 12 10 10 0 0016 2z"
  })), children);
});
var Idea16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Idea16(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H21V26H11zM13 28H19V30H13zM16 2A10 10 0 006 12a9.19 9.19 0 003.46 7.62c1 .93 1.54 1.46 1.54 2.38h2c0-1.84-1.11-2.87-2.19-3.86A7.2 7.2 0 018 12a8 8 0 0116 0 7.2 7.2 0 01-2.82 6.14c-1.07 1-2.18 2-2.18 3.86h2c0-.92.53-1.45 1.54-2.39A9.18 9.18 0 0026 12 10 10 0 0016 2z"
  })), children);
});
var Identification32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Identification32(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6V26H4V6H28m0-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6a2,2,0,0,0-2-2Z"
  })), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 10H13V12H6zM6 14H10V16H6zM23 18H17a3 3 0 00-3 3v2h2V21a1 1 0 011-1h6a1 1 0 011 1v2h2V21A3 3 0 0023 18zM20 17a4 4 0 10-4-4A4 4 0 0020 17zm0-6a2 2 0 11-2 2A2 2 0 0120 11z"
  })), children);
});
var Identification24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Identification24(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6V26H4V6H28m0-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6a2,2,0,0,0-2-2Z"
  })), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 10H13V12H6zM6 14H10V16H6zM23 18H17a3 3 0 00-3 3v2h2V21a1 1 0 011-1h6a1 1 0 011 1v2h2V21A3 3 0 0023 18zM20 17a4 4 0 10-4-4A4 4 0 0020 17zm0-6a2 2 0 11-2 2A2 2 0 0120 11z"
  })), children);
});
var Identification20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Identification20(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6V26H4V6H28m0-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6a2,2,0,0,0-2-2Z"
  })), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 10H13V12H6zM6 14H10V16H6zM23 18H17a3 3 0 00-3 3v2h2V21a1 1 0 011-1h6a1 1 0 011 1v2h2V21A3 3 0 0023 18zM20 17a4 4 0 10-4-4A4 4 0 0020 17zm0-6a2 2 0 11-2 2A2 2 0 0120 11z"
  })), children);
});
var Identification16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Identification16(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6V26H4V6H28m0-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6a2,2,0,0,0-2-2Z"
  })), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 10H13V12H6zM6 14H10V16H6zM23 18H17a3 3 0 00-3 3v2h2V21a1 1 0 011-1h6a1 1 0 011 1v2h2V21A3 3 0 0023 18zM20 17a4 4 0 10-4-4A4 4 0 0020 17zm0-6a2 2 0 11-2 2A2 2 0 0120 11z"
  })), children);
});
var Image32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Image32(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,14a3,3,0,1,0-3-3A3,3,0,0,0,19,14Zm0-4a1,1,0,1,1-1,1A1,1,0,0,1,19,10Z"
  })), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4Zm0,22H6V20l5-5,5.59,5.59a2,2,0,0,0,2.82,0L21,19l5,5Zm0-4.83-3.59-3.59a2,2,0,0,0-2.82,0L18,19.17l-5.59-5.59a2,2,0,0,0-2.82,0L6,17.17V6H26Z"
  })), children);
});
var Image24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Image24(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,14a3,3,0,1,0-3-3A3,3,0,0,0,19,14Zm0-4a1,1,0,1,1-1,1A1,1,0,0,1,19,10Z"
  })), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4Zm0,22H6V20l5-5,5.59,5.59a2,2,0,0,0,2.82,0L21,19l5,5Zm0-4.83-3.59-3.59a2,2,0,0,0-2.82,0L18,19.17l-5.59-5.59a2,2,0,0,0-2.82,0L6,17.17V6H26Z"
  })), children);
});
var Image20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Image20(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,14a3,3,0,1,0-3-3A3,3,0,0,0,19,14Zm0-4a1,1,0,1,1-1,1A1,1,0,0,1,19,10Z"
  })), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4Zm0,22H6V20l5-5,5.59,5.59a2,2,0,0,0,2.82,0L21,19l5,5Zm0-4.83-3.59-3.59a2,2,0,0,0-2.82,0L18,19.17l-5.59-5.59a2,2,0,0,0-2.82,0L6,17.17V6H26Z"
  })), children);
});
var Image16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Image16(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,14a3,3,0,1,0-3-3A3,3,0,0,0,19,14Zm0-4a1,1,0,1,1-1,1A1,1,0,0,1,19,10Z"
  })), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4Zm0,22H6V20l5-5,5.59,5.59a2,2,0,0,0,2.82,0L21,19l5,5Zm0-4.83-3.59-3.59a2,2,0,0,0-2.82,0L18,19.17l-5.59-5.59a2,2,0,0,0-2.82,0L6,17.17V6H26Z"
  })), children);
});
var ImageCopy32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageCopy32(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 22H2V4A2.0023 2.0023 0 014 2H22V4H4zM21 17a3 3 0 10-3-3A3.0033 3.0033 0 0021 17zm0-4a1 1 0 11-1 1A1.0009 1.0009 0 0121 13z"
  })), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,7H9A2.0025,2.0025,0,0,0,7,9V28a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V9A2.0025,2.0025,0,0,0,28,7Zm0,21H9v-6l4-3.9971,5.5859,5.586a2,2,0,0,0,2.8282,0L23,22.0034,28,27Zm0-3.8281-3.5859-3.586a2,2,0,0,0-2.8282,0L20,22.1719l-5.5859-5.586a2,2,0,0,0-2.8282,0L9,19.1719V9H28Z"
  })), children);
});
var ImageCopy24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageCopy24(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 22H2V4A2.0023 2.0023 0 014 2H22V4H4zM21 17a3 3 0 10-3-3A3.0033 3.0033 0 0021 17zm0-4a1 1 0 11-1 1A1.0009 1.0009 0 0121 13z"
  })), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,7H9A2.0025,2.0025,0,0,0,7,9V28a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V9A2.0025,2.0025,0,0,0,28,7Zm0,21H9v-6l4-3.9971,5.5859,5.586a2,2,0,0,0,2.8282,0L23,22.0034,28,27Zm0-3.8281-3.5859-3.586a2,2,0,0,0-2.8282,0L20,22.1719l-5.5859-5.586a2,2,0,0,0-2.8282,0L9,19.1719V9H28Z"
  })), children);
});
var ImageCopy20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageCopy20(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 22H2V4A2.0023 2.0023 0 014 2H22V4H4zM21 17a3 3 0 10-3-3A3.0033 3.0033 0 0021 17zm0-4a1 1 0 11-1 1A1.0009 1.0009 0 0121 13z"
  })), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,7H9A2.0025,2.0025,0,0,0,7,9V28a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V9A2.0025,2.0025,0,0,0,28,7Zm0,21H9v-6l4-3.9971,5.5859,5.586a2,2,0,0,0,2.8282,0L23,22.0034,28,27Zm0-3.8281-3.5859-3.586a2,2,0,0,0-2.8282,0L20,22.1719l-5.5859-5.586a2,2,0,0,0-2.8282,0L9,19.1719V9H28Z"
  })), children);
});
var ImageCopy16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageCopy16(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 22H2V4A2.0023 2.0023 0 014 2H22V4H4zM21 17a3 3 0 10-3-3A3.0033 3.0033 0 0021 17zm0-4a1 1 0 11-1 1A1.0009 1.0009 0 0121 13z"
  })), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,7H9A2.0025,2.0025,0,0,0,7,9V28a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V9A2.0025,2.0025,0,0,0,28,7Zm0,21H9v-6l4-3.9971,5.5859,5.586a2,2,0,0,0,2.8282,0L23,22.0034,28,27Zm0-3.8281-3.5859-3.586a2,2,0,0,0-2.8282,0L20,22.1719l-5.5859-5.586a2,2,0,0,0-2.8282,0L9,19.1719V9H28Z"
  })), children);
});
var ImageMedical32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageMedical32(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6V26H6V6H26m0-2H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6a2,2,0,0,0-2-2Z"
  })), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 16L22 14 17 14 17 12 20 12 20 10 17 10 17 8 15 8 15 10 12 10 12 12 15 12 15 14 10 14 10 16 15 16 15 18 10 18 10 20 15 20 15 22 12 22 12 24 20 24 20 22 17 22 17 20 22 20 22 18 17 18 17 16 22 16z"
  })), children);
});
var ImageMedical24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageMedical24(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6V26H6V6H26m0-2H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6a2,2,0,0,0-2-2Z"
  })), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 16L22 14 17 14 17 12 20 12 20 10 17 10 17 8 15 8 15 10 12 10 12 12 15 12 15 14 10 14 10 16 15 16 15 18 10 18 10 20 15 20 15 22 12 22 12 24 20 24 20 22 17 22 17 20 22 20 22 18 17 18 17 16 22 16z"
  })), children);
});
var ImageMedical20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageMedical20(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6V26H6V6H26m0-2H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6a2,2,0,0,0-2-2Z"
  })), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 16L22 14 17 14 17 12 20 12 20 10 17 10 17 8 15 8 15 10 12 10 12 12 15 12 15 14 10 14 10 16 15 16 15 18 10 18 10 20 15 20 15 22 12 22 12 24 20 24 20 22 17 22 17 20 22 20 22 18 17 18 17 16 22 16z"
  })), children);
});
var ImageMedical16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageMedical16(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6V26H6V6H26m0-2H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6a2,2,0,0,0-2-2Z"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 16L22 14 17 14 17 12 20 12 20 10 17 10 17 8 15 8 15 10 12 10 12 12 15 12 15 14 10 14 10 16 15 16 15 18 10 18 10 20 15 20 15 22 12 22 12 24 20 24 20 22 17 22 17 20 22 20 22 18 17 18 17 16 22 16z"
  })), children);
});
var ImageReference32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageReference32(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM19 14a3 3 0 10-3-3A3 3 0 0019 14zm0-4a1 1 0 11-1 1A1 1 0 0119 10z"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V16H6V6H26V21.17l-3.59-3.59a2,2,0,0,0-2.82,0L18,19.17,11.8308,13l-1.4151,1.4155L14,18l2.59,2.59a2,2,0,0,0,2.82,0L21,19l5,5v2H16v2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4Z"
  })), children);
});
var ImageReference24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageReference24(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM19 14a3 3 0 10-3-3A3 3 0 0019 14zm0-4a1 1 0 11-1 1A1 1 0 0119 10z"
  })), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V16H6V6H26V21.17l-3.59-3.59a2,2,0,0,0-2.82,0L18,19.17,11.8308,13l-1.4151,1.4155L14,18l2.59,2.59a2,2,0,0,0,2.82,0L21,19l5,5v2H16v2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4Z"
  })), children);
});
var ImageReference20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageReference20(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM19 14a3 3 0 10-3-3A3 3 0 0019 14zm0-4a1 1 0 11-1 1A1 1 0 0119 10z"
  })), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V16H6V6H26V21.17l-3.59-3.59a2,2,0,0,0-2.82,0L18,19.17,11.8308,13l-1.4151,1.4155L14,18l2.59,2.59a2,2,0,0,0,2.82,0L21,19l5,5v2H16v2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4Z"
  })), children);
});
var ImageReference16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageReference16(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM19 14a3 3 0 10-3-3A3 3 0 0019 14zm0-4a1 1 0 11-1 1A1 1 0 0119 10z"
  })), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V16H6V6H26V21.17l-3.59-3.59a2,2,0,0,0-2.82,0L18,19.17,11.8308,13l-1.4151,1.4155L14,18l2.59,2.59a2,2,0,0,0,2.82,0L21,19l5,5v2H16v2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4Z"
  })), children);
});
var ImageSearch32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageSearch32(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 14a5.99 5.99 0 00-4.885 9.4712L14 28.5859 15.4141 30l5.1147-5.1147A5.9971 5.9971 0 1024 14zm0 10a4 4 0 114-4A4.0045 4.0045 0 0124 24zM17 12a3 3 0 10-3-3A3.0033 3.0033 0 0017 12zm0-4a1 1 0 11-1 1A1.0009 1.0009 0 0117 8z"
  })), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,24H4V17.9966L9,13l5.5859,5.5859L16,17.168l-5.5859-5.5855a2,2,0,0,0-2.8282,0L4,15.168V4H24v6h2V4a2.0023,2.0023,0,0,0-2-2H4A2.002,2.002,0,0,0,2,4V24a2.0023,2.0023,0,0,0,2,2h8Z"
  })), children);
});
var ImageSearch24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageSearch24(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 14a5.99 5.99 0 00-4.885 9.4712L14 28.5859 15.4141 30l5.1147-5.1147A5.9971 5.9971 0 1024 14zm0 10a4 4 0 114-4A4.0045 4.0045 0 0124 24zM17 12a3 3 0 10-3-3A3.0033 3.0033 0 0017 12zm0-4a1 1 0 11-1 1A1.0009 1.0009 0 0117 8z"
  })), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,24H4V17.9966L9,13l5.5859,5.5859L16,17.168l-5.5859-5.5855a2,2,0,0,0-2.8282,0L4,15.168V4H24v6h2V4a2.0023,2.0023,0,0,0-2-2H4A2.002,2.002,0,0,0,2,4V24a2.0023,2.0023,0,0,0,2,2h8Z"
  })), children);
});
var ImageSearch20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageSearch20(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 14a5.99 5.99 0 00-4.885 9.4712L14 28.5859 15.4141 30l5.1147-5.1147A5.9971 5.9971 0 1024 14zm0 10a4 4 0 114-4A4.0045 4.0045 0 0124 24zM17 12a3 3 0 10-3-3A3.0033 3.0033 0 0017 12zm0-4a1 1 0 11-1 1A1.0009 1.0009 0 0117 8z"
  })), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,24H4V17.9966L9,13l5.5859,5.5859L16,17.168l-5.5859-5.5855a2,2,0,0,0-2.8282,0L4,15.168V4H24v6h2V4a2.0023,2.0023,0,0,0-2-2H4A2.002,2.002,0,0,0,2,4V24a2.0023,2.0023,0,0,0,2,2h8Z"
  })), children);
});
var ImageSearch16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageSearch16(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 14a5.99 5.99 0 00-4.885 9.4712L14 28.5859 15.4141 30l5.1147-5.1147A5.9971 5.9971 0 1024 14zm0 10a4 4 0 114-4A4.0045 4.0045 0 0124 24zM17 12a3 3 0 10-3-3A3.0033 3.0033 0 0017 12zm0-4a1 1 0 11-1 1A1.0009 1.0009 0 0117 8z"
  })), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,24H4V17.9966L9,13l5.5859,5.5859L16,17.168l-5.5859-5.5855a2,2,0,0,0-2.8282,0L4,15.168V4H24v6h2V4a2.0023,2.0023,0,0,0-2-2H4A2.002,2.002,0,0,0,2,4V24a2.0023,2.0023,0,0,0,2,2h8Z"
  })), children);
});
var ImageSearchAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageSearchAlt32(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,16a5.9908,5.9908,0,0,0,9.4712,4.8853L24.5859,26,26,24.5859l-5.115-5.1147A5.997,5.997,0,1,0,10,16Zm2,0a4,4,0,1,1,4,4A4.0045,4.0045,0,0,1,12,16Z"
  })), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,7H22.54L20.83,4.45A.9946.9946,0,0,0,20,4H12a.9946.9946,0,0,0-.83.45L9.46,7H3A1.0031,1.0031,0,0,0,2,8V25a1.0031,1.0031,0,0,0,1,1h9V24H4V9h6a.9946.9946,0,0,0,.83-.45L12.54,6h6.92l1.71,2.55A.9946.9946,0,0,0,22,9h6V21h2V8A1.0031,1.0031,0,0,0,29,7Z"
  })), children);
});
var ImageSearchAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageSearchAlt24(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,16a5.9908,5.9908,0,0,0,9.4712,4.8853L24.5859,26,26,24.5859l-5.115-5.1147A5.997,5.997,0,1,0,10,16Zm2,0a4,4,0,1,1,4,4A4.0045,4.0045,0,0,1,12,16Z"
  })), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,7H22.54L20.83,4.45A.9946.9946,0,0,0,20,4H12a.9946.9946,0,0,0-.83.45L9.46,7H3A1.0031,1.0031,0,0,0,2,8V25a1.0031,1.0031,0,0,0,1,1h9V24H4V9h6a.9946.9946,0,0,0,.83-.45L12.54,6h6.92l1.71,2.55A.9946.9946,0,0,0,22,9h6V21h2V8A1.0031,1.0031,0,0,0,29,7Z"
  })), children);
});
var ImageSearchAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageSearchAlt20(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,16a5.9908,5.9908,0,0,0,9.4712,4.8853L24.5859,26,26,24.5859l-5.115-5.1147A5.997,5.997,0,1,0,10,16Zm2,0a4,4,0,1,1,4,4A4.0045,4.0045,0,0,1,12,16Z"
  })), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,7H22.54L20.83,4.45A.9946.9946,0,0,0,20,4H12a.9946.9946,0,0,0-.83.45L9.46,7H3A1.0031,1.0031,0,0,0,2,8V25a1.0031,1.0031,0,0,0,1,1h9V24H4V9h6a.9946.9946,0,0,0,.83-.45L12.54,6h6.92l1.71,2.55A.9946.9946,0,0,0,22,9h6V21h2V8A1.0031,1.0031,0,0,0,29,7Z"
  })), children);
});
var ImageSearchAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageSearchAlt16(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,16a5.9908,5.9908,0,0,0,9.4712,4.8853L24.5859,26,26,24.5859l-5.115-5.1147A5.997,5.997,0,1,0,10,16Zm2,0a4,4,0,1,1,4,4A4.0045,4.0045,0,0,1,12,16Z"
  })), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,7H22.54L20.83,4.45A.9946.9946,0,0,0,20,4H12a.9946.9946,0,0,0-.83.45L9.46,7H3A1.0031,1.0031,0,0,0,2,8V25a1.0031,1.0031,0,0,0,1,1h9V24H4V9h6a.9946.9946,0,0,0,.83-.45L12.54,6h6.92l1.71,2.55A.9946.9946,0,0,0,22,9h6V21h2V8A1.0031,1.0031,0,0,0,29,7Z"
  })), children);
});
var ImageService32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageService32(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H6V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 4H15V12H13zM9 4H11V12H9zM21 12H19a2.0021 2.0021 0 01-2-2V6a2.0021 2.0021 0 012-2h2a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0121 12zM19 6v4h2V6zM21 14H23V22H21zM9 14H11V22H9zM17 22H15a2.0021 2.0021 0 01-2-2V16a2.0021 2.0021 0 012-2h2a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0117 22zm-2-6v4h2V16z"
  })), children);
});
var ImageService24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageService24(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H6V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 4H15V12H13zM9 4H11V12H9zM21 12H19a2.0021 2.0021 0 01-2-2V6a2.0021 2.0021 0 012-2h2a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0121 12zM19 6v4h2V6zM21 14H23V22H21zM9 14H11V22H9zM17 22H15a2.0021 2.0021 0 01-2-2V16a2.0021 2.0021 0 012-2h2a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0117 22zm-2-6v4h2V16z"
  })), children);
});
var ImageService20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageService20(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H6V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 4H15V12H13zM9 4H11V12H9zM21 12H19a2.0021 2.0021 0 01-2-2V6a2.0021 2.0021 0 012-2h2a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0121 12zM19 6v4h2V6zM21 14H23V22H21zM9 14H11V22H9zM17 22H15a2.0021 2.0021 0 01-2-2V16a2.0021 2.0021 0 012-2h2a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0117 22zm-2-6v4h2V16z"
  })), children);
});
var ImageService16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImageService16(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H6V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 4H15V12H13zM9 4H11V12H9zM21 12H19a2.0021 2.0021 0 01-2-2V6a2.0021 2.0021 0 012-2h2a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0121 12zM19 6v4h2V6zM21 14H23V22H21zM9 14H11V22H9zM17 22H15a2.0021 2.0021 0 01-2-2V16a2.0021 2.0021 0 012-2h2a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0117 22zm-2-6v4h2V16z"
  })), children);
});
var ImportExport32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImportExport32(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 24v4H4V24H2v4l.0076-.0049A1.9977 1.9977 0 004 30H28a2 2 0 002-2h0V24zM27.6 14.6L24 18.2 24 4 22 4 22 18.2 18.4 14.6 17 16 23 22 29 16 27.6 14.6zM9 4L3 10 4.4 11.4 8 7.8 8 22 10 22 10 7.8 13.6 11.4 15 10 9 4z"
  })), children);
});
var ImportExport24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImportExport24(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 24v4H4V24H2v4l.0076-.0049A1.9977 1.9977 0 004 30H28a2 2 0 002-2h0V24zM27.6 14.6L24 18.2 24 4 22 4 22 18.2 18.4 14.6 17 16 23 22 29 16 27.6 14.6zM9 4L3 10 4.4 11.4 8 7.8 8 22 10 22 10 7.8 13.6 11.4 15 10 9 4z"
  })), children);
});
var ImportExport20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImportExport20(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 24v4H4V24H2v4l.0076-.0049A1.9977 1.9977 0 004 30H28a2 2 0 002-2h0V24zM27.6 14.6L24 18.2 24 4 22 4 22 18.2 18.4 14.6 17 16 23 22 29 16 27.6 14.6zM9 4L3 10 4.4 11.4 8 7.8 8 22 10 22 10 7.8 13.6 11.4 15 10 9 4z"
  })), children);
});
var ImportExport16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImportExport16(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 24v4H4V24H2v4l.0076-.0049A1.9977 1.9977 0 004 30H28a2 2 0 002-2h0V24zM27.6 14.6L24 18.2 24 4 22 4 22 18.2 18.4 14.6 17 16 23 22 29 16 27.6 14.6zM9 4L3 10 4.4 11.4 8 7.8 8 22 10 22 10 7.8 13.6 11.4 15 10 9 4z"
  })), children);
});
var ImproveRelevance32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImproveRelevance32(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26.59L19.41 24 18 25.41 22 29.41 30 21.41 28.59 20 22 26.59z"
  })), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,16,22Zm0-10a4,4,0,1,0,4,4A4.0045,4.0045,0,0,0,16,12Z"
  })), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16A12,12,0,1,0,16,28V26A10,10,0,1,1,26,16Z"
  })), children);
});
var ImproveRelevance24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImproveRelevance24(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26.59L19.41 24 18 25.41 22 29.41 30 21.41 28.59 20 22 26.59z"
  })), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,16,22Zm0-10a4,4,0,1,0,4,4A4.0045,4.0045,0,0,0,16,12Z"
  })), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16A12,12,0,1,0,16,28V26A10,10,0,1,1,26,16Z"
  })), children);
});
var ImproveRelevance20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImproveRelevance20(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26.59L19.41 24 18 25.41 22 29.41 30 21.41 28.59 20 22 26.59z"
  })), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,16,22Zm0-10a4,4,0,1,0,4,4A4.0045,4.0045,0,0,0,16,12Z"
  })), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16A12,12,0,1,0,16,28V26A10,10,0,1,1,26,16Z"
  })), children);
});
var ImproveRelevance16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ImproveRelevance16(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26.59L19.41 24 18 25.41 22 29.41 30 21.41 28.59 20 22 26.59z"
  })), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,16,22Zm0-10a4,4,0,1,0,4,4A4.0045,4.0045,0,0,0,16,12Z"
  })), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16A12,12,0,1,0,16,28V26A10,10,0,1,1,26,16Z"
  })), children);
});
var InProgress32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InProgress32(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2Zm0,26A12,12,0,0,1,16,4V16l8.4812,8.4814A11.9625,11.9625,0,0,1,16,28Z"
  })), children);
});
var InProgress24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InProgress24(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2Zm0,26A12,12,0,0,1,16,4V16l8.4812,8.4814A11.9625,11.9625,0,0,1,16,28Z"
  })), children);
});
var InProgress20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InProgress20(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2Zm0,26A12,12,0,0,1,16,4V16l8.4812,8.4814A11.9625,11.9625,0,0,1,16,28Z"
  })), children);
});
var InProgress16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InProgress16(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2Zm0,26A12,12,0,0,1,16,4V16l8.4812,8.4814A11.9625,11.9625,0,0,1,16,28Z"
  })), children);
});
var InProgressError32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InProgressError32(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,24a6,6,0,1,0-6,6A6.0066,6.0066,0,0,0,30,24Zm-2,0a3.9521,3.9521,0,0,1-.5669,2.019L21.981,20.5669A3.9529,3.9529,0,0,1,24,20,4.0045,4.0045,0,0,1,28,24Zm-8,0a3.9521,3.9521,0,0,1,.5669-2.019l5.4521,5.4521A3.9529,3.9529,0,0,1,24,28,4.0045,4.0045,0,0,1,20,24Z"
  })), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2a12,12,0,1,0,2,23.8193v-2.021A10,10,0,1,1,14,4V14l4.343,4.3433A7.9751,7.9751,0,0,1,24,16h1.8193A11.93,11.93,0,0,0,14,2Z"
  })), children);
});
var InProgressError24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InProgressError24(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,24a6,6,0,1,0-6,6A6.0066,6.0066,0,0,0,30,24Zm-2,0a3.9521,3.9521,0,0,1-.5669,2.019L21.981,20.5669A3.9529,3.9529,0,0,1,24,20,4.0045,4.0045,0,0,1,28,24Zm-8,0a3.9521,3.9521,0,0,1,.5669-2.019l5.4521,5.4521A3.9529,3.9529,0,0,1,24,28,4.0045,4.0045,0,0,1,20,24Z"
  })), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2a12,12,0,1,0,2,23.8193v-2.021A10,10,0,1,1,14,4V14l4.343,4.3433A7.9751,7.9751,0,0,1,24,16h1.8193A11.93,11.93,0,0,0,14,2Z"
  })), children);
});
var InProgressError20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InProgressError20(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,24a6,6,0,1,0-6,6A6.0066,6.0066,0,0,0,30,24Zm-2,0a3.9521,3.9521,0,0,1-.5669,2.019L21.981,20.5669A3.9529,3.9529,0,0,1,24,20,4.0045,4.0045,0,0,1,28,24Zm-8,0a3.9521,3.9521,0,0,1,.5669-2.019l5.4521,5.4521A3.9529,3.9529,0,0,1,24,28,4.0045,4.0045,0,0,1,20,24Z"
  })), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2a12,12,0,1,0,2,23.8193v-2.021A10,10,0,1,1,14,4V14l4.343,4.3433A7.9751,7.9751,0,0,1,24,16h1.8193A11.93,11.93,0,0,0,14,2Z"
  })), children);
});
var InProgressError16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InProgressError16(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,24a6,6,0,1,0-6,6A6.0066,6.0066,0,0,0,30,24Zm-2,0a3.9521,3.9521,0,0,1-.5669,2.019L21.981,20.5669A3.9529,3.9529,0,0,1,24,20,4.0045,4.0045,0,0,1,28,24Zm-8,0a3.9521,3.9521,0,0,1,.5669-2.019l5.4521,5.4521A3.9529,3.9529,0,0,1,24,28,4.0045,4.0045,0,0,1,20,24Z"
  })), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2a12,12,0,1,0,2,23.8193v-2.021A10,10,0,1,1,14,4V14l4.343,4.3433A7.9751,7.9751,0,0,1,24,16h1.8193A11.93,11.93,0,0,0,14,2Z"
  })), children);
});
var InProgressWarning32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InProgressWarning32(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.38,28H20.6178L24,21.2358ZM24,18a1,1,0,0,0-.8947.5527l-5,10A1.0005,1.0005,0,0,0,19,30H29a1,1,0,0,0,.9214-1.3892L24.8946,18.5527A1,1,0,0,0,24,18Z"
  })), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.746,22.7993A9.999,9.999,0,1,1,14,4V14l6.0971,6.0972,1.22-2.44A2.9849,2.9849,0,0,1,24,16h1.8193A11.993,11.993,0,1,0,14,26a11.9337,11.9337,0,0,0,3.3939-.4966Z"
  })), children);
});
var InProgressWarning24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InProgressWarning24(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.38,28H20.6178L24,21.2358ZM24,18a1,1,0,0,0-.8947.5527l-5,10A1.0005,1.0005,0,0,0,19,30H29a1,1,0,0,0,.9214-1.3892L24.8946,18.5527A1,1,0,0,0,24,18Z"
  })), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.746,22.7993A9.999,9.999,0,1,1,14,4V14l6.0971,6.0972,1.22-2.44A2.9849,2.9849,0,0,1,24,16h1.8193A11.993,11.993,0,1,0,14,26a11.9337,11.9337,0,0,0,3.3939-.4966Z"
  })), children);
});
var InProgressWarning20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InProgressWarning20(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.38,28H20.6178L24,21.2358ZM24,18a1,1,0,0,0-.8947.5527l-5,10A1.0005,1.0005,0,0,0,19,30H29a1,1,0,0,0,.9214-1.3892L24.8946,18.5527A1,1,0,0,0,24,18Z"
  })), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.746,22.7993A9.999,9.999,0,1,1,14,4V14l6.0971,6.0972,1.22-2.44A2.9849,2.9849,0,0,1,24,16h1.8193A11.993,11.993,0,1,0,14,26a11.9337,11.9337,0,0,0,3.3939-.4966Z"
  })), children);
});
var InProgressWarning16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InProgressWarning16(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.38,28H20.6178L24,21.2358ZM24,18a1,1,0,0,0-.8947.5527l-5,10A1.0005,1.0005,0,0,0,19,30H29a1,1,0,0,0,.9214-1.3892L24.8946,18.5527A1,1,0,0,0,24,18Z"
  })), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.746,22.7993A9.999,9.999,0,1,1,14,4V14l6.0971,6.0972,1.22-2.44A2.9849,2.9849,0,0,1,24,16h1.8193A11.993,11.993,0,1,0,14,26a11.9337,11.9337,0,0,0,3.3939-.4966Z"
  })), children);
});
var Incomplete32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Incomplete32(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.7642 6.8593l1.2851-1.5315A13.976 13.976 0 0020.8672 2.887l-.6836 1.8776A11.9729 11.9729 0 0123.7642 6.8593zM27.81 14l1.9677-.4128A13.8888 13.8888 0 0028.14 9.0457L26.4087 10A12.52 12.52 0 0127.81 14zM20.1836 27.2354l.6836 1.8776a13.976 13.976 0 004.1821-2.4408l-1.2851-1.5315A11.9729 11.9729 0 0120.1836 27.2354zM26.4087 22L28.14 23a14.14 14.14 0 001.6382-4.5872L27.81 18.0659A12.1519 12.1519 0 0126.4087 22zM16 30V2a14 14 0 000 28z"
  })), children);
});
var Incomplete24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Incomplete24(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.7642 6.8593l1.2851-1.5315A13.976 13.976 0 0020.8672 2.887l-.6836 1.8776A11.9729 11.9729 0 0123.7642 6.8593zM27.81 14l1.9677-.4128A13.8888 13.8888 0 0028.14 9.0457L26.4087 10A12.52 12.52 0 0127.81 14zM20.1836 27.2354l.6836 1.8776a13.976 13.976 0 004.1821-2.4408l-1.2851-1.5315A11.9729 11.9729 0 0120.1836 27.2354zM26.4087 22L28.14 23a14.14 14.14 0 001.6382-4.5872L27.81 18.0659A12.1519 12.1519 0 0126.4087 22zM16 30V2a14 14 0 000 28z"
  })), children);
});
var Incomplete20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Incomplete20(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.7642 6.8593l1.2851-1.5315A13.976 13.976 0 0020.8672 2.887l-.6836 1.8776A11.9729 11.9729 0 0123.7642 6.8593zM27.81 14l1.9677-.4128A13.8888 13.8888 0 0028.14 9.0457L26.4087 10A12.52 12.52 0 0127.81 14zM20.1836 27.2354l.6836 1.8776a13.976 13.976 0 004.1821-2.4408l-1.2851-1.5315A11.9729 11.9729 0 0120.1836 27.2354zM26.4087 22L28.14 23a14.14 14.14 0 001.6382-4.5872L27.81 18.0659A12.1519 12.1519 0 0126.4087 22zM16 30V2a14 14 0 000 28z"
  })), children);
});
var Incomplete16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Incomplete16(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.7642 6.8593l1.2851-1.5315A13.976 13.976 0 0020.8672 2.887l-.6836 1.8776A11.9729 11.9729 0 0123.7642 6.8593zM27.81 14l1.9677-.4128A13.8888 13.8888 0 0028.14 9.0457L26.4087 10A12.52 12.52 0 0127.81 14zM20.1836 27.2354l.6836 1.8776a13.976 13.976 0 004.1821-2.4408l-1.2851-1.5315A11.9729 11.9729 0 0120.1836 27.2354zM26.4087 22L28.14 23a14.14 14.14 0 001.6382-4.5872L27.81 18.0659A12.1519 12.1519 0 0126.4087 22zM16 30V2a14 14 0 000 28z"
  })), children);
});
var IncompleteGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IncompleteGlyph(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,2a6,6,0,1,0,6,6A6,6,0,0,0,8,2ZM8,4a4.0045,4.0045,0,0,1,4,4H4A4.0045,4.0045,0,0,1,8,4Z"
  })), children);
});
var IncompleteCancel32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IncompleteCancel32(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 21.41L28.59 20 25 23.59 21.41 20 20 21.41 23.59 25 20 28.59 21.41 30 25 26.41 28.59 30 30 28.59 26.41 25 30 21.41zM14 26A12 12 0 0114 2zM17.8257 4.7642a10.0288 10.0288 0 013.2422 2.1679l1.4133-1.4135a12.0359 12.0359 0 00-3.89-2.6016zM26 14a11.93 11.93 0 00-.9167-4.5908l-1.8472.7651A9.9428 9.9428 0 0124 14z"
  })), children);
});
var IncompleteCancel24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IncompleteCancel24(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 21.41L28.59 20 25 23.59 21.41 20 20 21.41 23.59 25 20 28.59 21.41 30 25 26.41 28.59 30 30 28.59 26.41 25 30 21.41zM14 26A12 12 0 0114 2zM17.8257 4.7642a10.0288 10.0288 0 013.2422 2.1679l1.4133-1.4135a12.0359 12.0359 0 00-3.89-2.6016zM26 14a11.93 11.93 0 00-.9167-4.5908l-1.8472.7651A9.9428 9.9428 0 0124 14z"
  })), children);
});
var IncompleteCancel20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IncompleteCancel20(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 21.41L28.59 20 25 23.59 21.41 20 20 21.41 23.59 25 20 28.59 21.41 30 25 26.41 28.59 30 30 28.59 26.41 25 30 21.41zM14 26A12 12 0 0114 2zM17.8257 4.7642a10.0288 10.0288 0 013.2422 2.1679l1.4133-1.4135a12.0359 12.0359 0 00-3.89-2.6016zM26 14a11.93 11.93 0 00-.9167-4.5908l-1.8472.7651A9.9428 9.9428 0 0124 14z"
  })), children);
});
var IncompleteCancel16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IncompleteCancel16(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 21.41L28.59 20 25 23.59 21.41 20 20 21.41 23.59 25 20 28.59 21.41 30 25 26.41 28.59 30 30 28.59 26.41 25 30 21.41zM14 26A12 12 0 0114 2zM17.8257 4.7642a10.0288 10.0288 0 013.2422 2.1679l1.4133-1.4135a12.0359 12.0359 0 00-3.89-2.6016zM26 14a11.93 11.93 0 00-.9167-4.5908l-1.8472.7651A9.9428 9.9428 0 0124 14z"
  })), children);
});
var IncompleteError32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IncompleteError32(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 26A12 12 0 0114 2zM17.8257 4.7642a10.0288 10.0288 0 013.2422 2.1679l1.4133-1.4135a12.0359 12.0359 0 00-3.89-2.6016zM26 14a11.93 11.93 0 00-.9167-4.5908l-1.8472.7651A9.9428 9.9428 0 0124 14zM30 24a6 6 0 10-6 6A6.0066 6.0066 0 0030 24zm-2 0a3.9521 3.9521 0 01-.5669 2.019L21.981 20.5669A3.9529 3.9529 0 0124 20 4.0045 4.0045 0 0128 24zm-8 0a3.9521 3.9521 0 01.5669-2.019l5.4521 5.4521A3.9529 3.9529 0 0124 28 4.0045 4.0045 0 0120 24z"
  })), children);
});
var IncompleteError24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IncompleteError24(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 26A12 12 0 0114 2zM17.8257 4.7642a10.0288 10.0288 0 013.2422 2.1679l1.4133-1.4135a12.0359 12.0359 0 00-3.89-2.6016zM26 14a11.93 11.93 0 00-.9167-4.5908l-1.8472.7651A9.9428 9.9428 0 0124 14zM30 24a6 6 0 10-6 6A6.0066 6.0066 0 0030 24zm-2 0a3.9521 3.9521 0 01-.5669 2.019L21.981 20.5669A3.9529 3.9529 0 0124 20 4.0045 4.0045 0 0128 24zm-8 0a3.9521 3.9521 0 01.5669-2.019l5.4521 5.4521A3.9529 3.9529 0 0124 28 4.0045 4.0045 0 0120 24z"
  })), children);
});
var IncompleteError20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IncompleteError20(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 26A12 12 0 0114 2zM17.8257 4.7642a10.0288 10.0288 0 013.2422 2.1679l1.4133-1.4135a12.0359 12.0359 0 00-3.89-2.6016zM26 14a11.93 11.93 0 00-.9167-4.5908l-1.8472.7651A9.9428 9.9428 0 0124 14zM30 24a6 6 0 10-6 6A6.0066 6.0066 0 0030 24zm-2 0a3.9521 3.9521 0 01-.5669 2.019L21.981 20.5669A3.9529 3.9529 0 0124 20 4.0045 4.0045 0 0128 24zm-8 0a3.9521 3.9521 0 01.5669-2.019l5.4521 5.4521A3.9529 3.9529 0 0124 28 4.0045 4.0045 0 0120 24z"
  })), children);
});
var IncompleteError16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IncompleteError16(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 26A12 12 0 0114 2zM17.8257 4.7642a10.0288 10.0288 0 013.2422 2.1679l1.4133-1.4135a12.0359 12.0359 0 00-3.89-2.6016zM26 14a11.93 11.93 0 00-.9167-4.5908l-1.8472.7651A9.9428 9.9428 0 0124 14zM30 24a6 6 0 10-6 6A6.0066 6.0066 0 0030 24zm-2 0a3.9521 3.9521 0 01-.5669 2.019L21.981 20.5669A3.9529 3.9529 0 0124 20 4.0045 4.0045 0 0128 24zm-8 0a3.9521 3.9521 0 01.5669-2.019l5.4521 5.4521A3.9529 3.9529 0 0124 28 4.0045 4.0045 0 0120 24z"
  })), children);
});
var IncompleteWarning32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IncompleteWarning32(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 26A12 12 0 0114 2zM17.8257 4.7642a10.0288 10.0288 0 013.2422 2.1679l1.4133-1.4135a12.0359 12.0359 0 00-3.89-2.6016zM26 14a11.93 11.93 0 00-.9167-4.5908l-1.8472.7651A9.9428 9.9428 0 0124 14zM27.38 28H20.6178L24 21.2358zM24 18a1 1 0 00-.8947.5527l-5 10A1.0005 1.0005 0 0019 30H29a1 1 0 00.9214-1.3892L24.8946 18.5527A1 1 0 0024 18z"
  })), children);
});
var IncompleteWarning24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IncompleteWarning24(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 26A12 12 0 0114 2zM17.8257 4.7642a10.0288 10.0288 0 013.2422 2.1679l1.4133-1.4135a12.0359 12.0359 0 00-3.89-2.6016zM26 14a11.93 11.93 0 00-.9167-4.5908l-1.8472.7651A9.9428 9.9428 0 0124 14zM27.38 28H20.6178L24 21.2358zM24 18a1 1 0 00-.8947.5527l-5 10A1.0005 1.0005 0 0019 30H29a1 1 0 00.9214-1.3892L24.8946 18.5527A1 1 0 0024 18z"
  })), children);
});
var IncompleteWarning20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IncompleteWarning20(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 26A12 12 0 0114 2zM17.8257 4.7642a10.0288 10.0288 0 013.2422 2.1679l1.4133-1.4135a12.0359 12.0359 0 00-3.89-2.6016zM26 14a11.93 11.93 0 00-.9167-4.5908l-1.8472.7651A9.9428 9.9428 0 0124 14zM27.38 28H20.6178L24 21.2358zM24 18a1 1 0 00-.8947.5527l-5 10A1.0005 1.0005 0 0019 30H29a1 1 0 00.9214-1.3892L24.8946 18.5527A1 1 0 0024 18z"
  })), children);
});
var IncompleteWarning16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IncompleteWarning16(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 26A12 12 0 0114 2zM17.8257 4.7642a10.0288 10.0288 0 013.2422 2.1679l1.4133-1.4135a12.0359 12.0359 0 00-3.89-2.6016zM26 14a11.93 11.93 0 00-.9167-4.5908l-1.8472.7651A9.9428 9.9428 0 0124 14zM27.38 28H20.6178L24 21.2358zM24 18a1 1 0 00-.8947.5527l-5 10A1.0005 1.0005 0 0019 30H29a1 1 0 00.9214-1.3892L24.8946 18.5527A1 1 0 0024 18z"
  })), children);
});
var IncreaseLevel32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IncreaseLevel32(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 4L18 7.75 18 14.25 15 12 10 15.75 10 22.25 7 20 2 23.75 2 30 4 30 4 24.75 7 22.5 10 24.75 10 30 12 30 12 16.75 15 14.5 18 16.75 18 30 20 30 20 8.75 23 6.5 26 8.75 26 30 28 30 28 7.75 23 4z"
  })), children);
});
var IncreaseLevel24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IncreaseLevel24(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 4L18 7.75 18 14.25 15 12 10 15.75 10 22.25 7 20 2 23.75 2 30 4 30 4 24.75 7 22.5 10 24.75 10 30 12 30 12 16.75 15 14.5 18 16.75 18 30 20 30 20 8.75 23 6.5 26 8.75 26 30 28 30 28 7.75 23 4z"
  })), children);
});
var IncreaseLevel20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IncreaseLevel20(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 4L18 7.75 18 14.25 15 12 10 15.75 10 22.25 7 20 2 23.75 2 30 4 30 4 24.75 7 22.5 10 24.75 10 30 12 30 12 16.75 15 14.5 18 16.75 18 30 20 30 20 8.75 23 6.5 26 8.75 26 30 28 30 28 7.75 23 4z"
  })), children);
});
var IncreaseLevel16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IncreaseLevel16(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 4L18 7.75 18 14.25 15 12 10 15.75 10 22.25 7 20 2 23.75 2 30 4 30 4 24.75 7 22.5 10 24.75 10 30 12 30 12 16.75 15 14.5 18 16.75 18 30 20 30 20 8.75 23 6.5 26 8.75 26 30 28 30 28 7.75 23 4z"
  })), children);
});
var Industry32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Industry32(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.53,6.15a1,1,0,0,0-1,0L20,10.38V7a1,1,0,0,0-1.45-.89L10,10.38V3A1,1,0,0,0,9,2H3A1,1,0,0,0,2,3V28H30V7A1,1,0,0,0,29.53,6.15ZM22,26H18V19h4Zm6,0H24V18a1,1,0,0,0-1-1H17a1,1,0,0,0-1,1v8H4V4H8v9.62l10-5v5l10-5Z"
  })), children);
});
var Industry24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Industry24(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.53,6.15a1,1,0,0,0-1,0L20,10.38V7a1,1,0,0,0-1.45-.89L10,10.38V3A1,1,0,0,0,9,2H3A1,1,0,0,0,2,3V28H30V7A1,1,0,0,0,29.53,6.15ZM22,26H18V19h4Zm6,0H24V18a1,1,0,0,0-1-1H17a1,1,0,0,0-1,1v8H4V4H8v9.62l10-5v5l10-5Z"
  })), children);
});
var Industry20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Industry20(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.53,6.15a1,1,0,0,0-1,0L20,10.38V7a1,1,0,0,0-1.45-.89L10,10.38V3A1,1,0,0,0,9,2H3A1,1,0,0,0,2,3V28H30V7A1,1,0,0,0,29.53,6.15ZM22,26H18V19h4Zm6,0H24V18a1,1,0,0,0-1-1H17a1,1,0,0,0-1,1v8H4V4H8v9.62l10-5v5l10-5Z"
  })), children);
});
var Industry16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Industry16(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.53,6.15a1,1,0,0,0-1,0L20,10.38V7a1,1,0,0,0-1.45-.89L10,10.38V3A1,1,0,0,0,9,2H3A1,1,0,0,0,2,3V28H30V7A1,1,0,0,0,29.53,6.15ZM22,26H18V19h4Zm6,0H24V18a1,1,0,0,0-1-1H17a1,1,0,0,0-1,1v8H4V4H8v9.62l10-5v5l10-5Z"
  })), children);
});
var Information32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Information32(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 22L17 14 13 14 13 16 15 16 15 22 12 22 12 24 20 24 20 22 17 22zM16 8a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 8z"
  })), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14,14,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12,12,0,0,0,16,4Z"
  })), children);
});
var Information24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Information24(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 22L17 14 13 14 13 16 15 16 15 22 12 22 12 24 20 24 20 22 17 22zM16 8a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 8z"
  })), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14,14,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12,12,0,0,0,16,4Z"
  })), children);
});
var Information20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Information20(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 22L17 14 13 14 13 16 15 16 15 22 12 22 12 24 20 24 20 22 17 22zM16 8a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 8z"
  })), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14,14,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12,12,0,0,0,16,4Z"
  })), children);
});
var Information16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Information16(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.5 11L8.5 6.5 6.5 6.5 6.5 7.5 7.5 7.5 7.5 11 6 11 6 12 10 12 10 11zM8 3.5c-.4 0-.8.3-.8.8S7.6 5 8 5c.4 0 .8-.3.8-.8S8.4 3.5 8 3.5z"
  })), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,15c-3.9,0-7-3.1-7-7s3.1-7,7-7s7,3.1,7,7S11.9,15,8,15z M8,2C4.7,2,2,4.7,2,8s2.7,6,6,6s6-2.7,6-6S11.3,2,8,2z"
  })), children);
});
var InformationDisabled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InformationDisabled32(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 3.4141L28.5859 2 2 28.5859 3.4141 30l3.4433-3.4434A13.9614 13.9614 0 0026.5565 6.8574zM28 16A11.9734 11.9734 0 018.2678 25.146L15 18.4141V22H13v2h7V22H17V16.4141l8.146-8.146A11.8967 11.8967 0 0128 16zM16 8a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 8z"
  })), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.67,22.0854A11.9829,11.9829,0,0,1,22.0856,5.67L23.54,4.2163A13.985,13.985,0,0,0,4.2162,23.54Z"
  })), children);
});
var InformationDisabled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InformationDisabled24(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 3.4141L28.5859 2 2 28.5859 3.4141 30l3.4433-3.4434A13.9614 13.9614 0 0026.5565 6.8574zM28 16A11.9734 11.9734 0 018.2678 25.146L15 18.4141V22H13v2h7V22H17V16.4141l8.146-8.146A11.8967 11.8967 0 0128 16zM16 8a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 8z"
  })), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.67,22.0854A11.9829,11.9829,0,0,1,22.0856,5.67L23.54,4.2163A13.985,13.985,0,0,0,4.2162,23.54Z"
  })), children);
});
var InformationDisabled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InformationDisabled20(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 3.4141L28.5859 2 2 28.5859 3.4141 30l3.4433-3.4434A13.9614 13.9614 0 0026.5565 6.8574zM28 16A11.9734 11.9734 0 018.2678 25.146L15 18.4141V22H13v2h7V22H17V16.4141l8.146-8.146A11.8967 11.8967 0 0128 16zM16 8a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 8z"
  })), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.67,22.0854A11.9829,11.9829,0,0,1,22.0856,5.67L23.54,4.2163A13.985,13.985,0,0,0,4.2162,23.54Z"
  })), children);
});
var InformationDisabled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InformationDisabled16(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 3.4141L28.5859 2 2 28.5859 3.4141 30l3.4433-3.4434A13.9614 13.9614 0 0026.5565 6.8574zM28 16A11.9734 11.9734 0 018.2678 25.146L15 18.4141V22H13v2h7V22H17V16.4141l8.146-8.146A11.8967 11.8967 0 0128 16zM16 8a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 8z"
  })), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.67,22.0854A11.9829,11.9829,0,0,1,22.0856,5.67L23.54,4.2163A13.985,13.985,0,0,0,4.2162,23.54Z"
  })), children);
});
var InformationFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InformationFilled32(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,8a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,8Zm4,13.875H17.125v-8H13v2.25h1.875v5.75H12v2.25h8Z",
    "data-icon-path": "inner-path"
  })), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,6a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,8Zm4,16.125H12v-2.25h2.875v-5.75H13v-2.25h4.125v8H20Z"
  })), children);
});
var InformationFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InformationFilled24(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,8a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,8Zm4,13.875H17.125v-8H13v2.25h1.875v5.75H12v2.25h8Z",
    "data-icon-path": "inner-path"
  })), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,6a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,8Zm4,16.125H12v-2.25h2.875v-5.75H13v-2.25h4.125v8H20Z"
  })), children);
});
var InformationFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InformationFilled20(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,8a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,8Zm4,13.875H17.125v-8H13v2.25h1.875v5.75H12v2.25h8Z",
    "data-icon-path": "inner-path"
  })), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,6a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,8Zm4,16.125H12v-2.25h2.875v-5.75H13v-2.25h4.125v8H20Z"
  })), children);
});
var InformationFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InformationFilled16(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,8a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,8Zm4,13.875H17.125v-8H13v2.25h1.875v5.75H12v2.25h8Z",
    "data-icon-path": "inner-path"
  })), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,6a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,8Zm4,16.125H12v-2.25h2.875v-5.75H13v-2.25h4.125v8H20Z"
  })), children);
});
var InformationSquare32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InformationSquare32(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 22L17 14 13 14 13 16 15 16 15 22 12 22 12 24 20 24 20 22 17 22zM16 8a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 8z"
  })), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,6,4H26a2.0023,2.0023,0,0,1,2,2V26A2.0023,2.0023,0,0,1,26,28ZM6,6V26H26V6Z"
  })), children);
});
var InformationSquare24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InformationSquare24(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 22L17 14 13 14 13 16 15 16 15 22 12 22 12 24 20 24 20 22 17 22zM16 8a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 8z"
  })), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,6,4H26a2.0023,2.0023,0,0,1,2,2V26A2.0023,2.0023,0,0,1,26,28ZM6,6V26H26V6Z"
  })), children);
});
var InformationSquare20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InformationSquare20(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 22L17 14 13 14 13 16 15 16 15 22 12 22 12 24 20 24 20 22 17 22zM16 8a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 8z"
  })), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,6,4H26a2.0023,2.0023,0,0,1,2,2V26A2.0023,2.0023,0,0,1,26,28ZM6,6V26H26V6Z"
  })), children);
});
var InformationSquare16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InformationSquare16(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 22L17 14 13 14 13 16 15 16 15 22 12 22 12 24 20 24 20 22 17 22zM16 8a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 8z"
  })), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,6,4H26a2.0023,2.0023,0,0,1,2,2V26A2.0023,2.0023,0,0,1,26,28ZM6,6V26H26V6Z"
  })), children);
});
var InformationSquareFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InformationSquareFilled32(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,8a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,8Zm4,13.875H17.125v-8H13v2.25h1.875v5.75H12v2.25h8Z",
    "data-icon-path": "inner-path"
  })), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM16,8a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,8Zm4,16.125H12v-2.25h2.875v-5.75H13v-2.25h4.125v8H20Z"
  })), children);
});
var InformationSquareFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InformationSquareFilled24(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,8a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,8Zm4,13.875H17.125v-8H13v2.25h1.875v5.75H12v2.25h8Z",
    "data-icon-path": "inner-path"
  })), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM16,8a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,8Zm4,16.125H12v-2.25h2.875v-5.75H13v-2.25h4.125v8H20Z"
  })), children);
});
var InformationSquareFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InformationSquareFilled20(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,8a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,8Zm4,13.875H17.125v-8H13v2.25h1.875v5.75H12v2.25h8Z",
    "data-icon-path": "inner-path"
  })), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM16,8a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,8Zm4,16.125H12v-2.25h2.875v-5.75H13v-2.25h4.125v8H20Z"
  })), children);
});
var InformationSquareFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InformationSquareFilled16(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,8a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,8Zm4,13.875H17.125v-8H13v2.25h1.875v5.75H12v2.25h8Z",
    "data-icon-path": "inner-path"
  })), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM16,8a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,8Zm4,16.125H12v-2.25h2.875v-5.75H13v-2.25h4.125v8H20Z"
  })), children);
});
var InfrastructureClassic32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InfrastructureClassic32(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 26H30V28H18zM18 21H30V23H18zM18 16H30V18H18z"
  })), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,25H9.5A7.4964,7.4964,0,0,1,8.1782,10.124,10,10,0,0,1,28,12H26a7.999,7.999,0,0,0-15.9507-.87l-.09.8335L9.123,12.02A5.4962,5.4962,0,0,0,9.5,23H14Z"
  })), children);
});
var InfrastructureClassic24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InfrastructureClassic24(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 26H30V28H18zM18 21H30V23H18zM18 16H30V18H18z"
  })), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,25H9.5A7.4964,7.4964,0,0,1,8.1782,10.124,10,10,0,0,1,28,12H26a7.999,7.999,0,0,0-15.9507-.87l-.09.8335L9.123,12.02A5.4962,5.4962,0,0,0,9.5,23H14Z"
  })), children);
});
var InfrastructureClassic20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InfrastructureClassic20(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 26H30V28H18zM18 21H30V23H18zM18 16H30V18H18z"
  })), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,25H9.5A7.4964,7.4964,0,0,1,8.1782,10.124,10,10,0,0,1,28,12H26a7.999,7.999,0,0,0-15.9507-.87l-.09.8335L9.123,12.02A5.4962,5.4962,0,0,0,9.5,23H14Z"
  })), children);
});
var InfrastructureClassic16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InfrastructureClassic16(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 26H30V28H18zM18 21H30V23H18zM18 16H30V18H18z"
  })), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,25H9.5A7.4964,7.4964,0,0,1,8.1782,10.124,10,10,0,0,1,28,12H26a7.999,7.999,0,0,0-15.9507-.87l-.09.8335L9.123,12.02A5.4962,5.4962,0,0,0,9.5,23H14Z"
  })), children);
});
var Insert32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Insert32(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 9h9V2H2zM4 4H9V7H4zM2 19h9V12H2zm2-5H9v3H4zM2 29h9V22H2zm2-5H9v3H4zM27 9H18l3.41-3.59L20 4l-6 6 6 6 1.41-1.41L18 11h9a1 1 0 011 1V24a1 1 0 01-1 1H15v2H27a3 3 0 003-3V12A3 3 0 0027 9z"
  })), children);
});
var Insert24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Insert24(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 9h9V2H2zM4 4H9V7H4zM2 19h9V12H2zm2-5H9v3H4zM2 29h9V22H2zm2-5H9v3H4zM27 9H18l3.41-3.59L20 4l-6 6 6 6 1.41-1.41L18 11h9a1 1 0 011 1V24a1 1 0 01-1 1H15v2H27a3 3 0 003-3V12A3 3 0 0027 9z"
  })), children);
});
var Insert20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Insert20(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 9h9V2H2zM4 4H9V7H4zM2 19h9V12H2zm2-5H9v3H4zM2 29h9V22H2zm2-5H9v3H4zM27 9H18l3.41-3.59L20 4l-6 6 6 6 1.41-1.41L18 11h9a1 1 0 011 1V24a1 1 0 01-1 1H15v2H27a3 3 0 003-3V12A3 3 0 0027 9z"
  })), children);
});
var Insert16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Insert16(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 9h9V2H2zM4 4H9V7H4zM2 19h9V12H2zm2-5H9v3H4zM2 29h9V22H2zm2-5H9v3H4zM27 9H18l3.41-3.59L20 4l-6 6 6 6 1.41-1.41L18 11h9a1 1 0 011 1V24a1 1 0 01-1 1H15v2H27a3 3 0 003-3V12A3 3 0 0027 9z"
  })), children);
});
var InsertPage32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InsertPage32(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 30H24V20H12V30H10V20a2.0021 2.0021 0 012-2H24a2.0021 2.0021 0 012 2zM5.17 16L2 19.17 3.411 20.589 8 16 3.42 11.42 2 12.83 5.17 16zM24 14H12a2.0021 2.0021 0 01-2-2V2h2V12H24V2h2V12A2.0021 2.0021 0 0124 14z"
  })), children);
});
var InsertPage24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InsertPage24(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 30H24V20H12V30H10V20a2.0021 2.0021 0 012-2H24a2.0021 2.0021 0 012 2zM5.17 16L2 19.17 3.411 20.589 8 16 3.42 11.42 2 12.83 5.17 16zM24 14H12a2.0021 2.0021 0 01-2-2V2h2V12H24V2h2V12A2.0021 2.0021 0 0124 14z"
  })), children);
});
var InsertPage20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InsertPage20(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 30H24V20H12V30H10V20a2.0021 2.0021 0 012-2H24a2.0021 2.0021 0 012 2zM5.17 16L2 19.17 3.411 20.589 8 16 3.42 11.42 2 12.83 5.17 16zM24 14H12a2.0021 2.0021 0 01-2-2V2h2V12H24V2h2V12A2.0021 2.0021 0 0124 14z"
  })), children);
});
var InsertPage16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InsertPage16(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 30H24V20H12V30H10V20a2.0021 2.0021 0 012-2H24a2.0021 2.0021 0 012 2zM5.17 16L2 19.17 3.411 20.589 8 16 3.42 11.42 2 12.83 5.17 16zM24 14H12a2.0021 2.0021 0 01-2-2V2h2V12H24V2h2V12A2.0021 2.0021 0 0124 14z"
  })), children);
});
var InsertSyntax32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InsertSyntax32(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.17 16L17.59 18.58 19 20 23 16 19 12 17.58 13.41 20.17 16zM11.83 16L14.41 13.42 13 12 9 16 13 20 14.42 18.59 11.83 16z"
  })), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.142V9.858A3.9916,3.9916,0,1,0,22.142,5H9.858A3.9916,3.9916,0,1,0,5,9.858V22.142A3.9916,3.9916,0,1,0,9.858,27H22.142A3.9916,3.9916,0,1,0,27,22.142ZM26,4a2,2,0,1,1-2,2A2.0023,2.0023,0,0,1,26,4ZM4,6A2,2,0,1,1,6,8,2.002,2.002,0,0,1,4,6ZM6,28a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,6,28Zm16.142-3H9.858A3.9937,3.9937,0,0,0,7,22.142V9.858A3.9947,3.9947,0,0,0,9.858,7H22.142A3.9937,3.9937,0,0,0,25,9.858V22.142A3.9931,3.9931,0,0,0,22.142,25ZM26,28a2,2,0,1,1,2-2A2.0027,2.0027,0,0,1,26,28Z"
  })), children);
});
var InsertSyntax24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InsertSyntax24(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.17 16L17.59 18.58 19 20 23 16 19 12 17.58 13.41 20.17 16zM11.83 16L14.41 13.42 13 12 9 16 13 20 14.42 18.59 11.83 16z"
  })), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.142V9.858A3.9916,3.9916,0,1,0,22.142,5H9.858A3.9916,3.9916,0,1,0,5,9.858V22.142A3.9916,3.9916,0,1,0,9.858,27H22.142A3.9916,3.9916,0,1,0,27,22.142ZM26,4a2,2,0,1,1-2,2A2.0023,2.0023,0,0,1,26,4ZM4,6A2,2,0,1,1,6,8,2.002,2.002,0,0,1,4,6ZM6,28a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,6,28Zm16.142-3H9.858A3.9937,3.9937,0,0,0,7,22.142V9.858A3.9947,3.9947,0,0,0,9.858,7H22.142A3.9937,3.9937,0,0,0,25,9.858V22.142A3.9931,3.9931,0,0,0,22.142,25ZM26,28a2,2,0,1,1,2-2A2.0027,2.0027,0,0,1,26,28Z"
  })), children);
});
var InsertSyntax20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InsertSyntax20(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.17 16L17.59 18.58 19 20 23 16 19 12 17.58 13.41 20.17 16zM11.83 16L14.41 13.42 13 12 9 16 13 20 14.42 18.59 11.83 16z"
  })), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.142V9.858A3.9916,3.9916,0,1,0,22.142,5H9.858A3.9916,3.9916,0,1,0,5,9.858V22.142A3.9916,3.9916,0,1,0,9.858,27H22.142A3.9916,3.9916,0,1,0,27,22.142ZM26,4a2,2,0,1,1-2,2A2.0023,2.0023,0,0,1,26,4ZM4,6A2,2,0,1,1,6,8,2.002,2.002,0,0,1,4,6ZM6,28a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,6,28Zm16.142-3H9.858A3.9937,3.9937,0,0,0,7,22.142V9.858A3.9947,3.9947,0,0,0,9.858,7H22.142A3.9937,3.9937,0,0,0,25,9.858V22.142A3.9931,3.9931,0,0,0,22.142,25ZM26,28a2,2,0,1,1,2-2A2.0027,2.0027,0,0,1,26,28Z"
  })), children);
});
var InsertSyntax16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InsertSyntax16(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.17 16L17.59 18.58 19 20 23 16 19 12 17.58 13.41 20.17 16zM11.83 16L14.41 13.42 13 12 9 16 13 20 14.42 18.59 11.83 16z"
  })), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.142V9.858A3.9916,3.9916,0,1,0,22.142,5H9.858A3.9916,3.9916,0,1,0,5,9.858V22.142A3.9916,3.9916,0,1,0,9.858,27H22.142A3.9916,3.9916,0,1,0,27,22.142ZM26,4a2,2,0,1,1-2,2A2.0023,2.0023,0,0,1,26,4ZM4,6A2,2,0,1,1,6,8,2.002,2.002,0,0,1,4,6ZM6,28a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,6,28Zm16.142-3H9.858A3.9937,3.9937,0,0,0,7,22.142V9.858A3.9947,3.9947,0,0,0,9.858,7H22.142A3.9937,3.9937,0,0,0,25,9.858V22.142A3.9931,3.9931,0,0,0,22.142,25ZM26,28a2,2,0,1,1,2-2A2.0027,2.0027,0,0,1,26,28Z"
  })), children);
});
var Inspection32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Inspection32(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 17.18L12.41 14.59 11 16 15 20 22 13 20.59 11.59 15 17.18z"
  })), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H27.9492A12.0071,12.0071,0,0,0,17,4.0508V2H15V4.0508A12.0071,12.0071,0,0,0,4.0508,15H2v2H4.0508A12.0071,12.0071,0,0,0,15,27.9492V30h2V27.9492A12.0071,12.0071,0,0,0,27.9492,17H30ZM17,25.9492V23H15v2.9492A10.0166,10.0166,0,0,1,6.0508,17H9V15H6.0508A10.0166,10.0166,0,0,1,15,6.0508V9h2V6.0508A10.0166,10.0166,0,0,1,25.9492,15H23v2h2.949A10.0165,10.0165,0,0,1,17,25.9492Z"
  })), children);
});
var Inspection24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Inspection24(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 17.18L12.41 14.59 11 16 15 20 22 13 20.59 11.59 15 17.18z"
  })), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H27.9492A12.0071,12.0071,0,0,0,17,4.0508V2H15V4.0508A12.0071,12.0071,0,0,0,4.0508,15H2v2H4.0508A12.0071,12.0071,0,0,0,15,27.9492V30h2V27.9492A12.0071,12.0071,0,0,0,27.9492,17H30ZM17,25.9492V23H15v2.9492A10.0166,10.0166,0,0,1,6.0508,17H9V15H6.0508A10.0166,10.0166,0,0,1,15,6.0508V9h2V6.0508A10.0166,10.0166,0,0,1,25.9492,15H23v2h2.949A10.0165,10.0165,0,0,1,17,25.9492Z"
  })), children);
});
var Inspection20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Inspection20(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 17.18L12.41 14.59 11 16 15 20 22 13 20.59 11.59 15 17.18z"
  })), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H27.9492A12.0071,12.0071,0,0,0,17,4.0508V2H15V4.0508A12.0071,12.0071,0,0,0,4.0508,15H2v2H4.0508A12.0071,12.0071,0,0,0,15,27.9492V30h2V27.9492A12.0071,12.0071,0,0,0,27.9492,17H30ZM17,25.9492V23H15v2.9492A10.0166,10.0166,0,0,1,6.0508,17H9V15H6.0508A10.0166,10.0166,0,0,1,15,6.0508V9h2V6.0508A10.0166,10.0166,0,0,1,25.9492,15H23v2h2.949A10.0165,10.0165,0,0,1,17,25.9492Z"
  })), children);
});
var Inspection16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Inspection16(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 17.18L12.41 14.59 11 16 15 20 22 13 20.59 11.59 15 17.18z"
  })), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H27.9492A12.0071,12.0071,0,0,0,17,4.0508V2H15V4.0508A12.0071,12.0071,0,0,0,4.0508,15H2v2H4.0508A12.0071,12.0071,0,0,0,15,27.9492V30h2V27.9492A12.0071,12.0071,0,0,0,27.9492,17H30ZM17,25.9492V23H15v2.9492A10.0166,10.0166,0,0,1,6.0508,17H9V15H6.0508A10.0166,10.0166,0,0,1,15,6.0508V9h2V6.0508A10.0166,10.0166,0,0,1,25.9492,15H23v2h2.949A10.0165,10.0165,0,0,1,17,25.9492Z"
  })), children);
});
var InstanceBx32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceBx32(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 5A3.0033 3.0033 0 009 2H4V15H9a3.0033 3.0033 0 003-3V10.5a2.977 2.977 0 00-.78-2 2.9768 2.9768 0 00.78-2zM6 4H9a1.0013 1.0013 0 011 1V6.5513A.9587.9587 0 019 7.5H6zm4 8a1.0009 1.0009 0 01-1 1H6V9.5H9a1.0009 1.0009 0 011 1zM22 5L20 5 18 8.897 16 5 14 5 16.905 10 14 15 16 15 18 11.201 20 15 22 15 19.098 10 22 5z"
  })), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 18H6V20H2zM8 18H12V20H8zM14 18H18V20H14zM20 18H24V20H20zM26 18H30V20H26zM26 31H6a2.0021 2.0021 0 01-2-2V25a2.0021 2.0021 0 012-2H26a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0126 31zM6 25v4H26V25z"
  })), children);
});
var InstanceBx24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceBx24(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 5A3.0033 3.0033 0 009 2H4V15H9a3.0033 3.0033 0 003-3V10.5a2.977 2.977 0 00-.78-2 2.9768 2.9768 0 00.78-2zM6 4H9a1.0013 1.0013 0 011 1V6.5513A.9587.9587 0 019 7.5H6zm4 8a1.0009 1.0009 0 01-1 1H6V9.5H9a1.0009 1.0009 0 011 1zM22 5L20 5 18 8.897 16 5 14 5 16.905 10 14 15 16 15 18 11.201 20 15 22 15 19.098 10 22 5z"
  })), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 18H6V20H2zM8 18H12V20H8zM14 18H18V20H14zM20 18H24V20H20zM26 18H30V20H26zM26 31H6a2.0021 2.0021 0 01-2-2V25a2.0021 2.0021 0 012-2H26a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0126 31zM6 25v4H26V25z"
  })), children);
});
var InstanceBx20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceBx20(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 5A3.0033 3.0033 0 009 2H4V15H9a3.0033 3.0033 0 003-3V10.5a2.977 2.977 0 00-.78-2 2.9768 2.9768 0 00.78-2zM6 4H9a1.0013 1.0013 0 011 1V6.5513A.9587.9587 0 019 7.5H6zm4 8a1.0009 1.0009 0 01-1 1H6V9.5H9a1.0009 1.0009 0 011 1zM22 5L20 5 18 8.897 16 5 14 5 16.905 10 14 15 16 15 18 11.201 20 15 22 15 19.098 10 22 5z"
  })), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 18H6V20H2zM8 18H12V20H8zM14 18H18V20H14zM20 18H24V20H20zM26 18H30V20H26zM26 31H6a2.0021 2.0021 0 01-2-2V25a2.0021 2.0021 0 012-2H26a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0126 31zM6 25v4H26V25z"
  })), children);
});
var InstanceBx16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceBx16(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 5A3.0033 3.0033 0 009 2H4V15H9a3.0033 3.0033 0 003-3V10.5a2.977 2.977 0 00-.78-2 2.9768 2.9768 0 00.78-2zM6 4H9a1.0013 1.0013 0 011 1V6.5513A.9587.9587 0 019 7.5H6zm4 8a1.0009 1.0009 0 01-1 1H6V9.5H9a1.0009 1.0009 0 011 1zM22 5L20 5 18 8.897 16 5 14 5 16.905 10 14 15 16 15 18 11.201 20 15 22 15 19.098 10 22 5z"
  })), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 18H6V20H2zM8 18H12V20H8zM14 18H18V20H14zM20 18H24V20H20zM26 18H30V20H26zM26 31H6a2.0021 2.0021 0 01-2-2V25a2.0021 2.0021 0 012-2H26a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0126 31zM6 25v4H26V25z"
  })), children);
});
var InstanceClassic32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceClassic32(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,21H23V19h.5a4.4975,4.4975,0,0,0,.3564-8.981l-.8154-.0639-.0986-.812a6.9938,6.9938,0,0,0-13.8838,0l-.0991.812-.8155.0639A4.4975,4.4975,0,0,0,8.5,19H9v2H8.5A6.4973,6.4973,0,0,1,7.2,8.1362a8.9943,8.9943,0,0,1,17.6006,0A6.4974,6.4974,0,0,1,23.5,21Z"
  })), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,23H17V15.83l2.59,2.58L21,17l-5-5-5,5,1.41,1.41L15,15.83V23H6a2.0023,2.0023,0,0,0-2,2v4a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V25A2.0023,2.0023,0,0,0,26,23Zm0,6H6V25H26Z"
  })), children);
});
var InstanceClassic24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceClassic24(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,21H23V19h.5a4.4975,4.4975,0,0,0,.3564-8.981l-.8154-.0639-.0986-.812a6.9938,6.9938,0,0,0-13.8838,0l-.0991.812-.8155.0639A4.4975,4.4975,0,0,0,8.5,19H9v2H8.5A6.4973,6.4973,0,0,1,7.2,8.1362a8.9943,8.9943,0,0,1,17.6006,0A6.4974,6.4974,0,0,1,23.5,21Z"
  })), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,23H17V15.83l2.59,2.58L21,17l-5-5-5,5,1.41,1.41L15,15.83V23H6a2.0023,2.0023,0,0,0-2,2v4a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V25A2.0023,2.0023,0,0,0,26,23Zm0,6H6V25H26Z"
  })), children);
});
var InstanceClassic20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceClassic20(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,21H23V19h.5a4.4975,4.4975,0,0,0,.3564-8.981l-.8154-.0639-.0986-.812a6.9938,6.9938,0,0,0-13.8838,0l-.0991.812-.8155.0639A4.4975,4.4975,0,0,0,8.5,19H9v2H8.5A6.4973,6.4973,0,0,1,7.2,8.1362a8.9943,8.9943,0,0,1,17.6006,0A6.4974,6.4974,0,0,1,23.5,21Z"
  })), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,23H17V15.83l2.59,2.58L21,17l-5-5-5,5,1.41,1.41L15,15.83V23H6a2.0023,2.0023,0,0,0-2,2v4a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V25A2.0023,2.0023,0,0,0,26,23Zm0,6H6V25H26Z"
  })), children);
});
var InstanceClassic16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceClassic16(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,21H23V19h.5a4.4975,4.4975,0,0,0,.3564-8.981l-.8154-.0639-.0986-.812a6.9938,6.9938,0,0,0-13.8838,0l-.0991.812-.8155.0639A4.4975,4.4975,0,0,0,8.5,19H9v2H8.5A6.4973,6.4973,0,0,1,7.2,8.1362a8.9943,8.9943,0,0,1,17.6006,0A6.4974,6.4974,0,0,1,23.5,21Z"
  })), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,23H17V15.83l2.59,2.58L21,17l-5-5-5,5,1.41,1.41L15,15.83V23H6a2.0023,2.0023,0,0,0-2,2v4a2.0023,2.0023,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V25A2.0023,2.0023,0,0,0,26,23Zm0,6H6V25H26Z"
  })), children);
});
var InstanceCx32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceCx32(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 5L20 5 18 8.897 16 5 14 5 16.905 10 14 15 16 15 18 11.201 20 15 22 15 19.098 10 22 5zM12 15H6a2.0023 2.0023 0 01-2-2V4A2.002 2.002 0 016 2h6V4H6v9h6zM2 18H6V20H2zM8 18H12V20H8zM14 18H18V20H14zM20 18H24V20H20zM26 18H30V20H26zM26 31H6a2.0021 2.0021 0 01-2-2V25a2.0021 2.0021 0 012-2H26a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0126 31zM6 25v4H26V25z"
  })), children);
});
var InstanceCx24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceCx24(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 5L20 5 18 8.897 16 5 14 5 16.905 10 14 15 16 15 18 11.201 20 15 22 15 19.098 10 22 5zM12 15H6a2.0023 2.0023 0 01-2-2V4A2.002 2.002 0 016 2h6V4H6v9h6zM2 18H6V20H2zM8 18H12V20H8zM14 18H18V20H14zM20 18H24V20H20zM26 18H30V20H26zM26 31H6a2.0021 2.0021 0 01-2-2V25a2.0021 2.0021 0 012-2H26a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0126 31zM6 25v4H26V25z"
  })), children);
});
var InstanceCx20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceCx20(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 5L20 5 18 8.897 16 5 14 5 16.905 10 14 15 16 15 18 11.201 20 15 22 15 19.098 10 22 5zM12 15H6a2.0023 2.0023 0 01-2-2V4A2.002 2.002 0 016 2h6V4H6v9h6zM2 18H6V20H2zM8 18H12V20H8zM14 18H18V20H14zM20 18H24V20H20zM26 18H30V20H26zM26 31H6a2.0021 2.0021 0 01-2-2V25a2.0021 2.0021 0 012-2H26a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0126 31zM6 25v4H26V25z"
  })), children);
});
var InstanceCx16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceCx16(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 5L20 5 18 8.897 16 5 14 5 16.905 10 14 15 16 15 18 11.201 20 15 22 15 19.098 10 22 5zM12 15H6a2.0023 2.0023 0 01-2-2V4A2.002 2.002 0 016 2h6V4H6v9h6zM2 18H6V20H2zM8 18H12V20H8zM14 18H18V20H14zM20 18H24V20H20zM26 18H30V20H26zM26 31H6a2.0021 2.0021 0 01-2-2V25a2.0021 2.0021 0 012-2H26a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0126 31zM6 25v4H26V25z"
  })), children);
});
var InstanceMx32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceMx32(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 5L20 5 18 8.897 16 5 14 5 16.905 10 14 15 16 15 18 11.201 20 15 22 15 19.098 10 22 5zM10 2L8.485 6.374 8 8 7.535 6.374 6 2 4 2 4 15 6 15 6 7.374 5.841 5.378 6.421 7.374 8 12 9.579 7.374 10.159 5.374 10 7.374 10 15 12 15 12 2 10 2z"
  })), _circle21 || (_circle21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 18H6V20H2zM8 18H12V20H8zM14 18H18V20H14zM20 18H24V20H20zM26 18H30V20H26zM26 31H6a2.0021 2.0021 0 01-2-2V25a2.0021 2.0021 0 012-2H26a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0126 31zM6 25v4H26V25z"
  })), children);
});
var InstanceMx24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceMx24(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 5L20 5 18 8.897 16 5 14 5 16.905 10 14 15 16 15 18 11.201 20 15 22 15 19.098 10 22 5zM10 2L8.485 6.374 8 8 7.535 6.374 6 2 4 2 4 15 6 15 6 7.374 5.841 5.378 6.421 7.374 8 12 9.579 7.374 10.159 5.374 10 7.374 10 15 12 15 12 2 10 2z"
  })), _circle22 || (_circle22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 18H6V20H2zM8 18H12V20H8zM14 18H18V20H14zM20 18H24V20H20zM26 18H30V20H26zM26 31H6a2.0021 2.0021 0 01-2-2V25a2.0021 2.0021 0 012-2H26a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0126 31zM6 25v4H26V25z"
  })), children);
});
var InstanceMx20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceMx20(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 5L20 5 18 8.897 16 5 14 5 16.905 10 14 15 16 15 18 11.201 20 15 22 15 19.098 10 22 5zM10 2L8.485 6.374 8 8 7.535 6.374 6 2 4 2 4 15 6 15 6 7.374 5.841 5.378 6.421 7.374 8 12 9.579 7.374 10.159 5.374 10 7.374 10 15 12 15 12 2 10 2z"
  })), _circle23 || (_circle23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 18H6V20H2zM8 18H12V20H8zM14 18H18V20H14zM20 18H24V20H20zM26 18H30V20H26zM26 31H6a2.0021 2.0021 0 01-2-2V25a2.0021 2.0021 0 012-2H26a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0126 31zM6 25v4H26V25z"
  })), children);
});
var InstanceMx16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceMx16(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 5L20 5 18 8.897 16 5 14 5 16.905 10 14 15 16 15 18 11.201 20 15 22 15 19.098 10 22 5zM10 2L8.485 6.374 8 8 7.535 6.374 6 2 4 2 4 15 6 15 6 7.374 5.841 5.378 6.421 7.374 8 12 9.579 7.374 10.159 5.374 10 7.374 10 15 12 15 12 2 10 2z"
  })), _circle24 || (_circle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 18H6V20H2zM8 18H12V20H8zM14 18H18V20H14zM20 18H24V20H20zM26 18H30V20H26zM26 31H6a2.0021 2.0021 0 01-2-2V25a2.0021 2.0021 0 012-2H26a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0126 31zM6 25v4H26V25z"
  })), children);
});
var InstanceVirtual32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceVirtual32(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle25 || (_circle25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "23",
    r: "1"
  })), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 6H6V8H2zM8 6H12V8H8zM14 6H18V8H14zM20 6H24V8H20zM26 6H30V8H26zM28 28H4a2.0021 2.0021 0 01-2-2V20a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0128 28zM4 20v6H28V20zM2 12H30V14H2z"
  })), children);
});
var InstanceVirtual24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceVirtual24(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle26 || (_circle26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "23",
    r: "1"
  })), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 6H6V8H2zM8 6H12V8H8zM14 6H18V8H14zM20 6H24V8H20zM26 6H30V8H26zM28 28H4a2.0021 2.0021 0 01-2-2V20a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0128 28zM4 20v6H28V20zM2 12H30V14H2z"
  })), children);
});
var InstanceVirtual20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceVirtual20(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle27 || (_circle27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "23",
    r: "1"
  })), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 6H6V8H2zM8 6H12V8H8zM14 6H18V8H14zM20 6H24V8H20zM26 6H30V8H26zM28 28H4a2.0021 2.0021 0 01-2-2V20a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0128 28zM4 20v6H28V20zM2 12H30V14H2z"
  })), children);
});
var InstanceVirtual16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InstanceVirtual16(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle28 || (_circle28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "23",
    r: "1"
  })), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 6H6V8H2zM8 6H12V8H8zM14 6H18V8H14zM20 6H24V8H20zM26 6H30V8H26zM28 28H4a2.0021 2.0021 0 01-2-2V20a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0128 28zM4 20v6H28V20zM2 12H30V14H2z"
  })), children);
});
var Integration32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Integration32(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.88,15.52l-6-11A1,1,0,0,0,23,4H9a1,1,0,0,0-.88.52l-6,11a1,1,0,0,0,0,1l6,11A1,1,0,0,0,9,28H23a1,1,0,0,0,.88-.52l6-11A1,1,0,0,0,29.88,15.52ZM22.93,7l4.39,8h-9.5ZM16,14.14,10.82,6H21.18ZM9.07,7l5.11,8H4.68ZM4.68,17h9.5L9.07,25ZM16,17.86,21.18,26H10.82ZM22.93,25l-5.11-8h9.5Z"
  })), children);
});
var Integration24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Integration24(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.88,15.52l-6-11A1,1,0,0,0,23,4H9a1,1,0,0,0-.88.52l-6,11a1,1,0,0,0,0,1l6,11A1,1,0,0,0,9,28H23a1,1,0,0,0,.88-.52l6-11A1,1,0,0,0,29.88,15.52ZM22.93,7l4.39,8h-9.5ZM16,14.14,10.82,6H21.18ZM9.07,7l5.11,8H4.68ZM4.68,17h9.5L9.07,25ZM16,17.86,21.18,26H10.82ZM22.93,25l-5.11-8h9.5Z"
  })), children);
});
var Integration20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Integration20(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.88,15.52l-6-11A1,1,0,0,0,23,4H9a1,1,0,0,0-.88.52l-6,11a1,1,0,0,0,0,1l6,11A1,1,0,0,0,9,28H23a1,1,0,0,0,.88-.52l6-11A1,1,0,0,0,29.88,15.52ZM22.93,7l4.39,8h-9.5ZM16,14.14,10.82,6H21.18ZM9.07,7l5.11,8H4.68ZM4.68,17h9.5L9.07,25ZM16,17.86,21.18,26H10.82ZM22.93,25l-5.11-8h9.5Z"
  })), children);
});
var Integration16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Integration16(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.88,15.52l-6-11A1,1,0,0,0,23,4H9a1,1,0,0,0-.88.52l-6,11a1,1,0,0,0,0,1l6,11A1,1,0,0,0,9,28H23a1,1,0,0,0,.88-.52l6-11A1,1,0,0,0,29.88,15.52ZM22.93,7l4.39,8h-9.5ZM16,14.14,10.82,6H21.18ZM9.07,7l5.11,8H4.68ZM4.68,17h9.5L9.07,25ZM16,17.86,21.18,26H10.82ZM22.93,25l-5.11-8h9.5Z"
  })), children);
});
var IntentRequestActive32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestActive32(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 27.2L20.4 24.6 19 26 23 30 31 22 29.6 20.6z"
  })), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestActive24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestActive24(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 27.2L20.4 24.6 19 26 23 30 31 22 29.6 20.6z"
  })), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestActive20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestActive20(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 27.2L20.4 24.6 19 26 23 30 31 22 29.6 20.6z"
  })), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestActive16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestActive16(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 27.2L20.4 24.6 19 26 23 30 31 22 29.6 20.6z"
  })), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestCreate32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestCreate32(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 24L26 24 26 20 24 20 24 24 20 24 20 26 24 26 24 30 26 30 26 26 30 26z"
  })), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestCreate24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestCreate24(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 24L26 24 26 20 24 20 24 24 20 24 20 26 24 26 24 30 26 30 26 26 30 26z"
  })), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestCreate20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestCreate20(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 24L26 24 26 20 24 20 24 24 20 24 20 26 24 26 24 30 26 30 26 26 30 26z"
  })), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestCreate16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestCreate16(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 24L26 24 26 20 24 20 24 24 20 24 20 26 24 26 24 30 26 30 26 26 30 26z"
  })), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestHeal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestHeal32(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,20c-0.8,0-1.5,0.3-2.1,0.9l-0.4,0.5l-0.4-0.5C23.5,20.3,22.7,20,22,20s-1.5,0.3-2.1,0.9c-1.2,1.2-1.2,3.1,0,4.3l4.6,4.8\tl4.6-4.8c1.2-1.2,1.2-3.1,0-4.3C28.6,20.3,27.8,20,27,20L27,20z"
  })), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.6,28.6L4,16L16,4l12.6,12.6l1.4-1.4L17.5,2.6c-0.8-0.8-2.1-0.8-2.9,0L2.6,14.5c-0.8,0.8-0.8,2.1,0,2.9L15.1,30\tL16.6,28.6z"
  })), children);
});
var IntentRequestHeal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestHeal24(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,20c-0.8,0-1.5,0.3-2.1,0.9l-0.4,0.5l-0.4-0.5C23.5,20.3,22.7,20,22,20s-1.5,0.3-2.1,0.9c-1.2,1.2-1.2,3.1,0,4.3l4.6,4.8\tl4.6-4.8c1.2-1.2,1.2-3.1,0-4.3C28.6,20.3,27.8,20,27,20L27,20z"
  })), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.6,28.6L4,16L16,4l12.6,12.6l1.4-1.4L17.5,2.6c-0.8-0.8-2.1-0.8-2.9,0L2.6,14.5c-0.8,0.8-0.8,2.1,0,2.9L15.1,30\tL16.6,28.6z"
  })), children);
});
var IntentRequestHeal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestHeal20(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,20c-0.8,0-1.5,0.3-2.1,0.9l-0.4,0.5l-0.4-0.5C23.5,20.3,22.7,20,22,20s-1.5,0.3-2.1,0.9c-1.2,1.2-1.2,3.1,0,4.3l4.6,4.8\tl4.6-4.8c1.2-1.2,1.2-3.1,0-4.3C28.6,20.3,27.8,20,27,20L27,20z"
  })), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.6,28.6L4,16L16,4l12.6,12.6l1.4-1.4L17.5,2.6c-0.8-0.8-2.1-0.8-2.9,0L2.6,14.5c-0.8,0.8-0.8,2.1,0,2.9L15.1,30\tL16.6,28.6z"
  })), children);
});
var IntentRequestHeal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestHeal16(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,20c-0.8,0-1.5,0.3-2.1,0.9l-0.4,0.5l-0.4-0.5C23.5,20.3,22.7,20,22,20s-1.5,0.3-2.1,0.9c-1.2,1.2-1.2,3.1,0,4.3l4.6,4.8\tl4.6-4.8c1.2-1.2,1.2-3.1,0-4.3C28.6,20.3,27.8,20,27,20L27,20z"
  })), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.6,28.6L4,16L16,4l12.6,12.6l1.4-1.4L17.5,2.6c-0.8-0.8-2.1-0.8-2.9,0L2.6,14.5c-0.8,0.8-0.8,2.1,0,2.9L15.1,30\tL16.6,28.6z"
  })), children);
});
var IntentRequestInactive32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestInactive32(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle29 || (_circle29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18.5",
    cy: "22.5",
    r: "1.5"
  })), _circle30 || (_circle30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23.5",
    cy: "22.5",
    r: "1.5"
  })), _circle31 || (_circle31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28.5",
    cy: "22.5",
    r: "1.5"
  })), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestInactive24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestInactive24(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle32 || (_circle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18.5",
    cy: "22.5",
    r: "1.5"
  })), _circle33 || (_circle33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23.5",
    cy: "22.5",
    r: "1.5"
  })), _circle34 || (_circle34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28.5",
    cy: "22.5",
    r: "1.5"
  })), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestInactive20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestInactive20(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle35 || (_circle35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18.5",
    cy: "22.5",
    r: "1.5"
  })), _circle36 || (_circle36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23.5",
    cy: "22.5",
    r: "1.5"
  })), _circle37 || (_circle37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28.5",
    cy: "22.5",
    r: "1.5"
  })), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestInactive16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestInactive16(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle38 || (_circle38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18.5",
    cy: "22.5",
    r: "1.5"
  })), _circle39 || (_circle39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23.5",
    cy: "22.5",
    r: "1.5"
  })), _circle40 || (_circle40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28.5",
    cy: "22.5",
    r: "1.5"
  })), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestScaleIn32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestScaleIn32(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.6 30L30 28.6 22.4 21 29 21 29 19 19 19 19 29 21 29 21 22.4zM2 28.6L3.4 30 11 22.4 11 29 13 29 13 19 3 19 3 21 9.6 21zM17 2L15 2 15 12.2 10.4 7.6 9 9 16 16 23 9 21.6 7.6 17 12.2z"
  })), children);
});
var IntentRequestScaleIn24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestScaleIn24(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.6 30L30 28.6 22.4 21 29 21 29 19 19 19 19 29 21 29 21 22.4zM2 28.6L3.4 30 11 22.4 11 29 13 29 13 19 3 19 3 21 9.6 21zM17 2L15 2 15 12.2 10.4 7.6 9 9 16 16 23 9 21.6 7.6 17 12.2z"
  })), children);
});
var IntentRequestScaleIn20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestScaleIn20(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.6 30L30 28.6 22.4 21 29 21 29 19 19 19 19 29 21 29 21 22.4zM2 28.6L3.4 30 11 22.4 11 29 13 29 13 19 3 19 3 21 9.6 21zM17 2L15 2 15 12.2 10.4 7.6 9 9 16 16 23 9 21.6 7.6 17 12.2z"
  })), children);
});
var IntentRequestScaleIn16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestScaleIn16(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.6 30L30 28.6 22.4 21 29 21 29 19 19 19 19 29 21 29 21 22.4zM2 28.6L3.4 30 11 22.4 11 29 13 29 13 19 3 19 3 21 9.6 21zM17 2L15 2 15 12.2 10.4 7.6 9 9 16 16 23 9 21.6 7.6 17 12.2z"
  })), children);
});
var IntentRequestScaleOut32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestScaleOut32(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 20.4L20.4 19 28 26.6 28 20 30 20 30 30 20 30 20 28 26.6 28zM13 20.4L11.6 19 4 26.6 4 20 2 20 2 30 12 30 12 28 5.4 28zM17 16L15 16 15 5.8 10.4 10.4 9 9 16 2 23 9 21.6 10.4 17 5.8z"
  })), children);
});
var IntentRequestScaleOut24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestScaleOut24(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 20.4L20.4 19 28 26.6 28 20 30 20 30 30 20 30 20 28 26.6 28zM13 20.4L11.6 19 4 26.6 4 20 2 20 2 30 12 30 12 28 5.4 28zM17 16L15 16 15 5.8 10.4 10.4 9 9 16 2 23 9 21.6 10.4 17 5.8z"
  })), children);
});
var IntentRequestScaleOut20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestScaleOut20(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 20.4L20.4 19 28 26.6 28 20 30 20 30 30 20 30 20 28 26.6 28zM13 20.4L11.6 19 4 26.6 4 20 2 20 2 30 12 30 12 28 5.4 28zM17 16L15 16 15 5.8 10.4 10.4 9 9 16 2 23 9 21.6 10.4 17 5.8z"
  })), children);
});
var IntentRequestScaleOut16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestScaleOut16(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 20.4L20.4 19 28 26.6 28 20 30 20 30 30 20 30 20 28 26.6 28zM13 20.4L11.6 19 4 26.6 4 20 2 20 2 30 12 30 12 28 5.4 28zM17 16L15 16 15 5.8 10.4 10.4 9 9 16 2 23 9 21.6 10.4 17 5.8z"
  })), children);
});
var IntentRequestUninstall32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestUninstall32(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 21.4L28.6 20 25 23.6 21.4 20 20 21.4 23.6 25 20 28.6 21.4 30 25 26.4 28.6 30 30 28.6 26.4 25z"
  })), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestUninstall24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestUninstall24(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 21.4L28.6 20 25 23.6 21.4 20 20 21.4 23.6 25 20 28.6 21.4 30 25 26.4 28.6 30 30 28.6 26.4 25z"
  })), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestUninstall20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestUninstall20(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 21.4L28.6 20 25 23.6 21.4 20 20 21.4 23.6 25 20 28.6 21.4 30 25 26.4 28.6 30 30 28.6 26.4 25z"
  })), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestUninstall16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestUninstall16(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 21.4L28.6 20 25 23.6 21.4 20 20 21.4 23.6 25 20 28.6 21.4 30 25 26.4 28.6 30 30 28.6 26.4 25z"
  })), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestUpgrade32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestUpgrade32(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 23L26.6 24.4 24 21.8 24 30 22 30 22 21.8 19.4 24.4 18 23 23 18z"
  })), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestUpgrade24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestUpgrade24(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 23L26.6 24.4 24 21.8 24 30 22 30 22 21.8 19.4 24.4 18 23 23 18z"
  })), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestUpgrade20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestUpgrade20(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 23L26.6 24.4 24 21.8 24 30 22 30 22 21.8 19.4 24.4 18 23 23 18z"
  })), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var IntentRequestUpgrade16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntentRequestUpgrade16(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 23L26.6 24.4 24 21.8 24 30 22 30 22 21.8 19.4 24.4 18 23 23 18z"
  })), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4,30L5,23.8c-0.6-0.4-1-1-1-1.7V9.9c0-0.7,0.4-1.4,1-1.7l10-5.9C15.3,2.1,15.6,2,16,2c0.4,0,0.7,0.1,1,0.3l10,5.9\tc0.6,0.4,1,1,1,1.7V16h-2V9.9L16,4L6,9.9v12.2l10.5,6.2L15.4,30z"
  })), children);
});
var Interactions32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Interactions32(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 18H22V14H20V28h6a2.0027 2.0027 0 002-2V20A2.0023 2.0023 0 0026 18zm-4 8V20h4v6zM20 6.076L19.256 4.219 16 5.522 16 2 14 2 14 5.523 10.744 4.22 10 6.077 13.417 7.444 10.9 10.8 12.5 12 15 8.667 17.5 12 19.1 10.8 16.583 7.443 20 6.076zM10 18H5v2h5v2H6a2 2 0 00-2 2v2a2 2 0 002 2h6V20A2.0023 2.0023 0 0010 18zm0 8H6V24h4z"
  })), children);
});
var Interactions24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Interactions24(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 18H22V14H20V28h6a2.0027 2.0027 0 002-2V20A2.0023 2.0023 0 0026 18zm-4 8V20h4v6zM20 6.076L19.256 4.219 16 5.522 16 2 14 2 14 5.523 10.744 4.22 10 6.077 13.417 7.444 10.9 10.8 12.5 12 15 8.667 17.5 12 19.1 10.8 16.583 7.443 20 6.076zM10 18H5v2h5v2H6a2 2 0 00-2 2v2a2 2 0 002 2h6V20A2.0023 2.0023 0 0010 18zm0 8H6V24h4z"
  })), children);
});
var Interactions20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Interactions20(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 18H22V14H20V28h6a2.0027 2.0027 0 002-2V20A2.0023 2.0023 0 0026 18zm-4 8V20h4v6zM20 6.076L19.256 4.219 16 5.522 16 2 14 2 14 5.523 10.744 4.22 10 6.077 13.417 7.444 10.9 10.8 12.5 12 15 8.667 17.5 12 19.1 10.8 16.583 7.443 20 6.076zM10 18H5v2h5v2H6a2 2 0 00-2 2v2a2 2 0 002 2h6V20A2.0023 2.0023 0 0010 18zm0 8H6V24h4z"
  })), children);
});
var Interactions16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Interactions16(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M11,7 L11,9 L13,9 C13.5522847,9 14,9.44771525 14,10 L14,10 L14,13 C14,13.5522847 13.5522847,14 13,14 L13,14 L10,14 L10,7 L11,7 Z M5,9 C5.55228475,9 6,9.44771525 6,10 L6,10 L6,14 L3,14 C2.44771525,14 2,13.5522847 2,13 L2,13 L2,12 C2,11.4477153 2.44771525,11 3,11 L3,11 L5,11 L5,10 L2.5,10 L2.5,9 Z M13,10 L11,10 L11,13 L13,13 L13,10 Z M5,12 L3,12 L3,13 L5,13 L5,12 Z M7.912,2 L7.834,3.911 L9.628,3.248 L9.914,4.119 L8.068,4.626 L9.251,6.134 L8.523,6.667 L7.457,5.068 L6.391,6.667 L5.663,6.134 L6.846,4.626 L5,4.119 L5.286,3.248 L7.08,3.911 L7.002,2 L7.912,2 Z"
  })), children);
});
var WatsonHealthInteractiveSegmentationCursor32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthInteractiveSegmentationCursor32(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4139,24,15.9989,10.5663a2.0473,2.0473,0,0,0-2.8281,0l-2.586,2.586a2.0023,2.0023,0,0,0,0,2.8283L23.9989,29.4145a2.0021,2.0021,0,0,0,2.8281,0l2.5869-2.5865a1.9993,1.9993,0,0,0,0-2.8283Zm-17.415-9.4335,2.5859-2.5859,3.5,3.5L15.498,18.0676l-3.5-3.5ZM25.413,28l-8.5009-8.5188,2.5867-2.587L28,25.4143Z"
  })), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.586 18.586H10.414V21.413999999999998H7.586z",
    transform: "rotate(-45 9 20)"
  })), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.586 7.586H21.413999999999998V10.414H18.586z",
    transform: "rotate(-45 20 9)"
  })), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.586 7.586H10.414V10.414H7.586z",
    transform: "rotate(-45 9 9)"
  })), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 2L2 2 2 11 4 11 4 4 11 4 11 2z"
  })), children);
});
var WatsonHealthInteractiveSegmentationCursor24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthInteractiveSegmentationCursor24(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4139,24,15.9989,10.5663a2.0473,2.0473,0,0,0-2.8281,0l-2.586,2.586a2.0023,2.0023,0,0,0,0,2.8283L23.9989,29.4145a2.0021,2.0021,0,0,0,2.8281,0l2.5869-2.5865a1.9993,1.9993,0,0,0,0-2.8283Zm-17.415-9.4335,2.5859-2.5859,3.5,3.5L15.498,18.0676l-3.5-3.5ZM25.413,28l-8.5009-8.5188,2.5867-2.587L28,25.4143Z"
  })), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.586 18.586H10.414V21.413999999999998H7.586z",
    transform: "rotate(-45 9 20)"
  })), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.586 7.586H21.413999999999998V10.414H18.586z",
    transform: "rotate(-45 20 9)"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.586 7.586H10.414V10.414H7.586z",
    transform: "rotate(-45 9 9)"
  })), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 2L2 2 2 11 4 11 4 4 11 4 11 2z"
  })), children);
});
var WatsonHealthInteractiveSegmentationCursor20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthInteractiveSegmentationCursor20(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4139,24,15.9989,10.5663a2.0473,2.0473,0,0,0-2.8281,0l-2.586,2.586a2.0023,2.0023,0,0,0,0,2.8283L23.9989,29.4145a2.0021,2.0021,0,0,0,2.8281,0l2.5869-2.5865a1.9993,1.9993,0,0,0,0-2.8283Zm-17.415-9.4335,2.5859-2.5859,3.5,3.5L15.498,18.0676l-3.5-3.5ZM25.413,28l-8.5009-8.5188,2.5867-2.587L28,25.4143Z"
  })), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.586 18.586H10.414V21.413999999999998H7.586z",
    transform: "rotate(-45 9 20)"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.586 7.586H21.413999999999998V10.414H18.586z",
    transform: "rotate(-45 20 9)"
  })), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.586 7.586H10.414V10.414H7.586z",
    transform: "rotate(-45 9 9)"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 2L2 2 2 11 4 11 4 4 11 4 11 2z"
  })), children);
});
var WatsonHealthInteractiveSegmentationCursor16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthInteractiveSegmentationCursor16(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4139,24,15.9989,10.5663a2.0473,2.0473,0,0,0-2.8281,0l-2.586,2.586a2.0023,2.0023,0,0,0,0,2.8283L23.9989,29.4145a2.0021,2.0021,0,0,0,2.8281,0l2.5869-2.5865a1.9993,1.9993,0,0,0,0-2.8283Zm-17.415-9.4335,2.5859-2.5859,3.5,3.5L15.498,18.0676l-3.5-3.5ZM25.413,28l-8.5009-8.5188,2.5867-2.587L28,25.4143Z"
  })), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.586 18.586H10.414V21.413999999999998H7.586z",
    transform: "rotate(-45 9 20)"
  })), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.586 7.586H21.413999999999998V10.414H18.586z",
    transform: "rotate(-45 20 9)"
  })), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.586 7.586H10.414V10.414H7.586z",
    transform: "rotate(-45 9 9)"
  })), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 2L2 2 2 11 4 11 4 4 11 4 11 2z"
  })), children);
});
var Intersect32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Intersect32(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 24H18V22h4V18h2v4A2.0021 2.0021 0 0122 24zM10 14H8V10a2.0022 2.0022 0 012-2h4v2H10z"
  })), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H24V4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V22a2.0023,2.0023,0,0,0,2,2H8v4a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V10A2.0023,2.0023,0,0,0,28,8Zm0,20H10V24h4V22H10V18H8v4H4V4H22V8H18v2h4v4h2V10h4Z"
  })), children);
});
var Intersect24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Intersect24(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 24H18V22h4V18h2v4A2.0021 2.0021 0 0122 24zM10 14H8V10a2.0022 2.0022 0 012-2h4v2H10z"
  })), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H24V4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V22a2.0023,2.0023,0,0,0,2,2H8v4a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V10A2.0023,2.0023,0,0,0,28,8Zm0,20H10V24h4V22H10V18H8v4H4V4H22V8H18v2h4v4h2V10h4Z"
  })), children);
});
var Intersect20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Intersect20(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 24H18V22h4V18h2v4A2.0021 2.0021 0 0122 24zM10 14H8V10a2.0022 2.0022 0 012-2h4v2H10z"
  })), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H24V4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V22a2.0023,2.0023,0,0,0,2,2H8v4a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V10A2.0023,2.0023,0,0,0,28,8Zm0,20H10V24h4V22H10V18H8v4H4V4H22V8H18v2h4v4h2V10h4Z"
  })), children);
});
var Intersect16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Intersect16(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 24H18V22h4V18h2v4A2.0021 2.0021 0 0122 24zM10 14H8V10a2.0022 2.0022 0 012-2h4v2H10z"
  })), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H24V4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V22a2.0023,2.0023,0,0,0,2,2H8v4a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V10A2.0023,2.0023,0,0,0,28,8Zm0,20H10V24h4V22H10V18H8v4H4V4H22V8H18v2h4v4h2V10h4Z"
  })), children);
});
var IntrusionPrevention32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntrusionPrevention32(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle41 || (_circle41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "23.887",
    r: "2"
  })), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769 23.4785A8.64 8.64 0 0022 18a8.64 8.64 0 00-7.7769 5.4785L14 24l.2231.5215A8.64 8.64 0 0022 30a8.64 8.64 0 007.7769-5.4785L30 24zM22 28a4 4 0 114-4A4.0045 4.0045 0 0122 28zM25 10H4A2.0021 2.0021 0 012 8V4A2.0021 2.0021 0 014 2H25a2.0021 2.0021 0 012 2V8A2.0021 2.0021 0 0125 10zM4 4V8H25V4zM12 28H4V24h8V22H4a2.0023 2.0023 0 00-2 2v4a2.0023 2.0023 0 002 2h8z"
  })), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12H7a2.0023,2.0023,0,0,0-2,2v4a2.0023,2.0023,0,0,0,2,2h5V18H7V14H28l.0007,2H30V14A2.0023,2.0023,0,0,0,28,12Z"
  })), children);
});
var IntrusionPrevention24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntrusionPrevention24(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle42 || (_circle42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "23.887",
    r: "2"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769 23.4785A8.64 8.64 0 0022 18a8.64 8.64 0 00-7.7769 5.4785L14 24l.2231.5215A8.64 8.64 0 0022 30a8.64 8.64 0 007.7769-5.4785L30 24zM22 28a4 4 0 114-4A4.0045 4.0045 0 0122 28zM25 10H4A2.0021 2.0021 0 012 8V4A2.0021 2.0021 0 014 2H25a2.0021 2.0021 0 012 2V8A2.0021 2.0021 0 0125 10zM4 4V8H25V4zM12 28H4V24h8V22H4a2.0023 2.0023 0 00-2 2v4a2.0023 2.0023 0 002 2h8z"
  })), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12H7a2.0023,2.0023,0,0,0-2,2v4a2.0023,2.0023,0,0,0,2,2h5V18H7V14H28l.0007,2H30V14A2.0023,2.0023,0,0,0,28,12Z"
  })), children);
});
var IntrusionPrevention20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntrusionPrevention20(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle43 || (_circle43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "23.887",
    r: "2"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769 23.4785A8.64 8.64 0 0022 18a8.64 8.64 0 00-7.7769 5.4785L14 24l.2231.5215A8.64 8.64 0 0022 30a8.64 8.64 0 007.7769-5.4785L30 24zM22 28a4 4 0 114-4A4.0045 4.0045 0 0122 28zM25 10H4A2.0021 2.0021 0 012 8V4A2.0021 2.0021 0 014 2H25a2.0021 2.0021 0 012 2V8A2.0021 2.0021 0 0125 10zM4 4V8H25V4zM12 28H4V24h8V22H4a2.0023 2.0023 0 00-2 2v4a2.0023 2.0023 0 002 2h8z"
  })), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12H7a2.0023,2.0023,0,0,0-2,2v4a2.0023,2.0023,0,0,0,2,2h5V18H7V14H28l.0007,2H30V14A2.0023,2.0023,0,0,0,28,12Z"
  })), children);
});
var IntrusionPrevention16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IntrusionPrevention16(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle44 || (_circle44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "23.887",
    r: "2"
  })), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769 23.4785A8.64 8.64 0 0022 18a8.64 8.64 0 00-7.7769 5.4785L14 24l.2231.5215A8.64 8.64 0 0022 30a8.64 8.64 0 007.7769-5.4785L30 24zM22 28a4 4 0 114-4A4.0045 4.0045 0 0122 28zM25 10H4A2.0021 2.0021 0 012 8V4A2.0021 2.0021 0 014 2H25a2.0021 2.0021 0 012 2V8A2.0021 2.0021 0 0125 10zM4 4V8H25V4zM12 28H4V24h8V22H4a2.0023 2.0023 0 00-2 2v4a2.0023 2.0023 0 002 2h8z"
  })), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12H7a2.0023,2.0023,0,0,0-2,2v4a2.0023,2.0023,0,0,0,2,2h5V18H7V14H28l.0007,2H30V14A2.0023,2.0023,0,0,0,28,12Z"
  })), children);
});
var InventoryManagement32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InventoryManagement32(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 24H23V28H19zM26 24H30V28H26zM19 17H23V21H19zM26 17H30V21H26z"
  })), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,24H4V10H28v5h2V10a2.0023,2.0023,0,0,0-2-2H22V4a2.0023,2.0023,0,0,0-2-2H12a2.002,2.002,0,0,0-2,2V8H4a2.002,2.002,0,0,0-2,2V24a2.0023,2.0023,0,0,0,2,2H17ZM12,4h8V8H12Z"
  })), children);
});
var InventoryManagement24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InventoryManagement24(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 24H23V28H19zM26 24H30V28H26zM19 17H23V21H19zM26 17H30V21H26z"
  })), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,24H4V10H28v5h2V10a2.0023,2.0023,0,0,0-2-2H22V4a2.0023,2.0023,0,0,0-2-2H12a2.002,2.002,0,0,0-2,2V8H4a2.002,2.002,0,0,0-2,2V24a2.0023,2.0023,0,0,0,2,2H17ZM12,4h8V8H12Z"
  })), children);
});
var InventoryManagement20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InventoryManagement20(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 24H23V28H19zM26 24H30V28H26zM19 17H23V21H19zM26 17H30V21H26z"
  })), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,24H4V10H28v5h2V10a2.0023,2.0023,0,0,0-2-2H22V4a2.0023,2.0023,0,0,0-2-2H12a2.002,2.002,0,0,0-2,2V8H4a2.002,2.002,0,0,0-2,2V24a2.0023,2.0023,0,0,0,2,2H17ZM12,4h8V8H12Z"
  })), children);
});
var InventoryManagement16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function InventoryManagement16(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 24H23V28H19zM26 24H30V28H26zM19 17H23V21H19zM26 17H30V21H26z"
  })), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,24H4V10H28v5h2V10a2.0023,2.0023,0,0,0-2-2H22V4a2.0023,2.0023,0,0,0-2-2H12a2.002,2.002,0,0,0-2,2V8H4a2.002,2.002,0,0,0-2,2V24a2.0023,2.0023,0,0,0,2,2H17ZM12,4h8V8H12Z"
  })), children);
});
var IotConnect32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IotConnect32(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,19H26V15H24v9H8V8l9-.0009V6H13V2H11V6H8A2.002,2.002,0,0,0,6,8v3H2v2H6v6H2v2H6v3a2.0023,2.0023,0,0,0,2,2h3v4h2V26h6v4h2V26h3a2.0027,2.0027,0,0,0,2-2V21h4Z"
  })), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2a4.0042,4.0042,0,0,0-4,4,3.9556,3.9556,0,0,0,.5668,2.0192L19.5859,11H11V21H21V12.4141l2.9808-2.9808A3.9553,3.9553,0,0,0,26,10a4,4,0,0,0,0-8ZM19,19H13V13h6ZM26,8a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,26,8Z"
  })), children);
});
var IotConnect24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IotConnect24(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,19H26V15H24v9H8V8l9-.0009V6H13V2H11V6H8A2.002,2.002,0,0,0,6,8v3H2v2H6v6H2v2H6v3a2.0023,2.0023,0,0,0,2,2h3v4h2V26h6v4h2V26h3a2.0027,2.0027,0,0,0,2-2V21h4Z"
  })), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2a4.0042,4.0042,0,0,0-4,4,3.9556,3.9556,0,0,0,.5668,2.0192L19.5859,11H11V21H21V12.4141l2.9808-2.9808A3.9553,3.9553,0,0,0,26,10a4,4,0,0,0,0-8ZM19,19H13V13h6ZM26,8a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,26,8Z"
  })), children);
});
var IotConnect20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IotConnect20(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,19H26V15H24v9H8V8l9-.0009V6H13V2H11V6H8A2.002,2.002,0,0,0,6,8v3H2v2H6v6H2v2H6v3a2.0023,2.0023,0,0,0,2,2h3v4h2V26h6v4h2V26h3a2.0027,2.0027,0,0,0,2-2V21h4Z"
  })), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2a4.0042,4.0042,0,0,0-4,4,3.9556,3.9556,0,0,0,.5668,2.0192L19.5859,11H11V21H21V12.4141l2.9808-2.9808A3.9553,3.9553,0,0,0,26,10a4,4,0,0,0,0-8ZM19,19H13V13h6ZM26,8a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,26,8Z"
  })), children);
});
var IotConnect16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IotConnect16(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,19H26V15H24v9H8V8l9-.0009V6H13V2H11V6H8A2.002,2.002,0,0,0,6,8v3H2v2H6v6H2v2H6v3a2.0023,2.0023,0,0,0,2,2h3v4h2V26h6v4h2V26h3a2.0027,2.0027,0,0,0,2-2V21h4Z"
  })), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2a4.0042,4.0042,0,0,0-4,4,3.9556,3.9556,0,0,0,.5668,2.0192L19.5859,11H11V21H21V12.4141l2.9808-2.9808A3.9553,3.9553,0,0,0,26,10a4,4,0,0,0,0-8ZM19,19H13V13h6ZM26,8a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,26,8Z"
  })), children);
});
var IotPlatform32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IotPlatform32(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,19H26V15H24v9H8V8l9-.0009V6H13V2H11V6H8A2.002,2.002,0,0,0,6,8v3H2v2H6v6H2v2H6v3a2.0023,2.0023,0,0,0,2,2h3v4h2V26h6v4h2V26h3a2.0027,2.0027,0,0,0,2-2V21h4Z"
  })), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 21H11V11H21zm-8-2h6V13H13zM31 13H29A10.0117 10.0117 0 0019 3V1A12.0131 12.0131 0 0131 13z"
  })), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,13H24a5.0059,5.0059,0,0,0-5-5V6A7.0085,7.0085,0,0,1,26,13Z"
  })), children);
});
var IotPlatform24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IotPlatform24(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,19H26V15H24v9H8V8l9-.0009V6H13V2H11V6H8A2.002,2.002,0,0,0,6,8v3H2v2H6v6H2v2H6v3a2.0023,2.0023,0,0,0,2,2h3v4h2V26h6v4h2V26h3a2.0027,2.0027,0,0,0,2-2V21h4Z"
  })), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 21H11V11H21zm-8-2h6V13H13zM31 13H29A10.0117 10.0117 0 0019 3V1A12.0131 12.0131 0 0131 13z"
  })), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,13H24a5.0059,5.0059,0,0,0-5-5V6A7.0085,7.0085,0,0,1,26,13Z"
  })), children);
});
var IotPlatform20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IotPlatform20(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,19H26V15H24v9H8V8l9-.0009V6H13V2H11V6H8A2.002,2.002,0,0,0,6,8v3H2v2H6v6H2v2H6v3a2.0023,2.0023,0,0,0,2,2h3v4h2V26h6v4h2V26h3a2.0027,2.0027,0,0,0,2-2V21h4Z"
  })), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 21H11V11H21zm-8-2h6V13H13zM31 13H29A10.0117 10.0117 0 0019 3V1A12.0131 12.0131 0 0131 13z"
  })), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,13H24a5.0059,5.0059,0,0,0-5-5V6A7.0085,7.0085,0,0,1,26,13Z"
  })), children);
});
var IotPlatform16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IotPlatform16(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,19H26V15H24v9H8V8l9-.0009V6H13V2H11V6H8A2.002,2.002,0,0,0,6,8v3H2v2H6v6H2v2H6v3a2.0023,2.0023,0,0,0,2,2h3v4h2V26h6v4h2V26h3a2.0027,2.0027,0,0,0,2-2V21h4Z"
  })), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 21H11V11H21zm-8-2h6V13H13zM31 13H29A10.0117 10.0117 0 0019 3V1A12.0131 12.0131 0 0131 13z"
  })), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,13H24a5.0059,5.0059,0,0,0-5-5V6A7.0085,7.0085,0,0,1,26,13Z"
  })), children);
});
var Iso32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Iso32(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 23H24a2 2 0 01-2-2V11a2 2 0 012-2h4a2 2 0 012 2V21A2 2 0 0128 23zM24 11V21h4V11zM18 23H12V21h6V17H14a2 2 0 01-2-2V11a2 2 0 012-2h6v2H14v4h4a2 2 0 012 2v4A2 2 0 0118 23zM2 11L5 11 5 21 2 21 2 23 10 23 10 21 7 21 7 11 10 11 10 9 2 9 2 11z"
  })), children);
});
var Iso24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Iso24(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 23H24a2 2 0 01-2-2V11a2 2 0 012-2h4a2 2 0 012 2V21A2 2 0 0128 23zM24 11V21h4V11zM18 23H12V21h6V17H14a2 2 0 01-2-2V11a2 2 0 012-2h6v2H14v4h4a2 2 0 012 2v4A2 2 0 0118 23zM2 11L5 11 5 21 2 21 2 23 10 23 10 21 7 21 7 11 10 11 10 9 2 9 2 11z"
  })), children);
});
var Iso20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Iso20(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 23H24a2 2 0 01-2-2V11a2 2 0 012-2h4a2 2 0 012 2V21A2 2 0 0128 23zM24 11V21h4V11zM18 23H12V21h6V17H14a2 2 0 01-2-2V11a2 2 0 012-2h6v2H14v4h4a2 2 0 012 2v4A2 2 0 0118 23zM2 11L5 11 5 21 2 21 2 23 10 23 10 21 7 21 7 11 10 11 10 9 2 9 2 11z"
  })), children);
});
var Iso16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Iso16(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 23H24a2 2 0 01-2-2V11a2 2 0 012-2h4a2 2 0 012 2V21A2 2 0 0128 23zM24 11V21h4V11zM18 23H12V21h6V17H14a2 2 0 01-2-2V11a2 2 0 012-2h6v2H14v4h4a2 2 0 012 2v4A2 2 0 0118 23zM2 11L5 11 5 21 2 21 2 23 10 23 10 21 7 21 7 11 10 11 10 9 2 9 2 11z"
  })), children);
});
var IsoFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IsoFilled32(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 13H24V19H21z"
  })), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM8,21H6V11H8Zm9-8H12v2h3a2,2,0,0,1,2,2v2a2,2,0,0,1-2,2H10V19h5V17H12a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h5Zm9,6a2,2,0,0,1-2,2H21a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h3a2,2,0,0,1,2,2Z"
  })), children);
});
var IsoFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IsoFilled24(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 13H24V19H21z"
  })), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM8,21H6V11H8Zm9-8H12v2h3a2,2,0,0,1,2,2v2a2,2,0,0,1-2,2H10V19h5V17H12a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h5Zm9,6a2,2,0,0,1-2,2H21a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h3a2,2,0,0,1,2,2Z"
  })), children);
});
var IsoFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IsoFilled20(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 13H24V19H21z"
  })), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM8,21H6V11H8Zm9-8H12v2h3a2,2,0,0,1,2,2v2a2,2,0,0,1-2,2H10V19h5V17H12a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h5Zm9,6a2,2,0,0,1-2,2H21a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h3a2,2,0,0,1,2,2Z"
  })), children);
});
var IsoFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IsoFilled16(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 13H24V19H21z"
  })), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM8,21H6V11H8Zm9-8H12v2h3a2,2,0,0,1,2,2v2a2,2,0,0,1-2,2H10V19h5V17H12a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h5Zm9,6a2,2,0,0,1-2,2H21a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h3a2,2,0,0,1,2,2Z"
  })), children);
});
var IsoOutline32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IsoOutline32(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21H21a2 2 0 01-2-2V13a2 2 0 012-2h3a2 2 0 012 2v6A2 2 0 0124 21zm-3-8v6h3V13zM15 21H10V19h5V17H12a2 2 0 01-2-2V13a2 2 0 012-2h5v2H12v2h3a2 2 0 012 2v2A2 2 0 0115 21zM6 11H8V21H6z"
  })), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM4,24V8H28V24Z"
  })), children);
});
var IsoOutline24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IsoOutline24(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21H21a2 2 0 01-2-2V13a2 2 0 012-2h3a2 2 0 012 2v6A2 2 0 0124 21zm-3-8v6h3V13zM15 21H10V19h5V17H12a2 2 0 01-2-2V13a2 2 0 012-2h5v2H12v2h3a2 2 0 012 2v2A2 2 0 0115 21zM6 11H8V21H6z"
  })), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM4,24V8H28V24Z"
  })), children);
});
var IsoOutline20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IsoOutline20(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21H21a2 2 0 01-2-2V13a2 2 0 012-2h3a2 2 0 012 2v6A2 2 0 0124 21zm-3-8v6h3V13zM15 21H10V19h5V17H12a2 2 0 01-2-2V13a2 2 0 012-2h5v2H12v2h3a2 2 0 012 2v2A2 2 0 0115 21zM6 11H8V21H6z"
  })), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM4,24V8H28V24Z"
  })), children);
});
var IsoOutline16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function IsoOutline16(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21H21a2 2 0 01-2-2V13a2 2 0 012-2h3a2 2 0 012 2v6A2 2 0 0124 21zm-3-8v6h3V13zM15 21H10V19h5V17H12a2 2 0 01-2-2V13a2 2 0 012-2h5v2H12v2h3a2 2 0 012 2v2A2 2 0 0115 21zM6 11H8V21H6z"
  })), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM4,24V8H28V24Z"
  })), children);
});
var JoinFull32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinFull32(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,9.0752a7.9941,7.9941,0,0,1,0,13.85,7.9941,7.9941,0,0,1,0-13.85m0-2.2373a9.9953,9.9953,0,0,0,0,18.3242A9.9953,9.9953,0,0,0,16,6.8379Z",
    "data-icon-path": "inner-path"
  })), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,16a9.9976,9.9976,0,0,1,6-9.1621,10,10,0,1,0,0,18.3242A9.9976,9.9976,0,0,1,10,16Z"
  })), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,9.0752a7.9941,7.9941,0,0,0,0,13.85,7.9941,7.9941,0,0,0,0-13.85Z"
  })), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.9539,9.9539,0,0,0-4,.8379,9.9953,9.9953,0,0,1,0,18.3242A9.9988,9.9988,0,1,0,20,6Z"
  })), children);
});
var JoinFull24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinFull24(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,9.0752a7.9941,7.9941,0,0,1,0,13.85,7.9941,7.9941,0,0,1,0-13.85m0-2.2373a9.9953,9.9953,0,0,0,0,18.3242A9.9953,9.9953,0,0,0,16,6.8379Z",
    "data-icon-path": "inner-path"
  })), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,16a9.9976,9.9976,0,0,1,6-9.1621,10,10,0,1,0,0,18.3242A9.9976,9.9976,0,0,1,10,16Z"
  })), _path390 || (_path390 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,9.0752a7.9941,7.9941,0,0,0,0,13.85,7.9941,7.9941,0,0,0,0-13.85Z"
  })), _path391 || (_path391 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.9539,9.9539,0,0,0-4,.8379,9.9953,9.9953,0,0,1,0,18.3242A9.9988,9.9988,0,1,0,20,6Z"
  })), children);
});
var JoinFull20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinFull20(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path392 || (_path392 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,9.0752a7.9941,7.9941,0,0,1,0,13.85,7.9941,7.9941,0,0,1,0-13.85m0-2.2373a9.9953,9.9953,0,0,0,0,18.3242A9.9953,9.9953,0,0,0,16,6.8379Z",
    "data-icon-path": "inner-path"
  })), _path393 || (_path393 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,16a9.9976,9.9976,0,0,1,6-9.1621,10,10,0,1,0,0,18.3242A9.9976,9.9976,0,0,1,10,16Z"
  })), _path394 || (_path394 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,9.0752a7.9941,7.9941,0,0,0,0,13.85,7.9941,7.9941,0,0,0,0-13.85Z"
  })), _path395 || (_path395 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.9539,9.9539,0,0,0-4,.8379,9.9953,9.9953,0,0,1,0,18.3242A9.9988,9.9988,0,1,0,20,6Z"
  })), children);
});
var JoinFull16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinFull16(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path396 || (_path396 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,9.0752a7.9941,7.9941,0,0,1,0,13.85,7.9941,7.9941,0,0,1,0-13.85m0-2.2373a9.9953,9.9953,0,0,0,0,18.3242A9.9953,9.9953,0,0,0,16,6.8379Z",
    "data-icon-path": "inner-path"
  })), _path397 || (_path397 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,16a9.9976,9.9976,0,0,1,6-9.1621,10,10,0,1,0,0,18.3242A9.9976,9.9976,0,0,1,10,16Z"
  })), _path398 || (_path398 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,9.0752a7.9941,7.9941,0,0,0,0,13.85,7.9941,7.9941,0,0,0,0-13.85Z"
  })), _path399 || (_path399 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.9539,9.9539,0,0,0-4,.8379,9.9953,9.9953,0,0,1,0,18.3242A9.9988,9.9988,0,1,0,20,6Z"
  })), children);
});
var JoinInner32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinInner32(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path400 || (_path400 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.9355,9.9355,0,0,0-4,.8418A9.999,9.999,0,1,0,16,25.16,9.998,9.998,0,1,0,20,6ZM12,24A8,8,0,1,1,13.7573,8.2017a9.9734,9.9734,0,0,0,0,15.5986A7.9919,7.9919,0,0,1,12,24Zm8,0a7.9919,7.9919,0,0,1-1.7573-.2,9.9734,9.9734,0,0,0,0-15.5986A7.9972,7.9972,0,1,1,20,24Z"
  })), children);
});
var JoinInner24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinInner24(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path401 || (_path401 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.9355,9.9355,0,0,0-4,.8418A9.999,9.999,0,1,0,16,25.16,9.998,9.998,0,1,0,20,6ZM12,24A8,8,0,1,1,13.7573,8.2017a9.9734,9.9734,0,0,0,0,15.5986A7.9919,7.9919,0,0,1,12,24Zm8,0a7.9919,7.9919,0,0,1-1.7573-.2,9.9734,9.9734,0,0,0,0-15.5986A7.9972,7.9972,0,1,1,20,24Z"
  })), children);
});
var JoinInner20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinInner20(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path402 || (_path402 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.9355,9.9355,0,0,0-4,.8418A9.999,9.999,0,1,0,16,25.16,9.998,9.998,0,1,0,20,6ZM12,24A8,8,0,1,1,13.7573,8.2017a9.9734,9.9734,0,0,0,0,15.5986A7.9919,7.9919,0,0,1,12,24Zm8,0a7.9919,7.9919,0,0,1-1.7573-.2,9.9734,9.9734,0,0,0,0-15.5986A7.9972,7.9972,0,1,1,20,24Z"
  })), children);
});
var JoinInner16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinInner16(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path403 || (_path403 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.9355,9.9355,0,0,0-4,.8418A9.999,9.999,0,1,0,16,25.16,9.998,9.998,0,1,0,20,6ZM12,24A8,8,0,1,1,13.7573,8.2017a9.9734,9.9734,0,0,0,0,15.5986A7.9919,7.9919,0,0,1,12,24Zm8,0a7.9919,7.9919,0,0,1-1.7573-.2,9.9734,9.9734,0,0,0,0-15.5986A7.9972,7.9972,0,1,1,20,24Z"
  })), children);
});
var JoinLeft32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinLeft32(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path404 || (_path404 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.9272,9.9272,0,0,0-3.9968.8394,9.9758,9.9758,0,0,1,2.2451,1.36,8,8,0,1,1,0,15.6016,9.9758,9.9758,0,0,1-2.2451,1.36A9.9976,9.9976,0,1,0,20,6Z"
  })), _path405 || (_path405 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,16a8.01,8.01,0,0,0,6.2483,7.8008,9.9858,9.9858,0,0,0,0-15.6016A8.01,8.01,0,0,0,12,16Z"
  })), _path406 || (_path406 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M12,16a8.01,8.01,0,0,1,6.2483-7.8008,9.9758,9.9758,0,0,0-2.2451-1.36,9.9909,9.9909,0,0,0,0,18.3212,9.9758,9.9758,0,0,0,2.2451-1.36A8.01,8.01,0,0,1,12,16Z",
    "data-icon-path": "inner-path"
  })), _path407 || (_path407 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,16a10.0105,10.0105,0,0,1,6.0032-9.1606,10,10,0,1,0,0,18.3212A10.0105,10.0105,0,0,1,10,16Z"
  })), children);
});
var JoinLeft24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinLeft24(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path408 || (_path408 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.9272,9.9272,0,0,0-3.9968.8394,9.9758,9.9758,0,0,1,2.2451,1.36,8,8,0,1,1,0,15.6016,9.9758,9.9758,0,0,1-2.2451,1.36A9.9976,9.9976,0,1,0,20,6Z"
  })), _path409 || (_path409 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,16a8.01,8.01,0,0,0,6.2483,7.8008,9.9858,9.9858,0,0,0,0-15.6016A8.01,8.01,0,0,0,12,16Z"
  })), _path410 || (_path410 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M12,16a8.01,8.01,0,0,1,6.2483-7.8008,9.9758,9.9758,0,0,0-2.2451-1.36,9.9909,9.9909,0,0,0,0,18.3212,9.9758,9.9758,0,0,0,2.2451-1.36A8.01,8.01,0,0,1,12,16Z",
    "data-icon-path": "inner-path"
  })), _path411 || (_path411 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,16a10.0105,10.0105,0,0,1,6.0032-9.1606,10,10,0,1,0,0,18.3212A10.0105,10.0105,0,0,1,10,16Z"
  })), children);
});
var JoinLeft20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinLeft20(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path412 || (_path412 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.9272,9.9272,0,0,0-3.9968.8394,9.9758,9.9758,0,0,1,2.2451,1.36,8,8,0,1,1,0,15.6016,9.9758,9.9758,0,0,1-2.2451,1.36A9.9976,9.9976,0,1,0,20,6Z"
  })), _path413 || (_path413 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,16a8.01,8.01,0,0,0,6.2483,7.8008,9.9858,9.9858,0,0,0,0-15.6016A8.01,8.01,0,0,0,12,16Z"
  })), _path414 || (_path414 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M12,16a8.01,8.01,0,0,1,6.2483-7.8008,9.9758,9.9758,0,0,0-2.2451-1.36,9.9909,9.9909,0,0,0,0,18.3212,9.9758,9.9758,0,0,0,2.2451-1.36A8.01,8.01,0,0,1,12,16Z",
    "data-icon-path": "inner-path"
  })), _path415 || (_path415 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,16a10.0105,10.0105,0,0,1,6.0032-9.1606,10,10,0,1,0,0,18.3212A10.0105,10.0105,0,0,1,10,16Z"
  })), children);
});
var JoinLeft16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinLeft16(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path416 || (_path416 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.9272,9.9272,0,0,0-3.9968.8394,9.9758,9.9758,0,0,1,2.2451,1.36,8,8,0,1,1,0,15.6016,9.9758,9.9758,0,0,1-2.2451,1.36A9.9976,9.9976,0,1,0,20,6Z"
  })), _path417 || (_path417 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,16a8.01,8.01,0,0,0,6.2483,7.8008,9.9858,9.9858,0,0,0,0-15.6016A8.01,8.01,0,0,0,12,16Z"
  })), _path418 || (_path418 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M12,16a8.01,8.01,0,0,1,6.2483-7.8008,9.9758,9.9758,0,0,0-2.2451-1.36,9.9909,9.9909,0,0,0,0,18.3212,9.9758,9.9758,0,0,0,2.2451-1.36A8.01,8.01,0,0,1,12,16Z",
    "data-icon-path": "inner-path"
  })), _path419 || (_path419 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,16a10.0105,10.0105,0,0,1,6.0032-9.1606,10,10,0,1,0,0,18.3212A10.0105,10.0105,0,0,1,10,16Z"
  })), children);
});
var JoinOuter32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinOuter32(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path420 || (_path420 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 6a9.9539 9.9539 0 00-4 .8379 9.9953 9.9953 0 010 18.3242A9.9988 9.9988 0 1020 6zM10 16a9.9976 9.9976 0 016-9.1621 10 10 0 100 18.3242A9.9976 9.9976 0 0110 16z"
  })), children);
});
var JoinOuter24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinOuter24(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path421 || (_path421 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 6a9.9539 9.9539 0 00-4 .8379 9.9953 9.9953 0 010 18.3242A9.9988 9.9988 0 1020 6zM10 16a9.9976 9.9976 0 016-9.1621 10 10 0 100 18.3242A9.9976 9.9976 0 0110 16z"
  })), children);
});
var JoinOuter20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinOuter20(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path422 || (_path422 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 6a9.9539 9.9539 0 00-4 .8379 9.9953 9.9953 0 010 18.3242A9.9988 9.9988 0 1020 6zM10 16a9.9976 9.9976 0 016-9.1621 10 10 0 100 18.3242A9.9976 9.9976 0 0110 16z"
  })), children);
});
var JoinOuter16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinOuter16(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path423 || (_path423 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 6a9.9539 9.9539 0 00-4 .8379 9.9953 9.9953 0 010 18.3242A9.9988 9.9988 0 1020 6zM10 16a9.9976 9.9976 0 016-9.1621 10 10 0 100 18.3242A9.9976 9.9976 0 0110 16z"
  })), children);
});
var JoinRight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinRight32(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path424 || (_path424 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.95,9.95,0,0,0-4.0032.8394,9.9909,9.9909,0,0,1,0,18.3212A9.9988,9.9988,0,1,0,20,6Z"
  })), _path425 || (_path425 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M20,16a8.01,8.01,0,0,0-6.2483-7.8008,9.9758,9.9758,0,0,1,2.2451-1.36,9.9909,9.9909,0,0,1,0,18.3212,9.9758,9.9758,0,0,1-2.2451-1.36A8.01,8.01,0,0,0,20,16Z",
    "data-icon-path": "inner-path"
  })), _path426 || (_path426 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,16a9.9759,9.9759,0,0,0,3.7517,7.8008,7.9937,7.9937,0,0,0,0-15.6016A9.9759,9.9759,0,0,0,10,16Z"
  })), _path427 || (_path427 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,24A8,8,0,1,1,13.7517,8.1992a9.9758,9.9758,0,0,1,2.2451-1.36,10,10,0,1,0,0,18.3212,9.9758,9.9758,0,0,1-2.2451-1.36A7.9727,7.9727,0,0,1,12,24Z"
  })), children);
});
var JoinRight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinRight24(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path428 || (_path428 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.95,9.95,0,0,0-4.0032.8394,9.9909,9.9909,0,0,1,0,18.3212A9.9988,9.9988,0,1,0,20,6Z"
  })), _path429 || (_path429 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M20,16a8.01,8.01,0,0,0-6.2483-7.8008,9.9758,9.9758,0,0,1,2.2451-1.36,9.9909,9.9909,0,0,1,0,18.3212,9.9758,9.9758,0,0,1-2.2451-1.36A8.01,8.01,0,0,0,20,16Z",
    "data-icon-path": "inner-path"
  })), _path430 || (_path430 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,16a9.9759,9.9759,0,0,0,3.7517,7.8008,7.9937,7.9937,0,0,0,0-15.6016A9.9759,9.9759,0,0,0,10,16Z"
  })), _path431 || (_path431 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,24A8,8,0,1,1,13.7517,8.1992a9.9758,9.9758,0,0,1,2.2451-1.36,10,10,0,1,0,0,18.3212,9.9758,9.9758,0,0,1-2.2451-1.36A7.9727,7.9727,0,0,1,12,24Z"
  })), children);
});
var JoinRight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinRight20(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path432 || (_path432 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.95,9.95,0,0,0-4.0032.8394,9.9909,9.9909,0,0,1,0,18.3212A9.9988,9.9988,0,1,0,20,6Z"
  })), _path433 || (_path433 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M20,16a8.01,8.01,0,0,0-6.2483-7.8008,9.9758,9.9758,0,0,1,2.2451-1.36,9.9909,9.9909,0,0,1,0,18.3212,9.9758,9.9758,0,0,1-2.2451-1.36A8.01,8.01,0,0,0,20,16Z",
    "data-icon-path": "inner-path"
  })), _path434 || (_path434 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,16a9.9759,9.9759,0,0,0,3.7517,7.8008,7.9937,7.9937,0,0,0,0-15.6016A9.9759,9.9759,0,0,0,10,16Z"
  })), _path435 || (_path435 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,24A8,8,0,1,1,13.7517,8.1992a9.9758,9.9758,0,0,1,2.2451-1.36,10,10,0,1,0,0,18.3212,9.9758,9.9758,0,0,1-2.2451-1.36A7.9727,7.9727,0,0,1,12,24Z"
  })), children);
});
var JoinRight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JoinRight16(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path436 || (_path436 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.95,9.95,0,0,0-4.0032.8394,9.9909,9.9909,0,0,1,0,18.3212A9.9988,9.9988,0,1,0,20,6Z"
  })), _path437 || (_path437 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M20,16a8.01,8.01,0,0,0-6.2483-7.8008,9.9758,9.9758,0,0,1,2.2451-1.36,9.9909,9.9909,0,0,1,0,18.3212,9.9758,9.9758,0,0,1-2.2451-1.36A8.01,8.01,0,0,0,20,16Z",
    "data-icon-path": "inner-path"
  })), _path438 || (_path438 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,16a9.9759,9.9759,0,0,0,3.7517,7.8008,7.9937,7.9937,0,0,0,0-15.6016A9.9759,9.9759,0,0,0,10,16Z"
  })), _path439 || (_path439 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,24A8,8,0,1,1,13.7517,8.1992a9.9758,9.9758,0,0,1,2.2451-1.36,10,10,0,1,0,0,18.3212,9.9758,9.9758,0,0,1-2.2451-1.36A7.9727,7.9727,0,0,1,12,24Z"
  })), children);
});
var Jpg32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Jpg32(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path440 || (_path440 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2 2 0 01-2-2V11a2 2 0 012-2h6v2H24V21h4V17H26V15h4zM14 23H12V9h6a2 2 0 012 2v5a2 2 0 01-2 2H14zm0-7h4V11H14zM8 23H4a2 2 0 01-2-2V19H4v2H8V9h2V21A2 2 0 018 23z"
  })), children);
});
var Jpg24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Jpg24(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path441 || (_path441 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2 2 0 01-2-2V11a2 2 0 012-2h6v2H24V21h4V17H26V15h4zM14 23H12V9h6a2 2 0 012 2v5a2 2 0 01-2 2H14zm0-7h4V11H14zM8 23H4a2 2 0 01-2-2V19H4v2H8V9h2V21A2 2 0 018 23z"
  })), children);
});
var Jpg20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Jpg20(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path442 || (_path442 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2 2 0 01-2-2V11a2 2 0 012-2h6v2H24V21h4V17H26V15h4zM14 23H12V9h6a2 2 0 012 2v5a2 2 0 01-2 2H14zm0-7h4V11H14zM8 23H4a2 2 0 01-2-2V19H4v2H8V9h2V21A2 2 0 018 23z"
  })), children);
});
var Jpg16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Jpg16(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path443 || (_path443 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2 2 0 01-2-2V11a2 2 0 012-2h6v2H24V21h4V17H26V15h4zM14 23H12V9h6a2 2 0 012 2v5a2 2 0 01-2 2H14zm0-7h4V11H14zM8 23H4a2 2 0 01-2-2V19H4v2H8V9h2V21A2 2 0 018 23z"
  })), children);
});
var Json32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Json32(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path444 || (_path444 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 11L31 21 29 21 27 15 27 21 25 21 25 11 27 11 29 17 29 11 31 11zM21.3335 21h-2.667A1.6684 1.6684 0 0117 19.3335v-6.667A1.6684 1.6684 0 0118.6665 11h2.667A1.6684 1.6684 0 0123 12.6665v6.667A1.6684 1.6684 0 0121.3335 21zM19 19h2V13H19zM13.3335 21H9V19h4V17H11a2.002 2.002 0 01-2-2V12.6665A1.6684 1.6684 0 0110.6665 11H15v2H11v2h2a2.002 2.002 0 012 2v2.3335A1.6684 1.6684 0 0113.3335 21zM5.3335 21H2.6665A1.6684 1.6684 0 011 19.3335V17H3v2H5V11H7v8.3335A1.6684 1.6684 0 015.3335 21z"
  })), children);
});
var Json24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Json24(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path445 || (_path445 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 11L31 21 29 21 27 15 27 21 25 21 25 11 27 11 29 17 29 11 31 11zM21.3335 21h-2.667A1.6684 1.6684 0 0117 19.3335v-6.667A1.6684 1.6684 0 0118.6665 11h2.667A1.6684 1.6684 0 0123 12.6665v6.667A1.6684 1.6684 0 0121.3335 21zM19 19h2V13H19zM13.3335 21H9V19h4V17H11a2.002 2.002 0 01-2-2V12.6665A1.6684 1.6684 0 0110.6665 11H15v2H11v2h2a2.002 2.002 0 012 2v2.3335A1.6684 1.6684 0 0113.3335 21zM5.3335 21H2.6665A1.6684 1.6684 0 011 19.3335V17H3v2H5V11H7v8.3335A1.6684 1.6684 0 015.3335 21z"
  })), children);
});
var Json20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Json20(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path446 || (_path446 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 11L31 21 29 21 27 15 27 21 25 21 25 11 27 11 29 17 29 11 31 11zM21.3335 21h-2.667A1.6684 1.6684 0 0117 19.3335v-6.667A1.6684 1.6684 0 0118.6665 11h2.667A1.6684 1.6684 0 0123 12.6665v6.667A1.6684 1.6684 0 0121.3335 21zM19 19h2V13H19zM13.3335 21H9V19h4V17H11a2.002 2.002 0 01-2-2V12.6665A1.6684 1.6684 0 0110.6665 11H15v2H11v2h2a2.002 2.002 0 012 2v2.3335A1.6684 1.6684 0 0113.3335 21zM5.3335 21H2.6665A1.6684 1.6684 0 011 19.3335V17H3v2H5V11H7v8.3335A1.6684 1.6684 0 015.3335 21z"
  })), children);
});
var Json16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Json16(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path447 || (_path447 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 11L31 21 29 21 27 15 27 21 25 21 25 11 27 11 29 17 29 11 31 11zM21.3335 21h-2.667A1.6684 1.6684 0 0117 19.3335v-6.667A1.6684 1.6684 0 0118.6665 11h2.667A1.6684 1.6684 0 0123 12.6665v6.667A1.6684 1.6684 0 0121.3335 21zM19 19h2V13H19zM13.3335 21H9V19h4V17H11a2.002 2.002 0 01-2-2V12.6665A1.6684 1.6684 0 0110.6665 11H15v2H11v2h2a2.002 2.002 0 012 2v2.3335A1.6684 1.6684 0 0113.3335 21zM5.3335 21H2.6665A1.6684 1.6684 0 011 19.3335V17H3v2H5V11H7v8.3335A1.6684 1.6684 0 015.3335 21z"
  })), children);
});
var JsonReference32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JsonReference32(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path448 || (_path448 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM29 12L27 6 25 6 25 16 27 16 27 10 29 16 31 16 31 6 29 6 29 12zM21.3335 6h-2.667A1.6683 1.6683 0 0017 7.6665v6.667A1.6684 1.6684 0 0018.6665 16h2.667A1.6683 1.6683 0 0023 14.3335V7.6665A1.6683 1.6683 0 0021.3335 6zM21 14H19V8h2zM9 7.6665V10a2.002 2.002 0 002 2h2v2H9v2h4.3335A1.6683 1.6683 0 0015 14.3335V12a2.002 2.002 0 00-2-2H11V8h4V6H10.6665A1.6683 1.6683 0 009 7.6665zM5 14H3V12H1v2.3335A1.6684 1.6684 0 002.6665 16h2.667A1.6683 1.6683 0 007 14.3335V6H5z"
  })), children);
});
var JsonReference24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JsonReference24(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path449 || (_path449 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM29 12L27 6 25 6 25 16 27 16 27 10 29 16 31 16 31 6 29 6 29 12zM21.3335 6h-2.667A1.6683 1.6683 0 0017 7.6665v6.667A1.6684 1.6684 0 0018.6665 16h2.667A1.6683 1.6683 0 0023 14.3335V7.6665A1.6683 1.6683 0 0021.3335 6zM21 14H19V8h2zM9 7.6665V10a2.002 2.002 0 002 2h2v2H9v2h4.3335A1.6683 1.6683 0 0015 14.3335V12a2.002 2.002 0 00-2-2H11V8h4V6H10.6665A1.6683 1.6683 0 009 7.6665zM5 14H3V12H1v2.3335A1.6684 1.6684 0 002.6665 16h2.667A1.6683 1.6683 0 007 14.3335V6H5z"
  })), children);
});
var JsonReference20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JsonReference20(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path450 || (_path450 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM29 12L27 6 25 6 25 16 27 16 27 10 29 16 31 16 31 6 29 6 29 12zM21.3335 6h-2.667A1.6683 1.6683 0 0017 7.6665v6.667A1.6684 1.6684 0 0018.6665 16h2.667A1.6683 1.6683 0 0023 14.3335V7.6665A1.6683 1.6683 0 0021.3335 6zM21 14H19V8h2zM9 7.6665V10a2.002 2.002 0 002 2h2v2H9v2h4.3335A1.6683 1.6683 0 0015 14.3335V12a2.002 2.002 0 00-2-2H11V8h4V6H10.6665A1.6683 1.6683 0 009 7.6665zM5 14H3V12H1v2.3335A1.6684 1.6684 0 002.6665 16h2.667A1.6683 1.6683 0 007 14.3335V6H5z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-15.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-15.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "JsonReference16": () => (/* binding */ JsonReference16),
/* harmony export */   "JumpLink16": () => (/* binding */ JumpLink16),
/* harmony export */   "JumpLink20": () => (/* binding */ JumpLink20),
/* harmony export */   "JumpLink24": () => (/* binding */ JumpLink24),
/* harmony export */   "JumpLink32": () => (/* binding */ JumpLink32),
/* harmony export */   "KeepDry16": () => (/* binding */ KeepDry16),
/* harmony export */   "KeepDry20": () => (/* binding */ KeepDry20),
/* harmony export */   "KeepDry24": () => (/* binding */ KeepDry24),
/* harmony export */   "KeepDry32": () => (/* binding */ KeepDry32),
/* harmony export */   "Keyboard16": () => (/* binding */ Keyboard16),
/* harmony export */   "Keyboard20": () => (/* binding */ Keyboard20),
/* harmony export */   "Keyboard24": () => (/* binding */ Keyboard24),
/* harmony export */   "Keyboard32": () => (/* binding */ Keyboard32),
/* harmony export */   "Kubernetes16": () => (/* binding */ Kubernetes16),
/* harmony export */   "Kubernetes20": () => (/* binding */ Kubernetes20),
/* harmony export */   "Kubernetes24": () => (/* binding */ Kubernetes24),
/* harmony export */   "Kubernetes32": () => (/* binding */ Kubernetes32),
/* harmony export */   "Label16": () => (/* binding */ Label16),
/* harmony export */   "Label20": () => (/* binding */ Label20),
/* harmony export */   "Label24": () => (/* binding */ Label24),
/* harmony export */   "Label32": () => (/* binding */ Label32),
/* harmony export */   "Language16": () => (/* binding */ Language16),
/* harmony export */   "Language20": () => (/* binding */ Language20),
/* harmony export */   "Language24": () => (/* binding */ Language24),
/* harmony export */   "Language32": () => (/* binding */ Language32),
/* harmony export */   "Laptop16": () => (/* binding */ Laptop16),
/* harmony export */   "Laptop20": () => (/* binding */ Laptop20),
/* harmony export */   "Laptop24": () => (/* binding */ Laptop24),
/* harmony export */   "Laptop32": () => (/* binding */ Laptop32),
/* harmony export */   "Lasso16": () => (/* binding */ Lasso16),
/* harmony export */   "Lasso20": () => (/* binding */ Lasso20),
/* harmony export */   "Lasso24": () => (/* binding */ Lasso24),
/* harmony export */   "Lasso32": () => (/* binding */ Lasso32),
/* harmony export */   "LassoPolygon16": () => (/* binding */ LassoPolygon16),
/* harmony export */   "LassoPolygon20": () => (/* binding */ LassoPolygon20),
/* harmony export */   "LassoPolygon24": () => (/* binding */ LassoPolygon24),
/* harmony export */   "LassoPolygon32": () => (/* binding */ LassoPolygon32),
/* harmony export */   "Launch16": () => (/* binding */ Launch16),
/* harmony export */   "Launch20": () => (/* binding */ Launch20),
/* harmony export */   "Launch24": () => (/* binding */ Launch24),
/* harmony export */   "Launch32": () => (/* binding */ Launch32),
/* harmony export */   "Layers16": () => (/* binding */ Layers16),
/* harmony export */   "Layers20": () => (/* binding */ Layers20),
/* harmony export */   "Layers24": () => (/* binding */ Layers24),
/* harmony export */   "Layers32": () => (/* binding */ Layers32),
/* harmony export */   "Legend16": () => (/* binding */ Legend16),
/* harmony export */   "Legend20": () => (/* binding */ Legend20),
/* harmony export */   "Legend24": () => (/* binding */ Legend24),
/* harmony export */   "Legend32": () => (/* binding */ Legend32),
/* harmony export */   "LetterAa16": () => (/* binding */ LetterAa16),
/* harmony export */   "LetterAa20": () => (/* binding */ LetterAa20),
/* harmony export */   "LetterAa24": () => (/* binding */ LetterAa24),
/* harmony export */   "LetterAa32": () => (/* binding */ LetterAa32),
/* harmony export */   "LetterAaLarge16": () => (/* binding */ LetterAaLarge16),
/* harmony export */   "LetterAaLarge20": () => (/* binding */ LetterAaLarge20),
/* harmony export */   "LetterAaLarge24": () => (/* binding */ LetterAaLarge24),
/* harmony export */   "LetterAaLarge32": () => (/* binding */ LetterAaLarge32),
/* harmony export */   "LetterBb16": () => (/* binding */ LetterBb16),
/* harmony export */   "LetterBb20": () => (/* binding */ LetterBb20),
/* harmony export */   "LetterBb24": () => (/* binding */ LetterBb24),
/* harmony export */   "LetterBb32": () => (/* binding */ LetterBb32),
/* harmony export */   "LetterCc16": () => (/* binding */ LetterCc16),
/* harmony export */   "LetterCc20": () => (/* binding */ LetterCc20),
/* harmony export */   "LetterCc24": () => (/* binding */ LetterCc24),
/* harmony export */   "LetterCc32": () => (/* binding */ LetterCc32),
/* harmony export */   "LetterDd16": () => (/* binding */ LetterDd16),
/* harmony export */   "LetterDd20": () => (/* binding */ LetterDd20),
/* harmony export */   "LetterDd24": () => (/* binding */ LetterDd24),
/* harmony export */   "LetterDd32": () => (/* binding */ LetterDd32),
/* harmony export */   "LetterEe16": () => (/* binding */ LetterEe16),
/* harmony export */   "LetterEe20": () => (/* binding */ LetterEe20),
/* harmony export */   "LetterEe24": () => (/* binding */ LetterEe24),
/* harmony export */   "LetterEe32": () => (/* binding */ LetterEe32),
/* harmony export */   "LetterFf16": () => (/* binding */ LetterFf16),
/* harmony export */   "LetterFf20": () => (/* binding */ LetterFf20),
/* harmony export */   "LetterFf24": () => (/* binding */ LetterFf24),
/* harmony export */   "LetterFf32": () => (/* binding */ LetterFf32),
/* harmony export */   "LetterGg16": () => (/* binding */ LetterGg16),
/* harmony export */   "LetterGg20": () => (/* binding */ LetterGg20),
/* harmony export */   "LetterGg24": () => (/* binding */ LetterGg24),
/* harmony export */   "LetterGg32": () => (/* binding */ LetterGg32),
/* harmony export */   "LetterHh16": () => (/* binding */ LetterHh16),
/* harmony export */   "LetterHh20": () => (/* binding */ LetterHh20),
/* harmony export */   "LetterHh24": () => (/* binding */ LetterHh24),
/* harmony export */   "LetterHh32": () => (/* binding */ LetterHh32),
/* harmony export */   "LetterIi16": () => (/* binding */ LetterIi16),
/* harmony export */   "LetterIi20": () => (/* binding */ LetterIi20),
/* harmony export */   "LetterIi24": () => (/* binding */ LetterIi24),
/* harmony export */   "LetterIi32": () => (/* binding */ LetterIi32),
/* harmony export */   "LetterJj16": () => (/* binding */ LetterJj16),
/* harmony export */   "LetterJj20": () => (/* binding */ LetterJj20),
/* harmony export */   "LetterJj24": () => (/* binding */ LetterJj24),
/* harmony export */   "LetterJj32": () => (/* binding */ LetterJj32),
/* harmony export */   "LetterKk16": () => (/* binding */ LetterKk16),
/* harmony export */   "LetterKk20": () => (/* binding */ LetterKk20),
/* harmony export */   "LetterKk24": () => (/* binding */ LetterKk24),
/* harmony export */   "LetterKk32": () => (/* binding */ LetterKk32),
/* harmony export */   "LetterLl16": () => (/* binding */ LetterLl16),
/* harmony export */   "LetterLl20": () => (/* binding */ LetterLl20),
/* harmony export */   "LetterLl24": () => (/* binding */ LetterLl24),
/* harmony export */   "LetterLl32": () => (/* binding */ LetterLl32),
/* harmony export */   "LetterMm16": () => (/* binding */ LetterMm16),
/* harmony export */   "LetterMm20": () => (/* binding */ LetterMm20),
/* harmony export */   "LetterMm24": () => (/* binding */ LetterMm24),
/* harmony export */   "LetterMm32": () => (/* binding */ LetterMm32),
/* harmony export */   "LetterNn16": () => (/* binding */ LetterNn16),
/* harmony export */   "LetterNn20": () => (/* binding */ LetterNn20),
/* harmony export */   "LetterNn24": () => (/* binding */ LetterNn24),
/* harmony export */   "LetterNn32": () => (/* binding */ LetterNn32),
/* harmony export */   "LetterOo16": () => (/* binding */ LetterOo16),
/* harmony export */   "LetterOo20": () => (/* binding */ LetterOo20),
/* harmony export */   "LetterOo24": () => (/* binding */ LetterOo24),
/* harmony export */   "LetterOo32": () => (/* binding */ LetterOo32),
/* harmony export */   "LetterPp16": () => (/* binding */ LetterPp16),
/* harmony export */   "LetterPp20": () => (/* binding */ LetterPp20),
/* harmony export */   "LetterPp24": () => (/* binding */ LetterPp24),
/* harmony export */   "LetterPp32": () => (/* binding */ LetterPp32),
/* harmony export */   "LetterQq16": () => (/* binding */ LetterQq16),
/* harmony export */   "LetterQq20": () => (/* binding */ LetterQq20),
/* harmony export */   "LetterQq24": () => (/* binding */ LetterQq24),
/* harmony export */   "LetterQq32": () => (/* binding */ LetterQq32),
/* harmony export */   "LetterRr16": () => (/* binding */ LetterRr16),
/* harmony export */   "LetterRr20": () => (/* binding */ LetterRr20),
/* harmony export */   "LetterRr24": () => (/* binding */ LetterRr24),
/* harmony export */   "LetterRr32": () => (/* binding */ LetterRr32),
/* harmony export */   "LetterSs16": () => (/* binding */ LetterSs16),
/* harmony export */   "LetterSs20": () => (/* binding */ LetterSs20),
/* harmony export */   "LetterSs24": () => (/* binding */ LetterSs24),
/* harmony export */   "LetterSs32": () => (/* binding */ LetterSs32),
/* harmony export */   "LetterTt16": () => (/* binding */ LetterTt16),
/* harmony export */   "LetterTt20": () => (/* binding */ LetterTt20),
/* harmony export */   "LetterTt24": () => (/* binding */ LetterTt24),
/* harmony export */   "LetterTt32": () => (/* binding */ LetterTt32),
/* harmony export */   "LetterUu16": () => (/* binding */ LetterUu16),
/* harmony export */   "LetterUu20": () => (/* binding */ LetterUu20),
/* harmony export */   "LetterUu24": () => (/* binding */ LetterUu24),
/* harmony export */   "LetterUu32": () => (/* binding */ LetterUu32),
/* harmony export */   "LetterVv16": () => (/* binding */ LetterVv16),
/* harmony export */   "LetterVv20": () => (/* binding */ LetterVv20),
/* harmony export */   "LetterVv24": () => (/* binding */ LetterVv24),
/* harmony export */   "LetterVv32": () => (/* binding */ LetterVv32),
/* harmony export */   "LetterWw16": () => (/* binding */ LetterWw16),
/* harmony export */   "LetterWw20": () => (/* binding */ LetterWw20),
/* harmony export */   "LetterWw24": () => (/* binding */ LetterWw24),
/* harmony export */   "LetterWw32": () => (/* binding */ LetterWw32),
/* harmony export */   "LetterXx16": () => (/* binding */ LetterXx16),
/* harmony export */   "LetterXx20": () => (/* binding */ LetterXx20),
/* harmony export */   "LetterXx24": () => (/* binding */ LetterXx24),
/* harmony export */   "LetterXx32": () => (/* binding */ LetterXx32),
/* harmony export */   "LetterYy16": () => (/* binding */ LetterYy16),
/* harmony export */   "LetterYy20": () => (/* binding */ LetterYy20),
/* harmony export */   "LetterYy24": () => (/* binding */ LetterYy24),
/* harmony export */   "LetterYy32": () => (/* binding */ LetterYy32),
/* harmony export */   "LetterZz16": () => (/* binding */ LetterZz16),
/* harmony export */   "LetterZz20": () => (/* binding */ LetterZz20),
/* harmony export */   "LetterZz24": () => (/* binding */ LetterZz24),
/* harmony export */   "LetterZz32": () => (/* binding */ LetterZz32),
/* harmony export */   "License16": () => (/* binding */ License16),
/* harmony export */   "License20": () => (/* binding */ License20),
/* harmony export */   "License24": () => (/* binding */ License24),
/* harmony export */   "License32": () => (/* binding */ License32),
/* harmony export */   "LicenseDraft16": () => (/* binding */ LicenseDraft16),
/* harmony export */   "LicenseDraft20": () => (/* binding */ LicenseDraft20),
/* harmony export */   "LicenseDraft24": () => (/* binding */ LicenseDraft24),
/* harmony export */   "LicenseDraft32": () => (/* binding */ LicenseDraft32),
/* harmony export */   "LicenseGlobal16": () => (/* binding */ LicenseGlobal16),
/* harmony export */   "LicenseGlobal20": () => (/* binding */ LicenseGlobal20),
/* harmony export */   "LicenseGlobal24": () => (/* binding */ LicenseGlobal24),
/* harmony export */   "LicenseGlobal32": () => (/* binding */ LicenseGlobal32),
/* harmony export */   "LicenseMaintenance16": () => (/* binding */ LicenseMaintenance16),
/* harmony export */   "LicenseMaintenance20": () => (/* binding */ LicenseMaintenance20),
/* harmony export */   "LicenseMaintenance24": () => (/* binding */ LicenseMaintenance24),
/* harmony export */   "LicenseMaintenance32": () => (/* binding */ LicenseMaintenance32),
/* harmony export */   "LicenseMaintenanceDraft16": () => (/* binding */ LicenseMaintenanceDraft16),
/* harmony export */   "LicenseMaintenanceDraft20": () => (/* binding */ LicenseMaintenanceDraft20),
/* harmony export */   "LicenseMaintenanceDraft24": () => (/* binding */ LicenseMaintenanceDraft24),
/* harmony export */   "LicenseMaintenanceDraft32": () => (/* binding */ LicenseMaintenanceDraft32),
/* harmony export */   "LicenseThirdParty16": () => (/* binding */ LicenseThirdParty16),
/* harmony export */   "LicenseThirdParty20": () => (/* binding */ LicenseThirdParty20),
/* harmony export */   "LicenseThirdParty24": () => (/* binding */ LicenseThirdParty24),
/* harmony export */   "LicenseThirdParty32": () => (/* binding */ LicenseThirdParty32),
/* harmony export */   "LicenseThirdPartyDraft16": () => (/* binding */ LicenseThirdPartyDraft16),
/* harmony export */   "LicenseThirdPartyDraft20": () => (/* binding */ LicenseThirdPartyDraft20),
/* harmony export */   "LicenseThirdPartyDraft24": () => (/* binding */ LicenseThirdPartyDraft24),
/* harmony export */   "LicenseThirdPartyDraft32": () => (/* binding */ LicenseThirdPartyDraft32),
/* harmony export */   "Lifesaver16": () => (/* binding */ Lifesaver16),
/* harmony export */   "Lifesaver20": () => (/* binding */ Lifesaver20),
/* harmony export */   "Lifesaver24": () => (/* binding */ Lifesaver24),
/* harmony export */   "Lifesaver32": () => (/* binding */ Lifesaver32),
/* harmony export */   "Light16": () => (/* binding */ Light16),
/* harmony export */   "Light20": () => (/* binding */ Light20),
/* harmony export */   "Light24": () => (/* binding */ Light24),
/* harmony export */   "Light32": () => (/* binding */ Light32),
/* harmony export */   "LightFilled16": () => (/* binding */ LightFilled16),
/* harmony export */   "LightFilled20": () => (/* binding */ LightFilled20),
/* harmony export */   "LightFilled24": () => (/* binding */ LightFilled24),
/* harmony export */   "LightFilled32": () => (/* binding */ LightFilled32),
/* harmony export */   "Lightning16": () => (/* binding */ Lightning16),
/* harmony export */   "Lightning20": () => (/* binding */ Lightning20),
/* harmony export */   "Lightning24": () => (/* binding */ Lightning24),
/* harmony export */   "Lightning32": () => (/* binding */ Lightning32),
/* harmony export */   "Link16": () => (/* binding */ Link16),
/* harmony export */   "Link20": () => (/* binding */ Link20),
/* harmony export */   "Link24": () => (/* binding */ Link24),
/* harmony export */   "Link32": () => (/* binding */ Link32),
/* harmony export */   "Linux16": () => (/* binding */ Linux16),
/* harmony export */   "Linux20": () => (/* binding */ Linux20),
/* harmony export */   "Linux24": () => (/* binding */ Linux24),
/* harmony export */   "Linux32": () => (/* binding */ Linux32),
/* harmony export */   "LinuxAlt16": () => (/* binding */ LinuxAlt16),
/* harmony export */   "LinuxAlt20": () => (/* binding */ LinuxAlt20),
/* harmony export */   "LinuxAlt24": () => (/* binding */ LinuxAlt24),
/* harmony export */   "LinuxAlt32": () => (/* binding */ LinuxAlt32),
/* harmony export */   "List16": () => (/* binding */ List16),
/* harmony export */   "List20": () => (/* binding */ List20),
/* harmony export */   "List24": () => (/* binding */ List24),
/* harmony export */   "List32": () => (/* binding */ List32),
/* harmony export */   "ListBoxes16": () => (/* binding */ ListBoxes16),
/* harmony export */   "ListBoxes20": () => (/* binding */ ListBoxes20),
/* harmony export */   "ListBoxes24": () => (/* binding */ ListBoxes24),
/* harmony export */   "ListBoxes32": () => (/* binding */ ListBoxes32),
/* harmony export */   "ListBulleted16": () => (/* binding */ ListBulleted16),
/* harmony export */   "ListBulleted20": () => (/* binding */ ListBulleted20),
/* harmony export */   "ListBulleted24": () => (/* binding */ ListBulleted24),
/* harmony export */   "ListBulleted32": () => (/* binding */ ListBulleted32),
/* harmony export */   "ListChecked16": () => (/* binding */ ListChecked16),
/* harmony export */   "ListChecked20": () => (/* binding */ ListChecked20),
/* harmony export */   "ListChecked24": () => (/* binding */ ListChecked24),
/* harmony export */   "ListChecked32": () => (/* binding */ ListChecked32),
/* harmony export */   "ListDropdown16": () => (/* binding */ ListDropdown16),
/* harmony export */   "ListDropdown20": () => (/* binding */ ListDropdown20),
/* harmony export */   "ListDropdown24": () => (/* binding */ ListDropdown24),
/* harmony export */   "ListDropdown32": () => (/* binding */ ListDropdown32),
/* harmony export */   "ListNumbered16": () => (/* binding */ ListNumbered16),
/* harmony export */   "ListNumbered20": () => (/* binding */ ListNumbered20),
/* harmony export */   "ListNumbered24": () => (/* binding */ ListNumbered24),
/* harmony export */   "ListNumbered32": () => (/* binding */ ListNumbered32),
/* harmony export */   "LoadBalancerApplication32": () => (/* binding */ LoadBalancerApplication32),
/* harmony export */   "WatsonHealthLaunchStudy_116": () => (/* binding */ WatsonHealthLaunchStudy_116),
/* harmony export */   "WatsonHealthLaunchStudy_120": () => (/* binding */ WatsonHealthLaunchStudy_120),
/* harmony export */   "WatsonHealthLaunchStudy_124": () => (/* binding */ WatsonHealthLaunchStudy_124),
/* harmony export */   "WatsonHealthLaunchStudy_132": () => (/* binding */ WatsonHealthLaunchStudy_132),
/* harmony export */   "WatsonHealthLaunchStudy_216": () => (/* binding */ WatsonHealthLaunchStudy_216),
/* harmony export */   "WatsonHealthLaunchStudy_220": () => (/* binding */ WatsonHealthLaunchStudy_220),
/* harmony export */   "WatsonHealthLaunchStudy_224": () => (/* binding */ WatsonHealthLaunchStudy_224),
/* harmony export */   "WatsonHealthLaunchStudy_232": () => (/* binding */ WatsonHealthLaunchStudy_232),
/* harmony export */   "WatsonHealthLaunchStudy_316": () => (/* binding */ WatsonHealthLaunchStudy_316),
/* harmony export */   "WatsonHealthLaunchStudy_320": () => (/* binding */ WatsonHealthLaunchStudy_320),
/* harmony export */   "WatsonHealthLaunchStudy_324": () => (/* binding */ WatsonHealthLaunchStudy_324),
/* harmony export */   "WatsonHealthLaunchStudy_332": () => (/* binding */ WatsonHealthLaunchStudy_332)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _circle, _path62, _path63, _circle2, _path64, _path65, _circle3, _path66, _path67, _circle4, _path68, _path69, _circle5, _path70, _path71, _circle6, _path72, _path73, _circle7, _path74, _path75, _circle8, _path76, _path77, _circle9, _path78, _path79, _circle10, _path80, _path81, _circle11, _path82, _path83, _circle12, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _rect, _path95, _path96, _rect2, _path97, _path98, _rect3, _path99, _path100, _rect4, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _path224, _path225, _path226, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _circle13, _circle14, _path374, _circle15, _circle16, _path375, _circle17, _circle18, _path376, _circle19, _circle20, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388, _path389, _path390, _path391, _path392, _path393, _path394;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var didWarnAboutDeprecation = {};
var JsonReference16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JsonReference16(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM29 12L27 6 25 6 25 16 27 16 27 10 29 16 31 16 31 6 29 6 29 12zM21.3335 6h-2.667A1.6683 1.6683 0 0017 7.6665v6.667A1.6684 1.6684 0 0018.6665 16h2.667A1.6683 1.6683 0 0023 14.3335V7.6665A1.6683 1.6683 0 0021.3335 6zM21 14H19V8h2zM9 7.6665V10a2.002 2.002 0 002 2h2v2H9v2h4.3335A1.6683 1.6683 0 0015 14.3335V12a2.002 2.002 0 00-2-2H11V8h4V6H10.6665A1.6683 1.6683 0 009 7.6665zM5 14H3V12H1v2.3335A1.6684 1.6684 0 002.6665 16h2.667A1.6683 1.6683 0 007 14.3335V6H5z"
  })), children);
});
var JumpLink32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JumpLink32(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.4141,17.5859,18,22.1719V8H8V6H18a2.0024,2.0024,0,0,1,2,2V22.1719l4.5859-4.586L26,19l-7,7-7-7Z"
  })), children);
});
var JumpLink24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JumpLink24(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.4141,17.5859,18,22.1719V8H8V6H18a2.0024,2.0024,0,0,1,2,2V22.1719l4.5859-4.586L26,19l-7,7-7-7Z"
  })), children);
});
var JumpLink20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JumpLink20(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.4141,17.5859,18,22.1719V8H8V6H18a2.0024,2.0024,0,0,1,2,2V22.1719l4.5859-4.586L26,19l-7,7-7-7Z"
  })), children);
});
var JumpLink16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function JumpLink16(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.4141,17.5859,18,22.1719V8H8V6H18a2.0024,2.0024,0,0,1,2,2V22.1719l4.5859-4.586L26,19l-7,7-7-7Z"
  })), children);
});
var KeepDry32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function KeepDry32(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,10a3.8978,3.8978,0,0,1-4-3.777,3.9017,3.9017,0,0,1,.6533-2.0639L24.17.4141a1.0381,1.0381,0,0,1,1.6592,0L28.3154,4.11A3.9693,3.9693,0,0,1,29,6.223,3.8978,3.8978,0,0,1,25,10Zm0-7.2368L23.3438,5.2257A1.89,1.89,0,0,0,23,6.223a2.014,2.014,0,0,0,4,0,1.98,1.98,0,0,0-.375-1.0466Z"
  })), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9854,15.83a13.9726,13.9726,0,0,0-1.8147-4.8323L26.4329,12.001a12.092,12.092,0,0,1,1.07,2.2124A5.4079,5.4079,0,0,0,26,14a6.5439,6.5439,0,0,0-3.939,1.333,14.5177,14.5177,0,0,0-3.0456-8.9341A13.8858,13.8858,0,0,0,17,4.4014V2H15V4.0464A14.3808,14.3808,0,0,0,2.0146,15.83,1,1,0,0,0,3.51,16.86,4.8551,4.8551,0,0,1,6,16a4.8653,4.8653,0,0,1,4.1406,2.5107,1.0393,1.0393,0,0,0,1.7188,0A5.02,5.02,0,0,1,15,16.1255V25.5a2.5,2.5,0,0,1-5,0V25H8v.5a4.5,4.5,0,0,0,9,0V16.1255a5.02,5.02,0,0,1,3.1406,2.3852.9994.9994,0,0,0,1.7188,0A4.8653,4.8653,0,0,1,26,16a4.8551,4.8551,0,0,1,2.49.86,1,1,0,0,0,1.4957-1.03ZM9.939,15.333A6.5439,6.5439,0,0,0,6,14a5.4079,5.4079,0,0,0-1.5034.2134,12.4413,12.4413,0,0,1,8.488-7.8145A14.5157,14.5157,0,0,0,9.939,15.333ZM16,14a6.5526,6.5526,0,0,0-4.0564,1.4307c.0378-2.22.6089-6.49,4.0564-9.1763,3.4307,2.6768,4.009,6.9487,4.0522,9.1728A6.552,6.552,0,0,0,16,14Z"
  })), children);
});
var KeepDry24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function KeepDry24(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,10a3.8978,3.8978,0,0,1-4-3.777,3.9017,3.9017,0,0,1,.6533-2.0639L24.17.4141a1.0381,1.0381,0,0,1,1.6592,0L28.3154,4.11A3.9693,3.9693,0,0,1,29,6.223,3.8978,3.8978,0,0,1,25,10Zm0-7.2368L23.3438,5.2257A1.89,1.89,0,0,0,23,6.223a2.014,2.014,0,0,0,4,0,1.98,1.98,0,0,0-.375-1.0466Z"
  })), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9854,15.83a13.9726,13.9726,0,0,0-1.8147-4.8323L26.4329,12.001a12.092,12.092,0,0,1,1.07,2.2124A5.4079,5.4079,0,0,0,26,14a6.5439,6.5439,0,0,0-3.939,1.333,14.5177,14.5177,0,0,0-3.0456-8.9341A13.8858,13.8858,0,0,0,17,4.4014V2H15V4.0464A14.3808,14.3808,0,0,0,2.0146,15.83,1,1,0,0,0,3.51,16.86,4.8551,4.8551,0,0,1,6,16a4.8653,4.8653,0,0,1,4.1406,2.5107,1.0393,1.0393,0,0,0,1.7188,0A5.02,5.02,0,0,1,15,16.1255V25.5a2.5,2.5,0,0,1-5,0V25H8v.5a4.5,4.5,0,0,0,9,0V16.1255a5.02,5.02,0,0,1,3.1406,2.3852.9994.9994,0,0,0,1.7188,0A4.8653,4.8653,0,0,1,26,16a4.8551,4.8551,0,0,1,2.49.86,1,1,0,0,0,1.4957-1.03ZM9.939,15.333A6.5439,6.5439,0,0,0,6,14a5.4079,5.4079,0,0,0-1.5034.2134,12.4413,12.4413,0,0,1,8.488-7.8145A14.5157,14.5157,0,0,0,9.939,15.333ZM16,14a6.5526,6.5526,0,0,0-4.0564,1.4307c.0378-2.22.6089-6.49,4.0564-9.1763,3.4307,2.6768,4.009,6.9487,4.0522,9.1728A6.552,6.552,0,0,0,16,14Z"
  })), children);
});
var KeepDry20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function KeepDry20(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,10a3.8978,3.8978,0,0,1-4-3.777,3.9017,3.9017,0,0,1,.6533-2.0639L24.17.4141a1.0381,1.0381,0,0,1,1.6592,0L28.3154,4.11A3.9693,3.9693,0,0,1,29,6.223,3.8978,3.8978,0,0,1,25,10Zm0-7.2368L23.3438,5.2257A1.89,1.89,0,0,0,23,6.223a2.014,2.014,0,0,0,4,0,1.98,1.98,0,0,0-.375-1.0466Z"
  })), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9854,15.83a13.9726,13.9726,0,0,0-1.8147-4.8323L26.4329,12.001a12.092,12.092,0,0,1,1.07,2.2124A5.4079,5.4079,0,0,0,26,14a6.5439,6.5439,0,0,0-3.939,1.333,14.5177,14.5177,0,0,0-3.0456-8.9341A13.8858,13.8858,0,0,0,17,4.4014V2H15V4.0464A14.3808,14.3808,0,0,0,2.0146,15.83,1,1,0,0,0,3.51,16.86,4.8551,4.8551,0,0,1,6,16a4.8653,4.8653,0,0,1,4.1406,2.5107,1.0393,1.0393,0,0,0,1.7188,0A5.02,5.02,0,0,1,15,16.1255V25.5a2.5,2.5,0,0,1-5,0V25H8v.5a4.5,4.5,0,0,0,9,0V16.1255a5.02,5.02,0,0,1,3.1406,2.3852.9994.9994,0,0,0,1.7188,0A4.8653,4.8653,0,0,1,26,16a4.8551,4.8551,0,0,1,2.49.86,1,1,0,0,0,1.4957-1.03ZM9.939,15.333A6.5439,6.5439,0,0,0,6,14a5.4079,5.4079,0,0,0-1.5034.2134,12.4413,12.4413,0,0,1,8.488-7.8145A14.5157,14.5157,0,0,0,9.939,15.333ZM16,14a6.5526,6.5526,0,0,0-4.0564,1.4307c.0378-2.22.6089-6.49,4.0564-9.1763,3.4307,2.6768,4.009,6.9487,4.0522,9.1728A6.552,6.552,0,0,0,16,14Z"
  })), children);
});
var KeepDry16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function KeepDry16(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,10a3.8978,3.8978,0,0,1-4-3.777,3.9017,3.9017,0,0,1,.6533-2.0639L24.17.4141a1.0381,1.0381,0,0,1,1.6592,0L28.3154,4.11A3.9693,3.9693,0,0,1,29,6.223,3.8978,3.8978,0,0,1,25,10Zm0-7.2368L23.3438,5.2257A1.89,1.89,0,0,0,23,6.223a2.014,2.014,0,0,0,4,0,1.98,1.98,0,0,0-.375-1.0466Z"
  })), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9854,15.83a13.9726,13.9726,0,0,0-1.8147-4.8323L26.4329,12.001a12.092,12.092,0,0,1,1.07,2.2124A5.4079,5.4079,0,0,0,26,14a6.5439,6.5439,0,0,0-3.939,1.333,14.5177,14.5177,0,0,0-3.0456-8.9341A13.8858,13.8858,0,0,0,17,4.4014V2H15V4.0464A14.3808,14.3808,0,0,0,2.0146,15.83,1,1,0,0,0,3.51,16.86,4.8551,4.8551,0,0,1,6,16a4.8653,4.8653,0,0,1,4.1406,2.5107,1.0393,1.0393,0,0,0,1.7188,0A5.02,5.02,0,0,1,15,16.1255V25.5a2.5,2.5,0,0,1-5,0V25H8v.5a4.5,4.5,0,0,0,9,0V16.1255a5.02,5.02,0,0,1,3.1406,2.3852.9994.9994,0,0,0,1.7188,0A4.8653,4.8653,0,0,1,26,16a4.8551,4.8551,0,0,1,2.49.86,1,1,0,0,0,1.4957-1.03ZM9.939,15.333A6.5439,6.5439,0,0,0,6,14a5.4079,5.4079,0,0,0-1.5034.2134,12.4413,12.4413,0,0,1,8.488-7.8145A14.5157,14.5157,0,0,0,9.939,15.333ZM16,14a6.5526,6.5526,0,0,0-4.0564,1.4307c.0378-2.22.6089-6.49,4.0564-9.1763,3.4307,2.6768,4.009,6.9487,4.0522,9.1728A6.552,6.552,0,0,0,16,14Z"
  })), children);
});
var Keyboard32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Keyboard32(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H4a2,2,0,0,1-2-2V10A2,2,0,0,1,4,8H28a2,2,0,0,1,2,2V24A2,2,0,0,1,28,26ZM4,10V24H28V10Z"
  })), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 20H21V22H10zM6 12H8V14H6zM10 12H12V14H10zM14 12H16V14H14zM18 12H20V14H18zM6 20H8V22H6zM6 16H8V18H6zM10 16H12V18H10zM14 16H16V18H14zM22 12H26V14H22zM22 16H26V18H22zM18 16H20V18H18zM23 20H26V22H23z"
  })), children);
});
var Keyboard24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Keyboard24(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H4a2,2,0,0,1-2-2V10A2,2,0,0,1,4,8H28a2,2,0,0,1,2,2V24A2,2,0,0,1,28,26ZM4,10V24H28V10Z"
  })), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 20H21V22H10zM6 12H8V14H6zM10 12H12V14H10zM14 12H16V14H14zM18 12H20V14H18zM6 20H8V22H6zM6 16H8V18H6zM10 16H12V18H10zM14 16H16V18H14zM22 12H26V14H22zM22 16H26V18H22zM18 16H20V18H18zM23 20H26V22H23z"
  })), children);
});
var Keyboard20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Keyboard20(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H4a2,2,0,0,1-2-2V10A2,2,0,0,1,4,8H28a2,2,0,0,1,2,2V24A2,2,0,0,1,28,26ZM4,10V24H28V10Z"
  })), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 20H21V22H10zM6 12H8V14H6zM10 12H12V14H10zM14 12H16V14H14zM18 12H20V14H18zM6 20H8V22H6zM6 16H8V18H6zM10 16H12V18H10zM14 16H16V18H14zM22 12H26V14H22zM22 16H26V18H22zM18 16H20V18H18zM23 20H26V22H23z"
  })), children);
});
var Keyboard16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Keyboard16(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H4a2,2,0,0,1-2-2V10A2,2,0,0,1,4,8H28a2,2,0,0,1,2,2V24A2,2,0,0,1,28,26ZM4,10V24H28V10Z"
  })), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 20H21V22H10zM6 12H8V14H6zM10 12H12V14H10zM14 12H16V14H14zM18 12H20V14H18zM6 20H8V22H6zM6 16H8V18H6zM10 16H12V18H10zM14 16H16V18H14zM22 12H26V14H22zM22 16H26V18H22zM18 16H20V18H18zM23 20H26V22H23z"
  })), children);
});
var Kubernetes32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Kubernetes32(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.2227,17.9639,25.9194,17.21a9.7843,9.7843,0,0,0-1.5249-6.6245l2.54-2.0254L25.6875,6.9961,23.1482,9.0205A9.97,9.97,0,0,0,17,6.0508V3H15V6.0508a9.97,9.97,0,0,0-6.1482,2.97L6.3125,6.9961,5.0654,8.56l2.54,2.0254A9.7843,9.7843,0,0,0,6.0806,17.21l-3.3033.7544.4454,1.9492L6.52,19.1606a10.0359,10.0359,0,0,0,4.2688,5.358l-1.33,2.7631,1.8018.8677L12.59,25.3882a9.8113,9.8113,0,0,0,6.8208,0L20.74,28.1494l1.8018-.8682-1.33-2.7626a10.0359,10.0359,0,0,0,4.2688-5.358l3.2973.7525ZM24,16c0,.2573-.0148.5112-.0386.7627l-5-1.1416a2.9664,2.9664,0,0,0-.1376-.5942L22.82,11.84A7.9392,7.9392,0,0,1,24,16Zm-9,0a1,1,0,1,1,1,1A1.0009,1.0009,0,0,1,15,16Zm6.5758-5.7256L17.58,13.4609a3.0028,3.0028,0,0,0-.58-.2768V8.0693A7.9762,7.9762,0,0,1,21.5758,10.2744ZM15,8.0693v5.1148a3.0028,3.0028,0,0,0-.58.2768l-3.9956-3.1865A7.9762,7.9762,0,0,1,15,8.0693ZM8,16a7.9392,7.9392,0,0,1,1.18-4.16l3.9962,3.1866a2.9664,2.9664,0,0,0-.1376.5942l-5,1.1416C8.0148,16.5112,8,16.2573,8,16Zm.4835,2.7124,4.9752-1.1362a3.0132,3.0132,0,0,0,.4146.5366L11.6594,22.71A8.031,8.031,0,0,1,8.4835,18.7124ZM16,24a7.9679,7.9679,0,0,1-2.54-.42l2.2206-4.6123A2.9988,2.9988,0,0,0,16,19a2.9988,2.9988,0,0,0,.319-.0322L18.54,23.58A7.9546,7.9546,0,0,1,16,24Zm4.3406-1.29-2.2139-4.5976a3.0132,3.0132,0,0,0,.4146-.5366l4.9752,1.1362A8.031,8.031,0,0,1,20.3406,22.71Z"
  })), children);
});
var Kubernetes24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Kubernetes24(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.2227,17.9639,25.9194,17.21a9.7843,9.7843,0,0,0-1.5249-6.6245l2.54-2.0254L25.6875,6.9961,23.1482,9.0205A9.97,9.97,0,0,0,17,6.0508V3H15V6.0508a9.97,9.97,0,0,0-6.1482,2.97L6.3125,6.9961,5.0654,8.56l2.54,2.0254A9.7843,9.7843,0,0,0,6.0806,17.21l-3.3033.7544.4454,1.9492L6.52,19.1606a10.0359,10.0359,0,0,0,4.2688,5.358l-1.33,2.7631,1.8018.8677L12.59,25.3882a9.8113,9.8113,0,0,0,6.8208,0L20.74,28.1494l1.8018-.8682-1.33-2.7626a10.0359,10.0359,0,0,0,4.2688-5.358l3.2973.7525ZM24,16c0,.2573-.0148.5112-.0386.7627l-5-1.1416a2.9664,2.9664,0,0,0-.1376-.5942L22.82,11.84A7.9392,7.9392,0,0,1,24,16Zm-9,0a1,1,0,1,1,1,1A1.0009,1.0009,0,0,1,15,16Zm6.5758-5.7256L17.58,13.4609a3.0028,3.0028,0,0,0-.58-.2768V8.0693A7.9762,7.9762,0,0,1,21.5758,10.2744ZM15,8.0693v5.1148a3.0028,3.0028,0,0,0-.58.2768l-3.9956-3.1865A7.9762,7.9762,0,0,1,15,8.0693ZM8,16a7.9392,7.9392,0,0,1,1.18-4.16l3.9962,3.1866a2.9664,2.9664,0,0,0-.1376.5942l-5,1.1416C8.0148,16.5112,8,16.2573,8,16Zm.4835,2.7124,4.9752-1.1362a3.0132,3.0132,0,0,0,.4146.5366L11.6594,22.71A8.031,8.031,0,0,1,8.4835,18.7124ZM16,24a7.9679,7.9679,0,0,1-2.54-.42l2.2206-4.6123A2.9988,2.9988,0,0,0,16,19a2.9988,2.9988,0,0,0,.319-.0322L18.54,23.58A7.9546,7.9546,0,0,1,16,24Zm4.3406-1.29-2.2139-4.5976a3.0132,3.0132,0,0,0,.4146-.5366l4.9752,1.1362A8.031,8.031,0,0,1,20.3406,22.71Z"
  })), children);
});
var Kubernetes20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Kubernetes20(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.2227,17.9639,25.9194,17.21a9.7843,9.7843,0,0,0-1.5249-6.6245l2.54-2.0254L25.6875,6.9961,23.1482,9.0205A9.97,9.97,0,0,0,17,6.0508V3H15V6.0508a9.97,9.97,0,0,0-6.1482,2.97L6.3125,6.9961,5.0654,8.56l2.54,2.0254A9.7843,9.7843,0,0,0,6.0806,17.21l-3.3033.7544.4454,1.9492L6.52,19.1606a10.0359,10.0359,0,0,0,4.2688,5.358l-1.33,2.7631,1.8018.8677L12.59,25.3882a9.8113,9.8113,0,0,0,6.8208,0L20.74,28.1494l1.8018-.8682-1.33-2.7626a10.0359,10.0359,0,0,0,4.2688-5.358l3.2973.7525ZM24,16c0,.2573-.0148.5112-.0386.7627l-5-1.1416a2.9664,2.9664,0,0,0-.1376-.5942L22.82,11.84A7.9392,7.9392,0,0,1,24,16Zm-9,0a1,1,0,1,1,1,1A1.0009,1.0009,0,0,1,15,16Zm6.5758-5.7256L17.58,13.4609a3.0028,3.0028,0,0,0-.58-.2768V8.0693A7.9762,7.9762,0,0,1,21.5758,10.2744ZM15,8.0693v5.1148a3.0028,3.0028,0,0,0-.58.2768l-3.9956-3.1865A7.9762,7.9762,0,0,1,15,8.0693ZM8,16a7.9392,7.9392,0,0,1,1.18-4.16l3.9962,3.1866a2.9664,2.9664,0,0,0-.1376.5942l-5,1.1416C8.0148,16.5112,8,16.2573,8,16Zm.4835,2.7124,4.9752-1.1362a3.0132,3.0132,0,0,0,.4146.5366L11.6594,22.71A8.031,8.031,0,0,1,8.4835,18.7124ZM16,24a7.9679,7.9679,0,0,1-2.54-.42l2.2206-4.6123A2.9988,2.9988,0,0,0,16,19a2.9988,2.9988,0,0,0,.319-.0322L18.54,23.58A7.9546,7.9546,0,0,1,16,24Zm4.3406-1.29-2.2139-4.5976a3.0132,3.0132,0,0,0,.4146-.5366l4.9752,1.1362A8.031,8.031,0,0,1,20.3406,22.71Z"
  })), children);
});
var Kubernetes16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Kubernetes16(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.2227,17.9639,25.9194,17.21a9.7843,9.7843,0,0,0-1.5249-6.6245l2.54-2.0254L25.6875,6.9961,23.1482,9.0205A9.97,9.97,0,0,0,17,6.0508V3H15V6.0508a9.97,9.97,0,0,0-6.1482,2.97L6.3125,6.9961,5.0654,8.56l2.54,2.0254A9.7843,9.7843,0,0,0,6.0806,17.21l-3.3033.7544.4454,1.9492L6.52,19.1606a10.0359,10.0359,0,0,0,4.2688,5.358l-1.33,2.7631,1.8018.8677L12.59,25.3882a9.8113,9.8113,0,0,0,6.8208,0L20.74,28.1494l1.8018-.8682-1.33-2.7626a10.0359,10.0359,0,0,0,4.2688-5.358l3.2973.7525ZM24,16c0,.2573-.0148.5112-.0386.7627l-5-1.1416a2.9664,2.9664,0,0,0-.1376-.5942L22.82,11.84A7.9392,7.9392,0,0,1,24,16Zm-9,0a1,1,0,1,1,1,1A1.0009,1.0009,0,0,1,15,16Zm6.5758-5.7256L17.58,13.4609a3.0028,3.0028,0,0,0-.58-.2768V8.0693A7.9762,7.9762,0,0,1,21.5758,10.2744ZM15,8.0693v5.1148a3.0028,3.0028,0,0,0-.58.2768l-3.9956-3.1865A7.9762,7.9762,0,0,1,15,8.0693ZM8,16a7.9392,7.9392,0,0,1,1.18-4.16l3.9962,3.1866a2.9664,2.9664,0,0,0-.1376.5942l-5,1.1416C8.0148,16.5112,8,16.2573,8,16Zm.4835,2.7124,4.9752-1.1362a3.0132,3.0132,0,0,0,.4146.5366L11.6594,22.71A8.031,8.031,0,0,1,8.4835,18.7124ZM16,24a7.9679,7.9679,0,0,1-2.54-.42l2.2206-4.6123A2.9988,2.9988,0,0,0,16,19a2.9988,2.9988,0,0,0,.319-.0322L18.54,23.58A7.9546,7.9546,0,0,1,16,24Zm4.3406-1.29-2.2139-4.5976a3.0132,3.0132,0,0,0,.4146-.5366l4.9752,1.1362A8.031,8.031,0,0,1,20.3406,22.71Z"
  })), children);
});
var Label32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Label32(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 13H18v2h5v2H19a2 2 0 00-2 2v2a2 2 0 002 2h6V15A2.0023 2.0023 0 0023 13zm0 8H19V19h4zM13 9H9a2.002 2.002 0 00-2 2V23H9V18h4v5h2V11A2.002 2.002 0 0013 9zM9 16V11h4v5z"
  })), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,28H4a2.0021,2.0021,0,0,1-2-2V6A2.0021,2.0021,0,0,1,4,4H28a2.0021,2.0021,0,0,1,2,2V26A2.0021,2.0021,0,0,1,28,28ZM4,6V26H28V6Z"
  })), children);
});
var Label24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Label24(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 13H18v2h5v2H19a2 2 0 00-2 2v2a2 2 0 002 2h6V15A2.0023 2.0023 0 0023 13zm0 8H19V19h4zM13 9H9a2.002 2.002 0 00-2 2V23H9V18h4v5h2V11A2.002 2.002 0 0013 9zM9 16V11h4v5z"
  })), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,28H4a2.0021,2.0021,0,0,1-2-2V6A2.0021,2.0021,0,0,1,4,4H28a2.0021,2.0021,0,0,1,2,2V26A2.0021,2.0021,0,0,1,28,28ZM4,6V26H28V6Z"
  })), children);
});
var Label20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Label20(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 13H18v2h5v2H19a2 2 0 00-2 2v2a2 2 0 002 2h6V15A2.0023 2.0023 0 0023 13zm0 8H19V19h4zM13 9H9a2.002 2.002 0 00-2 2V23H9V18h4v5h2V11A2.002 2.002 0 0013 9zM9 16V11h4v5z"
  })), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,28H4a2.0021,2.0021,0,0,1-2-2V6A2.0021,2.0021,0,0,1,4,4H28a2.0021,2.0021,0,0,1,2,2V26A2.0021,2.0021,0,0,1,28,28ZM4,6V26H28V6Z"
  })), children);
});
var Label16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Label16(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 13H18v2h5v2H19a2 2 0 00-2 2v2a2 2 0 002 2h6V15A2.0023 2.0023 0 0023 13zm0 8H19V19h4zM13 9H9a2.002 2.002 0 00-2 2V23H9V18h4v5h2V11A2.002 2.002 0 0013 9zM9 16V11h4v5z"
  })), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,28H4a2.0021,2.0021,0,0,1-2-2V6A2.0021,2.0021,0,0,1,4,4H28a2.0021,2.0021,0,0,1,2,2V26A2.0021,2.0021,0,0,1,28,28ZM4,6V26H28V6Z"
  })), children);
});
var Language32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Language32(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 19H24V21H18zM18 15H30V17H18zM18 11H30V13H18zM14 21V19H9V17H7v2H2v2h8.2148a8.5914 8.5914 0 01-2.2159 3.9771A9.2731 9.2731 0 016.5521 23H4.3334a10.8553 10.8553 0 002.1451 3.2966A14.6584 14.6584 0 013 28.127L3.7021 30a16.42 16.42 0 004.2907-2.3362A16.4883 16.4883 0 0012.2979 30L13 28.127A14.664 14.664 0 019.5228 26.3 10.3132 10.3132 0 0012.2516 21zM11.1666 13H13.333L8.75 2H6.5832L2 13H4.1664L5 11h5.3335zM5.8331 9L7.6665 4.6 9.5 9z"
  })), children);
});
var Language24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Language24(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 19H24V21H18zM18 15H30V17H18zM18 11H30V13H18zM14 21V19H9V17H7v2H2v2h8.2148a8.5914 8.5914 0 01-2.2159 3.9771A9.2731 9.2731 0 016.5521 23H4.3334a10.8553 10.8553 0 002.1451 3.2966A14.6584 14.6584 0 013 28.127L3.7021 30a16.42 16.42 0 004.2907-2.3362A16.4883 16.4883 0 0012.2979 30L13 28.127A14.664 14.664 0 019.5228 26.3 10.3132 10.3132 0 0012.2516 21zM11.1666 13H13.333L8.75 2H6.5832L2 13H4.1664L5 11h5.3335zM5.8331 9L7.6665 4.6 9.5 9z"
  })), children);
});
var Language20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Language20(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 19H24V21H18zM18 15H30V17H18zM18 11H30V13H18zM14 21V19H9V17H7v2H2v2h8.2148a8.5914 8.5914 0 01-2.2159 3.9771A9.2731 9.2731 0 016.5521 23H4.3334a10.8553 10.8553 0 002.1451 3.2966A14.6584 14.6584 0 013 28.127L3.7021 30a16.42 16.42 0 004.2907-2.3362A16.4883 16.4883 0 0012.2979 30L13 28.127A14.664 14.664 0 019.5228 26.3 10.3132 10.3132 0 0012.2516 21zM11.1666 13H13.333L8.75 2H6.5832L2 13H4.1664L5 11h5.3335zM5.8331 9L7.6665 4.6 9.5 9z"
  })), children);
});
var Language16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Language16(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 19H24V21H18zM18 15H30V17H18zM18 11H30V13H18zM14 21V19H9V17H7v2H2v2h8.2148a8.5914 8.5914 0 01-2.2159 3.9771A9.2731 9.2731 0 016.5521 23H4.3334a10.8553 10.8553 0 002.1451 3.2966A14.6584 14.6584 0 013 28.127L3.7021 30a16.42 16.42 0 004.2907-2.3362A16.4883 16.4883 0 0012.2979 30L13 28.127A14.664 14.664 0 019.5228 26.3 10.3132 10.3132 0 0012.2516 21zM11.1666 13H13.333L8.75 2H6.5832L2 13H4.1664L5 11h5.3335zM5.8331 9L7.6665 4.6 9.5 9z"
  })), children);
});
var Laptop32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Laptop32(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,24H6a2.0023,2.0023,0,0,1-2-2V8A2.002,2.002,0,0,1,6,6H26a2.0023,2.0023,0,0,1,2,2V22A2.0027,2.0027,0,0,1,26,24ZM6,8V22H26V8Z",
    transform: "translate(0 .005)"
  })), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26.005H30V28.005H2z"
  })), children);
});
var Laptop24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Laptop24(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,24H6a2.0023,2.0023,0,0,1-2-2V8A2.002,2.002,0,0,1,6,6H26a2.0023,2.0023,0,0,1,2,2V22A2.0027,2.0027,0,0,1,26,24ZM6,8V22H26V8Z",
    transform: "translate(0 .005)"
  })), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26.005H30V28.005H2z"
  })), children);
});
var Laptop20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Laptop20(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,24H6a2.0023,2.0023,0,0,1-2-2V8A2.002,2.002,0,0,1,6,6H26a2.0023,2.0023,0,0,1,2,2V22A2.0027,2.0027,0,0,1,26,24ZM6,8V22H26V8Z",
    transform: "translate(0 .005)"
  })), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26.005H30V28.005H2z"
  })), children);
});
var Laptop16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Laptop16(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,24H6a2.0023,2.0023,0,0,1-2-2V8A2.002,2.002,0,0,1,6,6H26a2.0023,2.0023,0,0,1,2,2V22A2.0027,2.0027,0,0,1,26,24ZM6,8V22H26V8Z",
    transform: "translate(0 .005)"
  })), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26.005H30V28.005H2z"
  })), children);
});
var Lasso32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Lasso32(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,2H12A9.9842,9.9842,0,0,0,7.0349,20.6553C7.0249,20.7705,7,20.8818,7,21a3.9929,3.9929,0,0,0,2.9106,3.83A4.0049,4.0049,0,0,1,6,28H4v2H6a6.0044,6.0044,0,0,0,5.928-5.12,3.9966,3.9966,0,0,0,2.93-2.88H20A10,10,0,0,0,20,2ZM11,23a2,2,0,1,1,2-2A2.0025,2.0025,0,0,1,11,23Zm9-3H14.8579a3.9841,3.9841,0,0,0-7.15-1.2637A7.99,7.99,0,0,1,12,4h8a8,8,0,0,1,0,16Z"
  })), children);
});
var Lasso24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Lasso24(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,2H12A9.9842,9.9842,0,0,0,7.0349,20.6553C7.0249,20.7705,7,20.8818,7,21a3.9929,3.9929,0,0,0,2.9106,3.83A4.0049,4.0049,0,0,1,6,28H4v2H6a6.0044,6.0044,0,0,0,5.928-5.12,3.9966,3.9966,0,0,0,2.93-2.88H20A10,10,0,0,0,20,2ZM11,23a2,2,0,1,1,2-2A2.0025,2.0025,0,0,1,11,23Zm9-3H14.8579a3.9841,3.9841,0,0,0-7.15-1.2637A7.99,7.99,0,0,1,12,4h8a8,8,0,0,1,0,16Z"
  })), children);
});
var Lasso20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Lasso20(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,2H12A9.9842,9.9842,0,0,0,7.0349,20.6553C7.0249,20.7705,7,20.8818,7,21a3.9929,3.9929,0,0,0,2.9106,3.83A4.0049,4.0049,0,0,1,6,28H4v2H6a6.0044,6.0044,0,0,0,5.928-5.12,3.9966,3.9966,0,0,0,2.93-2.88H20A10,10,0,0,0,20,2ZM11,23a2,2,0,1,1,2-2A2.0025,2.0025,0,0,1,11,23Zm9-3H14.8579a3.9841,3.9841,0,0,0-7.15-1.2637A7.99,7.99,0,0,1,12,4h8a8,8,0,0,1,0,16Z"
  })), children);
});
var Lasso16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Lasso16(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,2H12A9.9842,9.9842,0,0,0,7.0349,20.6553C7.0249,20.7705,7,20.8818,7,21a3.9929,3.9929,0,0,0,2.9106,3.83A4.0049,4.0049,0,0,1,6,28H4v2H6a6.0044,6.0044,0,0,0,5.928-5.12,3.9966,3.9966,0,0,0,2.93-2.88H20A10,10,0,0,0,20,2ZM11,23a2,2,0,1,1,2-2A2.0025,2.0025,0,0,1,11,23Zm9-3H14.8579a3.9841,3.9841,0,0,0-7.15-1.2637A7.99,7.99,0,0,1,12,4h8a8,8,0,0,1,0,16Z"
  })), children);
});
var LassoPolygon32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LassoPolygon32(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.6245,2.2193a1.0005,1.0005,0,0,0-1.0972-.1006L17.9353,7.8,3.366,2.0694a1,1,0,0,0-1.28,1.3369l6.4353,14.479A3.965,3.965,0,0,0,9.9106,24.83,4.0049,4.0049,0,0,1,6,28H4v2H6a6.0044,6.0044,0,0,0,5.928-5.12,4.0021,4.0021,0,0,0,2.93-2.88H23.24a2,2,0,0,0,1.9273-1.4649L29.9634,3.2676A1,1,0,0,0,29.6245,2.2193ZM11,23a2,2,0,1,1,2-2A2.0025,2.0025,0,0,1,11,23Zm12.24-3H14.8579a3.897,3.897,0,0,0-4.5117-2.9336L4.905,4.8238,18.0647,10,27.41,4.9878Z"
  })), children);
});
var LassoPolygon24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LassoPolygon24(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.6245,2.2193a1.0005,1.0005,0,0,0-1.0972-.1006L17.9353,7.8,3.366,2.0694a1,1,0,0,0-1.28,1.3369l6.4353,14.479A3.965,3.965,0,0,0,9.9106,24.83,4.0049,4.0049,0,0,1,6,28H4v2H6a6.0044,6.0044,0,0,0,5.928-5.12,4.0021,4.0021,0,0,0,2.93-2.88H23.24a2,2,0,0,0,1.9273-1.4649L29.9634,3.2676A1,1,0,0,0,29.6245,2.2193ZM11,23a2,2,0,1,1,2-2A2.0025,2.0025,0,0,1,11,23Zm12.24-3H14.8579a3.897,3.897,0,0,0-4.5117-2.9336L4.905,4.8238,18.0647,10,27.41,4.9878Z"
  })), children);
});
var LassoPolygon20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LassoPolygon20(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.6245,2.2193a1.0005,1.0005,0,0,0-1.0972-.1006L17.9353,7.8,3.366,2.0694a1,1,0,0,0-1.28,1.3369l6.4353,14.479A3.965,3.965,0,0,0,9.9106,24.83,4.0049,4.0049,0,0,1,6,28H4v2H6a6.0044,6.0044,0,0,0,5.928-5.12,4.0021,4.0021,0,0,0,2.93-2.88H23.24a2,2,0,0,0,1.9273-1.4649L29.9634,3.2676A1,1,0,0,0,29.6245,2.2193ZM11,23a2,2,0,1,1,2-2A2.0025,2.0025,0,0,1,11,23Zm12.24-3H14.8579a3.897,3.897,0,0,0-4.5117-2.9336L4.905,4.8238,18.0647,10,27.41,4.9878Z"
  })), children);
});
var LassoPolygon16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LassoPolygon16(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.6245,2.2193a1.0005,1.0005,0,0,0-1.0972-.1006L17.9353,7.8,3.366,2.0694a1,1,0,0,0-1.28,1.3369l6.4353,14.479A3.965,3.965,0,0,0,9.9106,24.83,4.0049,4.0049,0,0,1,6,28H4v2H6a6.0044,6.0044,0,0,0,5.928-5.12,4.0021,4.0021,0,0,0,2.93-2.88H23.24a2,2,0,0,0,1.9273-1.4649L29.9634,3.2676A1,1,0,0,0,29.6245,2.2193ZM11,23a2,2,0,1,1,2-2A2.0025,2.0025,0,0,1,11,23Zm12.24-3H14.8579a3.897,3.897,0,0,0-4.5117-2.9336L4.905,4.8238,18.0647,10,27.41,4.9878Z"
  })), children);
});
var Launch32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Launch32(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0027,2.0027,0,0,1-2-2V6A2.0027,2.0027,0,0,1,6,4H16V6H6V26H26V16h2V26A2.0027,2.0027,0,0,1,26,28Z"
  })), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 2L20 4 26.586 4 18 12.586 19.414 14 28 5.414 28 12 30 12 30 2 20 2z"
  })), children);
});
var Launch24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Launch24(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0027,2.0027,0,0,1-2-2V6A2.0027,2.0027,0,0,1,6,4H16V6H6V26H26V16h2V26A2.0027,2.0027,0,0,1,26,28Z"
  })), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 2L20 4 26.586 4 18 12.586 19.414 14 28 5.414 28 12 30 12 30 2 20 2z"
  })), children);
});
var Launch20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Launch20(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0027,2.0027,0,0,1-2-2V6A2.0027,2.0027,0,0,1,6,4H16V6H6V26H26V16h2V26A2.0027,2.0027,0,0,1,26,28Z"
  })), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 2L20 4 26.586 4 18 12.586 19.414 14 28 5.414 28 12 30 12 30 2 20 2z"
  })), children);
});
var Launch16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Launch16(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,14H3c-0.6,0-1-0.4-1-1V3c0-0.6,0.4-1,1-1h5v1H3v10h10V8h1v5C14,13.6,13.6,14,13,14z"
  })), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 1L10 2 13.3 2 9 6.3 9.7 7 14 2.7 14 6 15 6 15 1z"
  })), children);
});
var WatsonHealthLaunchStudy_132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthLaunchStudy_132(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "25",
    r: "1"
  })), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 22v6H6V22H26m0-2H6a2 2 0 00-2 2v6a2 2 0 002 2H26a2 2 0 002-2V22a2 2 0 00-2-2zM20.59 10.59L17 14.17 17 2 15 2 15 14.17 11.41 10.59 10 12 16 18 22 12 20.59 10.59z"
  })), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 24H20V26H8z"
  })), children);
});
var WatsonHealthLaunchStudy_124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthLaunchStudy_124(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "25",
    r: "1"
  })), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 22v6H6V22H26m0-2H6a2 2 0 00-2 2v6a2 2 0 002 2H26a2 2 0 002-2V22a2 2 0 00-2-2zM20.59 10.59L17 14.17 17 2 15 2 15 14.17 11.41 10.59 10 12 16 18 22 12 20.59 10.59z"
  })), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 24H20V26H8z"
  })), children);
});
var WatsonHealthLaunchStudy_120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthLaunchStudy_120(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "25",
    r: "1"
  })), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 22v6H6V22H26m0-2H6a2 2 0 00-2 2v6a2 2 0 002 2H26a2 2 0 002-2V22a2 2 0 00-2-2zM20.59 10.59L17 14.17 17 2 15 2 15 14.17 11.41 10.59 10 12 16 18 22 12 20.59 10.59z"
  })), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 24H20V26H8z"
  })), children);
});
var WatsonHealthLaunchStudy_116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthLaunchStudy_116(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "25",
    r: "1"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 22v6H6V22H26m0-2H6a2 2 0 00-2 2v6a2 2 0 002 2H26a2 2 0 002-2V22a2 2 0 00-2-2zM20.59 10.59L17 14.17 17 2 15 2 15 14.17 11.41 10.59 10 12 16 18 22 12 20.59 10.59z"
  })), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 24H20V26H8z"
  })), children);
});
var WatsonHealthLaunchStudy_232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthLaunchStudy_232(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "7",
    r: "1"
  })), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 4v6H6V4H26m0-2H6A2 2 0 004 4v6a2 2 0 002 2H26a2 2 0 002-2V4a2 2 0 00-2-2zM20.59 21.41L17 17.83 17 30 15 30 15 17.83 11.41 21.41 10 20 16 14 22 20 20.59 21.41z"
  })), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 6H20V8H8z"
  })), children);
});
var WatsonHealthLaunchStudy_224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthLaunchStudy_224(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "7",
    r: "1"
  })), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 4v6H6V4H26m0-2H6A2 2 0 004 4v6a2 2 0 002 2H26a2 2 0 002-2V4a2 2 0 00-2-2zM20.59 21.41L17 17.83 17 30 15 30 15 17.83 11.41 21.41 10 20 16 14 22 20 20.59 21.41z"
  })), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 6H20V8H8z"
  })), children);
});
var WatsonHealthLaunchStudy_220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthLaunchStudy_220(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "7",
    r: "1"
  })), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 4v6H6V4H26m0-2H6A2 2 0 004 4v6a2 2 0 002 2H26a2 2 0 002-2V4a2 2 0 00-2-2zM20.59 21.41L17 17.83 17 30 15 30 15 17.83 11.41 21.41 10 20 16 14 22 20 20.59 21.41z"
  })), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 6H20V8H8z"
  })), children);
});
var WatsonHealthLaunchStudy_216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthLaunchStudy_216(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "7",
    r: "1"
  })), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 4v6H6V4H26m0-2H6A2 2 0 004 4v6a2 2 0 002 2H26a2 2 0 002-2V4a2 2 0 00-2-2zM20.59 21.41L17 17.83 17 30 15 30 15 17.83 11.41 21.41 10 20 16 14 22 20 20.59 21.41z"
  })), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 6H20V8H8z"
  })), children);
});
var WatsonHealthLaunchStudy_332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthLaunchStudy_332(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "25",
    r: "1"
  })), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 22v6H6V22H26m0-2H6a2 2 0 00-2 2v6a2 2 0 002 2H26a2 2 0 002-2V22a2 2 0 00-2-2zM20.59 4.59L17 8.17 17 0 15 0 15 8.17 11.41 4.59 10 6 16 12 22 6 20.59 4.59z"
  })), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.59 10.59L16 15.16 11.41 10.59 10 12 16 18 22 12 20.59 10.59zM8 24H20V26H8z"
  })), children);
});
var WatsonHealthLaunchStudy_324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthLaunchStudy_324(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "25",
    r: "1"
  })), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 22v6H6V22H26m0-2H6a2 2 0 00-2 2v6a2 2 0 002 2H26a2 2 0 002-2V22a2 2 0 00-2-2zM20.59 4.59L17 8.17 17 0 15 0 15 8.17 11.41 4.59 10 6 16 12 22 6 20.59 4.59z"
  })), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.59 10.59L16 15.16 11.41 10.59 10 12 16 18 22 12 20.59 10.59zM8 24H20V26H8z"
  })), children);
});
var WatsonHealthLaunchStudy_320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthLaunchStudy_320(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "25",
    r: "1"
  })), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 22v6H6V22H26m0-2H6a2 2 0 00-2 2v6a2 2 0 002 2H26a2 2 0 002-2V22a2 2 0 00-2-2zM20.59 4.59L17 8.17 17 0 15 0 15 8.17 11.41 4.59 10 6 16 12 22 6 20.59 4.59z"
  })), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.59 10.59L16 15.16 11.41 10.59 10 12 16 18 22 12 20.59 10.59zM8 24H20V26H8z"
  })), children);
});
var WatsonHealthLaunchStudy_316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthLaunchStudy_316(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "25",
    r: "1"
  })), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 22v6H6V22H26m0-2H6a2 2 0 00-2 2v6a2 2 0 002 2H26a2 2 0 002-2V22a2 2 0 00-2-2zM20.59 4.59L17 8.17 17 0 15 0 15 8.17 11.41 4.59 10 6 16 12 22 6 20.59 4.59z"
  })), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.59 10.59L16 15.16 11.41 10.59 10 12 16 18 22 12 20.59 10.59zM8 24H20V26H8z"
  })), children);
});
var Layers32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Layers32(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24a.9967.9967,0,0,1-.4741-.12l-13-7L3.4741,15.12,16,21.8643,28.5259,15.12l.9482,1.7607-13,7A.9967.9967,0,0,1,16,24Z"
  })), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30a.9967.9967 0 01-.4741-.12l-13-7L3.4741 21.12 16 27.8643 28.5259 21.12l.9482 1.7607-13 7A.9967.9967 0 0116 30zM16 18a.9967.9967 0 01-.4741-.12l-13-7a1 1 0 010-1.7607l13-7a.9982.9982 0 01.9482 0l13 7a1 1 0 010 1.7607l-13 7A.9967.9967 0 0116 18zM5.1094 10L16 15.8643 26.8906 10 16 4.1358z"
  })), children);
});
var Layers24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Layers24(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24a.9967.9967,0,0,1-.4741-.12l-13-7L3.4741,15.12,16,21.8643,28.5259,15.12l.9482,1.7607-13,7A.9967.9967,0,0,1,16,24Z"
  })), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30a.9967.9967 0 01-.4741-.12l-13-7L3.4741 21.12 16 27.8643 28.5259 21.12l.9482 1.7607-13 7A.9967.9967 0 0116 30zM16 18a.9967.9967 0 01-.4741-.12l-13-7a1 1 0 010-1.7607l13-7a.9982.9982 0 01.9482 0l13 7a1 1 0 010 1.7607l-13 7A.9967.9967 0 0116 18zM5.1094 10L16 15.8643 26.8906 10 16 4.1358z"
  })), children);
});
var Layers20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Layers20(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24a.9967.9967,0,0,1-.4741-.12l-13-7L3.4741,15.12,16,21.8643,28.5259,15.12l.9482,1.7607-13,7A.9967.9967,0,0,1,16,24Z"
  })), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30a.9967.9967 0 01-.4741-.12l-13-7L3.4741 21.12 16 27.8643 28.5259 21.12l.9482 1.7607-13 7A.9967.9967 0 0116 30zM16 18a.9967.9967 0 01-.4741-.12l-13-7a1 1 0 010-1.7607l13-7a.9982.9982 0 01.9482 0l13 7a1 1 0 010 1.7607l-13 7A.9967.9967 0 0116 18zM5.1094 10L16 15.8643 26.8906 10 16 4.1358z"
  })), children);
});
var Layers16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Layers16(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24a.9967.9967,0,0,1-.4741-.12l-13-7L3.4741,15.12,16,21.8643,28.5259,15.12l.9482,1.7607-13,7A.9967.9967,0,0,1,16,24Z"
  })), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30a.9967.9967 0 01-.4741-.12l-13-7L3.4741 21.12 16 27.8643 28.5259 21.12l.9482 1.7607-13 7A.9967.9967 0 0116 30zM16 18a.9967.9967 0 01-.4741-.12l-13-7a1 1 0 010-1.7607l13-7a.9982.9982 0 01.9482 0l13 7a1 1 0 010 1.7607l-13 7A.9967.9967 0 0116 18zM5.1094 10L16 15.8643 26.8906 10 16 4.1358z"
  })), children);
});
var Legend32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Legend32(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22H30V24H16z"
  })), _rect || (_rect = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("rect", {
    width: "6",
    height: "6",
    x: "4",
    y: "20",
    rx: "1"
  })), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8H30V10H16zM9.5 12h-5a.5.5 0 01-.4473-.7236l2.5-5.0224a.5206.5206 0 01.8945 0l2.5 5.0225A.5.5 0 019.5 12z"
  })), children);
});
var Legend24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Legend24(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22H30V24H16z"
  })), _rect2 || (_rect2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("rect", {
    width: "6",
    height: "6",
    x: "4",
    y: "20",
    rx: "1"
  })), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8H30V10H16zM9.5 12h-5a.5.5 0 01-.4473-.7236l2.5-5.0224a.5206.5206 0 01.8945 0l2.5 5.0225A.5.5 0 019.5 12z"
  })), children);
});
var Legend20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Legend20(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22H30V24H16z"
  })), _rect3 || (_rect3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("rect", {
    width: "6",
    height: "6",
    x: "4",
    y: "20",
    rx: "1"
  })), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8H30V10H16zM9.5 12h-5a.5.5 0 01-.4473-.7236l2.5-5.0224a.5206.5206 0 01.8945 0l2.5 5.0225A.5.5 0 019.5 12z"
  })), children);
});
var Legend16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Legend16(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22H30V24H16z"
  })), _rect4 || (_rect4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("rect", {
    width: "6",
    height: "6",
    x: "4",
    y: "20",
    rx: "1"
  })), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8H30V10H16zM9.5 12h-5a.5.5 0 01-.4473-.7236l2.5-5.0224a.5206.5206 0 01.8945 0l2.5 5.0225A.5.5 0 019.5 12z"
  })), children);
});
var LetterAa32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterAa32(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 13H18v2h5v2H19a2 2 0 00-2 2v2a2 2 0 002 2h6V15A2 2 0 0023 13zm0 8H19V19h4zM13 9H9a2 2 0 00-2 2V23H9V18h4v5h2V11A2 2 0 0013 9zM9 16V11h4v5z"
  })), children);
});
var LetterAa24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterAa24(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 13H18v2h5v2H19a2 2 0 00-2 2v2a2 2 0 002 2h6V15A2 2 0 0023 13zm0 8H19V19h4zM13 9H9a2 2 0 00-2 2V23H9V18h4v5h2V11A2 2 0 0013 9zM9 16V11h4v5z"
  })), children);
});
var LetterAa20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterAa20(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 13H18v2h5v2H19a2 2 0 00-2 2v2a2 2 0 002 2h6V15A2 2 0 0023 13zm0 8H19V19h4zM13 9H9a2 2 0 00-2 2V23H9V18h4v5h2V11A2 2 0 0013 9zM9 16V11h4v5z"
  })), children);
});
var LetterAa16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterAa16(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 13H18v2h5v2H19a2 2 0 00-2 2v2a2 2 0 002 2h6V15A2 2 0 0023 13zm0 8H19V19h4zM13 9H9a2 2 0 00-2 2V23H9V18h4v5h2V11A2 2 0 0013 9zM9 16V11h4v5z"
  })), children);
});
var LetterAaLarge32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterAaLarge32(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  if (true) {
    if (!didWarnAboutDeprecation['LetterAaLarge32']) {
      didWarnAboutDeprecation['LetterAaLarge32'] = true;
      console.warn("The LetterAaLarge32 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 12H20v2h5a1.0008 1.0008 0 011 1v2H22a3.0033 3.0033 0 00-3 3v1a3.0033 3.0033 0 003 3h6V15A3.0033 3.0033 0 0025 12zM22 22a1.0008 1.0008 0 01-1-1V20a1.0008 1.0008 0 011-1h4v3zM16 24h2L12 7H10L4 24H6l1.6936-5h6.6135zM8.3711 17l2.4966-7.3711.2668.0005L13.63 17z"
  })), children);
});
var LetterAaLarge24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterAaLarge24(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  if (true) {
    if (!didWarnAboutDeprecation['LetterAaLarge24']) {
      didWarnAboutDeprecation['LetterAaLarge24'] = true;
      console.warn("The LetterAaLarge24 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 12H20v2h5a1.0008 1.0008 0 011 1v2H22a3.0033 3.0033 0 00-3 3v1a3.0033 3.0033 0 003 3h6V15A3.0033 3.0033 0 0025 12zM22 22a1.0008 1.0008 0 01-1-1V20a1.0008 1.0008 0 011-1h4v3zM16 24h2L12 7H10L4 24H6l1.6936-5h6.6135zM8.3711 17l2.4966-7.3711.2668.0005L13.63 17z"
  })), children);
});
var LetterAaLarge20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterAaLarge20(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  if (true) {
    if (!didWarnAboutDeprecation['LetterAaLarge20']) {
      didWarnAboutDeprecation['LetterAaLarge20'] = true;
      console.warn("The LetterAaLarge20 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 12H20v2h5a1.0008 1.0008 0 011 1v2H22a3.0033 3.0033 0 00-3 3v1a3.0033 3.0033 0 003 3h6V15A3.0033 3.0033 0 0025 12zM22 22a1.0008 1.0008 0 01-1-1V20a1.0008 1.0008 0 011-1h4v3zM16 24h2L12 7H10L4 24H6l1.6936-5h6.6135zM8.3711 17l2.4966-7.3711.2668.0005L13.63 17z"
  })), children);
});
var LetterAaLarge16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterAaLarge16(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  if (true) {
    if (!didWarnAboutDeprecation['LetterAaLarge16']) {
      didWarnAboutDeprecation['LetterAaLarge16'] = true;
      console.warn("The LetterAaLarge16 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 12H20v2h5a1.0008 1.0008 0 011 1v2H22a3.0033 3.0033 0 00-3 3v1a3.0033 3.0033 0 003 3h6V15A3.0033 3.0033 0 0025 12zM22 22a1.0008 1.0008 0 01-1-1V20a1.0008 1.0008 0 011-1h4v3zM16 24h2L12 7H10L4 24H6l1.6936-5h6.6135zM8.3711 17l2.4966-7.3711.2668.0005L13.63 17z"
  })), children);
});
var LetterBb32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterBb32(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 13H19V9H17V23h6a2 2 0 002-2V15A2 2 0 0023 13zm-4 8V15h4v6zM15 12a3 3 0 00-3-3H7V23h5a3 3 0 003-3V18a3 3 0 00-.78-2A3 3 0 0015 14zM9 11h3a1 1 0 011 1v2a1 1 0 01-1 1H9zm4 9a1 1 0 01-1 1H9V17h3a1 1 0 011 1z"
  })), children);
});
var LetterBb24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterBb24(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 13H19V9H17V23h6a2 2 0 002-2V15A2 2 0 0023 13zm-4 8V15h4v6zM15 12a3 3 0 00-3-3H7V23h5a3 3 0 003-3V18a3 3 0 00-.78-2A3 3 0 0015 14zM9 11h3a1 1 0 011 1v2a1 1 0 01-1 1H9zm4 9a1 1 0 01-1 1H9V17h3a1 1 0 011 1z"
  })), children);
});
var LetterBb20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterBb20(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 13H19V9H17V23h6a2 2 0 002-2V15A2 2 0 0023 13zm-4 8V15h4v6zM15 12a3 3 0 00-3-3H7V23h5a3 3 0 003-3V18a3 3 0 00-.78-2A3 3 0 0015 14zM9 11h3a1 1 0 011 1v2a1 1 0 01-1 1H9zm4 9a1 1 0 01-1 1H9V17h3a1 1 0 011 1z"
  })), children);
});
var LetterBb16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterBb16(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 13H19V9H17V23h6a2 2 0 002-2V15A2 2 0 0023 13zm-4 8V15h4v6zM15 12a3 3 0 00-3-3H7V23h5a3 3 0 003-3V18a3 3 0 00-.78-2A3 3 0 0015 14zM9 11h3a1 1 0 011 1v2a1 1 0 01-1 1H9zm4 9a1 1 0 01-1 1H9V17h3a1 1 0 011 1z"
  })), children);
});
var LetterCc32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterCc32(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 23H19a2 2 0 01-2-2V15a2 2 0 012-2h5v2H19v6h5zM15 23H9a2 2 0 01-2-2V11A2 2 0 019 9h6v2H9V21h6z"
  })), children);
});
var LetterCc24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterCc24(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 23H19a2 2 0 01-2-2V15a2 2 0 012-2h5v2H19v6h5zM15 23H9a2 2 0 01-2-2V11A2 2 0 019 9h6v2H9V21h6z"
  })), children);
});
var LetterCc20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterCc20(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 23H19a2 2 0 01-2-2V15a2 2 0 012-2h5v2H19v6h5zM15 23H9a2 2 0 01-2-2V11A2 2 0 019 9h6v2H9V21h6z"
  })), children);
});
var LetterCc16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterCc16(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 23H19a2 2 0 01-2-2V15a2 2 0 012-2h5v2H19v6h5zM15 23H9a2 2 0 01-2-2V11A2 2 0 019 9h6v2H9V21h6z"
  })), children);
});
var LetterDd32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterDd32(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 9v4H19a2 2 0 00-2 2v6a2 2 0 002 2h6V9zm-4 6h4v6H19zM11 23H7V9h4a4 4 0 014 4v6A4 4 0 0111 23zM9 21h2a2 2 0 002-2V13a2 2 0 00-2-2H9z"
  })), children);
});
var LetterDd24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterDd24(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 9v4H19a2 2 0 00-2 2v6a2 2 0 002 2h6V9zm-4 6h4v6H19zM11 23H7V9h4a4 4 0 014 4v6A4 4 0 0111 23zM9 21h2a2 2 0 002-2V13a2 2 0 00-2-2H9z"
  })), children);
});
var LetterDd20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterDd20(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 9v4H19a2 2 0 00-2 2v6a2 2 0 002 2h6V9zm-4 6h4v6H19zM11 23H7V9h4a4 4 0 014 4v6A4 4 0 0111 23zM9 21h2a2 2 0 002-2V13a2 2 0 00-2-2H9z"
  })), children);
});
var LetterDd16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterDd16(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 9v4H19a2 2 0 00-2 2v6a2 2 0 002 2h6V9zm-4 6h4v6H19zM11 23H7V9h4a4 4 0 014 4v6A4 4 0 0111 23zM9 21h2a2 2 0 002-2V13a2 2 0 00-2-2H9z"
  })), children);
});
var LetterEe32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterEe32(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 19V15a2.0023 2.0023 0 00-2-2H19a2.0023 2.0023 0 00-2 2v6a2.0077 2.0077 0 002 2h5V21H19V19zm-6-4h4v2H19zM15 11L15 9 7 9 7 23 15 23 15 21 9 21 9 17 14 17 14 15 9 15 9 11 15 11z"
  })), children);
});
var LetterEe24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterEe24(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 19V15a2.0023 2.0023 0 00-2-2H19a2.0023 2.0023 0 00-2 2v6a2.0077 2.0077 0 002 2h5V21H19V19zm-6-4h4v2H19zM15 11L15 9 7 9 7 23 15 23 15 21 9 21 9 17 14 17 14 15 9 15 9 11 15 11z"
  })), children);
});
var LetterEe20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterEe20(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 19V15a2.0023 2.0023 0 00-2-2H19a2.0023 2.0023 0 00-2 2v6a2.0077 2.0077 0 002 2h5V21H19V19zm-6-4h4v2H19zM15 11L15 9 7 9 7 23 15 23 15 21 9 21 9 17 14 17 14 15 9 15 9 11 15 11z"
  })), children);
});
var LetterEe16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterEe16(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 19V15a2.0023 2.0023 0 00-2-2H19a2.0023 2.0023 0 00-2 2v6a2.0077 2.0077 0 002 2h5V21H19V19zm-6-4h4v2H19zM15 11L15 9 7 9 7 23 15 23 15 21 9 21 9 17 14 17 14 15 9 15 9 11 15 11z"
  })), children);
});
var LetterFf32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterFf32(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 11L16 9 8 9 8 23 10 23 10 17 15 17 15 15 10 15 10 11 16 11zM24 11V9H21a2 2 0 00-2 2v2H17v2h2v8h2V15h3V13H21V11z"
  })), children);
});
var LetterFf24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterFf24(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 11L16 9 8 9 8 23 10 23 10 17 15 17 15 15 10 15 10 11 16 11zM24 11V9H21a2 2 0 00-2 2v2H17v2h2v8h2V15h3V13H21V11z"
  })), children);
});
var LetterFf20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterFf20(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 11L16 9 8 9 8 23 10 23 10 17 15 17 15 15 10 15 10 11 16 11zM24 11V9H21a2 2 0 00-2 2v2H17v2h2v8h2V15h3V13H21V11z"
  })), children);
});
var LetterFf16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterFf16(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 11L16 9 8 9 8 23 10 23 10 17 15 17 15 15 10 15 10 11 16 11zM24 11V9H21a2 2 0 00-2 2v2H17v2h2v8h2V15h3V13H21V11z"
  })), children);
});
var LetterGg32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterGg32(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13a2 2 0 00-2 2v6a2 2 0 002 2h4v2H18v2h5a2 2 0 002-2V13zm4 8H19V15h4zM15 23H9a2 2 0 01-2-2V11A2 2 0 019 9h6v2H9V21h4V17H11V15h4z"
  })), children);
});
var LetterGg24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterGg24(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13a2 2 0 00-2 2v6a2 2 0 002 2h4v2H18v2h5a2 2 0 002-2V13zm4 8H19V15h4zM15 23H9a2 2 0 01-2-2V11A2 2 0 019 9h6v2H9V21h4V17H11V15h4z"
  })), children);
});
var LetterGg20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterGg20(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13a2 2 0 00-2 2v6a2 2 0 002 2h4v2H18v2h5a2 2 0 002-2V13zm4 8H19V15h4zM15 23H9a2 2 0 01-2-2V11A2 2 0 019 9h6v2H9V21h4V17H11V15h4z"
  })), children);
});
var LetterGg16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterGg16(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13a2 2 0 00-2 2v6a2 2 0 002 2h4v2H18v2h5a2 2 0 002-2V13zm4 8H19V15h4zM15 23H9a2 2 0 01-2-2V11A2 2 0 019 9h6v2H9V21h4V17H11V15h4z"
  })), children);
});
var LetterHh32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterHh32(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 9L13 15 9 15 9 9 7 9 7 23 9 23 9 17 13 17 13 23 15 23 15 9 13 9zM23 13H19V9H17V23h2V15h4v8h2V15A2 2 0 0023 13z"
  })), children);
});
var LetterHh24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterHh24(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 9L13 15 9 15 9 9 7 9 7 23 9 23 9 17 13 17 13 23 15 23 15 9 13 9zM23 13H19V9H17V23h2V15h4v8h2V15A2 2 0 0023 13z"
  })), children);
});
var LetterHh20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterHh20(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 9L13 15 9 15 9 9 7 9 7 23 9 23 9 17 13 17 13 23 15 23 15 9 13 9zM23 13H19V9H17V23h2V15h4v8h2V15A2 2 0 0023 13z"
  })), children);
});
var LetterHh16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterHh16(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 9L13 15 9 15 9 9 7 9 7 23 9 23 9 17 13 17 13 23 15 23 15 9 13 9zM23 13H19V9H17V23h2V15h4v8h2V15A2 2 0 0023 13z"
  })), children);
});
var LetterIi32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterIi32(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 11L13 11 13 21 10 21 10 23 18 23 18 21 15 21 15 11 18 11 18 9 10 9 10 11zM20 13H22V23H20zM20 9H22V11H20z"
  })), children);
});
var LetterIi24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterIi24(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 11L13 11 13 21 10 21 10 23 18 23 18 21 15 21 15 11 18 11 18 9 10 9 10 11zM20 13H22V23H20zM20 9H22V11H20z"
  })), children);
});
var LetterIi20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterIi20(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 11L13 11 13 21 10 21 10 23 18 23 18 21 15 21 15 11 18 11 18 9 10 9 10 11zM20 13H22V23H20zM20 9H22V11H20z"
  })), children);
});
var LetterIi16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterIi16(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 11L13 11 13 21 10 21 10 23 18 23 18 21 15 21 15 11 18 11 18 9 10 9 10 11zM20 13H22V23H20zM20 9H22V11H20z"
  })), children);
});
var LetterJj32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterJj32(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9H22V11H20zM20 25H17v2h3a2 2 0 002-2V13H20zM14 23H10a2 2 0 01-2-2V19h2v2h4V9h2V21A2 2 0 0114 23z"
  })), children);
});
var LetterJj24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterJj24(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9H22V11H20zM20 25H17v2h3a2 2 0 002-2V13H20zM14 23H10a2 2 0 01-2-2V19h2v2h4V9h2V21A2 2 0 0114 23z"
  })), children);
});
var LetterJj20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterJj20(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9H22V11H20zM20 25H17v2h3a2 2 0 002-2V13H20zM14 23H10a2 2 0 01-2-2V19h2v2h4V9h2V21A2 2 0 0114 23z"
  })), children);
});
var LetterJj16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterJj16(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9H22V11H20zM20 25H17v2h3a2 2 0 002-2V13H20zM14 23H10a2 2 0 01-2-2V19h2v2h4V9h2V21A2 2 0 0114 23z"
  })), children);
});
var LetterKk32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterKk32(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 9L12.89 9 9 15.55 9 9 7 9 7 23 9 23 9 18.71 9.93 17.22 12.89 23 15 23 11.11 15.43 15 9zM22.78 23L25 23 21.22 17 25 13 22.76 13 19 17.17 19 9 17 9 17 23 19 23 19 19.25 19.96 18.21 22.78 23z"
  })), children);
});
var LetterKk24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterKk24(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 9L12.89 9 9 15.55 9 9 7 9 7 23 9 23 9 18.71 9.93 17.22 12.89 23 15 23 11.11 15.43 15 9zM22.78 23L25 23 21.22 17 25 13 22.76 13 19 17.17 19 9 17 9 17 23 19 23 19 19.25 19.96 18.21 22.78 23z"
  })), children);
});
var LetterKk20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterKk20(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 9L12.89 9 9 15.55 9 9 7 9 7 23 9 23 9 18.71 9.93 17.22 12.89 23 15 23 11.11 15.43 15 9zM22.78 23L25 23 21.22 17 25 13 22.76 13 19 17.17 19 9 17 9 17 23 19 23 19 19.25 19.96 18.21 22.78 23z"
  })), children);
});
var LetterKk16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterKk16(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 9L12.89 9 9 15.55 9 9 7 9 7 23 9 23 9 18.71 9.93 17.22 12.89 23 15 23 11.11 15.43 15 9zM22.78 23L25 23 21.22 17 25 13 22.76 13 19 17.17 19 9 17 9 17 23 19 23 19 19.25 19.96 18.21 22.78 23z"
  })), children);
});
var LetterLl32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterLl32(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 21L11 9 9 9 9 23 17 23 17 21 11 21zM23 23H21a2 2 0 01-2-2V9h2V21h2z"
  })), children);
});
var LetterLl24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterLl24(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 21L11 9 9 9 9 23 17 23 17 21 11 21zM23 23H21a2 2 0 01-2-2V9h2V21h2z"
  })), children);
});
var LetterLl20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterLl20(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 21L11 9 9 9 9 23 17 23 17 21 11 21zM23 23H21a2 2 0 01-2-2V9h2V21h2z"
  })), children);
});
var LetterLl16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterLl16(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 21L11 9 9 9 9 23 17 23 17 21 11 21zM23 23H21a2 2 0 01-2-2V9h2V21h2z"
  })), children);
});
var LetterMm32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterMm32(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 13H16V23h2V15h2v8h2V15h2v8h2V15A2 2 0 0024 13zM12 9L10.48 14 10 15.98 9.54 14 8 9 6 9 6 23 8 23 8 15 7.84 13 8.42 15 10 19.63 11.58 15 12.16 13 12 15 12 23 14 23 14 9 12 9z"
  })), children);
});
var LetterMm24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterMm24(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 13H16V23h2V15h2v8h2V15h2v8h2V15A2 2 0 0024 13zM12 9L10.48 14 10 15.98 9.54 14 8 9 6 9 6 23 8 23 8 15 7.84 13 8.42 15 10 19.63 11.58 15 12.16 13 12 15 12 23 14 23 14 9 12 9z"
  })), children);
});
var LetterMm20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterMm20(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 13H16V23h2V15h2v8h2V15h2v8h2V15A2 2 0 0024 13zM12 9L10.48 14 10 15.98 9.54 14 8 9 6 9 6 23 8 23 8 15 7.84 13 8.42 15 10 19.63 11.58 15 12.16 13 12 15 12 23 14 23 14 9 12 9z"
  })), children);
});
var LetterMm16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterMm16(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 13H16V23h2V15h2v8h2V15h2v8h2V15A2 2 0 0024 13zM12 9L10.48 14 10 15.98 9.54 14 8 9 6 9 6 23 8 23 8 15 7.84 13 8.42 15 10 19.63 11.58 15 12.16 13 12 15 12 23 14 23 14 9 12 9z"
  })), children);
});
var LetterNn32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterNn32(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23H23V15H19v8H17V13h6a2 2 0 012 2zM13 19L9.32 9 7 9 7 23 9 23 9 13 12.68 23 15 23 15 9 13 9 13 19z"
  })), children);
});
var LetterNn24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterNn24(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23H23V15H19v8H17V13h6a2 2 0 012 2zM13 19L9.32 9 7 9 7 23 9 23 9 13 12.68 23 15 23 15 9 13 9 13 19z"
  })), children);
});
var LetterNn20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterNn20(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23H23V15H19v8H17V13h6a2 2 0 012 2zM13 19L9.32 9 7 9 7 23 9 23 9 13 12.68 23 15 23 15 9 13 9 13 19z"
  })), children);
});
var LetterNn16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterNn16(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23H23V15H19v8H17V13h6a2 2 0 012 2zM13 19L9.32 9 7 9 7 23 9 23 9 13 12.68 23 15 23 15 9 13 9 13 19z"
  })), children);
});
var LetterOo32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterOo32(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 23H19a2 2 0 01-2-2V15a2 2 0 012-2h4a2 2 0 012 2v6A2 2 0 0123 23zm-4-8v6h4V15zM13 23H9a2 2 0 01-2-2V11A2 2 0 019 9h4a2 2 0 012 2V21A2 2 0 0113 23zM9 11V21h4V11z"
  })), children);
});
var LetterOo24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterOo24(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 23H19a2 2 0 01-2-2V15a2 2 0 012-2h4a2 2 0 012 2v6A2 2 0 0123 23zm-4-8v6h4V15zM13 23H9a2 2 0 01-2-2V11A2 2 0 019 9h4a2 2 0 012 2V21A2 2 0 0113 23zM9 11V21h4V11z"
  })), children);
});
var LetterOo20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterOo20(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 23H19a2 2 0 01-2-2V15a2 2 0 012-2h4a2 2 0 012 2v6A2 2 0 0123 23zm-4-8v6h4V15zM13 23H9a2 2 0 01-2-2V11A2 2 0 019 9h4a2 2 0 012 2V21A2 2 0 0113 23zM9 11V21h4V11z"
  })), children);
});
var LetterOo16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterOo16(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 23H19a2 2 0 01-2-2V15a2 2 0 012-2h4a2 2 0 012 2v6A2 2 0 0123 23zm-4-8v6h4V15zM13 23H9a2 2 0 01-2-2V11A2 2 0 019 9h4a2 2 0 012 2V21A2 2 0 0113 23zM9 11V21h4V11z"
  })), children);
});
var LetterPp32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterPp32(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 13H17V27h2V23h4a2 2 0 002-2V15A2 2 0 0023 13zm-4 8V15h4v6zM9 23H7V9h6a2 2 0 012 2v5a2 2 0 01-2 2H9zm0-7h4V11H9z"
  })), children);
});
var LetterPp24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterPp24(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 13H17V27h2V23h4a2 2 0 002-2V15A2 2 0 0023 13zm-4 8V15h4v6zM9 23H7V9h6a2 2 0 012 2v5a2 2 0 01-2 2H9zm0-7h4V11H9z"
  })), children);
});
var LetterPp20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterPp20(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 13H17V27h2V23h4a2 2 0 002-2V15A2 2 0 0023 13zm-4 8V15h4v6zM9 23H7V9h6a2 2 0 012 2v5a2 2 0 01-2 2H9zm0-7h4V11H9z"
  })), children);
});
var LetterPp16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterPp16(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 13H17V27h2V23h4a2 2 0 002-2V15A2 2 0 0023 13zm-4 8V15h4v6zM9 23H7V9h6a2 2 0 012 2v5a2 2 0 01-2 2H9zm0-7h4V11H9z"
  })), children);
});
var LetterQq32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterQq32(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13a2 2 0 00-2 2v6a2 2 0 002 2h4v4h2V13zm4 8H19V15h4zM13 9H9a2 2 0 00-2 2V21a2 2 0 002 2h1v2a2 2 0 002 2h2V25H12V23h1a2 2 0 002-2V11A2 2 0 0013 9zM9 21V11h4V21z"
  })), children);
});
var LetterQq24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterQq24(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13a2 2 0 00-2 2v6a2 2 0 002 2h4v4h2V13zm4 8H19V15h4zM13 9H9a2 2 0 00-2 2V21a2 2 0 002 2h1v2a2 2 0 002 2h2V25H12V23h1a2 2 0 002-2V11A2 2 0 0013 9zM9 21V11h4V21z"
  })), children);
});
var LetterQq20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterQq20(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13a2 2 0 00-2 2v6a2 2 0 002 2h4v4h2V13zm4 8H19V15h4zM13 9H9a2 2 0 00-2 2V21a2 2 0 002 2h1v2a2 2 0 002 2h2V25H12V23h1a2 2 0 002-2V11A2 2 0 0013 9zM9 21V11h4V21z"
  })), children);
});
var LetterQq16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterQq16(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13a2 2 0 00-2 2v6a2 2 0 002 2h4v4h2V13zm4 8H19V15h4zM13 9H9a2 2 0 00-2 2V21a2 2 0 002 2h1v2a2 2 0 002 2h2V25H12V23h1a2 2 0 002-2V11A2 2 0 0013 9zM9 21V11h4V21z"
  })), children);
});
var LetterRr32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterRr32(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 15V11a2 2 0 00-2-2H8V23h2V17h1.48l2.34 6H16l-2.33-6H14A2 2 0 0016 15zm-6-4h4v4H10zM24 13L18 13 18 23 20 23 20 15 24 15 24 13z"
  })), children);
});
var LetterRr24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterRr24(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 15V11a2 2 0 00-2-2H8V23h2V17h1.48l2.34 6H16l-2.33-6H14A2 2 0 0016 15zm-6-4h4v4H10zM24 13L18 13 18 23 20 23 20 15 24 15 24 13z"
  })), children);
});
var LetterRr20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterRr20(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 15V11a2 2 0 00-2-2H8V23h2V17h1.48l2.34 6H16l-2.33-6H14A2 2 0 0016 15zm-6-4h4v4H10zM24 13L18 13 18 23 20 23 20 15 24 15 24 13z"
  })), children);
});
var LetterRr16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterRr16(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 15V11a2 2 0 00-2-2H8V23h2V17h1.48l2.34 6H16l-2.33-6H14A2 2 0 0016 15zm-6-4h4v4H10zM24 13L18 13 18 23 20 23 20 15 24 15 24 13z"
  })), children);
});
var LetterSs32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterSs32(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 23H17V21h5V19H19a2 2 0 01-2-2V15a2 2 0 012-2h5v2H19v2h3a2 2 0 012 2v2A2 2 0 0122 23zM13 23H7V21h6V17H9a2 2 0 01-2-2V11A2 2 0 019 9h6v2H9v4h4a2 2 0 012 2v4A2 2 0 0113 23z"
  })), children);
});
var LetterSs24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterSs24(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 23H17V21h5V19H19a2 2 0 01-2-2V15a2 2 0 012-2h5v2H19v2h3a2 2 0 012 2v2A2 2 0 0122 23zM13 23H7V21h6V17H9a2 2 0 01-2-2V11A2 2 0 019 9h6v2H9v4h4a2 2 0 012 2v4A2 2 0 0113 23z"
  })), children);
});
var LetterSs20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterSs20(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 23H17V21h5V19H19a2 2 0 01-2-2V15a2 2 0 012-2h5v2H19v2h3a2 2 0 012 2v2A2 2 0 0122 23zM13 23H7V21h6V17H9a2 2 0 01-2-2V11A2 2 0 019 9h6v2H9v4h4a2 2 0 012 2v4A2 2 0 0113 23z"
  })), children);
});
var LetterSs16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterSs16(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 23H17V21h5V19H19a2 2 0 01-2-2V15a2 2 0 012-2h5v2H19v2h3a2 2 0 012 2v2A2 2 0 0122 23zM13 23H7V21h6V17H9a2 2 0 01-2-2V11A2 2 0 019 9h6v2H9v4h4a2 2 0 012 2v4A2 2 0 0113 23z"
  })), children);
});
var LetterTt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterTt32(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 11L11 11 11 23 13 23 13 11 16 11 16 9 8 9 8 11zM23 15V13H20V11H18v2H16v2h2v6a2 2 0 002 2h3V21H20V15z"
  })), children);
});
var LetterTt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterTt24(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 11L11 11 11 23 13 23 13 11 16 11 16 9 8 9 8 11zM23 15V13H20V11H18v2H16v2h2v6a2 2 0 002 2h3V21H20V15z"
  })), children);
});
var LetterTt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterTt20(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 11L11 11 11 23 13 23 13 11 16 11 16 9 8 9 8 11zM23 15V13H20V11H18v2H16v2h2v6a2 2 0 002 2h3V21H20V15z"
  })), children);
});
var LetterTt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterTt16(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 11L11 11 11 23 13 23 13 11 16 11 16 9 8 9 8 11zM23 15V13H20V11H18v2H16v2h2v6a2 2 0 002 2h3V21H20V15z"
  })), children);
});
var LetterUu32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterUu32(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 23H19a2 2 0 01-2-2V13h2v8h4V13h2v8A2 2 0 0123 23zM13 23H9a2 2 0 01-2-2V9H9V21h4V9h2V21A2 2 0 0113 23z"
  })), children);
});
var LetterUu24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterUu24(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 23H19a2 2 0 01-2-2V13h2v8h4V13h2v8A2 2 0 0123 23zM13 23H9a2 2 0 01-2-2V9H9V21h4V9h2V21A2 2 0 0113 23z"
  })), children);
});
var LetterUu20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterUu20(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 23H19a2 2 0 01-2-2V13h2v8h4V13h2v8A2 2 0 0123 23zM13 23H9a2 2 0 01-2-2V9H9V21h4V9h2V21A2 2 0 0113 23z"
  })), children);
});
var LetterUu16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterUu16(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 23H19a2 2 0 01-2-2V13h2v8h4V13h2v8A2 2 0 0123 23zM13 23H9a2 2 0 01-2-2V9H9V21h4V9h2V21A2 2 0 0113 23z"
  })), children);
});
var LetterVv32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterVv32(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 13L23.25 13 21 22.03 18.79 13 17 13 19.5 23 22.5 23 25 13zM13 9L11 22 9 9 7 9 9.52 23 12.48 23 15 9 13 9z"
  })), children);
});
var LetterVv24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterVv24(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 13L23.25 13 21 22.03 18.79 13 17 13 19.5 23 22.5 23 25 13zM13 9L11 22 9 9 7 9 9.52 23 12.48 23 15 9 13 9z"
  })), children);
});
var LetterVv20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterVv20(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 13L23.25 13 21 22.03 18.79 13 17 13 19.5 23 22.5 23 25 13zM13 9L11 22 9 9 7 9 9.52 23 12.48 23 15 9 13 9z"
  })), children);
});
var LetterVv16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterVv16(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 13L23.25 13 21 22.03 18.79 13 17 13 19.5 23 22.5 23 25 13zM13 9L11 22 9 9 7 9 9.52 23 12.48 23 15 9 13 9z"
  })), children);
});
var LetterWw32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterWw32(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.3 13L23.39 21.61 22 13 20 13 18.61 21.61 17.7 13 16 13 17.36 23 19.64 23 21 14.63 22.36 23 24.64 23 26 13 24.3 13zM12.21 9L11.87 17 11.61 21.54 11.2 18 10.52 12.54 8.5 12.54 7.82 18 7.41 21.54 7.16 17 6.81 9 5.01 9 6.01 23 8.28 23 9.04 18.07 9.5 14 9.51 13.97 9.52 14 9.98 18.07 10.74 23 13.01 23 14.01 9 12.21 9z"
  })), children);
});
var LetterWw24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterWw24(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.3 13L23.39 21.61 22 13 20 13 18.61 21.61 17.7 13 16 13 17.36 23 19.64 23 21 14.63 22.36 23 24.64 23 26 13 24.3 13zM12.21 9L11.87 17 11.61 21.54 11.2 18 10.52 12.54 8.5 12.54 7.82 18 7.41 21.54 7.16 17 6.81 9 5.01 9 6.01 23 8.28 23 9.04 18.07 9.5 14 9.51 13.97 9.52 14 9.98 18.07 10.74 23 13.01 23 14.01 9 12.21 9z"
  })), children);
});
var LetterWw20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterWw20(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.3 13L23.39 21.61 22 13 20 13 18.61 21.61 17.7 13 16 13 17.36 23 19.64 23 21 14.63 22.36 23 24.64 23 26 13 24.3 13zM12.21 9L11.87 17 11.61 21.54 11.2 18 10.52 12.54 8.5 12.54 7.82 18 7.41 21.54 7.16 17 6.81 9 5.01 9 6.01 23 8.28 23 9.04 18.07 9.5 14 9.51 13.97 9.52 14 9.98 18.07 10.74 23 13.01 23 14.01 9 12.21 9z"
  })), children);
});
var LetterWw16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterWw16(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.3 13L23.39 21.61 22 13 20 13 18.61 21.61 17.7 13 16 13 17.36 23 19.64 23 21 14.63 22.36 23 24.64 23 26 13 24.3 13zM12.21 9L11.87 17 11.61 21.54 11.2 18 10.52 12.54 8.5 12.54 7.82 18 7.41 21.54 7.16 17 6.81 9 5.01 9 6.01 23 8.28 23 9.04 18.07 9.5 14 9.51 13.97 9.52 14 9.98 18.07 10.74 23 13.01 23 14.01 9 12.21 9z"
  })), children);
});
var LetterXx32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterXx32(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 9L13 9 11 15 9 9 7 9 9.75 16 7 23 9 23 11 17 13 23 15 23 12.24 16 15 9zM25 13L23 13 21 16.9 19 13 17 13 19.91 18 17 23 19 23 21 19.2 23 23 25 23 22.1 18 25 13z"
  })), children);
});
var LetterXx24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterXx24(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 9L13 9 11 15 9 9 7 9 9.75 16 7 23 9 23 11 17 13 23 15 23 12.24 16 15 9zM25 13L23 13 21 16.9 19 13 17 13 19.91 18 17 23 19 23 21 19.2 23 23 25 23 22.1 18 25 13z"
  })), children);
});
var LetterXx20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterXx20(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 9L13 9 11 15 9 9 7 9 9.75 16 7 23 9 23 11 17 13 23 15 23 12.24 16 15 9zM25 13L23 13 21 16.9 19 13 17 13 19.91 18 17 23 19 23 21 19.2 23 23 25 23 22.1 18 25 13z"
  })), children);
});
var LetterXx16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterXx16(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 9L13 9 11 15 9 9 7 9 9.75 16 7 23 9 23 11 17 13 23 15 23 12.24 16 15 9zM25 13L23 13 21 16.9 19 13 17 13 19.91 18 17 23 19 23 21 19.2 23 23 25 23 22.1 18 25 13z"
  })), children);
});
var LetterYy32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterYy32(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 9L13 9 11 16 9 9 7 9 10 18 10 23 12 23 12 18 12 18 15 9zM23 13l-2 7.52L19.08 13H17l3.15 9.87L19.53 25H17v2h2.26a2 2 0 001.91-1.42L25 13z"
  })), children);
});
var LetterYy24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterYy24(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 9L13 9 11 16 9 9 7 9 10 18 10 23 12 23 12 18 12 18 15 9zM23 13l-2 7.52L19.08 13H17l3.15 9.87L19.53 25H17v2h2.26a2 2 0 001.91-1.42L25 13z"
  })), children);
});
var LetterYy20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterYy20(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 9L13 9 11 16 9 9 7 9 10 18 10 23 12 23 12 18 12 18 15 9zM23 13l-2 7.52L19.08 13H17l3.15 9.87L19.53 25H17v2h2.26a2 2 0 001.91-1.42L25 13z"
  })), children);
});
var LetterYy16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterYy16(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 9L13 9 11 16 9 9 7 9 10 18 10 23 12 23 12 18 12 18 15 9zM23 13l-2 7.52L19.08 13H17l3.15 9.87L19.53 25H17v2h2.26a2 2 0 001.91-1.42L25 13z"
  })), children);
});
var LetterZz32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterZz32(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15L25 13 17 13 17 15 22.5 15 17 21 17 23 25 23 25 21 19.51 21 25 15zM15 9L7 9 7 11 13 11 7 21 7 23 15 23 15 21 9 21 15 11 15 9z"
  })), children);
});
var LetterZz24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterZz24(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15L25 13 17 13 17 15 22.5 15 17 21 17 23 25 23 25 21 19.51 21 25 15zM15 9L7 9 7 11 13 11 7 21 7 23 15 23 15 21 9 21 15 11 15 9z"
  })), children);
});
var LetterZz20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterZz20(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15L25 13 17 13 17 15 22.5 15 17 21 17 23 25 23 25 21 19.51 21 25 15zM15 9L7 9 7 11 13 11 7 21 7 23 15 23 15 21 9 21 15 11 15 9z"
  })), children);
});
var LetterZz16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LetterZz16(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15L25 13 17 13 17 15 22.5 15 17 21 17 23 25 23 25 21 19.51 21 25 15zM15 9L7 9 7 11 13 11 7 21 7 23 15 23 15 21 9 21 15 11 15 9z"
  })), children);
});
var License32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function License32(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6H22V8H10zM10 10H22V12H10zM10 24H16V26H10zM10 14H16V16H10z"
  })), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30H8a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,8,2H24a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,24,30ZM8,4V28H24V4Z"
  })), children);
});
var License24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function License24(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6H22V8H10zM10 10H22V12H10zM10 24H16V26H10zM10 14H16V16H10z"
  })), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30H8a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,8,2H24a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,24,30ZM8,4V28H24V4Z"
  })), children);
});
var License20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function License20(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6H22V8H10zM10 10H22V12H10zM10 24H16V26H10zM10 14H16V16H10z"
  })), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30H8a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,8,2H24a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,24,30ZM8,4V28H24V4Z"
  })), children);
});
var License16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function License16(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6H22V8H10zM10 10H22V12H10zM10 24H16V26H10zM10 14H16V16H10z"
  })), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30H8a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,8,2H24a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,24,30ZM8,4V28H24V4Z"
  })), children);
});
var LicenseDraft32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseDraft32(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 6H20V8H8zM8 10H20V12H8zM8 14H14V16H8zM8 24H12V26H8z"
  })), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM12 30H6a2.0021 2.0021 0 01-2-2V4A2.0021 2.0021 0 016 2H22a2.0021 2.0021 0 012 2V14H22V4H6V28h6z"
  })), children);
});
var LicenseDraft24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseDraft24(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 6H20V8H8zM8 10H20V12H8zM8 14H14V16H8zM8 24H12V26H8z"
  })), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM12 30H6a2.0021 2.0021 0 01-2-2V4A2.0021 2.0021 0 016 2H22a2.0021 2.0021 0 012 2V14H22V4H6V28h6z"
  })), children);
});
var LicenseDraft20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseDraft20(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 6H20V8H8zM8 10H20V12H8zM8 14H14V16H8zM8 24H12V26H8z"
  })), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM12 30H6a2.0021 2.0021 0 01-2-2V4A2.0021 2.0021 0 016 2H22a2.0021 2.0021 0 012 2V14H22V4H6V28h6z"
  })), children);
});
var LicenseDraft16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseDraft16(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 6H20V8H8zM8 10H20V12H8zM8 14H14V16H8zM8 24H12V26H8z"
  })), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM12 30H6a2.0021 2.0021 0 01-2-2V4A2.0021 2.0021 0 016 2H22a2.0021 2.0021 0 012 2V14H22V4H6V28h6z"
  })), children);
});
var LicenseGlobal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseGlobal32(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 14a8 8 0 108 8A8.0092 8.0092 0 0022 14zm5.91 7H25.9563a12.03 12.03 0 00-1.2183-4.3325A6.01 6.01 0 0127.91 21zm-7.8545 0A10.0135 10.0135 0 0122 16.0146 10.0121 10.0121 0 0123.9448 21zm3.89 2A10.01 10.01 0 0122 27.9854 10.0121 10.0121 0 0120.0552 23zm-4.6831-6.332A12.0265 12.0265 0 0018.0435 21H16.09A6.01 6.01 0 0119.2617 16.668zM16.09 23h1.9532a12.0265 12.0265 0 001.2182 4.332A6.01 6.01 0 0116.09 23zm8.6482 4.332A12.0242 12.0242 0 0025.9565 23H27.91A6.0088 6.0088 0 0124.7385 27.332zM6 14H12V16H6zM6 6H18V8H6zM6 10H18V12H6zM6 24H12V26H6z"
  })), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H20a2.0021,2.0021,0,0,1,2,2v8H20V4H4V28h8Z"
  })), children);
});
var LicenseGlobal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseGlobal24(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 14a8 8 0 108 8A8.0092 8.0092 0 0022 14zm5.91 7H25.9563a12.03 12.03 0 00-1.2183-4.3325A6.01 6.01 0 0127.91 21zm-7.8545 0A10.0135 10.0135 0 0122 16.0146 10.0121 10.0121 0 0123.9448 21zm3.89 2A10.01 10.01 0 0122 27.9854 10.0121 10.0121 0 0120.0552 23zm-4.6831-6.332A12.0265 12.0265 0 0018.0435 21H16.09A6.01 6.01 0 0119.2617 16.668zM16.09 23h1.9532a12.0265 12.0265 0 001.2182 4.332A6.01 6.01 0 0116.09 23zm8.6482 4.332A12.0242 12.0242 0 0025.9565 23H27.91A6.0088 6.0088 0 0124.7385 27.332zM6 14H12V16H6zM6 6H18V8H6zM6 10H18V12H6zM6 24H12V26H6z"
  })), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H20a2.0021,2.0021,0,0,1,2,2v8H20V4H4V28h8Z"
  })), children);
});
var LicenseGlobal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseGlobal20(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 14a8 8 0 108 8A8.0092 8.0092 0 0022 14zm5.91 7H25.9563a12.03 12.03 0 00-1.2183-4.3325A6.01 6.01 0 0127.91 21zm-7.8545 0A10.0135 10.0135 0 0122 16.0146 10.0121 10.0121 0 0123.9448 21zm3.89 2A10.01 10.01 0 0122 27.9854 10.0121 10.0121 0 0120.0552 23zm-4.6831-6.332A12.0265 12.0265 0 0018.0435 21H16.09A6.01 6.01 0 0119.2617 16.668zM16.09 23h1.9532a12.0265 12.0265 0 001.2182 4.332A6.01 6.01 0 0116.09 23zm8.6482 4.332A12.0242 12.0242 0 0025.9565 23H27.91A6.0088 6.0088 0 0124.7385 27.332zM6 14H12V16H6zM6 6H18V8H6zM6 10H18V12H6zM6 24H12V26H6z"
  })), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H20a2.0021,2.0021,0,0,1,2,2v8H20V4H4V28h8Z"
  })), children);
});
var LicenseGlobal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseGlobal16(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 14a8 8 0 108 8A8.0092 8.0092 0 0022 14zm5.91 7H25.9563a12.03 12.03 0 00-1.2183-4.3325A6.01 6.01 0 0127.91 21zm-7.8545 0A10.0135 10.0135 0 0122 16.0146 10.0121 10.0121 0 0123.9448 21zm3.89 2A10.01 10.01 0 0122 27.9854 10.0121 10.0121 0 0120.0552 23zm-4.6831-6.332A12.0265 12.0265 0 0018.0435 21H16.09A6.01 6.01 0 0119.2617 16.668zM16.09 23h1.9532a12.0265 12.0265 0 001.2182 4.332A6.01 6.01 0 0116.09 23zm8.6482 4.332A12.0242 12.0242 0 0025.9565 23H27.91A6.0088 6.0088 0 0124.7385 27.332zM6 14H12V16H6zM6 6H18V8H6zM6 10H18V12H6zM6 24H12V26H6z"
  })), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H20a2.0021,2.0021,0,0,1,2,2v8H20V4H4V28h8Z"
  })), children);
});
var LicenseMaintenance32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseMaintenance32(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 14H14V16H8zM8 6H20V8H8zM8 10H20V12H8zM8 24H14V26H8zM30 24V22H27.8989a4.9678 4.9678 0 00-.7319-1.7529l1.49-1.49-1.414-1.414-1.49 1.49A4.9678 4.9678 0 0024 18.1011V16H22v2.1011a4.9678 4.9678 0 00-1.7529.7319l-1.49-1.49-1.414 1.414 1.49 1.49A4.9678 4.9678 0 0018.1011 22H16v2h2.1011a4.9678 4.9678 0 00.7319 1.7529l-1.49 1.49 1.414 1.414 1.49-1.49A4.9678 4.9678 0 0022 27.8989V30h2V27.8989a4.9678 4.9678 0 001.7529-.7319l1.49 1.49 1.414-1.414-1.49-1.49A4.9678 4.9678 0 0027.8989 24zm-7 2a3 3 0 113-3A3.0033 3.0033 0 0123 26z"
  })), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h8Z"
  })), children);
});
var LicenseMaintenance24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseMaintenance24(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 14H14V16H8zM8 6H20V8H8zM8 10H20V12H8zM8 24H14V26H8zM30 24V22H27.8989a4.9678 4.9678 0 00-.7319-1.7529l1.49-1.49-1.414-1.414-1.49 1.49A4.9678 4.9678 0 0024 18.1011V16H22v2.1011a4.9678 4.9678 0 00-1.7529.7319l-1.49-1.49-1.414 1.414 1.49 1.49A4.9678 4.9678 0 0018.1011 22H16v2h2.1011a4.9678 4.9678 0 00.7319 1.7529l-1.49 1.49 1.414 1.414 1.49-1.49A4.9678 4.9678 0 0022 27.8989V30h2V27.8989a4.9678 4.9678 0 001.7529-.7319l1.49 1.49 1.414-1.414-1.49-1.49A4.9678 4.9678 0 0027.8989 24zm-7 2a3 3 0 113-3A3.0033 3.0033 0 0123 26z"
  })), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h8Z"
  })), children);
});
var LicenseMaintenance20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseMaintenance20(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 14H14V16H8zM8 6H20V8H8zM8 10H20V12H8zM8 24H14V26H8zM30 24V22H27.8989a4.9678 4.9678 0 00-.7319-1.7529l1.49-1.49-1.414-1.414-1.49 1.49A4.9678 4.9678 0 0024 18.1011V16H22v2.1011a4.9678 4.9678 0 00-1.7529.7319l-1.49-1.49-1.414 1.414 1.49 1.49A4.9678 4.9678 0 0018.1011 22H16v2h2.1011a4.9678 4.9678 0 00.7319 1.7529l-1.49 1.49 1.414 1.414 1.49-1.49A4.9678 4.9678 0 0022 27.8989V30h2V27.8989a4.9678 4.9678 0 001.7529-.7319l1.49 1.49 1.414-1.414-1.49-1.49A4.9678 4.9678 0 0027.8989 24zm-7 2a3 3 0 113-3A3.0033 3.0033 0 0123 26z"
  })), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h8Z"
  })), children);
});
var LicenseMaintenance16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseMaintenance16(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 14H14V16H8zM8 6H20V8H8zM8 10H20V12H8zM8 24H14V26H8zM30 24V22H27.8989a4.9678 4.9678 0 00-.7319-1.7529l1.49-1.49-1.414-1.414-1.49 1.49A4.9678 4.9678 0 0024 18.1011V16H22v2.1011a4.9678 4.9678 0 00-1.7529.7319l-1.49-1.49-1.414 1.414 1.49 1.49A4.9678 4.9678 0 0018.1011 22H16v2h2.1011a4.9678 4.9678 0 00.7319 1.7529l-1.49 1.49 1.414 1.414 1.49-1.49A4.9678 4.9678 0 0022 27.8989V30h2V27.8989a4.9678 4.9678 0 001.7529-.7319l1.49 1.49 1.414-1.414-1.49-1.49A4.9678 4.9678 0 0027.8989 24zm-7 2a3 3 0 113-3A3.0033 3.0033 0 0123 26z"
  })), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h8Z"
  })), children);
});
var LicenseMaintenanceDraft32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseMaintenanceDraft32(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM20 13V11H17.8579a3.94 3.94 0 00-.4248-1.019L18.95 8.4644 17.5356 7.05 16.019 8.5669A3.9443 3.9443 0 0015 8.1421V6H13V8.1421a3.9443 3.9443 0 00-1.019.4248L10.4644 7.05 9.05 8.4644 10.5669 9.981A3.94 3.94 0 0010.1421 11H8v2h2.1421a3.94 3.94 0 00.4248 1.019L9.05 15.5356 10.4644 16.95l1.5166-1.5166A3.9443 3.9443 0 0013 15.8579V18h2V15.8579a3.9443 3.9443 0 001.019-.4248L17.5356 16.95 18.95 15.5356 17.4331 14.019A3.94 3.94 0 0017.8579 13zm-6 1a2 2 0 112-2A2.0025 2.0025 0 0114 14z"
  })), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h6Z"
  })), children);
});
var LicenseMaintenanceDraft24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseMaintenanceDraft24(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM20 13V11H17.8579a3.94 3.94 0 00-.4248-1.019L18.95 8.4644 17.5356 7.05 16.019 8.5669A3.9443 3.9443 0 0015 8.1421V6H13V8.1421a3.9443 3.9443 0 00-1.019.4248L10.4644 7.05 9.05 8.4644 10.5669 9.981A3.94 3.94 0 0010.1421 11H8v2h2.1421a3.94 3.94 0 00.4248 1.019L9.05 15.5356 10.4644 16.95l1.5166-1.5166A3.9443 3.9443 0 0013 15.8579V18h2V15.8579a3.9443 3.9443 0 001.019-.4248L17.5356 16.95 18.95 15.5356 17.4331 14.019A3.94 3.94 0 0017.8579 13zm-6 1a2 2 0 112-2A2.0025 2.0025 0 0114 14z"
  })), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h6Z"
  })), children);
});
var LicenseMaintenanceDraft20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseMaintenanceDraft20(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM20 13V11H17.8579a3.94 3.94 0 00-.4248-1.019L18.95 8.4644 17.5356 7.05 16.019 8.5669A3.9443 3.9443 0 0015 8.1421V6H13V8.1421a3.9443 3.9443 0 00-1.019.4248L10.4644 7.05 9.05 8.4644 10.5669 9.981A3.94 3.94 0 0010.1421 11H8v2h2.1421a3.94 3.94 0 00.4248 1.019L9.05 15.5356 10.4644 16.95l1.5166-1.5166A3.9443 3.9443 0 0013 15.8579V18h2V15.8579a3.9443 3.9443 0 001.019-.4248L17.5356 16.95 18.95 15.5356 17.4331 14.019A3.94 3.94 0 0017.8579 13zm-6 1a2 2 0 112-2A2.0025 2.0025 0 0114 14z"
  })), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h6Z"
  })), children);
});
var LicenseMaintenanceDraft16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseMaintenanceDraft16(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM20 13V11H17.8579a3.94 3.94 0 00-.4248-1.019L18.95 8.4644 17.5356 7.05 16.019 8.5669A3.9443 3.9443 0 0015 8.1421V6H13V8.1421a3.9443 3.9443 0 00-1.019.4248L10.4644 7.05 9.05 8.4644 10.5669 9.981A3.94 3.94 0 0010.1421 11H8v2h2.1421a3.94 3.94 0 00.4248 1.019L9.05 15.5356 10.4644 16.95l1.5166-1.5166A3.9443 3.9443 0 0013 15.8579V18h2V15.8579a3.9443 3.9443 0 001.019-.4248L17.5356 16.95 18.95 15.5356 17.4331 14.019A3.94 3.94 0 0017.8579 13zm-6 1a2 2 0 112-2A2.0025 2.0025 0 0114 14z"
  })), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h6Z"
  })), children);
});
var LicenseThirdParty32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseThirdParty32(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 14H14V16H8zM8 6H20V8H8zM8 10H20V12H8zM8 24H14V26H8zM27 25H21a3 3 0 00-3 3v2h2V28a1 1 0 011-1h6a1 1 0 011 1v2h2V28A3 3 0 0027 25zM24 24a4 4 0 10-4-4A4 4 0 0024 24zm0-6a2 2 0 11-2 2A2 2 0 0124 18z"
  })), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h8Z"
  })), children);
});
var LicenseThirdParty24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseThirdParty24(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 14H14V16H8zM8 6H20V8H8zM8 10H20V12H8zM8 24H14V26H8zM27 25H21a3 3 0 00-3 3v2h2V28a1 1 0 011-1h6a1 1 0 011 1v2h2V28A3 3 0 0027 25zM24 24a4 4 0 10-4-4A4 4 0 0024 24zm0-6a2 2 0 11-2 2A2 2 0 0124 18z"
  })), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h8Z"
  })), children);
});
var LicenseThirdParty20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseThirdParty20(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 14H14V16H8zM8 6H20V8H8zM8 10H20V12H8zM8 24H14V26H8zM27 25H21a3 3 0 00-3 3v2h2V28a1 1 0 011-1h6a1 1 0 011 1v2h2V28A3 3 0 0027 25zM24 24a4 4 0 10-4-4A4 4 0 0024 24zm0-6a2 2 0 11-2 2A2 2 0 0124 18z"
  })), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h8Z"
  })), children);
});
var LicenseThirdParty16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseThirdParty16(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 14H14V16H8zM8 6H20V8H8zM8 10H20V12H8zM8 24H14V26H8zM27 25H21a3 3 0 00-3 3v2h2V28a1 1 0 011-1h6a1 1 0 011 1v2h2V28A3 3 0 0027 25zM24 24a4 4 0 10-4-4A4 4 0 0024 24zm0-6a2 2 0 11-2 2A2 2 0 0124 18z"
  })), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h8Z"
  })), children);
});
var LicenseThirdPartyDraft32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseThirdPartyDraft32(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM17 15H11a3 3 0 00-3 3v1h2V18a1 1 0 011-1h6a1 1 0 011 1v1h2V18A3 3 0 0017 15zM14 14a4 4 0 10-4-4A4 4 0 0014 14zm0-6a2 2 0 11-2 2A2 2 0 0114 8z"
  })), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h6Z"
  })), children);
});
var LicenseThirdPartyDraft24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseThirdPartyDraft24(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM17 15H11a3 3 0 00-3 3v1h2V18a1 1 0 011-1h6a1 1 0 011 1v1h2V18A3 3 0 0017 15zM14 14a4 4 0 10-4-4A4 4 0 0014 14zm0-6a2 2 0 11-2 2A2 2 0 0114 8z"
  })), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h6Z"
  })), children);
});
var LicenseThirdPartyDraft20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseThirdPartyDraft20(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM17 15H11a3 3 0 00-3 3v1h2V18a1 1 0 011-1h6a1 1 0 011 1v1h2V18A3 3 0 0017 15zM14 14a4 4 0 10-4-4A4 4 0 0014 14zm0-6a2 2 0 11-2 2A2 2 0 0114 8z"
  })), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h6Z"
  })), children);
});
var LicenseThirdPartyDraft16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LicenseThirdPartyDraft16(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM17 15H11a3 3 0 00-3 3v1h2V18a1 1 0 011-1h6a1 1 0 011 1v1h2V18A3 3 0 0017 15zM14 14a4 4 0 10-4-4A4 4 0 0014 14zm0-6a2 2 0 11-2 2A2 2 0 0114 8z"
  })), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h6Z"
  })), children);
});
var Lifesaver32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Lifesaver32(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.2261,22.812a13.9664,13.9664,0,0,0,0-13.624L28.4141,9a2.0021,2.0021,0,0,0,0-2.8281l-2.5857-2.586a2.0028,2.0028,0,0,0-2.8284,0l-.1877.1875a13.9687,13.9687,0,0,0-13.6243,0L9,3.5859a2.0024,2.0024,0,0,0-2.8284,0L3.5859,6.1719A2.0021,2.0021,0,0,0,3.5859,9l.1878.1875a13.97,13.97,0,0,0,0,13.625L3.5859,23a2.0021,2.0021,0,0,0,0,2.8281l2.5857,2.586a2.0021,2.0021,0,0,0,2.8284,0l.188-.188a13.9687,13.9687,0,0,0,13.6243.0005L23,28.4141a2.0021,2.0021,0,0,0,2.8284,0l2.5857-2.586a2.0021,2.0021,0,0,0,0-2.8281ZM28,16a11.973,11.973,0,0,1-1.2546,5.3315l-3.8948-3.895a6.9808,6.9808,0,0,0,0-2.873l3.8948-3.895A11.973,11.973,0,0,1,28,16ZM27,7.5859l-4.9346,4.9346A7.0434,7.0434,0,0,0,19.48,9.9346L24.4143,5ZM16,21a5,5,0,1,1,5-5A5.0057,5.0057,0,0,1,16,21ZM21.3154,5.2705,17.4365,9.1494a6.9808,6.9808,0,0,0-2.873,0L10.6846,5.2705A12.2484,12.2484,0,0,1,21.3154,5.2705ZM7.5859,5l4.9346,4.9346a7.0449,7.0449,0,0,0-2.5859,2.5859L5,7.5859ZM4,16a11.9716,11.9716,0,0,1,1.2546-5.3311l3.8948,3.8946a6.9808,6.9808,0,0,0,0,2.873L5.2546,21.3311A11.9716,11.9716,0,0,1,4,16ZM7.5857,27,5,24.4141,9.9346,19.48a7.0434,7.0434,0,0,0,2.5859,2.5859Zm3.0989-.27,3.8789-3.8789a6.9808,6.9808,0,0,0,2.873,0L21.3154,26.73A12.2484,12.2484,0,0,1,10.6846,26.73Zm13.73.27L19.48,22.0654A7.0449,7.0449,0,0,0,22.0654,19.48L27,24.4141Z"
  })), children);
});
var Lifesaver24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Lifesaver24(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.2261,22.812a13.9664,13.9664,0,0,0,0-13.624L28.4141,9a2.0021,2.0021,0,0,0,0-2.8281l-2.5857-2.586a2.0028,2.0028,0,0,0-2.8284,0l-.1877.1875a13.9687,13.9687,0,0,0-13.6243,0L9,3.5859a2.0024,2.0024,0,0,0-2.8284,0L3.5859,6.1719A2.0021,2.0021,0,0,0,3.5859,9l.1878.1875a13.97,13.97,0,0,0,0,13.625L3.5859,23a2.0021,2.0021,0,0,0,0,2.8281l2.5857,2.586a2.0021,2.0021,0,0,0,2.8284,0l.188-.188a13.9687,13.9687,0,0,0,13.6243.0005L23,28.4141a2.0021,2.0021,0,0,0,2.8284,0l2.5857-2.586a2.0021,2.0021,0,0,0,0-2.8281ZM28,16a11.973,11.973,0,0,1-1.2546,5.3315l-3.8948-3.895a6.9808,6.9808,0,0,0,0-2.873l3.8948-3.895A11.973,11.973,0,0,1,28,16ZM27,7.5859l-4.9346,4.9346A7.0434,7.0434,0,0,0,19.48,9.9346L24.4143,5ZM16,21a5,5,0,1,1,5-5A5.0057,5.0057,0,0,1,16,21ZM21.3154,5.2705,17.4365,9.1494a6.9808,6.9808,0,0,0-2.873,0L10.6846,5.2705A12.2484,12.2484,0,0,1,21.3154,5.2705ZM7.5859,5l4.9346,4.9346a7.0449,7.0449,0,0,0-2.5859,2.5859L5,7.5859ZM4,16a11.9716,11.9716,0,0,1,1.2546-5.3311l3.8948,3.8946a6.9808,6.9808,0,0,0,0,2.873L5.2546,21.3311A11.9716,11.9716,0,0,1,4,16ZM7.5857,27,5,24.4141,9.9346,19.48a7.0434,7.0434,0,0,0,2.5859,2.5859Zm3.0989-.27,3.8789-3.8789a6.9808,6.9808,0,0,0,2.873,0L21.3154,26.73A12.2484,12.2484,0,0,1,10.6846,26.73Zm13.73.27L19.48,22.0654A7.0449,7.0449,0,0,0,22.0654,19.48L27,24.4141Z"
  })), children);
});
var Lifesaver20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Lifesaver20(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.2261,22.812a13.9664,13.9664,0,0,0,0-13.624L28.4141,9a2.0021,2.0021,0,0,0,0-2.8281l-2.5857-2.586a2.0028,2.0028,0,0,0-2.8284,0l-.1877.1875a13.9687,13.9687,0,0,0-13.6243,0L9,3.5859a2.0024,2.0024,0,0,0-2.8284,0L3.5859,6.1719A2.0021,2.0021,0,0,0,3.5859,9l.1878.1875a13.97,13.97,0,0,0,0,13.625L3.5859,23a2.0021,2.0021,0,0,0,0,2.8281l2.5857,2.586a2.0021,2.0021,0,0,0,2.8284,0l.188-.188a13.9687,13.9687,0,0,0,13.6243.0005L23,28.4141a2.0021,2.0021,0,0,0,2.8284,0l2.5857-2.586a2.0021,2.0021,0,0,0,0-2.8281ZM28,16a11.973,11.973,0,0,1-1.2546,5.3315l-3.8948-3.895a6.9808,6.9808,0,0,0,0-2.873l3.8948-3.895A11.973,11.973,0,0,1,28,16ZM27,7.5859l-4.9346,4.9346A7.0434,7.0434,0,0,0,19.48,9.9346L24.4143,5ZM16,21a5,5,0,1,1,5-5A5.0057,5.0057,0,0,1,16,21ZM21.3154,5.2705,17.4365,9.1494a6.9808,6.9808,0,0,0-2.873,0L10.6846,5.2705A12.2484,12.2484,0,0,1,21.3154,5.2705ZM7.5859,5l4.9346,4.9346a7.0449,7.0449,0,0,0-2.5859,2.5859L5,7.5859ZM4,16a11.9716,11.9716,0,0,1,1.2546-5.3311l3.8948,3.8946a6.9808,6.9808,0,0,0,0,2.873L5.2546,21.3311A11.9716,11.9716,0,0,1,4,16ZM7.5857,27,5,24.4141,9.9346,19.48a7.0434,7.0434,0,0,0,2.5859,2.5859Zm3.0989-.27,3.8789-3.8789a6.9808,6.9808,0,0,0,2.873,0L21.3154,26.73A12.2484,12.2484,0,0,1,10.6846,26.73Zm13.73.27L19.48,22.0654A7.0449,7.0449,0,0,0,22.0654,19.48L27,24.4141Z"
  })), children);
});
var Lifesaver16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Lifesaver16(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.2261,22.812a13.9664,13.9664,0,0,0,0-13.624L28.4141,9a2.0021,2.0021,0,0,0,0-2.8281l-2.5857-2.586a2.0028,2.0028,0,0,0-2.8284,0l-.1877.1875a13.9687,13.9687,0,0,0-13.6243,0L9,3.5859a2.0024,2.0024,0,0,0-2.8284,0L3.5859,6.1719A2.0021,2.0021,0,0,0,3.5859,9l.1878.1875a13.97,13.97,0,0,0,0,13.625L3.5859,23a2.0021,2.0021,0,0,0,0,2.8281l2.5857,2.586a2.0021,2.0021,0,0,0,2.8284,0l.188-.188a13.9687,13.9687,0,0,0,13.6243.0005L23,28.4141a2.0021,2.0021,0,0,0,2.8284,0l2.5857-2.586a2.0021,2.0021,0,0,0,0-2.8281ZM28,16a11.973,11.973,0,0,1-1.2546,5.3315l-3.8948-3.895a6.9808,6.9808,0,0,0,0-2.873l3.8948-3.895A11.973,11.973,0,0,1,28,16ZM27,7.5859l-4.9346,4.9346A7.0434,7.0434,0,0,0,19.48,9.9346L24.4143,5ZM16,21a5,5,0,1,1,5-5A5.0057,5.0057,0,0,1,16,21ZM21.3154,5.2705,17.4365,9.1494a6.9808,6.9808,0,0,0-2.873,0L10.6846,5.2705A12.2484,12.2484,0,0,1,21.3154,5.2705ZM7.5859,5l4.9346,4.9346a7.0449,7.0449,0,0,0-2.5859,2.5859L5,7.5859ZM4,16a11.9716,11.9716,0,0,1,1.2546-5.3311l3.8948,3.8946a6.9808,6.9808,0,0,0,0,2.873L5.2546,21.3311A11.9716,11.9716,0,0,1,4,16ZM7.5857,27,5,24.4141,9.9346,19.48a7.0434,7.0434,0,0,0,2.5859,2.5859Zm3.0989-.27,3.8789-3.8789a6.9808,6.9808,0,0,0,2.873,0L21.3154,26.73A12.2484,12.2484,0,0,1,10.6846,26.73Zm13.73.27L19.48,22.0654A7.0449,7.0449,0,0,0,22.0654,19.48L27,24.4141Z"
  })), children);
});
var Light32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Light32(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V7H15z"
  })), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.147 7.853)"
  })), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15H30V17H25z"
  })), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.147 21.668H25.147V26.625999999999998H23.147z",
    transform: "rotate(-45 24.147 24.146)"
  })), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25H17V30H15z"
  })), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.375 23.147H10.333V25.147H5.375z",
    transform: "rotate(-45 7.853 24.146)"
  })), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15H7V17H2z"
  })), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.854 7.853)"
  })), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4.0045,4.0045,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z"
  })), children);
});
var Light24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Light24(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V7H15z"
  })), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.147 7.853)"
  })), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15H30V17H25z"
  })), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.147 21.668H25.147V26.625999999999998H23.147z",
    transform: "rotate(-45 24.147 24.146)"
  })), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25H17V30H15z"
  })), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.375 23.147H10.333V25.147H5.375z",
    transform: "rotate(-45 7.853 24.146)"
  })), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15H7V17H2z"
  })), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.854 7.853)"
  })), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4.0045,4.0045,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z"
  })), children);
});
var Light20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Light20(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V7H15z"
  })), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.147 7.853)"
  })), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15H30V17H25z"
  })), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.147 21.668H25.147V26.625999999999998H23.147z",
    transform: "rotate(-45 24.147 24.146)"
  })), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25H17V30H15z"
  })), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.375 23.147H10.333V25.147H5.375z",
    transform: "rotate(-45 7.853 24.146)"
  })), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15H7V17H2z"
  })), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.854 7.853)"
  })), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4.0045,4.0045,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z"
  })), children);
});
var Light16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Light16(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.5 1H8.5V3.5H7.5z"
  })), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.8 3.4H13.3V4.4H10.8z",
    transform: "rotate(-45.001 12.041 3.923)"
  })), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.5 7.5H15V8.5H12.5z"
  })), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.6 10.8H12.6V13.3H11.6z",
    transform: "rotate(-45.001 12.075 12.041)"
  })), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.5 12.5H8.5V15H7.5z"
  })), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.7 11.6H5.2V12.6H2.7z",
    transform: "rotate(-45.001 3.96 12.079)"
  })), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M1 7.5H3.5V8.5H1z"
  })), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.4 2.7H4.4V5.2H3.4z",
    transform: "rotate(-45.001 3.925 3.961)"
  })), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,6c1.1,0,2,0.9,2,2s-0.9,2-2,2S6,9.1,6,8S6.9,6,8,6 M8,5C6.3,5,5,6.3,5,8s1.3,3,3,3s3-1.3,3-3S9.7,5,8,5z"
  })), children);
});
var LightFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LightFilled32(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V7H15z"
  })), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.147 7.853)"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15H30V17H25z"
  })), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.147 21.668H25.147V26.625999999999998H23.147z",
    transform: "rotate(-45 24.147 24.146)"
  })), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25H17V30H15z"
  })), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.375 23.147H10.333V25.147H5.375z",
    transform: "rotate(-45 7.853 24.146)"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15H7V17H2z"
  })), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.854 7.853)"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z"
  })), children);
});
var LightFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LightFilled24(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V7H15z"
  })), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.147 7.853)"
  })), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15H30V17H25z"
  })), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.147 21.668H25.147V26.625999999999998H23.147z",
    transform: "rotate(-45 24.147 24.146)"
  })), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25H17V30H15z"
  })), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.375 23.147H10.333V25.147H5.375z",
    transform: "rotate(-45 7.853 24.146)"
  })), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15H7V17H2z"
  })), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.854 7.853)"
  })), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z"
  })), children);
});
var LightFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LightFilled20(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V7H15z"
  })), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.147 7.853)"
  })), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15H30V17H25z"
  })), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.147 21.668H25.147V26.625999999999998H23.147z",
    transform: "rotate(-45 24.147 24.146)"
  })), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25H17V30H15z"
  })), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.375 23.147H10.333V25.147H5.375z",
    transform: "rotate(-45 7.853 24.146)"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15H7V17H2z"
  })), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.854 7.853)"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z"
  })), children);
});
var LightFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LightFilled16(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V7H15z"
  })), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.147 7.853)"
  })), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15H30V17H25z"
  })), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.147 21.668H25.147V26.625999999999998H23.147z",
    transform: "rotate(-45 24.147 24.146)"
  })), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25H17V30H15z"
  })), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.375 23.147H10.333V25.147H5.375z",
    transform: "rotate(-45 7.853 24.146)"
  })), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15H7V17H2z"
  })), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.854 7.853)"
  })), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z"
  })), children);
});
var Lightning32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Lightning32(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.61,29.92a1,1,0,0,1-.6-1.07L12.83,17H8a1,1,0,0,1-1-1.23l3-13A1,1,0,0,1,11,2H21a1,1,0,0,1,.78.37,1,1,0,0,1,.2.85L20.25,11H25a1,1,0,0,1,.9.56,1,1,0,0,1-.11,1l-13,17A1,1,0,0,1,12,30,1.09,1.09,0,0,1,11.61,29.92ZM17.75,13l2-9H11.8L9.26,15h5.91L13.58,25.28,23,13Z"
  })), children);
});
var Lightning24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Lightning24(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.61,29.92a1,1,0,0,1-.6-1.07L12.83,17H8a1,1,0,0,1-1-1.23l3-13A1,1,0,0,1,11,2H21a1,1,0,0,1,.78.37,1,1,0,0,1,.2.85L20.25,11H25a1,1,0,0,1,.9.56,1,1,0,0,1-.11,1l-13,17A1,1,0,0,1,12,30,1.09,1.09,0,0,1,11.61,29.92ZM17.75,13l2-9H11.8L9.26,15h5.91L13.58,25.28,23,13Z"
  })), children);
});
var Lightning20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Lightning20(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.61,29.92a1,1,0,0,1-.6-1.07L12.83,17H8a1,1,0,0,1-1-1.23l3-13A1,1,0,0,1,11,2H21a1,1,0,0,1,.78.37,1,1,0,0,1,.2.85L20.25,11H25a1,1,0,0,1,.9.56,1,1,0,0,1-.11,1l-13,17A1,1,0,0,1,12,30,1.09,1.09,0,0,1,11.61,29.92ZM17.75,13l2-9H11.8L9.26,15h5.91L13.58,25.28,23,13Z"
  })), children);
});
var Lightning16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Lightning16(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.61,29.92a1,1,0,0,1-.6-1.07L12.83,17H8a1,1,0,0,1-1-1.23l3-13A1,1,0,0,1,11,2H21a1,1,0,0,1,.78.37,1,1,0,0,1,.2.85L20.25,11H25a1,1,0,0,1,.9.56,1,1,0,0,1-.11,1l-13,17A1,1,0,0,1,12,30,1.09,1.09,0,0,1,11.61,29.92ZM17.75,13l2-9H11.8L9.26,15h5.91L13.58,25.28,23,13Z"
  })), children);
});
var Link32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Link32(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.25,6.76a6,6,0,0,0-8.5,0l1.42,1.42a4,4,0,1,1,5.67,5.67l-8,8a4,4,0,1,1-5.67-5.66l1.41-1.42-1.41-1.42-1.42,1.42a6,6,0,0,0,0,8.5A6,6,0,0,0,17,25a6,6,0,0,0,4.27-1.76l8-8A6,6,0,0,0,29.25,6.76Z"
  })), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.19,24.82a4,4,0,0,1,0-5.67l8-8a4,4,0,0,1,5.67,0A3.94,3.94,0,0,1,19,14a4,4,0,0,1-1.17,2.85L15.71,19l1.42,1.42,2.12-2.12a6,6,0,0,0-8.51-8.51l-8,8a6,6,0,0,0,0,8.51A6,6,0,0,0,7,28a6.07,6.07,0,0,0,4.28-1.76L9.86,24.82A4,4,0,0,1,4.19,24.82Z"
  })), children);
});
var Link24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Link24(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.25,6.76a6,6,0,0,0-8.5,0l1.42,1.42a4,4,0,1,1,5.67,5.67l-8,8a4,4,0,1,1-5.67-5.66l1.41-1.42-1.41-1.42-1.42,1.42a6,6,0,0,0,0,8.5A6,6,0,0,0,17,25a6,6,0,0,0,4.27-1.76l8-8A6,6,0,0,0,29.25,6.76Z"
  })), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.19,24.82a4,4,0,0,1,0-5.67l8-8a4,4,0,0,1,5.67,0A3.94,3.94,0,0,1,19,14a4,4,0,0,1-1.17,2.85L15.71,19l1.42,1.42,2.12-2.12a6,6,0,0,0-8.51-8.51l-8,8a6,6,0,0,0,0,8.51A6,6,0,0,0,7,28a6.07,6.07,0,0,0,4.28-1.76L9.86,24.82A4,4,0,0,1,4.19,24.82Z"
  })), children);
});
var Link20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Link20(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.25,6.76a6,6,0,0,0-8.5,0l1.42,1.42a4,4,0,1,1,5.67,5.67l-8,8a4,4,0,1,1-5.67-5.66l1.41-1.42-1.41-1.42-1.42,1.42a6,6,0,0,0,0,8.5A6,6,0,0,0,17,25a6,6,0,0,0,4.27-1.76l8-8A6,6,0,0,0,29.25,6.76Z"
  })), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.19,24.82a4,4,0,0,1,0-5.67l8-8a4,4,0,0,1,5.67,0A3.94,3.94,0,0,1,19,14a4,4,0,0,1-1.17,2.85L15.71,19l1.42,1.42,2.12-2.12a6,6,0,0,0-8.51-8.51l-8,8a6,6,0,0,0,0,8.51A6,6,0,0,0,7,28a6.07,6.07,0,0,0,4.28-1.76L9.86,24.82A4,4,0,0,1,4.19,24.82Z"
  })), children);
});
var Link16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Link16(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.25,6.76a6,6,0,0,0-8.5,0l1.42,1.42a4,4,0,1,1,5.67,5.67l-8,8a4,4,0,1,1-5.67-5.66l1.41-1.42-1.41-1.42-1.42,1.42a6,6,0,0,0,0,8.5A6,6,0,0,0,17,25a6,6,0,0,0,4.27-1.76l8-8A6,6,0,0,0,29.25,6.76Z"
  })), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.19,24.82a4,4,0,0,1,0-5.67l8-8a4,4,0,0,1,5.67,0A3.94,3.94,0,0,1,19,14a4,4,0,0,1-1.17,2.85L15.71,19l1.42,1.42,2.12-2.12a6,6,0,0,0-8.51-8.51l-8,8a6,6,0,0,0,0,8.51A6,6,0,0,0,7,28a6.07,6.07,0,0,0,4.28-1.76L9.86,24.82A4,4,0,0,1,4.19,24.82Z"
  })), children);
});
var Linux32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Linux32(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.8945,23.542l-1.7238-3.4473a1.9994,1.9994,0,0,0-1.7886-1.1054h-.4683a14.887,14.887,0,0,0-1.8193-4.5977C23.0647,12.4429,22,10.4277,22,8A6,6,0,0,0,10,8a13.0041,13.0041,0,0,1-2.0486,6.2153,14.7022,14.7022,0,0,0-1.8708,4.7759H5.6184a2.0007,2.0007,0,0,0-1.7893,1.106L2.1055,23.5439a1,1,0,0,0,.0971,1.0508L6.2319,29.92a2.9995,2.9995,0,0,0,3.8482.6519l1.8735-1.1241A13.8223,13.8223,0,0,0,16,30a13.8034,13.8034,0,0,0,4.0488-.5527L21.92,30.57a2.9819,2.9819,0,0,0,1.5385.43,3.0385,3.0385,0,0,0,2.3389-1.1187l4-5.2885A1.001,1.001,0,0,0,29.8945,23.542Zm-7.5683-8.2158a14.8311,14.8311,0,0,1,1.5591,3.6631H21.738a16.6591,16.6591,0,0,0-.98-2.6455,12.7083,12.7083,0,0,1-.8789-2.4454,8.8046,8.8046,0,0,0,1.0034-1.4277l.0384-.0718A30.746,30.746,0,0,0,22.3262,15.3262ZM12,21a9.3959,9.3959,0,0,1,1.0728-3.8516c.2563-.5825.5158-1.1757.726-1.7993a4.0474,4.0474,0,0,0,4.4024,0c.21.6236.47,1.2168.726,1.7993A9.3959,9.3959,0,0,1,20,21c0,1.2881-.4146,3-4,3S12,22.2881,12,21Zm6.5105-8.5752A3.6265,3.6265,0,0,1,16,14a3.6273,3.6273,0,0,1-2.5107-1.5757,7.6356,7.6356,0,0,1,5.0212,0ZM12,8a4,4,0,0,1,8,0,10.9164,10.9164,0,0,0,.4673,3.1152A7.9811,7.9811,0,0,0,19,10.4849V8H17v2.0542a9.2522,9.2522,0,0,0-2,0V8H13v2.4849a7.9019,7.9019,0,0,0-1.4785.6372A10.7093,10.7093,0,0,0,12,8ZM9.7146,15.1592A29.8007,29.8007,0,0,0,11.0693,12.38l.0484.09a8.8046,8.8046,0,0,0,1.0034,1.4277,12.7083,12.7083,0,0,1-.8789,2.4454,16.6574,16.6574,0,0,0-.981,2.6474H8.1047A14.0567,14.0567,0,0,1,9.7146,15.1592Zm1.3708,12.4775L9.0508,28.8574a.9866.9866,0,0,1-1.2529-.1806L4.1724,23.8833l1.4458-2.8921h3.706L11.49,26.3853A1.0036,1.0036,0,0,1,11.0854,27.6367Zm2.316.1177a2.9571,2.9571,0,0,0-.0562-2.11A9.03,9.03,0,0,0,16,26a9.0237,9.0237,0,0,0,2.6562-.3564,2.9889,2.9889,0,0,0-.0546,2.11,13.8722,13.8722,0,0,1-5.2,0Zm10.83.8833a.996.996,0,0,1-1.2827.2178l-2.0342-1.2207h0a1.01,1.01,0,0,1-.396-1.273l2.157-5.3725h3.7058l1.4461,2.892Z"
  })), children);
});
var Linux24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Linux24(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.8945,23.542l-1.7238-3.4473a1.9994,1.9994,0,0,0-1.7886-1.1054h-.4683a14.887,14.887,0,0,0-1.8193-4.5977C23.0647,12.4429,22,10.4277,22,8A6,6,0,0,0,10,8a13.0041,13.0041,0,0,1-2.0486,6.2153,14.7022,14.7022,0,0,0-1.8708,4.7759H5.6184a2.0007,2.0007,0,0,0-1.7893,1.106L2.1055,23.5439a1,1,0,0,0,.0971,1.0508L6.2319,29.92a2.9995,2.9995,0,0,0,3.8482.6519l1.8735-1.1241A13.8223,13.8223,0,0,0,16,30a13.8034,13.8034,0,0,0,4.0488-.5527L21.92,30.57a2.9819,2.9819,0,0,0,1.5385.43,3.0385,3.0385,0,0,0,2.3389-1.1187l4-5.2885A1.001,1.001,0,0,0,29.8945,23.542Zm-7.5683-8.2158a14.8311,14.8311,0,0,1,1.5591,3.6631H21.738a16.6591,16.6591,0,0,0-.98-2.6455,12.7083,12.7083,0,0,1-.8789-2.4454,8.8046,8.8046,0,0,0,1.0034-1.4277l.0384-.0718A30.746,30.746,0,0,0,22.3262,15.3262ZM12,21a9.3959,9.3959,0,0,1,1.0728-3.8516c.2563-.5825.5158-1.1757.726-1.7993a4.0474,4.0474,0,0,0,4.4024,0c.21.6236.47,1.2168.726,1.7993A9.3959,9.3959,0,0,1,20,21c0,1.2881-.4146,3-4,3S12,22.2881,12,21Zm6.5105-8.5752A3.6265,3.6265,0,0,1,16,14a3.6273,3.6273,0,0,1-2.5107-1.5757,7.6356,7.6356,0,0,1,5.0212,0ZM12,8a4,4,0,0,1,8,0,10.9164,10.9164,0,0,0,.4673,3.1152A7.9811,7.9811,0,0,0,19,10.4849V8H17v2.0542a9.2522,9.2522,0,0,0-2,0V8H13v2.4849a7.9019,7.9019,0,0,0-1.4785.6372A10.7093,10.7093,0,0,0,12,8ZM9.7146,15.1592A29.8007,29.8007,0,0,0,11.0693,12.38l.0484.09a8.8046,8.8046,0,0,0,1.0034,1.4277,12.7083,12.7083,0,0,1-.8789,2.4454,16.6574,16.6574,0,0,0-.981,2.6474H8.1047A14.0567,14.0567,0,0,1,9.7146,15.1592Zm1.3708,12.4775L9.0508,28.8574a.9866.9866,0,0,1-1.2529-.1806L4.1724,23.8833l1.4458-2.8921h3.706L11.49,26.3853A1.0036,1.0036,0,0,1,11.0854,27.6367Zm2.316.1177a2.9571,2.9571,0,0,0-.0562-2.11A9.03,9.03,0,0,0,16,26a9.0237,9.0237,0,0,0,2.6562-.3564,2.9889,2.9889,0,0,0-.0546,2.11,13.8722,13.8722,0,0,1-5.2,0Zm10.83.8833a.996.996,0,0,1-1.2827.2178l-2.0342-1.2207h0a1.01,1.01,0,0,1-.396-1.273l2.157-5.3725h3.7058l1.4461,2.892Z"
  })), children);
});
var Linux20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Linux20(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.8945,23.542l-1.7238-3.4473a1.9994,1.9994,0,0,0-1.7886-1.1054h-.4683a14.887,14.887,0,0,0-1.8193-4.5977C23.0647,12.4429,22,10.4277,22,8A6,6,0,0,0,10,8a13.0041,13.0041,0,0,1-2.0486,6.2153,14.7022,14.7022,0,0,0-1.8708,4.7759H5.6184a2.0007,2.0007,0,0,0-1.7893,1.106L2.1055,23.5439a1,1,0,0,0,.0971,1.0508L6.2319,29.92a2.9995,2.9995,0,0,0,3.8482.6519l1.8735-1.1241A13.8223,13.8223,0,0,0,16,30a13.8034,13.8034,0,0,0,4.0488-.5527L21.92,30.57a2.9819,2.9819,0,0,0,1.5385.43,3.0385,3.0385,0,0,0,2.3389-1.1187l4-5.2885A1.001,1.001,0,0,0,29.8945,23.542Zm-7.5683-8.2158a14.8311,14.8311,0,0,1,1.5591,3.6631H21.738a16.6591,16.6591,0,0,0-.98-2.6455,12.7083,12.7083,0,0,1-.8789-2.4454,8.8046,8.8046,0,0,0,1.0034-1.4277l.0384-.0718A30.746,30.746,0,0,0,22.3262,15.3262ZM12,21a9.3959,9.3959,0,0,1,1.0728-3.8516c.2563-.5825.5158-1.1757.726-1.7993a4.0474,4.0474,0,0,0,4.4024,0c.21.6236.47,1.2168.726,1.7993A9.3959,9.3959,0,0,1,20,21c0,1.2881-.4146,3-4,3S12,22.2881,12,21Zm6.5105-8.5752A3.6265,3.6265,0,0,1,16,14a3.6273,3.6273,0,0,1-2.5107-1.5757,7.6356,7.6356,0,0,1,5.0212,0ZM12,8a4,4,0,0,1,8,0,10.9164,10.9164,0,0,0,.4673,3.1152A7.9811,7.9811,0,0,0,19,10.4849V8H17v2.0542a9.2522,9.2522,0,0,0-2,0V8H13v2.4849a7.9019,7.9019,0,0,0-1.4785.6372A10.7093,10.7093,0,0,0,12,8ZM9.7146,15.1592A29.8007,29.8007,0,0,0,11.0693,12.38l.0484.09a8.8046,8.8046,0,0,0,1.0034,1.4277,12.7083,12.7083,0,0,1-.8789,2.4454,16.6574,16.6574,0,0,0-.981,2.6474H8.1047A14.0567,14.0567,0,0,1,9.7146,15.1592Zm1.3708,12.4775L9.0508,28.8574a.9866.9866,0,0,1-1.2529-.1806L4.1724,23.8833l1.4458-2.8921h3.706L11.49,26.3853A1.0036,1.0036,0,0,1,11.0854,27.6367Zm2.316.1177a2.9571,2.9571,0,0,0-.0562-2.11A9.03,9.03,0,0,0,16,26a9.0237,9.0237,0,0,0,2.6562-.3564,2.9889,2.9889,0,0,0-.0546,2.11,13.8722,13.8722,0,0,1-5.2,0Zm10.83.8833a.996.996,0,0,1-1.2827.2178l-2.0342-1.2207h0a1.01,1.01,0,0,1-.396-1.273l2.157-5.3725h3.7058l1.4461,2.892Z"
  })), children);
});
var Linux16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Linux16(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.8945,23.542l-1.7238-3.4473a1.9994,1.9994,0,0,0-1.7886-1.1054h-.4683a14.887,14.887,0,0,0-1.8193-4.5977C23.0647,12.4429,22,10.4277,22,8A6,6,0,0,0,10,8a13.0041,13.0041,0,0,1-2.0486,6.2153,14.7022,14.7022,0,0,0-1.8708,4.7759H5.6184a2.0007,2.0007,0,0,0-1.7893,1.106L2.1055,23.5439a1,1,0,0,0,.0971,1.0508L6.2319,29.92a2.9995,2.9995,0,0,0,3.8482.6519l1.8735-1.1241A13.8223,13.8223,0,0,0,16,30a13.8034,13.8034,0,0,0,4.0488-.5527L21.92,30.57a2.9819,2.9819,0,0,0,1.5385.43,3.0385,3.0385,0,0,0,2.3389-1.1187l4-5.2885A1.001,1.001,0,0,0,29.8945,23.542Zm-7.5683-8.2158a14.8311,14.8311,0,0,1,1.5591,3.6631H21.738a16.6591,16.6591,0,0,0-.98-2.6455,12.7083,12.7083,0,0,1-.8789-2.4454,8.8046,8.8046,0,0,0,1.0034-1.4277l.0384-.0718A30.746,30.746,0,0,0,22.3262,15.3262ZM12,21a9.3959,9.3959,0,0,1,1.0728-3.8516c.2563-.5825.5158-1.1757.726-1.7993a4.0474,4.0474,0,0,0,4.4024,0c.21.6236.47,1.2168.726,1.7993A9.3959,9.3959,0,0,1,20,21c0,1.2881-.4146,3-4,3S12,22.2881,12,21Zm6.5105-8.5752A3.6265,3.6265,0,0,1,16,14a3.6273,3.6273,0,0,1-2.5107-1.5757,7.6356,7.6356,0,0,1,5.0212,0ZM12,8a4,4,0,0,1,8,0,10.9164,10.9164,0,0,0,.4673,3.1152A7.9811,7.9811,0,0,0,19,10.4849V8H17v2.0542a9.2522,9.2522,0,0,0-2,0V8H13v2.4849a7.9019,7.9019,0,0,0-1.4785.6372A10.7093,10.7093,0,0,0,12,8ZM9.7146,15.1592A29.8007,29.8007,0,0,0,11.0693,12.38l.0484.09a8.8046,8.8046,0,0,0,1.0034,1.4277,12.7083,12.7083,0,0,1-.8789,2.4454,16.6574,16.6574,0,0,0-.981,2.6474H8.1047A14.0567,14.0567,0,0,1,9.7146,15.1592Zm1.3708,12.4775L9.0508,28.8574a.9866.9866,0,0,1-1.2529-.1806L4.1724,23.8833l1.4458-2.8921h3.706L11.49,26.3853A1.0036,1.0036,0,0,1,11.0854,27.6367Zm2.316.1177a2.9571,2.9571,0,0,0-.0562-2.11A9.03,9.03,0,0,0,16,26a9.0237,9.0237,0,0,0,2.6562-.3564,2.9889,2.9889,0,0,0-.0546,2.11,13.8722,13.8722,0,0,1-5.2,0Zm10.83.8833a.996.996,0,0,1-1.2827.2178l-2.0342-1.2207h0a1.01,1.01,0,0,1-.396-1.273l2.157-5.3725h3.7058l1.4461,2.892Z"
  })), children);
});
var LinuxAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LinuxAlt32(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.6121,20.5215A6.1582,6.1582,0,0,0,24,16.5254C24,13.4785,21.9812,11,19.5,11A4.2435,4.2435,0,0,0,16,13.06,4.2435,4.2435,0,0,0,12.5,11C10.0188,11,8,13.4785,8,16.5254a6.1593,6.1593,0,0,0,1.3879,3.9961c-.5688.3686-.9389.6416-.988.6787a1,1,0,0,0-.1807,1.4248C8.6592,23.1748,12.6169,28,16,28s7.3408-4.8252,7.7808-5.375A1,1,0,0,0,23.6,21.2C23.551,21.1631,23.1812,20.89,22.6121,20.5215ZM12.5,13c1.3552,0,2.5,1.6143,2.5,3.5254v1.5664a9.1005,9.1005,0,0,0-1.0244.2314A2.6411,2.6411,0,0,0,14,18c0-1.1045-.6716-2-1.5-2s-1.5.8955-1.5,2a2.38,2.38,0,0,0,.4072,1.3623c-.0813.0415-.1687.0806-.248.1221A4.0291,4.0291,0,0,1,10,16.5254C10,14.6143,11.1448,13,12.5,13ZM16,26c-1.5691,0-3.9648-2.084-5.52-3.8057C11.9,21.2788,14.2656,20,16,20s4.1,1.2788,5.52,2.1943C19.9648,23.916,17.5691,26,16,26Zm4.8408-6.5156c-.0793-.0415-.1667-.0806-.248-.1221A2.38,2.38,0,0,0,21,18c0-1.1045-.6716-2-1.5-2s-1.5.8955-1.5,2a2.6411,2.6411,0,0,0,.0244.3232A9.1005,9.1005,0,0,0,17,18.0918V16.5254C17,14.6143,18.1448,13,19.5,13S22,14.6143,22,16.5254A4.0291,4.0291,0,0,1,20.8408,19.4844Z"
  })), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30a3.8876,3.8876,0,0,1-4-4V14A10,10,0,0,0,6,14V26a3.8876,3.8876,0,0,1-4,4V28a1.8793,1.8793,0,0,0,2-2V14a12,12,0,0,1,24,0V26a1.8825,1.8825,0,0,0,2,2Z"
  })), children);
});
var LinuxAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LinuxAlt24(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.6121,20.5215A6.1582,6.1582,0,0,0,24,16.5254C24,13.4785,21.9812,11,19.5,11A4.2435,4.2435,0,0,0,16,13.06,4.2435,4.2435,0,0,0,12.5,11C10.0188,11,8,13.4785,8,16.5254a6.1593,6.1593,0,0,0,1.3879,3.9961c-.5688.3686-.9389.6416-.988.6787a1,1,0,0,0-.1807,1.4248C8.6592,23.1748,12.6169,28,16,28s7.3408-4.8252,7.7808-5.375A1,1,0,0,0,23.6,21.2C23.551,21.1631,23.1812,20.89,22.6121,20.5215ZM12.5,13c1.3552,0,2.5,1.6143,2.5,3.5254v1.5664a9.1005,9.1005,0,0,0-1.0244.2314A2.6411,2.6411,0,0,0,14,18c0-1.1045-.6716-2-1.5-2s-1.5.8955-1.5,2a2.38,2.38,0,0,0,.4072,1.3623c-.0813.0415-.1687.0806-.248.1221A4.0291,4.0291,0,0,1,10,16.5254C10,14.6143,11.1448,13,12.5,13ZM16,26c-1.5691,0-3.9648-2.084-5.52-3.8057C11.9,21.2788,14.2656,20,16,20s4.1,1.2788,5.52,2.1943C19.9648,23.916,17.5691,26,16,26Zm4.8408-6.5156c-.0793-.0415-.1667-.0806-.248-.1221A2.38,2.38,0,0,0,21,18c0-1.1045-.6716-2-1.5-2s-1.5.8955-1.5,2a2.6411,2.6411,0,0,0,.0244.3232A9.1005,9.1005,0,0,0,17,18.0918V16.5254C17,14.6143,18.1448,13,19.5,13S22,14.6143,22,16.5254A4.0291,4.0291,0,0,1,20.8408,19.4844Z"
  })), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30a3.8876,3.8876,0,0,1-4-4V14A10,10,0,0,0,6,14V26a3.8876,3.8876,0,0,1-4,4V28a1.8793,1.8793,0,0,0,2-2V14a12,12,0,0,1,24,0V26a1.8825,1.8825,0,0,0,2,2Z"
  })), children);
});
var LinuxAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LinuxAlt20(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.6121,20.5215A6.1582,6.1582,0,0,0,24,16.5254C24,13.4785,21.9812,11,19.5,11A4.2435,4.2435,0,0,0,16,13.06,4.2435,4.2435,0,0,0,12.5,11C10.0188,11,8,13.4785,8,16.5254a6.1593,6.1593,0,0,0,1.3879,3.9961c-.5688.3686-.9389.6416-.988.6787a1,1,0,0,0-.1807,1.4248C8.6592,23.1748,12.6169,28,16,28s7.3408-4.8252,7.7808-5.375A1,1,0,0,0,23.6,21.2C23.551,21.1631,23.1812,20.89,22.6121,20.5215ZM12.5,13c1.3552,0,2.5,1.6143,2.5,3.5254v1.5664a9.1005,9.1005,0,0,0-1.0244.2314A2.6411,2.6411,0,0,0,14,18c0-1.1045-.6716-2-1.5-2s-1.5.8955-1.5,2a2.38,2.38,0,0,0,.4072,1.3623c-.0813.0415-.1687.0806-.248.1221A4.0291,4.0291,0,0,1,10,16.5254C10,14.6143,11.1448,13,12.5,13ZM16,26c-1.5691,0-3.9648-2.084-5.52-3.8057C11.9,21.2788,14.2656,20,16,20s4.1,1.2788,5.52,2.1943C19.9648,23.916,17.5691,26,16,26Zm4.8408-6.5156c-.0793-.0415-.1667-.0806-.248-.1221A2.38,2.38,0,0,0,21,18c0-1.1045-.6716-2-1.5-2s-1.5.8955-1.5,2a2.6411,2.6411,0,0,0,.0244.3232A9.1005,9.1005,0,0,0,17,18.0918V16.5254C17,14.6143,18.1448,13,19.5,13S22,14.6143,22,16.5254A4.0291,4.0291,0,0,1,20.8408,19.4844Z"
  })), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30a3.8876,3.8876,0,0,1-4-4V14A10,10,0,0,0,6,14V26a3.8876,3.8876,0,0,1-4,4V28a1.8793,1.8793,0,0,0,2-2V14a12,12,0,0,1,24,0V26a1.8825,1.8825,0,0,0,2,2Z"
  })), children);
});
var LinuxAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LinuxAlt16(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.6121,20.5215A6.1582,6.1582,0,0,0,24,16.5254C24,13.4785,21.9812,11,19.5,11A4.2435,4.2435,0,0,0,16,13.06,4.2435,4.2435,0,0,0,12.5,11C10.0188,11,8,13.4785,8,16.5254a6.1593,6.1593,0,0,0,1.3879,3.9961c-.5688.3686-.9389.6416-.988.6787a1,1,0,0,0-.1807,1.4248C8.6592,23.1748,12.6169,28,16,28s7.3408-4.8252,7.7808-5.375A1,1,0,0,0,23.6,21.2C23.551,21.1631,23.1812,20.89,22.6121,20.5215ZM12.5,13c1.3552,0,2.5,1.6143,2.5,3.5254v1.5664a9.1005,9.1005,0,0,0-1.0244.2314A2.6411,2.6411,0,0,0,14,18c0-1.1045-.6716-2-1.5-2s-1.5.8955-1.5,2a2.38,2.38,0,0,0,.4072,1.3623c-.0813.0415-.1687.0806-.248.1221A4.0291,4.0291,0,0,1,10,16.5254C10,14.6143,11.1448,13,12.5,13ZM16,26c-1.5691,0-3.9648-2.084-5.52-3.8057C11.9,21.2788,14.2656,20,16,20s4.1,1.2788,5.52,2.1943C19.9648,23.916,17.5691,26,16,26Zm4.8408-6.5156c-.0793-.0415-.1667-.0806-.248-.1221A2.38,2.38,0,0,0,21,18c0-1.1045-.6716-2-1.5-2s-1.5.8955-1.5,2a2.6411,2.6411,0,0,0,.0244.3232A9.1005,9.1005,0,0,0,17,18.0918V16.5254C17,14.6143,18.1448,13,19.5,13S22,14.6143,22,16.5254A4.0291,4.0291,0,0,1,20.8408,19.4844Z"
  })), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30a3.8876,3.8876,0,0,1-4-4V14A10,10,0,0,0,6,14V26a3.8876,3.8876,0,0,1-4,4V28a1.8793,1.8793,0,0,0,2-2V14a12,12,0,0,1,24,0V26a1.8825,1.8825,0,0,0,2,2Z"
  })), children);
});
var List32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function List32(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6H28V8H10zM10 24H28V26H10zM10 15H28V17H10zM4 15H6V17H4zM4 6H6V8H4zM4 24H6V26H4z"
  })), children);
});
var List24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function List24(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6H28V8H10zM10 24H28V26H10zM10 15H28V17H10zM4 15H6V17H4zM4 6H6V8H4zM4 24H6V26H4z"
  })), children);
});
var List20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function List20(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6H28V8H10zM10 24H28V26H10zM10 15H28V17H10zM4 15H6V17H4zM4 6H6V8H4zM4 24H6V26H4z"
  })), children);
});
var List16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function List16(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6H28V8H10zM10 24H28V26H10zM10 15H28V17H10zM4 15H6V17H4zM4 6H6V8H4zM4 24H6V26H4z"
  })), children);
});
var ListBoxes32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListBoxes32(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8H30V10H16zM16 22H30V24H16zM10 14H4a2.0023 2.0023 0 01-2-2V6A2.0023 2.0023 0 014 4h6a2.0023 2.0023 0 012 2v6A2.0023 2.0023 0 0110 14zM4 6v6h6.0012L10 6zM10 28H4a2.0023 2.0023 0 01-2-2V20a2.0023 2.0023 0 012-2h6a2.0023 2.0023 0 012 2v6A2.0023 2.0023 0 0110 28zM4 20v6h6.0012L10 20z"
  })), children);
});
var ListBoxes24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListBoxes24(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8H30V10H16zM16 22H30V24H16zM10 14H4a2.0023 2.0023 0 01-2-2V6A2.0023 2.0023 0 014 4h6a2.0023 2.0023 0 012 2v6A2.0023 2.0023 0 0110 14zM4 6v6h6.0012L10 6zM10 28H4a2.0023 2.0023 0 01-2-2V20a2.0023 2.0023 0 012-2h6a2.0023 2.0023 0 012 2v6A2.0023 2.0023 0 0110 28zM4 20v6h6.0012L10 20z"
  })), children);
});
var ListBoxes20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListBoxes20(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8H30V10H16zM16 22H30V24H16zM10 14H4a2.0023 2.0023 0 01-2-2V6A2.0023 2.0023 0 014 4h6a2.0023 2.0023 0 012 2v6A2.0023 2.0023 0 0110 14zM4 6v6h6.0012L10 6zM10 28H4a2.0023 2.0023 0 01-2-2V20a2.0023 2.0023 0 012-2h6a2.0023 2.0023 0 012 2v6A2.0023 2.0023 0 0110 28zM4 20v6h6.0012L10 20z"
  })), children);
});
var ListBoxes16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListBoxes16(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8H30V10H16zM16 22H30V24H16zM10 14H4a2.0023 2.0023 0 01-2-2V6A2.0023 2.0023 0 014 4h6a2.0023 2.0023 0 012 2v6A2.0023 2.0023 0 0110 14zM4 6v6h6.0012L10 6zM10 28H4a2.0023 2.0023 0 01-2-2V20a2.0023 2.0023 0 012-2h6a2.0023 2.0023 0 012 2v6A2.0023 2.0023 0 0110 28zM4 20v6h6.0012L10 20z"
  })), children);
});
var ListBulleted32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListBulleted32(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "9",
    r: "3"
  })), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "23",
    r: "3"
  })), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22H30V24H16zM16 8H30V10H16z"
  })), children);
});
var ListBulleted24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListBulleted24(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "9",
    r: "3"
  })), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "23",
    r: "3"
  })), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22H30V24H16zM16 8H30V10H16z"
  })), children);
});
var ListBulleted20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListBulleted20(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "9",
    r: "3"
  })), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "23",
    r: "3"
  })), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22H30V24H16zM16 8H30V10H16z"
  })), children);
});
var ListBulleted16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListBulleted16(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3.5",
    cy: "4.5",
    r: "1.5"
  })), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3.5",
    cy: "11.5",
    r: "1.5"
  })), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 11H15V12H8zM8 4H15V5H8z"
  })), children);
});
var ListChecked32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListChecked32(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8H30V10H16zM6 10.59L3.41 8 2 9.41 6 13.41 14 5.41 12.59 4 6 10.59zM16 22H30V24H16zM6 24.59L3.41 22 2 23.41 6 27.41 14 19.41 12.59 18 6 24.59z"
  })), children);
});
var ListChecked24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListChecked24(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8H30V10H16zM6 10.59L3.41 8 2 9.41 6 13.41 14 5.41 12.59 4 6 10.59zM16 22H30V24H16zM6 24.59L3.41 22 2 23.41 6 27.41 14 19.41 12.59 18 6 24.59z"
  })), children);
});
var ListChecked20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListChecked20(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8H30V10H16zM6 10.59L3.41 8 2 9.41 6 13.41 14 5.41 12.59 4 6 10.59zM16 22H30V24H16zM6 24.59L3.41 22 2 23.41 6 27.41 14 19.41 12.59 18 6 24.59z"
  })), children);
});
var ListChecked16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListChecked16(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8H30V10H16zM6 10.59L3.41 8 2 9.41 6 13.41 14 5.41 12.59 4 6 10.59zM16 22H30V24H16zM6 24.59L3.41 22 2 23.41 6 27.41 14 19.41 12.59 18 6 24.59z"
  })), children);
});
var ListDropdown32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListDropdown32(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6V2H2V12h9V30H30V6ZM4,10V4H24V6H11v4ZM28,28H13V8H28Z"
  })), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 11H17V13H15zM19 11H26V13H19zM15 17H17V19H15zM19 17H26V19H19zM15 23H17V25H15zM19 23H26V25H19z"
  })), children);
});
var ListDropdown24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListDropdown24(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6V2H2V12h9V30H30V6ZM4,10V4H24V6H11v4ZM28,28H13V8H28Z"
  })), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 11H17V13H15zM19 11H26V13H19zM15 17H17V19H15zM19 17H26V19H19zM15 23H17V25H15zM19 23H26V25H19z"
  })), children);
});
var ListDropdown20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListDropdown20(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6V2H2V12h9V30H30V6ZM4,10V4H24V6H11v4ZM28,28H13V8H28Z"
  })), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 11H17V13H15zM19 11H26V13H19zM15 17H17V19H15zM19 17H26V19H19zM15 23H17V25H15zM19 23H26V25H19z"
  })), children);
});
var ListDropdown16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListDropdown16(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6V2H2V12h9V30H30V6ZM4,10V4H24V6H11v4ZM28,28H13V8H28Z"
  })), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 11H17V13H15zM19 11H26V13H19zM15 17H17V19H15zM19 17H26V19H19zM15 23H17V25H15zM19 23H26V25H19z"
  })), children);
});
var ListNumbered32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListNumbered32(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path390 || (_path390 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22H30V24H16zM16 8H30V10H16zM8 12L8 4 6 4 6 5 4 5 4 7 6 7 6 12 4 12 4 14 6 14 8 14 10 14 10 12 8 12zM10 28H4V24a2 2 0 012-2H8V20H4V18H8a2 2 0 012 2v2a2 2 0 01-2 2H6v2h4z"
  })), children);
});
var ListNumbered24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListNumbered24(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path391 || (_path391 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22H30V24H16zM16 8H30V10H16zM8 12L8 4 6 4 6 5 4 5 4 7 6 7 6 12 4 12 4 14 6 14 8 14 10 14 10 12 8 12zM10 28H4V24a2 2 0 012-2H8V20H4V18H8a2 2 0 012 2v2a2 2 0 01-2 2H6v2h4z"
  })), children);
});
var ListNumbered20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListNumbered20(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path392 || (_path392 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22H30V24H16zM16 8H30V10H16zM8 12L8 4 6 4 6 5 4 5 4 7 6 7 6 12 4 12 4 14 6 14 8 14 10 14 10 12 8 12zM10 28H4V24a2 2 0 012-2H8V20H4V18H8a2 2 0 012 2v2a2 2 0 01-2 2H6v2h4z"
  })), children);
});
var ListNumbered16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ListNumbered16(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path393 || (_path393 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22H30V24H16zM16 8H30V10H16zM8 12L8 4 6 4 6 5 4 5 4 7 6 7 6 12 4 12 4 14 6 14 8 14 10 14 10 12 8 12zM10 28H4V24a2 2 0 012-2H8V20H4V18H8a2 2 0 012 2v2a2 2 0 01-2 2H6v2h4z"
  })), children);
});
var LoadBalancerApplication32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerApplication32(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path394 || (_path394 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM25 16H17V14H15v2H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM9 2V12H23V2zm2 2h2v6H11zm10 6H15V4h6z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-16.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-16.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "LoadBalancerApplication16": () => (/* binding */ LoadBalancerApplication16),
/* harmony export */   "LoadBalancerApplication20": () => (/* binding */ LoadBalancerApplication20),
/* harmony export */   "LoadBalancerApplication24": () => (/* binding */ LoadBalancerApplication24),
/* harmony export */   "LoadBalancerClassic16": () => (/* binding */ LoadBalancerClassic16),
/* harmony export */   "LoadBalancerClassic20": () => (/* binding */ LoadBalancerClassic20),
/* harmony export */   "LoadBalancerClassic24": () => (/* binding */ LoadBalancerClassic24),
/* harmony export */   "LoadBalancerClassic32": () => (/* binding */ LoadBalancerClassic32),
/* harmony export */   "LoadBalancerGlobal16": () => (/* binding */ LoadBalancerGlobal16),
/* harmony export */   "LoadBalancerGlobal20": () => (/* binding */ LoadBalancerGlobal20),
/* harmony export */   "LoadBalancerGlobal24": () => (/* binding */ LoadBalancerGlobal24),
/* harmony export */   "LoadBalancerGlobal32": () => (/* binding */ LoadBalancerGlobal32),
/* harmony export */   "LoadBalancerListener16": () => (/* binding */ LoadBalancerListener16),
/* harmony export */   "LoadBalancerListener20": () => (/* binding */ LoadBalancerListener20),
/* harmony export */   "LoadBalancerListener24": () => (/* binding */ LoadBalancerListener24),
/* harmony export */   "LoadBalancerListener32": () => (/* binding */ LoadBalancerListener32),
/* harmony export */   "LoadBalancerLocal16": () => (/* binding */ LoadBalancerLocal16),
/* harmony export */   "LoadBalancerLocal20": () => (/* binding */ LoadBalancerLocal20),
/* harmony export */   "LoadBalancerLocal24": () => (/* binding */ LoadBalancerLocal24),
/* harmony export */   "LoadBalancerLocal32": () => (/* binding */ LoadBalancerLocal32),
/* harmony export */   "LoadBalancerNetwork16": () => (/* binding */ LoadBalancerNetwork16),
/* harmony export */   "LoadBalancerNetwork20": () => (/* binding */ LoadBalancerNetwork20),
/* harmony export */   "LoadBalancerNetwork24": () => (/* binding */ LoadBalancerNetwork24),
/* harmony export */   "LoadBalancerNetwork32": () => (/* binding */ LoadBalancerNetwork32),
/* harmony export */   "LoadBalancerPool16": () => (/* binding */ LoadBalancerPool16),
/* harmony export */   "LoadBalancerPool20": () => (/* binding */ LoadBalancerPool20),
/* harmony export */   "LoadBalancerPool24": () => (/* binding */ LoadBalancerPool24),
/* harmony export */   "LoadBalancerPool32": () => (/* binding */ LoadBalancerPool32),
/* harmony export */   "LoadBalancerVpc16": () => (/* binding */ LoadBalancerVpc16),
/* harmony export */   "LoadBalancerVpc20": () => (/* binding */ LoadBalancerVpc20),
/* harmony export */   "LoadBalancerVpc24": () => (/* binding */ LoadBalancerVpc24),
/* harmony export */   "LoadBalancerVpc32": () => (/* binding */ LoadBalancerVpc32),
/* harmony export */   "Location16": () => (/* binding */ Location16),
/* harmony export */   "Location20": () => (/* binding */ Location20),
/* harmony export */   "Location24": () => (/* binding */ Location24),
/* harmony export */   "Location32": () => (/* binding */ Location32),
/* harmony export */   "LocationCompany16": () => (/* binding */ LocationCompany16),
/* harmony export */   "LocationCompany20": () => (/* binding */ LocationCompany20),
/* harmony export */   "LocationCompany24": () => (/* binding */ LocationCompany24),
/* harmony export */   "LocationCompany32": () => (/* binding */ LocationCompany32),
/* harmony export */   "LocationCompanyFilled16": () => (/* binding */ LocationCompanyFilled16),
/* harmony export */   "LocationCompanyFilled20": () => (/* binding */ LocationCompanyFilled20),
/* harmony export */   "LocationCompanyFilled24": () => (/* binding */ LocationCompanyFilled24),
/* harmony export */   "LocationCompanyFilled32": () => (/* binding */ LocationCompanyFilled32),
/* harmony export */   "LocationCurrent16": () => (/* binding */ LocationCurrent16),
/* harmony export */   "LocationCurrent20": () => (/* binding */ LocationCurrent20),
/* harmony export */   "LocationCurrent24": () => (/* binding */ LocationCurrent24),
/* harmony export */   "LocationCurrent32": () => (/* binding */ LocationCurrent32),
/* harmony export */   "LocationFilled16": () => (/* binding */ LocationFilled16),
/* harmony export */   "LocationFilled20": () => (/* binding */ LocationFilled20),
/* harmony export */   "LocationFilled24": () => (/* binding */ LocationFilled24),
/* harmony export */   "LocationFilled32": () => (/* binding */ LocationFilled32),
/* harmony export */   "LocationHazard16": () => (/* binding */ LocationHazard16),
/* harmony export */   "LocationHazard20": () => (/* binding */ LocationHazard20),
/* harmony export */   "LocationHazard24": () => (/* binding */ LocationHazard24),
/* harmony export */   "LocationHazard32": () => (/* binding */ LocationHazard32),
/* harmony export */   "LocationHazardFilled16": () => (/* binding */ LocationHazardFilled16),
/* harmony export */   "LocationHazardFilled20": () => (/* binding */ LocationHazardFilled20),
/* harmony export */   "LocationHazardFilled24": () => (/* binding */ LocationHazardFilled24),
/* harmony export */   "LocationHazardFilled32": () => (/* binding */ LocationHazardFilled32),
/* harmony export */   "LocationHeart16": () => (/* binding */ LocationHeart16),
/* harmony export */   "LocationHeart20": () => (/* binding */ LocationHeart20),
/* harmony export */   "LocationHeart24": () => (/* binding */ LocationHeart24),
/* harmony export */   "LocationHeart32": () => (/* binding */ LocationHeart32),
/* harmony export */   "LocationHeartFilled16": () => (/* binding */ LocationHeartFilled16),
/* harmony export */   "LocationHeartFilled20": () => (/* binding */ LocationHeartFilled20),
/* harmony export */   "LocationHeartFilled24": () => (/* binding */ LocationHeartFilled24),
/* harmony export */   "LocationHeartFilled32": () => (/* binding */ LocationHeartFilled32),
/* harmony export */   "LocationPerson16": () => (/* binding */ LocationPerson16),
/* harmony export */   "LocationPerson20": () => (/* binding */ LocationPerson20),
/* harmony export */   "LocationPerson24": () => (/* binding */ LocationPerson24),
/* harmony export */   "LocationPerson32": () => (/* binding */ LocationPerson32),
/* harmony export */   "LocationPersonFilled16": () => (/* binding */ LocationPersonFilled16),
/* harmony export */   "LocationPersonFilled20": () => (/* binding */ LocationPersonFilled20),
/* harmony export */   "LocationPersonFilled24": () => (/* binding */ LocationPersonFilled24),
/* harmony export */   "LocationPersonFilled32": () => (/* binding */ LocationPersonFilled32),
/* harmony export */   "LocationSave16": () => (/* binding */ LocationSave16),
/* harmony export */   "LocationSave20": () => (/* binding */ LocationSave20),
/* harmony export */   "LocationSave24": () => (/* binding */ LocationSave24),
/* harmony export */   "LocationSave32": () => (/* binding */ LocationSave32),
/* harmony export */   "LocationStar16": () => (/* binding */ LocationStar16),
/* harmony export */   "LocationStar20": () => (/* binding */ LocationStar20),
/* harmony export */   "LocationStar24": () => (/* binding */ LocationStar24),
/* harmony export */   "LocationStar32": () => (/* binding */ LocationStar32),
/* harmony export */   "LocationStarFilled16": () => (/* binding */ LocationStarFilled16),
/* harmony export */   "LocationStarFilled20": () => (/* binding */ LocationStarFilled20),
/* harmony export */   "LocationStarFilled24": () => (/* binding */ LocationStarFilled24),
/* harmony export */   "LocationStarFilled32": () => (/* binding */ LocationStarFilled32),
/* harmony export */   "Locked16": () => (/* binding */ Locked16),
/* harmony export */   "Locked20": () => (/* binding */ Locked20),
/* harmony export */   "Locked24": () => (/* binding */ Locked24),
/* harmony export */   "Locked32": () => (/* binding */ Locked32),
/* harmony export */   "LogicalPartition16": () => (/* binding */ LogicalPartition16),
/* harmony export */   "LogicalPartition20": () => (/* binding */ LogicalPartition20),
/* harmony export */   "LogicalPartition24": () => (/* binding */ LogicalPartition24),
/* harmony export */   "LogicalPartition32": () => (/* binding */ LogicalPartition32),
/* harmony export */   "Login16": () => (/* binding */ Login16),
/* harmony export */   "Login20": () => (/* binding */ Login20),
/* harmony export */   "Login24": () => (/* binding */ Login24),
/* harmony export */   "Login32": () => (/* binding */ Login32),
/* harmony export */   "LogoDelicious16": () => (/* binding */ LogoDelicious16),
/* harmony export */   "LogoDelicious20": () => (/* binding */ LogoDelicious20),
/* harmony export */   "LogoDelicious24": () => (/* binding */ LogoDelicious24),
/* harmony export */   "LogoDelicious32": () => (/* binding */ LogoDelicious32),
/* harmony export */   "LogoDigg16": () => (/* binding */ LogoDigg16),
/* harmony export */   "LogoDigg20": () => (/* binding */ LogoDigg20),
/* harmony export */   "LogoDigg24": () => (/* binding */ LogoDigg24),
/* harmony export */   "LogoDigg32": () => (/* binding */ LogoDigg32),
/* harmony export */   "LogoDiscord16": () => (/* binding */ LogoDiscord16),
/* harmony export */   "LogoDiscord20": () => (/* binding */ LogoDiscord20),
/* harmony export */   "LogoDiscord24": () => (/* binding */ LogoDiscord24),
/* harmony export */   "LogoDiscord32": () => (/* binding */ LogoDiscord32),
/* harmony export */   "LogoFacebook16": () => (/* binding */ LogoFacebook16),
/* harmony export */   "LogoFacebook20": () => (/* binding */ LogoFacebook20),
/* harmony export */   "LogoFacebook24": () => (/* binding */ LogoFacebook24),
/* harmony export */   "LogoFacebook32": () => (/* binding */ LogoFacebook32),
/* harmony export */   "LogoFlickr16": () => (/* binding */ LogoFlickr16),
/* harmony export */   "LogoFlickr20": () => (/* binding */ LogoFlickr20),
/* harmony export */   "LogoFlickr24": () => (/* binding */ LogoFlickr24),
/* harmony export */   "LogoFlickr32": () => (/* binding */ LogoFlickr32),
/* harmony export */   "LogoGithub16": () => (/* binding */ LogoGithub16),
/* harmony export */   "LogoGithub20": () => (/* binding */ LogoGithub20),
/* harmony export */   "LogoGithub24": () => (/* binding */ LogoGithub24),
/* harmony export */   "LogoGithub32": () => (/* binding */ LogoGithub32),
/* harmony export */   "LogoGlassdoor16": () => (/* binding */ LogoGlassdoor16),
/* harmony export */   "LogoGlassdoor20": () => (/* binding */ LogoGlassdoor20),
/* harmony export */   "LogoGlassdoor24": () => (/* binding */ LogoGlassdoor24),
/* harmony export */   "LogoGlassdoor32": () => (/* binding */ LogoGlassdoor32),
/* harmony export */   "LogoGoogle16": () => (/* binding */ LogoGoogle16),
/* harmony export */   "LogoGoogle20": () => (/* binding */ LogoGoogle20),
/* harmony export */   "LogoGoogle24": () => (/* binding */ LogoGoogle24),
/* harmony export */   "LogoGoogle32": () => (/* binding */ LogoGoogle32),
/* harmony export */   "LogoInstagram16": () => (/* binding */ LogoInstagram16),
/* harmony export */   "LogoInstagram20": () => (/* binding */ LogoInstagram20),
/* harmony export */   "LogoInstagram24": () => (/* binding */ LogoInstagram24),
/* harmony export */   "LogoInstagram32": () => (/* binding */ LogoInstagram32),
/* harmony export */   "LogoJupyter16": () => (/* binding */ LogoJupyter16),
/* harmony export */   "LogoJupyter20": () => (/* binding */ LogoJupyter20),
/* harmony export */   "LogoJupyter24": () => (/* binding */ LogoJupyter24),
/* harmony export */   "LogoJupyter32": () => (/* binding */ LogoJupyter32),
/* harmony export */   "LogoKeybase16": () => (/* binding */ LogoKeybase16),
/* harmony export */   "LogoKeybase20": () => (/* binding */ LogoKeybase20),
/* harmony export */   "LogoKeybase24": () => (/* binding */ LogoKeybase24),
/* harmony export */   "LogoKeybase32": () => (/* binding */ LogoKeybase32),
/* harmony export */   "LogoLinkedin16": () => (/* binding */ LogoLinkedin16),
/* harmony export */   "LogoLinkedin20": () => (/* binding */ LogoLinkedin20),
/* harmony export */   "LogoLinkedin24": () => (/* binding */ LogoLinkedin24),
/* harmony export */   "LogoLinkedin32": () => (/* binding */ LogoLinkedin32),
/* harmony export */   "LogoLivestream16": () => (/* binding */ LogoLivestream16),
/* harmony export */   "LogoLivestream20": () => (/* binding */ LogoLivestream20),
/* harmony export */   "LogoLivestream24": () => (/* binding */ LogoLivestream24),
/* harmony export */   "LogoLivestream32": () => (/* binding */ LogoLivestream32),
/* harmony export */   "LogoMedium16": () => (/* binding */ LogoMedium16),
/* harmony export */   "LogoMedium20": () => (/* binding */ LogoMedium20),
/* harmony export */   "LogoMedium24": () => (/* binding */ LogoMedium24),
/* harmony export */   "LogoMedium32": () => (/* binding */ LogoMedium32),
/* harmony export */   "LogoOpenshift16": () => (/* binding */ LogoOpenshift16),
/* harmony export */   "LogoOpenshift20": () => (/* binding */ LogoOpenshift20),
/* harmony export */   "LogoOpenshift24": () => (/* binding */ LogoOpenshift24),
/* harmony export */   "LogoOpenshift32": () => (/* binding */ LogoOpenshift32),
/* harmony export */   "LogoPinterest16": () => (/* binding */ LogoPinterest16),
/* harmony export */   "LogoPinterest20": () => (/* binding */ LogoPinterest20),
/* harmony export */   "LogoPinterest24": () => (/* binding */ LogoPinterest24),
/* harmony export */   "LogoPinterest32": () => (/* binding */ LogoPinterest32),
/* harmony export */   "LogoPython16": () => (/* binding */ LogoPython16),
/* harmony export */   "LogoPython20": () => (/* binding */ LogoPython20),
/* harmony export */   "LogoPython24": () => (/* binding */ LogoPython24),
/* harmony export */   "LogoPython32": () => (/* binding */ LogoPython32),
/* harmony export */   "LogoQuora16": () => (/* binding */ LogoQuora16),
/* harmony export */   "LogoQuora20": () => (/* binding */ LogoQuora20),
/* harmony export */   "LogoQuora24": () => (/* binding */ LogoQuora24),
/* harmony export */   "LogoQuora32": () => (/* binding */ LogoQuora32),
/* harmony export */   "LogoRScript16": () => (/* binding */ LogoRScript16),
/* harmony export */   "LogoRScript20": () => (/* binding */ LogoRScript20),
/* harmony export */   "LogoRScript24": () => (/* binding */ LogoRScript24),
/* harmony export */   "LogoRScript32": () => (/* binding */ LogoRScript32),
/* harmony export */   "LogoSkype16": () => (/* binding */ LogoSkype16),
/* harmony export */   "LogoSkype20": () => (/* binding */ LogoSkype20),
/* harmony export */   "LogoSkype24": () => (/* binding */ LogoSkype24),
/* harmony export */   "LogoSkype32": () => (/* binding */ LogoSkype32),
/* harmony export */   "LogoSlack16": () => (/* binding */ LogoSlack16),
/* harmony export */   "LogoSlack20": () => (/* binding */ LogoSlack20),
/* harmony export */   "LogoSlack24": () => (/* binding */ LogoSlack24),
/* harmony export */   "LogoSlack32": () => (/* binding */ LogoSlack32),
/* harmony export */   "LogoSnapchat16": () => (/* binding */ LogoSnapchat16),
/* harmony export */   "LogoSnapchat20": () => (/* binding */ LogoSnapchat20),
/* harmony export */   "LogoSnapchat24": () => (/* binding */ LogoSnapchat24),
/* harmony export */   "LogoSnapchat32": () => (/* binding */ LogoSnapchat32),
/* harmony export */   "LogoStumbleupon16": () => (/* binding */ LogoStumbleupon16),
/* harmony export */   "LogoStumbleupon20": () => (/* binding */ LogoStumbleupon20),
/* harmony export */   "LogoStumbleupon24": () => (/* binding */ LogoStumbleupon24),
/* harmony export */   "LogoStumbleupon32": () => (/* binding */ LogoStumbleupon32),
/* harmony export */   "LogoTumblr16": () => (/* binding */ LogoTumblr16),
/* harmony export */   "LogoTumblr20": () => (/* binding */ LogoTumblr20),
/* harmony export */   "LogoTumblr24": () => (/* binding */ LogoTumblr24),
/* harmony export */   "LogoTumblr32": () => (/* binding */ LogoTumblr32),
/* harmony export */   "LogoTwitter16": () => (/* binding */ LogoTwitter16),
/* harmony export */   "LogoTwitter20": () => (/* binding */ LogoTwitter20),
/* harmony export */   "LogoTwitter24": () => (/* binding */ LogoTwitter24),
/* harmony export */   "LogoTwitter32": () => (/* binding */ LogoTwitter32),
/* harmony export */   "LogoVmware16": () => (/* binding */ LogoVmware16),
/* harmony export */   "LogoVmware20": () => (/* binding */ LogoVmware20),
/* harmony export */   "LogoVmware24": () => (/* binding */ LogoVmware24),
/* harmony export */   "LogoVmware32": () => (/* binding */ LogoVmware32),
/* harmony export */   "LogoWechat16": () => (/* binding */ LogoWechat16),
/* harmony export */   "LogoWechat20": () => (/* binding */ LogoWechat20),
/* harmony export */   "LogoWechat24": () => (/* binding */ LogoWechat24),
/* harmony export */   "LogoWechat32": () => (/* binding */ LogoWechat32),
/* harmony export */   "LogoXing16": () => (/* binding */ LogoXing16),
/* harmony export */   "LogoXing20": () => (/* binding */ LogoXing20),
/* harmony export */   "LogoXing24": () => (/* binding */ LogoXing24),
/* harmony export */   "LogoXing32": () => (/* binding */ LogoXing32),
/* harmony export */   "LogoYelp16": () => (/* binding */ LogoYelp16),
/* harmony export */   "LogoYelp20": () => (/* binding */ LogoYelp20),
/* harmony export */   "LogoYelp24": () => (/* binding */ LogoYelp24),
/* harmony export */   "LogoYelp32": () => (/* binding */ LogoYelp32),
/* harmony export */   "LogoYoutube16": () => (/* binding */ LogoYoutube16),
/* harmony export */   "LogoYoutube20": () => (/* binding */ LogoYoutube20),
/* harmony export */   "LogoYoutube24": () => (/* binding */ LogoYoutube24),
/* harmony export */   "LogoYoutube32": () => (/* binding */ LogoYoutube32),
/* harmony export */   "Logout16": () => (/* binding */ Logout16),
/* harmony export */   "Logout20": () => (/* binding */ Logout20),
/* harmony export */   "Logout24": () => (/* binding */ Logout24),
/* harmony export */   "Logout32": () => (/* binding */ Logout32),
/* harmony export */   "Loop16": () => (/* binding */ Loop16),
/* harmony export */   "Loop20": () => (/* binding */ Loop20),
/* harmony export */   "Loop24": () => (/* binding */ Loop24),
/* harmony export */   "Loop32": () => (/* binding */ Loop32),
/* harmony export */   "LowSeverityGlyph": () => (/* binding */ LowSeverityGlyph),
/* harmony export */   "MacCommand16": () => (/* binding */ MacCommand16),
/* harmony export */   "MacCommand20": () => (/* binding */ MacCommand20),
/* harmony export */   "MacCommand24": () => (/* binding */ MacCommand24),
/* harmony export */   "MacCommand32": () => (/* binding */ MacCommand32),
/* harmony export */   "MacOption16": () => (/* binding */ MacOption16),
/* harmony export */   "MacOption20": () => (/* binding */ MacOption20),
/* harmony export */   "MacOption24": () => (/* binding */ MacOption24),
/* harmony export */   "MacOption32": () => (/* binding */ MacOption32),
/* harmony export */   "MacShift16": () => (/* binding */ MacShift16),
/* harmony export */   "MacShift20": () => (/* binding */ MacShift20),
/* harmony export */   "MacShift24": () => (/* binding */ MacShift24),
/* harmony export */   "MacShift32": () => (/* binding */ MacShift32),
/* harmony export */   "MachineLearning16": () => (/* binding */ MachineLearning16),
/* harmony export */   "MachineLearning20": () => (/* binding */ MachineLearning20),
/* harmony export */   "MachineLearning24": () => (/* binding */ MachineLearning24),
/* harmony export */   "MachineLearning32": () => (/* binding */ MachineLearning32),
/* harmony export */   "MachineLearningModel16": () => (/* binding */ MachineLearningModel16),
/* harmony export */   "MachineLearningModel20": () => (/* binding */ MachineLearningModel20),
/* harmony export */   "MachineLearningModel24": () => (/* binding */ MachineLearningModel24),
/* harmony export */   "MachineLearningModel32": () => (/* binding */ MachineLearningModel32),
/* harmony export */   "MagicWand24": () => (/* binding */ MagicWand24),
/* harmony export */   "MagicWand32": () => (/* binding */ MagicWand32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _circle, _path65, _circle2, _path66, _circle3, _path67, _circle4, _circle5, _path68, _path69, _circle6, _path70, _path71, _circle7, _path72, _path73, _circle8, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _circle9, _path109, _path110, _circle10, _path111, _path112, _circle11, _path113, _path114, _circle12, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _circle13, _path140, _circle14, _path141, _circle15, _path142, _circle16, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _circle17, _circle18, _circle19, _circle20, _circle21, _circle22, _circle23, _circle24, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _circle25, _path188, _path189, _circle26, _path190, _path191, _circle27, _path192, _path193, _circle28, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _path224, _path225, _path226, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var didWarnAboutDeprecation = {};
var LoadBalancerApplication24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerApplication24(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM25 16H17V14H15v2H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM9 2V12H23V2zm2 2h2v6H11zm10 6H15V4h6z"
  })), children);
});
var LoadBalancerApplication20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerApplication20(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM25 16H17V14H15v2H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM9 2V12H23V2zm2 2h2v6H11zm10 6H15V4h6z"
  })), children);
});
var LoadBalancerApplication16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerApplication16(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM25 16H17V14H15v2H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM9 2V12H23V2zm2 2h2v6H11zm10 6H15V4h6z"
  })), children);
});
var LoadBalancerClassic32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerClassic32(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM25 16H17V12H15v4H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM20 10V2H12v8zM14 8V4h4V8z"
  })), children);
});
var LoadBalancerClassic24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerClassic24(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM25 16H17V12H15v4H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM20 10V2H12v8zM14 8V4h4V8z"
  })), children);
});
var LoadBalancerClassic20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerClassic20(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM25 16H17V12H15v4H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM20 10V2H12v8zM14 8V4h4V8z"
  })), children);
});
var LoadBalancerClassic16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerClassic16(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM25 16H17V12H15v4H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM20 10V2H12v8zM14 8V4h4V8z"
  })), children);
});
var LoadBalancerGlobal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerGlobal32(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM25 16H17V12H15v4H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM16 10a4 4 0 114-4A4.0045 4.0045 0 0116 10zm0-6a2 2 0 102 2A2.0021 2.0021 0 0016 4z"
  })), children);
});
var LoadBalancerGlobal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerGlobal24(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM25 16H17V12H15v4H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM16 10a4 4 0 114-4A4.0045 4.0045 0 0116 10zm0-6a2 2 0 102 2A2.0021 2.0021 0 0016 4z"
  })), children);
});
var LoadBalancerGlobal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerGlobal20(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM25 16H17V12H15v4H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM16 10a4 4 0 114-4A4.0045 4.0045 0 0116 10zm0-6a2 2 0 102 2A2.0021 2.0021 0 0016 4z"
  })), children);
});
var LoadBalancerGlobal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerGlobal16(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM25 16H17V12H15v4H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM16 10a4 4 0 114-4A4.0045 4.0045 0 0116 10zm0-6a2 2 0 102 2A2.0021 2.0021 0 0016 4z"
  })), children);
});
var LoadBalancerListener32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerListener32(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 8H17V10H15zM19 8H21V10H19zM11 8H13V10H11zM25 16H17V13H15v3H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM11 3H21V5H11z"
  })), children);
});
var LoadBalancerListener24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerListener24(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 8H17V10H15zM19 8H21V10H19zM11 8H13V10H11zM25 16H17V13H15v3H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM11 3H21V5H11z"
  })), children);
});
var LoadBalancerListener20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerListener20(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 8H17V10H15zM19 8H21V10H19zM11 8H13V10H11zM25 16H17V13H15v3H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM11 3H21V5H11z"
  })), children);
});
var LoadBalancerListener16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerListener16(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 8H17V10H15zM19 8H21V10H19zM11 8H13V10H11zM25 16H17V13H15v3H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM11 3H21V5H11z"
  })), children);
});
var LoadBalancerLocal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerLocal32(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 16H17V10H15v6H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM11 5H21V7H11z"
  })), children);
});
var LoadBalancerLocal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerLocal24(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 16H17V10H15v6H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM11 5H21V7H11z"
  })), children);
});
var LoadBalancerLocal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerLocal20(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 16H17V10H15v6H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM11 5H21V7H11z"
  })), children);
});
var LoadBalancerLocal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerLocal16(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 16H17V10H15v6H7a2.0023 2.0023 0 00-2 2v6H7V18h8v6h2V18h8v6h2V18A2.0023 2.0023 0 0025 16zM4 26H8V30H4zM14 26H18V30H14zM24 26H28V30H24zM11 5H21V7H11z"
  })), children);
});
var LoadBalancerNetwork32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerNetwork32(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 16H17V12H15v4H7a2.0023 2.0023 0 00-2 2v4H7V18h8v4h2V18h8v4h2V18A2.0023 2.0023 0 0025 16zM20 10V2H12v8h8zM14 8V4h4V8zM26 24a2.9948 2.9948 0 00-2.8157 2H18.8157a2.982 2.982 0 00-5.6314 0H8.8157a3 3 0 100 2h4.3686a2.982 2.982 0 005.6314 0h4.3686A2.9947 2.9947 0 1026 24zM6 28a1 1 0 111-1A1.0009 1.0009 0 016 28zm10 0a1 1 0 111-1A1.0009 1.0009 0 0116 28zm10 0a1 1 0 111-1A1.0009 1.0009 0 0126 28z"
  })), children);
});
var LoadBalancerNetwork24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerNetwork24(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 16H17V12H15v4H7a2.0023 2.0023 0 00-2 2v4H7V18h8v4h2V18h8v4h2V18A2.0023 2.0023 0 0025 16zM20 10V2H12v8h8zM14 8V4h4V8zM26 24a2.9948 2.9948 0 00-2.8157 2H18.8157a2.982 2.982 0 00-5.6314 0H8.8157a3 3 0 100 2h4.3686a2.982 2.982 0 005.6314 0h4.3686A2.9947 2.9947 0 1026 24zM6 28a1 1 0 111-1A1.0009 1.0009 0 016 28zm10 0a1 1 0 111-1A1.0009 1.0009 0 0116 28zm10 0a1 1 0 111-1A1.0009 1.0009 0 0126 28z"
  })), children);
});
var LoadBalancerNetwork20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerNetwork20(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 16H17V12H15v4H7a2.0023 2.0023 0 00-2 2v4H7V18h8v4h2V18h8v4h2V18A2.0023 2.0023 0 0025 16zM20 10V2H12v8h8zM14 8V4h4V8zM26 24a2.9948 2.9948 0 00-2.8157 2H18.8157a2.982 2.982 0 00-5.6314 0H8.8157a3 3 0 100 2h4.3686a2.982 2.982 0 005.6314 0h4.3686A2.9947 2.9947 0 1026 24zM6 28a1 1 0 111-1A1.0009 1.0009 0 016 28zm10 0a1 1 0 111-1A1.0009 1.0009 0 0116 28zm10 0a1 1 0 111-1A1.0009 1.0009 0 0126 28z"
  })), children);
});
var LoadBalancerNetwork16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerNetwork16(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 16H17V12H15v4H7a2.0023 2.0023 0 00-2 2v4H7V18h8v4h2V18h8v4h2V18A2.0023 2.0023 0 0025 16zM20 10V2H12v8h8zM14 8V4h4V8zM26 24a2.9948 2.9948 0 00-2.8157 2H18.8157a2.982 2.982 0 00-5.6314 0H8.8157a3 3 0 100 2h4.3686a2.982 2.982 0 005.6314 0h4.3686A2.9947 2.9947 0 1026 24zM6 28a1 1 0 111-1A1.0009 1.0009 0 016 28zm10 0a1 1 0 111-1A1.0009 1.0009 0 0116 28zm10 0a1 1 0 111-1A1.0009 1.0009 0 0126 28z"
  })), children);
});
var LoadBalancerPool32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerPool32(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 15H22V17H10zM8.7 6.2852A2.9665 2.9665 0 009 5 3 3 0 106 8a2.96 2.96 0 001.2852-.3008L10 10.4141V13h2V9.5859zM6 6A1 1 0 117 5 1.0009 1.0009 0 016 6zM19 5a3 3 0 10-4 2.8154V13h2V7.8159A2.9957 2.9957 0 0019 5zM16 6a1 1 0 111-1A1.0009 1.0009 0 0116 6zM26 2a3.0033 3.0033 0 00-3 3 2.9665 2.9665 0 00.3 1.2852L20 9.5859V13h2V10.4141l2.7148-2.7149A2.96 2.96 0 0026 8a3 3 0 000-6zm0 4a1 1 0 111-1A1.0009 1.0009 0 0126 6zM12 19H10v2.5859L7.2854 24.3008A2.9609 2.9609 0 006 24a3 3 0 103 3 2.9665 2.9665 0 00-.3-1.2852L12 22.4141zM6 28a1 1 0 111-1A1.0009 1.0009 0 016 28zM17 24.1841V19H15v5.1841a3 3 0 102 0zM16 28a1 1 0 111-1A1.0009 1.0009 0 0116 28zM26 24a2.9609 2.9609 0 00-1.2854.3008L22 21.5859V19H20v3.4141l3.3 3.3007A2.9665 2.9665 0 0023 27a3 3 0 103-3zm0 4a1 1 0 111-1A1.0009 1.0009 0 0126 28z"
  })), children);
});
var LoadBalancerPool24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerPool24(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 15H22V17H10zM8.7 6.2852A2.9665 2.9665 0 009 5 3 3 0 106 8a2.96 2.96 0 001.2852-.3008L10 10.4141V13h2V9.5859zM6 6A1 1 0 117 5 1.0009 1.0009 0 016 6zM19 5a3 3 0 10-4 2.8154V13h2V7.8159A2.9957 2.9957 0 0019 5zM16 6a1 1 0 111-1A1.0009 1.0009 0 0116 6zM26 2a3.0033 3.0033 0 00-3 3 2.9665 2.9665 0 00.3 1.2852L20 9.5859V13h2V10.4141l2.7148-2.7149A2.96 2.96 0 0026 8a3 3 0 000-6zm0 4a1 1 0 111-1A1.0009 1.0009 0 0126 6zM12 19H10v2.5859L7.2854 24.3008A2.9609 2.9609 0 006 24a3 3 0 103 3 2.9665 2.9665 0 00-.3-1.2852L12 22.4141zM6 28a1 1 0 111-1A1.0009 1.0009 0 016 28zM17 24.1841V19H15v5.1841a3 3 0 102 0zM16 28a1 1 0 111-1A1.0009 1.0009 0 0116 28zM26 24a2.9609 2.9609 0 00-1.2854.3008L22 21.5859V19H20v3.4141l3.3 3.3007A2.9665 2.9665 0 0023 27a3 3 0 103-3zm0 4a1 1 0 111-1A1.0009 1.0009 0 0126 28z"
  })), children);
});
var LoadBalancerPool20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerPool20(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 15H22V17H10zM8.7 6.2852A2.9665 2.9665 0 009 5 3 3 0 106 8a2.96 2.96 0 001.2852-.3008L10 10.4141V13h2V9.5859zM6 6A1 1 0 117 5 1.0009 1.0009 0 016 6zM19 5a3 3 0 10-4 2.8154V13h2V7.8159A2.9957 2.9957 0 0019 5zM16 6a1 1 0 111-1A1.0009 1.0009 0 0116 6zM26 2a3.0033 3.0033 0 00-3 3 2.9665 2.9665 0 00.3 1.2852L20 9.5859V13h2V10.4141l2.7148-2.7149A2.96 2.96 0 0026 8a3 3 0 000-6zm0 4a1 1 0 111-1A1.0009 1.0009 0 0126 6zM12 19H10v2.5859L7.2854 24.3008A2.9609 2.9609 0 006 24a3 3 0 103 3 2.9665 2.9665 0 00-.3-1.2852L12 22.4141zM6 28a1 1 0 111-1A1.0009 1.0009 0 016 28zM17 24.1841V19H15v5.1841a3 3 0 102 0zM16 28a1 1 0 111-1A1.0009 1.0009 0 0116 28zM26 24a2.9609 2.9609 0 00-1.2854.3008L22 21.5859V19H20v3.4141l3.3 3.3007A2.9665 2.9665 0 0023 27a3 3 0 103-3zm0 4a1 1 0 111-1A1.0009 1.0009 0 0126 28z"
  })), children);
});
var LoadBalancerPool16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerPool16(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 15H22V17H10zM8.7 6.2852A2.9665 2.9665 0 009 5 3 3 0 106 8a2.96 2.96 0 001.2852-.3008L10 10.4141V13h2V9.5859zM6 6A1 1 0 117 5 1.0009 1.0009 0 016 6zM19 5a3 3 0 10-4 2.8154V13h2V7.8159A2.9957 2.9957 0 0019 5zM16 6a1 1 0 111-1A1.0009 1.0009 0 0116 6zM26 2a3.0033 3.0033 0 00-3 3 2.9665 2.9665 0 00.3 1.2852L20 9.5859V13h2V10.4141l2.7148-2.7149A2.96 2.96 0 0026 8a3 3 0 000-6zm0 4a1 1 0 111-1A1.0009 1.0009 0 0126 6zM12 19H10v2.5859L7.2854 24.3008A2.9609 2.9609 0 006 24a3 3 0 103 3 2.9665 2.9665 0 00-.3-1.2852L12 22.4141zM6 28a1 1 0 111-1A1.0009 1.0009 0 016 28zM17 24.1841V19H15v5.1841a3 3 0 102 0zM16 28a1 1 0 111-1A1.0009 1.0009 0 0116 28zM26 24a2.9609 2.9609 0 00-1.2854.3008L22 21.5859V19H20v3.4141l3.3 3.3007A2.9665 2.9665 0 0023 27a3 3 0 103-3zm0 4a1 1 0 111-1A1.0009 1.0009 0 0126 28z"
  })), children);
});
var LoadBalancerVpc32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerVpc32(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30H2V24H8zM4 28H6V26H4zM19 30H13V24h6zm-4-2h2V26H15zM30 30H24V24h6zm-4-2h2V26H26zM16 10a4 4 0 114-4A4.0045 4.0045 0 0116 10zm0-6a2 2 0 102 2A2.002 2.002 0 0016 4zM26 16H21a4.0045 4.0045 0 01-4-4H15a4.0045 4.0045 0 01-4 4H6a2.0023 2.0023 0 00-2 2v4H6V18h5A5.9694 5.9694 0 0015 16.46V22h2V16.46A5.9694 5.9694 0 0021 18h5v4h2V18A2.0023 2.0023 0 0026 16z"
  })), children);
});
var LoadBalancerVpc24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerVpc24(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30H2V24H8zM4 28H6V26H4zM19 30H13V24h6zm-4-2h2V26H15zM30 30H24V24h6zm-4-2h2V26H26zM16 10a4 4 0 114-4A4.0045 4.0045 0 0116 10zm0-6a2 2 0 102 2A2.002 2.002 0 0016 4zM26 16H21a4.0045 4.0045 0 01-4-4H15a4.0045 4.0045 0 01-4 4H6a2.0023 2.0023 0 00-2 2v4H6V18h5A5.9694 5.9694 0 0015 16.46V22h2V16.46A5.9694 5.9694 0 0021 18h5v4h2V18A2.0023 2.0023 0 0026 16z"
  })), children);
});
var LoadBalancerVpc20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerVpc20(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30H2V24H8zM4 28H6V26H4zM19 30H13V24h6zm-4-2h2V26H15zM30 30H24V24h6zm-4-2h2V26H26zM16 10a4 4 0 114-4A4.0045 4.0045 0 0116 10zm0-6a2 2 0 102 2A2.002 2.002 0 0016 4zM26 16H21a4.0045 4.0045 0 01-4-4H15a4.0045 4.0045 0 01-4 4H6a2.0023 2.0023 0 00-2 2v4H6V18h5A5.9694 5.9694 0 0015 16.46V22h2V16.46A5.9694 5.9694 0 0021 18h5v4h2V18A2.0023 2.0023 0 0026 16z"
  })), children);
});
var LoadBalancerVpc16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LoadBalancerVpc16(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30H2V24H8zM4 28H6V26H4zM19 30H13V24h6zm-4-2h2V26H15zM30 30H24V24h6zm-4-2h2V26H26zM16 10a4 4 0 114-4A4.0045 4.0045 0 0116 10zm0-6a2 2 0 102 2A2.002 2.002 0 0016 4zM26 16H21a4.0045 4.0045 0 01-4-4H15a4.0045 4.0045 0 01-4 4H6a2.0023 2.0023 0 00-2 2v4H6V18h5A5.9694 5.9694 0 0015 16.46V22h2V16.46A5.9694 5.9694 0 0021 18h5v4h2V18A2.0023 2.0023 0 0026 16z"
  })), children);
});
var Location32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Location32(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,18a5,5,0,1,1,5-5A5.0057,5.0057,0,0,1,16,18Zm0-8a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,16,10Z"
  })), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,1,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var Location24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Location24(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,18a5,5,0,1,1,5-5A5.0057,5.0057,0,0,1,16,18Zm0-8a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,16,10Z"
  })), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,1,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var Location20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Location20(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,18a5,5,0,1,1,5-5A5.0057,5.0057,0,0,1,16,18Zm0-8a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,16,10Z"
  })), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,1,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var Location16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Location16(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,18a5,5,0,1,1,5-5A5.0057,5.0057,0,0,1,16,18Zm0-8a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,16,10Z"
  })), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,1,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var LocationCompany32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationCompany32(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,18H19V10H13v8H11V10a2.0021,2.0021,0,0,1,2-2h6a2.0021,2.0021,0,0,1,2,2Z"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 16H17V18H15zM15 12H17V14H15z"
  })), children);
});
var LocationCompany24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationCompany24(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,18H19V10H13v8H11V10a2.0021,2.0021,0,0,1,2-2h6a2.0021,2.0021,0,0,1,2,2Z"
  })), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 16H17V18H15zM15 12H17V14H15z"
  })), children);
});
var LocationCompany20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationCompany20(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,18H19V10H13v8H11V10a2.0021,2.0021,0,0,1,2-2h6a2.0021,2.0021,0,0,1,2,2Z"
  })), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 16H17V18H15zM15 12H17V14H15z"
  })), children);
});
var LocationCompany16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationCompany16(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,18H19V10H13v8H11V10a2.0021,2.0021,0,0,1,2-2h6a2.0021,2.0021,0,0,1,2,2Z"
  })), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 16H17V18H15zM15 12H17V14H15z"
  })), children);
});
var LocationCompanyFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationCompanyFilled32(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M21,18H19V10H13v8H11V10a2.0021,2.0021,0,0,1,2-2h6a2.0021,2.0021,0,0,1,2,2Zm-4-2H15v2h2Zm0-4H15v2h2Z"
  })), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm1,16H15V16h2Zm0-4H15V12h2Zm4,4H19V10H13v8H11V10a2.0023,2.0023,0,0,1,2-2h6a2.0023,2.0023,0,0,1,2,2Z"
  })), children);
});
var LocationCompanyFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationCompanyFilled24(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M21,18H19V10H13v8H11V10a2.0021,2.0021,0,0,1,2-2h6a2.0021,2.0021,0,0,1,2,2Zm-4-2H15v2h2Zm0-4H15v2h2Z"
  })), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm1,16H15V16h2Zm0-4H15V12h2Zm4,4H19V10H13v8H11V10a2.0023,2.0023,0,0,1,2-2h6a2.0023,2.0023,0,0,1,2,2Z"
  })), children);
});
var LocationCompanyFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationCompanyFilled20(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M21,18H19V10H13v8H11V10a2.0021,2.0021,0,0,1,2-2h6a2.0021,2.0021,0,0,1,2,2Zm-4-2H15v2h2Zm0-4H15v2h2Z"
  })), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm1,16H15V16h2Zm0-4H15V12h2Zm4,4H19V10H13v8H11V10a2.0023,2.0023,0,0,1,2-2h6a2.0023,2.0023,0,0,1,2,2Z"
  })), children);
});
var LocationCompanyFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationCompanyFilled16(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M21,18H19V10H13v8H11V10a2.0021,2.0021,0,0,1,2-2h6a2.0021,2.0021,0,0,1,2,2Zm-4-2H15v2h2Zm0-4H15v2h2Z"
  })), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm1,16H15V16h2Zm0-4H15V12h2Zm4,4H19V10H13v8H11V10a2.0023,2.0023,0,0,1,2-2h6a2.0023,2.0023,0,0,1,2,2Z"
  })), children);
});
var LocationCurrent32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationCurrent32(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,12.9835a1,1,0,0,0,.6289.9448l9.6015,3.8409,3.8407,9.6019A1,1,0,0,0,19,28h.0162a1.0009,1.0009,0,0,0,.9238-.6582l8-22.0007A1,1,0,0,0,26.658,4.0594l-22,8A1.0011,1.0011,0,0,0,4,12.9835Z"
  })), children);
});
var LocationCurrent24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationCurrent24(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,12.9835a1,1,0,0,0,.6289.9448l9.6015,3.8409,3.8407,9.6019A1,1,0,0,0,19,28h.0162a1.0009,1.0009,0,0,0,.9238-.6582l8-22.0007A1,1,0,0,0,26.658,4.0594l-22,8A1.0011,1.0011,0,0,0,4,12.9835Z"
  })), children);
});
var LocationCurrent20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationCurrent20(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,12.9835a1,1,0,0,0,.6289.9448l9.6015,3.8409,3.8407,9.6019A1,1,0,0,0,19,28h.0162a1.0009,1.0009,0,0,0,.9238-.6582l8-22.0007A1,1,0,0,0,26.658,4.0594l-22,8A1.0011,1.0011,0,0,0,4,12.9835Z"
  })), children);
});
var LocationCurrent16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationCurrent16(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,12.9835a1,1,0,0,0,.6289.9448l9.6015,3.8409,3.8407,9.6019A1,1,0,0,0,19,28h.0162a1.0009,1.0009,0,0,0,.9238-.6582l8-22.0007A1,1,0,0,0,26.658,4.0594l-22,8A1.0011,1.0011,0,0,0,4,12.9835Z"
  })), children);
});
var LocationFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationFilled32(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm0,15a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,17Z"
  })), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "13",
    r: "4",
    fill: "none"
  })), children);
});
var LocationFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationFilled24(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm0,15a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,17Z"
  })), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "13",
    r: "4",
    fill: "none"
  })), children);
});
var LocationFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationFilled20(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm0,15a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,17Z"
  })), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "13",
    r: "4",
    fill: "none"
  })), children);
});
var LocationFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationFilled16(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm0,15a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,17Z"
  })), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "13",
    r: "4",
    fill: "none"
  })), children);
});
var LocationHazard32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationHazard32(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "20.5",
    r: "1.5"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 7H17V16H15z"
  })), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var LocationHazard24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationHazard24(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "20.5",
    r: "1.5"
  })), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 7H17V16H15z"
  })), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var LocationHazard20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationHazard20(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "20.5",
    r: "1.5"
  })), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 7H17V16H15z"
  })), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var LocationHazard16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationHazard16(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "20.5",
    r: "1.5"
  })), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 7H17V16H15z"
  })), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var LocationHazardFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationHazardFilled32(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,22a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,22Zm-1.125-6h2.25V7h-2.25Z"
  })), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2ZM14.875,7h2.25v9h-2.25ZM16,22a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,22Z"
  })), children);
});
var LocationHazardFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationHazardFilled24(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,22a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,22Zm-1.125-6h2.25V7h-2.25Z"
  })), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2ZM14.875,7h2.25v9h-2.25ZM16,22a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,22Z"
  })), children);
});
var LocationHazardFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationHazardFilled20(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,22a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,22Zm-1.125-6h2.25V7h-2.25Z"
  })), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2ZM14.875,7h2.25v9h-2.25ZM16,22a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,22Z"
  })), children);
});
var LocationHazardFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationHazardFilled16(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,22a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,22Zm-1.125-6h2.25V7h-2.25Z"
  })), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2ZM14.875,7h2.25v9h-2.25ZM16,22a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,22Z"
  })), children);
});
var LocationHeart32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationHeart32(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.303,9a2.6616,2.6616,0,0,0-1.9079.8058l-.3932.4054-.397-.4054a2.6615,2.6615,0,0,0-3.8157,0,2.7992,2.7992,0,0,0,0,3.8964L16.0019,18l4.2089-4.2978a2.7992,2.7992,0,0,0,0-3.8964A2.6616,2.6616,0,0,0,18.303,9Z"
  })), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var LocationHeart24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationHeart24(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.303,9a2.6616,2.6616,0,0,0-1.9079.8058l-.3932.4054-.397-.4054a2.6615,2.6615,0,0,0-3.8157,0,2.7992,2.7992,0,0,0,0,3.8964L16.0019,18l4.2089-4.2978a2.7992,2.7992,0,0,0,0-3.8964A2.6616,2.6616,0,0,0,18.303,9Z"
  })), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var LocationHeart20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationHeart20(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.303,9a2.6616,2.6616,0,0,0-1.9079.8058l-.3932.4054-.397-.4054a2.6615,2.6615,0,0,0-3.8157,0,2.7992,2.7992,0,0,0,0,3.8964L16.0019,18l4.2089-4.2978a2.7992,2.7992,0,0,0,0-3.8964A2.6616,2.6616,0,0,0,18.303,9Z"
  })), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var LocationHeart16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationHeart16(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.303,9a2.6616,2.6616,0,0,0-1.9079.8058l-.3932.4054-.397-.4054a2.6615,2.6615,0,0,0-3.8157,0,2.7992,2.7992,0,0,0,0,3.8964L16.0019,18l4.2089-4.2978a2.7992,2.7992,0,0,0,0-3.8964A2.6616,2.6616,0,0,0,18.303,9Z"
  })), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var LocationHeartFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationHeartFilled32(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M18.303,9a2.6616,2.6616,0,0,0-1.9079.8058l-.3932.4054-.397-.4054a2.6615,2.6615,0,0,0-3.8157,0,2.7992,2.7992,0,0,0,0,3.8964L16.0019,18l4.2089-4.2978a2.7992,2.7992,0,0,0,0-3.8964A2.6616,2.6616,0,0,0,18.303,9Z"
  })), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm4.2109,11.7021L16.002,18l-4.2129-4.2979a2.7992,2.7992,0,0,1,0-3.8964,2.6619,2.6619,0,0,1,3.8159,0l.397.4057.393-.4057a2.6619,2.6619,0,0,1,3.8159,0A2.7992,2.7992,0,0,1,20.2109,13.7021Z"
  })), children);
});
var LocationHeartFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationHeartFilled24(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M18.303,9a2.6616,2.6616,0,0,0-1.9079.8058l-.3932.4054-.397-.4054a2.6615,2.6615,0,0,0-3.8157,0,2.7992,2.7992,0,0,0,0,3.8964L16.0019,18l4.2089-4.2978a2.7992,2.7992,0,0,0,0-3.8964A2.6616,2.6616,0,0,0,18.303,9Z"
  })), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm4.2109,11.7021L16.002,18l-4.2129-4.2979a2.7992,2.7992,0,0,1,0-3.8964,2.6619,2.6619,0,0,1,3.8159,0l.397.4057.393-.4057a2.6619,2.6619,0,0,1,3.8159,0A2.7992,2.7992,0,0,1,20.2109,13.7021Z"
  })), children);
});
var LocationHeartFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationHeartFilled20(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M18.303,9a2.6616,2.6616,0,0,0-1.9079.8058l-.3932.4054-.397-.4054a2.6615,2.6615,0,0,0-3.8157,0,2.7992,2.7992,0,0,0,0,3.8964L16.0019,18l4.2089-4.2978a2.7992,2.7992,0,0,0,0-3.8964A2.6616,2.6616,0,0,0,18.303,9Z"
  })), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm4.2109,11.7021L16.002,18l-4.2129-4.2979a2.7992,2.7992,0,0,1,0-3.8964,2.6619,2.6619,0,0,1,3.8159,0l.397.4057.393-.4057a2.6619,2.6619,0,0,1,3.8159,0A2.7992,2.7992,0,0,1,20.2109,13.7021Z"
  })), children);
});
var LocationHeartFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationHeartFilled16(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M18.303,9a2.6616,2.6616,0,0,0-1.9079.8058l-.3932.4054-.397-.4054a2.6615,2.6615,0,0,0-3.8157,0,2.7992,2.7992,0,0,0,0,3.8964L16.0019,18l4.2089-4.2978a2.7992,2.7992,0,0,0,0-3.8964A2.6616,2.6616,0,0,0,18.303,9Z"
  })), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm4.2109,11.7021L16.002,18l-4.2129-4.2979a2.7992,2.7992,0,0,1,0-3.8964,2.6619,2.6619,0,0,1,3.8159,0l.397.4057.393-.4057a2.6619,2.6619,0,0,1,3.8159,0A2.7992,2.7992,0,0,1,20.2109,13.7021Z"
  })), children);
});
var LocationPerson32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationPerson32(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 19H18V17H14v2H12V17a2.0021 2.0021 0 012-2h4a2.0021 2.0021 0 012 2zM16 14a3 3 0 113-3A3.0033 3.0033 0 0116 14zm0-4a1 1 0 101 1A1.0011 1.0011 0 0016 10z"
  })), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var LocationPerson24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationPerson24(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 19H18V17H14v2H12V17a2.0021 2.0021 0 012-2h4a2.0021 2.0021 0 012 2zM16 14a3 3 0 113-3A3.0033 3.0033 0 0116 14zm0-4a1 1 0 101 1A1.0011 1.0011 0 0016 10z"
  })), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var LocationPerson20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationPerson20(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 19H18V17H14v2H12V17a2.0021 2.0021 0 012-2h4a2.0021 2.0021 0 012 2zM16 14a3 3 0 113-3A3.0033 3.0033 0 0116 14zm0-4a1 1 0 101 1A1.0011 1.0011 0 0016 10z"
  })), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var LocationPerson16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationPerson16(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 19H18V17H14v2H12V17a2.0021 2.0021 0 012-2h4a2.0021 2.0021 0 012 2zM16 14a3 3 0 113-3A3.0033 3.0033 0 0116 14zm0-4a1 1 0 101 1A1.0011 1.0011 0 0016 10z"
  })), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var LocationPersonFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationPersonFilled32(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M20,19H18V17H14v2H12V17a2.0021,2.0021,0,0,1,2-2h4a2.0021,2.0021,0,0,1,2,2Zm-1-8a3,3,0,1,0-3,3A3.0033,3.0033,0,0,0,19,11Zm-2,0a1,1,0,1,1-1-1A1.0011,1.0011,0,0,1,17,11Z"
  })), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "11",
    r: "1"
  })), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm0,6a3,3,0,1,1-3,3A3.0033,3.0033,0,0,1,16,8Zm4,11H18V17H14v2H12V17a2.0023,2.0023,0,0,1,2-2h4a2.0023,2.0023,0,0,1,2,2Z"
  })), children);
});
var LocationPersonFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationPersonFilled24(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M20,19H18V17H14v2H12V17a2.0021,2.0021,0,0,1,2-2h4a2.0021,2.0021,0,0,1,2,2Zm-1-8a3,3,0,1,0-3,3A3.0033,3.0033,0,0,0,19,11Zm-2,0a1,1,0,1,1-1-1A1.0011,1.0011,0,0,1,17,11Z"
  })), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "11",
    r: "1"
  })), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm0,6a3,3,0,1,1-3,3A3.0033,3.0033,0,0,1,16,8Zm4,11H18V17H14v2H12V17a2.0023,2.0023,0,0,1,2-2h4a2.0023,2.0023,0,0,1,2,2Z"
  })), children);
});
var LocationPersonFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationPersonFilled20(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M20,19H18V17H14v2H12V17a2.0021,2.0021,0,0,1,2-2h4a2.0021,2.0021,0,0,1,2,2Zm-1-8a3,3,0,1,0-3,3A3.0033,3.0033,0,0,0,19,11Zm-2,0a1,1,0,1,1-1-1A1.0011,1.0011,0,0,1,17,11Z"
  })), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "11",
    r: "1"
  })), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm0,6a3,3,0,1,1-3,3A3.0033,3.0033,0,0,1,16,8Zm4,11H18V17H14v2H12V17a2.0023,2.0023,0,0,1,2-2h4a2.0023,2.0023,0,0,1,2,2Z"
  })), children);
});
var LocationPersonFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationPersonFilled16(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M20,19H18V17H14v2H12V17a2.0021,2.0021,0,0,1,2-2h4a2.0021,2.0021,0,0,1,2,2Zm-1-8a3,3,0,1,0-3,3A3.0033,3.0033,0,0,0,19,11Zm-2,0a1,1,0,1,1-1-1A1.0011,1.0011,0,0,1,17,11Z"
  })), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "11",
    r: "1"
  })), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm0,6a3,3,0,1,1-3,3A3.0033,3.0033,0,0,1,16,8Zm4,11H18V17H14v2H12V17a2.0023,2.0023,0,0,1,2-2h4a2.0023,2.0023,0,0,1,2,2Z"
  })), children);
});
var LocationSave32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationSave32(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 30h2V28a1.0009 1.0009 0 011-1h6a1.0009 1.0009 0 011 1v2h2V28a3.0033 3.0033 0 00-3-3H21a3.0033 3.0033 0 00-3 3zM24 24a4 4 0 114-4A4.0042 4.0042 0 0124 24zm0-6a2 2 0 102 2A2.0023 2.0023 0 0024 18zM25.3418 10.06l-22-8A1 1 0 002.06 3.3415l8 22A1.001 1.001 0 0010.9839 26H11a1 1 0 00.9287-.6289L15.77 15.7692l9.6016-3.8408a1 1 0 00-.0293-1.8687zM14.6284 14.0709v0l-.3979.1591-.1591.3979 0 0-3.0269 7.5678L4.6719 4.6715l17.5244 6.3726z"
  })), children);
});
var LocationSave24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationSave24(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 30h2V28a1.0009 1.0009 0 011-1h6a1.0009 1.0009 0 011 1v2h2V28a3.0033 3.0033 0 00-3-3H21a3.0033 3.0033 0 00-3 3zM24 24a4 4 0 114-4A4.0042 4.0042 0 0124 24zm0-6a2 2 0 102 2A2.0023 2.0023 0 0024 18zM25.3418 10.06l-22-8A1 1 0 002.06 3.3415l8 22A1.001 1.001 0 0010.9839 26H11a1 1 0 00.9287-.6289L15.77 15.7692l9.6016-3.8408a1 1 0 00-.0293-1.8687zM14.6284 14.0709v0l-.3979.1591-.1591.3979 0 0-3.0269 7.5678L4.6719 4.6715l17.5244 6.3726z"
  })), children);
});
var LocationSave20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationSave20(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 30h2V28a1.0009 1.0009 0 011-1h6a1.0009 1.0009 0 011 1v2h2V28a3.0033 3.0033 0 00-3-3H21a3.0033 3.0033 0 00-3 3zM24 24a4 4 0 114-4A4.0042 4.0042 0 0124 24zm0-6a2 2 0 102 2A2.0023 2.0023 0 0024 18zM25.3418 10.06l-22-8A1 1 0 002.06 3.3415l8 22A1.001 1.001 0 0010.9839 26H11a1 1 0 00.9287-.6289L15.77 15.7692l9.6016-3.8408a1 1 0 00-.0293-1.8687zM14.6284 14.0709v0l-.3979.1591-.1591.3979 0 0-3.0269 7.5678L4.6719 4.6715l17.5244 6.3726z"
  })), children);
});
var LocationSave16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationSave16(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 30h2V28a1.0009 1.0009 0 011-1h6a1.0009 1.0009 0 011 1v2h2V28a3.0033 3.0033 0 00-3-3H21a3.0033 3.0033 0 00-3 3zM24 24a4 4 0 114-4A4.0042 4.0042 0 0124 24zm0-6a2 2 0 102 2A2.0023 2.0023 0 0024 18zM25.3418 10.06l-22-8A1 1 0 002.06 3.3415l8 22A1.001 1.001 0 0010.9839 26H11a1 1 0 00.9287-.6289L15.77 15.7692l9.6016-3.8408a1 1 0 00-.0293-1.8687zM14.6284 14.0709v0l-.3979.1591-.1591.3979 0 0-3.0269 7.5678L4.6719 4.6715l17.5244 6.3726z"
  })), children);
});
var LocationStar32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationStar32(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 7L17.912 10.667 22 11.173 19 13.926 19.6 18 16 15.708 12.4 18 13 13.926 10 11.173 14.2 10.667 16 7z"
  })), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var LocationStar24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationStar24(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 7L17.912 10.667 22 11.173 19 13.926 19.6 18 16 15.708 12.4 18 13 13.926 10 11.173 14.2 10.667 16 7z"
  })), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var LocationStar20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationStar20(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 7L17.912 10.667 22 11.173 19 13.926 19.6 18 16 15.708 12.4 18 13 13.926 10 11.173 14.2 10.667 16 7z"
  })), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var LocationStar16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationStar16(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 7L17.912 10.667 22 11.173 19 13.926 19.6 18 16 15.708 12.4 18 13 13.926 10 11.173 14.2 10.667 16 7z"
  })), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var LocationStarFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationStarFilled32(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16 7L17.912 10.667 22 11.173 19 13.926 19.6 18 16 15.708 12.4 18 13 13.926 10 11.173 14.2 10.667 16 7z"
  })), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm3.6,16L16,15.7085,12.4,18l.6-4.0742-3-2.7529,4.2-.5064L16,7l1.9116,3.6665L22,11.1729l-3,2.7529Z"
  })), children);
});
var LocationStarFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationStarFilled24(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16 7L17.912 10.667 22 11.173 19 13.926 19.6 18 16 15.708 12.4 18 13 13.926 10 11.173 14.2 10.667 16 7z"
  })), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm3.6,16L16,15.7085,12.4,18l.6-4.0742-3-2.7529,4.2-.5064L16,7l1.9116,3.6665L22,11.1729l-3,2.7529Z"
  })), children);
});
var LocationStarFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationStarFilled20(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16 7L17.912 10.667 22 11.173 19 13.926 19.6 18 16 15.708 12.4 18 13 13.926 10 11.173 14.2 10.667 16 7z"
  })), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm3.6,16L16,15.7085,12.4,18l.6-4.0742-3-2.7529,4.2-.5064L16,7l1.9116,3.6665L22,11.1729l-3,2.7529Z"
  })), children);
});
var LocationStarFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LocationStarFilled16(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16 7L17.912 10.667 22 11.173 19 13.926 19.6 18 16 15.708 12.4 18 13 13.926 10 11.173 14.2 10.667 16 7z"
  })), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm3.6,16L16,15.7085,12.4,18l.6-4.0742-3-2.7529,4.2-.5064L16,7l1.9116,3.6665L22,11.1729l-3,2.7529Z"
  })), children);
});
var Locked32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Locked32(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,14H22V8A6,6,0,0,0,10,8v6H8a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V16A2,2,0,0,0,24,14ZM12,8a4,4,0,0,1,8,0v6H12ZM24,28H8V16H24Z"
  })), children);
});
var Locked24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Locked24(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,14H22V8A6,6,0,0,0,10,8v6H8a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V16A2,2,0,0,0,24,14ZM12,8a4,4,0,0,1,8,0v6H12ZM24,28H8V16H24Z"
  })), children);
});
var Locked20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Locked20(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,14H22V8A6,6,0,0,0,10,8v6H8a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V16A2,2,0,0,0,24,14ZM12,8a4,4,0,0,1,8,0v6H12ZM24,28H8V16H24Z"
  })), children);
});
var Locked16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Locked16(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,14H22V8A6,6,0,0,0,10,8v6H8a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V16A2,2,0,0,0,24,14ZM12,8a4,4,0,0,1,8,0v6H12ZM24,28H8V16H24Z"
  })), children);
});
var LogicalPartition32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogicalPartition32(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "7",
    r: "1"
  })), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22V18a2,2,0,0,0-2-2H17V12h9a2,2,0,0,0,2-2V4a2,2,0,0,0-2-2H6A2,2,0,0,0,4,4v6a2,2,0,0,0,2,2h9v4H7a2,2,0,0,0-2,2v4H2v8h8V22H7V18h8v4H12v8h8V22H17V18h8v4H22v8h8V22ZM8,28H4V24H8Zm10-4v4H14V24ZM6,10V4H26v6ZM28,28H24V24h4Z"
  })), children);
});
var LogicalPartition24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogicalPartition24(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "7",
    r: "1"
  })), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22V18a2,2,0,0,0-2-2H17V12h9a2,2,0,0,0,2-2V4a2,2,0,0,0-2-2H6A2,2,0,0,0,4,4v6a2,2,0,0,0,2,2h9v4H7a2,2,0,0,0-2,2v4H2v8h8V22H7V18h8v4H12v8h8V22H17V18h8v4H22v8h8V22ZM8,28H4V24H8Zm10-4v4H14V24ZM6,10V4H26v6ZM28,28H24V24h4Z"
  })), children);
});
var LogicalPartition20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogicalPartition20(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "7",
    r: "1"
  })), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22V18a2,2,0,0,0-2-2H17V12h9a2,2,0,0,0,2-2V4a2,2,0,0,0-2-2H6A2,2,0,0,0,4,4v6a2,2,0,0,0,2,2h9v4H7a2,2,0,0,0-2,2v4H2v8h8V22H7V18h8v4H12v8h8V22H17V18h8v4H22v8h8V22ZM8,28H4V24H8Zm10-4v4H14V24ZM6,10V4H26v6ZM28,28H24V24h4Z"
  })), children);
});
var LogicalPartition16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogicalPartition16(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "7",
    r: "1"
  })), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22V18a2,2,0,0,0-2-2H17V12h9a2,2,0,0,0,2-2V4a2,2,0,0,0-2-2H6A2,2,0,0,0,4,4v6a2,2,0,0,0,2,2h9v4H7a2,2,0,0,0-2,2v4H2v8h8V22H7V18h8v4H12v8h8V22H17V18h8v4H22v8h8V22ZM8,28H4V24H8Zm10-4v4H14V24ZM6,10V4H26v6ZM28,28H24V24h4Z"
  })), children);
});
var Login32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Login32(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H14a2,2,0,0,1-2-2V25h2v3H26V4H14V7H12V4a2,2,0,0,1,2-2H26a2,2,0,0,1,2,2V28A2,2,0,0,1,26,30Z"
  })), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.59 20.59L18.17 17 4 17 4 15 18.17 15 14.59 11.41 16 10 22 16 16 22 14.59 20.59z"
  })), children);
});
var Login24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Login24(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H14a2,2,0,0,1-2-2V25h2v3H26V4H14V7H12V4a2,2,0,0,1,2-2H26a2,2,0,0,1,2,2V28A2,2,0,0,1,26,30Z"
  })), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.59 20.59L18.17 17 4 17 4 15 18.17 15 14.59 11.41 16 10 22 16 16 22 14.59 20.59z"
  })), children);
});
var Login20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Login20(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H14a2,2,0,0,1-2-2V25h2v3H26V4H14V7H12V4a2,2,0,0,1,2-2H26a2,2,0,0,1,2,2V28A2,2,0,0,1,26,30Z"
  })), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.59 20.59L18.17 17 4 17 4 15 18.17 15 14.59 11.41 16 10 22 16 16 22 14.59 20.59z"
  })), children);
});
var Login16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Login16(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H14a2,2,0,0,1-2-2V25h2v3H26V4H14V7H12V4a2,2,0,0,1,2-2H26a2,2,0,0,1,2,2V28A2,2,0,0,1,26,30Z"
  })), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.59 20.59L18.17 17 4 17 4 15 18.17 15 14.59 11.41 16 10 22 16 16 22 14.59 20.59z"
  })), children);
});
var LogoDelicious32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoDelicious32(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  if (true) {
    if (!didWarnAboutDeprecation['LogoDelicious32']) {
      didWarnAboutDeprecation['LogoDelicious32'] = true;
      console.warn("The LogoDelicious32 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 16H16V28H4zM16 4H28V16H16z"
  })), children);
});
var LogoDelicious24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoDelicious24(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  if (true) {
    if (!didWarnAboutDeprecation['LogoDelicious24']) {
      didWarnAboutDeprecation['LogoDelicious24'] = true;
      console.warn("The LogoDelicious24 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 16H16V28H4zM16 4H28V16H16z"
  })), children);
});
var LogoDelicious20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoDelicious20(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  if (true) {
    if (!didWarnAboutDeprecation['LogoDelicious20']) {
      didWarnAboutDeprecation['LogoDelicious20'] = true;
      console.warn("The LogoDelicious20 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 16H16V28H4zM16 4H28V16H16z"
  })), children);
});
var LogoDelicious16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoDelicious16(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  if (true) {
    if (!didWarnAboutDeprecation['LogoDelicious16']) {
      didWarnAboutDeprecation['LogoDelicious16'] = true;
      console.warn("The LogoDelicious16 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 16H16V28H4zM16 4H28V16H16z"
  })), children);
});
var LogoDigg32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoDigg32(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.48 7.6v3.92H2V21H9.28V7.6zm0 11.2H4.8v-5H6.48zM10.4 11.52H13.2V21.04H10.4zM10.4 7.6H13.2V10.399999999999999H10.4zM14.32 11.52V21H18.8v1.12H14.32V24.4H21.6V11.52zM18.8 18.8H17.12v-5H18.8zM22.72 11.52V21H27.2v1.12H22.72V24.4H30V11.52zM27.2 18.8H25.52v-5H27.2z"
  })), children);
});
var LogoDigg24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoDigg24(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.48 7.6v3.92H2V21H9.28V7.6zm0 11.2H4.8v-5H6.48zM10.4 11.52H13.2V21.04H10.4zM10.4 7.6H13.2V10.399999999999999H10.4zM14.32 11.52V21H18.8v1.12H14.32V24.4H21.6V11.52zM18.8 18.8H17.12v-5H18.8zM22.72 11.52V21H27.2v1.12H22.72V24.4H30V11.52zM27.2 18.8H25.52v-5H27.2z"
  })), children);
});
var LogoDigg20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoDigg20(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.48 7.6v3.92H2V21H9.28V7.6zm0 11.2H4.8v-5H6.48zM10.4 11.52H13.2V21.04H10.4zM10.4 7.6H13.2V10.399999999999999H10.4zM14.32 11.52V21H18.8v1.12H14.32V24.4H21.6V11.52zM18.8 18.8H17.12v-5H18.8zM22.72 11.52V21H27.2v1.12H22.72V24.4H30V11.52zM27.2 18.8H25.52v-5H27.2z"
  })), children);
});
var LogoDigg16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoDigg16(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.48 7.6v3.92H2V21H9.28V7.6zm0 11.2H4.8v-5H6.48zM10.4 11.52H13.2V21.04H10.4zM10.4 7.6H13.2V10.399999999999999H10.4zM14.32 11.52V21H18.8v1.12H14.32V24.4H21.6V11.52zM18.8 18.8H17.12v-5H18.8zM22.72 11.52V21H27.2v1.12H22.72V24.4H30V11.52zM27.2 18.8H25.52v-5H27.2z"
  })), children);
});
var LogoDiscord32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoDiscord32(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.647,14.907a1.4482,1.4482,0,1,0,1.326,1.443A1.385,1.385,0,0,0,13.647,14.907Zm4.745,0a1.4482,1.4482,0,1,0,1.326,1.443A1.385,1.385,0,0,0,18.392,14.907Z"
  })), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.71,4H7.29A2.6714,2.6714,0,0,0,4.625,6.678V24.254A2.6714,2.6714,0,0,0,7.29,26.932H22.032l-.689-2.405,1.664,1.547L24.58,27.53,27.375,30V6.678A2.6714,2.6714,0,0,0,24.71,4ZM19.692,20.978s-.468-.559-.858-1.053a4.1021,4.1021,0,0,0,2.353-1.547,7.4391,7.4391,0,0,1-1.495.767,8.5564,8.5564,0,0,1-1.885.559,9.1068,9.1068,0,0,1-3.367-.013,10.9127,10.9127,0,0,1-1.911-.559,7.6184,7.6184,0,0,1-.949-.442c-.039-.026-.078-.039-.117-.065a.18.18,0,0,1-.052-.039c-.234-.13-.364-.221-.364-.221a4.0432,4.0432,0,0,0,2.275,1.534c-.39.494-.871,1.079-.871,1.079a4.7134,4.7134,0,0,1-3.965-1.976,17.409,17.409,0,0,1,1.872-7.579,6.4285,6.4285,0,0,1,3.653-1.365l.13.156a8.77,8.77,0,0,0-3.419,1.703s.286-.156.767-.377a9.7625,9.7625,0,0,1,2.951-.819,1.2808,1.2808,0,0,1,.221-.026,11,11,0,0,1,2.626-.026A10.5971,10.5971,0,0,1,21.2,11.917a8.6518,8.6518,0,0,0-3.237-1.651l.182-.208a6.4285,6.4285,0,0,1,3.653,1.365,17.409,17.409,0,0,1,1.872,7.579A4.752,4.752,0,0,1,19.692,20.978Z"
  })), children);
});
var LogoDiscord24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoDiscord24(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.647,14.907a1.4482,1.4482,0,1,0,1.326,1.443A1.385,1.385,0,0,0,13.647,14.907Zm4.745,0a1.4482,1.4482,0,1,0,1.326,1.443A1.385,1.385,0,0,0,18.392,14.907Z"
  })), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.71,4H7.29A2.6714,2.6714,0,0,0,4.625,6.678V24.254A2.6714,2.6714,0,0,0,7.29,26.932H22.032l-.689-2.405,1.664,1.547L24.58,27.53,27.375,30V6.678A2.6714,2.6714,0,0,0,24.71,4ZM19.692,20.978s-.468-.559-.858-1.053a4.1021,4.1021,0,0,0,2.353-1.547,7.4391,7.4391,0,0,1-1.495.767,8.5564,8.5564,0,0,1-1.885.559,9.1068,9.1068,0,0,1-3.367-.013,10.9127,10.9127,0,0,1-1.911-.559,7.6184,7.6184,0,0,1-.949-.442c-.039-.026-.078-.039-.117-.065a.18.18,0,0,1-.052-.039c-.234-.13-.364-.221-.364-.221a4.0432,4.0432,0,0,0,2.275,1.534c-.39.494-.871,1.079-.871,1.079a4.7134,4.7134,0,0,1-3.965-1.976,17.409,17.409,0,0,1,1.872-7.579,6.4285,6.4285,0,0,1,3.653-1.365l.13.156a8.77,8.77,0,0,0-3.419,1.703s.286-.156.767-.377a9.7625,9.7625,0,0,1,2.951-.819,1.2808,1.2808,0,0,1,.221-.026,11,11,0,0,1,2.626-.026A10.5971,10.5971,0,0,1,21.2,11.917a8.6518,8.6518,0,0,0-3.237-1.651l.182-.208a6.4285,6.4285,0,0,1,3.653,1.365,17.409,17.409,0,0,1,1.872,7.579A4.752,4.752,0,0,1,19.692,20.978Z"
  })), children);
});
var LogoDiscord20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoDiscord20(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.647,14.907a1.4482,1.4482,0,1,0,1.326,1.443A1.385,1.385,0,0,0,13.647,14.907Zm4.745,0a1.4482,1.4482,0,1,0,1.326,1.443A1.385,1.385,0,0,0,18.392,14.907Z"
  })), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.71,4H7.29A2.6714,2.6714,0,0,0,4.625,6.678V24.254A2.6714,2.6714,0,0,0,7.29,26.932H22.032l-.689-2.405,1.664,1.547L24.58,27.53,27.375,30V6.678A2.6714,2.6714,0,0,0,24.71,4ZM19.692,20.978s-.468-.559-.858-1.053a4.1021,4.1021,0,0,0,2.353-1.547,7.4391,7.4391,0,0,1-1.495.767,8.5564,8.5564,0,0,1-1.885.559,9.1068,9.1068,0,0,1-3.367-.013,10.9127,10.9127,0,0,1-1.911-.559,7.6184,7.6184,0,0,1-.949-.442c-.039-.026-.078-.039-.117-.065a.18.18,0,0,1-.052-.039c-.234-.13-.364-.221-.364-.221a4.0432,4.0432,0,0,0,2.275,1.534c-.39.494-.871,1.079-.871,1.079a4.7134,4.7134,0,0,1-3.965-1.976,17.409,17.409,0,0,1,1.872-7.579,6.4285,6.4285,0,0,1,3.653-1.365l.13.156a8.77,8.77,0,0,0-3.419,1.703s.286-.156.767-.377a9.7625,9.7625,0,0,1,2.951-.819,1.2808,1.2808,0,0,1,.221-.026,11,11,0,0,1,2.626-.026A10.5971,10.5971,0,0,1,21.2,11.917a8.6518,8.6518,0,0,0-3.237-1.651l.182-.208a6.4285,6.4285,0,0,1,3.653,1.365,17.409,17.409,0,0,1,1.872,7.579A4.752,4.752,0,0,1,19.692,20.978Z"
  })), children);
});
var LogoDiscord16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoDiscord16(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.647,14.907a1.4482,1.4482,0,1,0,1.326,1.443A1.385,1.385,0,0,0,13.647,14.907Zm4.745,0a1.4482,1.4482,0,1,0,1.326,1.443A1.385,1.385,0,0,0,18.392,14.907Z"
  })), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.71,4H7.29A2.6714,2.6714,0,0,0,4.625,6.678V24.254A2.6714,2.6714,0,0,0,7.29,26.932H22.032l-.689-2.405,1.664,1.547L24.58,27.53,27.375,30V6.678A2.6714,2.6714,0,0,0,24.71,4ZM19.692,20.978s-.468-.559-.858-1.053a4.1021,4.1021,0,0,0,2.353-1.547,7.4391,7.4391,0,0,1-1.495.767,8.5564,8.5564,0,0,1-1.885.559,9.1068,9.1068,0,0,1-3.367-.013,10.9127,10.9127,0,0,1-1.911-.559,7.6184,7.6184,0,0,1-.949-.442c-.039-.026-.078-.039-.117-.065a.18.18,0,0,1-.052-.039c-.234-.13-.364-.221-.364-.221a4.0432,4.0432,0,0,0,2.275,1.534c-.39.494-.871,1.079-.871,1.079a4.7134,4.7134,0,0,1-3.965-1.976,17.409,17.409,0,0,1,1.872-7.579,6.4285,6.4285,0,0,1,3.653-1.365l.13.156a8.77,8.77,0,0,0-3.419,1.703s.286-.156.767-.377a9.7625,9.7625,0,0,1,2.951-.819,1.2808,1.2808,0,0,1,.221-.026,11,11,0,0,1,2.626-.026A10.5971,10.5971,0,0,1,21.2,11.917a8.6518,8.6518,0,0,0-3.237-1.651l.182-.208a6.4285,6.4285,0,0,1,3.653,1.365,17.409,17.409,0,0,1,1.872,7.579A4.752,4.752,0,0,1,19.692,20.978Z"
  })), children);
});
var LogoFacebook32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoFacebook32(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.67,4H5.33A1.34,1.34,0,0,0,4,5.33V26.67A1.34,1.34,0,0,0,5.33,28H16.82V18.72H13.7V15.09h3.12V12.42c0-3.1,1.89-4.79,4.67-4.79.93,0,1.86,0,2.79.14V11H22.37c-1.51,0-1.8.72-1.8,1.77v2.31h3.6l-.47,3.63H20.57V28h6.1A1.34,1.34,0,0,0,28,26.67V5.33A1.34,1.34,0,0,0,26.67,4Z"
  })), children);
});
var LogoFacebook24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoFacebook24(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.67,4H5.33A1.34,1.34,0,0,0,4,5.33V26.67A1.34,1.34,0,0,0,5.33,28H16.82V18.72H13.7V15.09h3.12V12.42c0-3.1,1.89-4.79,4.67-4.79.93,0,1.86,0,2.79.14V11H22.37c-1.51,0-1.8.72-1.8,1.77v2.31h3.6l-.47,3.63H20.57V28h6.1A1.34,1.34,0,0,0,28,26.67V5.33A1.34,1.34,0,0,0,26.67,4Z"
  })), children);
});
var LogoFacebook20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoFacebook20(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.67,4H5.33A1.34,1.34,0,0,0,4,5.33V26.67A1.34,1.34,0,0,0,5.33,28H16.82V18.72H13.7V15.09h3.12V12.42c0-3.1,1.89-4.79,4.67-4.79.93,0,1.86,0,2.79.14V11H22.37c-1.51,0-1.8.72-1.8,1.77v2.31h3.6l-.47,3.63H20.57V28h6.1A1.34,1.34,0,0,0,28,26.67V5.33A1.34,1.34,0,0,0,26.67,4Z"
  })), children);
});
var LogoFacebook16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoFacebook16(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.67,4H5.33A1.34,1.34,0,0,0,4,5.33V26.67A1.34,1.34,0,0,0,5.33,28H16.82V18.72H13.7V15.09h3.12V12.42c0-3.1,1.89-4.79,4.67-4.79.93,0,1.86,0,2.79.14V11H22.37c-1.51,0-1.8.72-1.8,1.77v2.31h3.6l-.47,3.63H20.57V28h6.1A1.34,1.34,0,0,0,28,26.67V5.33A1.34,1.34,0,0,0,26.67,4Z"
  })), children);
});
var LogoFlickr32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoFlickr32(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "6"
  })), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "16",
    r: "6"
  })), children);
});
var LogoFlickr24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoFlickr24(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "6"
  })), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "16",
    r: "6"
  })), children);
});
var LogoFlickr20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoFlickr20(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle21 || (_circle21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "6"
  })), _circle22 || (_circle22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "16",
    r: "6"
  })), children);
});
var LogoFlickr16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoFlickr16(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle23 || (_circle23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "6"
  })), _circle24 || (_circle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "16",
    r: "6"
  })), children);
});
var LogoGithub32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoGithub32(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M16,2a14,14,0,0,0-4.43,27.28c.7.13,1-.3,1-.67s0-1.21,0-2.38c-3.89.84-4.71-1.88-4.71-1.88A3.71,3.71,0,0,0,6.24,22.3c-1.27-.86.1-.85.1-.85A2.94,2.94,0,0,1,8.48,22.9a3,3,0,0,0,4.08,1.16,2.93,2.93,0,0,1,.88-1.87c-3.1-.36-6.37-1.56-6.37-6.92a5.4,5.4,0,0,1,1.44-3.76,5,5,0,0,1,.14-3.7s1.17-.38,3.85,1.43a13.3,13.3,0,0,1,7,0c2.67-1.81,3.84-1.43,3.84-1.43a5,5,0,0,1,.14,3.7,5.4,5.4,0,0,1,1.44,3.76c0,5.38-3.27,6.56-6.39,6.91a3.33,3.33,0,0,1,.95,2.59c0,1.87,0,3.38,0,3.84s.25.81,1,.67A14,14,0,0,0,16,2Z"
  })), children);
});
var LogoGithub24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoGithub24(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M16,2a14,14,0,0,0-4.43,27.28c.7.13,1-.3,1-.67s0-1.21,0-2.38c-3.89.84-4.71-1.88-4.71-1.88A3.71,3.71,0,0,0,6.24,22.3c-1.27-.86.1-.85.1-.85A2.94,2.94,0,0,1,8.48,22.9a3,3,0,0,0,4.08,1.16,2.93,2.93,0,0,1,.88-1.87c-3.1-.36-6.37-1.56-6.37-6.92a5.4,5.4,0,0,1,1.44-3.76,5,5,0,0,1,.14-3.7s1.17-.38,3.85,1.43a13.3,13.3,0,0,1,7,0c2.67-1.81,3.84-1.43,3.84-1.43a5,5,0,0,1,.14,3.7,5.4,5.4,0,0,1,1.44,3.76c0,5.38-3.27,6.56-6.39,6.91a3.33,3.33,0,0,1,.95,2.59c0,1.87,0,3.38,0,3.84s.25.81,1,.67A14,14,0,0,0,16,2Z"
  })), children);
});
var LogoGithub20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoGithub20(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M16,2a14,14,0,0,0-4.43,27.28c.7.13,1-.3,1-.67s0-1.21,0-2.38c-3.89.84-4.71-1.88-4.71-1.88A3.71,3.71,0,0,0,6.24,22.3c-1.27-.86.1-.85.1-.85A2.94,2.94,0,0,1,8.48,22.9a3,3,0,0,0,4.08,1.16,2.93,2.93,0,0,1,.88-1.87c-3.1-.36-6.37-1.56-6.37-6.92a5.4,5.4,0,0,1,1.44-3.76,5,5,0,0,1,.14-3.7s1.17-.38,3.85,1.43a13.3,13.3,0,0,1,7,0c2.67-1.81,3.84-1.43,3.84-1.43a5,5,0,0,1,.14,3.7,5.4,5.4,0,0,1,1.44,3.76c0,5.38-3.27,6.56-6.39,6.91a3.33,3.33,0,0,1,.95,2.59c0,1.87,0,3.38,0,3.84s.25.81,1,.67A14,14,0,0,0,16,2Z"
  })), children);
});
var LogoGithub16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoGithub16(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M16,2a14,14,0,0,0-4.43,27.28c.7.13,1-.3,1-.67s0-1.21,0-2.38c-3.89.84-4.71-1.88-4.71-1.88A3.71,3.71,0,0,0,6.24,22.3c-1.27-.86.1-.85.1-.85A2.94,2.94,0,0,1,8.48,22.9a3,3,0,0,0,4.08,1.16,2.93,2.93,0,0,1,.88-1.87c-3.1-.36-6.37-1.56-6.37-6.92a5.4,5.4,0,0,1,1.44-3.76,5,5,0,0,1,.14-3.7s1.17-.38,3.85,1.43a13.3,13.3,0,0,1,7,0c2.67-1.81,3.84-1.43,3.84-1.43a5,5,0,0,1,.14,3.7,5.4,5.4,0,0,1,1.44,3.76c0,5.38-3.27,6.56-6.39,6.91a3.33,3.33,0,0,1,.95,2.59c0,1.87,0,3.38,0,3.84s.25.81,1,.67A14,14,0,0,0,16,2Z"
  })), children);
});
var LogoGlassdoor32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoGlassdoor32(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.8281,28H21.1719a3.43,3.43,0,0,0,3.43-3.43V10.3306h-3.43V24.57H7.3981A3.43,3.43,0,0,0,10.8281,28Z"
  })), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.1719,4H10.8281a3.43,3.43,0,0,0-3.43,3.43v14.24h3.43V7.43H24.6019A3.43,3.43,0,0,0,21.1719,4Z"
  })), children);
});
var LogoGlassdoor24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoGlassdoor24(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.8281,28H21.1719a3.43,3.43,0,0,0,3.43-3.43V10.3306h-3.43V24.57H7.3981A3.43,3.43,0,0,0,10.8281,28Z"
  })), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.1719,4H10.8281a3.43,3.43,0,0,0-3.43,3.43v14.24h3.43V7.43H24.6019A3.43,3.43,0,0,0,21.1719,4Z"
  })), children);
});
var LogoGlassdoor20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoGlassdoor20(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.8281,28H21.1719a3.43,3.43,0,0,0,3.43-3.43V10.3306h-3.43V24.57H7.3981A3.43,3.43,0,0,0,10.8281,28Z"
  })), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.1719,4H10.8281a3.43,3.43,0,0,0-3.43,3.43v14.24h3.43V7.43H24.6019A3.43,3.43,0,0,0,21.1719,4Z"
  })), children);
});
var LogoGlassdoor16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoGlassdoor16(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.8281,28H21.1719a3.43,3.43,0,0,0,3.43-3.43V10.3306h-3.43V24.57H7.3981A3.43,3.43,0,0,0,10.8281,28Z"
  })), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.1719,4H10.8281a3.43,3.43,0,0,0-3.43,3.43v14.24h3.43V7.43H24.6019A3.43,3.43,0,0,0,21.1719,4Z"
  })), children);
});
var LogoGoogle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoGoogle32(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  if (true) {
    if (!didWarnAboutDeprecation['LogoGoogle32']) {
      didWarnAboutDeprecation['LogoGoogle32'] = true;
      console.warn("The LogoGoogle32 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.39,13.82H16.21v4.63h6.44c-.6,2.95-3.11,4.64-6.44,4.64a7.09,7.09,0,0,1,0-14.18,7,7,0,0,1,4.42,1.58L24.12,7a12,12,0,1,0-7.91,21c6,0,11.45-4.36,11.45-12A9.56,9.56,0,0,0,27.39,13.82Z"
  })), children);
});
var LogoGoogle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoGoogle24(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  if (true) {
    if (!didWarnAboutDeprecation['LogoGoogle24']) {
      didWarnAboutDeprecation['LogoGoogle24'] = true;
      console.warn("The LogoGoogle24 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.39,13.82H16.21v4.63h6.44c-.6,2.95-3.11,4.64-6.44,4.64a7.09,7.09,0,0,1,0-14.18,7,7,0,0,1,4.42,1.58L24.12,7a12,12,0,1,0-7.91,21c6,0,11.45-4.36,11.45-12A9.56,9.56,0,0,0,27.39,13.82Z"
  })), children);
});
var LogoGoogle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoGoogle20(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  if (true) {
    if (!didWarnAboutDeprecation['LogoGoogle20']) {
      didWarnAboutDeprecation['LogoGoogle20'] = true;
      console.warn("The LogoGoogle20 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.39,13.82H16.21v4.63h6.44c-.6,2.95-3.11,4.64-6.44,4.64a7.09,7.09,0,0,1,0-14.18,7,7,0,0,1,4.42,1.58L24.12,7a12,12,0,1,0-7.91,21c6,0,11.45-4.36,11.45-12A9.56,9.56,0,0,0,27.39,13.82Z"
  })), children);
});
var LogoGoogle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoGoogle16(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  if (true) {
    if (!didWarnAboutDeprecation['LogoGoogle16']) {
      didWarnAboutDeprecation['LogoGoogle16'] = true;
      console.warn("The LogoGoogle16 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.39,13.82H16.21v4.63h6.44c-.6,2.95-3.11,4.64-6.44,4.64a7.09,7.09,0,0,1,0-14.18,7,7,0,0,1,4.42,1.58L24.12,7a12,12,0,1,0-7.91,21c6,0,11.45-4.36,11.45-12A9.56,9.56,0,0,0,27.39,13.82Z"
  })), children);
});
var LogoInstagram32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoInstagram32(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle25 || (_circle25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22.406",
    cy: "9.594",
    r: "1.44"
  })), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,9.8378A6.1622,6.1622,0,1,0,22.1622,16,6.1622,6.1622,0,0,0,16,9.8378ZM16,20a4,4,0,1,1,4-4A4,4,0,0,1,16,20Z"
  })), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6.1622c3.2041,0,3.5837.0122,4.849.07a6.6418,6.6418,0,0,1,2.2283.4132,3.9748,3.9748,0,0,1,2.2774,2.2774,6.6418,6.6418,0,0,1,.4132,2.2283c.0577,1.2653.07,1.6449.07,4.849s-.0122,3.5837-.07,4.849a6.6418,6.6418,0,0,1-.4132,2.2283,3.9748,3.9748,0,0,1-2.2774,2.2774,6.6418,6.6418,0,0,1-2.2283.4132c-1.2652.0577-1.6446.07-4.849.07s-3.5838-.0122-4.849-.07a6.6418,6.6418,0,0,1-2.2283-.4132,3.9748,3.9748,0,0,1-2.2774-2.2774,6.6418,6.6418,0,0,1-.4132-2.2283c-.0577-1.2653-.07-1.6449-.07-4.849s.0122-3.5837.07-4.849a6.6418,6.6418,0,0,1,.4132-2.2283A3.9748,3.9748,0,0,1,8.9227,6.6453a6.6418,6.6418,0,0,1,2.2283-.4132c1.2653-.0577,1.6449-.07,4.849-.07M16,4c-3.259,0-3.6677.0138-4.9476.0722A8.8068,8.8068,0,0,0,8.14,4.63,6.1363,6.1363,0,0,0,4.63,8.14a8.8068,8.8068,0,0,0-.5578,2.9129C4.0138,12.3323,4,12.741,4,16s.0138,3.6677.0722,4.9476A8.8074,8.8074,0,0,0,4.63,23.8605a6.1363,6.1363,0,0,0,3.51,3.51,8.8068,8.8068,0,0,0,2.9129.5578C12.3323,27.9862,12.741,28,16,28s3.6677-.0138,4.9476-.0722a8.8074,8.8074,0,0,0,2.9129-.5578,6.1363,6.1363,0,0,0,3.51-3.51,8.8074,8.8074,0,0,0,.5578-2.9129C27.9862,19.6677,28,19.259,28,16s-.0138-3.6677-.0722-4.9476A8.8068,8.8068,0,0,0,27.37,8.14a6.1363,6.1363,0,0,0-3.51-3.5095,8.8074,8.8074,0,0,0-2.9129-.5578C19.6677,4.0138,19.259,4,16,4Z"
  })), children);
});
var LogoInstagram24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoInstagram24(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle26 || (_circle26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22.406",
    cy: "9.594",
    r: "1.44"
  })), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,9.8378A6.1622,6.1622,0,1,0,22.1622,16,6.1622,6.1622,0,0,0,16,9.8378ZM16,20a4,4,0,1,1,4-4A4,4,0,0,1,16,20Z"
  })), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6.1622c3.2041,0,3.5837.0122,4.849.07a6.6418,6.6418,0,0,1,2.2283.4132,3.9748,3.9748,0,0,1,2.2774,2.2774,6.6418,6.6418,0,0,1,.4132,2.2283c.0577,1.2653.07,1.6449.07,4.849s-.0122,3.5837-.07,4.849a6.6418,6.6418,0,0,1-.4132,2.2283,3.9748,3.9748,0,0,1-2.2774,2.2774,6.6418,6.6418,0,0,1-2.2283.4132c-1.2652.0577-1.6446.07-4.849.07s-3.5838-.0122-4.849-.07a6.6418,6.6418,0,0,1-2.2283-.4132,3.9748,3.9748,0,0,1-2.2774-2.2774,6.6418,6.6418,0,0,1-.4132-2.2283c-.0577-1.2653-.07-1.6449-.07-4.849s.0122-3.5837.07-4.849a6.6418,6.6418,0,0,1,.4132-2.2283A3.9748,3.9748,0,0,1,8.9227,6.6453a6.6418,6.6418,0,0,1,2.2283-.4132c1.2653-.0577,1.6449-.07,4.849-.07M16,4c-3.259,0-3.6677.0138-4.9476.0722A8.8068,8.8068,0,0,0,8.14,4.63,6.1363,6.1363,0,0,0,4.63,8.14a8.8068,8.8068,0,0,0-.5578,2.9129C4.0138,12.3323,4,12.741,4,16s.0138,3.6677.0722,4.9476A8.8074,8.8074,0,0,0,4.63,23.8605a6.1363,6.1363,0,0,0,3.51,3.51,8.8068,8.8068,0,0,0,2.9129.5578C12.3323,27.9862,12.741,28,16,28s3.6677-.0138,4.9476-.0722a8.8074,8.8074,0,0,0,2.9129-.5578,6.1363,6.1363,0,0,0,3.51-3.51,8.8074,8.8074,0,0,0,.5578-2.9129C27.9862,19.6677,28,19.259,28,16s-.0138-3.6677-.0722-4.9476A8.8068,8.8068,0,0,0,27.37,8.14a6.1363,6.1363,0,0,0-3.51-3.5095,8.8074,8.8074,0,0,0-2.9129-.5578C19.6677,4.0138,19.259,4,16,4Z"
  })), children);
});
var LogoInstagram20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoInstagram20(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle27 || (_circle27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22.406",
    cy: "9.594",
    r: "1.44"
  })), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,9.8378A6.1622,6.1622,0,1,0,22.1622,16,6.1622,6.1622,0,0,0,16,9.8378ZM16,20a4,4,0,1,1,4-4A4,4,0,0,1,16,20Z"
  })), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6.1622c3.2041,0,3.5837.0122,4.849.07a6.6418,6.6418,0,0,1,2.2283.4132,3.9748,3.9748,0,0,1,2.2774,2.2774,6.6418,6.6418,0,0,1,.4132,2.2283c.0577,1.2653.07,1.6449.07,4.849s-.0122,3.5837-.07,4.849a6.6418,6.6418,0,0,1-.4132,2.2283,3.9748,3.9748,0,0,1-2.2774,2.2774,6.6418,6.6418,0,0,1-2.2283.4132c-1.2652.0577-1.6446.07-4.849.07s-3.5838-.0122-4.849-.07a6.6418,6.6418,0,0,1-2.2283-.4132,3.9748,3.9748,0,0,1-2.2774-2.2774,6.6418,6.6418,0,0,1-.4132-2.2283c-.0577-1.2653-.07-1.6449-.07-4.849s.0122-3.5837.07-4.849a6.6418,6.6418,0,0,1,.4132-2.2283A3.9748,3.9748,0,0,1,8.9227,6.6453a6.6418,6.6418,0,0,1,2.2283-.4132c1.2653-.0577,1.6449-.07,4.849-.07M16,4c-3.259,0-3.6677.0138-4.9476.0722A8.8068,8.8068,0,0,0,8.14,4.63,6.1363,6.1363,0,0,0,4.63,8.14a8.8068,8.8068,0,0,0-.5578,2.9129C4.0138,12.3323,4,12.741,4,16s.0138,3.6677.0722,4.9476A8.8074,8.8074,0,0,0,4.63,23.8605a6.1363,6.1363,0,0,0,3.51,3.51,8.8068,8.8068,0,0,0,2.9129.5578C12.3323,27.9862,12.741,28,16,28s3.6677-.0138,4.9476-.0722a8.8074,8.8074,0,0,0,2.9129-.5578,6.1363,6.1363,0,0,0,3.51-3.51,8.8074,8.8074,0,0,0,.5578-2.9129C27.9862,19.6677,28,19.259,28,16s-.0138-3.6677-.0722-4.9476A8.8068,8.8068,0,0,0,27.37,8.14a6.1363,6.1363,0,0,0-3.51-3.5095,8.8074,8.8074,0,0,0-2.9129-.5578C19.6677,4.0138,19.259,4,16,4Z"
  })), children);
});
var LogoInstagram16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoInstagram16(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle28 || (_circle28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22.406",
    cy: "9.594",
    r: "1.44"
  })), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,9.8378A6.1622,6.1622,0,1,0,22.1622,16,6.1622,6.1622,0,0,0,16,9.8378ZM16,20a4,4,0,1,1,4-4A4,4,0,0,1,16,20Z"
  })), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6.1622c3.2041,0,3.5837.0122,4.849.07a6.6418,6.6418,0,0,1,2.2283.4132,3.9748,3.9748,0,0,1,2.2774,2.2774,6.6418,6.6418,0,0,1,.4132,2.2283c.0577,1.2653.07,1.6449.07,4.849s-.0122,3.5837-.07,4.849a6.6418,6.6418,0,0,1-.4132,2.2283,3.9748,3.9748,0,0,1-2.2774,2.2774,6.6418,6.6418,0,0,1-2.2283.4132c-1.2652.0577-1.6446.07-4.849.07s-3.5838-.0122-4.849-.07a6.6418,6.6418,0,0,1-2.2283-.4132,3.9748,3.9748,0,0,1-2.2774-2.2774,6.6418,6.6418,0,0,1-.4132-2.2283c-.0577-1.2653-.07-1.6449-.07-4.849s.0122-3.5837.07-4.849a6.6418,6.6418,0,0,1,.4132-2.2283A3.9748,3.9748,0,0,1,8.9227,6.6453a6.6418,6.6418,0,0,1,2.2283-.4132c1.2653-.0577,1.6449-.07,4.849-.07M16,4c-3.259,0-3.6677.0138-4.9476.0722A8.8068,8.8068,0,0,0,8.14,4.63,6.1363,6.1363,0,0,0,4.63,8.14a8.8068,8.8068,0,0,0-.5578,2.9129C4.0138,12.3323,4,12.741,4,16s.0138,3.6677.0722,4.9476A8.8074,8.8074,0,0,0,4.63,23.8605a6.1363,6.1363,0,0,0,3.51,3.51,8.8068,8.8068,0,0,0,2.9129.5578C12.3323,27.9862,12.741,28,16,28s3.6677-.0138,4.9476-.0722a8.8074,8.8074,0,0,0,2.9129-.5578,6.1363,6.1363,0,0,0,3.51-3.51,8.8074,8.8074,0,0,0,.5578-2.9129C27.9862,19.6677,28,19.259,28,16s-.0138-3.6677-.0722-4.9476A8.8068,8.8068,0,0,0,27.37,8.14a6.1363,6.1363,0,0,0-3.51-3.5095,8.8074,8.8074,0,0,0-2.9129-.5578C19.6677,4.0138,19.259,4,16,4Z"
  })), children);
});
var LogoJupyter32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoJupyter32(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.0766 3.5878a1.69 1.69 0 11-1.76-1.5853 1.67 1.67 0 011.76 1.5853zM16.2191 23.1113c-4.4866 0-8.43-1.61-10.4688-3.9882a11.1618 11.1618 0 0020.9377 0C24.6541 21.5011 20.7257 23.1113 16.2191 23.1113zM16.2191 7.6483c4.4867 0 8.43 1.61 10.4689 3.9881a11.1618 11.1618 0 00-20.9377 0C7.7892 9.2535 11.7126 7.6483 16.2191 7.6483zM10.0427 27.7388a2.1085 2.1085 0 11-.2031-.7976 2.1278 2.1278 0 01.2031.7976zM6.26 7.1064A1.2263 1.2263 0 117.4517 5.83 1.2415 1.2415 0 016.26 7.1064z"
  })), children);
});
var LogoJupyter24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoJupyter24(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.0766 3.5878a1.69 1.69 0 11-1.76-1.5853 1.67 1.67 0 011.76 1.5853zM16.2191 23.1113c-4.4866 0-8.43-1.61-10.4688-3.9882a11.1618 11.1618 0 0020.9377 0C24.6541 21.5011 20.7257 23.1113 16.2191 23.1113zM16.2191 7.6483c4.4867 0 8.43 1.61 10.4689 3.9881a11.1618 11.1618 0 00-20.9377 0C7.7892 9.2535 11.7126 7.6483 16.2191 7.6483zM10.0427 27.7388a2.1085 2.1085 0 11-.2031-.7976 2.1278 2.1278 0 01.2031.7976zM6.26 7.1064A1.2263 1.2263 0 117.4517 5.83 1.2415 1.2415 0 016.26 7.1064z"
  })), children);
});
var LogoJupyter20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoJupyter20(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.0766 3.5878a1.69 1.69 0 11-1.76-1.5853 1.67 1.67 0 011.76 1.5853zM16.2191 23.1113c-4.4866 0-8.43-1.61-10.4688-3.9882a11.1618 11.1618 0 0020.9377 0C24.6541 21.5011 20.7257 23.1113 16.2191 23.1113zM16.2191 7.6483c4.4867 0 8.43 1.61 10.4689 3.9881a11.1618 11.1618 0 00-20.9377 0C7.7892 9.2535 11.7126 7.6483 16.2191 7.6483zM10.0427 27.7388a2.1085 2.1085 0 11-.2031-.7976 2.1278 2.1278 0 01.2031.7976zM6.26 7.1064A1.2263 1.2263 0 117.4517 5.83 1.2415 1.2415 0 016.26 7.1064z"
  })), children);
});
var LogoJupyter16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoJupyter16(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.0766 3.5878a1.69 1.69 0 11-1.76-1.5853 1.67 1.67 0 011.76 1.5853zM16.2191 23.1113c-4.4866 0-8.43-1.61-10.4688-3.9882a11.1618 11.1618 0 0020.9377 0C24.6541 21.5011 20.7257 23.1113 16.2191 23.1113zM16.2191 7.6483c4.4867 0 8.43 1.61 10.4689 3.9881a11.1618 11.1618 0 00-20.9377 0C7.7892 9.2535 11.7126 7.6483 16.2191 7.6483zM10.0427 27.7388a2.1085 2.1085 0 11-.2031-.7976 2.1278 2.1278 0 01.2031.7976zM6.26 7.1064A1.2263 1.2263 0 117.4517 5.83 1.2415 1.2415 0 016.26 7.1064z"
  })), children);
});
var LogoKeybase32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoKeybase32(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.1233 26.9328a1.1122 1.1122 0 11-1.1121-1.1122 1.112 1.112 0 011.1121 1.1122M21.0257 26.9328a1.1122 1.1122 0 11-1.1122-1.1122 1.1121 1.1121 0 011.1122 1.1122"
  })), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.999 5.797H10.973V6.771H9.999z",
    transform: "rotate(-86.462 10.486 6.284)"
  })), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.4275,16.3825l-.0013.001a13.0868,13.0868,0,0,0-5.1431-4.1825c-.3754-.1667-.7543-.3142-1.1354-.4454.0128-.0314.0277-.0615.04-.0933a4.83,4.83,0,0,0-2.9861-6.319,5.9368,5.9368,0,0,0-1.9962-.3558c-.0366-.1253-.1165-.6743.58-2.1571L14.3742,2q-.17.236-.3368.4661c-.384.5309-.7549,1.0444-1.1029,1.55a2.1657,2.1657,0,0,0-1.4486-.6771L9.8543,3.2377H9.852l-.0025,0c-.0429-.0025-.0864-.0039-.1293-.0039A2.1877,2.1877,0,0,0,7.54,5.2825L7.4388,6.9169l0,.003,0,.0028A2.1882,2.1882,0,0,0,9.4854,9.23l1.1673.0723a5.1711,5.1711,0,0,0,.47,2.688,13.1954,13.1954,0,0,0-4.2637,2.9C3,18.7883,3,23.06,3,26.4916v2.0706l1.524-1.6163A12.3293,12.3293,0,0,0,5.8548,30H7.8367A10.7091,10.7091,0,0,1,5.878,25.51l2.2353-2.3708L6.963,26.745l2.03-1.4774c3.5858-2.61,7.8678-3.2093,12.7263-1.7826a4.6276,4.6276,0,0,0,5.2189-1.468c.0441-.0628.0828-.128.1228-.1926a9.6141,9.6141,0,0,1,.1638,1.7454,12.4214,12.4214,0,0,1-1.61,6.43h1.877A14.4022,14.4022,0,0,0,28.87,23.57,12.2666,12.2666,0,0,0,26.4275,16.3825ZM13.8455,5.9257a1.5872,1.5872,0,0,0,1.3983.7068,4.2111,4.2111,0,0,1,1.44.2719,3.17,3.17,0,0,1,1.0279,5.4638l-.4752-.5849-.0032-.004a1.7048,1.7048,0,0,0-3.0235.9865,3.2143,3.2143,0,0,1-1.899-3.5412,8.4815,8.4815,0,0,1,1.4374-3.466A1.642,1.642,0,0,0,13.8455,5.9257Zm3.49,9.2589-.6072.4962a.2675.2675,0,0,1-.376-.038l-.1264-.1549a.2791.2791,0,0,1,.0394-.3927l.6-.49-1.235-1.5158a.362.362,0,1,1,.5611-.4575l3.4546,4.2517a.3619.3619,0,0,1-.1988.5815.3566.3566,0,0,1-.0816.0094.3609.3609,0,0,1-.2806-.1332l-.3441-.4239-1.2215.9971a.2815.2815,0,0,1-.3965-.04l-.5532-.6775a.2786.2786,0,0,1,.04-.3919l1.2275-1.002ZM9.08,7.0184l.1014-1.6342A.5394.5394,0,0,1,9.72,4.8781l.0326.001,1.6335.1013a.5387.5387,0,0,1,.5046.5716l-.0073.1182a10.6739,10.6739,0,0,0-.9028,2.0046L9.5859,7.5886A.5407.5407,0,0,1,9.08,7.0184ZM25.5944,21.07a2.9883,2.9883,0,0,1-3.4112.8373c-4.5313-1.3305-8.6289-1.0534-12.2124.82l1.9069-5.978-7.203,7.6393a11.67,11.67,0,0,1,3.3532-8.3419,11.4953,11.4953,0,0,1,4.1073-2.6908,5.42,5.42,0,0,0,2.2411,1.2214,4.714,4.714,0,0,0,.5627.12,1.6258,1.6258,0,0,0,.2449,1.6416l.0847.1038a1.6247,1.6247,0,0,0,.2594,1.605l.5532.6777a1.6276,1.6276,0,0,0,2.29.2314l.3314-.2705a1.7079,1.7079,0,0,0,1.9867-2.6535l-1.9427-2.3911a4.88,4.88,0,0,0,.4863-.456,12.449,12.449,0,0,1,1.3829.5181,11.419,11.419,0,0,1,4.5085,3.6838C26.0987,18.7278,26.2745,20.1043,25.5944,21.07Z"
  })), children);
});
var LogoKeybase24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoKeybase24(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.1233 26.9328a1.1122 1.1122 0 11-1.1121-1.1122 1.112 1.112 0 011.1121 1.1122M21.0257 26.9328a1.1122 1.1122 0 11-1.1122-1.1122 1.1121 1.1121 0 011.1122 1.1122"
  })), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.999 5.797H10.973V6.771H9.999z",
    transform: "rotate(-86.462 10.486 6.284)"
  })), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.4275,16.3825l-.0013.001a13.0868,13.0868,0,0,0-5.1431-4.1825c-.3754-.1667-.7543-.3142-1.1354-.4454.0128-.0314.0277-.0615.04-.0933a4.83,4.83,0,0,0-2.9861-6.319,5.9368,5.9368,0,0,0-1.9962-.3558c-.0366-.1253-.1165-.6743.58-2.1571L14.3742,2q-.17.236-.3368.4661c-.384.5309-.7549,1.0444-1.1029,1.55a2.1657,2.1657,0,0,0-1.4486-.6771L9.8543,3.2377H9.852l-.0025,0c-.0429-.0025-.0864-.0039-.1293-.0039A2.1877,2.1877,0,0,0,7.54,5.2825L7.4388,6.9169l0,.003,0,.0028A2.1882,2.1882,0,0,0,9.4854,9.23l1.1673.0723a5.1711,5.1711,0,0,0,.47,2.688,13.1954,13.1954,0,0,0-4.2637,2.9C3,18.7883,3,23.06,3,26.4916v2.0706l1.524-1.6163A12.3293,12.3293,0,0,0,5.8548,30H7.8367A10.7091,10.7091,0,0,1,5.878,25.51l2.2353-2.3708L6.963,26.745l2.03-1.4774c3.5858-2.61,7.8678-3.2093,12.7263-1.7826a4.6276,4.6276,0,0,0,5.2189-1.468c.0441-.0628.0828-.128.1228-.1926a9.6141,9.6141,0,0,1,.1638,1.7454,12.4214,12.4214,0,0,1-1.61,6.43h1.877A14.4022,14.4022,0,0,0,28.87,23.57,12.2666,12.2666,0,0,0,26.4275,16.3825ZM13.8455,5.9257a1.5872,1.5872,0,0,0,1.3983.7068,4.2111,4.2111,0,0,1,1.44.2719,3.17,3.17,0,0,1,1.0279,5.4638l-.4752-.5849-.0032-.004a1.7048,1.7048,0,0,0-3.0235.9865,3.2143,3.2143,0,0,1-1.899-3.5412,8.4815,8.4815,0,0,1,1.4374-3.466A1.642,1.642,0,0,0,13.8455,5.9257Zm3.49,9.2589-.6072.4962a.2675.2675,0,0,1-.376-.038l-.1264-.1549a.2791.2791,0,0,1,.0394-.3927l.6-.49-1.235-1.5158a.362.362,0,1,1,.5611-.4575l3.4546,4.2517a.3619.3619,0,0,1-.1988.5815.3566.3566,0,0,1-.0816.0094.3609.3609,0,0,1-.2806-.1332l-.3441-.4239-1.2215.9971a.2815.2815,0,0,1-.3965-.04l-.5532-.6775a.2786.2786,0,0,1,.04-.3919l1.2275-1.002ZM9.08,7.0184l.1014-1.6342A.5394.5394,0,0,1,9.72,4.8781l.0326.001,1.6335.1013a.5387.5387,0,0,1,.5046.5716l-.0073.1182a10.6739,10.6739,0,0,0-.9028,2.0046L9.5859,7.5886A.5407.5407,0,0,1,9.08,7.0184ZM25.5944,21.07a2.9883,2.9883,0,0,1-3.4112.8373c-4.5313-1.3305-8.6289-1.0534-12.2124.82l1.9069-5.978-7.203,7.6393a11.67,11.67,0,0,1,3.3532-8.3419,11.4953,11.4953,0,0,1,4.1073-2.6908,5.42,5.42,0,0,0,2.2411,1.2214,4.714,4.714,0,0,0,.5627.12,1.6258,1.6258,0,0,0,.2449,1.6416l.0847.1038a1.6247,1.6247,0,0,0,.2594,1.605l.5532.6777a1.6276,1.6276,0,0,0,2.29.2314l.3314-.2705a1.7079,1.7079,0,0,0,1.9867-2.6535l-1.9427-2.3911a4.88,4.88,0,0,0,.4863-.456,12.449,12.449,0,0,1,1.3829.5181,11.419,11.419,0,0,1,4.5085,3.6838C26.0987,18.7278,26.2745,20.1043,25.5944,21.07Z"
  })), children);
});
var LogoKeybase20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoKeybase20(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.1233 26.9328a1.1122 1.1122 0 11-1.1121-1.1122 1.112 1.112 0 011.1121 1.1122M21.0257 26.9328a1.1122 1.1122 0 11-1.1122-1.1122 1.1121 1.1121 0 011.1122 1.1122"
  })), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.999 5.797H10.973V6.771H9.999z",
    transform: "rotate(-86.462 10.486 6.284)"
  })), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.4275,16.3825l-.0013.001a13.0868,13.0868,0,0,0-5.1431-4.1825c-.3754-.1667-.7543-.3142-1.1354-.4454.0128-.0314.0277-.0615.04-.0933a4.83,4.83,0,0,0-2.9861-6.319,5.9368,5.9368,0,0,0-1.9962-.3558c-.0366-.1253-.1165-.6743.58-2.1571L14.3742,2q-.17.236-.3368.4661c-.384.5309-.7549,1.0444-1.1029,1.55a2.1657,2.1657,0,0,0-1.4486-.6771L9.8543,3.2377H9.852l-.0025,0c-.0429-.0025-.0864-.0039-.1293-.0039A2.1877,2.1877,0,0,0,7.54,5.2825L7.4388,6.9169l0,.003,0,.0028A2.1882,2.1882,0,0,0,9.4854,9.23l1.1673.0723a5.1711,5.1711,0,0,0,.47,2.688,13.1954,13.1954,0,0,0-4.2637,2.9C3,18.7883,3,23.06,3,26.4916v2.0706l1.524-1.6163A12.3293,12.3293,0,0,0,5.8548,30H7.8367A10.7091,10.7091,0,0,1,5.878,25.51l2.2353-2.3708L6.963,26.745l2.03-1.4774c3.5858-2.61,7.8678-3.2093,12.7263-1.7826a4.6276,4.6276,0,0,0,5.2189-1.468c.0441-.0628.0828-.128.1228-.1926a9.6141,9.6141,0,0,1,.1638,1.7454,12.4214,12.4214,0,0,1-1.61,6.43h1.877A14.4022,14.4022,0,0,0,28.87,23.57,12.2666,12.2666,0,0,0,26.4275,16.3825ZM13.8455,5.9257a1.5872,1.5872,0,0,0,1.3983.7068,4.2111,4.2111,0,0,1,1.44.2719,3.17,3.17,0,0,1,1.0279,5.4638l-.4752-.5849-.0032-.004a1.7048,1.7048,0,0,0-3.0235.9865,3.2143,3.2143,0,0,1-1.899-3.5412,8.4815,8.4815,0,0,1,1.4374-3.466A1.642,1.642,0,0,0,13.8455,5.9257Zm3.49,9.2589-.6072.4962a.2675.2675,0,0,1-.376-.038l-.1264-.1549a.2791.2791,0,0,1,.0394-.3927l.6-.49-1.235-1.5158a.362.362,0,1,1,.5611-.4575l3.4546,4.2517a.3619.3619,0,0,1-.1988.5815.3566.3566,0,0,1-.0816.0094.3609.3609,0,0,1-.2806-.1332l-.3441-.4239-1.2215.9971a.2815.2815,0,0,1-.3965-.04l-.5532-.6775a.2786.2786,0,0,1,.04-.3919l1.2275-1.002ZM9.08,7.0184l.1014-1.6342A.5394.5394,0,0,1,9.72,4.8781l.0326.001,1.6335.1013a.5387.5387,0,0,1,.5046.5716l-.0073.1182a10.6739,10.6739,0,0,0-.9028,2.0046L9.5859,7.5886A.5407.5407,0,0,1,9.08,7.0184ZM25.5944,21.07a2.9883,2.9883,0,0,1-3.4112.8373c-4.5313-1.3305-8.6289-1.0534-12.2124.82l1.9069-5.978-7.203,7.6393a11.67,11.67,0,0,1,3.3532-8.3419,11.4953,11.4953,0,0,1,4.1073-2.6908,5.42,5.42,0,0,0,2.2411,1.2214,4.714,4.714,0,0,0,.5627.12,1.6258,1.6258,0,0,0,.2449,1.6416l.0847.1038a1.6247,1.6247,0,0,0,.2594,1.605l.5532.6777a1.6276,1.6276,0,0,0,2.29.2314l.3314-.2705a1.7079,1.7079,0,0,0,1.9867-2.6535l-1.9427-2.3911a4.88,4.88,0,0,0,.4863-.456,12.449,12.449,0,0,1,1.3829.5181,11.419,11.419,0,0,1,4.5085,3.6838C26.0987,18.7278,26.2745,20.1043,25.5944,21.07Z"
  })), children);
});
var LogoKeybase16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoKeybase16(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.1233 26.9328a1.1122 1.1122 0 11-1.1121-1.1122 1.112 1.112 0 011.1121 1.1122M21.0257 26.9328a1.1122 1.1122 0 11-1.1122-1.1122 1.1121 1.1121 0 011.1122 1.1122"
  })), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.999 5.797H10.973V6.771H9.999z",
    transform: "rotate(-86.462 10.486 6.284)"
  })), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.4275,16.3825l-.0013.001a13.0868,13.0868,0,0,0-5.1431-4.1825c-.3754-.1667-.7543-.3142-1.1354-.4454.0128-.0314.0277-.0615.04-.0933a4.83,4.83,0,0,0-2.9861-6.319,5.9368,5.9368,0,0,0-1.9962-.3558c-.0366-.1253-.1165-.6743.58-2.1571L14.3742,2q-.17.236-.3368.4661c-.384.5309-.7549,1.0444-1.1029,1.55a2.1657,2.1657,0,0,0-1.4486-.6771L9.8543,3.2377H9.852l-.0025,0c-.0429-.0025-.0864-.0039-.1293-.0039A2.1877,2.1877,0,0,0,7.54,5.2825L7.4388,6.9169l0,.003,0,.0028A2.1882,2.1882,0,0,0,9.4854,9.23l1.1673.0723a5.1711,5.1711,0,0,0,.47,2.688,13.1954,13.1954,0,0,0-4.2637,2.9C3,18.7883,3,23.06,3,26.4916v2.0706l1.524-1.6163A12.3293,12.3293,0,0,0,5.8548,30H7.8367A10.7091,10.7091,0,0,1,5.878,25.51l2.2353-2.3708L6.963,26.745l2.03-1.4774c3.5858-2.61,7.8678-3.2093,12.7263-1.7826a4.6276,4.6276,0,0,0,5.2189-1.468c.0441-.0628.0828-.128.1228-.1926a9.6141,9.6141,0,0,1,.1638,1.7454,12.4214,12.4214,0,0,1-1.61,6.43h1.877A14.4022,14.4022,0,0,0,28.87,23.57,12.2666,12.2666,0,0,0,26.4275,16.3825ZM13.8455,5.9257a1.5872,1.5872,0,0,0,1.3983.7068,4.2111,4.2111,0,0,1,1.44.2719,3.17,3.17,0,0,1,1.0279,5.4638l-.4752-.5849-.0032-.004a1.7048,1.7048,0,0,0-3.0235.9865,3.2143,3.2143,0,0,1-1.899-3.5412,8.4815,8.4815,0,0,1,1.4374-3.466A1.642,1.642,0,0,0,13.8455,5.9257Zm3.49,9.2589-.6072.4962a.2675.2675,0,0,1-.376-.038l-.1264-.1549a.2791.2791,0,0,1,.0394-.3927l.6-.49-1.235-1.5158a.362.362,0,1,1,.5611-.4575l3.4546,4.2517a.3619.3619,0,0,1-.1988.5815.3566.3566,0,0,1-.0816.0094.3609.3609,0,0,1-.2806-.1332l-.3441-.4239-1.2215.9971a.2815.2815,0,0,1-.3965-.04l-.5532-.6775a.2786.2786,0,0,1,.04-.3919l1.2275-1.002ZM9.08,7.0184l.1014-1.6342A.5394.5394,0,0,1,9.72,4.8781l.0326.001,1.6335.1013a.5387.5387,0,0,1,.5046.5716l-.0073.1182a10.6739,10.6739,0,0,0-.9028,2.0046L9.5859,7.5886A.5407.5407,0,0,1,9.08,7.0184ZM25.5944,21.07a2.9883,2.9883,0,0,1-3.4112.8373c-4.5313-1.3305-8.6289-1.0534-12.2124.82l1.9069-5.978-7.203,7.6393a11.67,11.67,0,0,1,3.3532-8.3419,11.4953,11.4953,0,0,1,4.1073-2.6908,5.42,5.42,0,0,0,2.2411,1.2214,4.714,4.714,0,0,0,.5627.12,1.6258,1.6258,0,0,0,.2449,1.6416l.0847.1038a1.6247,1.6247,0,0,0,.2594,1.605l.5532.6777a1.6276,1.6276,0,0,0,2.29.2314l.3314-.2705a1.7079,1.7079,0,0,0,1.9867-2.6535l-1.9427-2.3911a4.88,4.88,0,0,0,.4863-.456,12.449,12.449,0,0,1,1.3829.5181,11.419,11.419,0,0,1,4.5085,3.6838C26.0987,18.7278,26.2745,20.1043,25.5944,21.07Z"
  })), children);
});
var LogoLinkedin32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoLinkedin32(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.2,4H5.8C4.8,4,4,4.8,4,5.7v20.5c0,0.9,0.8,1.7,1.8,1.7h20.4c1,0,1.8-0.8,1.8-1.7V5.7C28,4.8,27.2,4,26.2,4z M11.1,24.4\tH7.6V13h3.5V24.4z M9.4,11.4c-1.1,0-2.1-0.9-2.1-2.1c0-1.2,0.9-2.1,2.1-2.1c1.1,0,2.1,0.9,2.1,2.1S10.5,11.4,9.4,11.4z M24.5,24.3\tH21v-5.6c0-1.3,0-3.1-1.9-3.1c-1.9,0-2.1,1.5-2.1,2.9v5.7h-3.5V13h3.3v1.5h0.1c0.5-0.9,1.7-1.9,3.4-1.9c3.6,0,4.3,2.4,4.3,5.5V24.3z"
  })), children);
});
var LogoLinkedin24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoLinkedin24(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.2,4H5.8C4.8,4,4,4.8,4,5.7v20.5c0,0.9,0.8,1.7,1.8,1.7h20.4c1,0,1.8-0.8,1.8-1.7V5.7C28,4.8,27.2,4,26.2,4z M11.1,24.4\tH7.6V13h3.5V24.4z M9.4,11.4c-1.1,0-2.1-0.9-2.1-2.1c0-1.2,0.9-2.1,2.1-2.1c1.1,0,2.1,0.9,2.1,2.1S10.5,11.4,9.4,11.4z M24.5,24.3\tH21v-5.6c0-1.3,0-3.1-1.9-3.1c-1.9,0-2.1,1.5-2.1,2.9v5.7h-3.5V13h3.3v1.5h0.1c0.5-0.9,1.7-1.9,3.4-1.9c3.6,0,4.3,2.4,4.3,5.5V24.3z"
  })), children);
});
var LogoLinkedin20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoLinkedin20(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.2,4H5.8C4.8,4,4,4.8,4,5.7v20.5c0,0.9,0.8,1.7,1.8,1.7h20.4c1,0,1.8-0.8,1.8-1.7V5.7C28,4.8,27.2,4,26.2,4z M11.1,24.4\tH7.6V13h3.5V24.4z M9.4,11.4c-1.1,0-2.1-0.9-2.1-2.1c0-1.2,0.9-2.1,2.1-2.1c1.1,0,2.1,0.9,2.1,2.1S10.5,11.4,9.4,11.4z M24.5,24.3\tH21v-5.6c0-1.3,0-3.1-1.9-3.1c-1.9,0-2.1,1.5-2.1,2.9v5.7h-3.5V13h3.3v1.5h0.1c0.5-0.9,1.7-1.9,3.4-1.9c3.6,0,4.3,2.4,4.3,5.5V24.3z"
  })), children);
});
var LogoLinkedin16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoLinkedin16(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.2,4H5.8C4.8,4,4,4.8,4,5.7v20.5c0,0.9,0.8,1.7,1.8,1.7h20.4c1,0,1.8-0.8,1.8-1.7V5.7C28,4.8,27.2,4,26.2,4z M11.1,24.4\tH7.6V13h3.5V24.4z M9.4,11.4c-1.1,0-2.1-0.9-2.1-2.1c0-1.2,0.9-2.1,2.1-2.1c1.1,0,2.1,0.9,2.1,2.1S10.5,11.4,9.4,11.4z M24.5,24.3\tH21v-5.6c0-1.3,0-3.1-1.9-3.1c-1.9,0-2.1,1.5-2.1,2.9v5.7h-3.5V13h3.3v1.5h0.1c0.5-0.9,1.7-1.9,3.4-1.9c3.6,0,4.3,2.4,4.3,5.5V24.3z"
  })), children);
});
var LogoLivestream32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoLivestream32(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.49 23.71h-.76c-2.26 0-4.52 0-6.78 0a3.12 3.12 0 01-2.41-1A14.91 14.91 0 0110 18.88c-1.3-2.6-2.54-5.22-3.82-7.82-.39-.8-.82-1.56-1.28-2.32A7.84 7.84 0 002 5.6c1.24 0 2.41 0 3.57 0a45.63 45.63 0 017 .61 8.09 8.09 0 016.34 5.09 48.51 48.51 0 012.17 7.36A26 26 0 0022.49 23.71zM28.1 26.38a2.93 2.93 0 01-2.74-2.64 42.08 42.08 0 01-.14-4.9 48 48 0 00-.61-7.58 3.75 3.75 0 00-.83-2h2.65c.54 0 .73.37.89.78A12.1 12.1 0 0128 13.28c.29 2.72.31 5.45.33 8.18a10.94 10.94 0 000 1.15c.09.78.4 1.1 1.17 1.08.5 0 .5-.06.5-.06v2.69A8.62 8.62 0 0128.1 26.38z"
  })), children);
});
var LogoLivestream24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoLivestream24(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.49 23.71h-.76c-2.26 0-4.52 0-6.78 0a3.12 3.12 0 01-2.41-1A14.91 14.91 0 0110 18.88c-1.3-2.6-2.54-5.22-3.82-7.82-.39-.8-.82-1.56-1.28-2.32A7.84 7.84 0 002 5.6c1.24 0 2.41 0 3.57 0a45.63 45.63 0 017 .61 8.09 8.09 0 016.34 5.09 48.51 48.51 0 012.17 7.36A26 26 0 0022.49 23.71zM28.1 26.38a2.93 2.93 0 01-2.74-2.64 42.08 42.08 0 01-.14-4.9 48 48 0 00-.61-7.58 3.75 3.75 0 00-.83-2h2.65c.54 0 .73.37.89.78A12.1 12.1 0 0128 13.28c.29 2.72.31 5.45.33 8.18a10.94 10.94 0 000 1.15c.09.78.4 1.1 1.17 1.08.5 0 .5-.06.5-.06v2.69A8.62 8.62 0 0128.1 26.38z"
  })), children);
});
var LogoLivestream20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoLivestream20(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.49 23.71h-.76c-2.26 0-4.52 0-6.78 0a3.12 3.12 0 01-2.41-1A14.91 14.91 0 0110 18.88c-1.3-2.6-2.54-5.22-3.82-7.82-.39-.8-.82-1.56-1.28-2.32A7.84 7.84 0 002 5.6c1.24 0 2.41 0 3.57 0a45.63 45.63 0 017 .61 8.09 8.09 0 016.34 5.09 48.51 48.51 0 012.17 7.36A26 26 0 0022.49 23.71zM28.1 26.38a2.93 2.93 0 01-2.74-2.64 42.08 42.08 0 01-.14-4.9 48 48 0 00-.61-7.58 3.75 3.75 0 00-.83-2h2.65c.54 0 .73.37.89.78A12.1 12.1 0 0128 13.28c.29 2.72.31 5.45.33 8.18a10.94 10.94 0 000 1.15c.09.78.4 1.1 1.17 1.08.5 0 .5-.06.5-.06v2.69A8.62 8.62 0 0128.1 26.38z"
  })), children);
});
var LogoLivestream16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoLivestream16(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.49 23.71h-.76c-2.26 0-4.52 0-6.78 0a3.12 3.12 0 01-2.41-1A14.91 14.91 0 0110 18.88c-1.3-2.6-2.54-5.22-3.82-7.82-.39-.8-.82-1.56-1.28-2.32A7.84 7.84 0 002 5.6c1.24 0 2.41 0 3.57 0a45.63 45.63 0 017 .61 8.09 8.09 0 016.34 5.09 48.51 48.51 0 012.17 7.36A26 26 0 0022.49 23.71zM28.1 26.38a2.93 2.93 0 01-2.74-2.64 42.08 42.08 0 01-.14-4.9 48 48 0 00-.61-7.58 3.75 3.75 0 00-.83-2h2.65c.54 0 .73.37.89.78A12.1 12.1 0 0128 13.28c.29 2.72.31 5.45.33 8.18a10.94 10.94 0 000 1.15c.09.78.4 1.1 1.17 1.08.5 0 .5-.06.5-.06v2.69A8.62 8.62 0 0128.1 26.38z"
  })), children);
});
var LogoMedium32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoMedium32(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,4V28H28V4ZM23.9385,9.6865,22.6514,10.92a.3766.3766,0,0,0-.1431.3613v9.0674a.3765.3765,0,0,0,.1431.3613l1.257,1.2339v.271h-6.323v-.271L18.8877,20.68c.1279-.128.1279-.1656.1279-.3609V12.99l-3.62,9.1958H14.906L10.6907,12.99v6.1631a.8505.8505,0,0,0,.2334.7071l1.6936,2.0547v.2709H7.8154v-.2709L9.509,19.86a.82.82,0,0,0,.2183-.7071V12.0264A.6231.6231,0,0,0,9.5239,11.5L8.0186,9.6865v-.271h4.6743l3.613,7.9239,3.1765-7.9239h4.4561Z"
  })), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M9.7273,12.0266A.6246.6246,0,0,0,9.524,11.5L8.0186,9.6863V9.4154H12.693l3.613,7.9238,3.1764-7.9238h4.4561v.2709L22.6513,10.92a.3763.3763,0,0,0-.143.3612v9.0676a.3763.3763,0,0,0,.143.3612l1.2571,1.2341v.2709H17.5856v-.2709L18.8878,20.68c.1279-.1279.1279-.1656.1279-.3612V12.99l-3.62,9.1955h-.4893L10.6907,12.99v6.1629a.8506.8506,0,0,0,.2334.7074l1.6936,2.0543v.2709H7.8154v-.2709L9.509,19.86a.82.82,0,0,0,.2183-.7074Z",
    "data-icon-path": "inner-path"
  })), children);
});
var LogoMedium24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoMedium24(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,4V28H28V4ZM23.9385,9.6865,22.6514,10.92a.3766.3766,0,0,0-.1431.3613v9.0674a.3765.3765,0,0,0,.1431.3613l1.257,1.2339v.271h-6.323v-.271L18.8877,20.68c.1279-.128.1279-.1656.1279-.3609V12.99l-3.62,9.1958H14.906L10.6907,12.99v6.1631a.8505.8505,0,0,0,.2334.7071l1.6936,2.0547v.2709H7.8154v-.2709L9.509,19.86a.82.82,0,0,0,.2183-.7071V12.0264A.6231.6231,0,0,0,9.5239,11.5L8.0186,9.6865v-.271h4.6743l3.613,7.9239,3.1765-7.9239h4.4561Z"
  })), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M9.7273,12.0266A.6246.6246,0,0,0,9.524,11.5L8.0186,9.6863V9.4154H12.693l3.613,7.9238,3.1764-7.9238h4.4561v.2709L22.6513,10.92a.3763.3763,0,0,0-.143.3612v9.0676a.3763.3763,0,0,0,.143.3612l1.2571,1.2341v.2709H17.5856v-.2709L18.8878,20.68c.1279-.1279.1279-.1656.1279-.3612V12.99l-3.62,9.1955h-.4893L10.6907,12.99v6.1629a.8506.8506,0,0,0,.2334.7074l1.6936,2.0543v.2709H7.8154v-.2709L9.509,19.86a.82.82,0,0,0,.2183-.7074Z",
    "data-icon-path": "inner-path"
  })), children);
});
var LogoMedium20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoMedium20(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,4V28H28V4ZM23.9385,9.6865,22.6514,10.92a.3766.3766,0,0,0-.1431.3613v9.0674a.3765.3765,0,0,0,.1431.3613l1.257,1.2339v.271h-6.323v-.271L18.8877,20.68c.1279-.128.1279-.1656.1279-.3609V12.99l-3.62,9.1958H14.906L10.6907,12.99v6.1631a.8505.8505,0,0,0,.2334.7071l1.6936,2.0547v.2709H7.8154v-.2709L9.509,19.86a.82.82,0,0,0,.2183-.7071V12.0264A.6231.6231,0,0,0,9.5239,11.5L8.0186,9.6865v-.271h4.6743l3.613,7.9239,3.1765-7.9239h4.4561Z"
  })), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M9.7273,12.0266A.6246.6246,0,0,0,9.524,11.5L8.0186,9.6863V9.4154H12.693l3.613,7.9238,3.1764-7.9238h4.4561v.2709L22.6513,10.92a.3763.3763,0,0,0-.143.3612v9.0676a.3763.3763,0,0,0,.143.3612l1.2571,1.2341v.2709H17.5856v-.2709L18.8878,20.68c.1279-.1279.1279-.1656.1279-.3612V12.99l-3.62,9.1955h-.4893L10.6907,12.99v6.1629a.8506.8506,0,0,0,.2334.7074l1.6936,2.0543v.2709H7.8154v-.2709L9.509,19.86a.82.82,0,0,0,.2183-.7074Z",
    "data-icon-path": "inner-path"
  })), children);
});
var LogoMedium16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoMedium16(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,4V28H28V4ZM23.9385,9.6865,22.6514,10.92a.3766.3766,0,0,0-.1431.3613v9.0674a.3765.3765,0,0,0,.1431.3613l1.257,1.2339v.271h-6.323v-.271L18.8877,20.68c.1279-.128.1279-.1656.1279-.3609V12.99l-3.62,9.1958H14.906L10.6907,12.99v6.1631a.8505.8505,0,0,0,.2334.7071l1.6936,2.0547v.2709H7.8154v-.2709L9.509,19.86a.82.82,0,0,0,.2183-.7071V12.0264A.6231.6231,0,0,0,9.5239,11.5L8.0186,9.6865v-.271h4.6743l3.613,7.9239,3.1765-7.9239h4.4561Z"
  })), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M9.7273,12.0266A.6246.6246,0,0,0,9.524,11.5L8.0186,9.6863V9.4154H12.693l3.613,7.9238,3.1764-7.9238h4.4561v.2709L22.6513,10.92a.3763.3763,0,0,0-.143.3612v9.0676a.3763.3763,0,0,0,.143.3612l1.2571,1.2341v.2709H17.5856v-.2709L18.8878,20.68c.1279-.1279.1279-.1656.1279-.3612V12.99l-3.62,9.1955h-.4893L10.6907,12.99v6.1629a.8506.8506,0,0,0,.2334.7074l1.6936,2.0543v.2709H7.8154v-.2709L9.509,19.86a.82.82,0,0,0,.2183-.7074Z",
    "data-icon-path": "inner-path"
  })), children);
});
var LogoOpenshift32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoOpenshift32(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.4612,15.7968A12.1352,12.1352,0,0,0,25.2821,11.48L29,10.13a11.9879,11.9879,0,0,0-1.0281-1.7382l-1.7431.635a11.9884,11.9884,0,0,0-21.71,7.9129l1.7477-.6412a12.19,12.19,0,0,0,.3309,1.9846L2.8838,19.6384A12.1451,12.1451,0,0,0,4.7565,23.7l1.9663-.7163.0026.0039a11.8856,11.8856,0,0,0,4.67,3.8909A12.013,12.013,0,0,0,27.34,21.0743a11.8725,11.8725,0,0,0,1.08-5.992Zm-2.92,3.4967a7.8,7.8,0,0,1-10.3533,3.7744,7.7207,7.7207,0,0,1-2.2714-1.6128l-1.9846.7235a7.84,7.84,0,0,1-2.0742-3.9895l.0009-.0008,3.7242-1.3566a7.8175,7.8175,0,0,1-.1232-2.0653l-1.7517.6362A7.7729,7.7729,0,0,1,19.7645,8.94h.0067a7.7442,7.7442,0,0,1,2.2646,1.615L23.78,9.921a7.8014,7.8014,0,0,1,1.229,1.6558l-3.71,1.3595a7.8245,7.8245,0,0,1,.9766,4.3882l1.9685-.7151A7.6714,7.6714,0,0,1,23.5411,19.2935Z"
  })), children);
});
var LogoOpenshift24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoOpenshift24(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.4612,15.7968A12.1352,12.1352,0,0,0,25.2821,11.48L29,10.13a11.9879,11.9879,0,0,0-1.0281-1.7382l-1.7431.635a11.9884,11.9884,0,0,0-21.71,7.9129l1.7477-.6412a12.19,12.19,0,0,0,.3309,1.9846L2.8838,19.6384A12.1451,12.1451,0,0,0,4.7565,23.7l1.9663-.7163.0026.0039a11.8856,11.8856,0,0,0,4.67,3.8909A12.013,12.013,0,0,0,27.34,21.0743a11.8725,11.8725,0,0,0,1.08-5.992Zm-2.92,3.4967a7.8,7.8,0,0,1-10.3533,3.7744,7.7207,7.7207,0,0,1-2.2714-1.6128l-1.9846.7235a7.84,7.84,0,0,1-2.0742-3.9895l.0009-.0008,3.7242-1.3566a7.8175,7.8175,0,0,1-.1232-2.0653l-1.7517.6362A7.7729,7.7729,0,0,1,19.7645,8.94h.0067a7.7442,7.7442,0,0,1,2.2646,1.615L23.78,9.921a7.8014,7.8014,0,0,1,1.229,1.6558l-3.71,1.3595a7.8245,7.8245,0,0,1,.9766,4.3882l1.9685-.7151A7.6714,7.6714,0,0,1,23.5411,19.2935Z"
  })), children);
});
var LogoOpenshift20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoOpenshift20(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.4612,15.7968A12.1352,12.1352,0,0,0,25.2821,11.48L29,10.13a11.9879,11.9879,0,0,0-1.0281-1.7382l-1.7431.635a11.9884,11.9884,0,0,0-21.71,7.9129l1.7477-.6412a12.19,12.19,0,0,0,.3309,1.9846L2.8838,19.6384A12.1451,12.1451,0,0,0,4.7565,23.7l1.9663-.7163.0026.0039a11.8856,11.8856,0,0,0,4.67,3.8909A12.013,12.013,0,0,0,27.34,21.0743a11.8725,11.8725,0,0,0,1.08-5.992Zm-2.92,3.4967a7.8,7.8,0,0,1-10.3533,3.7744,7.7207,7.7207,0,0,1-2.2714-1.6128l-1.9846.7235a7.84,7.84,0,0,1-2.0742-3.9895l.0009-.0008,3.7242-1.3566a7.8175,7.8175,0,0,1-.1232-2.0653l-1.7517.6362A7.7729,7.7729,0,0,1,19.7645,8.94h.0067a7.7442,7.7442,0,0,1,2.2646,1.615L23.78,9.921a7.8014,7.8014,0,0,1,1.229,1.6558l-3.71,1.3595a7.8245,7.8245,0,0,1,.9766,4.3882l1.9685-.7151A7.6714,7.6714,0,0,1,23.5411,19.2935Z"
  })), children);
});
var LogoOpenshift16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoOpenshift16(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.4612,15.7968A12.1352,12.1352,0,0,0,25.2821,11.48L29,10.13a11.9879,11.9879,0,0,0-1.0281-1.7382l-1.7431.635a11.9884,11.9884,0,0,0-21.71,7.9129l1.7477-.6412a12.19,12.19,0,0,0,.3309,1.9846L2.8838,19.6384A12.1451,12.1451,0,0,0,4.7565,23.7l1.9663-.7163.0026.0039a11.8856,11.8856,0,0,0,4.67,3.8909A12.013,12.013,0,0,0,27.34,21.0743a11.8725,11.8725,0,0,0,1.08-5.992Zm-2.92,3.4967a7.8,7.8,0,0,1-10.3533,3.7744,7.7207,7.7207,0,0,1-2.2714-1.6128l-1.9846.7235a7.84,7.84,0,0,1-2.0742-3.9895l.0009-.0008,3.7242-1.3566a7.8175,7.8175,0,0,1-.1232-2.0653l-1.7517.6362A7.7729,7.7729,0,0,1,19.7645,8.94h.0067a7.7442,7.7442,0,0,1,2.2646,1.615L23.78,9.921a7.8014,7.8014,0,0,1,1.229,1.6558l-3.71,1.3595a7.8245,7.8245,0,0,1,.9766,4.3882l1.9685-.7151A7.6714,7.6714,0,0,1,23.5411,19.2935Z"
  })), children);
});
var LogoPinterest32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoPinterest32(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2a14,14,0,0,0-5.1,27,13.24,13.24,0,0,1,0-4l1.65-7A5.05,5.05,0,0,1,12.17,16c0-1.94,1.13-3.4,2.53-3.4a1.76,1.76,0,0,1,1.77,2c0,1.2-.76,3-1.16,4.66a2,2,0,0,0,2.08,2.53c2.48,0,4.4-2.63,4.4-6.41a5.53,5.53,0,0,0-5.85-5.7,6.06,6.06,0,0,0-6.32,6.08,5.42,5.42,0,0,0,1,3.19.44.44,0,0,1,.1.4c-.11.44-.35,1.4-.39,1.59s-.21.31-.47.19c-1.75-.82-2.84-3.37-2.84-5.43,0-4.41,3.21-8.47,9.25-8.47,4.85,0,8.63,3.46,8.63,8.09,0,4.82-3,8.7-7.27,8.7a3.76,3.76,0,0,1-3.21-1.6l-.87,3.33a15.55,15.55,0,0,1-1.74,3.67A14.17,14.17,0,0,0,16,30,14,14,0,0,0,16,2"
  })), children);
});
var LogoPinterest24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoPinterest24(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2a14,14,0,0,0-5.1,27,13.24,13.24,0,0,1,0-4l1.65-7A5.05,5.05,0,0,1,12.17,16c0-1.94,1.13-3.4,2.53-3.4a1.76,1.76,0,0,1,1.77,2c0,1.2-.76,3-1.16,4.66a2,2,0,0,0,2.08,2.53c2.48,0,4.4-2.63,4.4-6.41a5.53,5.53,0,0,0-5.85-5.7,6.06,6.06,0,0,0-6.32,6.08,5.42,5.42,0,0,0,1,3.19.44.44,0,0,1,.1.4c-.11.44-.35,1.4-.39,1.59s-.21.31-.47.19c-1.75-.82-2.84-3.37-2.84-5.43,0-4.41,3.21-8.47,9.25-8.47,4.85,0,8.63,3.46,8.63,8.09,0,4.82-3,8.7-7.27,8.7a3.76,3.76,0,0,1-3.21-1.6l-.87,3.33a15.55,15.55,0,0,1-1.74,3.67A14.17,14.17,0,0,0,16,30,14,14,0,0,0,16,2"
  })), children);
});
var LogoPinterest20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoPinterest20(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2a14,14,0,0,0-5.1,27,13.24,13.24,0,0,1,0-4l1.65-7A5.05,5.05,0,0,1,12.17,16c0-1.94,1.13-3.4,2.53-3.4a1.76,1.76,0,0,1,1.77,2c0,1.2-.76,3-1.16,4.66a2,2,0,0,0,2.08,2.53c2.48,0,4.4-2.63,4.4-6.41a5.53,5.53,0,0,0-5.85-5.7,6.06,6.06,0,0,0-6.32,6.08,5.42,5.42,0,0,0,1,3.19.44.44,0,0,1,.1.4c-.11.44-.35,1.4-.39,1.59s-.21.31-.47.19c-1.75-.82-2.84-3.37-2.84-5.43,0-4.41,3.21-8.47,9.25-8.47,4.85,0,8.63,3.46,8.63,8.09,0,4.82-3,8.7-7.27,8.7a3.76,3.76,0,0,1-3.21-1.6l-.87,3.33a15.55,15.55,0,0,1-1.74,3.67A14.17,14.17,0,0,0,16,30,14,14,0,0,0,16,2"
  })), children);
});
var LogoPinterest16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoPinterest16(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2a14,14,0,0,0-5.1,27,13.24,13.24,0,0,1,0-4l1.65-7A5.05,5.05,0,0,1,12.17,16c0-1.94,1.13-3.4,2.53-3.4a1.76,1.76,0,0,1,1.77,2c0,1.2-.76,3-1.16,4.66a2,2,0,0,0,2.08,2.53c2.48,0,4.4-2.63,4.4-6.41a5.53,5.53,0,0,0-5.85-5.7,6.06,6.06,0,0,0-6.32,6.08,5.42,5.42,0,0,0,1,3.19.44.44,0,0,1,.1.4c-.11.44-.35,1.4-.39,1.59s-.21.31-.47.19c-1.75-.82-2.84-3.37-2.84-5.43,0-4.41,3.21-8.47,9.25-8.47,4.85,0,8.63,3.46,8.63,8.09,0,4.82-3,8.7-7.27,8.7a3.76,3.76,0,0,1-3.21-1.6l-.87,3.33a15.55,15.55,0,0,1-1.74,3.67A14.17,14.17,0,0,0,16,30,14,14,0,0,0,16,2"
  })), children);
});
var LogoPython32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoPython32(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.4882,9.14v2.9663a4.2843,4.2843,0,0,1-4.173,4.2352H12.6431a3.4077,3.4077,0,0,0-3.34,3.3945v6.3607c0,1.81,1.5742,2.8751,3.34,3.3945a11.1762,11.1762,0,0,0,6.6721,0c1.6817-.4869,3.34-1.4668,3.34-3.3945V23.55H15.983v-.8486H25.9951c1.9414,0,2.6648-1.3542,3.34-3.3867a11.4642,11.4642,0,0,0,0-6.7889c-.48-1.9327-1.3961-3.3867-3.34-3.3867ZM19.7356,25.2476a1.2731,1.2731,0,1,1-1.2534,1.269A1.2607,1.2607,0,0,1,19.7356,25.2476Z"
  })), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M19.7356,25.2476a1.2731,1.2731,0,1,1-1.2534,1.269A1.2607,1.2607,0,0,1,19.7356,25.2476Z"
  })), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.8351,2a19.0717,19.0717,0,0,0-3.192.2725c-2.8268.4994-3.34,1.5447-3.34,3.4723V8.2909h6.68V9.14H6.7962a4.1708,4.1708,0,0,0-4.173,3.3867,12.4855,12.4855,0,0,0,0,6.7889c.4748,1.9776,1.6088,3.3867,3.55,3.3867H8.47V19.65a4.2449,4.2449,0,0,1,4.173-4.15h6.6721a3.3654,3.3654,0,0,0,3.34-3.3944V5.745a3.729,3.729,0,0,0-3.34-3.4723A20.8377,20.8377,0,0,0,15.8351,2ZM12.2226,4.0478a1.2731,1.2731,0,1,1-1.2534,1.2768A1.2675,1.2675,0,0,1,12.2226,4.0478Z"
  })), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M12.2226,4.0478a1.2731,1.2731,0,1,1-1.2534,1.2768A1.2675,1.2675,0,0,1,12.2226,4.0478Z"
  })), children);
});
var LogoPython24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoPython24(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.4882,9.14v2.9663a4.2843,4.2843,0,0,1-4.173,4.2352H12.6431a3.4077,3.4077,0,0,0-3.34,3.3945v6.3607c0,1.81,1.5742,2.8751,3.34,3.3945a11.1762,11.1762,0,0,0,6.6721,0c1.6817-.4869,3.34-1.4668,3.34-3.3945V23.55H15.983v-.8486H25.9951c1.9414,0,2.6648-1.3542,3.34-3.3867a11.4642,11.4642,0,0,0,0-6.7889c-.48-1.9327-1.3961-3.3867-3.34-3.3867ZM19.7356,25.2476a1.2731,1.2731,0,1,1-1.2534,1.269A1.2607,1.2607,0,0,1,19.7356,25.2476Z"
  })), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M19.7356,25.2476a1.2731,1.2731,0,1,1-1.2534,1.269A1.2607,1.2607,0,0,1,19.7356,25.2476Z"
  })), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.8351,2a19.0717,19.0717,0,0,0-3.192.2725c-2.8268.4994-3.34,1.5447-3.34,3.4723V8.2909h6.68V9.14H6.7962a4.1708,4.1708,0,0,0-4.173,3.3867,12.4855,12.4855,0,0,0,0,6.7889c.4748,1.9776,1.6088,3.3867,3.55,3.3867H8.47V19.65a4.2449,4.2449,0,0,1,4.173-4.15h6.6721a3.3654,3.3654,0,0,0,3.34-3.3944V5.745a3.729,3.729,0,0,0-3.34-3.4723A20.8377,20.8377,0,0,0,15.8351,2ZM12.2226,4.0478a1.2731,1.2731,0,1,1-1.2534,1.2768A1.2675,1.2675,0,0,1,12.2226,4.0478Z"
  })), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M12.2226,4.0478a1.2731,1.2731,0,1,1-1.2534,1.2768A1.2675,1.2675,0,0,1,12.2226,4.0478Z"
  })), children);
});
var LogoPython20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoPython20(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.4882,9.14v2.9663a4.2843,4.2843,0,0,1-4.173,4.2352H12.6431a3.4077,3.4077,0,0,0-3.34,3.3945v6.3607c0,1.81,1.5742,2.8751,3.34,3.3945a11.1762,11.1762,0,0,0,6.6721,0c1.6817-.4869,3.34-1.4668,3.34-3.3945V23.55H15.983v-.8486H25.9951c1.9414,0,2.6648-1.3542,3.34-3.3867a11.4642,11.4642,0,0,0,0-6.7889c-.48-1.9327-1.3961-3.3867-3.34-3.3867ZM19.7356,25.2476a1.2731,1.2731,0,1,1-1.2534,1.269A1.2607,1.2607,0,0,1,19.7356,25.2476Z"
  })), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M19.7356,25.2476a1.2731,1.2731,0,1,1-1.2534,1.269A1.2607,1.2607,0,0,1,19.7356,25.2476Z"
  })), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.8351,2a19.0717,19.0717,0,0,0-3.192.2725c-2.8268.4994-3.34,1.5447-3.34,3.4723V8.2909h6.68V9.14H6.7962a4.1708,4.1708,0,0,0-4.173,3.3867,12.4855,12.4855,0,0,0,0,6.7889c.4748,1.9776,1.6088,3.3867,3.55,3.3867H8.47V19.65a4.2449,4.2449,0,0,1,4.173-4.15h6.6721a3.3654,3.3654,0,0,0,3.34-3.3944V5.745a3.729,3.729,0,0,0-3.34-3.4723A20.8377,20.8377,0,0,0,15.8351,2ZM12.2226,4.0478a1.2731,1.2731,0,1,1-1.2534,1.2768A1.2675,1.2675,0,0,1,12.2226,4.0478Z"
  })), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M12.2226,4.0478a1.2731,1.2731,0,1,1-1.2534,1.2768A1.2675,1.2675,0,0,1,12.2226,4.0478Z"
  })), children);
});
var LogoPython16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoPython16(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.4882,9.14v2.9663a4.2843,4.2843,0,0,1-4.173,4.2352H12.6431a3.4077,3.4077,0,0,0-3.34,3.3945v6.3607c0,1.81,1.5742,2.8751,3.34,3.3945a11.1762,11.1762,0,0,0,6.6721,0c1.6817-.4869,3.34-1.4668,3.34-3.3945V23.55H15.983v-.8486H25.9951c1.9414,0,2.6648-1.3542,3.34-3.3867a11.4642,11.4642,0,0,0,0-6.7889c-.48-1.9327-1.3961-3.3867-3.34-3.3867ZM19.7356,25.2476a1.2731,1.2731,0,1,1-1.2534,1.269A1.2607,1.2607,0,0,1,19.7356,25.2476Z"
  })), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M19.7356,25.2476a1.2731,1.2731,0,1,1-1.2534,1.269A1.2607,1.2607,0,0,1,19.7356,25.2476Z"
  })), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.8351,2a19.0717,19.0717,0,0,0-3.192.2725c-2.8268.4994-3.34,1.5447-3.34,3.4723V8.2909h6.68V9.14H6.7962a4.1708,4.1708,0,0,0-4.173,3.3867,12.4855,12.4855,0,0,0,0,6.7889c.4748,1.9776,1.6088,3.3867,3.55,3.3867H8.47V19.65a4.2449,4.2449,0,0,1,4.173-4.15h6.6721a3.3654,3.3654,0,0,0,3.34-3.3944V5.745a3.729,3.729,0,0,0-3.34-3.4723A20.8377,20.8377,0,0,0,15.8351,2ZM12.2226,4.0478a1.2731,1.2731,0,1,1-1.2534,1.2768A1.2675,1.2675,0,0,1,12.2226,4.0478Z"
  })), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M12.2226,4.0478a1.2731,1.2731,0,1,1-1.2534,1.2768A1.2675,1.2675,0,0,1,12.2226,4.0478Z"
  })), children);
});
var LogoQuora32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoQuora32(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,23.86H27a1.72,1.72,0,0,1-1.73,1.72c-1.15,0-1.82-.86-2.58-2a11,11,0,0,0,4.79-9.1c.09-7.19-5.85-11.89-12.17-11.89S3,7.37,3,14.37,9,26.16,15.17,26.16a10.71,10.71,0,0,0,3.07-.48c1.15,2.11,2.59,3.74,5.46,3.74A5,5,0,0,0,29,23.86Zm-8.14-3.45a6.31,6.31,0,0,0-5.56-3.16,6,6,0,0,0-3.74,1.15L12.2,20a2.56,2.56,0,0,1,.86-.1c1.82,0,3,1.53,4.12,3.64a7.58,7.58,0,0,1-1.91.19C10.86,23.76,9,20.6,9,14.47s1.91-9.3,6.23-9.3,6.32,3.16,6.32,9.3A20.68,20.68,0,0,1,20.83,20.41Z"
  })), children);
});
var LogoQuora24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoQuora24(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,23.86H27a1.72,1.72,0,0,1-1.73,1.72c-1.15,0-1.82-.86-2.58-2a11,11,0,0,0,4.79-9.1c.09-7.19-5.85-11.89-12.17-11.89S3,7.37,3,14.37,9,26.16,15.17,26.16a10.71,10.71,0,0,0,3.07-.48c1.15,2.11,2.59,3.74,5.46,3.74A5,5,0,0,0,29,23.86Zm-8.14-3.45a6.31,6.31,0,0,0-5.56-3.16,6,6,0,0,0-3.74,1.15L12.2,20a2.56,2.56,0,0,1,.86-.1c1.82,0,3,1.53,4.12,3.64a7.58,7.58,0,0,1-1.91.19C10.86,23.76,9,20.6,9,14.47s1.91-9.3,6.23-9.3,6.32,3.16,6.32,9.3A20.68,20.68,0,0,1,20.83,20.41Z"
  })), children);
});
var LogoQuora20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoQuora20(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,23.86H27a1.72,1.72,0,0,1-1.73,1.72c-1.15,0-1.82-.86-2.58-2a11,11,0,0,0,4.79-9.1c.09-7.19-5.85-11.89-12.17-11.89S3,7.37,3,14.37,9,26.16,15.17,26.16a10.71,10.71,0,0,0,3.07-.48c1.15,2.11,2.59,3.74,5.46,3.74A5,5,0,0,0,29,23.86Zm-8.14-3.45a6.31,6.31,0,0,0-5.56-3.16,6,6,0,0,0-3.74,1.15L12.2,20a2.56,2.56,0,0,1,.86-.1c1.82,0,3,1.53,4.12,3.64a7.58,7.58,0,0,1-1.91.19C10.86,23.76,9,20.6,9,14.47s1.91-9.3,6.23-9.3,6.32,3.16,6.32,9.3A20.68,20.68,0,0,1,20.83,20.41Z"
  })), children);
});
var LogoQuora16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoQuora16(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,23.86H27a1.72,1.72,0,0,1-1.73,1.72c-1.15,0-1.82-.86-2.58-2a11,11,0,0,0,4.79-9.1c.09-7.19-5.85-11.89-12.17-11.89S3,7.37,3,14.37,9,26.16,15.17,26.16a10.71,10.71,0,0,0,3.07-.48c1.15,2.11,2.59,3.74,5.46,3.74A5,5,0,0,0,29,23.86Zm-8.14-3.45a6.31,6.31,0,0,0-5.56-3.16,6,6,0,0,0-3.74,1.15L12.2,20a2.56,2.56,0,0,1,.86-.1c1.82,0,3,1.53,4.12,3.64a7.58,7.58,0,0,1-1.91.19C10.86,23.76,9,20.6,9,14.47s1.91-9.3,6.23-9.3,6.32,3.16,6.32,9.3A20.68,20.68,0,0,1,20.83,20.41Z"
  })), children);
});
var LogoRScript32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoRScript32(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M30,14.7842c0-5.1782-6.2681-9.376-14-9.376S2,9.606,2,14.7842c0,4.6147,4.9814,8.4419,11.5361,9.2226v2.9917l4.7762-.0019,0-2.9741a19.3812,19.3812,0,0,0,3.3418-.6646L23.593,27l5.3975-.0024-3.253-5.4849C28.3625,19.8086,30,17.4263,30,14.7842Zm-22.4983.7c0-3.54,4.7644-6.41,10.6414-6.41s10.2138,1.9629,10.2138,6.41A5.4694,5.4694,0,0,1,24.9587,20.61a3.2252,3.2252,0,0,0-.2978-.1749,10.4735,10.4735,0,0,0-1.34-.5048s4.1743-.31,4.1743-4.4659-4.3684-4.2343-4.3684-4.2343H13.5361V21.2554C9.97,20.22,7.5017,18.0283,7.5017,15.4839Zm13.7422,1.8452-2.8928.001.0014-2.6812,2.8914.0015a1.2476,1.2476,0,0,1,1.34,1.3149A1.3232,1.3232,0,0,1,21.2439,17.3291Zm-2.9326,3.4946h1.2825a.8785.8785,0,0,1,.6406.291,3.2917,3.2917,0,0,1,.51.63,22.4033,22.4033,0,0,1-2.4326.1455Z"
  })), children);
});
var LogoRScript24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoRScript24(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M30,14.7842c0-5.1782-6.2681-9.376-14-9.376S2,9.606,2,14.7842c0,4.6147,4.9814,8.4419,11.5361,9.2226v2.9917l4.7762-.0019,0-2.9741a19.3812,19.3812,0,0,0,3.3418-.6646L23.593,27l5.3975-.0024-3.253-5.4849C28.3625,19.8086,30,17.4263,30,14.7842Zm-22.4983.7c0-3.54,4.7644-6.41,10.6414-6.41s10.2138,1.9629,10.2138,6.41A5.4694,5.4694,0,0,1,24.9587,20.61a3.2252,3.2252,0,0,0-.2978-.1749,10.4735,10.4735,0,0,0-1.34-.5048s4.1743-.31,4.1743-4.4659-4.3684-4.2343-4.3684-4.2343H13.5361V21.2554C9.97,20.22,7.5017,18.0283,7.5017,15.4839Zm13.7422,1.8452-2.8928.001.0014-2.6812,2.8914.0015a1.2476,1.2476,0,0,1,1.34,1.3149A1.3232,1.3232,0,0,1,21.2439,17.3291Zm-2.9326,3.4946h1.2825a.8785.8785,0,0,1,.6406.291,3.2917,3.2917,0,0,1,.51.63,22.4033,22.4033,0,0,1-2.4326.1455Z"
  })), children);
});
var LogoRScript20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoRScript20(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M30,14.7842c0-5.1782-6.2681-9.376-14-9.376S2,9.606,2,14.7842c0,4.6147,4.9814,8.4419,11.5361,9.2226v2.9917l4.7762-.0019,0-2.9741a19.3812,19.3812,0,0,0,3.3418-.6646L23.593,27l5.3975-.0024-3.253-5.4849C28.3625,19.8086,30,17.4263,30,14.7842Zm-22.4983.7c0-3.54,4.7644-6.41,10.6414-6.41s10.2138,1.9629,10.2138,6.41A5.4694,5.4694,0,0,1,24.9587,20.61a3.2252,3.2252,0,0,0-.2978-.1749,10.4735,10.4735,0,0,0-1.34-.5048s4.1743-.31,4.1743-4.4659-4.3684-4.2343-4.3684-4.2343H13.5361V21.2554C9.97,20.22,7.5017,18.0283,7.5017,15.4839Zm13.7422,1.8452-2.8928.001.0014-2.6812,2.8914.0015a1.2476,1.2476,0,0,1,1.34,1.3149A1.3232,1.3232,0,0,1,21.2439,17.3291Zm-2.9326,3.4946h1.2825a.8785.8785,0,0,1,.6406.291,3.2917,3.2917,0,0,1,.51.63,22.4033,22.4033,0,0,1-2.4326.1455Z"
  })), children);
});
var LogoRScript16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoRScript16(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M30,14.7842c0-5.1782-6.2681-9.376-14-9.376S2,9.606,2,14.7842c0,4.6147,4.9814,8.4419,11.5361,9.2226v2.9917l4.7762-.0019,0-2.9741a19.3812,19.3812,0,0,0,3.3418-.6646L23.593,27l5.3975-.0024-3.253-5.4849C28.3625,19.8086,30,17.4263,30,14.7842Zm-22.4983.7c0-3.54,4.7644-6.41,10.6414-6.41s10.2138,1.9629,10.2138,6.41A5.4694,5.4694,0,0,1,24.9587,20.61a3.2252,3.2252,0,0,0-.2978-.1749,10.4735,10.4735,0,0,0-1.34-.5048s4.1743-.31,4.1743-4.4659-4.3684-4.2343-4.3684-4.2343H13.5361V21.2554C9.97,20.22,7.5017,18.0283,7.5017,15.4839Zm13.7422,1.8452-2.8928.001.0014-2.6812,2.8914.0015a1.2476,1.2476,0,0,1,1.34,1.3149A1.3232,1.3232,0,0,1,21.2439,17.3291Zm-2.9326,3.4946h1.2825a.8785.8785,0,0,1,.6406.291,3.2917,3.2917,0,0,1,.51.63,22.4033,22.4033,0,0,1-2.4326.1455Z"
  })), children);
});
var LogoSkype32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoSkype32(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.91,17.88A11.63,11.63,0,0,0,28.06,16,12.06,12.06,0,0,0,16,3.94a11.63,11.63,0,0,0-1.88.15,7.29,7.29,0,0,0-10,10A11.63,11.63,0,0,0,3.94,16,12.06,12.06,0,0,0,16,28.06a11.63,11.63,0,0,0,1.88-.15,7.29,7.29,0,0,0,10-10Zm-6.18,3.6a5,5,0,0,1-2.24,1.73,9,9,0,0,1-3.48.62A8.41,8.41,0,0,1,12,23a5.2,5.2,0,0,1-1.82-1.63,3.59,3.59,0,0,1-.7-2,1.36,1.36,0,0,1,.43-1A1.56,1.56,0,0,1,11,18a1.38,1.38,0,0,1,.91.32,2.5,2.5,0,0,1,.63.94,5.83,5.83,0,0,0,.66,1.18,2.61,2.61,0,0,0,1,.78,3.87,3.87,0,0,0,1.69.31,4,4,0,0,0,2.34-.62,1.8,1.8,0,0,0,.89-1.53,1.54,1.54,0,0,0-.47-1.17,3.09,3.09,0,0,0-1.25-.7c-.52-.17-1.21-.34-2.08-.53A16,16,0,0,1,12.41,16a4.78,4.78,0,0,1-1.89-1.4,3.5,3.5,0,0,1-.7-2.21,3.65,3.65,0,0,1,.74-2.24,4.7,4.7,0,0,1,2.14-1.5A9.51,9.51,0,0,1,16,8.17a8.63,8.63,0,0,1,2.59.35,5.81,5.81,0,0,1,1.83.92,3.91,3.91,0,0,1,1.06,1.21,2.62,2.62,0,0,1,.34,1.25,1.4,1.4,0,0,1-.43,1,1.43,1.43,0,0,1-1.07.46,1.25,1.25,0,0,1-.89-.28,3.36,3.36,0,0,1-.65-.87,3.79,3.79,0,0,0-1.05-1.31,3.13,3.13,0,0,0-1.95-.46,3.64,3.64,0,0,0-2,.5,1.44,1.44,0,0,0-.76,1.2,1.15,1.15,0,0,0,.25.75,2.21,2.21,0,0,0,.72.55,4.74,4.74,0,0,0,.92.36c.32.09.84.22,1.57.39.92.2,1.74.42,2.49.66a7.61,7.61,0,0,1,1.9.88,3.59,3.59,0,0,1,1.23,1.31A4,4,0,0,1,22.5,19,4.24,4.24,0,0,1,21.73,21.48Z"
  })), children);
});
var LogoSkype24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoSkype24(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.91,17.88A11.63,11.63,0,0,0,28.06,16,12.06,12.06,0,0,0,16,3.94a11.63,11.63,0,0,0-1.88.15,7.29,7.29,0,0,0-10,10A11.63,11.63,0,0,0,3.94,16,12.06,12.06,0,0,0,16,28.06a11.63,11.63,0,0,0,1.88-.15,7.29,7.29,0,0,0,10-10Zm-6.18,3.6a5,5,0,0,1-2.24,1.73,9,9,0,0,1-3.48.62A8.41,8.41,0,0,1,12,23a5.2,5.2,0,0,1-1.82-1.63,3.59,3.59,0,0,1-.7-2,1.36,1.36,0,0,1,.43-1A1.56,1.56,0,0,1,11,18a1.38,1.38,0,0,1,.91.32,2.5,2.5,0,0,1,.63.94,5.83,5.83,0,0,0,.66,1.18,2.61,2.61,0,0,0,1,.78,3.87,3.87,0,0,0,1.69.31,4,4,0,0,0,2.34-.62,1.8,1.8,0,0,0,.89-1.53,1.54,1.54,0,0,0-.47-1.17,3.09,3.09,0,0,0-1.25-.7c-.52-.17-1.21-.34-2.08-.53A16,16,0,0,1,12.41,16a4.78,4.78,0,0,1-1.89-1.4,3.5,3.5,0,0,1-.7-2.21,3.65,3.65,0,0,1,.74-2.24,4.7,4.7,0,0,1,2.14-1.5A9.51,9.51,0,0,1,16,8.17a8.63,8.63,0,0,1,2.59.35,5.81,5.81,0,0,1,1.83.92,3.91,3.91,0,0,1,1.06,1.21,2.62,2.62,0,0,1,.34,1.25,1.4,1.4,0,0,1-.43,1,1.43,1.43,0,0,1-1.07.46,1.25,1.25,0,0,1-.89-.28,3.36,3.36,0,0,1-.65-.87,3.79,3.79,0,0,0-1.05-1.31,3.13,3.13,0,0,0-1.95-.46,3.64,3.64,0,0,0-2,.5,1.44,1.44,0,0,0-.76,1.2,1.15,1.15,0,0,0,.25.75,2.21,2.21,0,0,0,.72.55,4.74,4.74,0,0,0,.92.36c.32.09.84.22,1.57.39.92.2,1.74.42,2.49.66a7.61,7.61,0,0,1,1.9.88,3.59,3.59,0,0,1,1.23,1.31A4,4,0,0,1,22.5,19,4.24,4.24,0,0,1,21.73,21.48Z"
  })), children);
});
var LogoSkype20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoSkype20(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.91,17.88A11.63,11.63,0,0,0,28.06,16,12.06,12.06,0,0,0,16,3.94a11.63,11.63,0,0,0-1.88.15,7.29,7.29,0,0,0-10,10A11.63,11.63,0,0,0,3.94,16,12.06,12.06,0,0,0,16,28.06a11.63,11.63,0,0,0,1.88-.15,7.29,7.29,0,0,0,10-10Zm-6.18,3.6a5,5,0,0,1-2.24,1.73,9,9,0,0,1-3.48.62A8.41,8.41,0,0,1,12,23a5.2,5.2,0,0,1-1.82-1.63,3.59,3.59,0,0,1-.7-2,1.36,1.36,0,0,1,.43-1A1.56,1.56,0,0,1,11,18a1.38,1.38,0,0,1,.91.32,2.5,2.5,0,0,1,.63.94,5.83,5.83,0,0,0,.66,1.18,2.61,2.61,0,0,0,1,.78,3.87,3.87,0,0,0,1.69.31,4,4,0,0,0,2.34-.62,1.8,1.8,0,0,0,.89-1.53,1.54,1.54,0,0,0-.47-1.17,3.09,3.09,0,0,0-1.25-.7c-.52-.17-1.21-.34-2.08-.53A16,16,0,0,1,12.41,16a4.78,4.78,0,0,1-1.89-1.4,3.5,3.5,0,0,1-.7-2.21,3.65,3.65,0,0,1,.74-2.24,4.7,4.7,0,0,1,2.14-1.5A9.51,9.51,0,0,1,16,8.17a8.63,8.63,0,0,1,2.59.35,5.81,5.81,0,0,1,1.83.92,3.91,3.91,0,0,1,1.06,1.21,2.62,2.62,0,0,1,.34,1.25,1.4,1.4,0,0,1-.43,1,1.43,1.43,0,0,1-1.07.46,1.25,1.25,0,0,1-.89-.28,3.36,3.36,0,0,1-.65-.87,3.79,3.79,0,0,0-1.05-1.31,3.13,3.13,0,0,0-1.95-.46,3.64,3.64,0,0,0-2,.5,1.44,1.44,0,0,0-.76,1.2,1.15,1.15,0,0,0,.25.75,2.21,2.21,0,0,0,.72.55,4.74,4.74,0,0,0,.92.36c.32.09.84.22,1.57.39.92.2,1.74.42,2.49.66a7.61,7.61,0,0,1,1.9.88,3.59,3.59,0,0,1,1.23,1.31A4,4,0,0,1,22.5,19,4.24,4.24,0,0,1,21.73,21.48Z"
  })), children);
});
var LogoSkype16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoSkype16(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.91,17.88A11.63,11.63,0,0,0,28.06,16,12.06,12.06,0,0,0,16,3.94a11.63,11.63,0,0,0-1.88.15,7.29,7.29,0,0,0-10,10A11.63,11.63,0,0,0,3.94,16,12.06,12.06,0,0,0,16,28.06a11.63,11.63,0,0,0,1.88-.15,7.29,7.29,0,0,0,10-10Zm-6.18,3.6a5,5,0,0,1-2.24,1.73,9,9,0,0,1-3.48.62A8.41,8.41,0,0,1,12,23a5.2,5.2,0,0,1-1.82-1.63,3.59,3.59,0,0,1-.7-2,1.36,1.36,0,0,1,.43-1A1.56,1.56,0,0,1,11,18a1.38,1.38,0,0,1,.91.32,2.5,2.5,0,0,1,.63.94,5.83,5.83,0,0,0,.66,1.18,2.61,2.61,0,0,0,1,.78,3.87,3.87,0,0,0,1.69.31,4,4,0,0,0,2.34-.62,1.8,1.8,0,0,0,.89-1.53,1.54,1.54,0,0,0-.47-1.17,3.09,3.09,0,0,0-1.25-.7c-.52-.17-1.21-.34-2.08-.53A16,16,0,0,1,12.41,16a4.78,4.78,0,0,1-1.89-1.4,3.5,3.5,0,0,1-.7-2.21,3.65,3.65,0,0,1,.74-2.24,4.7,4.7,0,0,1,2.14-1.5A9.51,9.51,0,0,1,16,8.17a8.63,8.63,0,0,1,2.59.35,5.81,5.81,0,0,1,1.83.92,3.91,3.91,0,0,1,1.06,1.21,2.62,2.62,0,0,1,.34,1.25,1.4,1.4,0,0,1-.43,1,1.43,1.43,0,0,1-1.07.46,1.25,1.25,0,0,1-.89-.28,3.36,3.36,0,0,1-.65-.87,3.79,3.79,0,0,0-1.05-1.31,3.13,3.13,0,0,0-1.95-.46,3.64,3.64,0,0,0-2,.5,1.44,1.44,0,0,0-.76,1.2,1.15,1.15,0,0,0,.25.75,2.21,2.21,0,0,0,.72.55,4.74,4.74,0,0,0,.92.36c.32.09.84.22,1.57.39.92.2,1.74.42,2.49.66a7.61,7.61,0,0,1,1.9.88,3.59,3.59,0,0,1,1.23,1.31A4,4,0,0,1,22.5,19,4.24,4.24,0,0,1,21.73,21.48Z"
  })), children);
});
var LogoSlack32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoSlack32(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.0423 19.1661A2.5212 2.5212 0 116.5212 16.645H9.0423zM10.3127 19.1661a2.5212 2.5212 0 015.0423 0v6.3127a2.5212 2.5212 0 11-5.0423 0zM12.8339 9.0423A2.5212 2.5212 0 1115.355 6.5212V9.0423zM12.8339 10.3127a2.5212 2.5212 0 010 5.0423H6.5212a2.5212 2.5212 0 110-5.0423zM22.9577 12.8339a2.5212 2.5212 0 112.5211 2.5211H22.9577zM21.6873 12.8339a2.5212 2.5212 0 01-5.0423 0V6.5212a2.5212 2.5212 0 115.0423 0zM19.1661 22.9577a2.5212 2.5212 0 11-2.5211 2.5211V22.9577zM19.1661 21.6873a2.5212 2.5212 0 010-5.0423h6.3127a2.5212 2.5212 0 110 5.0423z"
  })), children);
});
var LogoSlack24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoSlack24(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.0423 19.1661A2.5212 2.5212 0 116.5212 16.645H9.0423zM10.3127 19.1661a2.5212 2.5212 0 015.0423 0v6.3127a2.5212 2.5212 0 11-5.0423 0zM12.8339 9.0423A2.5212 2.5212 0 1115.355 6.5212V9.0423zM12.8339 10.3127a2.5212 2.5212 0 010 5.0423H6.5212a2.5212 2.5212 0 110-5.0423zM22.9577 12.8339a2.5212 2.5212 0 112.5211 2.5211H22.9577zM21.6873 12.8339a2.5212 2.5212 0 01-5.0423 0V6.5212a2.5212 2.5212 0 115.0423 0zM19.1661 22.9577a2.5212 2.5212 0 11-2.5211 2.5211V22.9577zM19.1661 21.6873a2.5212 2.5212 0 010-5.0423h6.3127a2.5212 2.5212 0 110 5.0423z"
  })), children);
});
var LogoSlack20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoSlack20(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.0423 19.1661A2.5212 2.5212 0 116.5212 16.645H9.0423zM10.3127 19.1661a2.5212 2.5212 0 015.0423 0v6.3127a2.5212 2.5212 0 11-5.0423 0zM12.8339 9.0423A2.5212 2.5212 0 1115.355 6.5212V9.0423zM12.8339 10.3127a2.5212 2.5212 0 010 5.0423H6.5212a2.5212 2.5212 0 110-5.0423zM22.9577 12.8339a2.5212 2.5212 0 112.5211 2.5211H22.9577zM21.6873 12.8339a2.5212 2.5212 0 01-5.0423 0V6.5212a2.5212 2.5212 0 115.0423 0zM19.1661 22.9577a2.5212 2.5212 0 11-2.5211 2.5211V22.9577zM19.1661 21.6873a2.5212 2.5212 0 010-5.0423h6.3127a2.5212 2.5212 0 110 5.0423z"
  })), children);
});
var LogoSlack16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoSlack16(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.0423 19.1661A2.5212 2.5212 0 116.5212 16.645H9.0423zM10.3127 19.1661a2.5212 2.5212 0 015.0423 0v6.3127a2.5212 2.5212 0 11-5.0423 0zM12.8339 9.0423A2.5212 2.5212 0 1115.355 6.5212V9.0423zM12.8339 10.3127a2.5212 2.5212 0 010 5.0423H6.5212a2.5212 2.5212 0 110-5.0423zM22.9577 12.8339a2.5212 2.5212 0 112.5211 2.5211H22.9577zM21.6873 12.8339a2.5212 2.5212 0 01-5.0423 0V6.5212a2.5212 2.5212 0 115.0423 0zM19.1661 22.9577a2.5212 2.5212 0 11-2.5211 2.5211V22.9577zM19.1661 21.6873a2.5212 2.5212 0 010-5.0423h6.3127a2.5212 2.5212 0 110 5.0423z"
  })), children);
});
var LogoSnapchat32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoSnapchat32(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.9774,9.6279a7.33,7.33,0,0,0-.1186-1.2888,5.2458,5.2458,0,0,0-.4872-1.4948,5.1869,5.1869,0,0,0-.9988-1.3324,4.9557,4.9557,0,0,0-2.1805-1.2433,8.8444,8.8444,0,0,0-2.3059-.2458l-.0044-.0119H10.1143l-.0007.0119a12.578,12.578,0,0,0-1.3221.0591A6.2955,6.2955,0,0,0,7.3792,4.4,5.1155,5.1155,0,0,0,4.2538,7.8152a8.8,8.8,0,0,0-.2459,2.2855L4,21.9065a14.9206,14.9206,0,0,0,.1088,1.5992A5.53,5.53,0,0,0,4.6,25.1205a5.17,5.17,0,0,0,1.443,1.744,4.6907,4.6907,0,0,0,1.4442.7822,7.83,7.83,0,0,0,2.3741.3484c.5034.0032,1.0069.0158,1.5106.0137,3.659-.0154,7.3178.0264,10.9767-.0226a8.6316,8.6316,0,0,0,1.44-.1528A4.8765,4.8765,0,0,0,26.2,26.6613a4.9915,4.9915,0,0,0,1.5931-2.6546,9.6646,9.6646,0,0,0,.2074-2.1v-.1407C28,21.7112,27.9793,9.7855,27.9774,9.6279ZM24.7635,20.7326c-.1536.36-.93.6577-2.2433.8606-.1232.019-.1751.2183-.2463.5445-.0293.1348-.0592.2669-.1.4057a.2451.2451,0,0,1-.26.1943h-.0205a2.1011,2.1011,0,0,1-.3738-.0472,4.921,4.921,0,0,0-.9852-.1044,4.37,4.37,0,0,0-.7106.06,3.4048,3.4048,0,0,0-1.3483.6888,3.912,3.912,0,0,1-2.3668.9328c-.05,0-.0973-.0018-.1335-.0035-.0287.0024-.0584.0035-.0881.0035a3.9062,3.9062,0,0,1-2.3651-.9322,3.4118,3.4118,0,0,0-1.35-.69,4.3612,4.3612,0,0,0-.71-.06,4.858,4.858,0,0,0-.9852.1115,2.1872,2.1872,0,0,1-.3737.0536.2574.2574,0,0,1-.2807-.2012c-.0414-.1407-.0711-.277-.1-.4082-.0716-.328-.1237-.5282-.2465-.5472-1.3133-.2026-2.0893-.5011-2.2439-.8626a.3349.3349,0,0,1-.0272-.114.2109.2109,0,0,1,.1764-.22,4.5854,4.5854,0,0,0,2.7564-1.6391,6.1681,6.1681,0,0,0,.94-1.4616l.0048-.01a.943.943,0,0,0,.09-.79c-.1693-.3991-.73-.5769-1.1007-.6946-.0921-.0291-.1794-.0567-.2488-.0844-.3288-.13-.8693-.4041-.7973-.7828a.7333.7333,0,0,1,.7127-.4683.5052.5052,0,0,1,.2158.043,2.1572,2.1572,0,0,0,.8916.2355.7465.7465,0,0,0,.5134-.1569q-.0145-.2629-.0318-.5256a8.8742,8.8742,0,0,1,.2122-3.5447A4.6074,4.6074,0,0,1,15.8173,7.76q.177-.0015.3539-.0033a4.6152,4.6152,0,0,1,4.2853,2.7606,8.884,8.884,0,0,1,.2118,3.5478l-.0036.0574c-.01.1629-.02.317-.0278.4665a.7215.7215,0,0,0,.4656.1558,2.2321,2.2321,0,0,0,.84-.234.6628.6628,0,0,1,.2751-.0545.832.832,0,0,1,.3133.06l.005.0019a.5825.5825,0,0,1,.4409.4781c.0034.1835-.133.4578-.8039.7226-.0687.0272-.1564.0551-.2489.0844-.3712.1178-.9312.2956-1.1005.6944a.9422.9422,0,0,0,.09.7893l.0048.01a5.4311,5.4311,0,0,0,3.6967,3.1005.211.211,0,0,1,.1764.22A.3408.3408,0,0,1,24.7635,20.7326Z"
  })), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M24.7635,20.7326c-.1536.36-.93.6577-2.2433.8606-.1232.019-.1751.2183-.2463.5445-.0293.1348-.0592.2669-.1.4057a.2451.2451,0,0,1-.26.1943h-.0205a2.1011,2.1011,0,0,1-.3738-.0472,4.921,4.921,0,0,0-.9852-.1044,4.37,4.37,0,0,0-.7106.06,3.4048,3.4048,0,0,0-1.3483.6888,3.912,3.912,0,0,1-2.3668.9328c-.05,0-.0973-.0018-.1335-.0035-.0287.0024-.0584.0035-.0881.0035a3.9062,3.9062,0,0,1-2.3651-.9322,3.4118,3.4118,0,0,0-1.35-.69,4.3612,4.3612,0,0,0-.71-.06,4.858,4.858,0,0,0-.9852.1115,2.1872,2.1872,0,0,1-.3737.0536.2574.2574,0,0,1-.2807-.2012c-.0414-.1407-.0711-.277-.1-.4082-.0716-.328-.1237-.5282-.2465-.5472-1.3133-.2026-2.0893-.5011-2.2439-.8626a.3349.3349,0,0,1-.0272-.114.2109.2109,0,0,1,.1764-.22,4.5854,4.5854,0,0,0,2.7564-1.6391,6.1681,6.1681,0,0,0,.94-1.4616l.0048-.01a.943.943,0,0,0,.09-.79c-.1693-.3991-.73-.5769-1.1007-.6946-.0921-.0291-.1794-.0567-.2488-.0844-.3288-.13-.8693-.4041-.7973-.7828a.7333.7333,0,0,1,.7127-.4683.5052.5052,0,0,1,.2158.043,2.1572,2.1572,0,0,0,.8916.2355.7465.7465,0,0,0,.5134-.1569q-.0145-.2629-.0318-.5256a8.8742,8.8742,0,0,1,.2122-3.5447A4.6074,4.6074,0,0,1,15.8173,7.76q.177-.0015.3539-.0033a4.6152,4.6152,0,0,1,4.2853,2.7606,8.884,8.884,0,0,1,.2118,3.5478l-.0036.0574c-.01.1629-.02.317-.0278.4665a.7215.7215,0,0,0,.4656.1558,2.2321,2.2321,0,0,0,.84-.234.6628.6628,0,0,1,.2751-.0545.832.832,0,0,1,.3133.06l.005.0019a.5825.5825,0,0,1,.4409.4781c.0034.1835-.133.4578-.8039.7226-.0687.0272-.1564.0551-.2489.0844-.3712.1178-.9312.2956-1.1005.6944a.9422.9422,0,0,0,.09.7893l.0048.01a5.4311,5.4311,0,0,0,3.6967,3.1005.211.211,0,0,1,.1764.22A.3408.3408,0,0,1,24.7635,20.7326Z",
    "data-icon-path": "inner-path"
  })), children);
});
var LogoSnapchat24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoSnapchat24(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.9774,9.6279a7.33,7.33,0,0,0-.1186-1.2888,5.2458,5.2458,0,0,0-.4872-1.4948,5.1869,5.1869,0,0,0-.9988-1.3324,4.9557,4.9557,0,0,0-2.1805-1.2433,8.8444,8.8444,0,0,0-2.3059-.2458l-.0044-.0119H10.1143l-.0007.0119a12.578,12.578,0,0,0-1.3221.0591A6.2955,6.2955,0,0,0,7.3792,4.4,5.1155,5.1155,0,0,0,4.2538,7.8152a8.8,8.8,0,0,0-.2459,2.2855L4,21.9065a14.9206,14.9206,0,0,0,.1088,1.5992A5.53,5.53,0,0,0,4.6,25.1205a5.17,5.17,0,0,0,1.443,1.744,4.6907,4.6907,0,0,0,1.4442.7822,7.83,7.83,0,0,0,2.3741.3484c.5034.0032,1.0069.0158,1.5106.0137,3.659-.0154,7.3178.0264,10.9767-.0226a8.6316,8.6316,0,0,0,1.44-.1528A4.8765,4.8765,0,0,0,26.2,26.6613a4.9915,4.9915,0,0,0,1.5931-2.6546,9.6646,9.6646,0,0,0,.2074-2.1v-.1407C28,21.7112,27.9793,9.7855,27.9774,9.6279ZM24.7635,20.7326c-.1536.36-.93.6577-2.2433.8606-.1232.019-.1751.2183-.2463.5445-.0293.1348-.0592.2669-.1.4057a.2451.2451,0,0,1-.26.1943h-.0205a2.1011,2.1011,0,0,1-.3738-.0472,4.921,4.921,0,0,0-.9852-.1044,4.37,4.37,0,0,0-.7106.06,3.4048,3.4048,0,0,0-1.3483.6888,3.912,3.912,0,0,1-2.3668.9328c-.05,0-.0973-.0018-.1335-.0035-.0287.0024-.0584.0035-.0881.0035a3.9062,3.9062,0,0,1-2.3651-.9322,3.4118,3.4118,0,0,0-1.35-.69,4.3612,4.3612,0,0,0-.71-.06,4.858,4.858,0,0,0-.9852.1115,2.1872,2.1872,0,0,1-.3737.0536.2574.2574,0,0,1-.2807-.2012c-.0414-.1407-.0711-.277-.1-.4082-.0716-.328-.1237-.5282-.2465-.5472-1.3133-.2026-2.0893-.5011-2.2439-.8626a.3349.3349,0,0,1-.0272-.114.2109.2109,0,0,1,.1764-.22,4.5854,4.5854,0,0,0,2.7564-1.6391,6.1681,6.1681,0,0,0,.94-1.4616l.0048-.01a.943.943,0,0,0,.09-.79c-.1693-.3991-.73-.5769-1.1007-.6946-.0921-.0291-.1794-.0567-.2488-.0844-.3288-.13-.8693-.4041-.7973-.7828a.7333.7333,0,0,1,.7127-.4683.5052.5052,0,0,1,.2158.043,2.1572,2.1572,0,0,0,.8916.2355.7465.7465,0,0,0,.5134-.1569q-.0145-.2629-.0318-.5256a8.8742,8.8742,0,0,1,.2122-3.5447A4.6074,4.6074,0,0,1,15.8173,7.76q.177-.0015.3539-.0033a4.6152,4.6152,0,0,1,4.2853,2.7606,8.884,8.884,0,0,1,.2118,3.5478l-.0036.0574c-.01.1629-.02.317-.0278.4665a.7215.7215,0,0,0,.4656.1558,2.2321,2.2321,0,0,0,.84-.234.6628.6628,0,0,1,.2751-.0545.832.832,0,0,1,.3133.06l.005.0019a.5825.5825,0,0,1,.4409.4781c.0034.1835-.133.4578-.8039.7226-.0687.0272-.1564.0551-.2489.0844-.3712.1178-.9312.2956-1.1005.6944a.9422.9422,0,0,0,.09.7893l.0048.01a5.4311,5.4311,0,0,0,3.6967,3.1005.211.211,0,0,1,.1764.22A.3408.3408,0,0,1,24.7635,20.7326Z"
  })), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M24.7635,20.7326c-.1536.36-.93.6577-2.2433.8606-.1232.019-.1751.2183-.2463.5445-.0293.1348-.0592.2669-.1.4057a.2451.2451,0,0,1-.26.1943h-.0205a2.1011,2.1011,0,0,1-.3738-.0472,4.921,4.921,0,0,0-.9852-.1044,4.37,4.37,0,0,0-.7106.06,3.4048,3.4048,0,0,0-1.3483.6888,3.912,3.912,0,0,1-2.3668.9328c-.05,0-.0973-.0018-.1335-.0035-.0287.0024-.0584.0035-.0881.0035a3.9062,3.9062,0,0,1-2.3651-.9322,3.4118,3.4118,0,0,0-1.35-.69,4.3612,4.3612,0,0,0-.71-.06,4.858,4.858,0,0,0-.9852.1115,2.1872,2.1872,0,0,1-.3737.0536.2574.2574,0,0,1-.2807-.2012c-.0414-.1407-.0711-.277-.1-.4082-.0716-.328-.1237-.5282-.2465-.5472-1.3133-.2026-2.0893-.5011-2.2439-.8626a.3349.3349,0,0,1-.0272-.114.2109.2109,0,0,1,.1764-.22,4.5854,4.5854,0,0,0,2.7564-1.6391,6.1681,6.1681,0,0,0,.94-1.4616l.0048-.01a.943.943,0,0,0,.09-.79c-.1693-.3991-.73-.5769-1.1007-.6946-.0921-.0291-.1794-.0567-.2488-.0844-.3288-.13-.8693-.4041-.7973-.7828a.7333.7333,0,0,1,.7127-.4683.5052.5052,0,0,1,.2158.043,2.1572,2.1572,0,0,0,.8916.2355.7465.7465,0,0,0,.5134-.1569q-.0145-.2629-.0318-.5256a8.8742,8.8742,0,0,1,.2122-3.5447A4.6074,4.6074,0,0,1,15.8173,7.76q.177-.0015.3539-.0033a4.6152,4.6152,0,0,1,4.2853,2.7606,8.884,8.884,0,0,1,.2118,3.5478l-.0036.0574c-.01.1629-.02.317-.0278.4665a.7215.7215,0,0,0,.4656.1558,2.2321,2.2321,0,0,0,.84-.234.6628.6628,0,0,1,.2751-.0545.832.832,0,0,1,.3133.06l.005.0019a.5825.5825,0,0,1,.4409.4781c.0034.1835-.133.4578-.8039.7226-.0687.0272-.1564.0551-.2489.0844-.3712.1178-.9312.2956-1.1005.6944a.9422.9422,0,0,0,.09.7893l.0048.01a5.4311,5.4311,0,0,0,3.6967,3.1005.211.211,0,0,1,.1764.22A.3408.3408,0,0,1,24.7635,20.7326Z",
    "data-icon-path": "inner-path"
  })), children);
});
var LogoSnapchat20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoSnapchat20(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.9774,9.6279a7.33,7.33,0,0,0-.1186-1.2888,5.2458,5.2458,0,0,0-.4872-1.4948,5.1869,5.1869,0,0,0-.9988-1.3324,4.9557,4.9557,0,0,0-2.1805-1.2433,8.8444,8.8444,0,0,0-2.3059-.2458l-.0044-.0119H10.1143l-.0007.0119a12.578,12.578,0,0,0-1.3221.0591A6.2955,6.2955,0,0,0,7.3792,4.4,5.1155,5.1155,0,0,0,4.2538,7.8152a8.8,8.8,0,0,0-.2459,2.2855L4,21.9065a14.9206,14.9206,0,0,0,.1088,1.5992A5.53,5.53,0,0,0,4.6,25.1205a5.17,5.17,0,0,0,1.443,1.744,4.6907,4.6907,0,0,0,1.4442.7822,7.83,7.83,0,0,0,2.3741.3484c.5034.0032,1.0069.0158,1.5106.0137,3.659-.0154,7.3178.0264,10.9767-.0226a8.6316,8.6316,0,0,0,1.44-.1528A4.8765,4.8765,0,0,0,26.2,26.6613a4.9915,4.9915,0,0,0,1.5931-2.6546,9.6646,9.6646,0,0,0,.2074-2.1v-.1407C28,21.7112,27.9793,9.7855,27.9774,9.6279ZM24.7635,20.7326c-.1536.36-.93.6577-2.2433.8606-.1232.019-.1751.2183-.2463.5445-.0293.1348-.0592.2669-.1.4057a.2451.2451,0,0,1-.26.1943h-.0205a2.1011,2.1011,0,0,1-.3738-.0472,4.921,4.921,0,0,0-.9852-.1044,4.37,4.37,0,0,0-.7106.06,3.4048,3.4048,0,0,0-1.3483.6888,3.912,3.912,0,0,1-2.3668.9328c-.05,0-.0973-.0018-.1335-.0035-.0287.0024-.0584.0035-.0881.0035a3.9062,3.9062,0,0,1-2.3651-.9322,3.4118,3.4118,0,0,0-1.35-.69,4.3612,4.3612,0,0,0-.71-.06,4.858,4.858,0,0,0-.9852.1115,2.1872,2.1872,0,0,1-.3737.0536.2574.2574,0,0,1-.2807-.2012c-.0414-.1407-.0711-.277-.1-.4082-.0716-.328-.1237-.5282-.2465-.5472-1.3133-.2026-2.0893-.5011-2.2439-.8626a.3349.3349,0,0,1-.0272-.114.2109.2109,0,0,1,.1764-.22,4.5854,4.5854,0,0,0,2.7564-1.6391,6.1681,6.1681,0,0,0,.94-1.4616l.0048-.01a.943.943,0,0,0,.09-.79c-.1693-.3991-.73-.5769-1.1007-.6946-.0921-.0291-.1794-.0567-.2488-.0844-.3288-.13-.8693-.4041-.7973-.7828a.7333.7333,0,0,1,.7127-.4683.5052.5052,0,0,1,.2158.043,2.1572,2.1572,0,0,0,.8916.2355.7465.7465,0,0,0,.5134-.1569q-.0145-.2629-.0318-.5256a8.8742,8.8742,0,0,1,.2122-3.5447A4.6074,4.6074,0,0,1,15.8173,7.76q.177-.0015.3539-.0033a4.6152,4.6152,0,0,1,4.2853,2.7606,8.884,8.884,0,0,1,.2118,3.5478l-.0036.0574c-.01.1629-.02.317-.0278.4665a.7215.7215,0,0,0,.4656.1558,2.2321,2.2321,0,0,0,.84-.234.6628.6628,0,0,1,.2751-.0545.832.832,0,0,1,.3133.06l.005.0019a.5825.5825,0,0,1,.4409.4781c.0034.1835-.133.4578-.8039.7226-.0687.0272-.1564.0551-.2489.0844-.3712.1178-.9312.2956-1.1005.6944a.9422.9422,0,0,0,.09.7893l.0048.01a5.4311,5.4311,0,0,0,3.6967,3.1005.211.211,0,0,1,.1764.22A.3408.3408,0,0,1,24.7635,20.7326Z"
  })), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M24.7635,20.7326c-.1536.36-.93.6577-2.2433.8606-.1232.019-.1751.2183-.2463.5445-.0293.1348-.0592.2669-.1.4057a.2451.2451,0,0,1-.26.1943h-.0205a2.1011,2.1011,0,0,1-.3738-.0472,4.921,4.921,0,0,0-.9852-.1044,4.37,4.37,0,0,0-.7106.06,3.4048,3.4048,0,0,0-1.3483.6888,3.912,3.912,0,0,1-2.3668.9328c-.05,0-.0973-.0018-.1335-.0035-.0287.0024-.0584.0035-.0881.0035a3.9062,3.9062,0,0,1-2.3651-.9322,3.4118,3.4118,0,0,0-1.35-.69,4.3612,4.3612,0,0,0-.71-.06,4.858,4.858,0,0,0-.9852.1115,2.1872,2.1872,0,0,1-.3737.0536.2574.2574,0,0,1-.2807-.2012c-.0414-.1407-.0711-.277-.1-.4082-.0716-.328-.1237-.5282-.2465-.5472-1.3133-.2026-2.0893-.5011-2.2439-.8626a.3349.3349,0,0,1-.0272-.114.2109.2109,0,0,1,.1764-.22,4.5854,4.5854,0,0,0,2.7564-1.6391,6.1681,6.1681,0,0,0,.94-1.4616l.0048-.01a.943.943,0,0,0,.09-.79c-.1693-.3991-.73-.5769-1.1007-.6946-.0921-.0291-.1794-.0567-.2488-.0844-.3288-.13-.8693-.4041-.7973-.7828a.7333.7333,0,0,1,.7127-.4683.5052.5052,0,0,1,.2158.043,2.1572,2.1572,0,0,0,.8916.2355.7465.7465,0,0,0,.5134-.1569q-.0145-.2629-.0318-.5256a8.8742,8.8742,0,0,1,.2122-3.5447A4.6074,4.6074,0,0,1,15.8173,7.76q.177-.0015.3539-.0033a4.6152,4.6152,0,0,1,4.2853,2.7606,8.884,8.884,0,0,1,.2118,3.5478l-.0036.0574c-.01.1629-.02.317-.0278.4665a.7215.7215,0,0,0,.4656.1558,2.2321,2.2321,0,0,0,.84-.234.6628.6628,0,0,1,.2751-.0545.832.832,0,0,1,.3133.06l.005.0019a.5825.5825,0,0,1,.4409.4781c.0034.1835-.133.4578-.8039.7226-.0687.0272-.1564.0551-.2489.0844-.3712.1178-.9312.2956-1.1005.6944a.9422.9422,0,0,0,.09.7893l.0048.01a5.4311,5.4311,0,0,0,3.6967,3.1005.211.211,0,0,1,.1764.22A.3408.3408,0,0,1,24.7635,20.7326Z",
    "data-icon-path": "inner-path"
  })), children);
});
var LogoSnapchat16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoSnapchat16(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.9774,9.6279a7.33,7.33,0,0,0-.1186-1.2888,5.2458,5.2458,0,0,0-.4872-1.4948,5.1869,5.1869,0,0,0-.9988-1.3324,4.9557,4.9557,0,0,0-2.1805-1.2433,8.8444,8.8444,0,0,0-2.3059-.2458l-.0044-.0119H10.1143l-.0007.0119a12.578,12.578,0,0,0-1.3221.0591A6.2955,6.2955,0,0,0,7.3792,4.4,5.1155,5.1155,0,0,0,4.2538,7.8152a8.8,8.8,0,0,0-.2459,2.2855L4,21.9065a14.9206,14.9206,0,0,0,.1088,1.5992A5.53,5.53,0,0,0,4.6,25.1205a5.17,5.17,0,0,0,1.443,1.744,4.6907,4.6907,0,0,0,1.4442.7822,7.83,7.83,0,0,0,2.3741.3484c.5034.0032,1.0069.0158,1.5106.0137,3.659-.0154,7.3178.0264,10.9767-.0226a8.6316,8.6316,0,0,0,1.44-.1528A4.8765,4.8765,0,0,0,26.2,26.6613a4.9915,4.9915,0,0,0,1.5931-2.6546,9.6646,9.6646,0,0,0,.2074-2.1v-.1407C28,21.7112,27.9793,9.7855,27.9774,9.6279ZM24.7635,20.7326c-.1536.36-.93.6577-2.2433.8606-.1232.019-.1751.2183-.2463.5445-.0293.1348-.0592.2669-.1.4057a.2451.2451,0,0,1-.26.1943h-.0205a2.1011,2.1011,0,0,1-.3738-.0472,4.921,4.921,0,0,0-.9852-.1044,4.37,4.37,0,0,0-.7106.06,3.4048,3.4048,0,0,0-1.3483.6888,3.912,3.912,0,0,1-2.3668.9328c-.05,0-.0973-.0018-.1335-.0035-.0287.0024-.0584.0035-.0881.0035a3.9062,3.9062,0,0,1-2.3651-.9322,3.4118,3.4118,0,0,0-1.35-.69,4.3612,4.3612,0,0,0-.71-.06,4.858,4.858,0,0,0-.9852.1115,2.1872,2.1872,0,0,1-.3737.0536.2574.2574,0,0,1-.2807-.2012c-.0414-.1407-.0711-.277-.1-.4082-.0716-.328-.1237-.5282-.2465-.5472-1.3133-.2026-2.0893-.5011-2.2439-.8626a.3349.3349,0,0,1-.0272-.114.2109.2109,0,0,1,.1764-.22,4.5854,4.5854,0,0,0,2.7564-1.6391,6.1681,6.1681,0,0,0,.94-1.4616l.0048-.01a.943.943,0,0,0,.09-.79c-.1693-.3991-.73-.5769-1.1007-.6946-.0921-.0291-.1794-.0567-.2488-.0844-.3288-.13-.8693-.4041-.7973-.7828a.7333.7333,0,0,1,.7127-.4683.5052.5052,0,0,1,.2158.043,2.1572,2.1572,0,0,0,.8916.2355.7465.7465,0,0,0,.5134-.1569q-.0145-.2629-.0318-.5256a8.8742,8.8742,0,0,1,.2122-3.5447A4.6074,4.6074,0,0,1,15.8173,7.76q.177-.0015.3539-.0033a4.6152,4.6152,0,0,1,4.2853,2.7606,8.884,8.884,0,0,1,.2118,3.5478l-.0036.0574c-.01.1629-.02.317-.0278.4665a.7215.7215,0,0,0,.4656.1558,2.2321,2.2321,0,0,0,.84-.234.6628.6628,0,0,1,.2751-.0545.832.832,0,0,1,.3133.06l.005.0019a.5825.5825,0,0,1,.4409.4781c.0034.1835-.133.4578-.8039.7226-.0687.0272-.1564.0551-.2489.0844-.3712.1178-.9312.2956-1.1005.6944a.9422.9422,0,0,0,.09.7893l.0048.01a5.4311,5.4311,0,0,0,3.6967,3.1005.211.211,0,0,1,.1764.22A.3408.3408,0,0,1,24.7635,20.7326Z"
  })), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M24.7635,20.7326c-.1536.36-.93.6577-2.2433.8606-.1232.019-.1751.2183-.2463.5445-.0293.1348-.0592.2669-.1.4057a.2451.2451,0,0,1-.26.1943h-.0205a2.1011,2.1011,0,0,1-.3738-.0472,4.921,4.921,0,0,0-.9852-.1044,4.37,4.37,0,0,0-.7106.06,3.4048,3.4048,0,0,0-1.3483.6888,3.912,3.912,0,0,1-2.3668.9328c-.05,0-.0973-.0018-.1335-.0035-.0287.0024-.0584.0035-.0881.0035a3.9062,3.9062,0,0,1-2.3651-.9322,3.4118,3.4118,0,0,0-1.35-.69,4.3612,4.3612,0,0,0-.71-.06,4.858,4.858,0,0,0-.9852.1115,2.1872,2.1872,0,0,1-.3737.0536.2574.2574,0,0,1-.2807-.2012c-.0414-.1407-.0711-.277-.1-.4082-.0716-.328-.1237-.5282-.2465-.5472-1.3133-.2026-2.0893-.5011-2.2439-.8626a.3349.3349,0,0,1-.0272-.114.2109.2109,0,0,1,.1764-.22,4.5854,4.5854,0,0,0,2.7564-1.6391,6.1681,6.1681,0,0,0,.94-1.4616l.0048-.01a.943.943,0,0,0,.09-.79c-.1693-.3991-.73-.5769-1.1007-.6946-.0921-.0291-.1794-.0567-.2488-.0844-.3288-.13-.8693-.4041-.7973-.7828a.7333.7333,0,0,1,.7127-.4683.5052.5052,0,0,1,.2158.043,2.1572,2.1572,0,0,0,.8916.2355.7465.7465,0,0,0,.5134-.1569q-.0145-.2629-.0318-.5256a8.8742,8.8742,0,0,1,.2122-3.5447A4.6074,4.6074,0,0,1,15.8173,7.76q.177-.0015.3539-.0033a4.6152,4.6152,0,0,1,4.2853,2.7606,8.884,8.884,0,0,1,.2118,3.5478l-.0036.0574c-.01.1629-.02.317-.0278.4665a.7215.7215,0,0,0,.4656.1558,2.2321,2.2321,0,0,0,.84-.234.6628.6628,0,0,1,.2751-.0545.832.832,0,0,1,.3133.06l.005.0019a.5825.5825,0,0,1,.4409.4781c.0034.1835-.133.4578-.8039.7226-.0687.0272-.1564.0551-.2489.0844-.3712.1178-.9312.2956-1.1005.6944a.9422.9422,0,0,0,.09.7893l.0048.01a5.4311,5.4311,0,0,0,3.6967,3.1005.211.211,0,0,1,.1764.22A.3408.3408,0,0,1,24.7635,20.7326Z",
    "data-icon-path": "inner-path"
  })), children);
});
var LogoStumbleupon32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoStumbleupon32(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  if (true) {
    if (!didWarnAboutDeprecation['LogoStumbleupon32']) {
      didWarnAboutDeprecation['LogoStumbleupon32'] = true;
      console.warn("The LogoStumbleupon32 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm-.09,10.45a.84.84,0,0,0-.84.84v5.14a3.55,3.55,0,0,1-7.1,0V16.09h2.71v2.24a.84.84,0,0,0,1.68,0v-5a3.55,3.55,0,0,1,7.09,0v1l-1.58.51-1.12-.51v-1A.85.85,0,0,0,15.91,12.45Zm7.93,6a3.55,3.55,0,0,1-7.09,0V16.14l1.12.51,1.58-.51v2.29a.84.84,0,0,0,1.68,0V16.19h2.71Z"
  })), children);
});
var LogoStumbleupon24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoStumbleupon24(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  if (true) {
    if (!didWarnAboutDeprecation['LogoStumbleupon24']) {
      didWarnAboutDeprecation['LogoStumbleupon24'] = true;
      console.warn("The LogoStumbleupon24 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm-.09,10.45a.84.84,0,0,0-.84.84v5.14a3.55,3.55,0,0,1-7.1,0V16.09h2.71v2.24a.84.84,0,0,0,1.68,0v-5a3.55,3.55,0,0,1,7.09,0v1l-1.58.51-1.12-.51v-1A.85.85,0,0,0,15.91,12.45Zm7.93,6a3.55,3.55,0,0,1-7.09,0V16.14l1.12.51,1.58-.51v2.29a.84.84,0,0,0,1.68,0V16.19h2.71Z"
  })), children);
});
var LogoStumbleupon20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoStumbleupon20(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  if (true) {
    if (!didWarnAboutDeprecation['LogoStumbleupon20']) {
      didWarnAboutDeprecation['LogoStumbleupon20'] = true;
      console.warn("The LogoStumbleupon20 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm-.09,10.45a.84.84,0,0,0-.84.84v5.14a3.55,3.55,0,0,1-7.1,0V16.09h2.71v2.24a.84.84,0,0,0,1.68,0v-5a3.55,3.55,0,0,1,7.09,0v1l-1.58.51-1.12-.51v-1A.85.85,0,0,0,15.91,12.45Zm7.93,6a3.55,3.55,0,0,1-7.09,0V16.14l1.12.51,1.58-.51v2.29a.84.84,0,0,0,1.68,0V16.19h2.71Z"
  })), children);
});
var LogoStumbleupon16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoStumbleupon16(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  if (true) {
    if (!didWarnAboutDeprecation['LogoStumbleupon16']) {
      didWarnAboutDeprecation['LogoStumbleupon16'] = true;
      console.warn("The LogoStumbleupon16 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm-.09,10.45a.84.84,0,0,0-.84.84v5.14a3.55,3.55,0,0,1-7.1,0V16.09h2.71v2.24a.84.84,0,0,0,1.68,0v-5a3.55,3.55,0,0,1,7.09,0v1l-1.58.51-1.12-.51v-1A.85.85,0,0,0,15.91,12.45Zm7.93,6a3.55,3.55,0,0,1-7.09,0V16.14l1.12.51,1.58-.51v2.29a.84.84,0,0,0,1.68,0V16.19h2.71Z"
  })), children);
});
var LogoTumblr32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoTumblr32(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.6,28h-4c-3.59,0-6.3-1.86-6.3-6.3V14.58H9V10.72A7.17,7.17,0,0,0,14.3,4h3.76v6.12h4.36v4.46H18.06v6.2c0,1.86.94,2.49,2.42,2.49H22.6Z"
  })), children);
});
var LogoTumblr24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoTumblr24(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.6,28h-4c-3.59,0-6.3-1.86-6.3-6.3V14.58H9V10.72A7.17,7.17,0,0,0,14.3,4h3.76v6.12h4.36v4.46H18.06v6.2c0,1.86.94,2.49,2.42,2.49H22.6Z"
  })), children);
});
var LogoTumblr20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoTumblr20(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.6,28h-4c-3.59,0-6.3-1.86-6.3-6.3V14.58H9V10.72A7.17,7.17,0,0,0,14.3,4h3.76v6.12h4.36v4.46H18.06v6.2c0,1.86.94,2.49,2.42,2.49H22.6Z"
  })), children);
});
var LogoTumblr16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoTumblr16(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.6,28h-4c-3.59,0-6.3-1.86-6.3-6.3V14.58H9V10.72A7.17,7.17,0,0,0,14.3,4h3.76v6.12h4.36v4.46H18.06v6.2c0,1.86.94,2.49,2.42,2.49H22.6Z"
  })), children);
});
var LogoTwitter32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoTwitter32(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.92,24.94A12.76,12.76,0,0,0,24.76,12.1c0-.2,0-.39,0-.59A9.4,9.4,0,0,0,27,9.18a9.31,9.31,0,0,1-2.59.71,4.56,4.56,0,0,0,2-2.5,8.89,8.89,0,0,1-2.86,1.1,4.52,4.52,0,0,0-7.7,4.11,12.79,12.79,0,0,1-9.3-4.71,4.51,4.51,0,0,0,1.4,6,4.47,4.47,0,0,1-2-.56v.05A4.53,4.53,0,0,0,9.5,17.83a4.53,4.53,0,0,1-2,.08A4.51,4.51,0,0,0,11.68,21,9.05,9.05,0,0,1,6.07,23,9.77,9.77,0,0,1,5,22.91a12.77,12.77,0,0,0,6.92,2"
  })), children);
});
var LogoTwitter24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoTwitter24(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.92,24.94A12.76,12.76,0,0,0,24.76,12.1c0-.2,0-.39,0-.59A9.4,9.4,0,0,0,27,9.18a9.31,9.31,0,0,1-2.59.71,4.56,4.56,0,0,0,2-2.5,8.89,8.89,0,0,1-2.86,1.1,4.52,4.52,0,0,0-7.7,4.11,12.79,12.79,0,0,1-9.3-4.71,4.51,4.51,0,0,0,1.4,6,4.47,4.47,0,0,1-2-.56v.05A4.53,4.53,0,0,0,9.5,17.83a4.53,4.53,0,0,1-2,.08A4.51,4.51,0,0,0,11.68,21,9.05,9.05,0,0,1,6.07,23,9.77,9.77,0,0,1,5,22.91a12.77,12.77,0,0,0,6.92,2"
  })), children);
});
var LogoTwitter20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoTwitter20(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.92,24.94A12.76,12.76,0,0,0,24.76,12.1c0-.2,0-.39,0-.59A9.4,9.4,0,0,0,27,9.18a9.31,9.31,0,0,1-2.59.71,4.56,4.56,0,0,0,2-2.5,8.89,8.89,0,0,1-2.86,1.1,4.52,4.52,0,0,0-7.7,4.11,12.79,12.79,0,0,1-9.3-4.71,4.51,4.51,0,0,0,1.4,6,4.47,4.47,0,0,1-2-.56v.05A4.53,4.53,0,0,0,9.5,17.83a4.53,4.53,0,0,1-2,.08A4.51,4.51,0,0,0,11.68,21,9.05,9.05,0,0,1,6.07,23,9.77,9.77,0,0,1,5,22.91a12.77,12.77,0,0,0,6.92,2"
  })), children);
});
var LogoTwitter16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoTwitter16(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.92,24.94A12.76,12.76,0,0,0,24.76,12.1c0-.2,0-.39,0-.59A9.4,9.4,0,0,0,27,9.18a9.31,9.31,0,0,1-2.59.71,4.56,4.56,0,0,0,2-2.5,8.89,8.89,0,0,1-2.86,1.1,4.52,4.52,0,0,0-7.7,4.11,12.79,12.79,0,0,1-9.3-4.71,4.51,4.51,0,0,0,1.4,6,4.47,4.47,0,0,1-2-.56v.05A4.53,4.53,0,0,0,9.5,17.83a4.53,4.53,0,0,1-2,.08A4.51,4.51,0,0,0,11.68,21,9.05,9.05,0,0,1,6.07,23,9.77,9.77,0,0,1,5,22.91a12.77,12.77,0,0,0,6.92,2"
  })), children);
});
var LogoVmware32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoVmware32(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32,16.77V13.8372c0-2.4818-2.4817-3.8355-4.5123-3.8355a6.7446,6.7446,0,0,0-3.8354,1.5793,5.066,5.066,0,0,0-3.61-1.5793,5.9389,5.9389,0,0,0-3.8354,1.5793,3.8172,3.8172,0,0,0-3.3842-1.5793A3.4913,3.4913,0,0,0,9.482,11.8232L6.5058,18.575,3.2011,11.0011a1.67,1.67,0,0,0-2.1883-.8656h0A1.67,1.67,0,0,0,.1536,12.37L4.25,21.2824s.6769,1.5793,2.0305,1.5793a1.9088,1.9088,0,0,0,2.0306-1.1281c.3124-.4687,2.6809-5.45,4.1078-8.4692a.5679.5679,0,0,1,1.0812.2437v7.4868a1.8462,1.8462,0,0,0,1.6848,1.8629,1.8051,1.8051,0,0,0,1.9251-1.801V14.8524a1.9177,1.9177,0,0,1,3.8354,0v6.2044a1.8049,1.8049,0,0,0,3.61,0V14.8524a1.9177,1.9177,0,0,1,3.8354,0v6.2044a1.8049,1.8049,0,0,0,3.61,0Z"
  })), children);
});
var LogoVmware24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoVmware24(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32,16.77V13.8372c0-2.4818-2.4817-3.8355-4.5123-3.8355a6.7446,6.7446,0,0,0-3.8354,1.5793,5.066,5.066,0,0,0-3.61-1.5793,5.9389,5.9389,0,0,0-3.8354,1.5793,3.8172,3.8172,0,0,0-3.3842-1.5793A3.4913,3.4913,0,0,0,9.482,11.8232L6.5058,18.575,3.2011,11.0011a1.67,1.67,0,0,0-2.1883-.8656h0A1.67,1.67,0,0,0,.1536,12.37L4.25,21.2824s.6769,1.5793,2.0305,1.5793a1.9088,1.9088,0,0,0,2.0306-1.1281c.3124-.4687,2.6809-5.45,4.1078-8.4692a.5679.5679,0,0,1,1.0812.2437v7.4868a1.8462,1.8462,0,0,0,1.6848,1.8629,1.8051,1.8051,0,0,0,1.9251-1.801V14.8524a1.9177,1.9177,0,0,1,3.8354,0v6.2044a1.8049,1.8049,0,0,0,3.61,0V14.8524a1.9177,1.9177,0,0,1,3.8354,0v6.2044a1.8049,1.8049,0,0,0,3.61,0Z"
  })), children);
});
var LogoVmware20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoVmware20(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32,16.77V13.8372c0-2.4818-2.4817-3.8355-4.5123-3.8355a6.7446,6.7446,0,0,0-3.8354,1.5793,5.066,5.066,0,0,0-3.61-1.5793,5.9389,5.9389,0,0,0-3.8354,1.5793,3.8172,3.8172,0,0,0-3.3842-1.5793A3.4913,3.4913,0,0,0,9.482,11.8232L6.5058,18.575,3.2011,11.0011a1.67,1.67,0,0,0-2.1883-.8656h0A1.67,1.67,0,0,0,.1536,12.37L4.25,21.2824s.6769,1.5793,2.0305,1.5793a1.9088,1.9088,0,0,0,2.0306-1.1281c.3124-.4687,2.6809-5.45,4.1078-8.4692a.5679.5679,0,0,1,1.0812.2437v7.4868a1.8462,1.8462,0,0,0,1.6848,1.8629,1.8051,1.8051,0,0,0,1.9251-1.801V14.8524a1.9177,1.9177,0,0,1,3.8354,0v6.2044a1.8049,1.8049,0,0,0,3.61,0V14.8524a1.9177,1.9177,0,0,1,3.8354,0v6.2044a1.8049,1.8049,0,0,0,3.61,0Z"
  })), children);
});
var LogoVmware16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoVmware16(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32,16.77V13.8372c0-2.4818-2.4817-3.8355-4.5123-3.8355a6.7446,6.7446,0,0,0-3.8354,1.5793,5.066,5.066,0,0,0-3.61-1.5793,5.9389,5.9389,0,0,0-3.8354,1.5793,3.8172,3.8172,0,0,0-3.3842-1.5793A3.4913,3.4913,0,0,0,9.482,11.8232L6.5058,18.575,3.2011,11.0011a1.67,1.67,0,0,0-2.1883-.8656h0A1.67,1.67,0,0,0,.1536,12.37L4.25,21.2824s.6769,1.5793,2.0305,1.5793a1.9088,1.9088,0,0,0,2.0306-1.1281c.3124-.4687,2.6809-5.45,4.1078-8.4692a.5679.5679,0,0,1,1.0812.2437v7.4868a1.8462,1.8462,0,0,0,1.6848,1.8629,1.8051,1.8051,0,0,0,1.9251-1.801V14.8524a1.9177,1.9177,0,0,1,3.8354,0v6.2044a1.8049,1.8049,0,0,0,3.61,0V14.8524a1.9177,1.9177,0,0,1,3.8354,0v6.2044a1.8049,1.8049,0,0,0,3.61,0Z"
  })), children);
});
var LogoWechat32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoWechat32(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M27.0857,24.7792A6.6179,6.6179,0,0,0,30,19.4662c0-3.88-3.7765-7.0269-8.4338-7.0269s-8.4339,3.1465-8.4339,7.0269,3.7765,7.028,8.4339,7.028a9.9547,9.9547,0,0,0,2.7533-.385l.2473-.0374a.8923.8923,0,0,1,.448.13l1.8469,1.0664.1621.0525a.2813.2813,0,0,0,.2812-.2812l-.0455-.2053-.38-1.4175-.0292-.18A.56.56,0,0,1,27.0857,24.7792ZM12.1208,4.68C6.5313,4.68,2,8.4552,2,13.1137a7.9386,7.9386,0,0,0,3.4965,6.3746.6713.6713,0,0,1,.2835.55l-.035.2147-.4562,1.701L5.234,22.2a.3384.3384,0,0,0,.3372.3383l.196-.063,2.2155-1.28a1.0584,1.0584,0,0,1,.5366-.1552l.2975.0443a11.9674,11.9674,0,0,0,3.304.4632l.5554-.014a6.5153,6.5153,0,0,1-.3395-2.0662c0-4.2478,4.1323-7.6918,9.2295-7.6918l.55.014C21.3538,7.761,17.169,4.68,12.1208,4.68Zm6.6337,13.6629a1.1247,1.1247,0,1,1,1.1247-1.1247A1.1243,1.1243,0,0,1,18.7545,18.3427Zm5.6233,0a1.1247,1.1247,0,1,1,1.1235-1.1247A1.1245,1.1245,0,0,1,24.3778,18.3427ZM8.7468,11.7638a1.3493,1.3493,0,1,1,1.35-1.3486A1.3485,1.3485,0,0,1,8.7468,11.7638Zm6.7469,0a1.3493,1.3493,0,1,1,1.35-1.3486A1.3486,1.3486,0,0,1,15.4937,11.7638Z"
  })), children);
});
var LogoWechat24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoWechat24(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M27.0857,24.7792A6.6179,6.6179,0,0,0,30,19.4662c0-3.88-3.7765-7.0269-8.4338-7.0269s-8.4339,3.1465-8.4339,7.0269,3.7765,7.028,8.4339,7.028a9.9547,9.9547,0,0,0,2.7533-.385l.2473-.0374a.8923.8923,0,0,1,.448.13l1.8469,1.0664.1621.0525a.2813.2813,0,0,0,.2812-.2812l-.0455-.2053-.38-1.4175-.0292-.18A.56.56,0,0,1,27.0857,24.7792ZM12.1208,4.68C6.5313,4.68,2,8.4552,2,13.1137a7.9386,7.9386,0,0,0,3.4965,6.3746.6713.6713,0,0,1,.2835.55l-.035.2147-.4562,1.701L5.234,22.2a.3384.3384,0,0,0,.3372.3383l.196-.063,2.2155-1.28a1.0584,1.0584,0,0,1,.5366-.1552l.2975.0443a11.9674,11.9674,0,0,0,3.304.4632l.5554-.014a6.5153,6.5153,0,0,1-.3395-2.0662c0-4.2478,4.1323-7.6918,9.2295-7.6918l.55.014C21.3538,7.761,17.169,4.68,12.1208,4.68Zm6.6337,13.6629a1.1247,1.1247,0,1,1,1.1247-1.1247A1.1243,1.1243,0,0,1,18.7545,18.3427Zm5.6233,0a1.1247,1.1247,0,1,1,1.1235-1.1247A1.1245,1.1245,0,0,1,24.3778,18.3427ZM8.7468,11.7638a1.3493,1.3493,0,1,1,1.35-1.3486A1.3485,1.3485,0,0,1,8.7468,11.7638Zm6.7469,0a1.3493,1.3493,0,1,1,1.35-1.3486A1.3486,1.3486,0,0,1,15.4937,11.7638Z"
  })), children);
});
var LogoWechat20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoWechat20(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M27.0857,24.7792A6.6179,6.6179,0,0,0,30,19.4662c0-3.88-3.7765-7.0269-8.4338-7.0269s-8.4339,3.1465-8.4339,7.0269,3.7765,7.028,8.4339,7.028a9.9547,9.9547,0,0,0,2.7533-.385l.2473-.0374a.8923.8923,0,0,1,.448.13l1.8469,1.0664.1621.0525a.2813.2813,0,0,0,.2812-.2812l-.0455-.2053-.38-1.4175-.0292-.18A.56.56,0,0,1,27.0857,24.7792ZM12.1208,4.68C6.5313,4.68,2,8.4552,2,13.1137a7.9386,7.9386,0,0,0,3.4965,6.3746.6713.6713,0,0,1,.2835.55l-.035.2147-.4562,1.701L5.234,22.2a.3384.3384,0,0,0,.3372.3383l.196-.063,2.2155-1.28a1.0584,1.0584,0,0,1,.5366-.1552l.2975.0443a11.9674,11.9674,0,0,0,3.304.4632l.5554-.014a6.5153,6.5153,0,0,1-.3395-2.0662c0-4.2478,4.1323-7.6918,9.2295-7.6918l.55.014C21.3538,7.761,17.169,4.68,12.1208,4.68Zm6.6337,13.6629a1.1247,1.1247,0,1,1,1.1247-1.1247A1.1243,1.1243,0,0,1,18.7545,18.3427Zm5.6233,0a1.1247,1.1247,0,1,1,1.1235-1.1247A1.1245,1.1245,0,0,1,24.3778,18.3427ZM8.7468,11.7638a1.3493,1.3493,0,1,1,1.35-1.3486A1.3485,1.3485,0,0,1,8.7468,11.7638Zm6.7469,0a1.3493,1.3493,0,1,1,1.35-1.3486A1.3486,1.3486,0,0,1,15.4937,11.7638Z"
  })), children);
});
var LogoWechat16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoWechat16(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M27.0857,24.7792A6.6179,6.6179,0,0,0,30,19.4662c0-3.88-3.7765-7.0269-8.4338-7.0269s-8.4339,3.1465-8.4339,7.0269,3.7765,7.028,8.4339,7.028a9.9547,9.9547,0,0,0,2.7533-.385l.2473-.0374a.8923.8923,0,0,1,.448.13l1.8469,1.0664.1621.0525a.2813.2813,0,0,0,.2812-.2812l-.0455-.2053-.38-1.4175-.0292-.18A.56.56,0,0,1,27.0857,24.7792ZM12.1208,4.68C6.5313,4.68,2,8.4552,2,13.1137a7.9386,7.9386,0,0,0,3.4965,6.3746.6713.6713,0,0,1,.2835.55l-.035.2147-.4562,1.701L5.234,22.2a.3384.3384,0,0,0,.3372.3383l.196-.063,2.2155-1.28a1.0584,1.0584,0,0,1,.5366-.1552l.2975.0443a11.9674,11.9674,0,0,0,3.304.4632l.5554-.014a6.5153,6.5153,0,0,1-.3395-2.0662c0-4.2478,4.1323-7.6918,9.2295-7.6918l.55.014C21.3538,7.761,17.169,4.68,12.1208,4.68Zm6.6337,13.6629a1.1247,1.1247,0,1,1,1.1247-1.1247A1.1243,1.1243,0,0,1,18.7545,18.3427Zm5.6233,0a1.1247,1.1247,0,1,1,1.1235-1.1247A1.1245,1.1245,0,0,1,24.3778,18.3427ZM8.7468,11.7638a1.3493,1.3493,0,1,1,1.35-1.3486A1.3485,1.3485,0,0,1,8.7468,11.7638Zm6.7469,0a1.3493,1.3493,0,1,1,1.35-1.3486A1.3486,1.3486,0,0,1,15.4937,11.7638Z"
  })), children);
});
var LogoXing32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoXing32(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.42,8.29a1.25,1.25,0,0,0-1.13-.76h-4a.65.65,0,0,0-.55.25.63.63,0,0,0,0,.62l2.73,4.73v0L4.17,20.72a.6.6,0,0,0,0,.62.58.58,0,0,0,.52.28h4a1.22,1.22,0,0,0,1.1-.78l4.36-7.71S11.42,8.29,11.42,8.29Z"
  })), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.83,2.88a.65.65,0,0,0,0-.62A.61.61,0,0,0,27.3,2H23.22a1.19,1.19,0,0,0-1.08.77s-8.7,15.43-9,15.93l5.74,10.53A1.26,1.26,0,0,0,20,30h4a.59.59,0,0,0,.54-.26.62.62,0,0,0,0-.62l-5.69-10.4a0,0,0,0,1,0,0Z"
  })), children);
});
var LogoXing24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoXing24(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.42,8.29a1.25,1.25,0,0,0-1.13-.76h-4a.65.65,0,0,0-.55.25.63.63,0,0,0,0,.62l2.73,4.73v0L4.17,20.72a.6.6,0,0,0,0,.62.58.58,0,0,0,.52.28h4a1.22,1.22,0,0,0,1.1-.78l4.36-7.71S11.42,8.29,11.42,8.29Z"
  })), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.83,2.88a.65.65,0,0,0,0-.62A.61.61,0,0,0,27.3,2H23.22a1.19,1.19,0,0,0-1.08.77s-8.7,15.43-9,15.93l5.74,10.53A1.26,1.26,0,0,0,20,30h4a.59.59,0,0,0,.54-.26.62.62,0,0,0,0-.62l-5.69-10.4a0,0,0,0,1,0,0Z"
  })), children);
});
var LogoXing20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoXing20(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.42,8.29a1.25,1.25,0,0,0-1.13-.76h-4a.65.65,0,0,0-.55.25.63.63,0,0,0,0,.62l2.73,4.73v0L4.17,20.72a.6.6,0,0,0,0,.62.58.58,0,0,0,.52.28h4a1.22,1.22,0,0,0,1.1-.78l4.36-7.71S11.42,8.29,11.42,8.29Z"
  })), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.83,2.88a.65.65,0,0,0,0-.62A.61.61,0,0,0,27.3,2H23.22a1.19,1.19,0,0,0-1.08.77s-8.7,15.43-9,15.93l5.74,10.53A1.26,1.26,0,0,0,20,30h4a.59.59,0,0,0,.54-.26.62.62,0,0,0,0-.62l-5.69-10.4a0,0,0,0,1,0,0Z"
  })), children);
});
var LogoXing16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoXing16(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.42,8.29a1.25,1.25,0,0,0-1.13-.76h-4a.65.65,0,0,0-.55.25.63.63,0,0,0,0,.62l2.73,4.73v0L4.17,20.72a.6.6,0,0,0,0,.62.58.58,0,0,0,.52.28h4a1.22,1.22,0,0,0,1.1-.78l4.36-7.71S11.42,8.29,11.42,8.29Z"
  })), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.83,2.88a.65.65,0,0,0,0-.62A.61.61,0,0,0,27.3,2H23.22a1.19,1.19,0,0,0-1.08.77s-8.7,15.43-9,15.93l5.74,10.53A1.26,1.26,0,0,0,20,30h4a.59.59,0,0,0,.54-.26.62.62,0,0,0,0-.62l-5.69-10.4a0,0,0,0,1,0,0Z"
  })), children);
});
var LogoYelp32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoYelp32(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M9.09 15.2458l4.6706 2.2777a1.0706 1.0706 0 01-.21 2.0011L8.5087 20.7818a1.0729 1.0729 0 01-1.3241-.921 9.2173 9.2173 0 01.4213-3.9965A1.0706 1.0706 0 019.09 15.2458zM10.96 24.8605l3.4763-3.8613a1.0707 1.0707 0 011.8657.7537l-.1814 5.1945a1.072 1.072 0 01-1.2491 1.0192A9.3014 9.3014 0 0111.1488 26.46 1.0713 1.0713 0 0110.96 24.8605zM19.2025 19.7222l4.9412 1.6058a1.0713 1.0713 0 01.6363 1.4794 9.3022 9.3022 0 01-2.4707 3.1663 1.072 1.072 0 01-1.5914-.2581l-2.7543-4.4078A1.0707 1.0707 0 0119.2025 19.7222zM24.2273 16.57l-4.9948 1.4321A1.0706 1.0706 0 0118.05 16.3742l2.906-4.3078A1.0706 1.0706 0 0122.55 11.86 9.2168 9.2168 0 0124.9135 15.11 1.0729 1.0729 0 0124.2273 16.57zM12.5561 4.45a14.9542 14.9542 0 00-2.5676.9459 1.07 1.07 0 00-.4636 1.5013l4.8819 8.4557a1.0707 1.0707 0 001.9979-.5353V5.0534A1.07 1.07 0 0015.2526 3.985 14.9577 14.9577 0 0012.5561 4.45z"
  })), children);
});
var LogoYelp24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoYelp24(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M9.09 15.2458l4.6706 2.2777a1.0706 1.0706 0 01-.21 2.0011L8.5087 20.7818a1.0729 1.0729 0 01-1.3241-.921 9.2173 9.2173 0 01.4213-3.9965A1.0706 1.0706 0 019.09 15.2458zM10.96 24.8605l3.4763-3.8613a1.0707 1.0707 0 011.8657.7537l-.1814 5.1945a1.072 1.072 0 01-1.2491 1.0192A9.3014 9.3014 0 0111.1488 26.46 1.0713 1.0713 0 0110.96 24.8605zM19.2025 19.7222l4.9412 1.6058a1.0713 1.0713 0 01.6363 1.4794 9.3022 9.3022 0 01-2.4707 3.1663 1.072 1.072 0 01-1.5914-.2581l-2.7543-4.4078A1.0707 1.0707 0 0119.2025 19.7222zM24.2273 16.57l-4.9948 1.4321A1.0706 1.0706 0 0118.05 16.3742l2.906-4.3078A1.0706 1.0706 0 0122.55 11.86 9.2168 9.2168 0 0124.9135 15.11 1.0729 1.0729 0 0124.2273 16.57zM12.5561 4.45a14.9542 14.9542 0 00-2.5676.9459 1.07 1.07 0 00-.4636 1.5013l4.8819 8.4557a1.0707 1.0707 0 001.9979-.5353V5.0534A1.07 1.07 0 0015.2526 3.985 14.9577 14.9577 0 0012.5561 4.45z"
  })), children);
});
var LogoYelp20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoYelp20(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M9.09 15.2458l4.6706 2.2777a1.0706 1.0706 0 01-.21 2.0011L8.5087 20.7818a1.0729 1.0729 0 01-1.3241-.921 9.2173 9.2173 0 01.4213-3.9965A1.0706 1.0706 0 019.09 15.2458zM10.96 24.8605l3.4763-3.8613a1.0707 1.0707 0 011.8657.7537l-.1814 5.1945a1.072 1.072 0 01-1.2491 1.0192A9.3014 9.3014 0 0111.1488 26.46 1.0713 1.0713 0 0110.96 24.8605zM19.2025 19.7222l4.9412 1.6058a1.0713 1.0713 0 01.6363 1.4794 9.3022 9.3022 0 01-2.4707 3.1663 1.072 1.072 0 01-1.5914-.2581l-2.7543-4.4078A1.0707 1.0707 0 0119.2025 19.7222zM24.2273 16.57l-4.9948 1.4321A1.0706 1.0706 0 0118.05 16.3742l2.906-4.3078A1.0706 1.0706 0 0122.55 11.86 9.2168 9.2168 0 0124.9135 15.11 1.0729 1.0729 0 0124.2273 16.57zM12.5561 4.45a14.9542 14.9542 0 00-2.5676.9459 1.07 1.07 0 00-.4636 1.5013l4.8819 8.4557a1.0707 1.0707 0 001.9979-.5353V5.0534A1.07 1.07 0 0015.2526 3.985 14.9577 14.9577 0 0012.5561 4.45z"
  })), children);
});
var LogoYelp16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoYelp16(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M9.09 15.2458l4.6706 2.2777a1.0706 1.0706 0 01-.21 2.0011L8.5087 20.7818a1.0729 1.0729 0 01-1.3241-.921 9.2173 9.2173 0 01.4213-3.9965A1.0706 1.0706 0 019.09 15.2458zM10.96 24.8605l3.4763-3.8613a1.0707 1.0707 0 011.8657.7537l-.1814 5.1945a1.072 1.072 0 01-1.2491 1.0192A9.3014 9.3014 0 0111.1488 26.46 1.0713 1.0713 0 0110.96 24.8605zM19.2025 19.7222l4.9412 1.6058a1.0713 1.0713 0 01.6363 1.4794 9.3022 9.3022 0 01-2.4707 3.1663 1.072 1.072 0 01-1.5914-.2581l-2.7543-4.4078A1.0707 1.0707 0 0119.2025 19.7222zM24.2273 16.57l-4.9948 1.4321A1.0706 1.0706 0 0118.05 16.3742l2.906-4.3078A1.0706 1.0706 0 0122.55 11.86 9.2168 9.2168 0 0124.9135 15.11 1.0729 1.0729 0 0124.2273 16.57zM12.5561 4.45a14.9542 14.9542 0 00-2.5676.9459 1.07 1.07 0 00-.4636 1.5013l4.8819 8.4557a1.0707 1.0707 0 001.9979-.5353V5.0534A1.07 1.07 0 0015.2526 3.985 14.9577 14.9577 0 0012.5561 4.45z"
  })), children);
});
var LogoYoutube32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoYoutube32(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.41,9.26a3.5,3.5,0,0,0-2.47-2.47C24.76,6.2,16,6.2,16,6.2s-8.76,0-10.94.59A3.5,3.5,0,0,0,2.59,9.26,36.13,36.13,0,0,0,2,16a36.13,36.13,0,0,0,.59,6.74,3.5,3.5,0,0,0,2.47,2.47C7.24,25.8,16,25.8,16,25.8s8.76,0,10.94-.59a3.5,3.5,0,0,0,2.47-2.47A36.13,36.13,0,0,0,30,16,36.13,36.13,0,0,0,29.41,9.26ZM13.2,20.2V11.8L20.47,16Z"
  })), children);
});
var LogoYoutube24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoYoutube24(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.41,9.26a3.5,3.5,0,0,0-2.47-2.47C24.76,6.2,16,6.2,16,6.2s-8.76,0-10.94.59A3.5,3.5,0,0,0,2.59,9.26,36.13,36.13,0,0,0,2,16a36.13,36.13,0,0,0,.59,6.74,3.5,3.5,0,0,0,2.47,2.47C7.24,25.8,16,25.8,16,25.8s8.76,0,10.94-.59a3.5,3.5,0,0,0,2.47-2.47A36.13,36.13,0,0,0,30,16,36.13,36.13,0,0,0,29.41,9.26ZM13.2,20.2V11.8L20.47,16Z"
  })), children);
});
var LogoYoutube20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoYoutube20(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.41,9.26a3.5,3.5,0,0,0-2.47-2.47C24.76,6.2,16,6.2,16,6.2s-8.76,0-10.94.59A3.5,3.5,0,0,0,2.59,9.26,36.13,36.13,0,0,0,2,16a36.13,36.13,0,0,0,.59,6.74,3.5,3.5,0,0,0,2.47,2.47C7.24,25.8,16,25.8,16,25.8s8.76,0,10.94-.59a3.5,3.5,0,0,0,2.47-2.47A36.13,36.13,0,0,0,30,16,36.13,36.13,0,0,0,29.41,9.26ZM13.2,20.2V11.8L20.47,16Z"
  })), children);
});
var LogoYoutube16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LogoYoutube16(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.41,9.26a3.5,3.5,0,0,0-2.47-2.47C24.76,6.2,16,6.2,16,6.2s-8.76,0-10.94.59A3.5,3.5,0,0,0,2.59,9.26,36.13,36.13,0,0,0,2,16a36.13,36.13,0,0,0,.59,6.74,3.5,3.5,0,0,0,2.47,2.47C7.24,25.8,16,25.8,16,25.8s8.76,0,10.94-.59a3.5,3.5,0,0,0,2.47-2.47A36.13,36.13,0,0,0,30,16,36.13,36.13,0,0,0,29.41,9.26ZM13.2,20.2V11.8L20.47,16Z"
  })), children);
});
var Logout32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Logout32(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H18a2.0023,2.0023,0,0,0,2-2V25H18v3H6V4H18V7h2V4a2.0023,2.0023,0,0,0-2-2H6A2.0023,2.0023,0,0,0,4,4V28A2.0023,2.0023,0,0,0,6,30Z"
  })), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.586 20.586L24.172 17 10 17 10 15 24.172 15 20.586 11.414 22 10 28 16 22 22 20.586 20.586z"
  })), children);
});
var Logout24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Logout24(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H18a2.0023,2.0023,0,0,0,2-2V25H18v3H6V4H18V7h2V4a2.0023,2.0023,0,0,0-2-2H6A2.0023,2.0023,0,0,0,4,4V28A2.0023,2.0023,0,0,0,6,30Z"
  })), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.586 20.586L24.172 17 10 17 10 15 24.172 15 20.586 11.414 22 10 28 16 22 22 20.586 20.586z"
  })), children);
});
var Logout20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Logout20(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H18a2.0023,2.0023,0,0,0,2-2V25H18v3H6V4H18V7h2V4a2.0023,2.0023,0,0,0-2-2H6A2.0023,2.0023,0,0,0,4,4V28A2.0023,2.0023,0,0,0,6,30Z"
  })), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.586 20.586L24.172 17 10 17 10 15 24.172 15 20.586 11.414 22 10 28 16 22 22 20.586 20.586z"
  })), children);
});
var Logout16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Logout16(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H18a2.0023,2.0023,0,0,0,2-2V25H18v3H6V4H18V7h2V4a2.0023,2.0023,0,0,0-2-2H6A2.0023,2.0023,0,0,0,4,4V28A2.0023,2.0023,0,0,0,6,30Z"
  })), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.586 20.586L24.172 17 10 17 10 15 24.172 15 20.586 11.414 22 10 28 16 22 22 20.586 20.586z"
  })), children);
});
var Loop32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Loop32(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.59 19.41L26 22 21 22 21 24 26 24 23.59 26.59 25 28 30 23 25 18 23.59 19.41zM13 6A9 9 0 005.52 20l1.66-1.11A7 7 0 1113 22H2v2H13A9 9 0 0013 6z"
  })), children);
});
var Loop24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Loop24(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.59 19.41L26 22 21 22 21 24 26 24 23.59 26.59 25 28 30 23 25 18 23.59 19.41zM13 6A9 9 0 005.52 20l1.66-1.11A7 7 0 1113 22H2v2H13A9 9 0 0013 6z"
  })), children);
});
var Loop20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Loop20(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.59 19.41L26 22 21 22 21 24 26 24 23.59 26.59 25 28 30 23 25 18 23.59 19.41zM13 6A9 9 0 005.52 20l1.66-1.11A7 7 0 1113 22H2v2H13A9 9 0 0013 6z"
  })), children);
});
var Loop16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Loop16(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.59 19.41L26 22 21 22 21 24 26 24 23.59 26.59 25 28 30 23 25 18 23.59 19.41zM13 6A9 9 0 005.52 20l1.66-1.11A7 7 0 1113 22H2v2H13A9 9 0 0013 6z"
  })), children);
});
var LowSeverityGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function LowSeverityGlyph(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 4H12V12H4z"
  })), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,4v8H4V4h8m1-1H3V13H13V3Z"
  })), children);
});
var MacCommand32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MacCommand32(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,13a4,4,0,0,0,4-4V8a4,4,0,0,0-4-4H23a4,4,0,0,0-4,4v3H13V8A4,4,0,0,0,9,4H8A4,4,0,0,0,4,8V9a4,4,0,0,0,4,4h3v6H8a4,4,0,0,0-4,4v1a4,4,0,0,0,4,4H9a4,4,0,0,0,4-4V21h6v3a4,4,0,0,0,4,4h1a4,4,0,0,0,4-4V23a4,4,0,0,0-4-4H21V13ZM21,8a2,2,0,0,1,2-2h1a2,2,0,0,1,2,2V9a2,2,0,0,1-2,2H21ZM8,11A2,2,0,0,1,6,9V8A2,2,0,0,1,8,6H9a2,2,0,0,1,2,2v3H8Zm3,13a2,2,0,0,1-2,2H8a2,2,0,0,1-2-2V23a2,2,0,0,1,2-2h3Zm8-5H13V13h6Zm2,2h3a2,2,0,0,1,2,2v1a2,2,0,0,1-2,2H23a2,2,0,0,1-2-2Z"
  })), children);
});
var MacCommand24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MacCommand24(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,13a4,4,0,0,0,4-4V8a4,4,0,0,0-4-4H23a4,4,0,0,0-4,4v3H13V8A4,4,0,0,0,9,4H8A4,4,0,0,0,4,8V9a4,4,0,0,0,4,4h3v6H8a4,4,0,0,0-4,4v1a4,4,0,0,0,4,4H9a4,4,0,0,0,4-4V21h6v3a4,4,0,0,0,4,4h1a4,4,0,0,0,4-4V23a4,4,0,0,0-4-4H21V13ZM21,8a2,2,0,0,1,2-2h1a2,2,0,0,1,2,2V9a2,2,0,0,1-2,2H21ZM8,11A2,2,0,0,1,6,9V8A2,2,0,0,1,8,6H9a2,2,0,0,1,2,2v3H8Zm3,13a2,2,0,0,1-2,2H8a2,2,0,0,1-2-2V23a2,2,0,0,1,2-2h3Zm8-5H13V13h6Zm2,2h3a2,2,0,0,1,2,2v1a2,2,0,0,1-2,2H23a2,2,0,0,1-2-2Z"
  })), children);
});
var MacCommand20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MacCommand20(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,13a4,4,0,0,0,4-4V8a4,4,0,0,0-4-4H23a4,4,0,0,0-4,4v3H13V8A4,4,0,0,0,9,4H8A4,4,0,0,0,4,8V9a4,4,0,0,0,4,4h3v6H8a4,4,0,0,0-4,4v1a4,4,0,0,0,4,4H9a4,4,0,0,0,4-4V21h6v3a4,4,0,0,0,4,4h1a4,4,0,0,0,4-4V23a4,4,0,0,0-4-4H21V13ZM21,8a2,2,0,0,1,2-2h1a2,2,0,0,1,2,2V9a2,2,0,0,1-2,2H21ZM8,11A2,2,0,0,1,6,9V8A2,2,0,0,1,8,6H9a2,2,0,0,1,2,2v3H8Zm3,13a2,2,0,0,1-2,2H8a2,2,0,0,1-2-2V23a2,2,0,0,1,2-2h3Zm8-5H13V13h6Zm2,2h3a2,2,0,0,1,2,2v1a2,2,0,0,1-2,2H23a2,2,0,0,1-2-2Z"
  })), children);
});
var MacCommand16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MacCommand16(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,13a4,4,0,0,0,4-4V8a4,4,0,0,0-4-4H23a4,4,0,0,0-4,4v3H13V8A4,4,0,0,0,9,4H8A4,4,0,0,0,4,8V9a4,4,0,0,0,4,4h3v6H8a4,4,0,0,0-4,4v1a4,4,0,0,0,4,4H9a4,4,0,0,0,4-4V21h6v3a4,4,0,0,0,4,4h1a4,4,0,0,0,4-4V23a4,4,0,0,0-4-4H21V13ZM21,8a2,2,0,0,1,2-2h1a2,2,0,0,1,2,2V9a2,2,0,0,1-2,2H21ZM8,11A2,2,0,0,1,6,9V8A2,2,0,0,1,8,6H9a2,2,0,0,1,2,2v3H8Zm3,13a2,2,0,0,1-2,2H8a2,2,0,0,1-2-2V23a2,2,0,0,1,2-2h3Zm8-5H13V13h6Zm2,2h3a2,2,0,0,1,2,2v1a2,2,0,0,1-2,2H23a2,2,0,0,1-2-2Z"
  })), children);
});
var MacOption32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MacOption32(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 5H28V7H18zM10.6 5L4 5 4 7 9.4 7 18.4 27 28 27 28 25 19.6 25z"
  })), children);
});
var MacOption24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MacOption24(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 5H28V7H18zM10.6 5L4 5 4 7 9.4 7 18.4 27 28 27 28 25 19.6 25z"
  })), children);
});
var MacOption20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MacOption20(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 5H28V7H18zM10.6 5L4 5 4 7 9.4 7 18.4 27 28 27 28 25 19.6 25z"
  })), children);
});
var MacOption16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MacOption16(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 5H28V7H18zM10.6 5L4 5 4 7 9.4 7 18.4 27 28 27 28 25 19.6 25z"
  })), children);
});
var MacShift32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MacShift32(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,28H11a2.0023,2.0023,0,0,1-2-2V16H4a1,1,0,0,1-.707-1.707l12-12a.9994.9994,0,0,1,1.414,0l12,12A1,1,0,0,1,28,16H23V26A2.0027,2.0027,0,0,1,21,28ZM6.4141,14H11V26H21V14h4.5859L16,4.4141Z"
  })), children);
});
var MacShift24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MacShift24(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,28H11a2.0023,2.0023,0,0,1-2-2V16H4a1,1,0,0,1-.707-1.707l12-12a.9994.9994,0,0,1,1.414,0l12,12A1,1,0,0,1,28,16H23V26A2.0027,2.0027,0,0,1,21,28ZM6.4141,14H11V26H21V14h4.5859L16,4.4141Z"
  })), children);
});
var MacShift20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MacShift20(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,28H11a2.0023,2.0023,0,0,1-2-2V16H4a1,1,0,0,1-.707-1.707l12-12a.9994.9994,0,0,1,1.414,0l12,12A1,1,0,0,1,28,16H23V26A2.0027,2.0027,0,0,1,21,28ZM6.4141,14H11V26H21V14h4.5859L16,4.4141Z"
  })), children);
});
var MacShift16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MacShift16(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,28H11a2.0023,2.0023,0,0,1-2-2V16H4a1,1,0,0,1-.707-1.707l12-12a.9994.9994,0,0,1,1.414,0l12,12A1,1,0,0,1,28,16H23V26A2.0027,2.0027,0,0,1,21,28ZM6.4141,14H11V26H21V14h4.5859L16,4.4141Z"
  })), children);
});
var MachineLearning32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MachineLearning32(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 25a6.9908 6.9908 0 01-5.833-3.1287l1.666-1.1074a5.0007 5.0007 0 008.334 0l1.666 1.1074A6.9908 6.9908 0 0116 25zM20 14a2 2 0 102 2A1.9806 1.9806 0 0020 14zM12 14a2 2 0 102 2A1.9806 1.9806 0 0012 14z"
  })), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16V14H28V10a4.0045,4.0045,0,0,0-4-4H22V2H20V6H12V2H10V6H8a4.0045,4.0045,0,0,0-4,4v4H2v2H4v5H2v2H4v3a4.0045,4.0045,0,0,0,4,4H24a4.0045,4.0045,0,0,0,4-4V23h2V21H28V16ZM26,26a2.0023,2.0023,0,0,1-2,2H8a2.0023,2.0023,0,0,1-2-2V10A2.0023,2.0023,0,0,1,8,8H24a2.0023,2.0023,0,0,1,2,2Z"
  })), children);
});
var MachineLearning24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MachineLearning24(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 25a6.9908 6.9908 0 01-5.833-3.1287l1.666-1.1074a5.0007 5.0007 0 008.334 0l1.666 1.1074A6.9908 6.9908 0 0116 25zM20 14a2 2 0 102 2A1.9806 1.9806 0 0020 14zM12 14a2 2 0 102 2A1.9806 1.9806 0 0012 14z"
  })), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16V14H28V10a4.0045,4.0045,0,0,0-4-4H22V2H20V6H12V2H10V6H8a4.0045,4.0045,0,0,0-4,4v4H2v2H4v5H2v2H4v3a4.0045,4.0045,0,0,0,4,4H24a4.0045,4.0045,0,0,0,4-4V23h2V21H28V16ZM26,26a2.0023,2.0023,0,0,1-2,2H8a2.0023,2.0023,0,0,1-2-2V10A2.0023,2.0023,0,0,1,8,8H24a2.0023,2.0023,0,0,1,2,2Z"
  })), children);
});
var MachineLearning20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MachineLearning20(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 25a6.9908 6.9908 0 01-5.833-3.1287l1.666-1.1074a5.0007 5.0007 0 008.334 0l1.666 1.1074A6.9908 6.9908 0 0116 25zM20 14a2 2 0 102 2A1.9806 1.9806 0 0020 14zM12 14a2 2 0 102 2A1.9806 1.9806 0 0012 14z"
  })), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16V14H28V10a4.0045,4.0045,0,0,0-4-4H22V2H20V6H12V2H10V6H8a4.0045,4.0045,0,0,0-4,4v4H2v2H4v5H2v2H4v3a4.0045,4.0045,0,0,0,4,4H24a4.0045,4.0045,0,0,0,4-4V23h2V21H28V16ZM26,26a2.0023,2.0023,0,0,1-2,2H8a2.0023,2.0023,0,0,1-2-2V10A2.0023,2.0023,0,0,1,8,8H24a2.0023,2.0023,0,0,1,2,2Z"
  })), children);
});
var MachineLearning16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MachineLearning16(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 25a6.9908 6.9908 0 01-5.833-3.1287l1.666-1.1074a5.0007 5.0007 0 008.334 0l1.666 1.1074A6.9908 6.9908 0 0116 25zM20 14a2 2 0 102 2A1.9806 1.9806 0 0020 14zM12 14a2 2 0 102 2A1.9806 1.9806 0 0012 14z"
  })), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16V14H28V10a4.0045,4.0045,0,0,0-4-4H22V2H20V6H12V2H10V6H8a4.0045,4.0045,0,0,0-4,4v4H2v2H4v5H2v2H4v3a4.0045,4.0045,0,0,0,4,4H24a4.0045,4.0045,0,0,0,4-4V23h2V21H28V16ZM26,26a2.0023,2.0023,0,0,1-2,2H8a2.0023,2.0023,0,0,1-2-2V10A2.0023,2.0023,0,0,1,8,8H24a2.0023,2.0023,0,0,1,2,2Z"
  })), children);
});
var MachineLearningModel32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MachineLearningModel32(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 24a2.9609 2.9609 0 00-1.2854.3008L21.4141 20H18v2h2.5859l3.7146 3.7148A2.9665 2.9665 0 0024 27a3 3 0 103-3zm0 4a1 1 0 111-1A1.0009 1.0009 0 0127 28zM27 13a2.9948 2.9948 0 00-2.8157 2H18v2h6.1843A2.9947 2.9947 0 1027 13zm0 4a1 1 0 111-1A1.0009 1.0009 0 0127 17zM27 2a3.0033 3.0033 0 00-3 3 2.9657 2.9657 0 00.3481 1.373L20.5957 10H18v2h3.4043l4.3989-4.2524A2.9987 2.9987 0 1027 2zm0 4a1 1 0 111-1A1.0009 1.0009 0 0127 6z"
  })), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,6h2V4H18a3.9756,3.9756,0,0,0-3,1.3823A3.9756,3.9756,0,0,0,12,4H11a9.01,9.01,0,0,0-9,9v6a9.01,9.01,0,0,0,9,9h1a3.9756,3.9756,0,0,0,3-1.3823A3.9756,3.9756,0,0,0,18,28h2V26H18a2.0023,2.0023,0,0,1-2-2V8A2.0023,2.0023,0,0,1,18,6ZM12,26H11a7.0047,7.0047,0,0,1-6.92-6H6V18H4V14H7a3.0033,3.0033,0,0,0,3-3V9H8v2a1.0009,1.0009,0,0,1-1,1H4.08A7.0047,7.0047,0,0,1,11,6h1a2.0023,2.0023,0,0,1,2,2v4H12v2h2v4H12a3.0033,3.0033,0,0,0-3,3v2h2V21a1.0009,1.0009,0,0,1,1-1h2v4A2.0023,2.0023,0,0,1,12,26Z"
  })), children);
});
var MachineLearningModel24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MachineLearningModel24(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 24a2.9609 2.9609 0 00-1.2854.3008L21.4141 20H18v2h2.5859l3.7146 3.7148A2.9665 2.9665 0 0024 27a3 3 0 103-3zm0 4a1 1 0 111-1A1.0009 1.0009 0 0127 28zM27 13a2.9948 2.9948 0 00-2.8157 2H18v2h6.1843A2.9947 2.9947 0 1027 13zm0 4a1 1 0 111-1A1.0009 1.0009 0 0127 17zM27 2a3.0033 3.0033 0 00-3 3 2.9657 2.9657 0 00.3481 1.373L20.5957 10H18v2h3.4043l4.3989-4.2524A2.9987 2.9987 0 1027 2zm0 4a1 1 0 111-1A1.0009 1.0009 0 0127 6z"
  })), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,6h2V4H18a3.9756,3.9756,0,0,0-3,1.3823A3.9756,3.9756,0,0,0,12,4H11a9.01,9.01,0,0,0-9,9v6a9.01,9.01,0,0,0,9,9h1a3.9756,3.9756,0,0,0,3-1.3823A3.9756,3.9756,0,0,0,18,28h2V26H18a2.0023,2.0023,0,0,1-2-2V8A2.0023,2.0023,0,0,1,18,6ZM12,26H11a7.0047,7.0047,0,0,1-6.92-6H6V18H4V14H7a3.0033,3.0033,0,0,0,3-3V9H8v2a1.0009,1.0009,0,0,1-1,1H4.08A7.0047,7.0047,0,0,1,11,6h1a2.0023,2.0023,0,0,1,2,2v4H12v2h2v4H12a3.0033,3.0033,0,0,0-3,3v2h2V21a1.0009,1.0009,0,0,1,1-1h2v4A2.0023,2.0023,0,0,1,12,26Z"
  })), children);
});
var MachineLearningModel20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MachineLearningModel20(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 24a2.9609 2.9609 0 00-1.2854.3008L21.4141 20H18v2h2.5859l3.7146 3.7148A2.9665 2.9665 0 0024 27a3 3 0 103-3zm0 4a1 1 0 111-1A1.0009 1.0009 0 0127 28zM27 13a2.9948 2.9948 0 00-2.8157 2H18v2h6.1843A2.9947 2.9947 0 1027 13zm0 4a1 1 0 111-1A1.0009 1.0009 0 0127 17zM27 2a3.0033 3.0033 0 00-3 3 2.9657 2.9657 0 00.3481 1.373L20.5957 10H18v2h3.4043l4.3989-4.2524A2.9987 2.9987 0 1027 2zm0 4a1 1 0 111-1A1.0009 1.0009 0 0127 6z"
  })), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,6h2V4H18a3.9756,3.9756,0,0,0-3,1.3823A3.9756,3.9756,0,0,0,12,4H11a9.01,9.01,0,0,0-9,9v6a9.01,9.01,0,0,0,9,9h1a3.9756,3.9756,0,0,0,3-1.3823A3.9756,3.9756,0,0,0,18,28h2V26H18a2.0023,2.0023,0,0,1-2-2V8A2.0023,2.0023,0,0,1,18,6ZM12,26H11a7.0047,7.0047,0,0,1-6.92-6H6V18H4V14H7a3.0033,3.0033,0,0,0,3-3V9H8v2a1.0009,1.0009,0,0,1-1,1H4.08A7.0047,7.0047,0,0,1,11,6h1a2.0023,2.0023,0,0,1,2,2v4H12v2h2v4H12a3.0033,3.0033,0,0,0-3,3v2h2V21a1.0009,1.0009,0,0,1,1-1h2v4A2.0023,2.0023,0,0,1,12,26Z"
  })), children);
});
var MachineLearningModel16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MachineLearningModel16(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 24a2.9609 2.9609 0 00-1.2854.3008L21.4141 20H18v2h2.5859l3.7146 3.7148A2.9665 2.9665 0 0024 27a3 3 0 103-3zm0 4a1 1 0 111-1A1.0009 1.0009 0 0127 28zM27 13a2.9948 2.9948 0 00-2.8157 2H18v2h6.1843A2.9947 2.9947 0 1027 13zm0 4a1 1 0 111-1A1.0009 1.0009 0 0127 17zM27 2a3.0033 3.0033 0 00-3 3 2.9657 2.9657 0 00.3481 1.373L20.5957 10H18v2h3.4043l4.3989-4.2524A2.9987 2.9987 0 1027 2zm0 4a1 1 0 111-1A1.0009 1.0009 0 0127 6z"
  })), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,6h2V4H18a3.9756,3.9756,0,0,0-3,1.3823A3.9756,3.9756,0,0,0,12,4H11a9.01,9.01,0,0,0-9,9v6a9.01,9.01,0,0,0,9,9h1a3.9756,3.9756,0,0,0,3-1.3823A3.9756,3.9756,0,0,0,18,28h2V26H18a2.0023,2.0023,0,0,1-2-2V8A2.0023,2.0023,0,0,1,18,6ZM12,26H11a7.0047,7.0047,0,0,1-6.92-6H6V18H4V14H7a3.0033,3.0033,0,0,0,3-3V9H8v2a1.0009,1.0009,0,0,1-1,1H4.08A7.0047,7.0047,0,0,1,11,6h1a2.0023,2.0023,0,0,1,2,2v4H12v2h2v4H12a3.0033,3.0033,0,0,0-3,3v2h2V21a1.0009,1.0009,0,0,1,1-1h2v4A2.0023,2.0023,0,0,1,12,26Z"
  })), children);
});
var MagicWand32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MagicWand32(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4141,24,12,6.5859a2.0476,2.0476,0,0,0-2.8281,0l-2.586,2.586a2.0021,2.0021,0,0,0,0,2.8281L23.999,29.4141a2.0024,2.0024,0,0,0,2.8281,0l2.587-2.5865a1.9993,1.9993,0,0,0,0-2.8281ZM8,10.5859,10.5859,8l5,5-2.5866,2.5869-5-5ZM25.4131,28l-11-10.999L17,14.4141l11,11Z"
  })), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.586 14.586H5.414V17.414H2.586z",
    transform: "rotate(-45 4 16)"
  })), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.586 2.586H17.414V5.414H14.586z",
    transform: "rotate(-45 16 4)"
  })), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.586 2.586H5.414V5.414H2.586z",
    transform: "rotate(-45 4 4)"
  })), children);
});
var MagicWand24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function MagicWand24(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4141,24,12,6.5859a2.0476,2.0476,0,0,0-2.8281,0l-2.586,2.586a2.0021,2.0021,0,0,0,0,2.8281L23.999,29.4141a2.0024,2.0024,0,0,0,2.8281,0l2.587-2.5865a1.9993,1.9993,0,0,0,0-2.8281ZM8,10.5859,10.5859,8l5,5-2.5866,2.5869-5-5ZM25.4131,28l-11-10.999L17,14.4141l11,11Z"
  })), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.586 14.586H5.414V17.414H2.586z",
    transform: "rotate(-45 4 16)"
  })), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.586 2.586H17.414V5.414H14.586z",
    transform: "rotate(-45 16 4)"
  })), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.586 2.586H5.414V5.414H2.586z",
    transform: "rotate(-45 4 4)"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-19.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-19.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "NumberSmall_016": () => (/* binding */ NumberSmall_016),
/* harmony export */   "NumberSmall_020": () => (/* binding */ NumberSmall_020),
/* harmony export */   "NumberSmall_024": () => (/* binding */ NumberSmall_024),
/* harmony export */   "NumberSmall_032": () => (/* binding */ NumberSmall_032),
/* harmony export */   "NumberSmall_116": () => (/* binding */ NumberSmall_116),
/* harmony export */   "NumberSmall_120": () => (/* binding */ NumberSmall_120),
/* harmony export */   "NumberSmall_124": () => (/* binding */ NumberSmall_124),
/* harmony export */   "NumberSmall_132": () => (/* binding */ NumberSmall_132),
/* harmony export */   "NumberSmall_216": () => (/* binding */ NumberSmall_216),
/* harmony export */   "NumberSmall_220": () => (/* binding */ NumberSmall_220),
/* harmony export */   "NumberSmall_224": () => (/* binding */ NumberSmall_224),
/* harmony export */   "NumberSmall_232": () => (/* binding */ NumberSmall_232),
/* harmony export */   "NumberSmall_316": () => (/* binding */ NumberSmall_316),
/* harmony export */   "NumberSmall_320": () => (/* binding */ NumberSmall_320),
/* harmony export */   "NumberSmall_324": () => (/* binding */ NumberSmall_324),
/* harmony export */   "NumberSmall_332": () => (/* binding */ NumberSmall_332),
/* harmony export */   "NumberSmall_416": () => (/* binding */ NumberSmall_416),
/* harmony export */   "NumberSmall_420": () => (/* binding */ NumberSmall_420),
/* harmony export */   "NumberSmall_424": () => (/* binding */ NumberSmall_424),
/* harmony export */   "NumberSmall_432": () => (/* binding */ NumberSmall_432),
/* harmony export */   "NumberSmall_516": () => (/* binding */ NumberSmall_516),
/* harmony export */   "NumberSmall_520": () => (/* binding */ NumberSmall_520),
/* harmony export */   "NumberSmall_524": () => (/* binding */ NumberSmall_524),
/* harmony export */   "NumberSmall_532": () => (/* binding */ NumberSmall_532),
/* harmony export */   "NumberSmall_616": () => (/* binding */ NumberSmall_616),
/* harmony export */   "NumberSmall_620": () => (/* binding */ NumberSmall_620),
/* harmony export */   "NumberSmall_624": () => (/* binding */ NumberSmall_624),
/* harmony export */   "NumberSmall_632": () => (/* binding */ NumberSmall_632),
/* harmony export */   "NumberSmall_716": () => (/* binding */ NumberSmall_716),
/* harmony export */   "NumberSmall_720": () => (/* binding */ NumberSmall_720),
/* harmony export */   "NumberSmall_724": () => (/* binding */ NumberSmall_724),
/* harmony export */   "NumberSmall_732": () => (/* binding */ NumberSmall_732),
/* harmony export */   "NumberSmall_816": () => (/* binding */ NumberSmall_816),
/* harmony export */   "NumberSmall_820": () => (/* binding */ NumberSmall_820),
/* harmony export */   "NumberSmall_824": () => (/* binding */ NumberSmall_824),
/* harmony export */   "NumberSmall_832": () => (/* binding */ NumberSmall_832),
/* harmony export */   "NumberSmall_916": () => (/* binding */ NumberSmall_916),
/* harmony export */   "NumberSmall_920": () => (/* binding */ NumberSmall_920),
/* harmony export */   "NumberSmall_924": () => (/* binding */ NumberSmall_924),
/* harmony export */   "NumberSmall_932": () => (/* binding */ NumberSmall_932),
/* harmony export */   "Number_716": () => (/* binding */ Number_716),
/* harmony export */   "Number_720": () => (/* binding */ Number_720),
/* harmony export */   "Number_816": () => (/* binding */ Number_816),
/* harmony export */   "Number_820": () => (/* binding */ Number_820),
/* harmony export */   "Number_824": () => (/* binding */ Number_824),
/* harmony export */   "Number_832": () => (/* binding */ Number_832),
/* harmony export */   "Number_916": () => (/* binding */ Number_916),
/* harmony export */   "Number_920": () => (/* binding */ Number_920),
/* harmony export */   "Number_924": () => (/* binding */ Number_924),
/* harmony export */   "Number_932": () => (/* binding */ Number_932),
/* harmony export */   "ObjectStorage16": () => (/* binding */ ObjectStorage16),
/* harmony export */   "ObjectStorage20": () => (/* binding */ ObjectStorage20),
/* harmony export */   "ObjectStorage24": () => (/* binding */ ObjectStorage24),
/* harmony export */   "ObjectStorage32": () => (/* binding */ ObjectStorage32),
/* harmony export */   "ObjectStorageAlt16": () => (/* binding */ ObjectStorageAlt16),
/* harmony export */   "ObjectStorageAlt20": () => (/* binding */ ObjectStorageAlt20),
/* harmony export */   "ObjectStorageAlt24": () => (/* binding */ ObjectStorageAlt24),
/* harmony export */   "ObjectStorageAlt32": () => (/* binding */ ObjectStorageAlt32),
/* harmony export */   "ObservedHail16": () => (/* binding */ ObservedHail16),
/* harmony export */   "ObservedHail20": () => (/* binding */ ObservedHail20),
/* harmony export */   "ObservedHail24": () => (/* binding */ ObservedHail24),
/* harmony export */   "ObservedHail32": () => (/* binding */ ObservedHail32),
/* harmony export */   "ObservedLightning16": () => (/* binding */ ObservedLightning16),
/* harmony export */   "ObservedLightning20": () => (/* binding */ ObservedLightning20),
/* harmony export */   "ObservedLightning24": () => (/* binding */ ObservedLightning24),
/* harmony export */   "ObservedLightning32": () => (/* binding */ ObservedLightning32),
/* harmony export */   "Omega16": () => (/* binding */ Omega16),
/* harmony export */   "Omega20": () => (/* binding */ Omega20),
/* harmony export */   "Omega24": () => (/* binding */ Omega24),
/* harmony export */   "Omega32": () => (/* binding */ Omega32),
/* harmony export */   "Opacity16": () => (/* binding */ Opacity16),
/* harmony export */   "Opacity20": () => (/* binding */ Opacity20),
/* harmony export */   "Opacity24": () => (/* binding */ Opacity24),
/* harmony export */   "Opacity32": () => (/* binding */ Opacity32),
/* harmony export */   "OpenPanelBottom16": () => (/* binding */ OpenPanelBottom16),
/* harmony export */   "OpenPanelBottom20": () => (/* binding */ OpenPanelBottom20),
/* harmony export */   "OpenPanelBottom24": () => (/* binding */ OpenPanelBottom24),
/* harmony export */   "OpenPanelBottom32": () => (/* binding */ OpenPanelBottom32),
/* harmony export */   "OpenPanelFilledBottom16": () => (/* binding */ OpenPanelFilledBottom16),
/* harmony export */   "OpenPanelFilledBottom20": () => (/* binding */ OpenPanelFilledBottom20),
/* harmony export */   "OpenPanelFilledBottom24": () => (/* binding */ OpenPanelFilledBottom24),
/* harmony export */   "OpenPanelFilledBottom32": () => (/* binding */ OpenPanelFilledBottom32),
/* harmony export */   "OpenPanelFilledLeft16": () => (/* binding */ OpenPanelFilledLeft16),
/* harmony export */   "OpenPanelFilledLeft20": () => (/* binding */ OpenPanelFilledLeft20),
/* harmony export */   "OpenPanelFilledLeft24": () => (/* binding */ OpenPanelFilledLeft24),
/* harmony export */   "OpenPanelFilledLeft32": () => (/* binding */ OpenPanelFilledLeft32),
/* harmony export */   "OpenPanelFilledRight16": () => (/* binding */ OpenPanelFilledRight16),
/* harmony export */   "OpenPanelFilledRight20": () => (/* binding */ OpenPanelFilledRight20),
/* harmony export */   "OpenPanelFilledRight24": () => (/* binding */ OpenPanelFilledRight24),
/* harmony export */   "OpenPanelFilledRight32": () => (/* binding */ OpenPanelFilledRight32),
/* harmony export */   "OpenPanelFilledTop16": () => (/* binding */ OpenPanelFilledTop16),
/* harmony export */   "OpenPanelFilledTop20": () => (/* binding */ OpenPanelFilledTop20),
/* harmony export */   "OpenPanelFilledTop24": () => (/* binding */ OpenPanelFilledTop24),
/* harmony export */   "OpenPanelFilledTop32": () => (/* binding */ OpenPanelFilledTop32),
/* harmony export */   "OpenPanelLeft16": () => (/* binding */ OpenPanelLeft16),
/* harmony export */   "OpenPanelLeft20": () => (/* binding */ OpenPanelLeft20),
/* harmony export */   "OpenPanelLeft24": () => (/* binding */ OpenPanelLeft24),
/* harmony export */   "OpenPanelLeft32": () => (/* binding */ OpenPanelLeft32),
/* harmony export */   "OpenPanelRight16": () => (/* binding */ OpenPanelRight16),
/* harmony export */   "OpenPanelRight20": () => (/* binding */ OpenPanelRight20),
/* harmony export */   "OpenPanelRight24": () => (/* binding */ OpenPanelRight24),
/* harmony export */   "OpenPanelRight32": () => (/* binding */ OpenPanelRight32),
/* harmony export */   "OpenPanelTop16": () => (/* binding */ OpenPanelTop16),
/* harmony export */   "OpenPanelTop20": () => (/* binding */ OpenPanelTop20),
/* harmony export */   "OpenPanelTop24": () => (/* binding */ OpenPanelTop24),
/* harmony export */   "OpenPanelTop32": () => (/* binding */ OpenPanelTop32),
/* harmony export */   "OperationsField16": () => (/* binding */ OperationsField16),
/* harmony export */   "OperationsField20": () => (/* binding */ OperationsField20),
/* harmony export */   "OperationsField24": () => (/* binding */ OperationsField24),
/* harmony export */   "OperationsField32": () => (/* binding */ OperationsField32),
/* harmony export */   "OperationsRecord16": () => (/* binding */ OperationsRecord16),
/* harmony export */   "OperationsRecord20": () => (/* binding */ OperationsRecord20),
/* harmony export */   "OperationsRecord24": () => (/* binding */ OperationsRecord24),
/* harmony export */   "OperationsRecord32": () => (/* binding */ OperationsRecord32),
/* harmony export */   "OrderDetails16": () => (/* binding */ OrderDetails16),
/* harmony export */   "OrderDetails20": () => (/* binding */ OrderDetails20),
/* harmony export */   "OrderDetails24": () => (/* binding */ OrderDetails24),
/* harmony export */   "OrderDetails32": () => (/* binding */ OrderDetails32),
/* harmony export */   "Ordinal16": () => (/* binding */ Ordinal16),
/* harmony export */   "Ordinal20": () => (/* binding */ Ordinal20),
/* harmony export */   "Ordinal24": () => (/* binding */ Ordinal24),
/* harmony export */   "Ordinal32": () => (/* binding */ Ordinal32),
/* harmony export */   "Outage16": () => (/* binding */ Outage16),
/* harmony export */   "Outage20": () => (/* binding */ Outage20),
/* harmony export */   "Outage24": () => (/* binding */ Outage24),
/* harmony export */   "Outage32": () => (/* binding */ Outage32),
/* harmony export */   "OutlookSevere16": () => (/* binding */ OutlookSevere16),
/* harmony export */   "OutlookSevere20": () => (/* binding */ OutlookSevere20),
/* harmony export */   "OutlookSevere24": () => (/* binding */ OutlookSevere24),
/* harmony export */   "OutlookSevere32": () => (/* binding */ OutlookSevere32),
/* harmony export */   "OverflowMenuHorizontal16": () => (/* binding */ OverflowMenuHorizontal16),
/* harmony export */   "OverflowMenuHorizontal20": () => (/* binding */ OverflowMenuHorizontal20),
/* harmony export */   "OverflowMenuHorizontal24": () => (/* binding */ OverflowMenuHorizontal24),
/* harmony export */   "OverflowMenuHorizontal32": () => (/* binding */ OverflowMenuHorizontal32),
/* harmony export */   "OverflowMenuVertical16": () => (/* binding */ OverflowMenuVertical16),
/* harmony export */   "OverflowMenuVertical20": () => (/* binding */ OverflowMenuVertical20),
/* harmony export */   "OverflowMenuVertical24": () => (/* binding */ OverflowMenuVertical24),
/* harmony export */   "OverflowMenuVertical32": () => (/* binding */ OverflowMenuVertical32),
/* harmony export */   "Overlay16": () => (/* binding */ Overlay16),
/* harmony export */   "Overlay20": () => (/* binding */ Overlay20),
/* harmony export */   "Overlay24": () => (/* binding */ Overlay24),
/* harmony export */   "Overlay32": () => (/* binding */ Overlay32),
/* harmony export */   "Package16": () => (/* binding */ Package16),
/* harmony export */   "Package20": () => (/* binding */ Package20),
/* harmony export */   "Package24": () => (/* binding */ Package24),
/* harmony export */   "Package32": () => (/* binding */ Package32),
/* harmony export */   "PageBreak16": () => (/* binding */ PageBreak16),
/* harmony export */   "PageBreak20": () => (/* binding */ PageBreak20),
/* harmony export */   "PageBreak24": () => (/* binding */ PageBreak24),
/* harmony export */   "PageBreak32": () => (/* binding */ PageBreak32),
/* harmony export */   "PageFirst16": () => (/* binding */ PageFirst16),
/* harmony export */   "PageFirst20": () => (/* binding */ PageFirst20),
/* harmony export */   "PageFirst24": () => (/* binding */ PageFirst24),
/* harmony export */   "PageFirst32": () => (/* binding */ PageFirst32),
/* harmony export */   "PageLast16": () => (/* binding */ PageLast16),
/* harmony export */   "PageLast20": () => (/* binding */ PageLast20),
/* harmony export */   "PageLast24": () => (/* binding */ PageLast24),
/* harmony export */   "PageLast32": () => (/* binding */ PageLast32),
/* harmony export */   "PageNumber16": () => (/* binding */ PageNumber16),
/* harmony export */   "PageNumber20": () => (/* binding */ PageNumber20),
/* harmony export */   "PageNumber24": () => (/* binding */ PageNumber24),
/* harmony export */   "PageNumber32": () => (/* binding */ PageNumber32),
/* harmony export */   "PaintBrush16": () => (/* binding */ PaintBrush16),
/* harmony export */   "PaintBrush20": () => (/* binding */ PaintBrush20),
/* harmony export */   "PaintBrush24": () => (/* binding */ PaintBrush24),
/* harmony export */   "PaintBrush32": () => (/* binding */ PaintBrush32),
/* harmony export */   "PaintBrushAlt16": () => (/* binding */ PaintBrushAlt16),
/* harmony export */   "PaintBrushAlt20": () => (/* binding */ PaintBrushAlt20),
/* harmony export */   "PaintBrushAlt24": () => (/* binding */ PaintBrushAlt24),
/* harmony export */   "PaintBrushAlt32": () => (/* binding */ PaintBrushAlt32),
/* harmony export */   "PalmTree16": () => (/* binding */ PalmTree16),
/* harmony export */   "PalmTree20": () => (/* binding */ PalmTree20),
/* harmony export */   "PalmTree24": () => (/* binding */ PalmTree24),
/* harmony export */   "PalmTree32": () => (/* binding */ PalmTree32),
/* harmony export */   "PanHorizontal16": () => (/* binding */ PanHorizontal16),
/* harmony export */   "PanHorizontal20": () => (/* binding */ PanHorizontal20),
/* harmony export */   "PanHorizontal24": () => (/* binding */ PanHorizontal24),
/* harmony export */   "PanHorizontal32": () => (/* binding */ PanHorizontal32),
/* harmony export */   "PanVertical16": () => (/* binding */ PanVertical16),
/* harmony export */   "PanVertical20": () => (/* binding */ PanVertical20),
/* harmony export */   "PanVertical24": () => (/* binding */ PanVertical24),
/* harmony export */   "PanVertical32": () => (/* binding */ PanVertical32),
/* harmony export */   "PanelExpansion16": () => (/* binding */ PanelExpansion16),
/* harmony export */   "PanelExpansion20": () => (/* binding */ PanelExpansion20),
/* harmony export */   "PanelExpansion24": () => (/* binding */ PanelExpansion24),
/* harmony export */   "PanelExpansion32": () => (/* binding */ PanelExpansion32),
/* harmony export */   "Paragraph16": () => (/* binding */ Paragraph16),
/* harmony export */   "Paragraph20": () => (/* binding */ Paragraph20),
/* harmony export */   "Paragraph24": () => (/* binding */ Paragraph24),
/* harmony export */   "Paragraph32": () => (/* binding */ Paragraph32),
/* harmony export */   "Parameter16": () => (/* binding */ Parameter16),
/* harmony export */   "Parameter20": () => (/* binding */ Parameter20),
/* harmony export */   "Parameter24": () => (/* binding */ Parameter24),
/* harmony export */   "Parameter32": () => (/* binding */ Parameter32),
/* harmony export */   "ParentChild16": () => (/* binding */ ParentChild16),
/* harmony export */   "ParentChild20": () => (/* binding */ ParentChild20),
/* harmony export */   "ParentChild24": () => (/* binding */ ParentChild24),
/* harmony export */   "ParentChild32": () => (/* binding */ ParentChild32),
/* harmony export */   "PartlyCloudy16": () => (/* binding */ PartlyCloudy16),
/* harmony export */   "PartlyCloudy20": () => (/* binding */ PartlyCloudy20),
/* harmony export */   "PartlyCloudy24": () => (/* binding */ PartlyCloudy24),
/* harmony export */   "PartlyCloudy32": () => (/* binding */ PartlyCloudy32),
/* harmony export */   "PartlyCloudyNight16": () => (/* binding */ PartlyCloudyNight16),
/* harmony export */   "PartlyCloudyNight20": () => (/* binding */ PartlyCloudyNight20),
/* harmony export */   "PartlyCloudyNight24": () => (/* binding */ PartlyCloudyNight24),
/* harmony export */   "PartlyCloudyNight32": () => (/* binding */ PartlyCloudyNight32),
/* harmony export */   "Partnership16": () => (/* binding */ Partnership16),
/* harmony export */   "Partnership20": () => (/* binding */ Partnership20),
/* harmony export */   "Partnership24": () => (/* binding */ Partnership24),
/* harmony export */   "Partnership32": () => (/* binding */ Partnership32),
/* harmony export */   "PassengerDrinks16": () => (/* binding */ PassengerDrinks16),
/* harmony export */   "PassengerDrinks20": () => (/* binding */ PassengerDrinks20),
/* harmony export */   "PassengerDrinks24": () => (/* binding */ PassengerDrinks24),
/* harmony export */   "PassengerDrinks32": () => (/* binding */ PassengerDrinks32),
/* harmony export */   "PassengerPlus16": () => (/* binding */ PassengerPlus16),
/* harmony export */   "PassengerPlus20": () => (/* binding */ PassengerPlus20),
/* harmony export */   "PassengerPlus24": () => (/* binding */ PassengerPlus24),
/* harmony export */   "PassengerPlus32": () => (/* binding */ PassengerPlus32),
/* harmony export */   "Password16": () => (/* binding */ Password16),
/* harmony export */   "Password20": () => (/* binding */ Password20),
/* harmony export */   "Password24": () => (/* binding */ Password24),
/* harmony export */   "Password32": () => (/* binding */ Password32),
/* harmony export */   "Paste16": () => (/* binding */ Paste16),
/* harmony export */   "Paste20": () => (/* binding */ Paste20),
/* harmony export */   "Paste24": () => (/* binding */ Paste24),
/* harmony export */   "Paste32": () => (/* binding */ Paste32),
/* harmony export */   "Pause16": () => (/* binding */ Pause16),
/* harmony export */   "Pause20": () => (/* binding */ Pause20),
/* harmony export */   "Pause24": () => (/* binding */ Pause24),
/* harmony export */   "Pause32": () => (/* binding */ Pause32),
/* harmony export */   "PauseFilled16": () => (/* binding */ PauseFilled16),
/* harmony export */   "PauseFilled20": () => (/* binding */ PauseFilled20),
/* harmony export */   "PauseFilled24": () => (/* binding */ PauseFilled24),
/* harmony export */   "PauseFilled32": () => (/* binding */ PauseFilled32),
/* harmony export */   "QOperation16": () => (/* binding */ QOperation16),
/* harmony export */   "QOperation20": () => (/* binding */ QOperation20),
/* harmony export */   "QOperation24": () => (/* binding */ QOperation24),
/* harmony export */   "QOperation32": () => (/* binding */ QOperation32),
/* harmony export */   "QOperationGauge16": () => (/* binding */ QOperationGauge16),
/* harmony export */   "QOperationGauge20": () => (/* binding */ QOperationGauge20),
/* harmony export */   "QOperationGauge24": () => (/* binding */ QOperationGauge24),
/* harmony export */   "QOperationGauge32": () => (/* binding */ QOperationGauge32),
/* harmony export */   "QOperationIf16": () => (/* binding */ QOperationIf16),
/* harmony export */   "QOperationIf20": () => (/* binding */ QOperationIf20),
/* harmony export */   "QOperationIf24": () => (/* binding */ QOperationIf24),
/* harmony export */   "QOperationIf32": () => (/* binding */ QOperationIf32),
/* harmony export */   "WatsonHealthPageScroll16": () => (/* binding */ WatsonHealthPageScroll16),
/* harmony export */   "WatsonHealthPageScroll20": () => (/* binding */ WatsonHealthPageScroll20),
/* harmony export */   "WatsonHealthPageScroll24": () => (/* binding */ WatsonHealthPageScroll24),
/* harmony export */   "WatsonHealthPageScroll32": () => (/* binding */ WatsonHealthPageScroll32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _circle, _path52, _path53, _circle2, _path54, _path55, _circle3, _path56, _path57, _circle4, _path58, _path59, _circle5, _path60, _path61, _circle6, _path62, _path63, _circle7, _path64, _path65, _circle8, _path66, _path67, _circle9, _circle10, _circle11, _path68, _path69, _path70, _circle12, _circle13, _circle14, _path71, _path72, _path73, _circle15, _circle16, _circle17, _path74, _path75, _path76, _circle18, _circle19, _circle20, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _circle21, _circle22, _circle23, _circle24, _circle25, _circle26, _circle27, _circle28, _circle29, _circle30, _circle31, _circle32, _circle33, _circle34, _circle35, _circle36, _circle37, _circle38, _circle39, _circle40, _circle41, _circle42, _circle43, _circle44, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _path224, _path225, _path226, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _circle45, _path340, _circle46, _path341, _circle47, _path342, _circle48, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var Number_720 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Number_720(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L12 9 12 13 14 13 14 11 17.85 11 13 23 15.16 23 20 11 20 9z"
  })), children);
});
var Number_716 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Number_716(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L12 9 12 13 14 13 14 11 17.85 11 13 23 15.16 23 20 11 20 9z"
  })), children);
});
var Number_832 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Number_832(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,9H14a2,2,0,0,0-2,2V21a2,2,0,0,0,2,2h4a2,2,0,0,0,2-2V11A2,2,0,0,0,18,9Zm0,2v4H14V11ZM14,21V17h4v4Z"
  })), children);
});
var Number_824 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Number_824(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,9H14a2,2,0,0,0-2,2V21a2,2,0,0,0,2,2h4a2,2,0,0,0,2-2V11A2,2,0,0,0,18,9Zm0,2v4H14V11ZM14,21V17h4v4Z"
  })), children);
});
var Number_820 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Number_820(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,9H14a2,2,0,0,0-2,2V21a2,2,0,0,0,2,2h4a2,2,0,0,0,2-2V11A2,2,0,0,0,18,9Zm0,2v4H14V11ZM14,21V17h4v4Z"
  })), children);
});
var Number_816 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Number_816(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,9H14a2,2,0,0,0-2,2V21a2,2,0,0,0,2,2h4a2,2,0,0,0,2-2V11A2,2,0,0,0,18,9Zm0,2v4H14V11ZM14,21V17h4v4Z"
  })), children);
});
var Number_932 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Number_932(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,9H14a2,2,0,0,0-2,2v5a2,2,0,0,0,2,2h4v3H13v2h5a2,2,0,0,0,2-2V11A2,2,0,0,0,18,9Zm0,7H14V11h4Z"
  })), children);
});
var Number_924 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Number_924(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,9H14a2,2,0,0,0-2,2v5a2,2,0,0,0,2,2h4v3H13v2h5a2,2,0,0,0,2-2V11A2,2,0,0,0,18,9Zm0,7H14V11h4Z"
  })), children);
});
var Number_920 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Number_920(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,9H14a2,2,0,0,0-2,2v5a2,2,0,0,0,2,2h4v3H13v2h5a2,2,0,0,0,2-2V11A2,2,0,0,0,18,9Zm0,7H14V11h4Z"
  })), children);
});
var Number_916 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Number_916(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,9H14a2,2,0,0,0-2,2v5a2,2,0,0,0,2,2h4v3H13v2h5a2,2,0,0,0,2-2V11A2,2,0,0,0,18,9Zm0,7H14V11h4Z"
  })), children);
});
var NumberSmall_032 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_032(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,21H15a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h2a2,2,0,0,1,2,2v6A2,2,0,0,1,17,21Zm-2-8v6h2V13Z"
  })), children);
});
var NumberSmall_024 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_024(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,21H15a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h2a2,2,0,0,1,2,2v6A2,2,0,0,1,17,21Zm-2-8v6h2V13Z"
  })), children);
});
var NumberSmall_020 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_020(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,21H15a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h2a2,2,0,0,1,2,2v6A2,2,0,0,1,17,21Zm-2-8v6h2V13Z"
  })), children);
});
var NumberSmall_016 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_016(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,21H15a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h2a2,2,0,0,1,2,2v6A2,2,0,0,1,17,21Zm-2-8v6h2V13Z"
  })), children);
});
var NumberSmall_132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_132(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 19L17 11 15 11 15 12 13 12 13 14 15 14 15 19 13 19 13 21 19 21 19 19 17 19z"
  })), children);
});
var NumberSmall_124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_124(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 19L17 11 15 11 15 12 13 12 13 14 15 14 15 19 13 19 13 21 19 21 19 19 17 19z"
  })), children);
});
var NumberSmall_120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_120(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 19L17 11 15 11 15 12 13 12 13 14 15 14 15 19 13 19 13 21 19 21 19 19 17 19z"
  })), children);
});
var NumberSmall_116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_116(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 19L17 11 15 11 15 12 13 12 13 14 15 14 15 19 13 19 13 21 19 21 19 19 17 19z"
  })), children);
});
var NumberSmall_232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_232(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,21H13V17a2,2,0,0,1,2-2h2V13H13V11h4a2,2,0,0,1,2,2v2a2,2,0,0,1-2,2H15v2h4Z"
  })), children);
});
var NumberSmall_224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_224(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,21H13V17a2,2,0,0,1,2-2h2V13H13V11h4a2,2,0,0,1,2,2v2a2,2,0,0,1-2,2H15v2h4Z"
  })), children);
});
var NumberSmall_220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_220(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,21H13V17a2,2,0,0,1,2-2h2V13H13V11h4a2,2,0,0,1,2,2v2a2,2,0,0,1-2,2H15v2h4Z"
  })), children);
});
var NumberSmall_216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_216(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,21H13V17a2,2,0,0,1,2-2h2V13H13V11h4a2,2,0,0,1,2,2v2a2,2,0,0,1-2,2H15v2h4Z"
  })), children);
});
var NumberSmall_332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_332(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,11H13v2h4v2H14v2h3v2H13v2h4a2,2,0,0,0,2-2V13A2,2,0,0,0,17,11Z"
  })), children);
});
var NumberSmall_324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_324(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,11H13v2h4v2H14v2h3v2H13v2h4a2,2,0,0,0,2-2V13A2,2,0,0,0,17,11Z"
  })), children);
});
var NumberSmall_320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_320(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,11H13v2h4v2H14v2h3v2H13v2h4a2,2,0,0,0,2-2V13A2,2,0,0,0,17,11Z"
  })), children);
});
var NumberSmall_316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_316(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,11H13v2h4v2H14v2h3v2H13v2h4a2,2,0,0,0,2-2V13A2,2,0,0,0,17,11Z"
  })), children);
});
var NumberSmall_432 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_432(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 11L17 15 15 15 15 11 13 11 13 17 17 17 17 21 19 21 19 11 17 11z"
  })), children);
});
var NumberSmall_424 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_424(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 11L17 15 15 15 15 11 13 11 13 17 17 17 17 21 19 21 19 11 17 11z"
  })), children);
});
var NumberSmall_420 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_420(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 11L17 15 15 15 15 11 13 11 13 17 17 17 17 21 19 21 19 11 17 11z"
  })), children);
});
var NumberSmall_416 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_416(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 11L17 15 15 15 15 11 13 11 13 17 17 17 17 21 19 21 19 11 17 11z"
  })), children);
});
var NumberSmall_532 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_532(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,21H13V19h4V17H13V11h6v2H15v2h2a2,2,0,0,1,2,2v2A2,2,0,0,1,17,21Z"
  })), children);
});
var NumberSmall_524 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_524(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,21H13V19h4V17H13V11h6v2H15v2h2a2,2,0,0,1,2,2v2A2,2,0,0,1,17,21Z"
  })), children);
});
var NumberSmall_520 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_520(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,21H13V19h4V17H13V11h6v2H15v2h2a2,2,0,0,1,2,2v2A2,2,0,0,1,17,21Z"
  })), children);
});
var NumberSmall_516 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_516(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,21H13V19h4V17H13V11h6v2H15v2h2a2,2,0,0,1,2,2v2A2,2,0,0,1,17,21Z"
  })), children);
});
var NumberSmall_632 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_632(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,21H15a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h3v2H15v2h2a2,2,0,0,1,2,2v2A2,2,0,0,1,17,21Zm-2-4v2h2V17Z"
  })), children);
});
var NumberSmall_624 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_624(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,21H15a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h3v2H15v2h2a2,2,0,0,1,2,2v2A2,2,0,0,1,17,21Zm-2-4v2h2V17Z"
  })), children);
});
var NumberSmall_620 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_620(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,21H15a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h3v2H15v2h2a2,2,0,0,1,2,2v2A2,2,0,0,1,17,21Zm-2-4v2h2V17Z"
  })), children);
});
var NumberSmall_616 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_616(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,21H15a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h3v2H15v2h2a2,2,0,0,1,2,2v2A2,2,0,0,1,17,21Zm-2-4v2h2V17Z"
  })), children);
});
var NumberSmall_732 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_732(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.44 21L14.44 21 17 13 15 13 15 14 13 14 13 11 19 11 19 13 16.44 21z"
  })), children);
});
var NumberSmall_724 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_724(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.44 21L14.44 21 17 13 15 13 15 14 13 14 13 11 19 11 19 13 16.44 21z"
  })), children);
});
var NumberSmall_720 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_720(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.44 21L14.44 21 17 13 15 13 15 14 13 14 13 11 19 11 19 13 16.44 21z"
  })), children);
});
var NumberSmall_716 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_716(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.44 21L14.44 21 17 13 15 13 15 14 13 14 13 11 19 11 19 13 16.44 21z"
  })), children);
});
var NumberSmall_832 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_832(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,11H15a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h2a2,2,0,0,0,2-2V13A2,2,0,0,0,17,11Zm0,2v2H15V13Zm-2,6V17h2v2Z"
  })), children);
});
var NumberSmall_824 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_824(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,11H15a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h2a2,2,0,0,0,2-2V13A2,2,0,0,0,17,11Zm0,2v2H15V13Zm-2,6V17h2v2Z"
  })), children);
});
var NumberSmall_820 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_820(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,11H15a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h2a2,2,0,0,0,2-2V13A2,2,0,0,0,17,11Zm0,2v2H15V13Zm-2,6V17h2v2Z"
  })), children);
});
var NumberSmall_816 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_816(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,11H15a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h2a2,2,0,0,0,2-2V13A2,2,0,0,0,17,11Zm0,2v2H15V13Zm-2,6V17h2v2Z"
  })), children);
});
var NumberSmall_932 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_932(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,21H14V19h3V17H15a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h2a2,2,0,0,1,2,2v6A2,2,0,0,1,17,21Zm-2-8v2h2V13Z"
  })), children);
});
var NumberSmall_924 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_924(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,21H14V19h3V17H15a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h2a2,2,0,0,1,2,2v6A2,2,0,0,1,17,21Zm-2-8v2h2V13Z"
  })), children);
});
var NumberSmall_920 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_920(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,21H14V19h3V17H15a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h2a2,2,0,0,1,2,2v6A2,2,0,0,1,17,21Zm-2-8v2h2V13Z"
  })), children);
});
var NumberSmall_916 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function NumberSmall_916(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,21H14V19h3V17H15a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h2a2,2,0,0,1,2,2v6A2,2,0,0,1,17,21Zm-2-8v2h2V13Z"
  })), children);
});
var ObjectStorage32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ObjectStorage32(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H14V20H4a2.0023,2.0023,0,0,0-2,2v6a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V22A2.0023,2.0023,0,0,0,28,20Z"
  })), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 8H22v6H16v8h8V16h6zM22 20H18V16h4zm6-6H24V10h4zM18 10H10V2h8zM12 8h4V4H12z"
  })), children);
});
var ObjectStorage24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ObjectStorage24(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H14V20H4a2.0023,2.0023,0,0,0-2,2v6a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V22A2.0023,2.0023,0,0,0,28,20Z"
  })), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 8H22v6H16v8h8V16h6zM22 20H18V16h4zm6-6H24V10h4zM18 10H10V2h8zM12 8h4V4H12z"
  })), children);
});
var ObjectStorage20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ObjectStorage20(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H14V20H4a2.0023,2.0023,0,0,0-2,2v6a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V22A2.0023,2.0023,0,0,0,28,20Z"
  })), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 8H22v6H16v8h8V16h6zM22 20H18V16h4zm6-6H24V10h4zM18 10H10V2h8zM12 8h4V4H12z"
  })), children);
});
var ObjectStorage16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ObjectStorage16(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H14V20H4a2.0023,2.0023,0,0,0-2,2v6a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V22A2.0023,2.0023,0,0,0,28,20Z"
  })), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 8H22v6H16v8h8V16h6zM22 20H18V16h4zm6-6H24V10h4zM18 10H10V2h8zM12 8h4V4H12z"
  })), children);
});
var ObjectStorageAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ObjectStorageAlt32(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H14V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,14a2.981,2.981,0,0,0-2.0374.811l-4.0039-2.4023A2.9578,2.9578,0,0,0,15,12a2.9578,2.9578,0,0,0-.0413-.4087L18.9626,9.189A2.9909,2.9909,0,1,0,18,7a2.9345,2.9345,0,0,0,.0415.4092L14.0376,9.8115a3,3,0,1,0,0,4.377l4.0039,2.4023A2.9345,2.9345,0,0,0,18,17a3,3,0,1,0,3-3Zm0-8a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,21,6Zm-9,7a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,12,13Zm9,5a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,21,18Z"
  })), children);
});
var ObjectStorageAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ObjectStorageAlt24(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H14V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,14a2.981,2.981,0,0,0-2.0374.811l-4.0039-2.4023A2.9578,2.9578,0,0,0,15,12a2.9578,2.9578,0,0,0-.0413-.4087L18.9626,9.189A2.9909,2.9909,0,1,0,18,7a2.9345,2.9345,0,0,0,.0415.4092L14.0376,9.8115a3,3,0,1,0,0,4.377l4.0039,2.4023A2.9345,2.9345,0,0,0,18,17a3,3,0,1,0,3-3Zm0-8a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,21,6Zm-9,7a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,12,13Zm9,5a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,21,18Z"
  })), children);
});
var ObjectStorageAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ObjectStorageAlt20(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H14V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,14a2.981,2.981,0,0,0-2.0374.811l-4.0039-2.4023A2.9578,2.9578,0,0,0,15,12a2.9578,2.9578,0,0,0-.0413-.4087L18.9626,9.189A2.9909,2.9909,0,1,0,18,7a2.9345,2.9345,0,0,0,.0415.4092L14.0376,9.8115a3,3,0,1,0,0,4.377l4.0039,2.4023A2.9345,2.9345,0,0,0,18,17a3,3,0,1,0,3-3Zm0-8a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,21,6Zm-9,7a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,12,13Zm9,5a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,21,18Z"
  })), children);
});
var ObjectStorageAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ObjectStorageAlt16(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H14V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,14a2.981,2.981,0,0,0-2.0374.811l-4.0039-2.4023A2.9578,2.9578,0,0,0,15,12a2.9578,2.9578,0,0,0-.0413-.4087L18.9626,9.189A2.9909,2.9909,0,1,0,18,7a2.9345,2.9345,0,0,0,.0415.4092L14.0376,9.8115a3,3,0,1,0,0,4.377l4.0039,2.4023A2.9345,2.9345,0,0,0,18,17a3,3,0,1,0,3-3Zm0-8a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,21,6Zm-9,7a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,12,13Zm9,5a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,21,18Z"
  })), children);
});
var ObservedHail32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ObservedHail32(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13.5",
    cy: "23.5",
    r: "1.5"
  })), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10.5",
    cy: "19.5",
    r: "1.5"
  })), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16.5",
    cy: "19.5",
    r: "1.5"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.964 14.5H17.036V16.499H11.964z",
    transform: "rotate(-45 14.5 15.5)"
  })), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.964 14.5H23.035999999999998V16.499H17.964z",
    transform: "rotate(-45 20.5 15.5)"
  })), children);
});
var ObservedHail24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ObservedHail24(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13.5",
    cy: "23.5",
    r: "1.5"
  })), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10.5",
    cy: "19.5",
    r: "1.5"
  })), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16.5",
    cy: "19.5",
    r: "1.5"
  })), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.964 14.5H17.036V16.499H11.964z",
    transform: "rotate(-45 14.5 15.5)"
  })), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.964 14.5H23.035999999999998V16.499H17.964z",
    transform: "rotate(-45 20.5 15.5)"
  })), children);
});
var ObservedHail20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ObservedHail20(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13.5",
    cy: "23.5",
    r: "1.5"
  })), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10.5",
    cy: "19.5",
    r: "1.5"
  })), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16.5",
    cy: "19.5",
    r: "1.5"
  })), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.964 14.5H17.036V16.499H11.964z",
    transform: "rotate(-45 14.5 15.5)"
  })), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.964 14.5H23.035999999999998V16.499H17.964z",
    transform: "rotate(-45 20.5 15.5)"
  })), children);
});
var ObservedHail16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ObservedHail16(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13.5",
    cy: "23.5",
    r: "1.5"
  })), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10.5",
    cy: "19.5",
    r: "1.5"
  })), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16.5",
    cy: "19.5",
    r: "1.5"
  })), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.964 14.5H17.036V16.499H11.964z",
    transform: "rotate(-45 14.5 15.5)"
  })), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.964 14.5H23.035999999999998V16.499H17.964z",
    transform: "rotate(-45 20.5 15.5)"
  })), children);
});
var ObservedLightning32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ObservedLightning32(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.67 24L13.934 23 16.221 19 12.332 19 16.325 12 18.062 13 15.778 17 19.668 17 15.67 24z"
  })), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), children);
});
var ObservedLightning24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ObservedLightning24(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.67 24L13.934 23 16.221 19 12.332 19 16.325 12 18.062 13 15.778 17 19.668 17 15.67 24z"
  })), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), children);
});
var ObservedLightning20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ObservedLightning20(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.67 24L13.934 23 16.221 19 12.332 19 16.325 12 18.062 13 15.778 17 19.668 17 15.67 24z"
  })), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), children);
});
var ObservedLightning16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ObservedLightning16(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.67 24L13.934 23 16.221 19 12.332 19 16.325 12 18.062 13 15.778 17 19.668 17 15.67 24z"
  })), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), children);
});
var Omega32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Omega32(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.7373,25A14.3093,14.3093,0,0,0,27,15C27,8.42,22.58,4,16,4S5,8.42,5,15A14.3093,14.3093,0,0,0,9.2627,25H4v2h8V24.7617A12.5683,12.5683,0,0,1,7,15c0-5.4673,3.5327-9,9-9s9,3.5327,9,9a12.5683,12.5683,0,0,1-5,9.7617V27h8V25Z"
  })), children);
});
var Omega24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Omega24(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.7373,25A14.3093,14.3093,0,0,0,27,15C27,8.42,22.58,4,16,4S5,8.42,5,15A14.3093,14.3093,0,0,0,9.2627,25H4v2h8V24.7617A12.5683,12.5683,0,0,1,7,15c0-5.4673,3.5327-9,9-9s9,3.5327,9,9a12.5683,12.5683,0,0,1-5,9.7617V27h8V25Z"
  })), children);
});
var Omega20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Omega20(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.7373,25A14.3093,14.3093,0,0,0,27,15C27,8.42,22.58,4,16,4S5,8.42,5,15A14.3093,14.3093,0,0,0,9.2627,25H4v2h8V24.7617A12.5683,12.5683,0,0,1,7,15c0-5.4673,3.5327-9,9-9s9,3.5327,9,9a12.5683,12.5683,0,0,1-5,9.7617V27h8V25Z"
  })), children);
});
var Omega16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Omega16(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.7373,25A14.3093,14.3093,0,0,0,27,15C27,8.42,22.58,4,16,4S5,8.42,5,15A14.3093,14.3093,0,0,0,9.2627,25H4v2h8V24.7617A12.5683,12.5683,0,0,1,7,15c0-5.4673,3.5327-9,9-9s9,3.5327,9,9a12.5683,12.5683,0,0,1-5,9.7617V27h8V25Z"
  })), children);
});
var Opacity32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Opacity32(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 6H10V10H6zM10 10H14V14H10zM14 6H18V10H14zM22 6H26V10H22zM6 14H10V18H6zM14 14H18V18H14zM22 14H26V18H22zM6 22H10V26H6zM14 22H18V26H14zM22 22H26V26H22zM18 10H22V14H18zM10 18H14V22H10zM18 18H22V22H18z"
  })), children);
});
var Opacity24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Opacity24(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 6H10V10H6zM10 10H14V14H10zM14 6H18V10H14zM22 6H26V10H22zM6 14H10V18H6zM14 14H18V18H14zM22 14H26V18H22zM6 22H10V26H6zM14 22H18V26H14zM22 22H26V26H22zM18 10H22V14H18zM10 18H14V22H10zM18 18H22V22H18z"
  })), children);
});
var Opacity20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Opacity20(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 6H10V10H6zM10 10H14V14H10zM14 6H18V10H14zM22 6H26V10H22zM6 14H10V18H6zM14 14H18V18H14zM22 14H26V18H22zM6 22H10V26H6zM14 22H18V26H14zM22 22H26V26H22zM18 10H22V14H18zM10 18H14V22H10zM18 18H22V22H18z"
  })), children);
});
var Opacity16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Opacity16(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 6H10V10H6zM10 10H14V14H10zM14 6H18V10H14zM22 6H26V10H22zM6 14H10V18H6zM14 14H18V18H14zM22 14H26V18H22zM6 22H10V26H6zM14 22H18V26H14zM22 22H26V26H22zM18 10H22V14H18zM10 18H14V22H10zM18 18H22V22H18z"
  })), children);
});
var OpenPanelBottom32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelBottom32(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,2V18H4V6ZM4,26V20H28v6Z"
  })), children);
});
var OpenPanelBottom24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelBottom24(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,2V18H4V6ZM4,26V20H28v6Z"
  })), children);
});
var OpenPanelBottom20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelBottom20(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,2V18H4V6ZM4,26V20H28v6Z"
  })), children);
});
var OpenPanelBottom16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelBottom16(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,2V18H4V6ZM4,26V20H28v6Z"
  })), children);
});
var OpenPanelFilledBottom32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelFilledBottom32(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,2V18H4V6Z"
  })), children);
});
var OpenPanelFilledBottom24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelFilledBottom24(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,2V18H4V6Z"
  })), children);
});
var OpenPanelFilledBottom20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelFilledBottom20(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,2V18H4V6Z"
  })), children);
});
var OpenPanelFilledBottom16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelFilledBottom16(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,2V18H4V6Z"
  })), children);
});
var OpenPanelFilledLeft32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelFilledLeft32(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,22H12V6H28Z"
  })), children);
});
var OpenPanelFilledLeft24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelFilledLeft24(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,22H12V6H28Z"
  })), children);
});
var OpenPanelFilledLeft20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelFilledLeft20(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,22H12V6H28Z"
  })), children);
});
var OpenPanelFilledLeft16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelFilledLeft16(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,22H12V6H28Z"
  })), children);
});
var OpenPanelFilledRight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelFilledRight32(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM4,6H20V26H4Z"
  })), children);
});
var OpenPanelFilledRight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelFilledRight24(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM4,6H20V26H4Z"
  })), children);
});
var OpenPanelFilledRight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelFilledRight20(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM4,6H20V26H4Z"
  })), children);
});
var OpenPanelFilledRight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelFilledRight16(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM4,6H20V26H4Z"
  })), children);
});
var OpenPanelFilledTop32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelFilledTop32(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM4,26V14H28V26Z"
  })), children);
});
var OpenPanelFilledTop24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelFilledTop24(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM4,26V14H28V26Z"
  })), children);
});
var OpenPanelFilledTop20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelFilledTop20(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM4,26V14H28V26Z"
  })), children);
});
var OpenPanelFilledTop16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelFilledTop16(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM4,26V14H28V26Z"
  })), children);
});
var OpenPanelLeft32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelLeft32(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM4,6h6V26H4ZM28,26H12V6H28Z"
  })), children);
});
var OpenPanelLeft24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelLeft24(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM4,6h6V26H4ZM28,26H12V6H28Z"
  })), children);
});
var OpenPanelLeft20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelLeft20(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM4,6h6V26H4ZM28,26H12V6H28Z"
  })), children);
});
var OpenPanelLeft16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelLeft16(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM4,6h6V26H4ZM28,26H12V6H28Z"
  })), children);
});
var OpenPanelRight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelRight32(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM4,6H20V26H4ZM28,26H22V6h6Z"
  })), children);
});
var OpenPanelRight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelRight24(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM4,6H20V26H4ZM28,26H22V6h6Z"
  })), children);
});
var OpenPanelRight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelRight20(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM4,6H20V26H4ZM28,26H22V6h6Z"
  })), children);
});
var OpenPanelRight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelRight16(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM4,6H20V26H4ZM28,26H22V6h6Z"
  })), children);
});
var OpenPanelTop32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelTop32(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,2v6H4V6ZM4,26V14H28V26Z"
  })), children);
});
var OpenPanelTop24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelTop24(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,2v6H4V6ZM4,26V14H28V26Z"
  })), children);
});
var OpenPanelTop20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelTop20(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,2v6H4V6ZM4,26V14H28V26Z"
  })), children);
});
var OpenPanelTop16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OpenPanelTop16(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4Zm0,2v6H4V6ZM4,26V14H28V26Z"
  })), children);
});
var QOperation32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QOperation32(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 26L21 26 26 16 21 6 23 6 28 16 23 26zM4 6H6V26H4zM16 9H12a2 2 0 00-2 2V21a2 2 0 002 2h4a2 2 0 002-2V11A2 2 0 0016 9zm0 12H12V11h4z"
  })), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 15H15V17H13z"
  })), children);
});
var QOperation24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QOperation24(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 26L21 26 26 16 21 6 23 6 28 16 23 26zM4 6H6V26H4zM16 9H12a2 2 0 00-2 2V21a2 2 0 002 2h4a2 2 0 002-2V11A2 2 0 0016 9zm0 12H12V11h4z"
  })), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 15H15V17H13z"
  })), children);
});
var QOperation20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QOperation20(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 26L21 26 26 16 21 6 23 6 28 16 23 26zM4 6H6V26H4zM16 9H12a2 2 0 00-2 2V21a2 2 0 002 2h4a2 2 0 002-2V11A2 2 0 0016 9zm0 12H12V11h4z"
  })), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 15H15V17H13z"
  })), children);
});
var QOperation16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QOperation16(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 26L21 26 26 16 21 6 23 6 28 16 23 26zM4 6H6V26H4zM16 9H12a2 2 0 00-2 2V21a2 2 0 002 2h4a2 2 0 002-2V11A2 2 0 0016 9zm0 12H12V11h4z"
  })), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 15H15V17H13z"
  })), children);
});
var QOperationGauge32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QOperationGauge32(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 4L24 4 24 6 27.75 6 24 10 24 12 30 12 30 10 26.38 10 30 6 30 4zM20 17.62L22.08 14l-1.73-1-2.18 3.76A12 12 0 002 28H4a10 10 0 0113.16-9.48L14 24a2 2 0 102 2 2 2 0 00-.27-1L19 19.35A10 10 0 0124 28h2A12 12 0 0020 17.62z"
  })), children);
});
var QOperationGauge24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QOperationGauge24(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 4L24 4 24 6 27.75 6 24 10 24 12 30 12 30 10 26.38 10 30 6 30 4zM20 17.62L22.08 14l-1.73-1-2.18 3.76A12 12 0 002 28H4a10 10 0 0113.16-9.48L14 24a2 2 0 102 2 2 2 0 00-.27-1L19 19.35A10 10 0 0124 28h2A12 12 0 0020 17.62z"
  })), children);
});
var QOperationGauge20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QOperationGauge20(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 4L24 4 24 6 27.75 6 24 10 24 12 30 12 30 10 26.38 10 30 6 30 4zM20 17.62L22.08 14l-1.73-1-2.18 3.76A12 12 0 002 28H4a10 10 0 0113.16-9.48L14 24a2 2 0 102 2 2 2 0 00-.27-1L19 19.35A10 10 0 0124 28h2A12 12 0 0020 17.62z"
  })), children);
});
var QOperationGauge16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QOperationGauge16(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 4L24 4 24 6 27.75 6 24 10 24 12 30 12 30 10 26.38 10 30 6 30 4zM20 17.62L22.08 14l-1.73-1-2.18 3.76A12 12 0 002 28H4a10 10 0 0113.16-9.48L14 24a2 2 0 102 2 2 2 0 00-.27-1L19 19.35A10 10 0 0124 28h2A12 12 0 0020 17.62z"
  })), children);
});
var QOperationIf32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QOperationIf32(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 13H14V23H12zM12 9H14V11H12zM23 11V9H20a2 2 0 00-2 2v2H16v2h2v8h2V15h3V13H20V11z"
  })), children);
});
var QOperationIf24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QOperationIf24(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 13H14V23H12zM12 9H14V11H12zM23 11V9H20a2 2 0 00-2 2v2H16v2h2v8h2V15h3V13H20V11z"
  })), children);
});
var QOperationIf20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QOperationIf20(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 13H14V23H12zM12 9H14V11H12zM23 11V9H20a2 2 0 00-2 2v2H16v2h2v8h2V15h3V13H20V11z"
  })), children);
});
var QOperationIf16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QOperationIf16(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 13H14V23H12zM12 9H14V11H12zM23 11V9H20a2 2 0 00-2 2v2H16v2h2v8h2V15h3V13H20V11z"
  })), children);
});
var OperationsField32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OperationsField32(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 6H26V8H16z",
    transform: "rotate(-90 21 7)"
  })), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 6H30V8H20z",
    transform: "rotate(-90 25 7)"
  })), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 6H34V8H24z",
    transform: "rotate(-90 29 7)"
  })), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,20a3.9123,3.9123,0,0,1-4-4,3.9123,3.9123,0,0,1,4-4V10a6,6,0,1,0,6,6H20A3.9123,3.9123,0,0,1,16,20Z"
  })), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8928,18.4536,26.0979,16,24.78,17.5044l2.7922,2.4517-2.36,4.0878-3.4273-1.1591a9.0315,9.0315,0,0,1-2.7143,1.5644L18.36,28H13.64l-.71-3.5508a9.0953,9.0953,0,0,1-2.6948-1.5713l-3.4468,1.166-2.36-4.0878L7.1528,17.561a8.9263,8.9263,0,0,1-.007-3.1279L4.4275,12.0439,6.7886,7.9561l3.4267,1.1591a9.0305,9.0305,0,0,1,2.7141-1.5644L13.64,4H16V2H13.64a2,2,0,0,0-1.9611,1.6079l-.5037,2.5186A10.9666,10.9666,0,0,0,9.8481,6.88L7.4287,6.0615a1.9977,1.9977,0,0,0-2.3728.8946L2.6953,11.0439a2.0006,2.0006,0,0,0,.4119,2.5025l1.9309,1.6968C5.021,15.4946,5,15.7446,5,16c0,.2578.01.5127.0278.7656l-1.9206,1.688a2.0006,2.0006,0,0,0-.4119,2.5025l2.3606,4.0878a1.9977,1.9977,0,0,0,2.3728.8946l2.4341-.8233a10.9736,10.9736,0,0,0,1.312.7583l.5037,2.5186A2,2,0,0,0,13.64,30H18.36a2,2,0,0,0,1.9611-1.6079l.5037-2.5186a10.9666,10.9666,0,0,0,1.3267-.7534l2.4194.8184a1.9977,1.9977,0,0,0,2.3728-.8946l2.3606-4.0878A2.0006,2.0006,0,0,0,28.8928,18.4536Z"
  })), children);
});
var OperationsField24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OperationsField24(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 6H26V8H16z",
    transform: "rotate(-90 21 7)"
  })), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 6H30V8H20z",
    transform: "rotate(-90 25 7)"
  })), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 6H34V8H24z",
    transform: "rotate(-90 29 7)"
  })), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,20a3.9123,3.9123,0,0,1-4-4,3.9123,3.9123,0,0,1,4-4V10a6,6,0,1,0,6,6H20A3.9123,3.9123,0,0,1,16,20Z"
  })), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8928,18.4536,26.0979,16,24.78,17.5044l2.7922,2.4517-2.36,4.0878-3.4273-1.1591a9.0315,9.0315,0,0,1-2.7143,1.5644L18.36,28H13.64l-.71-3.5508a9.0953,9.0953,0,0,1-2.6948-1.5713l-3.4468,1.166-2.36-4.0878L7.1528,17.561a8.9263,8.9263,0,0,1-.007-3.1279L4.4275,12.0439,6.7886,7.9561l3.4267,1.1591a9.0305,9.0305,0,0,1,2.7141-1.5644L13.64,4H16V2H13.64a2,2,0,0,0-1.9611,1.6079l-.5037,2.5186A10.9666,10.9666,0,0,0,9.8481,6.88L7.4287,6.0615a1.9977,1.9977,0,0,0-2.3728.8946L2.6953,11.0439a2.0006,2.0006,0,0,0,.4119,2.5025l1.9309,1.6968C5.021,15.4946,5,15.7446,5,16c0,.2578.01.5127.0278.7656l-1.9206,1.688a2.0006,2.0006,0,0,0-.4119,2.5025l2.3606,4.0878a1.9977,1.9977,0,0,0,2.3728.8946l2.4341-.8233a10.9736,10.9736,0,0,0,1.312.7583l.5037,2.5186A2,2,0,0,0,13.64,30H18.36a2,2,0,0,0,1.9611-1.6079l.5037-2.5186a10.9666,10.9666,0,0,0,1.3267-.7534l2.4194.8184a1.9977,1.9977,0,0,0,2.3728-.8946l2.3606-4.0878A2.0006,2.0006,0,0,0,28.8928,18.4536Z"
  })), children);
});
var OperationsField20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OperationsField20(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 6H26V8H16z",
    transform: "rotate(-90 21 7)"
  })), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 6H30V8H20z",
    transform: "rotate(-90 25 7)"
  })), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 6H34V8H24z",
    transform: "rotate(-90 29 7)"
  })), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,20a3.9123,3.9123,0,0,1-4-4,3.9123,3.9123,0,0,1,4-4V10a6,6,0,1,0,6,6H20A3.9123,3.9123,0,0,1,16,20Z"
  })), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8928,18.4536,26.0979,16,24.78,17.5044l2.7922,2.4517-2.36,4.0878-3.4273-1.1591a9.0315,9.0315,0,0,1-2.7143,1.5644L18.36,28H13.64l-.71-3.5508a9.0953,9.0953,0,0,1-2.6948-1.5713l-3.4468,1.166-2.36-4.0878L7.1528,17.561a8.9263,8.9263,0,0,1-.007-3.1279L4.4275,12.0439,6.7886,7.9561l3.4267,1.1591a9.0305,9.0305,0,0,1,2.7141-1.5644L13.64,4H16V2H13.64a2,2,0,0,0-1.9611,1.6079l-.5037,2.5186A10.9666,10.9666,0,0,0,9.8481,6.88L7.4287,6.0615a1.9977,1.9977,0,0,0-2.3728.8946L2.6953,11.0439a2.0006,2.0006,0,0,0,.4119,2.5025l1.9309,1.6968C5.021,15.4946,5,15.7446,5,16c0,.2578.01.5127.0278.7656l-1.9206,1.688a2.0006,2.0006,0,0,0-.4119,2.5025l2.3606,4.0878a1.9977,1.9977,0,0,0,2.3728.8946l2.4341-.8233a10.9736,10.9736,0,0,0,1.312.7583l.5037,2.5186A2,2,0,0,0,13.64,30H18.36a2,2,0,0,0,1.9611-1.6079l.5037-2.5186a10.9666,10.9666,0,0,0,1.3267-.7534l2.4194.8184a1.9977,1.9977,0,0,0,2.3728-.8946l2.3606-4.0878A2.0006,2.0006,0,0,0,28.8928,18.4536Z"
  })), children);
});
var OperationsField16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OperationsField16(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 6H26V8H16z",
    transform: "rotate(-90 21 7)"
  })), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 6H30V8H20z",
    transform: "rotate(-90 25 7)"
  })), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 6H34V8H24z",
    transform: "rotate(-90 29 7)"
  })), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,20a3.9123,3.9123,0,0,1-4-4,3.9123,3.9123,0,0,1,4-4V10a6,6,0,1,0,6,6H20A3.9123,3.9123,0,0,1,16,20Z"
  })), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8928,18.4536,26.0979,16,24.78,17.5044l2.7922,2.4517-2.36,4.0878-3.4273-1.1591a9.0315,9.0315,0,0,1-2.7143,1.5644L18.36,28H13.64l-.71-3.5508a9.0953,9.0953,0,0,1-2.6948-1.5713l-3.4468,1.166-2.36-4.0878L7.1528,17.561a8.9263,8.9263,0,0,1-.007-3.1279L4.4275,12.0439,6.7886,7.9561l3.4267,1.1591a9.0305,9.0305,0,0,1,2.7141-1.5644L13.64,4H16V2H13.64a2,2,0,0,0-1.9611,1.6079l-.5037,2.5186A10.9666,10.9666,0,0,0,9.8481,6.88L7.4287,6.0615a1.9977,1.9977,0,0,0-2.3728.8946L2.6953,11.0439a2.0006,2.0006,0,0,0,.4119,2.5025l1.9309,1.6968C5.021,15.4946,5,15.7446,5,16c0,.2578.01.5127.0278.7656l-1.9206,1.688a2.0006,2.0006,0,0,0-.4119,2.5025l2.3606,4.0878a1.9977,1.9977,0,0,0,2.3728.8946l2.4341-.8233a10.9736,10.9736,0,0,0,1.312.7583l.5037,2.5186A2,2,0,0,0,13.64,30H18.36a2,2,0,0,0,1.9611-1.6079l.5037-2.5186a10.9666,10.9666,0,0,0,1.3267-.7534l2.4194.8184a1.9977,1.9977,0,0,0,2.3728-.8946l2.3606-4.0878A2.0006,2.0006,0,0,0,28.8928,18.4536Z"
  })), children);
});
var OperationsRecord32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OperationsRecord32(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20H30V22H20zM20 24H30V26H20zM20 28H30V30H20zM16 20a3.9123 3.9123 0 01-4-4 3.9123 3.9123 0 014-4 3.9123 3.9123 0 014 4h2a6 6 0 10-6 6z"
  })), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3047,11.0439,26.9441,6.9561a1.9977,1.9977,0,0,0-2.3728-.8946l-2.4341.8233a11.0419,11.0419,0,0,0-1.312-.7583l-.5037-2.5186A2,2,0,0,0,18.36,2H13.64a2,2,0,0,0-1.9611,1.6079l-.5037,2.5186A10.9666,10.9666,0,0,0,9.8481,6.88L7.4287,6.0615a1.9977,1.9977,0,0,0-2.3728.8946L2.6953,11.0439a2.0006,2.0006,0,0,0,.4119,2.5025l1.9309,1.6968C5.021,15.4946,5,15.7446,5,16c0,.2578.01.5127.0278.7656l-1.9206,1.688a2.0006,2.0006,0,0,0-.4119,2.5025l2.3606,4.0878a1.9977,1.9977,0,0,0,2.3728.8946l2.4341-.8233a10.9736,10.9736,0,0,0,1.312.7583l.5037,2.5186A2,2,0,0,0,13.64,30H16V28H13.64l-.71-3.5508a9.0953,9.0953,0,0,1-2.6948-1.5713l-3.4468,1.166-2.36-4.0878L7.1528,17.561a8.9263,8.9263,0,0,1-.007-3.1279L4.4275,12.0439,6.7886,7.9561l3.4267,1.1591a9.0305,9.0305,0,0,1,2.7141-1.5644L13.64,4H18.36l.71,3.5508a9.0978,9.0978,0,0,1,2.6948,1.5713l3.4468-1.166,2.36,4.0878-2.7978,2.4522L26.0923,16l2.8-2.4536A2.0006,2.0006,0,0,0,29.3047,11.0439Z"
  })), children);
});
var OperationsRecord24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OperationsRecord24(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20H30V22H20zM20 24H30V26H20zM20 28H30V30H20zM16 20a3.9123 3.9123 0 01-4-4 3.9123 3.9123 0 014-4 3.9123 3.9123 0 014 4h2a6 6 0 10-6 6z"
  })), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3047,11.0439,26.9441,6.9561a1.9977,1.9977,0,0,0-2.3728-.8946l-2.4341.8233a11.0419,11.0419,0,0,0-1.312-.7583l-.5037-2.5186A2,2,0,0,0,18.36,2H13.64a2,2,0,0,0-1.9611,1.6079l-.5037,2.5186A10.9666,10.9666,0,0,0,9.8481,6.88L7.4287,6.0615a1.9977,1.9977,0,0,0-2.3728.8946L2.6953,11.0439a2.0006,2.0006,0,0,0,.4119,2.5025l1.9309,1.6968C5.021,15.4946,5,15.7446,5,16c0,.2578.01.5127.0278.7656l-1.9206,1.688a2.0006,2.0006,0,0,0-.4119,2.5025l2.3606,4.0878a1.9977,1.9977,0,0,0,2.3728.8946l2.4341-.8233a10.9736,10.9736,0,0,0,1.312.7583l.5037,2.5186A2,2,0,0,0,13.64,30H16V28H13.64l-.71-3.5508a9.0953,9.0953,0,0,1-2.6948-1.5713l-3.4468,1.166-2.36-4.0878L7.1528,17.561a8.9263,8.9263,0,0,1-.007-3.1279L4.4275,12.0439,6.7886,7.9561l3.4267,1.1591a9.0305,9.0305,0,0,1,2.7141-1.5644L13.64,4H18.36l.71,3.5508a9.0978,9.0978,0,0,1,2.6948,1.5713l3.4468-1.166,2.36,4.0878-2.7978,2.4522L26.0923,16l2.8-2.4536A2.0006,2.0006,0,0,0,29.3047,11.0439Z"
  })), children);
});
var OperationsRecord20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OperationsRecord20(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20H30V22H20zM20 24H30V26H20zM20 28H30V30H20zM16 20a3.9123 3.9123 0 01-4-4 3.9123 3.9123 0 014-4 3.9123 3.9123 0 014 4h2a6 6 0 10-6 6z"
  })), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3047,11.0439,26.9441,6.9561a1.9977,1.9977,0,0,0-2.3728-.8946l-2.4341.8233a11.0419,11.0419,0,0,0-1.312-.7583l-.5037-2.5186A2,2,0,0,0,18.36,2H13.64a2,2,0,0,0-1.9611,1.6079l-.5037,2.5186A10.9666,10.9666,0,0,0,9.8481,6.88L7.4287,6.0615a1.9977,1.9977,0,0,0-2.3728.8946L2.6953,11.0439a2.0006,2.0006,0,0,0,.4119,2.5025l1.9309,1.6968C5.021,15.4946,5,15.7446,5,16c0,.2578.01.5127.0278.7656l-1.9206,1.688a2.0006,2.0006,0,0,0-.4119,2.5025l2.3606,4.0878a1.9977,1.9977,0,0,0,2.3728.8946l2.4341-.8233a10.9736,10.9736,0,0,0,1.312.7583l.5037,2.5186A2,2,0,0,0,13.64,30H16V28H13.64l-.71-3.5508a9.0953,9.0953,0,0,1-2.6948-1.5713l-3.4468,1.166-2.36-4.0878L7.1528,17.561a8.9263,8.9263,0,0,1-.007-3.1279L4.4275,12.0439,6.7886,7.9561l3.4267,1.1591a9.0305,9.0305,0,0,1,2.7141-1.5644L13.64,4H18.36l.71,3.5508a9.0978,9.0978,0,0,1,2.6948,1.5713l3.4468-1.166,2.36,4.0878-2.7978,2.4522L26.0923,16l2.8-2.4536A2.0006,2.0006,0,0,0,29.3047,11.0439Z"
  })), children);
});
var OperationsRecord16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OperationsRecord16(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20H30V22H20zM20 24H30V26H20zM20 28H30V30H20zM16 20a3.9123 3.9123 0 01-4-4 3.9123 3.9123 0 014-4 3.9123 3.9123 0 014 4h2a6 6 0 10-6 6z"
  })), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3047,11.0439,26.9441,6.9561a1.9977,1.9977,0,0,0-2.3728-.8946l-2.4341.8233a11.0419,11.0419,0,0,0-1.312-.7583l-.5037-2.5186A2,2,0,0,0,18.36,2H13.64a2,2,0,0,0-1.9611,1.6079l-.5037,2.5186A10.9666,10.9666,0,0,0,9.8481,6.88L7.4287,6.0615a1.9977,1.9977,0,0,0-2.3728.8946L2.6953,11.0439a2.0006,2.0006,0,0,0,.4119,2.5025l1.9309,1.6968C5.021,15.4946,5,15.7446,5,16c0,.2578.01.5127.0278.7656l-1.9206,1.688a2.0006,2.0006,0,0,0-.4119,2.5025l2.3606,4.0878a1.9977,1.9977,0,0,0,2.3728.8946l2.4341-.8233a10.9736,10.9736,0,0,0,1.312.7583l.5037,2.5186A2,2,0,0,0,13.64,30H16V28H13.64l-.71-3.5508a9.0953,9.0953,0,0,1-2.6948-1.5713l-3.4468,1.166-2.36-4.0878L7.1528,17.561a8.9263,8.9263,0,0,1-.007-3.1279L4.4275,12.0439,6.7886,7.9561l3.4267,1.1591a9.0305,9.0305,0,0,1,2.7141-1.5644L13.64,4H18.36l.71,3.5508a9.0978,9.0978,0,0,1,2.6948,1.5713l3.4468-1.166,2.36,4.0878-2.7978,2.4522L26.0923,16l2.8-2.4536A2.0006,2.0006,0,0,0,29.3047,11.0439Z"
  })), children);
});
var OrderDetails32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OrderDetails32(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 21H13a3 3 0 00-3 3v2h2V24a1 1 0 011-1h6a1 1 0 011 1v2h2V24A3 3 0 0019 21zM16 20a4 4 0 10-4-4A4 4 0 0016 20zm0-6a2 2 0 11-2 2A2 2 0 0116 14z"
  })), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,5H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H25a2,2,0,0,0,2-2V7A2,2,0,0,0,25,5ZM12,4h8V8H12ZM25,28H7V7h3v3H22V7h3Z"
  })), children);
});
var OrderDetails24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OrderDetails24(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 21H13a3 3 0 00-3 3v2h2V24a1 1 0 011-1h6a1 1 0 011 1v2h2V24A3 3 0 0019 21zM16 20a4 4 0 10-4-4A4 4 0 0016 20zm0-6a2 2 0 11-2 2A2 2 0 0116 14z"
  })), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,5H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H25a2,2,0,0,0,2-2V7A2,2,0,0,0,25,5ZM12,4h8V8H12ZM25,28H7V7h3v3H22V7h3Z"
  })), children);
});
var OrderDetails20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OrderDetails20(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 21H13a3 3 0 00-3 3v2h2V24a1 1 0 011-1h6a1 1 0 011 1v2h2V24A3 3 0 0019 21zM16 20a4 4 0 10-4-4A4 4 0 0016 20zm0-6a2 2 0 11-2 2A2 2 0 0116 14z"
  })), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,5H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H25a2,2,0,0,0,2-2V7A2,2,0,0,0,25,5ZM12,4h8V8H12ZM25,28H7V7h3v3H22V7h3Z"
  })), children);
});
var OrderDetails16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OrderDetails16(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 21H13a3 3 0 00-3 3v2h2V24a1 1 0 011-1h6a1 1 0 011 1v2h2V24A3 3 0 0019 21zM16 20a4 4 0 10-4-4A4 4 0 0016 20zm0-6a2 2 0 11-2 2A2 2 0 0116 14z"
  })), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,5H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H25a2,2,0,0,0,2-2V7A2,2,0,0,0,25,5ZM12,4h8V8H12ZM25,28H7V7h3v3H22V7h3Z"
  })), children);
});
var Ordinal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Ordinal32(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,26V4H18v6H12v6H6V26H2v2H30V26ZM8,26V18h4v8Zm6,0V12h4V26Zm6,0V6h4V26Z"
  })), children);
});
var Ordinal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Ordinal24(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,26V4H18v6H12v6H6V26H2v2H30V26ZM8,26V18h4v8Zm6,0V12h4V26Zm6,0V6h4V26Z"
  })), children);
});
var Ordinal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Ordinal20(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,26V4H18v6H12v6H6V26H2v2H30V26ZM8,26V18h4v8Zm6,0V12h4V26Zm6,0V6h4V26Z"
  })), children);
});
var Ordinal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Ordinal16(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M1,13 L1,12 L3,12 L3,9 L5.999,9 L6,6 L9,6 L9,3 L13,3 L13,12 L15,12 L15,13 L1,13 Z M5.999,10 L4,10 L4,12 L5.999,12 L5.999,10 Z M8.999,7 L6.999,7 L6.999,9 L7,9 L7,12 L8.999,12 L8.999,7 Z M12,4 L10,4 L10,12 L12,12 L12,4 Z"
  })), children);
});
var Outage32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Outage32(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 24H21V26H12zM13 28H19V30H13z"
  })), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.7832 18.9746l1.4177-1.418A6.9206 6.9206 0 018 12 7.99 7.99 0 0121.5273 6.2305l1.4136-1.4136A9.9884 9.9884 0 006 12 8.9411 8.9411 0 008.7832 18.9746zM30 3.4141L28.5859 2 2 28.5859 3.4141 30 23.6606 9.7534A7.7069 7.7069 0 0124 12a7.2032 7.2032 0 01-2.8223 6.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.193 9.193 0 0026 12a9.8739 9.8739 0 00-.7764-3.81z"
  })), children);
});
var Outage24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Outage24(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 24H21V26H12zM13 28H19V30H13z"
  })), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.7832 18.9746l1.4177-1.418A6.9206 6.9206 0 018 12 7.99 7.99 0 0121.5273 6.2305l1.4136-1.4136A9.9884 9.9884 0 006 12 8.9411 8.9411 0 008.7832 18.9746zM30 3.4141L28.5859 2 2 28.5859 3.4141 30 23.6606 9.7534A7.7069 7.7069 0 0124 12a7.2032 7.2032 0 01-2.8223 6.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.193 9.193 0 0026 12a9.8739 9.8739 0 00-.7764-3.81z"
  })), children);
});
var Outage20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Outage20(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 24H21V26H12zM13 28H19V30H13z"
  })), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.7832 18.9746l1.4177-1.418A6.9206 6.9206 0 018 12 7.99 7.99 0 0121.5273 6.2305l1.4136-1.4136A9.9884 9.9884 0 006 12 8.9411 8.9411 0 008.7832 18.9746zM30 3.4141L28.5859 2 2 28.5859 3.4141 30 23.6606 9.7534A7.7069 7.7069 0 0124 12a7.2032 7.2032 0 01-2.8223 6.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.193 9.193 0 0026 12a9.8739 9.8739 0 00-.7764-3.81z"
  })), children);
});
var Outage16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Outage16(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 24H21V26H12zM13 28H19V30H13z"
  })), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.7832 18.9746l1.4177-1.418A6.9206 6.9206 0 018 12 7.99 7.99 0 0121.5273 6.2305l1.4136-1.4136A9.9884 9.9884 0 006 12 8.9411 8.9411 0 008.7832 18.9746zM30 3.4141L28.5859 2 2 28.5859 3.4141 30 23.6606 9.7534A7.7069 7.7069 0 0124 12a7.2032 7.2032 0 01-2.8223 6.1426C20.1069 19.1348 19 20.1611 19 22h2c0-.9194.5264-1.45 1.5352-2.3857A9.193 9.193 0 0026 12a9.8739 9.8739 0 00-.7764-3.81z"
  })), children);
});
var OutlookSevere32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OutlookSevere32(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M15.1249,19h1.75v5.5h-1.75ZM17,27a1,1,0,1,0-1,1A1,1,0,0,0,17,27Z"
  })), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.9084,28.94,16.8318,14.4878a.9531.9531,0,0,0-1.6636,0L7.0916,28.94A.7122.7122,0,0,0,7.7134,30H24.2867A.7121.7121,0,0,0,24.9084,28.94ZM15.125,19h1.75v5.5h-1.75ZM16,28a1,1,0,1,1,1-1A1,1,0,0,1,16,28Z"
  })), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0,6.4926,6.4926,0,0,0,.9153,12.8443L9.2217,20H8.5a4.48,4.48,0,0,1-3.3693-7.4556l5.297,5.2964,1.013-1.8135-4.66-4.6606A4.402,4.402,0,0,1,8.144,11.019l.8155-.0639.0991-.812c.0237-.1944.0581-.3848.0972-.5733l3.78,3.7808,1.0138-1.815L9.936,7.522a7.0212,7.0212,0,0,1,1.9754-2.1968L25.8861,19.3A4.4594,4.4594,0,0,1,23.5,20h-.7239l1.107,1.98a6.4927,6.4927,0,0,0,.9177-12.8443Zm2.4994,8.75L13.7823,4.3682a6.9736,6.9736,0,0,1,9.16,5.7749l.0986.812.8154.0639A4.5171,4.5171,0,0,1,28,15.5,4.46,4.46,0,0,1,27.3,17.8862Z"
  })), children);
});
var OutlookSevere24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OutlookSevere24(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M15.1249,19h1.75v5.5h-1.75ZM17,27a1,1,0,1,0-1,1A1,1,0,0,0,17,27Z"
  })), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.9084,28.94,16.8318,14.4878a.9531.9531,0,0,0-1.6636,0L7.0916,28.94A.7122.7122,0,0,0,7.7134,30H24.2867A.7121.7121,0,0,0,24.9084,28.94ZM15.125,19h1.75v5.5h-1.75ZM16,28a1,1,0,1,1,1-1A1,1,0,0,1,16,28Z"
  })), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0,6.4926,6.4926,0,0,0,.9153,12.8443L9.2217,20H8.5a4.48,4.48,0,0,1-3.3693-7.4556l5.297,5.2964,1.013-1.8135-4.66-4.6606A4.402,4.402,0,0,1,8.144,11.019l.8155-.0639.0991-.812c.0237-.1944.0581-.3848.0972-.5733l3.78,3.7808,1.0138-1.815L9.936,7.522a7.0212,7.0212,0,0,1,1.9754-2.1968L25.8861,19.3A4.4594,4.4594,0,0,1,23.5,20h-.7239l1.107,1.98a6.4927,6.4927,0,0,0,.9177-12.8443Zm2.4994,8.75L13.7823,4.3682a6.9736,6.9736,0,0,1,9.16,5.7749l.0986.812.8154.0639A4.5171,4.5171,0,0,1,28,15.5,4.46,4.46,0,0,1,27.3,17.8862Z"
  })), children);
});
var OutlookSevere20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OutlookSevere20(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M15.1249,19h1.75v5.5h-1.75ZM17,27a1,1,0,1,0-1,1A1,1,0,0,0,17,27Z"
  })), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.9084,28.94,16.8318,14.4878a.9531.9531,0,0,0-1.6636,0L7.0916,28.94A.7122.7122,0,0,0,7.7134,30H24.2867A.7121.7121,0,0,0,24.9084,28.94ZM15.125,19h1.75v5.5h-1.75ZM16,28a1,1,0,1,1,1-1A1,1,0,0,1,16,28Z"
  })), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0,6.4926,6.4926,0,0,0,.9153,12.8443L9.2217,20H8.5a4.48,4.48,0,0,1-3.3693-7.4556l5.297,5.2964,1.013-1.8135-4.66-4.6606A4.402,4.402,0,0,1,8.144,11.019l.8155-.0639.0991-.812c.0237-.1944.0581-.3848.0972-.5733l3.78,3.7808,1.0138-1.815L9.936,7.522a7.0212,7.0212,0,0,1,1.9754-2.1968L25.8861,19.3A4.4594,4.4594,0,0,1,23.5,20h-.7239l1.107,1.98a6.4927,6.4927,0,0,0,.9177-12.8443Zm2.4994,8.75L13.7823,4.3682a6.9736,6.9736,0,0,1,9.16,5.7749l.0986.812.8154.0639A4.5171,4.5171,0,0,1,28,15.5,4.46,4.46,0,0,1,27.3,17.8862Z"
  })), children);
});
var OutlookSevere16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OutlookSevere16(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M15.1249,19h1.75v5.5h-1.75ZM17,27a1,1,0,1,0-1,1A1,1,0,0,0,17,27Z"
  })), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.9084,28.94,16.8318,14.4878a.9531.9531,0,0,0-1.6636,0L7.0916,28.94A.7122.7122,0,0,0,7.7134,30H24.2867A.7121.7121,0,0,0,24.9084,28.94ZM15.125,19h1.75v5.5h-1.75ZM16,28a1,1,0,1,1,1-1A1,1,0,0,1,16,28Z"
  })), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0,6.4926,6.4926,0,0,0,.9153,12.8443L9.2217,20H8.5a4.48,4.48,0,0,1-3.3693-7.4556l5.297,5.2964,1.013-1.8135-4.66-4.6606A4.402,4.402,0,0,1,8.144,11.019l.8155-.0639.0991-.812c.0237-.1944.0581-.3848.0972-.5733l3.78,3.7808,1.0138-1.815L9.936,7.522a7.0212,7.0212,0,0,1,1.9754-2.1968L25.8861,19.3A4.4594,4.4594,0,0,1,23.5,20h-.7239l1.107,1.98a6.4927,6.4927,0,0,0,.9177-12.8443Zm2.4994,8.75L13.7823,4.3682a6.9736,6.9736,0,0,1,9.16,5.7749l.0986.812.8154.0639A4.5171,4.5171,0,0,1,28,15.5,4.46,4.46,0,0,1,27.3,17.8862Z"
  })), children);
});
var OverflowMenuHorizontal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OverflowMenuHorizontal32(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle21 || (_circle21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "2"
  })), _circle22 || (_circle22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _circle23 || (_circle23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "16",
    r: "2"
  })), children);
});
var OverflowMenuHorizontal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OverflowMenuHorizontal24(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle24 || (_circle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "2"
  })), _circle25 || (_circle25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _circle26 || (_circle26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "16",
    r: "2"
  })), children);
});
var OverflowMenuHorizontal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OverflowMenuHorizontal20(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle27 || (_circle27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "2"
  })), _circle28 || (_circle28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _circle29 || (_circle29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "16",
    r: "2"
  })), children);
});
var OverflowMenuHorizontal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OverflowMenuHorizontal16(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle30 || (_circle30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "2"
  })), _circle31 || (_circle31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _circle32 || (_circle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "16",
    r: "2"
  })), children);
});
var OverflowMenuVertical32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OverflowMenuVertical32(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle33 || (_circle33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "8",
    r: "2"
  })), _circle34 || (_circle34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _circle35 || (_circle35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "24",
    r: "2"
  })), children);
});
var OverflowMenuVertical24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OverflowMenuVertical24(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle36 || (_circle36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "8",
    r: "2"
  })), _circle37 || (_circle37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _circle38 || (_circle38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "24",
    r: "2"
  })), children);
});
var OverflowMenuVertical20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OverflowMenuVertical20(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle39 || (_circle39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "8",
    r: "2"
  })), _circle40 || (_circle40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _circle41 || (_circle41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "24",
    r: "2"
  })), children);
});
var OverflowMenuVertical16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function OverflowMenuVertical16(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle42 || (_circle42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "8",
    r: "2"
  })), _circle43 || (_circle43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _circle44 || (_circle44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "24",
    r: "2"
  })), children);
});
var Overlay32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Overlay32(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H24V4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V22a2.0023,2.0023,0,0,0,2,2H8v4a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V10A2.0023,2.0023,0,0,0,28,8ZM4,22V4H22V8H10a2.0023,2.0023,0,0,0-2,2V22Zm18,0H19.4141L10,12.586V10h2.5859l9.4153,9.4156ZM10,15.4141,16.5859,22H10ZM22.001,16.587,15.4141,10H22ZM10,28V24H22a2.0023,2.0023,0,0,0,2-2V10h4V28Z"
  })), children);
});
var Overlay24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Overlay24(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H24V4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V22a2.0023,2.0023,0,0,0,2,2H8v4a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V10A2.0023,2.0023,0,0,0,28,8ZM4,22V4H22V8H10a2.0023,2.0023,0,0,0-2,2V22Zm18,0H19.4141L10,12.586V10h2.5859l9.4153,9.4156ZM10,15.4141,16.5859,22H10ZM22.001,16.587,15.4141,10H22ZM10,28V24H22a2.0023,2.0023,0,0,0,2-2V10h4V28Z"
  })), children);
});
var Overlay20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Overlay20(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H24V4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V22a2.0023,2.0023,0,0,0,2,2H8v4a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V10A2.0023,2.0023,0,0,0,28,8ZM4,22V4H22V8H10a2.0023,2.0023,0,0,0-2,2V22Zm18,0H19.4141L10,12.586V10h2.5859l9.4153,9.4156ZM10,15.4141,16.5859,22H10ZM22.001,16.587,15.4141,10H22ZM10,28V24H22a2.0023,2.0023,0,0,0,2-2V10h4V28Z"
  })), children);
});
var Overlay16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Overlay16(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H24V4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V22a2.0023,2.0023,0,0,0,2,2H8v4a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V10A2.0023,2.0023,0,0,0,28,8ZM4,22V4H22V8H10a2.0023,2.0023,0,0,0-2,2V22Zm18,0H19.4141L10,12.586V10h2.5859l9.4153,9.4156ZM10,15.4141,16.5859,22H10ZM22.001,16.587,15.4141,10H22ZM10,28V24H22a2.0023,2.0023,0,0,0,2-2V10h4V28Z"
  })), children);
});
var Package32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Package32(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2,2,0,0,1-2-2V16a2,2,0,0,1,2-2H9v2H6V28H26V16H23V14h3a2,2,0,0,1,2,2V28A2,2,0,0,1,26,30Z"
  })), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 20H19V22H13zM20.59 8.59L17 12.17 17 2 15 2 15 12.17 11.41 8.59 10 10 16 16 22 10 20.59 8.59z"
  })), children);
});
var Package24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Package24(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2,2,0,0,1-2-2V16a2,2,0,0,1,2-2H9v2H6V28H26V16H23V14h3a2,2,0,0,1,2,2V28A2,2,0,0,1,26,30Z"
  })), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 20H19V22H13zM20.59 8.59L17 12.17 17 2 15 2 15 12.17 11.41 8.59 10 10 16 16 22 10 20.59 8.59z"
  })), children);
});
var Package20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Package20(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2,2,0,0,1-2-2V16a2,2,0,0,1,2-2H9v2H6V28H26V16H23V14h3a2,2,0,0,1,2,2V28A2,2,0,0,1,26,30Z"
  })), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 20H19V22H13zM20.59 8.59L17 12.17 17 2 15 2 15 12.17 11.41 8.59 10 10 16 16 22 10 20.59 8.59z"
  })), children);
});
var Package16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Package16(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H6a2,2,0,0,1-2-2V16a2,2,0,0,1,2-2H9v2H6V28H26V16H23V14h3a2,2,0,0,1,2,2V28A2,2,0,0,1,26,30Z"
  })), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 20H19V22H13zM20.59 8.59L17 12.17 17 2 15 2 15 12.17 11.41 8.59 10 10 16 16 22 10 20.59 8.59z"
  })), children);
});
var PageFirst32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PageFirst32(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 16L24 6 25.4 7.4 16.8 16 25.4 24.6 24 26zM8 4H10V28H8z"
  })), children);
});
var PageFirst24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PageFirst24(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 16L24 6 25.4 7.4 16.8 16 25.4 24.6 24 26zM8 4H10V28H8z"
  })), children);
});
var PageFirst20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PageFirst20(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 16L24 6 25.4 7.4 16.8 16 25.4 24.6 24 26zM8 4H10V28H8z"
  })), children);
});
var PageFirst16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PageFirst16(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 16L24 6 25.4 7.4 16.8 16 25.4 24.6 24 26zM8 4H10V28H8z"
  })), children);
});
var PageLast32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PageLast32(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 16L8 26 6.6 24.6 15.2 16 6.6 7.4 8 6zM22 4H24V28H22z"
  })), children);
});
var PageLast24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PageLast24(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 16L8 26 6.6 24.6 15.2 16 6.6 7.4 8 6zM22 4H24V28H22z"
  })), children);
});
var PageLast20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PageLast20(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 16L8 26 6.6 24.6 15.2 16 6.6 7.4 8 6zM22 4H24V28H22z"
  })), children);
});
var PageLast16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PageLast16(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 16L8 26 6.6 24.6 15.2 16 6.6 7.4 8 6zM22 4H24V28H22z"
  })), children);
});
var PageBreak32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PageBreak32(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 18H6V20H2zM26 18H30V20H26zM24 22v6H8V22H6v6a2.0058 2.0058 0 002 2H24a2.0058 2.0058 0 002-2V22zM8 16V4h8v6a2.0058 2.0058 0 002 2h6v4h2V10a.9092.9092 0 00-.3-.7l-7-7A.9087.9087 0 0018 2H8A2.0058 2.0058 0 006 4V16zM18 4.4L23.6 10H18zM10 18H14V20H10zM18 18H22V20H18z"
  })), children);
});
var PageBreak24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PageBreak24(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 18H6V20H2zM26 18H30V20H26zM24 22v6H8V22H6v6a2.0058 2.0058 0 002 2H24a2.0058 2.0058 0 002-2V22zM8 16V4h8v6a2.0058 2.0058 0 002 2h6v4h2V10a.9092.9092 0 00-.3-.7l-7-7A.9087.9087 0 0018 2H8A2.0058 2.0058 0 006 4V16zM18 4.4L23.6 10H18zM10 18H14V20H10zM18 18H22V20H18z"
  })), children);
});
var PageBreak20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PageBreak20(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 18H6V20H2zM26 18H30V20H26zM24 22v6H8V22H6v6a2.0058 2.0058 0 002 2H24a2.0058 2.0058 0 002-2V22zM8 16V4h8v6a2.0058 2.0058 0 002 2h6v4h2V10a.9092.9092 0 00-.3-.7l-7-7A.9087.9087 0 0018 2H8A2.0058 2.0058 0 006 4V16zM18 4.4L23.6 10H18zM10 18H14V20H10zM18 18H22V20H18z"
  })), children);
});
var PageBreak16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PageBreak16(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 18H6V20H2zM26 18H30V20H26zM24 22v6H8V22H6v6a2.0058 2.0058 0 002 2H24a2.0058 2.0058 0 002-2V22zM8 16V4h8v6a2.0058 2.0058 0 002 2h6v4h2V10a.9092.9092 0 00-.3-.7l-7-7A.9087.9087 0 0018 2H8A2.0058 2.0058 0 006 4V16zM18 4.4L23.6 10H18zM10 18H14V20H10zM18 18H22V20H18z"
  })), children);
});
var PageNumber32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PageNumber32(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26L16 26 16 20 20 20 20 18 16 18 16 16 22 16 22 22 18 22 18 24 22 24 22 26z"
  })), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.7,9.3l-7-7A.9078.9078,0,0,0,18,2H8A2.0059,2.0059,0,0,0,6,4V28a2.0059,2.0059,0,0,0,2,2H24a2.0059,2.0059,0,0,0,2-2V10A.9078.9078,0,0,0,25.7,9.3ZM18,4.4,23.6,10H18ZM24,28H8V4h8v6a2.0059,2.0059,0,0,0,2,2h6Z"
  })), children);
});
var PageNumber24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PageNumber24(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26L16 26 16 20 20 20 20 18 16 18 16 16 22 16 22 22 18 22 18 24 22 24 22 26z"
  })), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.7,9.3l-7-7A.9078.9078,0,0,0,18,2H8A2.0059,2.0059,0,0,0,6,4V28a2.0059,2.0059,0,0,0,2,2H24a2.0059,2.0059,0,0,0,2-2V10A.9078.9078,0,0,0,25.7,9.3ZM18,4.4,23.6,10H18ZM24,28H8V4h8v6a2.0059,2.0059,0,0,0,2,2h6Z"
  })), children);
});
var PageNumber20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PageNumber20(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26L16 26 16 20 20 20 20 18 16 18 16 16 22 16 22 22 18 22 18 24 22 24 22 26z"
  })), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.7,9.3l-7-7A.9078.9078,0,0,0,18,2H8A2.0059,2.0059,0,0,0,6,4V28a2.0059,2.0059,0,0,0,2,2H24a2.0059,2.0059,0,0,0,2-2V10A.9078.9078,0,0,0,25.7,9.3ZM18,4.4,23.6,10H18ZM24,28H8V4h8v6a2.0059,2.0059,0,0,0,2,2h6Z"
  })), children);
});
var PageNumber16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PageNumber16(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26L16 26 16 20 20 20 20 18 16 18 16 16 22 16 22 22 18 22 18 24 22 24 22 26z"
  })), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.7,9.3l-7-7A.9078.9078,0,0,0,18,2H8A2.0059,2.0059,0,0,0,6,4V28a2.0059,2.0059,0,0,0,2,2H24a2.0059,2.0059,0,0,0,2-2V10A.9078.9078,0,0,0,25.7,9.3ZM18,4.4,23.6,10H18ZM24,28H8V4h8v6a2.0059,2.0059,0,0,0,2,2h6Z"
  })), children);
});
var WatsonHealthPageScroll32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthPageScroll32(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H4a1.89,1.89,0,0,1-2-2V14a1.89,1.89,0,0,1,2-2H16a1.89,1.89,0,0,1,2,2V26A1.89,1.89,0,0,1,16,28ZM4,14V26H16V14Z"
  })), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,19H20V10H10V8H20a1.89,1.89,0,0,1,2,2Z"
  })), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 14H24V6H16V4h8a1.89 1.89 0 012 2zM24 17L24 19 26.8 19 22 24.4 22 22 20 22 20 28 26 28 26 26 23.2 26 28 20.6 28 23 30 23 30 17 24 17z"
  })), children);
});
var WatsonHealthPageScroll24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthPageScroll24(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H4a1.89,1.89,0,0,1-2-2V14a1.89,1.89,0,0,1,2-2H16a1.89,1.89,0,0,1,2,2V26A1.89,1.89,0,0,1,16,28ZM4,14V26H16V14Z"
  })), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,19H20V10H10V8H20a1.89,1.89,0,0,1,2,2Z"
  })), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 14H24V6H16V4h8a1.89 1.89 0 012 2zM24 17L24 19 26.8 19 22 24.4 22 22 20 22 20 28 26 28 26 26 23.2 26 28 20.6 28 23 30 23 30 17 24 17z"
  })), children);
});
var WatsonHealthPageScroll20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthPageScroll20(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H4a1.89,1.89,0,0,1-2-2V14a1.89,1.89,0,0,1,2-2H16a1.89,1.89,0,0,1,2,2V26A1.89,1.89,0,0,1,16,28ZM4,14V26H16V14Z"
  })), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,19H20V10H10V8H20a1.89,1.89,0,0,1,2,2Z"
  })), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 14H24V6H16V4h8a1.89 1.89 0 012 2zM24 17L24 19 26.8 19 22 24.4 22 22 20 22 20 28 26 28 26 26 23.2 26 28 20.6 28 23 30 23 30 17 24 17z"
  })), children);
});
var WatsonHealthPageScroll16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthPageScroll16(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H4a1.89,1.89,0,0,1-2-2V14a1.89,1.89,0,0,1,2-2H16a1.89,1.89,0,0,1,2,2V26A1.89,1.89,0,0,1,16,28ZM4,14V26H16V14Z"
  })), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,19H20V10H10V8H20a1.89,1.89,0,0,1,2,2Z"
  })), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 14H24V6H16V4h8a1.89 1.89 0 012 2zM24 17L24 19 26.8 19 22 24.4 22 22 20 22 20 28 26 28 26 26 23.2 26 28 20.6 28 23 30 23 30 17 24 17z"
  })), children);
});
var PaintBrush32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PaintBrush32(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.83,23.17,23,17.33V13a1,1,0,0,0-.29-.71l-10-10a1,1,0,0,0-1.42,0l-9,9a1,1,0,0,0,0,1.42l10,10A1,1,0,0,0,13,23h4.34l5.83,5.84a4,4,0,0,0,5.66-5.66ZM6,10.41l2.29,2.3,1.42-1.42L7.41,9,9,7.41l4.29,4.3,1.42-1.42L10.41,6,12,4.41,18.59,11,11,18.59,4.41,12Zm21.41,17a2,2,0,0,1-2.82,0l-6.13-6.12a1.8,1.8,0,0,0-.71-.29H13.41l-1-1L20,12.41l1,1v4.34a1,1,0,0,0,.29.7l6.12,6.14a2,2,0,0,1,0,2.82Z"
  })), children);
});
var PaintBrush24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PaintBrush24(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.83,23.17,23,17.33V13a1,1,0,0,0-.29-.71l-10-10a1,1,0,0,0-1.42,0l-9,9a1,1,0,0,0,0,1.42l10,10A1,1,0,0,0,13,23h4.34l5.83,5.84a4,4,0,0,0,5.66-5.66ZM6,10.41l2.29,2.3,1.42-1.42L7.41,9,9,7.41l4.29,4.3,1.42-1.42L10.41,6,12,4.41,18.59,11,11,18.59,4.41,12Zm21.41,17a2,2,0,0,1-2.82,0l-6.13-6.12a1.8,1.8,0,0,0-.71-.29H13.41l-1-1L20,12.41l1,1v4.34a1,1,0,0,0,.29.7l6.12,6.14a2,2,0,0,1,0,2.82Z"
  })), children);
});
var PaintBrush20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PaintBrush20(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.83,23.17,23,17.33V13a1,1,0,0,0-.29-.71l-10-10a1,1,0,0,0-1.42,0l-9,9a1,1,0,0,0,0,1.42l10,10A1,1,0,0,0,13,23h4.34l5.83,5.84a4,4,0,0,0,5.66-5.66ZM6,10.41l2.29,2.3,1.42-1.42L7.41,9,9,7.41l4.29,4.3,1.42-1.42L10.41,6,12,4.41,18.59,11,11,18.59,4.41,12Zm21.41,17a2,2,0,0,1-2.82,0l-6.13-6.12a1.8,1.8,0,0,0-.71-.29H13.41l-1-1L20,12.41l1,1v4.34a1,1,0,0,0,.29.7l6.12,6.14a2,2,0,0,1,0,2.82Z"
  })), children);
});
var PaintBrush16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PaintBrush16(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.83,23.17,23,17.33V13a1,1,0,0,0-.29-.71l-10-10a1,1,0,0,0-1.42,0l-9,9a1,1,0,0,0,0,1.42l10,10A1,1,0,0,0,13,23h4.34l5.83,5.84a4,4,0,0,0,5.66-5.66ZM6,10.41l2.29,2.3,1.42-1.42L7.41,9,9,7.41l4.29,4.3,1.42-1.42L10.41,6,12,4.41,18.59,11,11,18.59,4.41,12Zm21.41,17a2,2,0,0,1-2.82,0l-6.13-6.12a1.8,1.8,0,0,0-.71-.29H13.41l-1-1L20,12.41l1,1v4.34a1,1,0,0,0,.29.7l6.12,6.14a2,2,0,0,1,0,2.82Z"
  })), children);
});
var PaintBrushAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PaintBrushAlt32(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8281,3.1719a4.0941,4.0941,0,0,0-5.6562,0L4.05,22.292A6.9537,6.9537,0,0,0,2,27.2412V30H4.7559a6.9523,6.9523,0,0,0,4.95-2.05L28.8281,8.8286a3.999,3.999,0,0,0,0-5.6567ZM10.91,18.26l2.8286,2.8286L11.6172,23.21,8.7886,20.3818ZM8.2915,26.5356A4.9665,4.9665,0,0,1,4.7559,28H4v-.7588a4.9671,4.9671,0,0,1,1.4644-3.5351l1.91-1.91,2.8286,2.8281ZM27.4141,7.4141,15.1528,19.6748l-2.8286-2.8286,12.2617-12.26a2.0473,2.0473,0,0,1,2.8282,0,1.9995,1.9995,0,0,1,0,2.8282Z"
  })), children);
});
var PaintBrushAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PaintBrushAlt24(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8281,3.1719a4.0941,4.0941,0,0,0-5.6562,0L4.05,22.292A6.9537,6.9537,0,0,0,2,27.2412V30H4.7559a6.9523,6.9523,0,0,0,4.95-2.05L28.8281,8.8286a3.999,3.999,0,0,0,0-5.6567ZM10.91,18.26l2.8286,2.8286L11.6172,23.21,8.7886,20.3818ZM8.2915,26.5356A4.9665,4.9665,0,0,1,4.7559,28H4v-.7588a4.9671,4.9671,0,0,1,1.4644-3.5351l1.91-1.91,2.8286,2.8281ZM27.4141,7.4141,15.1528,19.6748l-2.8286-2.8286,12.2617-12.26a2.0473,2.0473,0,0,1,2.8282,0,1.9995,1.9995,0,0,1,0,2.8282Z"
  })), children);
});
var PaintBrushAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PaintBrushAlt20(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8281,3.1719a4.0941,4.0941,0,0,0-5.6562,0L4.05,22.292A6.9537,6.9537,0,0,0,2,27.2412V30H4.7559a6.9523,6.9523,0,0,0,4.95-2.05L28.8281,8.8286a3.999,3.999,0,0,0,0-5.6567ZM10.91,18.26l2.8286,2.8286L11.6172,23.21,8.7886,20.3818ZM8.2915,26.5356A4.9665,4.9665,0,0,1,4.7559,28H4v-.7588a4.9671,4.9671,0,0,1,1.4644-3.5351l1.91-1.91,2.8286,2.8281ZM27.4141,7.4141,15.1528,19.6748l-2.8286-2.8286,12.2617-12.26a2.0473,2.0473,0,0,1,2.8282,0,1.9995,1.9995,0,0,1,0,2.8282Z"
  })), children);
});
var PaintBrushAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PaintBrushAlt16(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8281,3.1719a4.0941,4.0941,0,0,0-5.6562,0L4.05,22.292A6.9537,6.9537,0,0,0,2,27.2412V30H4.7559a6.9523,6.9523,0,0,0,4.95-2.05L28.8281,8.8286a3.999,3.999,0,0,0,0-5.6567ZM10.91,18.26l2.8286,2.8286L11.6172,23.21,8.7886,20.3818ZM8.2915,26.5356A4.9665,4.9665,0,0,1,4.7559,28H4v-.7588a4.9671,4.9671,0,0,1,1.4644-3.5351l1.91-1.91,2.8286,2.8281ZM27.4141,7.4141,15.1528,19.6748l-2.8286-2.8286,12.2617-12.26a2.0473,2.0473,0,0,1,2.8282,0,1.9995,1.9995,0,0,1,0,2.8282Z"
  })), children);
});
var PalmTree32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PalmTree32(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.57,28C17.897,26.7251,16,22.2261,16,12v-.1313l1.1172.7446A6.4613,6.4613,0,0,1,20,18h2a8.457,8.457,0,0,0-3.7734-7.0508L16.8027,10h1.5308a7.04,7.04,0,0,1,4.2,1.4L24.4,12.8l1.2-1.6L23.7334,9.8a9.06,9.06,0,0,0-5.4-1.8H17.1172A7.0306,7.0306,0,0,1,22,6h2V4H22a9.035,9.035,0,0,0-7,3.3643A9.035,9.035,0,0,0,8,4H6V6H8a7.0306,7.0306,0,0,1,4.8828,2H11.6665a9.06,9.06,0,0,0-5.4,1.8L4.4,11.2l1.2,1.6L7.4668,11.4a7.04,7.04,0,0,1,4.2-1.4h1.5308l-1.4239.9492A8.457,8.457,0,0,0,8,18h2a6.4613,6.4613,0,0,1,2.8828-5.3867L14,11.8687V12c0,8.9438,1.4116,13.7646,2.3611,16H2v2H30V28Z"
  })), children);
});
var PalmTree24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PalmTree24(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.57,28C17.897,26.7251,16,22.2261,16,12v-.1313l1.1172.7446A6.4613,6.4613,0,0,1,20,18h2a8.457,8.457,0,0,0-3.7734-7.0508L16.8027,10h1.5308a7.04,7.04,0,0,1,4.2,1.4L24.4,12.8l1.2-1.6L23.7334,9.8a9.06,9.06,0,0,0-5.4-1.8H17.1172A7.0306,7.0306,0,0,1,22,6h2V4H22a9.035,9.035,0,0,0-7,3.3643A9.035,9.035,0,0,0,8,4H6V6H8a7.0306,7.0306,0,0,1,4.8828,2H11.6665a9.06,9.06,0,0,0-5.4,1.8L4.4,11.2l1.2,1.6L7.4668,11.4a7.04,7.04,0,0,1,4.2-1.4h1.5308l-1.4239.9492A8.457,8.457,0,0,0,8,18h2a6.4613,6.4613,0,0,1,2.8828-5.3867L14,11.8687V12c0,8.9438,1.4116,13.7646,2.3611,16H2v2H30V28Z"
  })), children);
});
var PalmTree20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PalmTree20(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.57,28C17.897,26.7251,16,22.2261,16,12v-.1313l1.1172.7446A6.4613,6.4613,0,0,1,20,18h2a8.457,8.457,0,0,0-3.7734-7.0508L16.8027,10h1.5308a7.04,7.04,0,0,1,4.2,1.4L24.4,12.8l1.2-1.6L23.7334,9.8a9.06,9.06,0,0,0-5.4-1.8H17.1172A7.0306,7.0306,0,0,1,22,6h2V4H22a9.035,9.035,0,0,0-7,3.3643A9.035,9.035,0,0,0,8,4H6V6H8a7.0306,7.0306,0,0,1,4.8828,2H11.6665a9.06,9.06,0,0,0-5.4,1.8L4.4,11.2l1.2,1.6L7.4668,11.4a7.04,7.04,0,0,1,4.2-1.4h1.5308l-1.4239.9492A8.457,8.457,0,0,0,8,18h2a6.4613,6.4613,0,0,1,2.8828-5.3867L14,11.8687V12c0,8.9438,1.4116,13.7646,2.3611,16H2v2H30V28Z"
  })), children);
});
var PalmTree16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PalmTree16(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.57,28C17.897,26.7251,16,22.2261,16,12v-.1313l1.1172.7446A6.4613,6.4613,0,0,1,20,18h2a8.457,8.457,0,0,0-3.7734-7.0508L16.8027,10h1.5308a7.04,7.04,0,0,1,4.2,1.4L24.4,12.8l1.2-1.6L23.7334,9.8a9.06,9.06,0,0,0-5.4-1.8H17.1172A7.0306,7.0306,0,0,1,22,6h2V4H22a9.035,9.035,0,0,0-7,3.3643A9.035,9.035,0,0,0,8,4H6V6H8a7.0306,7.0306,0,0,1,4.8828,2H11.6665a9.06,9.06,0,0,0-5.4,1.8L4.4,11.2l1.2,1.6L7.4668,11.4a7.04,7.04,0,0,1,4.2-1.4h1.5308l-1.4239.9492A8.457,8.457,0,0,0,8,18h2a6.4613,6.4613,0,0,1,2.8828-5.3867L14,11.8687V12c0,8.9438,1.4116,13.7646,2.3611,16H2v2H30V28Z"
  })), children);
});
var PanHorizontal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PanHorizontal32(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 10L22.586 11.414 26.172 15 5.828 15 9.414 11.414 8 10 2 16 8 22 9.414 20.586 5.828 17 26.172 17 22.586 20.586 24 22 30 16 24 10z"
  })), children);
});
var PanHorizontal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PanHorizontal24(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 10L22.586 11.414 26.172 15 5.828 15 9.414 11.414 8 10 2 16 8 22 9.414 20.586 5.828 17 26.172 17 22.586 20.586 24 22 30 16 24 10z"
  })), children);
});
var PanHorizontal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PanHorizontal20(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 10L22.586 11.414 26.172 15 5.828 15 9.414 11.414 8 10 2 16 8 22 9.414 20.586 5.828 17 26.172 17 22.586 20.586 24 22 30 16 24 10z"
  })), children);
});
var PanHorizontal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PanHorizontal16(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 10L22.586 11.414 26.172 15 5.828 15 9.414 11.414 8 10 2 16 8 22 9.414 20.586 5.828 17 26.172 17 22.586 20.586 24 22 30 16 24 10z"
  })), children);
});
var PanVertical32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PanVertical32(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 8L11.414 9.414 15 5.828 15 26.172 11.414 22.586 10 24 16 30 22 24 20.586 22.586 17 26.172 17 5.828 20.586 9.414 22 8 16 2 10 8z"
  })), children);
});
var PanVertical24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PanVertical24(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 8L11.414 9.414 15 5.828 15 26.172 11.414 22.586 10 24 16 30 22 24 20.586 22.586 17 26.172 17 5.828 20.586 9.414 22 8 16 2 10 8z"
  })), children);
});
var PanVertical20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PanVertical20(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 8L11.414 9.414 15 5.828 15 26.172 11.414 22.586 10 24 16 30 22 24 20.586 22.586 17 26.172 17 5.828 20.586 9.414 22 8 16 2 10 8z"
  })), children);
});
var PanVertical16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PanVertical16(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 8L11.414 9.414 15 5.828 15 26.172 11.414 22.586 10 24 16 30 22 24 20.586 22.586 17 26.172 17 5.828 20.586 9.414 22 8 16 2 10 8z"
  })), children);
});
var PanelExpansion32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PanelExpansion32(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6H6A2 2 0 004 8v6a2 2 0 002 2h6a2 2 0 002-2V8A2 2 0 0012 6zM6 14V8h6v6zM26 6H20a2 2 0 00-2 2V24a2 2 0 002 2h6a2 2 0 002-2V8A2 2 0 0026 6zM20 24V8h6V24z"
  })), children);
});
var PanelExpansion24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PanelExpansion24(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6H6A2 2 0 004 8v6a2 2 0 002 2h6a2 2 0 002-2V8A2 2 0 0012 6zM6 14V8h6v6zM26 6H20a2 2 0 00-2 2V24a2 2 0 002 2h6a2 2 0 002-2V8A2 2 0 0026 6zM20 24V8h6V24z"
  })), children);
});
var PanelExpansion20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PanelExpansion20(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6H6A2 2 0 004 8v6a2 2 0 002 2h6a2 2 0 002-2V8A2 2 0 0012 6zM6 14V8h6v6zM26 6H20a2 2 0 00-2 2V24a2 2 0 002 2h6a2 2 0 002-2V8A2 2 0 0026 6zM20 24V8h6V24z"
  })), children);
});
var PanelExpansion16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PanelExpansion16(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6H6A2 2 0 004 8v6a2 2 0 002 2h6a2 2 0 002-2V8A2 2 0 0012 6zM6 14V8h6v6zM26 6H20a2 2 0 00-2 2V24a2 2 0 002 2h6a2 2 0 002-2V8A2 2 0 0026 6zM20 24V8h6V24z"
  })), children);
});
var Paragraph32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Paragraph32(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,4H13a7,7,0,0,0,0,14V28h2V6h5V28h2V6h5ZM13,16A5,5,0,0,1,13,6Z"
  })), children);
});
var Paragraph24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Paragraph24(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,4H13a7,7,0,0,0,0,14V28h2V6h5V28h2V6h5ZM13,16A5,5,0,0,1,13,6Z"
  })), children);
});
var Paragraph20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Paragraph20(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,4H13a7,7,0,0,0,0,14V28h2V6h5V28h2V6h5ZM13,16A5,5,0,0,1,13,6Z"
  })), children);
});
var Paragraph16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Paragraph16(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,4H13a7,7,0,0,0,0,14V28h2V6h5V28h2V6h5ZM13,16A5,5,0,0,1,13,6Z"
  })), children);
});
var Parameter32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Parameter32(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,13V8a2.0023,2.0023,0,0,0-2-2H23V8h3v5a3.9756,3.9756,0,0,0,1.3823,3A3.9756,3.9756,0,0,0,26,19v5H23v2h3a2.0023,2.0023,0,0,0,2-2V19a2.0023,2.0023,0,0,1,2-2V15A2.0023,2.0023,0,0,1,28,13Z"
  })), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M17,9l-.857,3h2L19,9h2l-.857,3H22v2H19.572l-1.143,4H21v2H17.857L17,23H15l.857-3h-2L13,23H11l.857-3H10V18h2.429l1.143-4H11V12h3.143L15,9Zm.572,5h-2l-1.143,4h2Z"
  })), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,13V8H9V6H6A2.0023,2.0023,0,0,0,4,8v5a2.0023,2.0023,0,0,1-2,2v2a2.0023,2.0023,0,0,1,2,2v5a2.0023,2.0023,0,0,0,2,2H9V24H6V19a3.9756,3.9756,0,0,0-1.3823-3A3.9756,3.9756,0,0,0,6,13Z"
  })), children);
});
var Parameter24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Parameter24(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,13V8a2.0023,2.0023,0,0,0-2-2H23V8h3v5a3.9756,3.9756,0,0,0,1.3823,3A3.9756,3.9756,0,0,0,26,19v5H23v2h3a2.0023,2.0023,0,0,0,2-2V19a2.0023,2.0023,0,0,1,2-2V15A2.0023,2.0023,0,0,1,28,13Z"
  })), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M17,9l-.857,3h2L19,9h2l-.857,3H22v2H19.572l-1.143,4H21v2H17.857L17,23H15l.857-3h-2L13,23H11l.857-3H10V18h2.429l1.143-4H11V12h3.143L15,9Zm.572,5h-2l-1.143,4h2Z"
  })), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,13V8H9V6H6A2.0023,2.0023,0,0,0,4,8v5a2.0023,2.0023,0,0,1-2,2v2a2.0023,2.0023,0,0,1,2,2v5a2.0023,2.0023,0,0,0,2,2H9V24H6V19a3.9756,3.9756,0,0,0-1.3823-3A3.9756,3.9756,0,0,0,6,13Z"
  })), children);
});
var Parameter20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Parameter20(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,13V8a2.0023,2.0023,0,0,0-2-2H23V8h3v5a3.9756,3.9756,0,0,0,1.3823,3A3.9756,3.9756,0,0,0,26,19v5H23v2h3a2.0023,2.0023,0,0,0,2-2V19a2.0023,2.0023,0,0,1,2-2V15A2.0023,2.0023,0,0,1,28,13Z"
  })), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M17,9l-.857,3h2L19,9h2l-.857,3H22v2H19.572l-1.143,4H21v2H17.857L17,23H15l.857-3h-2L13,23H11l.857-3H10V18h2.429l1.143-4H11V12h3.143L15,9Zm.572,5h-2l-1.143,4h2Z"
  })), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,13V8H9V6H6A2.0023,2.0023,0,0,0,4,8v5a2.0023,2.0023,0,0,1-2,2v2a2.0023,2.0023,0,0,1,2,2v5a2.0023,2.0023,0,0,0,2,2H9V24H6V19a3.9756,3.9756,0,0,0-1.3823-3A3.9756,3.9756,0,0,0,6,13Z"
  })), children);
});
var Parameter16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Parameter16(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,13V8a2.0023,2.0023,0,0,0-2-2H23V8h3v5a3.9756,3.9756,0,0,0,1.3823,3A3.9756,3.9756,0,0,0,26,19v5H23v2h3a2.0023,2.0023,0,0,0,2-2V19a2.0023,2.0023,0,0,1,2-2V15A2.0023,2.0023,0,0,1,28,13Z"
  })), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M17,9l-.857,3h2L19,9h2l-.857,3H22v2H19.572l-1.143,4H21v2H17.857L17,23H15l.857-3h-2L13,23H11l.857-3H10V18h2.429l1.143-4H11V12h3.143L15,9Zm.572,5h-2l-1.143,4h2Z"
  })), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,13V8H9V6H6A2.0023,2.0023,0,0,0,4,8v5a2.0023,2.0023,0,0,1-2,2v2a2.0023,2.0023,0,0,1,2,2v5a2.0023,2.0023,0,0,0,2,2H9V24H6V19a3.9756,3.9756,0,0,0-1.3823-3A3.9756,3.9756,0,0,0,6,13Z"
  })), children);
});
var ParentChild32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ParentChild32(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12a2,2,0,0,0,2-2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4v6a2,2,0,0,0,2,2H15v4H9a2,2,0,0,0-2,2v4H4a2,2,0,0,0-2,2v4a2,2,0,0,0,2,2h8a2,2,0,0,0,2-2V24a2,2,0,0,0-2-2H9V18H23v4H20a2,2,0,0,0-2,2v4a2,2,0,0,0,2,2h8a2,2,0,0,0,2-2V24a2,2,0,0,0-2-2H25V18a2,2,0,0,0-2-2H17V12ZM12,28H4V24h8Zm16,0H20V24h8ZM4,4H28v6H4Z"
  })), children);
});
var ParentChild24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ParentChild24(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12a2,2,0,0,0,2-2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4v6a2,2,0,0,0,2,2H15v4H9a2,2,0,0,0-2,2v4H4a2,2,0,0,0-2,2v4a2,2,0,0,0,2,2h8a2,2,0,0,0,2-2V24a2,2,0,0,0-2-2H9V18H23v4H20a2,2,0,0,0-2,2v4a2,2,0,0,0,2,2h8a2,2,0,0,0,2-2V24a2,2,0,0,0-2-2H25V18a2,2,0,0,0-2-2H17V12ZM12,28H4V24h8Zm16,0H20V24h8ZM4,4H28v6H4Z"
  })), children);
});
var ParentChild20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ParentChild20(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12a2,2,0,0,0,2-2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4v6a2,2,0,0,0,2,2H15v4H9a2,2,0,0,0-2,2v4H4a2,2,0,0,0-2,2v4a2,2,0,0,0,2,2h8a2,2,0,0,0,2-2V24a2,2,0,0,0-2-2H9V18H23v4H20a2,2,0,0,0-2,2v4a2,2,0,0,0,2,2h8a2,2,0,0,0,2-2V24a2,2,0,0,0-2-2H25V18a2,2,0,0,0-2-2H17V12ZM12,28H4V24h8Zm16,0H20V24h8ZM4,4H28v6H4Z"
  })), children);
});
var ParentChild16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ParentChild16(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12a2,2,0,0,0,2-2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4v6a2,2,0,0,0,2,2H15v4H9a2,2,0,0,0-2,2v4H4a2,2,0,0,0-2,2v4a2,2,0,0,0,2,2h8a2,2,0,0,0,2-2V24a2,2,0,0,0-2-2H9V18H23v4H20a2,2,0,0,0-2,2v4a2,2,0,0,0,2,2h8a2,2,0,0,0,2-2V24a2,2,0,0,0-2-2H25V18a2,2,0,0,0-2-2H17V12ZM12,28H4V24h8Zm16,0H20V24h8ZM4,4H28v6H4Z"
  })), children);
});
var PartlyCloudy32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PartlyCloudy32(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 15H31V17H27z"
  })), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.086 5.794H27.329V7.794H23.086z",
    transform: "rotate(-45 25.207 6.794)"
  })), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 1H17V5H15z"
  })), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.672 24.208H8.915V26.208H4.672z",
    transform: "rotate(-45 6.793 25.208)"
  })), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.793 4.672H7.793V8.915H5.793z",
    transform: "rotate(-45 6.793 6.794)"
  })), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M1 15H5V17H1zM26.7939 20.3418a6.9617 6.9617 0 00-1.8681-3.2671A8.485 8.485 0 0025 16a9 9 0 10-14.585 7.0332A4.9771 4.9771 0 0015 30H25a4.9947 4.9947 0 001.7939-9.6582zM9 16a6.9955 6.9955 0 0113.9849-.2969A6.8883 6.8883 0 0020 15a7.04 7.04 0 00-6.7944 5.3418A4.986 4.986 0 0011.5618 21.39 6.9675 6.9675 0 019 16zM25 28H15a2.9945 2.9945 0 01-.6963-5.9082l.6587-.1572.0986-.67a4.9923 4.9923 0 019.878 0l.0986.6695.6587.1572A2.9945 2.9945 0 0125 28z"
  })), children);
});
var PartlyCloudy24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PartlyCloudy24(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 15H31V17H27z"
  })), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.086 5.794H27.329V7.794H23.086z",
    transform: "rotate(-45 25.207 6.794)"
  })), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 1H17V5H15z"
  })), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.672 24.208H8.915V26.208H4.672z",
    transform: "rotate(-45 6.793 25.208)"
  })), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.793 4.672H7.793V8.915H5.793z",
    transform: "rotate(-45 6.793 6.794)"
  })), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M1 15H5V17H1zM26.7939 20.3418a6.9617 6.9617 0 00-1.8681-3.2671A8.485 8.485 0 0025 16a9 9 0 10-14.585 7.0332A4.9771 4.9771 0 0015 30H25a4.9947 4.9947 0 001.7939-9.6582zM9 16a6.9955 6.9955 0 0113.9849-.2969A6.8883 6.8883 0 0020 15a7.04 7.04 0 00-6.7944 5.3418A4.986 4.986 0 0011.5618 21.39 6.9675 6.9675 0 019 16zM25 28H15a2.9945 2.9945 0 01-.6963-5.9082l.6587-.1572.0986-.67a4.9923 4.9923 0 019.878 0l.0986.6695.6587.1572A2.9945 2.9945 0 0125 28z"
  })), children);
});
var PartlyCloudy20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PartlyCloudy20(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 15H31V17H27z"
  })), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.086 5.794H27.329V7.794H23.086z",
    transform: "rotate(-45 25.207 6.794)"
  })), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 1H17V5H15z"
  })), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.672 24.208H8.915V26.208H4.672z",
    transform: "rotate(-45 6.793 25.208)"
  })), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.793 4.672H7.793V8.915H5.793z",
    transform: "rotate(-45 6.793 6.794)"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M1 15H5V17H1zM26.7939 20.3418a6.9617 6.9617 0 00-1.8681-3.2671A8.485 8.485 0 0025 16a9 9 0 10-14.585 7.0332A4.9771 4.9771 0 0015 30H25a4.9947 4.9947 0 001.7939-9.6582zM9 16a6.9955 6.9955 0 0113.9849-.2969A6.8883 6.8883 0 0020 15a7.04 7.04 0 00-6.7944 5.3418A4.986 4.986 0 0011.5618 21.39 6.9675 6.9675 0 019 16zM25 28H15a2.9945 2.9945 0 01-.6963-5.9082l.6587-.1572.0986-.67a4.9923 4.9923 0 019.878 0l.0986.6695.6587.1572A2.9945 2.9945 0 0125 28z"
  })), children);
});
var PartlyCloudy16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PartlyCloudy16(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 15H31V17H27z"
  })), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.086 5.794H27.329V7.794H23.086z",
    transform: "rotate(-45 25.207 6.794)"
  })), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 1H17V5H15z"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.672 24.208H8.915V26.208H4.672z",
    transform: "rotate(-45 6.793 25.208)"
  })), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.793 4.672H7.793V8.915H5.793z",
    transform: "rotate(-45 6.793 6.794)"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M1 15H5V17H1zM26.7939 20.3418a6.9617 6.9617 0 00-1.8681-3.2671A8.485 8.485 0 0025 16a9 9 0 10-14.585 7.0332A4.9771 4.9771 0 0015 30H25a4.9947 4.9947 0 001.7939-9.6582zM9 16a6.9955 6.9955 0 0113.9849-.2969A6.8883 6.8883 0 0020 15a7.04 7.04 0 00-6.7944 5.3418A4.986 4.986 0 0011.5618 21.39 6.9675 6.9675 0 019 16zM25 28H15a2.9945 2.9945 0 01-.6963-5.9082l.6587-.1572.0986-.67a4.9923 4.9923 0 019.878 0l.0986.6695.6587.1572A2.9945 2.9945 0 0125 28z"
  })), children);
});
var PartlyCloudyNight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PartlyCloudyNight32(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,19a4.974,4.974,0,0,0-3.2061-4.6582A6.9711,6.9711,0,0,0,13.7578,12.9a13.1418,13.1418,0,0,1,.1314-8.52A1.015,1.015,0,0,0,12.98,3a.9825.9825,0,0,0-.1746.0156A13.0958,13.0958,0,0,0,14.63,28.9971c.164.0063.3281,0,.4907,0a13.0412,13.0412,0,0,0,10.29-5.0386A4.99,4.99,0,0,0,30,19ZM14.7034,26.9976a11.0945,11.0945,0,0,1-3.201-21.584,15.1817,15.1817,0,0,0,.8443,9.3676A4.9877,4.9877,0,0,0,15,24h7.6772a11.0991,11.0991,0,0,1-7.5561,2.9976C14.9827,26.9976,14.8428,27.0024,14.7034,26.9976ZM25,22H15a2.9945,2.9945,0,0,1-.6963-5.9082l.6587-.1572.0986-.67a4.9923,4.9923,0,0,1,9.878.0005l.0986.6695.6587.1572A2.9945,2.9945,0,0,1,25,22Z"
  })), children);
});
var PartlyCloudyNight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PartlyCloudyNight24(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,19a4.974,4.974,0,0,0-3.2061-4.6582A6.9711,6.9711,0,0,0,13.7578,12.9a13.1418,13.1418,0,0,1,.1314-8.52A1.015,1.015,0,0,0,12.98,3a.9825.9825,0,0,0-.1746.0156A13.0958,13.0958,0,0,0,14.63,28.9971c.164.0063.3281,0,.4907,0a13.0412,13.0412,0,0,0,10.29-5.0386A4.99,4.99,0,0,0,30,19ZM14.7034,26.9976a11.0945,11.0945,0,0,1-3.201-21.584,15.1817,15.1817,0,0,0,.8443,9.3676A4.9877,4.9877,0,0,0,15,24h7.6772a11.0991,11.0991,0,0,1-7.5561,2.9976C14.9827,26.9976,14.8428,27.0024,14.7034,26.9976ZM25,22H15a2.9945,2.9945,0,0,1-.6963-5.9082l.6587-.1572.0986-.67a4.9923,4.9923,0,0,1,9.878.0005l.0986.6695.6587.1572A2.9945,2.9945,0,0,1,25,22Z"
  })), children);
});
var PartlyCloudyNight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PartlyCloudyNight20(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,19a4.974,4.974,0,0,0-3.2061-4.6582A6.9711,6.9711,0,0,0,13.7578,12.9a13.1418,13.1418,0,0,1,.1314-8.52A1.015,1.015,0,0,0,12.98,3a.9825.9825,0,0,0-.1746.0156A13.0958,13.0958,0,0,0,14.63,28.9971c.164.0063.3281,0,.4907,0a13.0412,13.0412,0,0,0,10.29-5.0386A4.99,4.99,0,0,0,30,19ZM14.7034,26.9976a11.0945,11.0945,0,0,1-3.201-21.584,15.1817,15.1817,0,0,0,.8443,9.3676A4.9877,4.9877,0,0,0,15,24h7.6772a11.0991,11.0991,0,0,1-7.5561,2.9976C14.9827,26.9976,14.8428,27.0024,14.7034,26.9976ZM25,22H15a2.9945,2.9945,0,0,1-.6963-5.9082l.6587-.1572.0986-.67a4.9923,4.9923,0,0,1,9.878.0005l.0986.6695.6587.1572A2.9945,2.9945,0,0,1,25,22Z"
  })), children);
});
var PartlyCloudyNight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PartlyCloudyNight16(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,19a4.974,4.974,0,0,0-3.2061-4.6582A6.9711,6.9711,0,0,0,13.7578,12.9a13.1418,13.1418,0,0,1,.1314-8.52A1.015,1.015,0,0,0,12.98,3a.9825.9825,0,0,0-.1746.0156A13.0958,13.0958,0,0,0,14.63,28.9971c.164.0063.3281,0,.4907,0a13.0412,13.0412,0,0,0,10.29-5.0386A4.99,4.99,0,0,0,30,19ZM14.7034,26.9976a11.0945,11.0945,0,0,1-3.201-21.584,15.1817,15.1817,0,0,0,.8443,9.3676A4.9877,4.9877,0,0,0,15,24h7.6772a11.0991,11.0991,0,0,1-7.5561,2.9976C14.9827,26.9976,14.8428,27.0024,14.7034,26.9976ZM25,22H15a2.9945,2.9945,0,0,1-.6963-5.9082l.6587-.1572.0986-.67a4.9923,4.9923,0,0,1,9.878.0005l.0986.6695.6587.1572A2.9945,2.9945,0,0,1,25,22Z"
  })), children);
});
var Partnership32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Partnership32(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 9a4 4 0 114-4A4 4 0 018 9zM8 3a2 2 0 102 2A2 2 0 008 3zM24 9a4 4 0 114-4A4 4 0 0124 9zm0-6a2 2 0 102 2A2 2 0 0024 3zM26 30H22a2 2 0 01-2-2V21h2v7h4V19h2V13a1 1 0 00-1-1H20.58L16 20l-4.58-8H5a1 1 0 00-1 1v6H6v9h4V21h2v7a2 2 0 01-2 2H6a2 2 0 01-2-2V21a2 2 0 01-2-2V13a3 3 0 013-3h7.58L16 16l3.42-6H27a3 3 0 013 3v6a2 2 0 01-2 2v7A2 2 0 0126 30z"
  })), children);
});
var Partnership24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Partnership24(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 9a4 4 0 114-4A4 4 0 018 9zM8 3a2 2 0 102 2A2 2 0 008 3zM24 9a4 4 0 114-4A4 4 0 0124 9zm0-6a2 2 0 102 2A2 2 0 0024 3zM26 30H22a2 2 0 01-2-2V21h2v7h4V19h2V13a1 1 0 00-1-1H20.58L16 20l-4.58-8H5a1 1 0 00-1 1v6H6v9h4V21h2v7a2 2 0 01-2 2H6a2 2 0 01-2-2V21a2 2 0 01-2-2V13a3 3 0 013-3h7.58L16 16l3.42-6H27a3 3 0 013 3v6a2 2 0 01-2 2v7A2 2 0 0126 30z"
  })), children);
});
var Partnership20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Partnership20(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 9a4 4 0 114-4A4 4 0 018 9zM8 3a2 2 0 102 2A2 2 0 008 3zM24 9a4 4 0 114-4A4 4 0 0124 9zm0-6a2 2 0 102 2A2 2 0 0024 3zM26 30H22a2 2 0 01-2-2V21h2v7h4V19h2V13a1 1 0 00-1-1H20.58L16 20l-4.58-8H5a1 1 0 00-1 1v6H6v9h4V21h2v7a2 2 0 01-2 2H6a2 2 0 01-2-2V21a2 2 0 01-2-2V13a3 3 0 013-3h7.58L16 16l3.42-6H27a3 3 0 013 3v6a2 2 0 01-2 2v7A2 2 0 0126 30z"
  })), children);
});
var Partnership16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Partnership16(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 9a4 4 0 114-4A4 4 0 018 9zM8 3a2 2 0 102 2A2 2 0 008 3zM24 9a4 4 0 114-4A4 4 0 0124 9zm0-6a2 2 0 102 2A2 2 0 0024 3zM26 30H22a2 2 0 01-2-2V21h2v7h4V19h2V13a1 1 0 00-1-1H20.58L16 20l-4.58-8H5a1 1 0 00-1 1v6H6v9h4V21h2v7a2 2 0 01-2 2H6a2 2 0 01-2-2V21a2 2 0 01-2-2V13a3 3 0 013-3h7.58L16 16l3.42-6H27a3 3 0 013 3v6a2 2 0 01-2 2v7A2 2 0 0126 30z"
  })), children);
});
var PassengerDrinks32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PassengerDrinks32(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 4V2H22V4a3.9906 3.9906 0 003 3.8586V11H23v2h6V11H27V7.8586A3.9906 3.9906 0 0030 4zM10.5 9A3.5 3.5 0 1114 5.5 3.5042 3.5042 0 0110.5 9zm0-5A1.5 1.5 0 1012 5.5 1.5017 1.5017 0 0010.5 4zM22.4746 31.313L19.3408 24H12.2393A4.0073 4.0073 0 018.373 21.0293l-1.6337-6.126a3.8987 3.8987 0 017.5341-2.0092L15.1016 16H21v2H13.5645l-1.2227-4.5908a1.9 1.9 0 00-3.6709.979l1.6338 6.1255A2.0052 2.0052 0 0012.2393 22h8.42l3.6543 8.5254z"
  })), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28H7.7683a2.0025,2.0025,0,0,1-1.9326-1.4849L2.0337,12.2576l1.9326-.5152L7.7683,26H18Z"
  })), children);
});
var PassengerDrinks24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PassengerDrinks24(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 4V2H22V4a3.9906 3.9906 0 003 3.8586V11H23v2h6V11H27V7.8586A3.9906 3.9906 0 0030 4zM10.5 9A3.5 3.5 0 1114 5.5 3.5042 3.5042 0 0110.5 9zm0-5A1.5 1.5 0 1012 5.5 1.5017 1.5017 0 0010.5 4zM22.4746 31.313L19.3408 24H12.2393A4.0073 4.0073 0 018.373 21.0293l-1.6337-6.126a3.8987 3.8987 0 017.5341-2.0092L15.1016 16H21v2H13.5645l-1.2227-4.5908a1.9 1.9 0 00-3.6709.979l1.6338 6.1255A2.0052 2.0052 0 0012.2393 22h8.42l3.6543 8.5254z"
  })), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28H7.7683a2.0025,2.0025,0,0,1-1.9326-1.4849L2.0337,12.2576l1.9326-.5152L7.7683,26H18Z"
  })), children);
});
var PassengerDrinks20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PassengerDrinks20(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 4V2H22V4a3.9906 3.9906 0 003 3.8586V11H23v2h6V11H27V7.8586A3.9906 3.9906 0 0030 4zM10.5 9A3.5 3.5 0 1114 5.5 3.5042 3.5042 0 0110.5 9zm0-5A1.5 1.5 0 1012 5.5 1.5017 1.5017 0 0010.5 4zM22.4746 31.313L19.3408 24H12.2393A4.0073 4.0073 0 018.373 21.0293l-1.6337-6.126a3.8987 3.8987 0 017.5341-2.0092L15.1016 16H21v2H13.5645l-1.2227-4.5908a1.9 1.9 0 00-3.6709.979l1.6338 6.1255A2.0052 2.0052 0 0012.2393 22h8.42l3.6543 8.5254z"
  })), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28H7.7683a2.0025,2.0025,0,0,1-1.9326-1.4849L2.0337,12.2576l1.9326-.5152L7.7683,26H18Z"
  })), children);
});
var PassengerDrinks16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PassengerDrinks16(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 4V2H22V4a3.9906 3.9906 0 003 3.8586V11H23v2h6V11H27V7.8586A3.9906 3.9906 0 0030 4zM10.5 9A3.5 3.5 0 1114 5.5 3.5042 3.5042 0 0110.5 9zm0-5A1.5 1.5 0 1012 5.5 1.5017 1.5017 0 0010.5 4zM22.4746 31.313L19.3408 24H12.2393A4.0073 4.0073 0 018.373 21.0293l-1.6337-6.126a3.8987 3.8987 0 017.5341-2.0092L15.1016 16H21v2H13.5645l-1.2227-4.5908a1.9 1.9 0 00-3.6709.979l1.6338 6.1255A2.0052 2.0052 0 0012.2393 22h8.42l3.6543 8.5254z"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28H7.7683a2.0025,2.0025,0,0,1-1.9326-1.4849L2.0337,12.2576l1.9326-.5152L7.7683,26H18Z"
  })), children);
});
var PassengerPlus32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PassengerPlus32(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.5 9A3.5 3.5 0 1114 5.5 3.5042 3.5042 0 0110.5 9zm0-5A1.5 1.5 0 1012 5.5 1.5017 1.5017 0 0010.5 4zM22.4739 31.313L19.34 24H12.2385a4.0072 4.0072 0 01-3.8662-2.9707l-1.6338-6.126a3.8988 3.8988 0 017.5342-2.0092L15.1008 16H21v2H13.5637l-1.2226-4.5908a1.9 1.9 0 00-3.6709.979l1.6338 6.1255A2.0051 2.0051 0 0012.2385 22h8.42l3.6543 8.5254zM30 6L26 6 26 2 24 2 24 6 20 6 20 8 24 8 24 12 26 12 26 8 30 8 30 6z"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28H7.7676A2.0025,2.0025,0,0,1,5.835,26.5151L2.033,12.2576l1.9326-.5152L7.7676,26H18Z"
  })), children);
});
var PassengerPlus24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PassengerPlus24(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.5 9A3.5 3.5 0 1114 5.5 3.5042 3.5042 0 0110.5 9zm0-5A1.5 1.5 0 1012 5.5 1.5017 1.5017 0 0010.5 4zM22.4739 31.313L19.34 24H12.2385a4.0072 4.0072 0 01-3.8662-2.9707l-1.6338-6.126a3.8988 3.8988 0 017.5342-2.0092L15.1008 16H21v2H13.5637l-1.2226-4.5908a1.9 1.9 0 00-3.6709.979l1.6338 6.1255A2.0051 2.0051 0 0012.2385 22h8.42l3.6543 8.5254zM30 6L26 6 26 2 24 2 24 6 20 6 20 8 24 8 24 12 26 12 26 8 30 8 30 6z"
  })), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28H7.7676A2.0025,2.0025,0,0,1,5.835,26.5151L2.033,12.2576l1.9326-.5152L7.7676,26H18Z"
  })), children);
});
var PassengerPlus20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PassengerPlus20(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.5 9A3.5 3.5 0 1114 5.5 3.5042 3.5042 0 0110.5 9zm0-5A1.5 1.5 0 1012 5.5 1.5017 1.5017 0 0010.5 4zM22.4739 31.313L19.34 24H12.2385a4.0072 4.0072 0 01-3.8662-2.9707l-1.6338-6.126a3.8988 3.8988 0 017.5342-2.0092L15.1008 16H21v2H13.5637l-1.2226-4.5908a1.9 1.9 0 00-3.6709.979l1.6338 6.1255A2.0051 2.0051 0 0012.2385 22h8.42l3.6543 8.5254zM30 6L26 6 26 2 24 2 24 6 20 6 20 8 24 8 24 12 26 12 26 8 30 8 30 6z"
  })), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28H7.7676A2.0025,2.0025,0,0,1,5.835,26.5151L2.033,12.2576l1.9326-.5152L7.7676,26H18Z"
  })), children);
});
var PassengerPlus16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PassengerPlus16(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.5 9A3.5 3.5 0 1114 5.5 3.5042 3.5042 0 0110.5 9zm0-5A1.5 1.5 0 1012 5.5 1.5017 1.5017 0 0010.5 4zM22.4739 31.313L19.34 24H12.2385a4.0072 4.0072 0 01-3.8662-2.9707l-1.6338-6.126a3.8988 3.8988 0 017.5342-2.0092L15.1008 16H21v2H13.5637l-1.2226-4.5908a1.9 1.9 0 00-3.6709.979l1.6338 6.1255A2.0051 2.0051 0 0012.2385 22h8.42l3.6543 8.5254zM30 6L26 6 26 2 24 2 24 6 20 6 20 8 24 8 24 12 26 12 26 8 30 8 30 6z"
  })), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28H7.7676A2.0025,2.0025,0,0,1,5.835,26.5151L2.033,12.2576l1.9326-.5152L7.7676,26H18Z"
  })), children);
});
var Password32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Password32(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,2a8.9977,8.9977,0,0,0-8.6119,11.6118L2,24v6H8L18.3881,19.6118A9,9,0,1,0,21,2Zm0,16a7.0125,7.0125,0,0,1-2.0322-.3022L17.821,17.35l-.8472.8472-3.1811,3.1812L12.4141,20,11,21.4141l1.3787,1.3786-1.5859,1.586L9.4141,23,8,24.4141l1.3787,1.3786L7.1716,28H4V24.8284l9.8023-9.8023.8472-.8474-.3473-1.1467A7,7,0,1,1,21,18Z"
  })), _circle45 || (_circle45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "10",
    r: "2"
  })), children);
});
var Password24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Password24(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,2a8.9977,8.9977,0,0,0-8.6119,11.6118L2,24v6H8L18.3881,19.6118A9,9,0,1,0,21,2Zm0,16a7.0125,7.0125,0,0,1-2.0322-.3022L17.821,17.35l-.8472.8472-3.1811,3.1812L12.4141,20,11,21.4141l1.3787,1.3786-1.5859,1.586L9.4141,23,8,24.4141l1.3787,1.3786L7.1716,28H4V24.8284l9.8023-9.8023.8472-.8474-.3473-1.1467A7,7,0,1,1,21,18Z"
  })), _circle46 || (_circle46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "10",
    r: "2"
  })), children);
});
var Password20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Password20(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,2a8.9977,8.9977,0,0,0-8.6119,11.6118L2,24v6H8L18.3881,19.6118A9,9,0,1,0,21,2Zm0,16a7.0125,7.0125,0,0,1-2.0322-.3022L17.821,17.35l-.8472.8472-3.1811,3.1812L12.4141,20,11,21.4141l1.3787,1.3786-1.5859,1.586L9.4141,23,8,24.4141l1.3787,1.3786L7.1716,28H4V24.8284l9.8023-9.8023.8472-.8474-.3473-1.1467A7,7,0,1,1,21,18Z"
  })), _circle47 || (_circle47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "10",
    r: "2"
  })), children);
});
var Password16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Password16(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,2a8.9977,8.9977,0,0,0-8.6119,11.6118L2,24v6H8L18.3881,19.6118A9,9,0,1,0,21,2Zm0,16a7.0125,7.0125,0,0,1-2.0322-.3022L17.821,17.35l-.8472.8472-3.1811,3.1812L12.4141,20,11,21.4141l1.3787,1.3786-1.5859,1.586L9.4141,23,8,24.4141l1.3787,1.3786L7.1716,28H4V24.8284l9.8023-9.8023.8472-.8474-.3473-1.1467A7,7,0,1,1,21,18Z"
  })), _circle48 || (_circle48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "10",
    r: "2"
  })), children);
});
var Paste32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Paste32(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20H17.83l2.58-2.59L19,16l-5,5,5,5,1.41-1.41L17.83,22H26v8h2V22A2,2,0,0,0,26,20Z"
  })), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.71,9.29l-7-7A1,1,0,0,0,16,2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2h8V28H6V4h8v6a2,2,0,0,0,2,2h6v2h2V10A1,1,0,0,0,23.71,9.29ZM16,4.41,21.59,10H16Z"
  })), children);
});
var Paste24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Paste24(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20H17.83l2.58-2.59L19,16l-5,5,5,5,1.41-1.41L17.83,22H26v8h2V22A2,2,0,0,0,26,20Z"
  })), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.71,9.29l-7-7A1,1,0,0,0,16,2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2h8V28H6V4h8v6a2,2,0,0,0,2,2h6v2h2V10A1,1,0,0,0,23.71,9.29ZM16,4.41,21.59,10H16Z"
  })), children);
});
var Paste20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Paste20(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20H17.83l2.58-2.59L19,16l-5,5,5,5,1.41-1.41L17.83,22H26v8h2V22A2,2,0,0,0,26,20Z"
  })), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.71,9.29l-7-7A1,1,0,0,0,16,2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2h8V28H6V4h8v6a2,2,0,0,0,2,2h6v2h2V10A1,1,0,0,0,23.71,9.29ZM16,4.41,21.59,10H16Z"
  })), children);
});
var Paste16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Paste16(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20H17.83l2.58-2.59L19,16l-5,5,5,5,1.41-1.41L17.83,22H26v8h2V22A2,2,0,0,0,26,20Z"
  })), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.71,9.29l-7-7A1,1,0,0,0,16,2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2h8V28H6V4h8v6a2,2,0,0,0,2,2h6v2h2V10A1,1,0,0,0,23.71,9.29ZM16,4.41,21.59,10H16Z"
  })), children);
});
var Pause32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pause32(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 8V24H8V8h4m0-2H8A2 2 0 006 8V24a2 2 0 002 2h4a2 2 0 002-2V8a2 2 0 00-2-2zM24 8V24H20V8h4m0-2H20a2 2 0 00-2 2V24a2 2 0 002 2h4a2 2 0 002-2V8a2 2 0 00-2-2z"
  })), children);
});
var Pause24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pause24(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 8V24H8V8h4m0-2H8A2 2 0 006 8V24a2 2 0 002 2h4a2 2 0 002-2V8a2 2 0 00-2-2zM24 8V24H20V8h4m0-2H20a2 2 0 00-2 2V24a2 2 0 002 2h4a2 2 0 002-2V8a2 2 0 00-2-2z"
  })), children);
});
var Pause20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pause20(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 8V24H8V8h4m0-2H8A2 2 0 006 8V24a2 2 0 002 2h4a2 2 0 002-2V8a2 2 0 00-2-2zM24 8V24H20V8h4m0-2H20a2 2 0 00-2 2V24a2 2 0 002 2h4a2 2 0 002-2V8a2 2 0 00-2-2z"
  })), children);
});
var Pause16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pause16(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 4v8H4V4H6M6 3H4C3.4 3 3 3.4 3 4v8c0 .6.4 1 1 1h2c.6 0 1-.4 1-1V4C7 3.4 6.6 3 6 3zM12 4v8h-2V4H12M12 3h-2C9.4 3 9 3.4 9 4v8c0 .6.4 1 1 1h2c.6 0 1-.4 1-1V4C13 3.4 12.6 3 12 3z"
  })), children);
});
var PauseFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PauseFilled32(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6H10A2 2 0 008 8V24a2 2 0 002 2h2a2 2 0 002-2V8a2 2 0 00-2-2zM22 6H20a2 2 0 00-2 2V24a2 2 0 002 2h2a2 2 0 002-2V8a2 2 0 00-2-2z"
  })), children);
});
var PauseFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PauseFilled24(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6H10A2 2 0 008 8V24a2 2 0 002 2h2a2 2 0 002-2V8a2 2 0 00-2-2zM22 6H20a2 2 0 00-2 2V24a2 2 0 002 2h2a2 2 0 002-2V8a2 2 0 00-2-2z"
  })), children);
});
var PauseFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PauseFilled20(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6H10A2 2 0 008 8V24a2 2 0 002 2h2a2 2 0 002-2V8a2 2 0 00-2-2zM22 6H20a2 2 0 00-2 2V24a2 2 0 002 2h2a2 2 0 002-2V8a2 2 0 00-2-2z"
  })), children);
});
var PauseFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PauseFilled16(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6H10A2 2 0 008 8V24a2 2 0 002 2h2a2 2 0 002-2V8a2 2 0 00-2-2zM22 6H20a2 2 0 00-2 2V24a2 2 0 002 2h2a2 2 0 002-2V8a2 2 0 00-2-2z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-20.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-20.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "PauseFuture16": () => (/* binding */ PauseFuture16),
/* harmony export */   "PauseFuture20": () => (/* binding */ PauseFuture20),
/* harmony export */   "PauseFuture24": () => (/* binding */ PauseFuture24),
/* harmony export */   "PauseFuture32": () => (/* binding */ PauseFuture32),
/* harmony export */   "PauseOutline16": () => (/* binding */ PauseOutline16),
/* harmony export */   "PauseOutline20": () => (/* binding */ PauseOutline20),
/* harmony export */   "PauseOutline24": () => (/* binding */ PauseOutline24),
/* harmony export */   "PauseOutline32": () => (/* binding */ PauseOutline32),
/* harmony export */   "PauseOutlineFilled16": () => (/* binding */ PauseOutlineFilled16),
/* harmony export */   "PauseOutlineFilled20": () => (/* binding */ PauseOutlineFilled20),
/* harmony export */   "PauseOutlineFilled24": () => (/* binding */ PauseOutlineFilled24),
/* harmony export */   "PauseOutlineFilled32": () => (/* binding */ PauseOutlineFilled32),
/* harmony export */   "PausePast16": () => (/* binding */ PausePast16),
/* harmony export */   "PausePast20": () => (/* binding */ PausePast20),
/* harmony export */   "PausePast24": () => (/* binding */ PausePast24),
/* harmony export */   "PausePast32": () => (/* binding */ PausePast32),
/* harmony export */   "PcnENode16": () => (/* binding */ PcnENode16),
/* harmony export */   "PcnENode20": () => (/* binding */ PcnENode20),
/* harmony export */   "PcnENode24": () => (/* binding */ PcnENode24),
/* harmony export */   "PcnENode32": () => (/* binding */ PcnENode32),
/* harmony export */   "PcnMilitary16": () => (/* binding */ PcnMilitary16),
/* harmony export */   "PcnMilitary20": () => (/* binding */ PcnMilitary20),
/* harmony export */   "PcnMilitary24": () => (/* binding */ PcnMilitary24),
/* harmony export */   "PcnMilitary32": () => (/* binding */ PcnMilitary32),
/* harmony export */   "PcnPNode16": () => (/* binding */ PcnPNode16),
/* harmony export */   "PcnPNode20": () => (/* binding */ PcnPNode20),
/* harmony export */   "PcnPNode24": () => (/* binding */ PcnPNode24),
/* harmony export */   "PcnPNode32": () => (/* binding */ PcnPNode32),
/* harmony export */   "PcnZNode16": () => (/* binding */ PcnZNode16),
/* harmony export */   "PcnZNode20": () => (/* binding */ PcnZNode20),
/* harmony export */   "PcnZNode24": () => (/* binding */ PcnZNode24),
/* harmony export */   "PcnZNode32": () => (/* binding */ PcnZNode32),
/* harmony export */   "Pdf16": () => (/* binding */ Pdf16),
/* harmony export */   "Pdf20": () => (/* binding */ Pdf20),
/* harmony export */   "Pdf24": () => (/* binding */ Pdf24),
/* harmony export */   "Pdf32": () => (/* binding */ Pdf32),
/* harmony export */   "PdfReference16": () => (/* binding */ PdfReference16),
/* harmony export */   "PdfReference20": () => (/* binding */ PdfReference20),
/* harmony export */   "PdfReference24": () => (/* binding */ PdfReference24),
/* harmony export */   "PdfReference32": () => (/* binding */ PdfReference32),
/* harmony export */   "Pedestrian16": () => (/* binding */ Pedestrian16),
/* harmony export */   "Pedestrian20": () => (/* binding */ Pedestrian20),
/* harmony export */   "Pedestrian24": () => (/* binding */ Pedestrian24),
/* harmony export */   "Pedestrian32": () => (/* binding */ Pedestrian32),
/* harmony export */   "PedestrianChild16": () => (/* binding */ PedestrianChild16),
/* harmony export */   "PedestrianChild20": () => (/* binding */ PedestrianChild20),
/* harmony export */   "PedestrianChild24": () => (/* binding */ PedestrianChild24),
/* harmony export */   "PedestrianChild32": () => (/* binding */ PedestrianChild32),
/* harmony export */   "PedestrianFamily16": () => (/* binding */ PedestrianFamily16),
/* harmony export */   "PedestrianFamily20": () => (/* binding */ PedestrianFamily20),
/* harmony export */   "PedestrianFamily24": () => (/* binding */ PedestrianFamily24),
/* harmony export */   "PedestrianFamily32": () => (/* binding */ PedestrianFamily32),
/* harmony export */   "Pen16": () => (/* binding */ Pen16),
/* harmony export */   "Pen20": () => (/* binding */ Pen20),
/* harmony export */   "Pen24": () => (/* binding */ Pen24),
/* harmony export */   "Pen32": () => (/* binding */ Pen32),
/* harmony export */   "PenFountain16": () => (/* binding */ PenFountain16),
/* harmony export */   "PenFountain20": () => (/* binding */ PenFountain20),
/* harmony export */   "PenFountain24": () => (/* binding */ PenFountain24),
/* harmony export */   "PenFountain32": () => (/* binding */ PenFountain32),
/* harmony export */   "Pending16": () => (/* binding */ Pending16),
/* harmony export */   "Pending20": () => (/* binding */ Pending20),
/* harmony export */   "Pending24": () => (/* binding */ Pending24),
/* harmony export */   "Pending32": () => (/* binding */ Pending32),
/* harmony export */   "PendingFilled16": () => (/* binding */ PendingFilled16),
/* harmony export */   "PendingFilled20": () => (/* binding */ PendingFilled20),
/* harmony export */   "PendingFilled24": () => (/* binding */ PendingFilled24),
/* harmony export */   "PendingFilled32": () => (/* binding */ PendingFilled32),
/* harmony export */   "Percentage16": () => (/* binding */ Percentage16),
/* harmony export */   "Percentage20": () => (/* binding */ Percentage20),
/* harmony export */   "Percentage24": () => (/* binding */ Percentage24),
/* harmony export */   "Percentage32": () => (/* binding */ Percentage32),
/* harmony export */   "PercentageFilled16": () => (/* binding */ PercentageFilled16),
/* harmony export */   "PercentageFilled20": () => (/* binding */ PercentageFilled20),
/* harmony export */   "PercentageFilled24": () => (/* binding */ PercentageFilled24),
/* harmony export */   "PercentageFilled32": () => (/* binding */ PercentageFilled32),
/* harmony export */   "Person16": () => (/* binding */ Person16),
/* harmony export */   "Person20": () => (/* binding */ Person20),
/* harmony export */   "Person24": () => (/* binding */ Person24),
/* harmony export */   "Person32": () => (/* binding */ Person32),
/* harmony export */   "PersonFavorite16": () => (/* binding */ PersonFavorite16),
/* harmony export */   "PersonFavorite20": () => (/* binding */ PersonFavorite20),
/* harmony export */   "PersonFavorite24": () => (/* binding */ PersonFavorite24),
/* harmony export */   "PersonFavorite32": () => (/* binding */ PersonFavorite32),
/* harmony export */   "Pest16": () => (/* binding */ Pest16),
/* harmony export */   "Pest20": () => (/* binding */ Pest20),
/* harmony export */   "Pest24": () => (/* binding */ Pest24),
/* harmony export */   "Pest32": () => (/* binding */ Pest32),
/* harmony export */   "Phone16": () => (/* binding */ Phone16),
/* harmony export */   "Phone20": () => (/* binding */ Phone20),
/* harmony export */   "Phone24": () => (/* binding */ Phone24),
/* harmony export */   "Phone32": () => (/* binding */ Phone32),
/* harmony export */   "PhoneApplication16": () => (/* binding */ PhoneApplication16),
/* harmony export */   "PhoneApplication20": () => (/* binding */ PhoneApplication20),
/* harmony export */   "PhoneApplication24": () => (/* binding */ PhoneApplication24),
/* harmony export */   "PhoneApplication32": () => (/* binding */ PhoneApplication32),
/* harmony export */   "PhoneBlock16": () => (/* binding */ PhoneBlock16),
/* harmony export */   "PhoneBlock20": () => (/* binding */ PhoneBlock20),
/* harmony export */   "PhoneBlock24": () => (/* binding */ PhoneBlock24),
/* harmony export */   "PhoneBlock32": () => (/* binding */ PhoneBlock32),
/* harmony export */   "PhoneBlockFilled16": () => (/* binding */ PhoneBlockFilled16),
/* harmony export */   "PhoneBlockFilled20": () => (/* binding */ PhoneBlockFilled20),
/* harmony export */   "PhoneBlockFilled24": () => (/* binding */ PhoneBlockFilled24),
/* harmony export */   "PhoneBlockFilled32": () => (/* binding */ PhoneBlockFilled32),
/* harmony export */   "PhoneFilled16": () => (/* binding */ PhoneFilled16),
/* harmony export */   "PhoneFilled20": () => (/* binding */ PhoneFilled20),
/* harmony export */   "PhoneFilled24": () => (/* binding */ PhoneFilled24),
/* harmony export */   "PhoneFilled32": () => (/* binding */ PhoneFilled32),
/* harmony export */   "PhoneIncoming16": () => (/* binding */ PhoneIncoming16),
/* harmony export */   "PhoneIncoming20": () => (/* binding */ PhoneIncoming20),
/* harmony export */   "PhoneIncoming24": () => (/* binding */ PhoneIncoming24),
/* harmony export */   "PhoneIncoming32": () => (/* binding */ PhoneIncoming32),
/* harmony export */   "PhoneIncomingFilled16": () => (/* binding */ PhoneIncomingFilled16),
/* harmony export */   "PhoneIncomingFilled20": () => (/* binding */ PhoneIncomingFilled20),
/* harmony export */   "PhoneIncomingFilled24": () => (/* binding */ PhoneIncomingFilled24),
/* harmony export */   "PhoneIncomingFilled32": () => (/* binding */ PhoneIncomingFilled32),
/* harmony export */   "PhoneIp16": () => (/* binding */ PhoneIp16),
/* harmony export */   "PhoneIp20": () => (/* binding */ PhoneIp20),
/* harmony export */   "PhoneIp24": () => (/* binding */ PhoneIp24),
/* harmony export */   "PhoneIp32": () => (/* binding */ PhoneIp32),
/* harmony export */   "PhoneOff16": () => (/* binding */ PhoneOff16),
/* harmony export */   "PhoneOff20": () => (/* binding */ PhoneOff20),
/* harmony export */   "PhoneOff24": () => (/* binding */ PhoneOff24),
/* harmony export */   "PhoneOff32": () => (/* binding */ PhoneOff32),
/* harmony export */   "PhoneOffFilled16": () => (/* binding */ PhoneOffFilled16),
/* harmony export */   "PhoneOffFilled20": () => (/* binding */ PhoneOffFilled20),
/* harmony export */   "PhoneOffFilled24": () => (/* binding */ PhoneOffFilled24),
/* harmony export */   "PhoneOffFilled32": () => (/* binding */ PhoneOffFilled32),
/* harmony export */   "PhoneOutgoing16": () => (/* binding */ PhoneOutgoing16),
/* harmony export */   "PhoneOutgoing20": () => (/* binding */ PhoneOutgoing20),
/* harmony export */   "PhoneOutgoing24": () => (/* binding */ PhoneOutgoing24),
/* harmony export */   "PhoneOutgoing32": () => (/* binding */ PhoneOutgoing32),
/* harmony export */   "PhoneOutgoingFilled16": () => (/* binding */ PhoneOutgoingFilled16),
/* harmony export */   "PhoneOutgoingFilled20": () => (/* binding */ PhoneOutgoingFilled20),
/* harmony export */   "PhoneOutgoingFilled24": () => (/* binding */ PhoneOutgoingFilled24),
/* harmony export */   "PhoneOutgoingFilled32": () => (/* binding */ PhoneOutgoingFilled32),
/* harmony export */   "PhoneSettings16": () => (/* binding */ PhoneSettings16),
/* harmony export */   "PhoneSettings20": () => (/* binding */ PhoneSettings20),
/* harmony export */   "PhoneSettings24": () => (/* binding */ PhoneSettings24),
/* harmony export */   "PhoneSettings32": () => (/* binding */ PhoneSettings32),
/* harmony export */   "PhoneVoice16": () => (/* binding */ PhoneVoice16),
/* harmony export */   "PhoneVoice20": () => (/* binding */ PhoneVoice20),
/* harmony export */   "PhoneVoice24": () => (/* binding */ PhoneVoice24),
/* harmony export */   "PhoneVoice32": () => (/* binding */ PhoneVoice32),
/* harmony export */   "PhoneVoiceFilled16": () => (/* binding */ PhoneVoiceFilled16),
/* harmony export */   "PhoneVoiceFilled20": () => (/* binding */ PhoneVoiceFilled20),
/* harmony export */   "PhoneVoiceFilled24": () => (/* binding */ PhoneVoiceFilled24),
/* harmony export */   "PhoneVoiceFilled32": () => (/* binding */ PhoneVoiceFilled32),
/* harmony export */   "PhraseSentiment16": () => (/* binding */ PhraseSentiment16),
/* harmony export */   "PhraseSentiment20": () => (/* binding */ PhraseSentiment20),
/* harmony export */   "PhraseSentiment24": () => (/* binding */ PhraseSentiment24),
/* harmony export */   "PhraseSentiment32": () => (/* binding */ PhraseSentiment32),
/* harmony export */   "PicnicArea16": () => (/* binding */ PicnicArea16),
/* harmony export */   "PicnicArea20": () => (/* binding */ PicnicArea20),
/* harmony export */   "PicnicArea24": () => (/* binding */ PicnicArea24),
/* harmony export */   "PicnicArea32": () => (/* binding */ PicnicArea32),
/* harmony export */   "PiggyBank16": () => (/* binding */ PiggyBank16),
/* harmony export */   "PiggyBank20": () => (/* binding */ PiggyBank20),
/* harmony export */   "PiggyBank24": () => (/* binding */ PiggyBank24),
/* harmony export */   "PiggyBank32": () => (/* binding */ PiggyBank32),
/* harmony export */   "PiggyBankSlot16": () => (/* binding */ PiggyBankSlot16),
/* harmony export */   "PiggyBankSlot20": () => (/* binding */ PiggyBankSlot20),
/* harmony export */   "PiggyBankSlot24": () => (/* binding */ PiggyBankSlot24),
/* harmony export */   "PiggyBankSlot32": () => (/* binding */ PiggyBankSlot32),
/* harmony export */   "Pills16": () => (/* binding */ Pills16),
/* harmony export */   "Pills20": () => (/* binding */ Pills20),
/* harmony export */   "Pills24": () => (/* binding */ Pills24),
/* harmony export */   "Pills32": () => (/* binding */ Pills32),
/* harmony export */   "PillsAdd16": () => (/* binding */ PillsAdd16),
/* harmony export */   "PillsAdd20": () => (/* binding */ PillsAdd20),
/* harmony export */   "PillsAdd24": () => (/* binding */ PillsAdd24),
/* harmony export */   "PillsAdd32": () => (/* binding */ PillsAdd32),
/* harmony export */   "PillsSubtract16": () => (/* binding */ PillsSubtract16),
/* harmony export */   "PillsSubtract20": () => (/* binding */ PillsSubtract20),
/* harmony export */   "PillsSubtract24": () => (/* binding */ PillsSubtract24),
/* harmony export */   "PillsSubtract32": () => (/* binding */ PillsSubtract32),
/* harmony export */   "Pin16": () => (/* binding */ Pin16),
/* harmony export */   "Pin20": () => (/* binding */ Pin20),
/* harmony export */   "Pin24": () => (/* binding */ Pin24),
/* harmony export */   "Pin32": () => (/* binding */ Pin32),
/* harmony export */   "PinFilled16": () => (/* binding */ PinFilled16),
/* harmony export */   "PinFilled20": () => (/* binding */ PinFilled20),
/* harmony export */   "PinFilled24": () => (/* binding */ PinFilled24),
/* harmony export */   "PinFilled32": () => (/* binding */ PinFilled32),
/* harmony export */   "Plane16": () => (/* binding */ Plane16),
/* harmony export */   "Plane20": () => (/* binding */ Plane20),
/* harmony export */   "Plane24": () => (/* binding */ Plane24),
/* harmony export */   "Plane32": () => (/* binding */ Plane32),
/* harmony export */   "PlanePrivate16": () => (/* binding */ PlanePrivate16),
/* harmony export */   "PlanePrivate20": () => (/* binding */ PlanePrivate20),
/* harmony export */   "PlanePrivate24": () => (/* binding */ PlanePrivate24),
/* harmony export */   "PlanePrivate32": () => (/* binding */ PlanePrivate32),
/* harmony export */   "PlaneSea16": () => (/* binding */ PlaneSea16),
/* harmony export */   "PlaneSea20": () => (/* binding */ PlaneSea20),
/* harmony export */   "PlaneSea24": () => (/* binding */ PlaneSea24),
/* harmony export */   "PlaneSea32": () => (/* binding */ PlaneSea32),
/* harmony export */   "Play16": () => (/* binding */ Play16),
/* harmony export */   "Play20": () => (/* binding */ Play20),
/* harmony export */   "Play24": () => (/* binding */ Play24),
/* harmony export */   "Play32": () => (/* binding */ Play32),
/* harmony export */   "PlayFilled16": () => (/* binding */ PlayFilled16),
/* harmony export */   "PlayFilled20": () => (/* binding */ PlayFilled20),
/* harmony export */   "PlayFilled24": () => (/* binding */ PlayFilled24),
/* harmony export */   "PlayFilled32": () => (/* binding */ PlayFilled32),
/* harmony export */   "PlayFilledAlt16": () => (/* binding */ PlayFilledAlt16),
/* harmony export */   "PlayFilledAlt20": () => (/* binding */ PlayFilledAlt20),
/* harmony export */   "PlayFilledAlt24": () => (/* binding */ PlayFilledAlt24),
/* harmony export */   "PlayFilledAlt32": () => (/* binding */ PlayFilledAlt32),
/* harmony export */   "PlayOutline16": () => (/* binding */ PlayOutline16),
/* harmony export */   "PlayOutline20": () => (/* binding */ PlayOutline20),
/* harmony export */   "PlayOutline24": () => (/* binding */ PlayOutline24),
/* harmony export */   "PlayOutline32": () => (/* binding */ PlayOutline32),
/* harmony export */   "PlayOutlineFilled16": () => (/* binding */ PlayOutlineFilled16),
/* harmony export */   "PlayOutlineFilled20": () => (/* binding */ PlayOutlineFilled20),
/* harmony export */   "PlayOutlineFilled24": () => (/* binding */ PlayOutlineFilled24),
/* harmony export */   "PlayOutlineFilled32": () => (/* binding */ PlayOutlineFilled32),
/* harmony export */   "Playlist16": () => (/* binding */ Playlist16),
/* harmony export */   "Playlist20": () => (/* binding */ Playlist20),
/* harmony export */   "Playlist24": () => (/* binding */ Playlist24),
/* harmony export */   "Playlist32": () => (/* binding */ Playlist32),
/* harmony export */   "Plug16": () => (/* binding */ Plug16),
/* harmony export */   "Plug20": () => (/* binding */ Plug20),
/* harmony export */   "Plug24": () => (/* binding */ Plug24),
/* harmony export */   "Plug32": () => (/* binding */ Plug32),
/* harmony export */   "PlugFilled16": () => (/* binding */ PlugFilled16),
/* harmony export */   "PlugFilled20": () => (/* binding */ PlugFilled20),
/* harmony export */   "PlugFilled24": () => (/* binding */ PlugFilled24),
/* harmony export */   "PlugFilled32": () => (/* binding */ PlugFilled32),
/* harmony export */   "Png16": () => (/* binding */ Png16),
/* harmony export */   "Png20": () => (/* binding */ Png20),
/* harmony export */   "Png24": () => (/* binding */ Png24),
/* harmony export */   "Png32": () => (/* binding */ Png32),
/* harmony export */   "PointOfPresence16": () => (/* binding */ PointOfPresence16),
/* harmony export */   "PointOfPresence20": () => (/* binding */ PointOfPresence20),
/* harmony export */   "PointOfPresence24": () => (/* binding */ PointOfPresence24),
/* harmony export */   "PointOfPresence32": () => (/* binding */ PointOfPresence32),
/* harmony export */   "Police24": () => (/* binding */ Police24),
/* harmony export */   "Police32": () => (/* binding */ Police32),
/* harmony export */   "WatsonHealthPetImageB16": () => (/* binding */ WatsonHealthPetImageB16),
/* harmony export */   "WatsonHealthPetImageB20": () => (/* binding */ WatsonHealthPetImageB20),
/* harmony export */   "WatsonHealthPetImageB24": () => (/* binding */ WatsonHealthPetImageB24),
/* harmony export */   "WatsonHealthPetImageB32": () => (/* binding */ WatsonHealthPetImageB32),
/* harmony export */   "WatsonHealthPetImageO16": () => (/* binding */ WatsonHealthPetImageO16),
/* harmony export */   "WatsonHealthPetImageO20": () => (/* binding */ WatsonHealthPetImageO20),
/* harmony export */   "WatsonHealthPetImageO24": () => (/* binding */ WatsonHealthPetImageO24),
/* harmony export */   "WatsonHealthPetImageO32": () => (/* binding */ WatsonHealthPetImageO32),
/* harmony export */   "WatsonHealthPointerText16": () => (/* binding */ WatsonHealthPointerText16),
/* harmony export */   "WatsonHealthPointerText20": () => (/* binding */ WatsonHealthPointerText20),
/* harmony export */   "WatsonHealthPointerText24": () => (/* binding */ WatsonHealthPointerText24),
/* harmony export */   "WatsonHealthPointerText32": () => (/* binding */ WatsonHealthPointerText32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _path65, _path66, _path67, _path68, _path69, _path70, _path71, _path72, _path73, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _circle, _circle2, _circle3, _path113, _circle4, _circle5, _circle6, _path114, _circle7, _circle8, _circle9, _path115, _circle10, _circle11, _circle12, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _circle13, _circle14, _circle15, _path157, _circle16, _circle17, _circle18, _path158, _circle19, _circle20, _circle21, _path159, _circle22, _circle23, _circle24, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _path224, _path225, _path226, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388, _path389, _path390, _path391, _path392, _path393, _path394, _path395, _path396, _path397, _path398, _path399, _path400, _path401, _path402, _path403, _path404, _path405, _path406, _path407, _path408, _path409, _path410, _path411, _path412, _path413, _path414, _path415, _path416, _path417, _path418, _path419, _path420, _path421, _path422, _path423, _path424, _path425, _path426, _path427, _path428, _path429, _path430, _path431, _path432, _path433, _path434, _path435, _path436, _path437, _path438, _path439, _path440, _path441, _path442, _path443, _path444, _path445, _path446, _path447, _path448, _path449, _path450, _path451, _path452;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var PauseOutline32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PauseOutline32(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 10L12 10 12 22 14 22 14 10 14 10zM20 10L18 10 18 22 20 22 20 10 20 10z"
  })), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12,12,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), children);
});
var PauseOutline24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PauseOutline24(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 10L12 10 12 22 14 22 14 10 14 10zM20 10L18 10 18 22 20 22 20 10 20 10z"
  })), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12,12,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), children);
});
var PauseOutline20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PauseOutline20(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 10L12 10 12 22 14 22 14 10 14 10zM20 10L18 10 18 22 20 22 20 10 20 10z"
  })), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12,12,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), children);
});
var PauseOutline16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PauseOutline16(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 5L6 5 6 11 7 11 7 5zM10 5L9 5 9 11 10 11 10 5z"
  })), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,2c3.3,0,6,2.7,6,6s-2.7,6-6,6s-6-2.7-6-6S4.7,2,8,2 M8,1C4.1,1,1,4.1,1,8s3.1,7,7,7s7-3.1,7-7S11.9,1,8,1z"
  })), children);
});
var PauseOutlineFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PauseOutlineFilled32(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM14,22H12V10h2Zm6,0H18V10h2Z"
  })), children);
});
var PauseOutlineFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PauseOutlineFilled24(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM14,22H12V10h2Zm6,0H18V10h2Z"
  })), children);
});
var PauseOutlineFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PauseOutlineFilled20(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM14,22H12V10h2Zm6,0H18V10h2Z"
  })), children);
});
var PauseOutlineFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PauseOutlineFilled16(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,1C4.1,1,1,4.1,1,8s3.1,7,7,7s7-3.1,7-7S11.9,1,8,1z M7,11H6V5h1V11z M10,11H9V5h1V11z"
  })), children);
});
var PauseFuture32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PauseFuture32(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 11L12 11 12 22 14 22 14 11 14 11zM20 11L18 11 18 22 20 22 20 11 20 11z"
  })), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9158,13.9158,0,0,1,26,6.2343V2h2v8H20V8h4.9217A11.9818,11.9818,0,1,0,28,16h2A14,14,0,1,1,16,2Z"
  })), children);
});
var PauseFuture24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PauseFuture24(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 11L12 11 12 22 14 22 14 11 14 11zM20 11L18 11 18 22 20 22 20 11 20 11z"
  })), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9158,13.9158,0,0,1,26,6.2343V2h2v8H20V8h4.9217A11.9818,11.9818,0,1,0,28,16h2A14,14,0,1,1,16,2Z"
  })), children);
});
var PauseFuture20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PauseFuture20(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 11L12 11 12 22 14 22 14 11 14 11zM20 11L18 11 18 22 20 22 20 11 20 11z"
  })), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9158,13.9158,0,0,1,26,6.2343V2h2v8H20V8h4.9217A11.9818,11.9818,0,1,0,28,16h2A14,14,0,1,1,16,2Z"
  })), children);
});
var PauseFuture16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PauseFuture16(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 11L12 11 12 22 14 22 14 11 14 11zM20 11L18 11 18 22 20 22 20 11 20 11z"
  })), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9158,13.9158,0,0,1,26,6.2343V2h2v8H20V8h4.9217A11.9818,11.9818,0,1,0,28,16h2A14,14,0,1,1,16,2Z"
  })), children);
});
var PausePast32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PausePast32(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 11L12 11 12 22 14 22 14 11 14 11zM20 11L18 11 18 22 20 22 20 11 20 11z"
  })), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9158,13.9158,0,0,0,6,6.2343V2H4v8h8V8H7.0783A11.9818,11.9818,0,1,1,4,16H2A14,14,0,1,0,16,2Z"
  })), children);
});
var PausePast24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PausePast24(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 11L12 11 12 22 14 22 14 11 14 11zM20 11L18 11 18 22 20 22 20 11 20 11z"
  })), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9158,13.9158,0,0,0,6,6.2343V2H4v8h8V8H7.0783A11.9818,11.9818,0,1,1,4,16H2A14,14,0,1,0,16,2Z"
  })), children);
});
var PausePast20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PausePast20(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 11L12 11 12 22 14 22 14 11 14 11zM20 11L18 11 18 22 20 22 20 11 20 11z"
  })), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9158,13.9158,0,0,0,6,6.2343V2H4v8h8V8H7.0783A11.9818,11.9818,0,1,1,4,16H2A14,14,0,1,0,16,2Z"
  })), children);
});
var PausePast16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PausePast16(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 11L12 11 12 22 14 22 14 11 14 11zM20 11L18 11 18 22 20 22 20 11 20 11z"
  })), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9158,13.9158,0,0,0,6,6.2343V2H4v8h8V8H7.0783A11.9818,11.9818,0,1,1,4,16H2A14,14,0,1,0,16,2Z"
  })), children);
});
var PcnENode32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PcnENode32(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 11L20 9 12 9 12 23 20 23 20 21 14 21 14 17 19 17 19 15 14 15 14 11 20 11z"
  })), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4141,17.4141a1.9995,1.9995,0,0,0,0-2.8282L24.6272,8.7993l2.9006-2.8628a2.0018,2.0018,0,1,0-1.4416-1.3872L23.2129,7.3848,17.4141,1.5859a1.9995,1.9995,0,0,0-2.8282,0L8.7993,7.3726,5.9368,4.4717A2.002,2.002,0,1,0,4.55,5.9136l2.835,2.8735L1.5859,14.5859a1.9995,1.9995,0,0,0,0,2.8282l5.7989,5.7988L4.55,26.0864a1.9977,1.9977,0,1,0,1.387,1.4419l2.8625-2.9009,5.7866,5.7867a1.9995,1.9995,0,0,0,2.8282,0l5.7988-5.7989,2.8733,2.8355a1.998,1.998,0,1,0,1.4416-1.3872l-2.9006-2.8628ZM16,29,3,16,16,3,29,16Z"
  })), children);
});
var PcnENode24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PcnENode24(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 11L20 9 12 9 12 23 20 23 20 21 14 21 14 17 19 17 19 15 14 15 14 11 20 11z"
  })), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4141,17.4141a1.9995,1.9995,0,0,0,0-2.8282L24.6272,8.7993l2.9006-2.8628a2.0018,2.0018,0,1,0-1.4416-1.3872L23.2129,7.3848,17.4141,1.5859a1.9995,1.9995,0,0,0-2.8282,0L8.7993,7.3726,5.9368,4.4717A2.002,2.002,0,1,0,4.55,5.9136l2.835,2.8735L1.5859,14.5859a1.9995,1.9995,0,0,0,0,2.8282l5.7989,5.7988L4.55,26.0864a1.9977,1.9977,0,1,0,1.387,1.4419l2.8625-2.9009,5.7866,5.7867a1.9995,1.9995,0,0,0,2.8282,0l5.7988-5.7989,2.8733,2.8355a1.998,1.998,0,1,0,1.4416-1.3872l-2.9006-2.8628ZM16,29,3,16,16,3,29,16Z"
  })), children);
});
var PcnENode20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PcnENode20(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 11L20 9 12 9 12 23 20 23 20 21 14 21 14 17 19 17 19 15 14 15 14 11 20 11z"
  })), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4141,17.4141a1.9995,1.9995,0,0,0,0-2.8282L24.6272,8.7993l2.9006-2.8628a2.0018,2.0018,0,1,0-1.4416-1.3872L23.2129,7.3848,17.4141,1.5859a1.9995,1.9995,0,0,0-2.8282,0L8.7993,7.3726,5.9368,4.4717A2.002,2.002,0,1,0,4.55,5.9136l2.835,2.8735L1.5859,14.5859a1.9995,1.9995,0,0,0,0,2.8282l5.7989,5.7988L4.55,26.0864a1.9977,1.9977,0,1,0,1.387,1.4419l2.8625-2.9009,5.7866,5.7867a1.9995,1.9995,0,0,0,2.8282,0l5.7988-5.7989,2.8733,2.8355a1.998,1.998,0,1,0,1.4416-1.3872l-2.9006-2.8628ZM16,29,3,16,16,3,29,16Z"
  })), children);
});
var PcnENode16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PcnENode16(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 11L20 9 12 9 12 23 20 23 20 21 14 21 14 17 19 17 19 15 14 15 14 11 20 11z"
  })), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4141,17.4141a1.9995,1.9995,0,0,0,0-2.8282L24.6272,8.7993l2.9006-2.8628a2.0018,2.0018,0,1,0-1.4416-1.3872L23.2129,7.3848,17.4141,1.5859a1.9995,1.9995,0,0,0-2.8282,0L8.7993,7.3726,5.9368,4.4717A2.002,2.002,0,1,0,4.55,5.9136l2.835,2.8735L1.5859,14.5859a1.9995,1.9995,0,0,0,0,2.8282l5.7989,5.7988L4.55,26.0864a1.9977,1.9977,0,1,0,1.387,1.4419l2.8625-2.9009,5.7866,5.7867a1.9995,1.9995,0,0,0,2.8282,0l5.7988-5.7989,2.8733,2.8355a1.998,1.998,0,1,0,1.4416-1.3872l-2.9006-2.8628ZM16,29,3,16,16,3,29,16Z"
  })), children);
});
var PcnMilitary32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PcnMilitary32(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 16L14.407 19 11 19.414 13.5 21.667 13 25 16 23.125 19 25 18.5 21.667 21 19.414 17.5 19 16 16z"
  })), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.414 17.414L16 13.834 16 13.834 19.588 17.416 21 16 16 11 11 16 12.414 17.414z"
  })), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.414 12.414L16 8.834 16 8.834 19.588 12.416 21 11 16 6 11 11 12.414 12.414z"
  })), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4141,17.4141a1.9995,1.9995,0,0,0,0-2.8282L24.6272,8.7993l2.9006-2.8628a2.0018,2.0018,0,1,0-1.4416-1.3872L23.2129,7.3848,17.4141,1.5859a1.9995,1.9995,0,0,0-2.8282,0L8.7993,7.3726,5.9368,4.4717A2.002,2.002,0,1,0,4.55,5.9136l2.835,2.8735L1.5859,14.5859a1.9995,1.9995,0,0,0,0,2.8282l5.7989,5.7988L4.55,26.0864a1.9977,1.9977,0,1,0,1.387,1.4419l2.8625-2.9009,5.7866,5.7867a1.9995,1.9995,0,0,0,2.8282,0l5.7988-5.7989,2.8733,2.8355a1.998,1.998,0,1,0,1.4416-1.3872l-2.9006-2.8628ZM16,29,3,16,16,3,29,16Z"
  })), children);
});
var PcnMilitary24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PcnMilitary24(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 16L14.407 19 11 19.414 13.5 21.667 13 25 16 23.125 19 25 18.5 21.667 21 19.414 17.5 19 16 16z"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.414 17.414L16 13.834 16 13.834 19.588 17.416 21 16 16 11 11 16 12.414 17.414z"
  })), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.414 12.414L16 8.834 16 8.834 19.588 12.416 21 11 16 6 11 11 12.414 12.414z"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4141,17.4141a1.9995,1.9995,0,0,0,0-2.8282L24.6272,8.7993l2.9006-2.8628a2.0018,2.0018,0,1,0-1.4416-1.3872L23.2129,7.3848,17.4141,1.5859a1.9995,1.9995,0,0,0-2.8282,0L8.7993,7.3726,5.9368,4.4717A2.002,2.002,0,1,0,4.55,5.9136l2.835,2.8735L1.5859,14.5859a1.9995,1.9995,0,0,0,0,2.8282l5.7989,5.7988L4.55,26.0864a1.9977,1.9977,0,1,0,1.387,1.4419l2.8625-2.9009,5.7866,5.7867a1.9995,1.9995,0,0,0,2.8282,0l5.7988-5.7989,2.8733,2.8355a1.998,1.998,0,1,0,1.4416-1.3872l-2.9006-2.8628ZM16,29,3,16,16,3,29,16Z"
  })), children);
});
var PcnMilitary20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PcnMilitary20(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 16L14.407 19 11 19.414 13.5 21.667 13 25 16 23.125 19 25 18.5 21.667 21 19.414 17.5 19 16 16z"
  })), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.414 17.414L16 13.834 16 13.834 19.588 17.416 21 16 16 11 11 16 12.414 17.414z"
  })), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.414 12.414L16 8.834 16 8.834 19.588 12.416 21 11 16 6 11 11 12.414 12.414z"
  })), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4141,17.4141a1.9995,1.9995,0,0,0,0-2.8282L24.6272,8.7993l2.9006-2.8628a2.0018,2.0018,0,1,0-1.4416-1.3872L23.2129,7.3848,17.4141,1.5859a1.9995,1.9995,0,0,0-2.8282,0L8.7993,7.3726,5.9368,4.4717A2.002,2.002,0,1,0,4.55,5.9136l2.835,2.8735L1.5859,14.5859a1.9995,1.9995,0,0,0,0,2.8282l5.7989,5.7988L4.55,26.0864a1.9977,1.9977,0,1,0,1.387,1.4419l2.8625-2.9009,5.7866,5.7867a1.9995,1.9995,0,0,0,2.8282,0l5.7988-5.7989,2.8733,2.8355a1.998,1.998,0,1,0,1.4416-1.3872l-2.9006-2.8628ZM16,29,3,16,16,3,29,16Z"
  })), children);
});
var PcnMilitary16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PcnMilitary16(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 16L14.407 19 11 19.414 13.5 21.667 13 25 16 23.125 19 25 18.5 21.667 21 19.414 17.5 19 16 16z"
  })), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.414 17.414L16 13.834 16 13.834 19.588 17.416 21 16 16 11 11 16 12.414 17.414z"
  })), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.414 12.414L16 8.834 16 8.834 19.588 12.416 21 11 16 6 11 11 12.414 12.414z"
  })), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4141,17.4141a1.9995,1.9995,0,0,0,0-2.8282L24.6272,8.7993l2.9006-2.8628a2.0018,2.0018,0,1,0-1.4416-1.3872L23.2129,7.3848,17.4141,1.5859a1.9995,1.9995,0,0,0-2.8282,0L8.7993,7.3726,5.9368,4.4717A2.002,2.002,0,1,0,4.55,5.9136l2.835,2.8735L1.5859,14.5859a1.9995,1.9995,0,0,0,0,2.8282l5.7989,5.7988L4.55,26.0864a1.9977,1.9977,0,1,0,1.387,1.4419l2.8625-2.9009,5.7866,5.7867a1.9995,1.9995,0,0,0,2.8282,0l5.7988-5.7989,2.8733,2.8355a1.998,1.998,0,1,0,1.4416-1.3872l-2.9006-2.8628ZM16,29,3,16,16,3,29,16Z"
  })), children);
});
var PcnPNode32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PcnPNode32(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,23H12V9h6a2.002,2.002,0,0,1,2,2v5a2.002,2.002,0,0,1-2,2H14Zm0-7h4V10.9985H14Z"
  })), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4141,17.4141a1.9995,1.9995,0,0,0,0-2.8282L24.6272,8.7993l2.9006-2.8628a2.0018,2.0018,0,1,0-1.4416-1.3872L23.2129,7.3848,17.4141,1.5859a1.9995,1.9995,0,0,0-2.8282,0L8.7993,7.3726,5.9368,4.4717A2.002,2.002,0,1,0,4.55,5.9136l2.835,2.8735L1.5859,14.5859a1.9995,1.9995,0,0,0,0,2.8282l5.7989,5.7988L4.55,26.0864a1.9977,1.9977,0,1,0,1.387,1.4419l2.8625-2.9009,5.7866,5.7867a1.9995,1.9995,0,0,0,2.8282,0l5.7988-5.7989,2.8733,2.8355a1.998,1.998,0,1,0,1.4416-1.3872l-2.9006-2.8628ZM16,29,3,16,16,3,29,16Z"
  })), children);
});
var PcnPNode24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PcnPNode24(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,23H12V9h6a2.002,2.002,0,0,1,2,2v5a2.002,2.002,0,0,1-2,2H14Zm0-7h4V10.9985H14Z"
  })), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4141,17.4141a1.9995,1.9995,0,0,0,0-2.8282L24.6272,8.7993l2.9006-2.8628a2.0018,2.0018,0,1,0-1.4416-1.3872L23.2129,7.3848,17.4141,1.5859a1.9995,1.9995,0,0,0-2.8282,0L8.7993,7.3726,5.9368,4.4717A2.002,2.002,0,1,0,4.55,5.9136l2.835,2.8735L1.5859,14.5859a1.9995,1.9995,0,0,0,0,2.8282l5.7989,5.7988L4.55,26.0864a1.9977,1.9977,0,1,0,1.387,1.4419l2.8625-2.9009,5.7866,5.7867a1.9995,1.9995,0,0,0,2.8282,0l5.7988-5.7989,2.8733,2.8355a1.998,1.998,0,1,0,1.4416-1.3872l-2.9006-2.8628ZM16,29,3,16,16,3,29,16Z"
  })), children);
});
var PcnPNode20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PcnPNode20(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,23H12V9h6a2.002,2.002,0,0,1,2,2v5a2.002,2.002,0,0,1-2,2H14Zm0-7h4V10.9985H14Z"
  })), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4141,17.4141a1.9995,1.9995,0,0,0,0-2.8282L24.6272,8.7993l2.9006-2.8628a2.0018,2.0018,0,1,0-1.4416-1.3872L23.2129,7.3848,17.4141,1.5859a1.9995,1.9995,0,0,0-2.8282,0L8.7993,7.3726,5.9368,4.4717A2.002,2.002,0,1,0,4.55,5.9136l2.835,2.8735L1.5859,14.5859a1.9995,1.9995,0,0,0,0,2.8282l5.7989,5.7988L4.55,26.0864a1.9977,1.9977,0,1,0,1.387,1.4419l2.8625-2.9009,5.7866,5.7867a1.9995,1.9995,0,0,0,2.8282,0l5.7988-5.7989,2.8733,2.8355a1.998,1.998,0,1,0,1.4416-1.3872l-2.9006-2.8628ZM16,29,3,16,16,3,29,16Z"
  })), children);
});
var PcnPNode16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PcnPNode16(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,23H12V9h6a2.002,2.002,0,0,1,2,2v5a2.002,2.002,0,0,1-2,2H14Zm0-7h4V10.9985H14Z"
  })), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4141,17.4141a1.9995,1.9995,0,0,0,0-2.8282L24.6272,8.7993l2.9006-2.8628a2.0018,2.0018,0,1,0-1.4416-1.3872L23.2129,7.3848,17.4141,1.5859a1.9995,1.9995,0,0,0-2.8282,0L8.7993,7.3726,5.9368,4.4717A2.002,2.002,0,1,0,4.55,5.9136l2.835,2.8735L1.5859,14.5859a1.9995,1.9995,0,0,0,0,2.8282l5.7989,5.7988L4.55,26.0864a1.9977,1.9977,0,1,0,1.387,1.4419l2.8625-2.9009,5.7866,5.7867a1.9995,1.9995,0,0,0,2.8282,0l5.7988-5.7989,2.8733,2.8355a1.998,1.998,0,1,0,1.4416-1.3872l-2.9006-2.8628ZM16,29,3,16,16,3,29,16Z"
  })), children);
});
var PcnZNode32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PcnZNode32(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L12 9 12 11 18 11 12 21 12 23 20 23 20 21 14 21 20 11 20 9z"
  })), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4141,17.4141a1.9995,1.9995,0,0,0,0-2.8282L24.6272,8.7993l2.9006-2.8628a2.0018,2.0018,0,1,0-1.4416-1.3872L23.2129,7.3848,17.4141,1.5859a1.9995,1.9995,0,0,0-2.8282,0L8.7993,7.3726,5.9368,4.4717A2.002,2.002,0,1,0,4.55,5.9136l2.835,2.8735L1.5859,14.5859a1.9995,1.9995,0,0,0,0,2.8282l5.7989,5.7988L4.55,26.0864a1.9977,1.9977,0,1,0,1.387,1.4419l2.8625-2.9009,5.7866,5.7867a1.9995,1.9995,0,0,0,2.8282,0l5.7988-5.7989,2.8733,2.8355a1.998,1.998,0,1,0,1.4416-1.3872l-2.9006-2.8628ZM16,29,3,16,16,3,29,16Z"
  })), children);
});
var PcnZNode24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PcnZNode24(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L12 9 12 11 18 11 12 21 12 23 20 23 20 21 14 21 20 11 20 9z"
  })), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4141,17.4141a1.9995,1.9995,0,0,0,0-2.8282L24.6272,8.7993l2.9006-2.8628a2.0018,2.0018,0,1,0-1.4416-1.3872L23.2129,7.3848,17.4141,1.5859a1.9995,1.9995,0,0,0-2.8282,0L8.7993,7.3726,5.9368,4.4717A2.002,2.002,0,1,0,4.55,5.9136l2.835,2.8735L1.5859,14.5859a1.9995,1.9995,0,0,0,0,2.8282l5.7989,5.7988L4.55,26.0864a1.9977,1.9977,0,1,0,1.387,1.4419l2.8625-2.9009,5.7866,5.7867a1.9995,1.9995,0,0,0,2.8282,0l5.7988-5.7989,2.8733,2.8355a1.998,1.998,0,1,0,1.4416-1.3872l-2.9006-2.8628ZM16,29,3,16,16,3,29,16Z"
  })), children);
});
var PcnZNode20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PcnZNode20(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L12 9 12 11 18 11 12 21 12 23 20 23 20 21 14 21 20 11 20 9z"
  })), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4141,17.4141a1.9995,1.9995,0,0,0,0-2.8282L24.6272,8.7993l2.9006-2.8628a2.0018,2.0018,0,1,0-1.4416-1.3872L23.2129,7.3848,17.4141,1.5859a1.9995,1.9995,0,0,0-2.8282,0L8.7993,7.3726,5.9368,4.4717A2.002,2.002,0,1,0,4.55,5.9136l2.835,2.8735L1.5859,14.5859a1.9995,1.9995,0,0,0,0,2.8282l5.7989,5.7988L4.55,26.0864a1.9977,1.9977,0,1,0,1.387,1.4419l2.8625-2.9009,5.7866,5.7867a1.9995,1.9995,0,0,0,2.8282,0l5.7988-5.7989,2.8733,2.8355a1.998,1.998,0,1,0,1.4416-1.3872l-2.9006-2.8628ZM16,29,3,16,16,3,29,16Z"
  })), children);
});
var PcnZNode16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PcnZNode16(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L12 9 12 11 18 11 12 21 12 23 20 23 20 21 14 21 20 11 20 9z"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.4141,17.4141a1.9995,1.9995,0,0,0,0-2.8282L24.6272,8.7993l2.9006-2.8628a2.0018,2.0018,0,1,0-1.4416-1.3872L23.2129,7.3848,17.4141,1.5859a1.9995,1.9995,0,0,0-2.8282,0L8.7993,7.3726,5.9368,4.4717A2.002,2.002,0,1,0,4.55,5.9136l2.835,2.8735L1.5859,14.5859a1.9995,1.9995,0,0,0,0,2.8282l5.7989,5.7988L4.55,26.0864a1.9977,1.9977,0,1,0,1.387,1.4419l2.8625-2.9009,5.7866,5.7867a1.9995,1.9995,0,0,0,2.8282,0l5.7988-5.7989,2.8733,2.8355a1.998,1.998,0,1,0,1.4416-1.3872l-2.9006-2.8628ZM16,29,3,16,16,3,29,16Z"
  })), children);
});
var Pdf32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pdf32(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 11L30 9 22 9 22 23 24 23 24 17 29 17 29 15 24 15 24 11 30 11zM8 9H2V23H4V18H8a2 2 0 002-2V11A2 2 0 008 9zm0 7H4V11H8zM16 23H12V9h4a4 4 0 014 4v6A4 4 0 0116 23zm-2-2h2a2 2 0 002-2V13a2 2 0 00-2-2H14z"
  })), children);
});
var Pdf24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pdf24(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 11L30 9 22 9 22 23 24 23 24 17 29 17 29 15 24 15 24 11 30 11zM8 9H2V23H4V18H8a2 2 0 002-2V11A2 2 0 008 9zm0 7H4V11H8zM16 23H12V9h4a4 4 0 014 4v6A4 4 0 0116 23zm-2-2h2a2 2 0 002-2V13a2 2 0 00-2-2H14z"
  })), children);
});
var Pdf20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pdf20(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 11L30 9 22 9 22 23 24 23 24 17 29 17 29 15 24 15 24 11 30 11zM8 9H2V23H4V18H8a2 2 0 002-2V11A2 2 0 008 9zm0 7H4V11H8zM16 23H12V9h4a4 4 0 014 4v6A4 4 0 0116 23zm-2-2h2a2 2 0 002-2V13a2 2 0 00-2-2H14z"
  })), children);
});
var Pdf16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pdf16(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 11L30 9 22 9 22 23 24 23 24 17 29 17 29 15 24 15 24 11 30 11zM8 9H2V23H4V18H8a2 2 0 002-2V11A2 2 0 008 9zm0 7H4V11H8zM16 23H12V9h4a4 4 0 014 4v6A4 4 0 0116 23zm-2-2h2a2 2 0 002-2V13a2 2 0 00-2-2H14z"
  })), children);
});
var PdfReference32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PdfReference32(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM22 16L24 16 24 10 29 10 29 8 24 8 24 4 30 4 30 2 22 2 22 16zM16 2H12V16h4a4 4 0 004-4V6A4 4 0 0016 2zm2 10a2 2 0 01-2 2H14V4h2a2 2 0 012 2zM8 2H2V16H4V11H8a2 2 0 002-2V4A2 2 0 008 2zM8 9H4V4H8z"
  })), children);
});
var PdfReference24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PdfReference24(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM22 16L24 16 24 10 29 10 29 8 24 8 24 4 30 4 30 2 22 2 22 16zM16 2H12V16h4a4 4 0 004-4V6A4 4 0 0016 2zm2 10a2 2 0 01-2 2H14V4h2a2 2 0 012 2zM8 2H2V16H4V11H8a2 2 0 002-2V4A2 2 0 008 2zM8 9H4V4H8z"
  })), children);
});
var PdfReference20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PdfReference20(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM22 16L24 16 24 10 29 10 29 8 24 8 24 4 30 4 30 2 22 2 22 16zM16 2H12V16h4a4 4 0 004-4V6A4 4 0 0016 2zm2 10a2 2 0 01-2 2H14V4h2a2 2 0 012 2zM8 2H2V16H4V11H8a2 2 0 002-2V4A2 2 0 008 2zM8 9H4V4H8z"
  })), children);
});
var PdfReference16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PdfReference16(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM22 16L24 16 24 10 29 10 29 8 24 8 24 4 30 4 30 2 22 2 22 16zM16 2H12V16h4a4 4 0 004-4V6A4 4 0 0016 2zm2 10a2 2 0 01-2 2H14V4h2a2 2 0 012 2zM8 2H2V16H4V11H8a2 2 0 002-2V4A2 2 0 008 2zM8 9H4V4H8z"
  })), children);
});
var Pedestrian32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pedestrian32(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.6772,14l-1.2456-3.1143A2.9861,2.9861,0,0,0,17.646,9H13.5542a3.0018,3.0018,0,0,0-1.5439.4277L7,12.4336V18H9V13.5664l3-1.8V23.6973L8.5383,28.8906,10.2024,30,14,24.3027V11h3.646a.9949.9949,0,0,1,.9282.6289L20.3228,16H26V14Z"
  })), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.051 18.316L19 24.162 19 30 21 30 21 23.838 18.949 17.684 17.051 18.316zM16.5 8A3.5 3.5 0 1120 4.5 3.5042 3.5042 0 0116.5 8zm0-5A1.5 1.5 0 1018 4.5 1.5017 1.5017 0 0016.5 3z"
  })), children);
});
var Pedestrian24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pedestrian24(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.6772,14l-1.2456-3.1143A2.9861,2.9861,0,0,0,17.646,9H13.5542a3.0018,3.0018,0,0,0-1.5439.4277L7,12.4336V18H9V13.5664l3-1.8V23.6973L8.5383,28.8906,10.2024,30,14,24.3027V11h3.646a.9949.9949,0,0,1,.9282.6289L20.3228,16H26V14Z"
  })), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.051 18.316L19 24.162 19 30 21 30 21 23.838 18.949 17.684 17.051 18.316zM16.5 8A3.5 3.5 0 1120 4.5 3.5042 3.5042 0 0116.5 8zm0-5A1.5 1.5 0 1018 4.5 1.5017 1.5017 0 0016.5 3z"
  })), children);
});
var Pedestrian20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pedestrian20(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.6772,14l-1.2456-3.1143A2.9861,2.9861,0,0,0,17.646,9H13.5542a3.0018,3.0018,0,0,0-1.5439.4277L7,12.4336V18H9V13.5664l3-1.8V23.6973L8.5383,28.8906,10.2024,30,14,24.3027V11h3.646a.9949.9949,0,0,1,.9282.6289L20.3228,16H26V14Z"
  })), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.051 18.316L19 24.162 19 30 21 30 21 23.838 18.949 17.684 17.051 18.316zM16.5 8A3.5 3.5 0 1120 4.5 3.5042 3.5042 0 0116.5 8zm0-5A1.5 1.5 0 1018 4.5 1.5017 1.5017 0 0016.5 3z"
  })), children);
});
var Pedestrian16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pedestrian16(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.6772,14l-1.2456-3.1143A2.9861,2.9861,0,0,0,17.646,9H13.5542a3.0018,3.0018,0,0,0-1.5439.4277L7,12.4336V18H9V13.5664l3-1.8V23.6973L8.5383,28.8906,10.2024,30,14,24.3027V11h3.646a.9949.9949,0,0,1,.9282.6289L20.3228,16H26V14Z"
  })), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.051 18.316L19 24.162 19 30 21 30 21 23.838 18.949 17.684 17.051 18.316zM16.5 8A3.5 3.5 0 1120 4.5 3.5042 3.5042 0 0116.5 8zm0-5A1.5 1.5 0 1018 4.5 1.5017 1.5017 0 0016.5 3z"
  })), children);
});
var PedestrianFamily32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PedestrianFamily32(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 30H17a2.0021 2.0021 0 01-2-2V23h2v5h3V23h2V19a1.0011 1.0011 0 00-1-1H12.2793l-2-6H4a1.0011 1.0011 0 00-1 1v6H5v9H9V21h2v7a2.0021 2.0021 0 01-2 2H5a2.0021 2.0021 0 01-2-2V21a2.0021 2.0021 0 01-2-2V13a3.0033 3.0033 0 013-3h6.2793a1.998 1.998 0 011.8975 1.3674L13.7207 16H21a3.0033 3.0033 0 013 3v4a2.0021 2.0021 0 01-2 2v3A2.0021 2.0021 0 0120 30zM28 30H26V19h3V13a1.0011 1.0011 0 00-1-1H24V10h4a3.0033 3.0033 0 013 3v6a2.0021 2.0021 0 01-2 2H28zM7 9a4 4 0 114-4A4.0045 4.0045 0 017 9zM7 3A2 2 0 109 5 2.0021 2.0021 0 007 3zM25 9a4 4 0 114-4A4.0045 4.0045 0 0125 9zm0-6a2 2 0 102 2A2.0021 2.0021 0 0025 3z"
  })), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.5,15A3.5,3.5,0,1,1,22,11.5,3.5041,3.5041,0,0,1,18.5,15Zm0-5A1.5,1.5,0,1,0,20,11.5,1.5017,1.5017,0,0,0,18.5,10Z"
  })), children);
});
var PedestrianFamily24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PedestrianFamily24(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 30H17a2.0021 2.0021 0 01-2-2V23h2v5h3V23h2V19a1.0011 1.0011 0 00-1-1H12.2793l-2-6H4a1.0011 1.0011 0 00-1 1v6H5v9H9V21h2v7a2.0021 2.0021 0 01-2 2H5a2.0021 2.0021 0 01-2-2V21a2.0021 2.0021 0 01-2-2V13a3.0033 3.0033 0 013-3h6.2793a1.998 1.998 0 011.8975 1.3674L13.7207 16H21a3.0033 3.0033 0 013 3v4a2.0021 2.0021 0 01-2 2v3A2.0021 2.0021 0 0120 30zM28 30H26V19h3V13a1.0011 1.0011 0 00-1-1H24V10h4a3.0033 3.0033 0 013 3v6a2.0021 2.0021 0 01-2 2H28zM7 9a4 4 0 114-4A4.0045 4.0045 0 017 9zM7 3A2 2 0 109 5 2.0021 2.0021 0 007 3zM25 9a4 4 0 114-4A4.0045 4.0045 0 0125 9zm0-6a2 2 0 102 2A2.0021 2.0021 0 0025 3z"
  })), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.5,15A3.5,3.5,0,1,1,22,11.5,3.5041,3.5041,0,0,1,18.5,15Zm0-5A1.5,1.5,0,1,0,20,11.5,1.5017,1.5017,0,0,0,18.5,10Z"
  })), children);
});
var PedestrianFamily20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PedestrianFamily20(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 30H17a2.0021 2.0021 0 01-2-2V23h2v5h3V23h2V19a1.0011 1.0011 0 00-1-1H12.2793l-2-6H4a1.0011 1.0011 0 00-1 1v6H5v9H9V21h2v7a2.0021 2.0021 0 01-2 2H5a2.0021 2.0021 0 01-2-2V21a2.0021 2.0021 0 01-2-2V13a3.0033 3.0033 0 013-3h6.2793a1.998 1.998 0 011.8975 1.3674L13.7207 16H21a3.0033 3.0033 0 013 3v4a2.0021 2.0021 0 01-2 2v3A2.0021 2.0021 0 0120 30zM28 30H26V19h3V13a1.0011 1.0011 0 00-1-1H24V10h4a3.0033 3.0033 0 013 3v6a2.0021 2.0021 0 01-2 2H28zM7 9a4 4 0 114-4A4.0045 4.0045 0 017 9zM7 3A2 2 0 109 5 2.0021 2.0021 0 007 3zM25 9a4 4 0 114-4A4.0045 4.0045 0 0125 9zm0-6a2 2 0 102 2A2.0021 2.0021 0 0025 3z"
  })), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.5,15A3.5,3.5,0,1,1,22,11.5,3.5041,3.5041,0,0,1,18.5,15Zm0-5A1.5,1.5,0,1,0,20,11.5,1.5017,1.5017,0,0,0,18.5,10Z"
  })), children);
});
var PedestrianFamily16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PedestrianFamily16(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 30H17a2.0021 2.0021 0 01-2-2V23h2v5h3V23h2V19a1.0011 1.0011 0 00-1-1H12.2793l-2-6H4a1.0011 1.0011 0 00-1 1v6H5v9H9V21h2v7a2.0021 2.0021 0 01-2 2H5a2.0021 2.0021 0 01-2-2V21a2.0021 2.0021 0 01-2-2V13a3.0033 3.0033 0 013-3h6.2793a1.998 1.998 0 011.8975 1.3674L13.7207 16H21a3.0033 3.0033 0 013 3v4a2.0021 2.0021 0 01-2 2v3A2.0021 2.0021 0 0120 30zM28 30H26V19h3V13a1.0011 1.0011 0 00-1-1H24V10h4a3.0033 3.0033 0 013 3v6a2.0021 2.0021 0 01-2 2H28zM7 9a4 4 0 114-4A4.0045 4.0045 0 017 9zM7 3A2 2 0 109 5 2.0021 2.0021 0 007 3zM25 9a4 4 0 114-4A4.0045 4.0045 0 0125 9zm0-6a2 2 0 102 2A2.0021 2.0021 0 0025 3z"
  })), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.5,15A3.5,3.5,0,1,1,22,11.5,3.5041,3.5041,0,0,1,18.5,15Zm0-5A1.5,1.5,0,1,0,20,11.5,1.5017,1.5017,0,0,0,18.5,10Z"
  })), children);
});
var PedestrianChild32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PedestrianChild32(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,16H17.4683l-5-6H5a3.0033,3.0033,0,0,0-3,3v6a2.0023,2.0023,0,0,0,2,2v7a2.0023,2.0023,0,0,0,2,2h4a2.0023,2.0023,0,0,0,2-2V21H10v7H6V19H4V13a1.0009,1.0009,0,0,1,1-1h6.5317l5,6H26a1.0009,1.0009,0,0,1,1,1v3H25v6H22V22H20v6a2.0023,2.0023,0,0,0,2,2h3a2.0023,2.0023,0,0,0,2-2V24a2.0023,2.0023,0,0,0,2-2V19A3.0033,3.0033,0,0,0,26,16Z"
  })), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 15A3.5 3.5 0 1127 11.5 3.5042 3.5042 0 0123.5 15zm0-5A1.5 1.5 0 1025 11.5 1.5017 1.5017 0 0023.5 10zM8 9a4 4 0 114-4A4.0042 4.0042 0 018 9zM8 3a2 2 0 102 2A2.0023 2.0023 0 008 3z"
  })), children);
});
var PedestrianChild24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PedestrianChild24(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,16H17.4683l-5-6H5a3.0033,3.0033,0,0,0-3,3v6a2.0023,2.0023,0,0,0,2,2v7a2.0023,2.0023,0,0,0,2,2h4a2.0023,2.0023,0,0,0,2-2V21H10v7H6V19H4V13a1.0009,1.0009,0,0,1,1-1h6.5317l5,6H26a1.0009,1.0009,0,0,1,1,1v3H25v6H22V22H20v6a2.0023,2.0023,0,0,0,2,2h3a2.0023,2.0023,0,0,0,2-2V24a2.0023,2.0023,0,0,0,2-2V19A3.0033,3.0033,0,0,0,26,16Z"
  })), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 15A3.5 3.5 0 1127 11.5 3.5042 3.5042 0 0123.5 15zm0-5A1.5 1.5 0 1025 11.5 1.5017 1.5017 0 0023.5 10zM8 9a4 4 0 114-4A4.0042 4.0042 0 018 9zM8 3a2 2 0 102 2A2.0023 2.0023 0 008 3z"
  })), children);
});
var PedestrianChild20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PedestrianChild20(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,16H17.4683l-5-6H5a3.0033,3.0033,0,0,0-3,3v6a2.0023,2.0023,0,0,0,2,2v7a2.0023,2.0023,0,0,0,2,2h4a2.0023,2.0023,0,0,0,2-2V21H10v7H6V19H4V13a1.0009,1.0009,0,0,1,1-1h6.5317l5,6H26a1.0009,1.0009,0,0,1,1,1v3H25v6H22V22H20v6a2.0023,2.0023,0,0,0,2,2h3a2.0023,2.0023,0,0,0,2-2V24a2.0023,2.0023,0,0,0,2-2V19A3.0033,3.0033,0,0,0,26,16Z"
  })), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 15A3.5 3.5 0 1127 11.5 3.5042 3.5042 0 0123.5 15zm0-5A1.5 1.5 0 1025 11.5 1.5017 1.5017 0 0023.5 10zM8 9a4 4 0 114-4A4.0042 4.0042 0 018 9zM8 3a2 2 0 102 2A2.0023 2.0023 0 008 3z"
  })), children);
});
var PedestrianChild16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PedestrianChild16(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,16H17.4683l-5-6H5a3.0033,3.0033,0,0,0-3,3v6a2.0023,2.0023,0,0,0,2,2v7a2.0023,2.0023,0,0,0,2,2h4a2.0023,2.0023,0,0,0,2-2V21H10v7H6V19H4V13a1.0009,1.0009,0,0,1,1-1h6.5317l5,6H26a1.0009,1.0009,0,0,1,1,1v3H25v6H22V22H20v6a2.0023,2.0023,0,0,0,2,2h3a2.0023,2.0023,0,0,0,2-2V24a2.0023,2.0023,0,0,0,2-2V19A3.0033,3.0033,0,0,0,26,16Z"
  })), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 15A3.5 3.5 0 1127 11.5 3.5042 3.5042 0 0123.5 15zm0-5A1.5 1.5 0 1025 11.5 1.5017 1.5017 0 0023.5 10zM8 9a4 4 0 114-4A4.0042 4.0042 0 018 9zM8 3a2 2 0 102 2A2.0023 2.0023 0 008 3z"
  })), children);
});
var Pen32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pen32(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.3069,6.1069,30,3.4141,28.5859,2,25.8931,4.6929,24.8,3.6a1.9328,1.9328,0,0,0-2.8,0L4,21.6V28h6.4l18-18a1.9329,1.9329,0,0,0,0-2.8ZM9.6,26H6V22.4L23.4,5,27,8.6Z"
  })), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.136 7.5H18.863999999999997V9.5H8.136z",
    transform: "rotate(-45 13.5 8.5)"
  })), children);
});
var Pen24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pen24(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.3069,6.1069,30,3.4141,28.5859,2,25.8931,4.6929,24.8,3.6a1.9328,1.9328,0,0,0-2.8,0L4,21.6V28h6.4l18-18a1.9329,1.9329,0,0,0,0-2.8ZM9.6,26H6V22.4L23.4,5,27,8.6Z"
  })), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.136 7.5H18.863999999999997V9.5H8.136z",
    transform: "rotate(-45 13.5 8.5)"
  })), children);
});
var Pen20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pen20(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.3069,6.1069,30,3.4141,28.5859,2,25.8931,4.6929,24.8,3.6a1.9328,1.9328,0,0,0-2.8,0L4,21.6V28h6.4l18-18a1.9329,1.9329,0,0,0,0-2.8ZM9.6,26H6V22.4L23.4,5,27,8.6Z"
  })), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.136 7.5H18.863999999999997V9.5H8.136z",
    transform: "rotate(-45 13.5 8.5)"
  })), children);
});
var Pen16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pen16(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.3069,6.1069,30,3.4141,28.5859,2,25.8931,4.6929,24.8,3.6a1.9328,1.9328,0,0,0-2.8,0L4,21.6V28h6.4l18-18a1.9329,1.9329,0,0,0,0-2.8ZM9.6,26H6V22.4L23.4,5,27,8.6Z"
  })), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.136 7.5H18.863999999999997V9.5H8.136z",
    transform: "rotate(-45 13.5 8.5)"
  })), children);
});
var PenFountain32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PenFountain32(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707,5.293l-3-3a.9994.9994,0,0,0-1.414,0L19.5859,8H17.0947A11.0118,11.0118,0,0,0,6.7124,15.3662L2.0562,28.67a1,1,0,0,0,1.2744,1.2739l13.3037-4.6562A11.012,11.012,0,0,0,24,14.9053V12.4141L29.707,6.707A.9994.9994,0,0,0,29.707,5.293Zm-7.414,6A1,1,0,0,0,22,12v2.9053A9.01,9.01,0,0,1,15.9731,23.4l-9.1677,3.209L16,17.4141,14.5859,16,5.3914,25.1948,8.6,16.0269A9.01,9.01,0,0,1,17.0947,10H20a1,1,0,0,0,.707-.293L26,4.4141,27.5859,6Z"
  })), children);
});
var PenFountain24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PenFountain24(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707,5.293l-3-3a.9994.9994,0,0,0-1.414,0L19.5859,8H17.0947A11.0118,11.0118,0,0,0,6.7124,15.3662L2.0562,28.67a1,1,0,0,0,1.2744,1.2739l13.3037-4.6562A11.012,11.012,0,0,0,24,14.9053V12.4141L29.707,6.707A.9994.9994,0,0,0,29.707,5.293Zm-7.414,6A1,1,0,0,0,22,12v2.9053A9.01,9.01,0,0,1,15.9731,23.4l-9.1677,3.209L16,17.4141,14.5859,16,5.3914,25.1948,8.6,16.0269A9.01,9.01,0,0,1,17.0947,10H20a1,1,0,0,0,.707-.293L26,4.4141,27.5859,6Z"
  })), children);
});
var PenFountain20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PenFountain20(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707,5.293l-3-3a.9994.9994,0,0,0-1.414,0L19.5859,8H17.0947A11.0118,11.0118,0,0,0,6.7124,15.3662L2.0562,28.67a1,1,0,0,0,1.2744,1.2739l13.3037-4.6562A11.012,11.012,0,0,0,24,14.9053V12.4141L29.707,6.707A.9994.9994,0,0,0,29.707,5.293Zm-7.414,6A1,1,0,0,0,22,12v2.9053A9.01,9.01,0,0,1,15.9731,23.4l-9.1677,3.209L16,17.4141,14.5859,16,5.3914,25.1948,8.6,16.0269A9.01,9.01,0,0,1,17.0947,10H20a1,1,0,0,0,.707-.293L26,4.4141,27.5859,6Z"
  })), children);
});
var PenFountain16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PenFountain16(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707,5.293l-3-3a.9994.9994,0,0,0-1.414,0L19.5859,8H17.0947A11.0118,11.0118,0,0,0,6.7124,15.3662L2.0562,28.67a1,1,0,0,0,1.2744,1.2739l13.3037-4.6562A11.012,11.012,0,0,0,24,14.9053V12.4141L29.707,6.707A.9994.9994,0,0,0,29.707,5.293Zm-7.414,6A1,1,0,0,0,22,12v2.9053A9.01,9.01,0,0,1,15.9731,23.4l-9.1677,3.209L16,17.4141,14.5859,16,5.3914,25.1948,8.6,16.0269A9.01,9.01,0,0,1,17.0947,10H20a1,1,0,0,0,.707-.293L26,4.4141,27.5859,6Z"
  })), children);
});
var Pending32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pending32(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "16",
    r: "2"
  })), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "16",
    r: "2"
  })), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var Pending24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pending24(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "16",
    r: "2"
  })), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "16",
    r: "2"
  })), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var Pending20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pending20(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "16",
    r: "2"
  })), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "16",
    r: "2"
  })), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var Pending16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pending16(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "16",
    r: "2"
  })), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "16",
    r: "2"
  })), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var PendingFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PendingFilled32(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM8,18a2,2,0,1,1,2-2A2,2,0,0,1,8,18Zm8,0a2,2,0,1,1,2-2A2,2,0,0,1,16,18Zm8,0a2,2,0,1,1,2-2A2,2,0,0,1,24,18Z"
  })), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M10,16a2,2,0,1,1-2-2A2,2,0,0,1,10,16Zm6-2a2,2,0,1,0,2,2A2,2,0,0,0,16,14Zm8,0a2,2,0,1,0,2,2A2,2,0,0,0,24,14Z",
    "data-icon-path": "inner-path"
  })), children);
});
var PendingFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PendingFilled24(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM8,18a2,2,0,1,1,2-2A2,2,0,0,1,8,18Zm8,0a2,2,0,1,1,2-2A2,2,0,0,1,16,18Zm8,0a2,2,0,1,1,2-2A2,2,0,0,1,24,18Z"
  })), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M10,16a2,2,0,1,1-2-2A2,2,0,0,1,10,16Zm6-2a2,2,0,1,0,2,2A2,2,0,0,0,16,14Zm8,0a2,2,0,1,0,2,2A2,2,0,0,0,24,14Z",
    "data-icon-path": "inner-path"
  })), children);
});
var PendingFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PendingFilled20(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM8,18a2,2,0,1,1,2-2A2,2,0,0,1,8,18Zm8,0a2,2,0,1,1,2-2A2,2,0,0,1,16,18Zm8,0a2,2,0,1,1,2-2A2,2,0,0,1,24,18Z"
  })), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M10,16a2,2,0,1,1-2-2A2,2,0,0,1,10,16Zm6-2a2,2,0,1,0,2,2A2,2,0,0,0,16,14Zm8,0a2,2,0,1,0,2,2A2,2,0,0,0,24,14Z",
    "data-icon-path": "inner-path"
  })), children);
});
var PendingFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PendingFilled16(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM8,18a2,2,0,1,1,2-2A2,2,0,0,1,8,18Zm8,0a2,2,0,1,1,2-2A2,2,0,0,1,16,18Zm8,0a2,2,0,1,1,2-2A2,2,0,0,1,24,18Z"
  })), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M10,16a2,2,0,1,1-2-2A2,2,0,0,1,10,16Zm6-2a2,2,0,1,0,2,2A2,2,0,0,0,16,14Zm8,0a2,2,0,1,0,2,2A2,2,0,0,0,24,14Z",
    "data-icon-path": "inner-path"
  })), children);
});
var Percentage32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Percentage32(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,14a5,5,0,1,1,5-5A5.0055,5.0055,0,0,1,9,14ZM9,6a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,9,6Z"
  })), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M0.029 15H31.97V17H0.029z",
    transform: "rotate(-45 16 16)"
  })), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,28a5,5,0,1,1,5-5A5.0055,5.0055,0,0,1,23,28Zm0-8a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,23,20Z"
  })), children);
});
var Percentage24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Percentage24(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,14a5,5,0,1,1,5-5A5.0055,5.0055,0,0,1,9,14ZM9,6a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,9,6Z"
  })), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M0.029 15H31.97V17H0.029z",
    transform: "rotate(-45 16 16)"
  })), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,28a5,5,0,1,1,5-5A5.0055,5.0055,0,0,1,23,28Zm0-8a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,23,20Z"
  })), children);
});
var Percentage20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Percentage20(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,14a5,5,0,1,1,5-5A5.0055,5.0055,0,0,1,9,14ZM9,6a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,9,6Z"
  })), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M0.029 15H31.97V17H0.029z",
    transform: "rotate(-45 16 16)"
  })), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,28a5,5,0,1,1,5-5A5.0055,5.0055,0,0,1,23,28Zm0-8a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,23,20Z"
  })), children);
});
var Percentage16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Percentage16(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,14a5,5,0,1,1,5-5A5.0055,5.0055,0,0,1,9,14ZM9,6a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,9,6Z"
  })), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M0.029 15H31.97V17H0.029z",
    transform: "rotate(-45 16 16)"
  })), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,28a5,5,0,1,1,5-5A5.0055,5.0055,0,0,1,23,28Zm0-8a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,23,20Z"
  })), children);
});
var PercentageFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PercentageFilled32(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,14a5,5,0,1,1,5-5A5.0055,5.0055,0,0,1,9,14Z"
  })), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M0.029 15H31.97V17H0.029z",
    transform: "rotate(-45 16 16)"
  })), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,28a5,5,0,1,1,5-5A5.0055,5.0055,0,0,1,23,28Z"
  })), children);
});
var PercentageFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PercentageFilled24(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,14a5,5,0,1,1,5-5A5.0055,5.0055,0,0,1,9,14Z"
  })), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M0.029 15H31.97V17H0.029z",
    transform: "rotate(-45 16 16)"
  })), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,28a5,5,0,1,1,5-5A5.0055,5.0055,0,0,1,23,28Z"
  })), children);
});
var PercentageFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PercentageFilled20(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,14a5,5,0,1,1,5-5A5.0055,5.0055,0,0,1,9,14Z"
  })), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M0.029 15H31.97V17H0.029z",
    transform: "rotate(-45 16 16)"
  })), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,28a5,5,0,1,1,5-5A5.0055,5.0055,0,0,1,23,28Z"
  })), children);
});
var PercentageFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PercentageFilled16(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,14a5,5,0,1,1,5-5A5.0055,5.0055,0,0,1,9,14Z"
  })), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M0.029 15H31.97V17H0.029z",
    transform: "rotate(-45 16 16)"
  })), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,28a5,5,0,1,1,5-5A5.0055,5.0055,0,0,1,23,28Z"
  })), children);
});
var Person32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Person32(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 30H14a2 2 0 01-2-2V21a2 2 0 01-2-2V13a3 3 0 013-3h6a3 3 0 013 3v6a2 2 0 01-2 2v7A2 2 0 0118 30zM13 12a.94.94 0 00-1 1v6h2v9h4V19h2V13a.94.94 0 00-1-1zM16 9a4 4 0 114-4h0A4 4 0 0116 9zm0-6a2 2 0 102 2h0a2 2 0 00-2-2z"
  })), children);
});
var Person24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Person24(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 30H14a2 2 0 01-2-2V21a2 2 0 01-2-2V13a3 3 0 013-3h6a3 3 0 013 3v6a2 2 0 01-2 2v7A2 2 0 0118 30zM13 12a.94.94 0 00-1 1v6h2v9h4V19h2V13a.94.94 0 00-1-1zM16 9a4 4 0 114-4h0A4 4 0 0116 9zm0-6a2 2 0 102 2h0a2 2 0 00-2-2z"
  })), children);
});
var Person20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Person20(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 30H14a2 2 0 01-2-2V21a2 2 0 01-2-2V13a3 3 0 013-3h6a3 3 0 013 3v6a2 2 0 01-2 2v7A2 2 0 0118 30zM13 12a.94.94 0 00-1 1v6h2v9h4V19h2V13a.94.94 0 00-1-1zM16 9a4 4 0 114-4h0A4 4 0 0116 9zm0-6a2 2 0 102 2h0a2 2 0 00-2-2z"
  })), children);
});
var Person16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Person16(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 30H14a2 2 0 01-2-2V21a2 2 0 01-2-2V13a3 3 0 013-3h6a3 3 0 013 3v6a2 2 0 01-2 2v7A2 2 0 0118 30zM13 12a.94.94 0 00-1 1v6h2v9h4V19h2V13a.94.94 0 00-1-1zM16 9a4 4 0 114-4h0A4 4 0 0116 9zm0-6a2 2 0 102 2h0a2 2 0 00-2-2z"
  })), children);
});
var PersonFavorite32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PersonFavorite32(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 31H6a2.0059 2.0059 0 01-2-2V22a2.0059 2.0059 0 01-2-2V14a2.9465 2.9465 0 013-3h6a2.9465 2.9465 0 013 3v6a2.0059 2.0059 0 01-2 2v7A2.0059 2.0059 0 0110 31zM5 13a.9448.9448 0 00-1 1v6H6v9h4V20h2V14a.9448.9448 0 00-1-1zM8 10a4 4 0 114-4A4.0045 4.0045 0 018 10zM8 4a2 2 0 102 2A2.002 2.002 0 008 4zM28.7663 4.2558A4.2121 4.2121 0 0023 4.0321a4.2121 4.2121 0 00-5.7663.2237 4.319 4.319 0 000 6.0447L22.998 16.14 23 16.1376l.002.0019 5.7643-5.839A4.319 4.319 0 0028.7663 4.2558zM27.342 8.8948l-4.34 4.3973L23 13.29l-.002.002-4.34-4.3973a2.3085 2.3085 0 010-3.2338 2.2639 2.2639 0 013.1561 0l1.181 1.2074L23 6.8634l.0049.005 1.181-1.2074a2.2639 2.2639 0 013.1561 0A2.3085 2.3085 0 0127.342 8.8948z"
  })), children);
});
var PersonFavorite24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PersonFavorite24(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 31H6a2.0059 2.0059 0 01-2-2V22a2.0059 2.0059 0 01-2-2V14a2.9465 2.9465 0 013-3h6a2.9465 2.9465 0 013 3v6a2.0059 2.0059 0 01-2 2v7A2.0059 2.0059 0 0110 31zM5 13a.9448.9448 0 00-1 1v6H6v9h4V20h2V14a.9448.9448 0 00-1-1zM8 10a4 4 0 114-4A4.0045 4.0045 0 018 10zM8 4a2 2 0 102 2A2.002 2.002 0 008 4zM28.7663 4.2558A4.2121 4.2121 0 0023 4.0321a4.2121 4.2121 0 00-5.7663.2237 4.319 4.319 0 000 6.0447L22.998 16.14 23 16.1376l.002.0019 5.7643-5.839A4.319 4.319 0 0028.7663 4.2558zM27.342 8.8948l-4.34 4.3973L23 13.29l-.002.002-4.34-4.3973a2.3085 2.3085 0 010-3.2338 2.2639 2.2639 0 013.1561 0l1.181 1.2074L23 6.8634l.0049.005 1.181-1.2074a2.2639 2.2639 0 013.1561 0A2.3085 2.3085 0 0127.342 8.8948z"
  })), children);
});
var PersonFavorite20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PersonFavorite20(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 31H6a2.0059 2.0059 0 01-2-2V22a2.0059 2.0059 0 01-2-2V14a2.9465 2.9465 0 013-3h6a2.9465 2.9465 0 013 3v6a2.0059 2.0059 0 01-2 2v7A2.0059 2.0059 0 0110 31zM5 13a.9448.9448 0 00-1 1v6H6v9h4V20h2V14a.9448.9448 0 00-1-1zM8 10a4 4 0 114-4A4.0045 4.0045 0 018 10zM8 4a2 2 0 102 2A2.002 2.002 0 008 4zM28.7663 4.2558A4.2121 4.2121 0 0023 4.0321a4.2121 4.2121 0 00-5.7663.2237 4.319 4.319 0 000 6.0447L22.998 16.14 23 16.1376l.002.0019 5.7643-5.839A4.319 4.319 0 0028.7663 4.2558zM27.342 8.8948l-4.34 4.3973L23 13.29l-.002.002-4.34-4.3973a2.3085 2.3085 0 010-3.2338 2.2639 2.2639 0 013.1561 0l1.181 1.2074L23 6.8634l.0049.005 1.181-1.2074a2.2639 2.2639 0 013.1561 0A2.3085 2.3085 0 0127.342 8.8948z"
  })), children);
});
var PersonFavorite16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PersonFavorite16(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 31H6a2.0059 2.0059 0 01-2-2V22a2.0059 2.0059 0 01-2-2V14a2.9465 2.9465 0 013-3h6a2.9465 2.9465 0 013 3v6a2.0059 2.0059 0 01-2 2v7A2.0059 2.0059 0 0110 31zM5 13a.9448.9448 0 00-1 1v6H6v9h4V20h2V14a.9448.9448 0 00-1-1zM8 10a4 4 0 114-4A4.0045 4.0045 0 018 10zM8 4a2 2 0 102 2A2.002 2.002 0 008 4zM28.7663 4.2558A4.2121 4.2121 0 0023 4.0321a4.2121 4.2121 0 00-5.7663.2237 4.319 4.319 0 000 6.0447L22.998 16.14 23 16.1376l.002.0019 5.7643-5.839A4.319 4.319 0 0028.7663 4.2558zM27.342 8.8948l-4.34 4.3973L23 13.29l-.002.002-4.34-4.3973a2.3085 2.3085 0 010-3.2338 2.2639 2.2639 0 013.1561 0l1.181 1.2074L23 6.8634l.0049.005 1.181-1.2074a2.2639 2.2639 0 013.1561 0A2.3085 2.3085 0 0127.342 8.8948z"
  })), children);
});
var Pest32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pest32(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7.5",
    cy: "9.5",
    r: "1.5"
  })), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13",
    cy: "13",
    r: "1"
  })), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "21",
    r: "1"
  })), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,14a8.9844,8.9844,0,0,0-7,3.3555V13a10.9054,10.9054,0,0,0-1.0093-4.5845l-.3569-.7768L15.811,7.87A2.9549,2.9549,0,0,1,15,8a3.0033,3.0033,0,0,1-3-3,2.9574,2.9574,0,0,1,.1294-.8105l.2324-.8233-.7773-.3569A10.9115,10.9115,0,0,0,7,2H2V9a10.8954,10.8954,0,0,0,2.2339,6.627l.3887.4277.54-.0381a5.5286,5.5286,0,0,1,5.3628,3.2559l.2207.497.5376.0845A11.0219,11.0219,0,0,0,13,20h3V30h2V26h3a9.01,9.01,0,0,0,9-9V14ZM12.1016,17.9468A7.51,7.51,0,0,0,5.5283,14,8.8945,8.8945,0,0,1,4,9V4H7a8.8624,8.8624,0,0,1,3.0259.53A4.2457,4.2457,0,0,0,10,5a4.9658,4.9658,0,0,0,5.47,4.9736A8.8793,8.8793,0,0,1,16,13v5H13A8.1153,8.1153,0,0,1,12.1016,17.9468ZM28,17a7.0078,7.0078,0,0,1-7,7H18V23a7.01,7.01,0,0,1,5.0212-6.7109A1.4971,1.4971,0,1,0,26,16.5a1.485,1.485,0,0,0-.0918-.5H28Z"
  })), children);
});
var Pest24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pest24(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7.5",
    cy: "9.5",
    r: "1.5"
  })), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13",
    cy: "13",
    r: "1"
  })), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "21",
    r: "1"
  })), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,14a8.9844,8.9844,0,0,0-7,3.3555V13a10.9054,10.9054,0,0,0-1.0093-4.5845l-.3569-.7768L15.811,7.87A2.9549,2.9549,0,0,1,15,8a3.0033,3.0033,0,0,1-3-3,2.9574,2.9574,0,0,1,.1294-.8105l.2324-.8233-.7773-.3569A10.9115,10.9115,0,0,0,7,2H2V9a10.8954,10.8954,0,0,0,2.2339,6.627l.3887.4277.54-.0381a5.5286,5.5286,0,0,1,5.3628,3.2559l.2207.497.5376.0845A11.0219,11.0219,0,0,0,13,20h3V30h2V26h3a9.01,9.01,0,0,0,9-9V14ZM12.1016,17.9468A7.51,7.51,0,0,0,5.5283,14,8.8945,8.8945,0,0,1,4,9V4H7a8.8624,8.8624,0,0,1,3.0259.53A4.2457,4.2457,0,0,0,10,5a4.9658,4.9658,0,0,0,5.47,4.9736A8.8793,8.8793,0,0,1,16,13v5H13A8.1153,8.1153,0,0,1,12.1016,17.9468ZM28,17a7.0078,7.0078,0,0,1-7,7H18V23a7.01,7.01,0,0,1,5.0212-6.7109A1.4971,1.4971,0,1,0,26,16.5a1.485,1.485,0,0,0-.0918-.5H28Z"
  })), children);
});
var Pest20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pest20(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7.5",
    cy: "9.5",
    r: "1.5"
  })), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13",
    cy: "13",
    r: "1"
  })), _circle21 || (_circle21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "21",
    r: "1"
  })), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,14a8.9844,8.9844,0,0,0-7,3.3555V13a10.9054,10.9054,0,0,0-1.0093-4.5845l-.3569-.7768L15.811,7.87A2.9549,2.9549,0,0,1,15,8a3.0033,3.0033,0,0,1-3-3,2.9574,2.9574,0,0,1,.1294-.8105l.2324-.8233-.7773-.3569A10.9115,10.9115,0,0,0,7,2H2V9a10.8954,10.8954,0,0,0,2.2339,6.627l.3887.4277.54-.0381a5.5286,5.5286,0,0,1,5.3628,3.2559l.2207.497.5376.0845A11.0219,11.0219,0,0,0,13,20h3V30h2V26h3a9.01,9.01,0,0,0,9-9V14ZM12.1016,17.9468A7.51,7.51,0,0,0,5.5283,14,8.8945,8.8945,0,0,1,4,9V4H7a8.8624,8.8624,0,0,1,3.0259.53A4.2457,4.2457,0,0,0,10,5a4.9658,4.9658,0,0,0,5.47,4.9736A8.8793,8.8793,0,0,1,16,13v5H13A8.1153,8.1153,0,0,1,12.1016,17.9468ZM28,17a7.0078,7.0078,0,0,1-7,7H18V23a7.01,7.01,0,0,1,5.0212-6.7109A1.4971,1.4971,0,1,0,26,16.5a1.485,1.485,0,0,0-.0918-.5H28Z"
  })), children);
});
var Pest16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pest16(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle22 || (_circle22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7.5",
    cy: "9.5",
    r: "1.5"
  })), _circle23 || (_circle23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13",
    cy: "13",
    r: "1"
  })), _circle24 || (_circle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "21",
    r: "1"
  })), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,14a8.9844,8.9844,0,0,0-7,3.3555V13a10.9054,10.9054,0,0,0-1.0093-4.5845l-.3569-.7768L15.811,7.87A2.9549,2.9549,0,0,1,15,8a3.0033,3.0033,0,0,1-3-3,2.9574,2.9574,0,0,1,.1294-.8105l.2324-.8233-.7773-.3569A10.9115,10.9115,0,0,0,7,2H2V9a10.8954,10.8954,0,0,0,2.2339,6.627l.3887.4277.54-.0381a5.5286,5.5286,0,0,1,5.3628,3.2559l.2207.497.5376.0845A11.0219,11.0219,0,0,0,13,20h3V30h2V26h3a9.01,9.01,0,0,0,9-9V14ZM12.1016,17.9468A7.51,7.51,0,0,0,5.5283,14,8.8945,8.8945,0,0,1,4,9V4H7a8.8624,8.8624,0,0,1,3.0259.53A4.2457,4.2457,0,0,0,10,5a4.9658,4.9658,0,0,0,5.47,4.9736A8.8793,8.8793,0,0,1,16,13v5H13A8.1153,8.1153,0,0,1,12.1016,17.9468ZM28,17a7.0078,7.0078,0,0,1-7,7H18V23a7.01,7.01,0,0,1,5.0212-6.7109A1.4971,1.4971,0,1,0,26,16.5a1.485,1.485,0,0,0-.0918-.5H28Z"
  })), children);
});
var WatsonHealthPetImageB32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthPetImageB32(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 21H21V24H19zM19 0H21V3H19zM8 11H11V13H8zM29 11H32V13H29z"
  })), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.59 3.07H13.57V6.07H11.59z",
    transform: "rotate(-45 12.586 4.577)"
  })), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.44 17.92H28.42V20.92H26.44z",
    transform: "rotate(-45 27.43 19.408)"
  })), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.09 18.42H14.09V20.400000000000002H11.09z",
    transform: "rotate(-45 12.592 19.414)"
  })), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.93 3.58H28.93V5.5600000000000005H25.93z",
    transform: "rotate(-45 27.423 4.57)"
  })), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 5a7 7 0 107 7A7 7 0 0020 5zm0 12A5 5 0 0120 7zM5 18H0V32H5a3 3 0 003-3V27a3 3 0 00-.78-2A3 3 0 008 23V21A3 3 0 005 18zM2 20H5a1 1 0 011 1v2a1 1 0 01-1 1H2zm4 9a1 1 0 01-1 1H2V26H5a1 1 0 011 1zM2 2L9 2 9 0 0 0 0 9 2 9 2 2z"
  })), children);
});
var WatsonHealthPetImageB24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthPetImageB24(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 21H21V24H19zM19 0H21V3H19zM8 11H11V13H8zM29 11H32V13H29z"
  })), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.59 3.07H13.57V6.07H11.59z",
    transform: "rotate(-45 12.586 4.577)"
  })), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.44 17.92H28.42V20.92H26.44z",
    transform: "rotate(-45 27.43 19.408)"
  })), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.09 18.42H14.09V20.400000000000002H11.09z",
    transform: "rotate(-45 12.592 19.414)"
  })), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.93 3.58H28.93V5.5600000000000005H25.93z",
    transform: "rotate(-45 27.423 4.57)"
  })), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 5a7 7 0 107 7A7 7 0 0020 5zm0 12A5 5 0 0120 7zM5 18H0V32H5a3 3 0 003-3V27a3 3 0 00-.78-2A3 3 0 008 23V21A3 3 0 005 18zM2 20H5a1 1 0 011 1v2a1 1 0 01-1 1H2zm4 9a1 1 0 01-1 1H2V26H5a1 1 0 011 1zM2 2L9 2 9 0 0 0 0 9 2 9 2 2z"
  })), children);
});
var WatsonHealthPetImageB20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthPetImageB20(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 21H21V24H19zM19 0H21V3H19zM8 11H11V13H8zM29 11H32V13H29z"
  })), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.59 3.07H13.57V6.07H11.59z",
    transform: "rotate(-45 12.586 4.577)"
  })), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.44 17.92H28.42V20.92H26.44z",
    transform: "rotate(-45 27.43 19.408)"
  })), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.09 18.42H14.09V20.400000000000002H11.09z",
    transform: "rotate(-45 12.592 19.414)"
  })), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.93 3.58H28.93V5.5600000000000005H25.93z",
    transform: "rotate(-45 27.423 4.57)"
  })), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 5a7 7 0 107 7A7 7 0 0020 5zm0 12A5 5 0 0120 7zM5 18H0V32H5a3 3 0 003-3V27a3 3 0 00-.78-2A3 3 0 008 23V21A3 3 0 005 18zM2 20H5a1 1 0 011 1v2a1 1 0 01-1 1H2zm4 9a1 1 0 01-1 1H2V26H5a1 1 0 011 1zM2 2L9 2 9 0 0 0 0 9 2 9 2 2z"
  })), children);
});
var WatsonHealthPetImageB16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthPetImageB16(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 21H21V24H19zM19 0H21V3H19zM8 11H11V13H8zM29 11H32V13H29z"
  })), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.59 3.07H13.57V6.07H11.59z",
    transform: "rotate(-45 12.586 4.577)"
  })), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.44 17.92H28.42V20.92H26.44z",
    transform: "rotate(-45 27.43 19.408)"
  })), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.09 18.42H14.09V20.400000000000002H11.09z",
    transform: "rotate(-45 12.592 19.414)"
  })), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.93 3.58H28.93V5.5600000000000005H25.93z",
    transform: "rotate(-45 27.423 4.57)"
  })), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 5a7 7 0 107 7A7 7 0 0020 5zm0 12A5 5 0 0120 7zM5 18H0V32H5a3 3 0 003-3V27a3 3 0 00-.78-2A3 3 0 008 23V21A3 3 0 005 18zM2 20H5a1 1 0 011 1v2a1 1 0 01-1 1H2zm4 9a1 1 0 01-1 1H2V26H5a1 1 0 011 1zM2 2L9 2 9 0 0 0 0 9 2 9 2 2z"
  })), children);
});
var WatsonHealthPetImageO32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthPetImageO32(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 29H13V32H11zM11 8H13V11H11zM0 19H3V21H0zM21 19H24V21H21z"
  })), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.59 11.09H5.57V14.09H3.59z",
    transform: "rotate(-45 4.585 12.59)"
  })), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.44 25.93H20.42V28.93H18.44z",
    transform: "rotate(-45 19.429 27.422)"
  })), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.09 26.44H6.09V28.42H3.09z",
    transform: "rotate(-45 4.591 27.428)"
  })), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.93 11.59H20.93V13.57H17.93z",
    transform: "rotate(-45 19.423 12.585)"
  })), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 13a7 7 0 107 7A7 7 0 0012 13zm0 12a5 5 0 010-10zM2 2L9 2 9 0 0 0 0 9 2 9 2 2zM30 0H26a2 2 0 00-2 2V12a2 2 0 002 2h4a2 2 0 002-2V2A2 2 0 0030 0zM26 12V2h4V12z"
  })), children);
});
var WatsonHealthPetImageO24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthPetImageO24(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 29H13V32H11zM11 8H13V11H11zM0 19H3V21H0zM21 19H24V21H21z"
  })), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.59 11.09H5.57V14.09H3.59z",
    transform: "rotate(-45 4.585 12.59)"
  })), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.44 25.93H20.42V28.93H18.44z",
    transform: "rotate(-45 19.429 27.422)"
  })), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.09 26.44H6.09V28.42H3.09z",
    transform: "rotate(-45 4.591 27.428)"
  })), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.93 11.59H20.93V13.57H17.93z",
    transform: "rotate(-45 19.423 12.585)"
  })), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 13a7 7 0 107 7A7 7 0 0012 13zm0 12a5 5 0 010-10zM2 2L9 2 9 0 0 0 0 9 2 9 2 2zM30 0H26a2 2 0 00-2 2V12a2 2 0 002 2h4a2 2 0 002-2V2A2 2 0 0030 0zM26 12V2h4V12z"
  })), children);
});
var WatsonHealthPetImageO20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthPetImageO20(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 29H13V32H11zM11 8H13V11H11zM0 19H3V21H0zM21 19H24V21H21z"
  })), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.59 11.09H5.57V14.09H3.59z",
    transform: "rotate(-45 4.585 12.59)"
  })), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.44 25.93H20.42V28.93H18.44z",
    transform: "rotate(-45 19.429 27.422)"
  })), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.09 26.44H6.09V28.42H3.09z",
    transform: "rotate(-45 4.591 27.428)"
  })), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.93 11.59H20.93V13.57H17.93z",
    transform: "rotate(-45 19.423 12.585)"
  })), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 13a7 7 0 107 7A7 7 0 0012 13zm0 12a5 5 0 010-10zM2 2L9 2 9 0 0 0 0 9 2 9 2 2zM30 0H26a2 2 0 00-2 2V12a2 2 0 002 2h4a2 2 0 002-2V2A2 2 0 0030 0zM26 12V2h4V12z"
  })), children);
});
var WatsonHealthPetImageO16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthPetImageO16(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 29H13V32H11zM11 8H13V11H11zM0 19H3V21H0zM21 19H24V21H21z"
  })), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.59 11.09H5.57V14.09H3.59z",
    transform: "rotate(-45 4.585 12.59)"
  })), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.44 25.93H20.42V28.93H18.44z",
    transform: "rotate(-45 19.429 27.422)"
  })), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.09 26.44H6.09V28.42H3.09z",
    transform: "rotate(-45 4.591 27.428)"
  })), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.93 11.59H20.93V13.57H17.93z",
    transform: "rotate(-45 19.423 12.585)"
  })), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 13a7 7 0 107 7A7 7 0 0012 13zm0 12a5 5 0 010-10zM2 2L9 2 9 0 0 0 0 9 2 9 2 2zM30 0H26a2 2 0 00-2 2V12a2 2 0 002 2h4a2 2 0 002-2V2A2 2 0 0030 0zM26 12V2h4V12z"
  })), children);
});
var Phone32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Phone32(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,29h-.17C6.18,27.87,3.39,11.29,3,6.23A3,3,0,0,1,5.76,3h5.51a2,2,0,0,1,1.86,1.26L14.65,8a2,2,0,0,1-.44,2.16l-2.13,2.15a9.37,9.37,0,0,0,7.58,7.6l2.17-2.15A2,2,0,0,1,24,17.35l3.77,1.51A2,2,0,0,1,29,20.72V26A3,3,0,0,1,26,29ZM6,5A1,1,0,0,0,5,6v.08C5.46,12,8.41,26,25.94,27A1,1,0,0,0,27,26.06V20.72l-3.77-1.51-2.87,2.85L19.88,22C11.18,20.91,10,12.21,10,12.12l-.06-.48,2.84-2.87L11.28,5Z"
  })), children);
});
var Phone24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Phone24(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,29h-.17C6.18,27.87,3.39,11.29,3,6.23A3,3,0,0,1,5.76,3h5.51a2,2,0,0,1,1.86,1.26L14.65,8a2,2,0,0,1-.44,2.16l-2.13,2.15a9.37,9.37,0,0,0,7.58,7.6l2.17-2.15A2,2,0,0,1,24,17.35l3.77,1.51A2,2,0,0,1,29,20.72V26A3,3,0,0,1,26,29ZM6,5A1,1,0,0,0,5,6v.08C5.46,12,8.41,26,25.94,27A1,1,0,0,0,27,26.06V20.72l-3.77-1.51-2.87,2.85L19.88,22C11.18,20.91,10,12.21,10,12.12l-.06-.48,2.84-2.87L11.28,5Z"
  })), children);
});
var Phone20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Phone20(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,29h-.17C6.18,27.87,3.39,11.29,3,6.23A3,3,0,0,1,5.76,3h5.51a2,2,0,0,1,1.86,1.26L14.65,8a2,2,0,0,1-.44,2.16l-2.13,2.15a9.37,9.37,0,0,0,7.58,7.6l2.17-2.15A2,2,0,0,1,24,17.35l3.77,1.51A2,2,0,0,1,29,20.72V26A3,3,0,0,1,26,29ZM6,5A1,1,0,0,0,5,6v.08C5.46,12,8.41,26,25.94,27A1,1,0,0,0,27,26.06V20.72l-3.77-1.51-2.87,2.85L19.88,22C11.18,20.91,10,12.21,10,12.12l-.06-.48,2.84-2.87L11.28,5Z"
  })), children);
});
var Phone16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Phone16(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,29h-.17C6.18,27.87,3.39,11.29,3,6.23A3,3,0,0,1,5.76,3h5.51a2,2,0,0,1,1.86,1.26L14.65,8a2,2,0,0,1-.44,2.16l-2.13,2.15a9.37,9.37,0,0,0,7.58,7.6l2.17-2.15A2,2,0,0,1,24,17.35l3.77,1.51A2,2,0,0,1,29,20.72V26A3,3,0,0,1,26,29ZM6,5A1,1,0,0,0,5,6v.08C5.46,12,8.41,26,25.94,27A1,1,0,0,0,27,26.06V20.72l-3.77-1.51-2.87,2.85L19.88,22C11.18,20.91,10,12.21,10,12.12l-.06-.48,2.84-2.87L11.28,5Z"
  })), children);
});
var PhoneApplication32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneApplication32(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 2H30V6H26zM26 8H30V12H26zM20 2H24V6H20zM20 8H24V12H20zM25 30h-.17C5.18 28.87 2.39 12.29 2 7.23A3 3 0 014.7611 4.0088Q4.88 4 5 4h5.27a2 2 0 011.86 1.26L13.65 9a2 2 0 01-.44 2.16l-2.13 2.15a9.36 9.36 0 007.58 7.6l2.17-2.15A2 2 0 0123 18.35l3.77 1.51A2 2 0 0128 21.72V27A3 3 0 0125 30zM5 6a1 1 0 00-1.0032.9968c0 .0278.001.0555.0032.0832C4.46 13 7.41 27 24.94 28a1 1 0 001.0581-.9382Q26 27.0309 26 27V21.72l-3.77-1.51-2.87 2.85L18.88 23C10.18 21.91 9 13.21 9 13.12l-.06-.48 2.84-2.87L10.28 6z"
  })), children);
});
var PhoneApplication24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneApplication24(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 2H30V6H26zM26 8H30V12H26zM20 2H24V6H20zM20 8H24V12H20zM25 30h-.17C5.18 28.87 2.39 12.29 2 7.23A3 3 0 014.7611 4.0088Q4.88 4 5 4h5.27a2 2 0 011.86 1.26L13.65 9a2 2 0 01-.44 2.16l-2.13 2.15a9.36 9.36 0 007.58 7.6l2.17-2.15A2 2 0 0123 18.35l3.77 1.51A2 2 0 0128 21.72V27A3 3 0 0125 30zM5 6a1 1 0 00-1.0032.9968c0 .0278.001.0555.0032.0832C4.46 13 7.41 27 24.94 28a1 1 0 001.0581-.9382Q26 27.0309 26 27V21.72l-3.77-1.51-2.87 2.85L18.88 23C10.18 21.91 9 13.21 9 13.12l-.06-.48 2.84-2.87L10.28 6z"
  })), children);
});
var PhoneApplication20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneApplication20(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 2H30V6H26zM26 8H30V12H26zM20 2H24V6H20zM20 8H24V12H20zM25 30h-.17C5.18 28.87 2.39 12.29 2 7.23A3 3 0 014.7611 4.0088Q4.88 4 5 4h5.27a2 2 0 011.86 1.26L13.65 9a2 2 0 01-.44 2.16l-2.13 2.15a9.36 9.36 0 007.58 7.6l2.17-2.15A2 2 0 0123 18.35l3.77 1.51A2 2 0 0128 21.72V27A3 3 0 0125 30zM5 6a1 1 0 00-1.0032.9968c0 .0278.001.0555.0032.0832C4.46 13 7.41 27 24.94 28a1 1 0 001.0581-.9382Q26 27.0309 26 27V21.72l-3.77-1.51-2.87 2.85L18.88 23C10.18 21.91 9 13.21 9 13.12l-.06-.48 2.84-2.87L10.28 6z"
  })), children);
});
var PhoneApplication16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneApplication16(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 2H30V6H26zM26 8H30V12H26zM20 2H24V6H20zM20 8H24V12H20zM25 30h-.17C5.18 28.87 2.39 12.29 2 7.23A3 3 0 014.7611 4.0088Q4.88 4 5 4h5.27a2 2 0 011.86 1.26L13.65 9a2 2 0 01-.44 2.16l-2.13 2.15a9.36 9.36 0 007.58 7.6l2.17-2.15A2 2 0 0123 18.35l3.77 1.51A2 2 0 0128 21.72V27A3 3 0 0125 30zM5 6a1 1 0 00-1.0032.9968c0 .0278.001.0555.0032.0832C4.46 13 7.41 27 24.94 28a1 1 0 001.0581-.9382Q26 27.0309 26 27V21.72l-3.77-1.51-2.87 2.85L18.88 23C10.18 21.91 9 13.21 9 13.12l-.06-.48 2.84-2.87L10.28 6z"
  })), children);
});
var PhoneBlock32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneBlock32(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,29h-.17C6.18,27.87,3.39,11.29,3,6.23A3,3,0,0,1,5.7612,3.0088Q5.88,3,6,3h5.27a2,2,0,0,1,1.86,1.26L14.65,8a2,2,0,0,1-.44,2.16l-2.13,2.15a9.36,9.36,0,0,0,7.58,7.6l2.17-2.15A2,2,0,0,1,24,17.35l3.77,1.51A2,2,0,0,1,29,20.72V26A3,3,0,0,1,26,29ZM6,5a1,1,0,0,0-1.0032.9968q0,.0417.0032.0832C5.46,12,8.41,26,25.94,27a1,1,0,0,0,1.0582-.9382Q27,26.0309,27,26V20.72l-3.77-1.51-2.87,2.85L19.88,22C11.18,20.91,10,12.21,10,12.12l-.06-.48,2.84-2.87L11.28,5Z"
  })), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.41 9L28 5.41 26.59 4 23 7.59 19.41 4 18 5.41 21.59 9 18 12.59 19.41 14 23 10.41 26.59 14 28 12.59 24.41 9z"
  })), children);
});
var PhoneBlock24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneBlock24(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,29h-.17C6.18,27.87,3.39,11.29,3,6.23A3,3,0,0,1,5.7612,3.0088Q5.88,3,6,3h5.27a2,2,0,0,1,1.86,1.26L14.65,8a2,2,0,0,1-.44,2.16l-2.13,2.15a9.36,9.36,0,0,0,7.58,7.6l2.17-2.15A2,2,0,0,1,24,17.35l3.77,1.51A2,2,0,0,1,29,20.72V26A3,3,0,0,1,26,29ZM6,5a1,1,0,0,0-1.0032.9968q0,.0417.0032.0832C5.46,12,8.41,26,25.94,27a1,1,0,0,0,1.0582-.9382Q27,26.0309,27,26V20.72l-3.77-1.51-2.87,2.85L19.88,22C11.18,20.91,10,12.21,10,12.12l-.06-.48,2.84-2.87L11.28,5Z"
  })), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.41 9L28 5.41 26.59 4 23 7.59 19.41 4 18 5.41 21.59 9 18 12.59 19.41 14 23 10.41 26.59 14 28 12.59 24.41 9z"
  })), children);
});
var PhoneBlock20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneBlock20(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,29h-.17C6.18,27.87,3.39,11.29,3,6.23A3,3,0,0,1,5.7612,3.0088Q5.88,3,6,3h5.27a2,2,0,0,1,1.86,1.26L14.65,8a2,2,0,0,1-.44,2.16l-2.13,2.15a9.36,9.36,0,0,0,7.58,7.6l2.17-2.15A2,2,0,0,1,24,17.35l3.77,1.51A2,2,0,0,1,29,20.72V26A3,3,0,0,1,26,29ZM6,5a1,1,0,0,0-1.0032.9968q0,.0417.0032.0832C5.46,12,8.41,26,25.94,27a1,1,0,0,0,1.0582-.9382Q27,26.0309,27,26V20.72l-3.77-1.51-2.87,2.85L19.88,22C11.18,20.91,10,12.21,10,12.12l-.06-.48,2.84-2.87L11.28,5Z"
  })), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.41 9L28 5.41 26.59 4 23 7.59 19.41 4 18 5.41 21.59 9 18 12.59 19.41 14 23 10.41 26.59 14 28 12.59 24.41 9z"
  })), children);
});
var PhoneBlock16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneBlock16(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,29h-.17C6.18,27.87,3.39,11.29,3,6.23A3,3,0,0,1,5.7612,3.0088Q5.88,3,6,3h5.27a2,2,0,0,1,1.86,1.26L14.65,8a2,2,0,0,1-.44,2.16l-2.13,2.15a9.36,9.36,0,0,0,7.58,7.6l2.17-2.15A2,2,0,0,1,24,17.35l3.77,1.51A2,2,0,0,1,29,20.72V26A3,3,0,0,1,26,29ZM6,5a1,1,0,0,0-1.0032.9968q0,.0417.0032.0832C5.46,12,8.41,26,25.94,27a1,1,0,0,0,1.0582-.9382Q27,26.0309,27,26V20.72l-3.77-1.51-2.87,2.85L19.88,22C11.18,20.91,10,12.21,10,12.12l-.06-.48,2.84-2.87L11.28,5Z"
  })), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.41 9L28 5.41 26.59 4 23 7.59 19.41 4 18 5.41 21.59 9 18 12.59 19.41 14 23 10.41 26.59 14 28 12.59 24.41 9z"
  })), children);
});
var PhoneBlockFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneBlockFilled32(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.3333,21.4823l2.24-2.24a2.1667,2.1667,0,0,1,2.3368-.48l2.7281,1.0913A2.1666,2.1666,0,0,1,29,21.8659v4.9613a2.1668,2.1668,0,0,1-2.2843,2.1686C7.5938,27.8054,3.7321,11.6114,3.0146,5.4079A2.162,2.162,0,0,1,5.1692,3H10.042a2.1666,2.1666,0,0,1,2.0117,1.362L13.145,7.09a2.1666,2.1666,0,0,1-.48,2.3367l-2.24,2.24S11.6667,20.399,20.3333,21.4823Z"
  })), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.41 9L28 5.41 26.59 4 23 7.59 19.41 4 18 5.41 21.59 9 18 12.59 19.41 14 23 10.41 26.59 14 28 12.59 24.41 9z"
  })), children);
});
var PhoneBlockFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneBlockFilled24(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.3333,21.4823l2.24-2.24a2.1667,2.1667,0,0,1,2.3368-.48l2.7281,1.0913A2.1666,2.1666,0,0,1,29,21.8659v4.9613a2.1668,2.1668,0,0,1-2.2843,2.1686C7.5938,27.8054,3.7321,11.6114,3.0146,5.4079A2.162,2.162,0,0,1,5.1692,3H10.042a2.1666,2.1666,0,0,1,2.0117,1.362L13.145,7.09a2.1666,2.1666,0,0,1-.48,2.3367l-2.24,2.24S11.6667,20.399,20.3333,21.4823Z"
  })), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.41 9L28 5.41 26.59 4 23 7.59 19.41 4 18 5.41 21.59 9 18 12.59 19.41 14 23 10.41 26.59 14 28 12.59 24.41 9z"
  })), children);
});
var PhoneBlockFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneBlockFilled20(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.3333,21.4823l2.24-2.24a2.1667,2.1667,0,0,1,2.3368-.48l2.7281,1.0913A2.1666,2.1666,0,0,1,29,21.8659v4.9613a2.1668,2.1668,0,0,1-2.2843,2.1686C7.5938,27.8054,3.7321,11.6114,3.0146,5.4079A2.162,2.162,0,0,1,5.1692,3H10.042a2.1666,2.1666,0,0,1,2.0117,1.362L13.145,7.09a2.1666,2.1666,0,0,1-.48,2.3367l-2.24,2.24S11.6667,20.399,20.3333,21.4823Z"
  })), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.41 9L28 5.41 26.59 4 23 7.59 19.41 4 18 5.41 21.59 9 18 12.59 19.41 14 23 10.41 26.59 14 28 12.59 24.41 9z"
  })), children);
});
var PhoneBlockFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneBlockFilled16(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.3333,21.4823l2.24-2.24a2.1667,2.1667,0,0,1,2.3368-.48l2.7281,1.0913A2.1666,2.1666,0,0,1,29,21.8659v4.9613a2.1668,2.1668,0,0,1-2.2843,2.1686C7.5938,27.8054,3.7321,11.6114,3.0146,5.4079A2.162,2.162,0,0,1,5.1692,3H10.042a2.1666,2.1666,0,0,1,2.0117,1.362L13.145,7.09a2.1666,2.1666,0,0,1-.48,2.3367l-2.24,2.24S11.6667,20.399,20.3333,21.4823Z"
  })), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.41 9L28 5.41 26.59 4 23 7.59 19.41 4 18 5.41 21.59 9 18 12.59 19.41 14 23 10.41 26.59 14 28 12.59 24.41 9z"
  })), children);
});
var PhoneFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneFilled32(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.33,21.48l2.24-2.24a2.19,2.19,0,0,1,2.34-.48l2.73,1.09a2.18,2.18,0,0,1,1.36,2v5A2.17,2.17,0,0,1,26.72,29C7.59,27.81,3.73,11.61,3,5.41A2.17,2.17,0,0,1,5.17,3H10a2.16,2.16,0,0,1,2,1.36l1.09,2.73a2.16,2.16,0,0,1-.47,2.34l-2.24,2.24S11.67,20.4,20.33,21.48Z"
  })), children);
});
var PhoneFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneFilled24(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.33,21.48l2.24-2.24a2.19,2.19,0,0,1,2.34-.48l2.73,1.09a2.18,2.18,0,0,1,1.36,2v5A2.17,2.17,0,0,1,26.72,29C7.59,27.81,3.73,11.61,3,5.41A2.17,2.17,0,0,1,5.17,3H10a2.16,2.16,0,0,1,2,1.36l1.09,2.73a2.16,2.16,0,0,1-.47,2.34l-2.24,2.24S11.67,20.4,20.33,21.48Z"
  })), children);
});
var PhoneFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneFilled20(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.33,21.48l2.24-2.24a2.19,2.19,0,0,1,2.34-.48l2.73,1.09a2.18,2.18,0,0,1,1.36,2v5A2.17,2.17,0,0,1,26.72,29C7.59,27.81,3.73,11.61,3,5.41A2.17,2.17,0,0,1,5.17,3H10a2.16,2.16,0,0,1,2,1.36l1.09,2.73a2.16,2.16,0,0,1-.47,2.34l-2.24,2.24S11.67,20.4,20.33,21.48Z"
  })), children);
});
var PhoneFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneFilled16(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.33,21.48l2.24-2.24a2.19,2.19,0,0,1,2.34-.48l2.73,1.09a2.18,2.18,0,0,1,1.36,2v5A2.17,2.17,0,0,1,26.72,29C7.59,27.81,3.73,11.61,3,5.41A2.17,2.17,0,0,1,5.17,3H10a2.16,2.16,0,0,1,2,1.36l1.09,2.73a2.16,2.16,0,0,1-.47,2.34l-2.24,2.24S11.67,20.4,20.33,21.48Z"
  })), children);
});
var PhoneIncoming32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneIncoming32(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,29h-.17C6.18,27.87,3.39,11.29,3,6.23A3,3,0,0,1,5.7612,3.0088Q5.88,3,6,3h5.27a2,2,0,0,1,1.86,1.26L14.65,8a2,2,0,0,1-.44,2.16l-2.13,2.15a9.36,9.36,0,0,0,7.58,7.6l2.17-2.15A2,2,0,0,1,24,17.35l3.77,1.51A2,2,0,0,1,29,20.72V26A3,3,0,0,1,26,29ZM6,5a1,1,0,0,0-1.0032.9968q0,.0417.0032.0832C5.46,12,8.41,26,25.94,27a1,1,0,0,0,1.0582-.9382Q27,26.0309,27,26V20.72l-3.77-1.51-2.87,2.85L19.88,22C11.18,20.91,10,12.21,10,12.12l-.06-.48,2.84-2.87L11.28,5Z"
  })), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 13L27 11 22.414 11 29 4.414 27.586 3 21 9.586 21 5 19 5 19 13 27 13z"
  })), children);
});
var PhoneIncoming24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneIncoming24(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,29h-.17C6.18,27.87,3.39,11.29,3,6.23A3,3,0,0,1,5.7612,3.0088Q5.88,3,6,3h5.27a2,2,0,0,1,1.86,1.26L14.65,8a2,2,0,0,1-.44,2.16l-2.13,2.15a9.36,9.36,0,0,0,7.58,7.6l2.17-2.15A2,2,0,0,1,24,17.35l3.77,1.51A2,2,0,0,1,29,20.72V26A3,3,0,0,1,26,29ZM6,5a1,1,0,0,0-1.0032.9968q0,.0417.0032.0832C5.46,12,8.41,26,25.94,27a1,1,0,0,0,1.0582-.9382Q27,26.0309,27,26V20.72l-3.77-1.51-2.87,2.85L19.88,22C11.18,20.91,10,12.21,10,12.12l-.06-.48,2.84-2.87L11.28,5Z"
  })), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 13L27 11 22.414 11 29 4.414 27.586 3 21 9.586 21 5 19 5 19 13 27 13z"
  })), children);
});
var PhoneIncoming20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneIncoming20(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,29h-.17C6.18,27.87,3.39,11.29,3,6.23A3,3,0,0,1,5.7612,3.0088Q5.88,3,6,3h5.27a2,2,0,0,1,1.86,1.26L14.65,8a2,2,0,0,1-.44,2.16l-2.13,2.15a9.36,9.36,0,0,0,7.58,7.6l2.17-2.15A2,2,0,0,1,24,17.35l3.77,1.51A2,2,0,0,1,29,20.72V26A3,3,0,0,1,26,29ZM6,5a1,1,0,0,0-1.0032.9968q0,.0417.0032.0832C5.46,12,8.41,26,25.94,27a1,1,0,0,0,1.0582-.9382Q27,26.0309,27,26V20.72l-3.77-1.51-2.87,2.85L19.88,22C11.18,20.91,10,12.21,10,12.12l-.06-.48,2.84-2.87L11.28,5Z"
  })), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 13L27 11 22.414 11 29 4.414 27.586 3 21 9.586 21 5 19 5 19 13 27 13z"
  })), children);
});
var PhoneIncoming16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneIncoming16(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,29h-.17C6.18,27.87,3.39,11.29,3,6.23A3,3,0,0,1,5.7612,3.0088Q5.88,3,6,3h5.27a2,2,0,0,1,1.86,1.26L14.65,8a2,2,0,0,1-.44,2.16l-2.13,2.15a9.36,9.36,0,0,0,7.58,7.6l2.17-2.15A2,2,0,0,1,24,17.35l3.77,1.51A2,2,0,0,1,29,20.72V26A3,3,0,0,1,26,29ZM6,5a1,1,0,0,0-1.0032.9968q0,.0417.0032.0832C5.46,12,8.41,26,25.94,27a1,1,0,0,0,1.0582-.9382Q27,26.0309,27,26V20.72l-3.77-1.51-2.87,2.85L19.88,22C11.18,20.91,10,12.21,10,12.12l-.06-.48,2.84-2.87L11.28,5Z"
  })), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 13L27 11 22.414 11 29 4.414 27.586 3 21 9.586 21 5 19 5 19 13 27 13z"
  })), children);
});
var PhoneIncomingFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneIncomingFilled32(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.3333,21.4823l2.24-2.24a2.1667,2.1667,0,0,1,2.3368-.48l2.7281,1.0913A2.1666,2.1666,0,0,1,29,21.8659v4.9613a2.1668,2.1668,0,0,1-2.2843,2.1686C7.5938,27.8054,3.7321,11.6114,3.0146,5.4079A2.162,2.162,0,0,1,5.1692,3H10.042a2.1666,2.1666,0,0,1,2.0117,1.362L13.145,7.09a2.1666,2.1666,0,0,1-.48,2.3367l-2.24,2.24S11.6667,20.399,20.3333,21.4823Z"
  })), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 13L27 11 22.414 11 29 4.414 27.586 3 21 9.586 21 5 19 5 19 13 27 13z"
  })), children);
});
var PhoneIncomingFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneIncomingFilled24(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.3333,21.4823l2.24-2.24a2.1667,2.1667,0,0,1,2.3368-.48l2.7281,1.0913A2.1666,2.1666,0,0,1,29,21.8659v4.9613a2.1668,2.1668,0,0,1-2.2843,2.1686C7.5938,27.8054,3.7321,11.6114,3.0146,5.4079A2.162,2.162,0,0,1,5.1692,3H10.042a2.1666,2.1666,0,0,1,2.0117,1.362L13.145,7.09a2.1666,2.1666,0,0,1-.48,2.3367l-2.24,2.24S11.6667,20.399,20.3333,21.4823Z"
  })), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 13L27 11 22.414 11 29 4.414 27.586 3 21 9.586 21 5 19 5 19 13 27 13z"
  })), children);
});
var PhoneIncomingFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneIncomingFilled20(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.3333,21.4823l2.24-2.24a2.1667,2.1667,0,0,1,2.3368-.48l2.7281,1.0913A2.1666,2.1666,0,0,1,29,21.8659v4.9613a2.1668,2.1668,0,0,1-2.2843,2.1686C7.5938,27.8054,3.7321,11.6114,3.0146,5.4079A2.162,2.162,0,0,1,5.1692,3H10.042a2.1666,2.1666,0,0,1,2.0117,1.362L13.145,7.09a2.1666,2.1666,0,0,1-.48,2.3367l-2.24,2.24S11.6667,20.399,20.3333,21.4823Z"
  })), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 13L27 11 22.414 11 29 4.414 27.586 3 21 9.586 21 5 19 5 19 13 27 13z"
  })), children);
});
var PhoneIncomingFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneIncomingFilled16(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.3333,21.4823l2.24-2.24a2.1667,2.1667,0,0,1,2.3368-.48l2.7281,1.0913A2.1666,2.1666,0,0,1,29,21.8659v4.9613a2.1668,2.1668,0,0,1-2.2843,2.1686C7.5938,27.8054,3.7321,11.6114,3.0146,5.4079A2.162,2.162,0,0,1,5.1692,3H10.042a2.1666,2.1666,0,0,1,2.0117,1.362L13.145,7.09a2.1666,2.1666,0,0,1-.48,2.3367l-2.24,2.24S11.6667,20.399,20.3333,21.4823Z"
  })), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 13L27 11 22.414 11 29 4.414 27.586 3 21 9.586 21 5 19 5 19 13 27 13z"
  })), children);
});
var PhoneIp32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneIp32(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 14H18V16H16zM20 14H22V16H20zM24 14H26V16H24zM16 18H18V20H16zM20 18H22V20H20zM24 18H26V20H24zM16 22H18V24H16zM20 22H22V24H20zM24 22H26V24H24zM16 10H26V12H16z"
  })), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H14V5a2.0025,2.0025,0,0,0-2-2H8A2.0025,2.0025,0,0,0,6,5V6H4A2.0025,2.0025,0,0,0,2,8V26a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V8A2.0025,2.0025,0,0,0,28,6ZM8,5h4V22H8ZM28,26H4V8H6V22a2.0025,2.0025,0,0,0,2,2h4a2.0025,2.0025,0,0,0,2-2V8H28Z"
  })), children);
});
var PhoneIp24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneIp24(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 14H18V16H16zM20 14H22V16H20zM24 14H26V16H24zM16 18H18V20H16zM20 18H22V20H20zM24 18H26V20H24zM16 22H18V24H16zM20 22H22V24H20zM24 22H26V24H24zM16 10H26V12H16z"
  })), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H14V5a2.0025,2.0025,0,0,0-2-2H8A2.0025,2.0025,0,0,0,6,5V6H4A2.0025,2.0025,0,0,0,2,8V26a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V8A2.0025,2.0025,0,0,0,28,6ZM8,5h4V22H8ZM28,26H4V8H6V22a2.0025,2.0025,0,0,0,2,2h4a2.0025,2.0025,0,0,0,2-2V8H28Z"
  })), children);
});
var PhoneIp20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneIp20(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 14H18V16H16zM20 14H22V16H20zM24 14H26V16H24zM16 18H18V20H16zM20 18H22V20H20zM24 18H26V20H24zM16 22H18V24H16zM20 22H22V24H20zM24 22H26V24H24zM16 10H26V12H16z"
  })), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H14V5a2.0025,2.0025,0,0,0-2-2H8A2.0025,2.0025,0,0,0,6,5V6H4A2.0025,2.0025,0,0,0,2,8V26a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V8A2.0025,2.0025,0,0,0,28,6ZM8,5h4V22H8ZM28,26H4V8H6V22a2.0025,2.0025,0,0,0,2,2h4a2.0025,2.0025,0,0,0,2-2V8H28Z"
  })), children);
});
var PhoneIp16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneIp16(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 14H18V16H16zM20 14H22V16H20zM24 14H26V16H24zM16 18H18V20H16zM20 18H22V20H20zM24 18H26V20H24zM16 22H18V24H16zM20 22H22V24H20zM24 22H26V24H24zM16 10H26V12H16z"
  })), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H14V5a2.0025,2.0025,0,0,0-2-2H8A2.0025,2.0025,0,0,0,6,5V6H4A2.0025,2.0025,0,0,0,2,8V26a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V8A2.0025,2.0025,0,0,0,28,6ZM8,5h4V22H8ZM28,26H4V8H6V22a2.0025,2.0025,0,0,0,2,2h4a2.0025,2.0025,0,0,0,2-2V8H28Z"
  })), children);
});
var PhoneOff32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneOff32(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.19 18.56A25.66 25.66 0 015 6.08V6A1 1 0 016 5h5.28l1.5 3.77L9.94 11.64l.06.48a13 13 0 001.46 4.17l1.46-1.46a9.34 9.34 0 01-.84-2.52l2.13-2.15A2 2 0 0014.65 8L13.13 4.26A2 2 0 0011.27 3H5.76A3 3 0 003 6.23 28 28 0 007.79 20zM27.77 18.86L24 17.35a2 2 0 00-2.17.41l-2.17 2.15A9.17 9.17 0 0115.45 18L30 3.41 28.59 2 2 28.59 3.41 30l7-7c3.38 3.18 8.28 5.62 15.39 6H26a3 3 0 003-3V20.72A2 2 0 0027.77 18.86zM27 26v.06a1 1 0 01-1.06.94c-6.51-.37-11-2.54-14.11-5.42L14 19.44A10.77 10.77 0 0019.88 22l.48.06 2.87-2.85L27 20.72z"
  })), children);
});
var PhoneOff24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneOff24(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.19 18.56A25.66 25.66 0 015 6.08V6A1 1 0 016 5h5.28l1.5 3.77L9.94 11.64l.06.48a13 13 0 001.46 4.17l1.46-1.46a9.34 9.34 0 01-.84-2.52l2.13-2.15A2 2 0 0014.65 8L13.13 4.26A2 2 0 0011.27 3H5.76A3 3 0 003 6.23 28 28 0 007.79 20zM27.77 18.86L24 17.35a2 2 0 00-2.17.41l-2.17 2.15A9.17 9.17 0 0115.45 18L30 3.41 28.59 2 2 28.59 3.41 30l7-7c3.38 3.18 8.28 5.62 15.39 6H26a3 3 0 003-3V20.72A2 2 0 0027.77 18.86zM27 26v.06a1 1 0 01-1.06.94c-6.51-.37-11-2.54-14.11-5.42L14 19.44A10.77 10.77 0 0019.88 22l.48.06 2.87-2.85L27 20.72z"
  })), children);
});
var PhoneOff20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneOff20(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.19 18.56A25.66 25.66 0 015 6.08V6A1 1 0 016 5h5.28l1.5 3.77L9.94 11.64l.06.48a13 13 0 001.46 4.17l1.46-1.46a9.34 9.34 0 01-.84-2.52l2.13-2.15A2 2 0 0014.65 8L13.13 4.26A2 2 0 0011.27 3H5.76A3 3 0 003 6.23 28 28 0 007.79 20zM27.77 18.86L24 17.35a2 2 0 00-2.17.41l-2.17 2.15A9.17 9.17 0 0115.45 18L30 3.41 28.59 2 2 28.59 3.41 30l7-7c3.38 3.18 8.28 5.62 15.39 6H26a3 3 0 003-3V20.72A2 2 0 0027.77 18.86zM27 26v.06a1 1 0 01-1.06.94c-6.51-.37-11-2.54-14.11-5.42L14 19.44A10.77 10.77 0 0019.88 22l.48.06 2.87-2.85L27 20.72z"
  })), children);
});
var PhoneOff16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneOff16(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.19 18.56A25.66 25.66 0 015 6.08V6A1 1 0 016 5h5.28l1.5 3.77L9.94 11.64l.06.48a13 13 0 001.46 4.17l1.46-1.46a9.34 9.34 0 01-.84-2.52l2.13-2.15A2 2 0 0014.65 8L13.13 4.26A2 2 0 0011.27 3H5.76A3 3 0 003 6.23 28 28 0 007.79 20zM27.77 18.86L24 17.35a2 2 0 00-2.17.41l-2.17 2.15A9.17 9.17 0 0115.45 18L30 3.41 28.59 2 2 28.59 3.41 30l7-7c3.38 3.18 8.28 5.62 15.39 6H26a3 3 0 003-3V20.72A2 2 0 0027.77 18.86zM27 26v.06a1 1 0 01-1.06.94c-6.51-.37-11-2.54-14.11-5.42L14 19.44A10.77 10.77 0 0019.88 22l.48.06 2.87-2.85L27 20.72z"
  })), children);
});
var PhoneOffFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneOffFilled32(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.74 19.56l-2.52-1a2 2 0 00-2.15.44L20 21.06a9.93 9.93 0 01-5.35-2.29L30 3.41 28.59 2 2 28.59 3.41 30l7.93-7.92c3.24 3.12 7.89 5.5 14.55 5.92A2 2 0 0028 26V21.41A2 2 0 0026.74 19.56zM8.15 18.19l3.52-3.52A11.68 11.68 0 0110.85 12l2.07-2.07a2 2 0 00.44-2.15l-1-2.52A2 2 0 0010.5 4H6A2 2 0 004 6.22 29 29 0 008.15 18.19z"
  })), children);
});
var PhoneOffFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneOffFilled24(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.74 19.56l-2.52-1a2 2 0 00-2.15.44L20 21.06a9.93 9.93 0 01-5.35-2.29L30 3.41 28.59 2 2 28.59 3.41 30l7.93-7.92c3.24 3.12 7.89 5.5 14.55 5.92A2 2 0 0028 26V21.41A2 2 0 0026.74 19.56zM8.15 18.19l3.52-3.52A11.68 11.68 0 0110.85 12l2.07-2.07a2 2 0 00.44-2.15l-1-2.52A2 2 0 0010.5 4H6A2 2 0 004 6.22 29 29 0 008.15 18.19z"
  })), children);
});
var PhoneOffFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneOffFilled20(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.74 19.56l-2.52-1a2 2 0 00-2.15.44L20 21.06a9.93 9.93 0 01-5.35-2.29L30 3.41 28.59 2 2 28.59 3.41 30l7.93-7.92c3.24 3.12 7.89 5.5 14.55 5.92A2 2 0 0028 26V21.41A2 2 0 0026.74 19.56zM8.15 18.19l3.52-3.52A11.68 11.68 0 0110.85 12l2.07-2.07a2 2 0 00.44-2.15l-1-2.52A2 2 0 0010.5 4H6A2 2 0 004 6.22 29 29 0 008.15 18.19z"
  })), children);
});
var PhoneOffFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneOffFilled16(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.74 19.56l-2.52-1a2 2 0 00-2.15.44L20 21.06a9.93 9.93 0 01-5.35-2.29L30 3.41 28.59 2 2 28.59 3.41 30l7.93-7.92c3.24 3.12 7.89 5.5 14.55 5.92A2 2 0 0028 26V21.41A2 2 0 0026.74 19.56zM8.15 18.19l3.52-3.52A11.68 11.68 0 0110.85 12l2.07-2.07a2 2 0 00.44-2.15l-1-2.52A2 2 0 0010.5 4H6A2 2 0 004 6.22 29 29 0 008.15 18.19z"
  })), children);
});
var PhoneOutgoing32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneOutgoing32(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,29h-0.2C6.2,27.9,3.4,11.3,3,6.2C2.9,4.6,4.1,3.1,5.8,3C5.8,3,5.9,3,6,3h5.3c0.8,0,1.6,0.5,1.9,1.3L14.6,8\tc0.3,0.7,0.1,1.6-0.4,2.2l-2.1,2.1c0.7,3.9,3.7,6.9,7.6,7.6l2.2-2.1c0.6-0.6,1.4-0.7,2.2-0.4l3.8,1.5c0.7,0.3,1.2,1,1.2,1.9V26\tC29,27.7,27.7,29,26,29z M6,5C5.4,5,5,5.4,5,6c0,0,0,0.1,0,0.1C5.5,12,8.4,26,25.9,27c0.6,0,1-0.4,1.1-0.9c0,0,0,0,0-0.1v-5.3\tl-3.8-1.5l-2.9,2.9L19.9,22c-8.7-1.1-9.9-9.8-9.9-9.9l-0.1-0.5l2.8-2.9L11.3,5H6z"
  })), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 4L20 6 24.6 6 18 12.6 19.4 14 26 7.4 26 12 28 12 28 4z"
  })), children);
});
var PhoneOutgoing24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneOutgoing24(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,29h-0.2C6.2,27.9,3.4,11.3,3,6.2C2.9,4.6,4.1,3.1,5.8,3C5.8,3,5.9,3,6,3h5.3c0.8,0,1.6,0.5,1.9,1.3L14.6,8\tc0.3,0.7,0.1,1.6-0.4,2.2l-2.1,2.1c0.7,3.9,3.7,6.9,7.6,7.6l2.2-2.1c0.6-0.6,1.4-0.7,2.2-0.4l3.8,1.5c0.7,0.3,1.2,1,1.2,1.9V26\tC29,27.7,27.7,29,26,29z M6,5C5.4,5,5,5.4,5,6c0,0,0,0.1,0,0.1C5.5,12,8.4,26,25.9,27c0.6,0,1-0.4,1.1-0.9c0,0,0,0,0-0.1v-5.3\tl-3.8-1.5l-2.9,2.9L19.9,22c-8.7-1.1-9.9-9.8-9.9-9.9l-0.1-0.5l2.8-2.9L11.3,5H6z"
  })), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 4L20 6 24.6 6 18 12.6 19.4 14 26 7.4 26 12 28 12 28 4z"
  })), children);
});
var PhoneOutgoing20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneOutgoing20(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,29h-0.2C6.2,27.9,3.4,11.3,3,6.2C2.9,4.6,4.1,3.1,5.8,3C5.8,3,5.9,3,6,3h5.3c0.8,0,1.6,0.5,1.9,1.3L14.6,8\tc0.3,0.7,0.1,1.6-0.4,2.2l-2.1,2.1c0.7,3.9,3.7,6.9,7.6,7.6l2.2-2.1c0.6-0.6,1.4-0.7,2.2-0.4l3.8,1.5c0.7,0.3,1.2,1,1.2,1.9V26\tC29,27.7,27.7,29,26,29z M6,5C5.4,5,5,5.4,5,6c0,0,0,0.1,0,0.1C5.5,12,8.4,26,25.9,27c0.6,0,1-0.4,1.1-0.9c0,0,0,0,0-0.1v-5.3\tl-3.8-1.5l-2.9,2.9L19.9,22c-8.7-1.1-9.9-9.8-9.9-9.9l-0.1-0.5l2.8-2.9L11.3,5H6z"
  })), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 4L20 6 24.6 6 18 12.6 19.4 14 26 7.4 26 12 28 12 28 4z"
  })), children);
});
var PhoneOutgoing16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneOutgoing16(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,29h-0.2C6.2,27.9,3.4,11.3,3,6.2C2.9,4.6,4.1,3.1,5.8,3C5.8,3,5.9,3,6,3h5.3c0.8,0,1.6,0.5,1.9,1.3L14.6,8\tc0.3,0.7,0.1,1.6-0.4,2.2l-2.1,2.1c0.7,3.9,3.7,6.9,7.6,7.6l2.2-2.1c0.6-0.6,1.4-0.7,2.2-0.4l3.8,1.5c0.7,0.3,1.2,1,1.2,1.9V26\tC29,27.7,27.7,29,26,29z M6,5C5.4,5,5,5.4,5,6c0,0,0,0.1,0,0.1C5.5,12,8.4,26,25.9,27c0.6,0,1-0.4,1.1-0.9c0,0,0,0,0-0.1v-5.3\tl-3.8-1.5l-2.9,2.9L19.9,22c-8.7-1.1-9.9-9.8-9.9-9.9l-0.1-0.5l2.8-2.9L11.3,5H6z"
  })), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 4L20 6 24.6 6 18 12.6 19.4 14 26 7.4 26 12 28 12 28 4z"
  })), children);
});
var PhoneOutgoingFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneOutgoingFilled32(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.3333,21.4823l2.24-2.24a2.1667,2.1667,0,0,1,2.3368-.48l2.7281,1.0913A2.1666,2.1666,0,0,1,29,21.8659v4.9613a2.1668,2.1668,0,0,1-2.2843,2.1686C7.5938,27.8054,3.7321,11.6114,3.0146,5.4079A2.162,2.162,0,0,1,5.1692,3H10.042a2.1666,2.1666,0,0,1,2.0117,1.362L13.145,7.09a2.1666,2.1666,0,0,1-.48,2.3367l-2.24,2.24S11.6667,20.399,20.3333,21.4823Z"
  })), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 4L20 6 24.586 6 18 12.586 19.414 14 26 7.414 26 12 28 12 28 4 20 4z"
  })), children);
});
var PhoneOutgoingFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneOutgoingFilled24(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.3333,21.4823l2.24-2.24a2.1667,2.1667,0,0,1,2.3368-.48l2.7281,1.0913A2.1666,2.1666,0,0,1,29,21.8659v4.9613a2.1668,2.1668,0,0,1-2.2843,2.1686C7.5938,27.8054,3.7321,11.6114,3.0146,5.4079A2.162,2.162,0,0,1,5.1692,3H10.042a2.1666,2.1666,0,0,1,2.0117,1.362L13.145,7.09a2.1666,2.1666,0,0,1-.48,2.3367l-2.24,2.24S11.6667,20.399,20.3333,21.4823Z"
  })), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 4L20 6 24.586 6 18 12.586 19.414 14 26 7.414 26 12 28 12 28 4 20 4z"
  })), children);
});
var PhoneOutgoingFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneOutgoingFilled20(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.3333,21.4823l2.24-2.24a2.1667,2.1667,0,0,1,2.3368-.48l2.7281,1.0913A2.1666,2.1666,0,0,1,29,21.8659v4.9613a2.1668,2.1668,0,0,1-2.2843,2.1686C7.5938,27.8054,3.7321,11.6114,3.0146,5.4079A2.162,2.162,0,0,1,5.1692,3H10.042a2.1666,2.1666,0,0,1,2.0117,1.362L13.145,7.09a2.1666,2.1666,0,0,1-.48,2.3367l-2.24,2.24S11.6667,20.399,20.3333,21.4823Z"
  })), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 4L20 6 24.586 6 18 12.586 19.414 14 26 7.414 26 12 28 12 28 4 20 4z"
  })), children);
});
var PhoneOutgoingFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneOutgoingFilled16(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.3333,21.4823l2.24-2.24a2.1667,2.1667,0,0,1,2.3368-.48l2.7281,1.0913A2.1666,2.1666,0,0,1,29,21.8659v4.9613a2.1668,2.1668,0,0,1-2.2843,2.1686C7.5938,27.8054,3.7321,11.6114,3.0146,5.4079A2.162,2.162,0,0,1,5.1692,3H10.042a2.1666,2.1666,0,0,1,2.0117,1.362L13.145,7.09a2.1666,2.1666,0,0,1-.48,2.3367l-2.24,2.24S11.6667,20.399,20.3333,21.4823Z"
  })), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 4L20 6 24.586 6 18 12.586 19.414 14 26 7.414 26 12 28 12 28 4 20 4z"
  })), children);
});
var PhoneSettings32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneSettings32(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10V8H27.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,24,4.1011V2H22V4.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,18.1011,8H16v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,22,13.8989V16h2V13.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,27.8989,10Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,23,12Z"
  })), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,30h-.17C5.18,28.87,2.39,12.29,2,7.23A3,3,0,0,1,4.7611,4.0088Q4.88,4,5,4h5.27a2,2,0,0,1,1.86,1.26L13.65,9a2,2,0,0,1-.44,2.16l-2.13,2.15a9.36,9.36,0,0,0,7.58,7.6l2.17-2.15A2,2,0,0,1,23,18.35l3.77,1.51A2,2,0,0,1,28,21.72V27A3,3,0,0,1,25,30ZM5,6a1,1,0,0,0-1.0032.9968c0,.0278.001.0555.0032.0832C4.46,13,7.41,27,24.94,28a1,1,0,0,0,1.0581-.9382Q26,27.0309,26,27V21.72l-3.77-1.51-2.87,2.85L18.88,23C10.18,21.91,9,13.21,9,13.12l-.06-.48,2.84-2.87L10.28,6Z"
  })), children);
});
var PhoneSettings24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneSettings24(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10V8H27.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,24,4.1011V2H22V4.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,18.1011,8H16v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,22,13.8989V16h2V13.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,27.8989,10Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,23,12Z"
  })), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,30h-.17C5.18,28.87,2.39,12.29,2,7.23A3,3,0,0,1,4.7611,4.0088Q4.88,4,5,4h5.27a2,2,0,0,1,1.86,1.26L13.65,9a2,2,0,0,1-.44,2.16l-2.13,2.15a9.36,9.36,0,0,0,7.58,7.6l2.17-2.15A2,2,0,0,1,23,18.35l3.77,1.51A2,2,0,0,1,28,21.72V27A3,3,0,0,1,25,30ZM5,6a1,1,0,0,0-1.0032.9968c0,.0278.001.0555.0032.0832C4.46,13,7.41,27,24.94,28a1,1,0,0,0,1.0581-.9382Q26,27.0309,26,27V21.72l-3.77-1.51-2.87,2.85L18.88,23C10.18,21.91,9,13.21,9,13.12l-.06-.48,2.84-2.87L10.28,6Z"
  })), children);
});
var PhoneSettings20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneSettings20(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10V8H27.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,24,4.1011V2H22V4.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,18.1011,8H16v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,22,13.8989V16h2V13.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,27.8989,10Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,23,12Z"
  })), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,30h-.17C5.18,28.87,2.39,12.29,2,7.23A3,3,0,0,1,4.7611,4.0088Q4.88,4,5,4h5.27a2,2,0,0,1,1.86,1.26L13.65,9a2,2,0,0,1-.44,2.16l-2.13,2.15a9.36,9.36,0,0,0,7.58,7.6l2.17-2.15A2,2,0,0,1,23,18.35l3.77,1.51A2,2,0,0,1,28,21.72V27A3,3,0,0,1,25,30ZM5,6a1,1,0,0,0-1.0032.9968c0,.0278.001.0555.0032.0832C4.46,13,7.41,27,24.94,28a1,1,0,0,0,1.0581-.9382Q26,27.0309,26,27V21.72l-3.77-1.51-2.87,2.85L18.88,23C10.18,21.91,9,13.21,9,13.12l-.06-.48,2.84-2.87L10.28,6Z"
  })), children);
});
var PhoneSettings16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneSettings16(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10V8H27.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,24,4.1011V2H22V4.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,18.1011,8H16v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,22,13.8989V16h2V13.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,27.8989,10Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,23,12Z"
  })), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,30h-.17C5.18,28.87,2.39,12.29,2,7.23A3,3,0,0,1,4.7611,4.0088Q4.88,4,5,4h5.27a2,2,0,0,1,1.86,1.26L13.65,9a2,2,0,0,1-.44,2.16l-2.13,2.15a9.36,9.36,0,0,0,7.58,7.6l2.17-2.15A2,2,0,0,1,23,18.35l3.77,1.51A2,2,0,0,1,28,21.72V27A3,3,0,0,1,25,30ZM5,6a1,1,0,0,0-1.0032.9968c0,.0278.001.0555.0032.0832C4.46,13,7.41,27,24.94,28a1,1,0,0,0,1.0581-.9382Q26,27.0309,26,27V21.72l-3.77-1.51-2.87,2.85L18.88,23C10.18,21.91,9,13.21,9,13.12l-.06-.48,2.84-2.87L10.28,6Z"
  })), children);
});
var PhoneVoice32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneVoice32(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,13H22a3.0033,3.0033,0,0,0-3-3V8A5.0057,5.0057,0,0,1,24,13Z"
  })), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 13H26a7.0078 7.0078 0 00-7-7V4A9.01 9.01 0 0128 13zM26 29h-.17C6.18 27.87 3.39 11.29 3 6.23A3 3 0 015.7612 3.0088Q5.88 3 6 3h5.27a2 2 0 011.86 1.26L14.65 8a2 2 0 01-.44 2.16l-2.13 2.15a9.36 9.36 0 007.58 7.6l2.17-2.15A2 2 0 0124 17.35l3.77 1.51A2 2 0 0129 20.72V26A3 3 0 0126 29zM6 5a1 1 0 00-1.0032.9968q0 .0417.0032.0832C5.46 12 8.41 26 25.94 27a1 1 0 001.0582-.9382Q27 26.0309 27 26V20.72l-3.77-1.51-2.87 2.85L19.88 22C11.18 20.91 10 12.21 10 12.12l-.06-.48 2.84-2.87L11.28 5z"
  })), children);
});
var PhoneVoice24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneVoice24(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,13H22a3.0033,3.0033,0,0,0-3-3V8A5.0057,5.0057,0,0,1,24,13Z"
  })), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 13H26a7.0078 7.0078 0 00-7-7V4A9.01 9.01 0 0128 13zM26 29h-.17C6.18 27.87 3.39 11.29 3 6.23A3 3 0 015.7612 3.0088Q5.88 3 6 3h5.27a2 2 0 011.86 1.26L14.65 8a2 2 0 01-.44 2.16l-2.13 2.15a9.36 9.36 0 007.58 7.6l2.17-2.15A2 2 0 0124 17.35l3.77 1.51A2 2 0 0129 20.72V26A3 3 0 0126 29zM6 5a1 1 0 00-1.0032.9968q0 .0417.0032.0832C5.46 12 8.41 26 25.94 27a1 1 0 001.0582-.9382Q27 26.0309 27 26V20.72l-3.77-1.51-2.87 2.85L19.88 22C11.18 20.91 10 12.21 10 12.12l-.06-.48 2.84-2.87L11.28 5z"
  })), children);
});
var PhoneVoice20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneVoice20(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,13H22a3.0033,3.0033,0,0,0-3-3V8A5.0057,5.0057,0,0,1,24,13Z"
  })), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 13H26a7.0078 7.0078 0 00-7-7V4A9.01 9.01 0 0128 13zM26 29h-.17C6.18 27.87 3.39 11.29 3 6.23A3 3 0 015.7612 3.0088Q5.88 3 6 3h5.27a2 2 0 011.86 1.26L14.65 8a2 2 0 01-.44 2.16l-2.13 2.15a9.36 9.36 0 007.58 7.6l2.17-2.15A2 2 0 0124 17.35l3.77 1.51A2 2 0 0129 20.72V26A3 3 0 0126 29zM6 5a1 1 0 00-1.0032.9968q0 .0417.0032.0832C5.46 12 8.41 26 25.94 27a1 1 0 001.0582-.9382Q27 26.0309 27 26V20.72l-3.77-1.51-2.87 2.85L19.88 22C11.18 20.91 10 12.21 10 12.12l-.06-.48 2.84-2.87L11.28 5z"
  })), children);
});
var PhoneVoice16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneVoice16(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,13H22a3.0033,3.0033,0,0,0-3-3V8A5.0057,5.0057,0,0,1,24,13Z"
  })), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 13H26a7.0078 7.0078 0 00-7-7V4A9.01 9.01 0 0128 13zM26 29h-.17C6.18 27.87 3.39 11.29 3 6.23A3 3 0 015.7612 3.0088Q5.88 3 6 3h5.27a2 2 0 011.86 1.26L14.65 8a2 2 0 01-.44 2.16l-2.13 2.15a9.36 9.36 0 007.58 7.6l2.17-2.15A2 2 0 0124 17.35l3.77 1.51A2 2 0 0129 20.72V26A3 3 0 0126 29zM6 5a1 1 0 00-1.0032.9968q0 .0417.0032.0832C5.46 12 8.41 26 25.94 27a1 1 0 001.0582-.9382Q27 26.0309 27 26V20.72l-3.77-1.51-2.87 2.85L19.88 22C11.18 20.91 10 12.21 10 12.12l-.06-.48 2.84-2.87L11.28 5z"
  })), children);
});
var PhoneVoiceFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneVoiceFilled32(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,13H22a3.0033,3.0033,0,0,0-3-3V8A5.0057,5.0057,0,0,1,24,13Z"
  })), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 13H26a7.0078 7.0078 0 00-7-7V4A9.01 9.01 0 0128 13zM20.3333 21.4823l2.24-2.24a2.1667 2.1667 0 012.3368-.48l2.7281 1.0913A2.1666 2.1666 0 0129 21.8659v4.9613a2.1668 2.1668 0 01-2.2843 2.1686C7.5938 27.8054 3.7321 11.6114 3.0146 5.4079A2.162 2.162 0 015.1692 3H10.042a2.1666 2.1666 0 012.0117 1.362L13.145 7.09a2.1666 2.1666 0 01-.48 2.3367l-2.24 2.24S11.6667 20.399 20.3333 21.4823z"
  })), children);
});
var PhoneVoiceFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneVoiceFilled24(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,13H22a3.0033,3.0033,0,0,0-3-3V8A5.0057,5.0057,0,0,1,24,13Z"
  })), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 13H26a7.0078 7.0078 0 00-7-7V4A9.01 9.01 0 0128 13zM20.3333 21.4823l2.24-2.24a2.1667 2.1667 0 012.3368-.48l2.7281 1.0913A2.1666 2.1666 0 0129 21.8659v4.9613a2.1668 2.1668 0 01-2.2843 2.1686C7.5938 27.8054 3.7321 11.6114 3.0146 5.4079A2.162 2.162 0 015.1692 3H10.042a2.1666 2.1666 0 012.0117 1.362L13.145 7.09a2.1666 2.1666 0 01-.48 2.3367l-2.24 2.24S11.6667 20.399 20.3333 21.4823z"
  })), children);
});
var PhoneVoiceFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneVoiceFilled20(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,13H22a3.0033,3.0033,0,0,0-3-3V8A5.0057,5.0057,0,0,1,24,13Z"
  })), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 13H26a7.0078 7.0078 0 00-7-7V4A9.01 9.01 0 0128 13zM20.3333 21.4823l2.24-2.24a2.1667 2.1667 0 012.3368-.48l2.7281 1.0913A2.1666 2.1666 0 0129 21.8659v4.9613a2.1668 2.1668 0 01-2.2843 2.1686C7.5938 27.8054 3.7321 11.6114 3.0146 5.4079A2.162 2.162 0 015.1692 3H10.042a2.1666 2.1666 0 012.0117 1.362L13.145 7.09a2.1666 2.1666 0 01-.48 2.3367l-2.24 2.24S11.6667 20.399 20.3333 21.4823z"
  })), children);
});
var PhoneVoiceFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhoneVoiceFilled16(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,13H22a3.0033,3.0033,0,0,0-3-3V8A5.0057,5.0057,0,0,1,24,13Z"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 13H26a7.0078 7.0078 0 00-7-7V4A9.01 9.01 0 0128 13zM20.3333 21.4823l2.24-2.24a2.1667 2.1667 0 012.3368-.48l2.7281 1.0913A2.1666 2.1666 0 0129 21.8659v4.9613a2.1668 2.1668 0 01-2.2843 2.1686C7.5938 27.8054 3.7321 11.6114 3.0146 5.4079A2.162 2.162 0 015.1692 3H10.042a2.1666 2.1666 0 012.0117 1.362L13.145 7.09a2.1666 2.1666 0 01-.48 2.3367l-2.24 2.24S11.6667 20.399 20.3333 21.4823z"
  })), children);
});
var PhraseSentiment32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhraseSentiment32(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.303,10a2.6616,2.6616,0,0,0-1.9079.8058l-.3932.4054-.397-.4054a2.6615,2.6615,0,0,0-3.8157,0,2.7992,2.7992,0,0,0,0,3.8964L16.0019,19l4.2089-4.2978a2.7992,2.7992,0,0,0,0-3.8964A2.6616,2.6616,0,0,0,18.303,10Z"
  })), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V8a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,8V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V8A3.9988,3.9988,0,0,1,6,4H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var PhraseSentiment24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhraseSentiment24(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.303,10a2.6616,2.6616,0,0,0-1.9079.8058l-.3932.4054-.397-.4054a2.6615,2.6615,0,0,0-3.8157,0,2.7992,2.7992,0,0,0,0,3.8964L16.0019,19l4.2089-4.2978a2.7992,2.7992,0,0,0,0-3.8964A2.6616,2.6616,0,0,0,18.303,10Z"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V8a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,8V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V8A3.9988,3.9988,0,0,1,6,4H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var PhraseSentiment20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhraseSentiment20(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.303,10a2.6616,2.6616,0,0,0-1.9079.8058l-.3932.4054-.397-.4054a2.6615,2.6615,0,0,0-3.8157,0,2.7992,2.7992,0,0,0,0,3.8964L16.0019,19l4.2089-4.2978a2.7992,2.7992,0,0,0,0-3.8964A2.6616,2.6616,0,0,0,18.303,10Z"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V8a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,8V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V8A3.9988,3.9988,0,0,1,6,4H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var PhraseSentiment16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PhraseSentiment16(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.303,10a2.6616,2.6616,0,0,0-1.9079.8058l-.3932.4054-.397-.4054a2.6615,2.6615,0,0,0-3.8157,0,2.7992,2.7992,0,0,0,0,3.8964L16.0019,19l4.2089-4.2978a2.7992,2.7992,0,0,0,0-3.8964A2.6616,2.6616,0,0,0,18.303,10Z"
  })), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V8a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,8V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V8A3.9988,3.9988,0,0,1,6,4H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var PicnicArea32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PicnicArea32(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 12a4 4 0 114-4A4.0045 4.0045 0 0124 12zm0-6a2 2 0 102 2A2.0021 2.0021 0 0024 6zM26 22H21.8472L21.18 18H24V16H8v2h2.82l-.6668 4H6v2H9.82l-.6668 4H11.18l.6668-4h8.3056l.6668 4h2.0276L22.18 24H26zM12.18 22l.6665-4h6.3062l.6665 4z"
  })), children);
});
var PicnicArea24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PicnicArea24(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 12a4 4 0 114-4A4.0045 4.0045 0 0124 12zm0-6a2 2 0 102 2A2.0021 2.0021 0 0024 6zM26 22H21.8472L21.18 18H24V16H8v2h2.82l-.6668 4H6v2H9.82l-.6668 4H11.18l.6668-4h8.3056l.6668 4h2.0276L22.18 24H26zM12.18 22l.6665-4h6.3062l.6665 4z"
  })), children);
});
var PicnicArea20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PicnicArea20(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 12a4 4 0 114-4A4.0045 4.0045 0 0124 12zm0-6a2 2 0 102 2A2.0021 2.0021 0 0024 6zM26 22H21.8472L21.18 18H24V16H8v2h2.82l-.6668 4H6v2H9.82l-.6668 4H11.18l.6668-4h8.3056l.6668 4h2.0276L22.18 24H26zM12.18 22l.6665-4h6.3062l.6665 4z"
  })), children);
});
var PicnicArea16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PicnicArea16(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 12a4 4 0 114-4A4.0045 4.0045 0 0124 12zm0-6a2 2 0 102 2A2.0021 2.0021 0 0024 6zM26 22H21.8472L21.18 18H24V16H8v2h2.82l-.6668 4H6v2H9.82l-.6668 4H11.18l.6668-4h8.3056l.6668 4h2.0276L22.18 24H26zM12.18 22l.6665-4h6.3062l.6665 4z"
  })), children);
});
var PiggyBank32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PiggyBank32(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.5,14H20V12H18V11H16v1.0508A2.5,2.5,0,0,0,16.5,17h1a.5.5,0,0,1,0,1H14v2h2v1h2V19.9492A2.5,2.5,0,0,0,17.5,15h-1a.5.5,0,0,1,0-1Z"
  })), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,13H26.98A5.7789,5.7789,0,0,0,25,8.8525V5a1,1,0,0,0-1.6-.8L19.6665,7H15c-5.5095,0-9.4634,3.2412-9.9485,8H5a1.0009,1.0009,0,0,1-1-1V12H2v2a3.0033,3.0033,0,0,0,3,3h.07A9.1733,9.1733,0,0,0,9,23.5566V27a1,1,0,0,0,1,1h4a1,1,0,0,0,1-1V25h3v2a1,1,0,0,0,1,1h4a1,1,0,0,0,1-1V23.6372A5.0926,5.0926,0,0,0,26.8188,20H29a1,1,0,0,0,1-1V14A1,1,0,0,0,29,13Zm-1,5H25.124c-.3052,2.7529-.8235,3.4854-3.124,4.3154V26H20V23H13v3H11V22.3779A7.013,7.013,0,0,1,7,16c0-4.8354,4.0181-7,8-7h5.3335L23,7V9.7764c2.4182,1.8593,1.9126,3.186,2.0183,5.2236H28Z"
  })), children);
});
var PiggyBank24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PiggyBank24(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.5,14H20V12H18V11H16v1.0508A2.5,2.5,0,0,0,16.5,17h1a.5.5,0,0,1,0,1H14v2h2v1h2V19.9492A2.5,2.5,0,0,0,17.5,15h-1a.5.5,0,0,1,0-1Z"
  })), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,13H26.98A5.7789,5.7789,0,0,0,25,8.8525V5a1,1,0,0,0-1.6-.8L19.6665,7H15c-5.5095,0-9.4634,3.2412-9.9485,8H5a1.0009,1.0009,0,0,1-1-1V12H2v2a3.0033,3.0033,0,0,0,3,3h.07A9.1733,9.1733,0,0,0,9,23.5566V27a1,1,0,0,0,1,1h4a1,1,0,0,0,1-1V25h3v2a1,1,0,0,0,1,1h4a1,1,0,0,0,1-1V23.6372A5.0926,5.0926,0,0,0,26.8188,20H29a1,1,0,0,0,1-1V14A1,1,0,0,0,29,13Zm-1,5H25.124c-.3052,2.7529-.8235,3.4854-3.124,4.3154V26H20V23H13v3H11V22.3779A7.013,7.013,0,0,1,7,16c0-4.8354,4.0181-7,8-7h5.3335L23,7V9.7764c2.4182,1.8593,1.9126,3.186,2.0183,5.2236H28Z"
  })), children);
});
var PiggyBank20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PiggyBank20(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.5,14H20V12H18V11H16v1.0508A2.5,2.5,0,0,0,16.5,17h1a.5.5,0,0,1,0,1H14v2h2v1h2V19.9492A2.5,2.5,0,0,0,17.5,15h-1a.5.5,0,0,1,0-1Z"
  })), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,13H26.98A5.7789,5.7789,0,0,0,25,8.8525V5a1,1,0,0,0-1.6-.8L19.6665,7H15c-5.5095,0-9.4634,3.2412-9.9485,8H5a1.0009,1.0009,0,0,1-1-1V12H2v2a3.0033,3.0033,0,0,0,3,3h.07A9.1733,9.1733,0,0,0,9,23.5566V27a1,1,0,0,0,1,1h4a1,1,0,0,0,1-1V25h3v2a1,1,0,0,0,1,1h4a1,1,0,0,0,1-1V23.6372A5.0926,5.0926,0,0,0,26.8188,20H29a1,1,0,0,0,1-1V14A1,1,0,0,0,29,13Zm-1,5H25.124c-.3052,2.7529-.8235,3.4854-3.124,4.3154V26H20V23H13v3H11V22.3779A7.013,7.013,0,0,1,7,16c0-4.8354,4.0181-7,8-7h5.3335L23,7V9.7764c2.4182,1.8593,1.9126,3.186,2.0183,5.2236H28Z"
  })), children);
});
var PiggyBank16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PiggyBank16(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.5,14H20V12H18V11H16v1.0508A2.5,2.5,0,0,0,16.5,17h1a.5.5,0,0,1,0,1H14v2h2v1h2V19.9492A2.5,2.5,0,0,0,17.5,15h-1a.5.5,0,0,1,0-1Z"
  })), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,13H26.98A5.7789,5.7789,0,0,0,25,8.8525V5a1,1,0,0,0-1.6-.8L19.6665,7H15c-5.5095,0-9.4634,3.2412-9.9485,8H5a1.0009,1.0009,0,0,1-1-1V12H2v2a3.0033,3.0033,0,0,0,3,3h.07A9.1733,9.1733,0,0,0,9,23.5566V27a1,1,0,0,0,1,1h4a1,1,0,0,0,1-1V25h3v2a1,1,0,0,0,1,1h4a1,1,0,0,0,1-1V23.6372A5.0926,5.0926,0,0,0,26.8188,20H29a1,1,0,0,0,1-1V14A1,1,0,0,0,29,13Zm-1,5H25.124c-.3052,2.7529-.8235,3.4854-3.124,4.3154V26H20V23H13v3H11V22.3779A7.013,7.013,0,0,1,7,16c0-4.8354,4.0181-7,8-7h5.3335L23,7V9.7764c2.4182,1.8593,1.9126,3.186,2.0183,5.2236H28Z"
  })), children);
});
var PiggyBankSlot32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PiggyBankSlot32(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 11H20V13H13z"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,13H26.98A5.7791,5.7791,0,0,0,25,8.8525V5a1,1,0,0,0-1.6-.8L19.6665,7H15c-5.5095,0-9.4634,3.2412-9.9485,8H5a1.0009,1.0009,0,0,1-1-1V12H2v2a3.0033,3.0033,0,0,0,3,3h.07A9.1733,9.1733,0,0,0,9,23.5566V27a1,1,0,0,0,1,1h4a1,1,0,0,0,1-1V25h3v2a1,1,0,0,0,1,1h4a1,1,0,0,0,1-1V23.6372A5.0928,5.0928,0,0,0,26.8188,20H29a1,1,0,0,0,1-1V14A1,1,0,0,0,29,13Zm-1,5H25.124c-.3052,2.7529-.8235,3.4854-3.124,4.3154V26H20V23H13v3H11V22.3779A7.0129,7.0129,0,0,1,7,16c0-4.8354,4.0181-7,8-7h5.3335L23,7V9.7764c2.4182,1.8593,1.9126,3.186,2.0183,5.2236H28Z"
  })), children);
});
var PiggyBankSlot24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PiggyBankSlot24(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 11H20V13H13z"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,13H26.98A5.7791,5.7791,0,0,0,25,8.8525V5a1,1,0,0,0-1.6-.8L19.6665,7H15c-5.5095,0-9.4634,3.2412-9.9485,8H5a1.0009,1.0009,0,0,1-1-1V12H2v2a3.0033,3.0033,0,0,0,3,3h.07A9.1733,9.1733,0,0,0,9,23.5566V27a1,1,0,0,0,1,1h4a1,1,0,0,0,1-1V25h3v2a1,1,0,0,0,1,1h4a1,1,0,0,0,1-1V23.6372A5.0928,5.0928,0,0,0,26.8188,20H29a1,1,0,0,0,1-1V14A1,1,0,0,0,29,13Zm-1,5H25.124c-.3052,2.7529-.8235,3.4854-3.124,4.3154V26H20V23H13v3H11V22.3779A7.0129,7.0129,0,0,1,7,16c0-4.8354,4.0181-7,8-7h5.3335L23,7V9.7764c2.4182,1.8593,1.9126,3.186,2.0183,5.2236H28Z"
  })), children);
});
var PiggyBankSlot20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PiggyBankSlot20(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 11H20V13H13z"
  })), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,13H26.98A5.7791,5.7791,0,0,0,25,8.8525V5a1,1,0,0,0-1.6-.8L19.6665,7H15c-5.5095,0-9.4634,3.2412-9.9485,8H5a1.0009,1.0009,0,0,1-1-1V12H2v2a3.0033,3.0033,0,0,0,3,3h.07A9.1733,9.1733,0,0,0,9,23.5566V27a1,1,0,0,0,1,1h4a1,1,0,0,0,1-1V25h3v2a1,1,0,0,0,1,1h4a1,1,0,0,0,1-1V23.6372A5.0928,5.0928,0,0,0,26.8188,20H29a1,1,0,0,0,1-1V14A1,1,0,0,0,29,13Zm-1,5H25.124c-.3052,2.7529-.8235,3.4854-3.124,4.3154V26H20V23H13v3H11V22.3779A7.0129,7.0129,0,0,1,7,16c0-4.8354,4.0181-7,8-7h5.3335L23,7V9.7764c2.4182,1.8593,1.9126,3.186,2.0183,5.2236H28Z"
  })), children);
});
var PiggyBankSlot16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PiggyBankSlot16(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 11H20V13H13z"
  })), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,13H26.98A5.7791,5.7791,0,0,0,25,8.8525V5a1,1,0,0,0-1.6-.8L19.6665,7H15c-5.5095,0-9.4634,3.2412-9.9485,8H5a1.0009,1.0009,0,0,1-1-1V12H2v2a3.0033,3.0033,0,0,0,3,3h.07A9.1733,9.1733,0,0,0,9,23.5566V27a1,1,0,0,0,1,1h4a1,1,0,0,0,1-1V25h3v2a1,1,0,0,0,1,1h4a1,1,0,0,0,1-1V23.6372A5.0928,5.0928,0,0,0,26.8188,20H29a1,1,0,0,0,1-1V14A1,1,0,0,0,29,13Zm-1,5H25.124c-.3052,2.7529-.8235,3.4854-3.124,4.3154V26H20V23H13v3H11V22.3779A7.0129,7.0129,0,0,1,7,16c0-4.8354,4.0181-7,8-7h5.3335L23,7V9.7764c2.4182,1.8593,1.9126,3.186,2.0183,5.2236H28Z"
  })), children);
});
var Pills32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pills32(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14a7.94,7.94,0,0,0-4,1.0825V9A7,7,0,0,0,4,9V23a6.999,6.999,0,0,0,12.2855,4.5878A7.9969,7.9969,0,1,0,22,14Zm0,2a6.0046,6.0046,0,0,1,5.91,5H16.09A6.0046,6.0046,0,0,1,22,16ZM6,9A5,5,0,0,1,16,9v6H6Zm5,19a5.0059,5.0059,0,0,1-5-5V17h9.765a7.9566,7.9566,0,0,0-.7242,8.9315A4.9885,4.9885,0,0,1,11,28Zm11,0a6.0046,6.0046,0,0,1-5.91-5H27.91A6.0046,6.0046,0,0,1,22,28Z"
  })), children);
});
var Pills24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pills24(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14a7.94,7.94,0,0,0-4,1.0825V9A7,7,0,0,0,4,9V23a6.999,6.999,0,0,0,12.2855,4.5878A7.9969,7.9969,0,1,0,22,14Zm0,2a6.0046,6.0046,0,0,1,5.91,5H16.09A6.0046,6.0046,0,0,1,22,16ZM6,9A5,5,0,0,1,16,9v6H6Zm5,19a5.0059,5.0059,0,0,1-5-5V17h9.765a7.9566,7.9566,0,0,0-.7242,8.9315A4.9885,4.9885,0,0,1,11,28Zm11,0a6.0046,6.0046,0,0,1-5.91-5H27.91A6.0046,6.0046,0,0,1,22,28Z"
  })), children);
});
var Pills20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pills20(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14a7.94,7.94,0,0,0-4,1.0825V9A7,7,0,0,0,4,9V23a6.999,6.999,0,0,0,12.2855,4.5878A7.9969,7.9969,0,1,0,22,14Zm0,2a6.0046,6.0046,0,0,1,5.91,5H16.09A6.0046,6.0046,0,0,1,22,16ZM6,9A5,5,0,0,1,16,9v6H6Zm5,19a5.0059,5.0059,0,0,1-5-5V17h9.765a7.9566,7.9566,0,0,0-.7242,8.9315A4.9885,4.9885,0,0,1,11,28Zm11,0a6.0046,6.0046,0,0,1-5.91-5H27.91A6.0046,6.0046,0,0,1,22,28Z"
  })), children);
});
var Pills16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pills16(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14a7.94,7.94,0,0,0-4,1.0825V9A7,7,0,0,0,4,9V23a6.999,6.999,0,0,0,12.2855,4.5878A7.9969,7.9969,0,1,0,22,14Zm0,2a6.0046,6.0046,0,0,1,5.91,5H16.09A6.0046,6.0046,0,0,1,22,16ZM6,9A5,5,0,0,1,16,9v6H6Zm5,19a5.0059,5.0059,0,0,1-5-5V17h9.765a7.9566,7.9566,0,0,0-.7242,8.9315A4.9885,4.9885,0,0,1,11,28Zm11,0a6.0046,6.0046,0,0,1-5.91-5H27.91A6.0046,6.0046,0,0,1,22,28Z"
  })), children);
});
var PillsAdd32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PillsAdd32(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14a7.94,7.94,0,0,0-4,1.0825V9A7,7,0,0,0,4,9V23a6.9857,6.9857,0,0,0,12.2756,4.5768A7.9966,7.9966,0,1,0,22,14ZM11,4a5.0059,5.0059,0,0,1,5,5v6H6V9A5.0059,5.0059,0,0,1,11,4Zm0,24a5.0059,5.0059,0,0,1-5-5V17h9.765a7.9564,7.9564,0,0,0-.7239,8.9319A5.0147,5.0147,0,0,1,11,28Zm11,0a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,22,28Z"
  })), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 21L23 21 23 19 21 19 21 21 19 21 19 23 21 23 21 25 23 25 23 23 25 23 25 21z"
  })), children);
});
var PillsAdd24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PillsAdd24(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14a7.94,7.94,0,0,0-4,1.0825V9A7,7,0,0,0,4,9V23a6.9857,6.9857,0,0,0,12.2756,4.5768A7.9966,7.9966,0,1,0,22,14ZM11,4a5.0059,5.0059,0,0,1,5,5v6H6V9A5.0059,5.0059,0,0,1,11,4Zm0,24a5.0059,5.0059,0,0,1-5-5V17h9.765a7.9564,7.9564,0,0,0-.7239,8.9319A5.0147,5.0147,0,0,1,11,28Zm11,0a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,22,28Z"
  })), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 21L23 21 23 19 21 19 21 21 19 21 19 23 21 23 21 25 23 25 23 23 25 23 25 21z"
  })), children);
});
var PillsAdd20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PillsAdd20(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14a7.94,7.94,0,0,0-4,1.0825V9A7,7,0,0,0,4,9V23a6.9857,6.9857,0,0,0,12.2756,4.5768A7.9966,7.9966,0,1,0,22,14ZM11,4a5.0059,5.0059,0,0,1,5,5v6H6V9A5.0059,5.0059,0,0,1,11,4Zm0,24a5.0059,5.0059,0,0,1-5-5V17h9.765a7.9564,7.9564,0,0,0-.7239,8.9319A5.0147,5.0147,0,0,1,11,28Zm11,0a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,22,28Z"
  })), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 21L23 21 23 19 21 19 21 21 19 21 19 23 21 23 21 25 23 25 23 23 25 23 25 21z"
  })), children);
});
var PillsAdd16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PillsAdd16(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14a7.94,7.94,0,0,0-4,1.0825V9A7,7,0,0,0,4,9V23a6.9857,6.9857,0,0,0,12.2756,4.5768A7.9966,7.9966,0,1,0,22,14ZM11,4a5.0059,5.0059,0,0,1,5,5v6H6V9A5.0059,5.0059,0,0,1,11,4Zm0,24a5.0059,5.0059,0,0,1-5-5V17h9.765a7.9564,7.9564,0,0,0-.7239,8.9319A5.0147,5.0147,0,0,1,11,28Zm11,0a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,22,28Z"
  })), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 21L23 21 23 19 21 19 21 21 19 21 19 23 21 23 21 25 23 25 23 23 25 23 25 21z"
  })), children);
});
var PillsSubtract32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PillsSubtract32(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14a7.94,7.94,0,0,0-4,1.0825V9A7,7,0,0,0,4,9V23a6.9857,6.9857,0,0,0,12.2756,4.5768A7.9966,7.9966,0,1,0,22,14ZM11,4a5.0059,5.0059,0,0,1,5,5v6H6V9A5.0059,5.0059,0,0,1,11,4Zm0,24a5.0059,5.0059,0,0,1-5-5V17h9.765a7.9564,7.9564,0,0,0-.7239,8.9319A5.0147,5.0147,0,0,1,11,28Zm11,0a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,22,28Z"
  })), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 21H25V23H19z"
  })), children);
});
var PillsSubtract24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PillsSubtract24(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14a7.94,7.94,0,0,0-4,1.0825V9A7,7,0,0,0,4,9V23a6.9857,6.9857,0,0,0,12.2756,4.5768A7.9966,7.9966,0,1,0,22,14ZM11,4a5.0059,5.0059,0,0,1,5,5v6H6V9A5.0059,5.0059,0,0,1,11,4Zm0,24a5.0059,5.0059,0,0,1-5-5V17h9.765a7.9564,7.9564,0,0,0-.7239,8.9319A5.0147,5.0147,0,0,1,11,28Zm11,0a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,22,28Z"
  })), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 21H25V23H19z"
  })), children);
});
var PillsSubtract20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PillsSubtract20(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14a7.94,7.94,0,0,0-4,1.0825V9A7,7,0,0,0,4,9V23a6.9857,6.9857,0,0,0,12.2756,4.5768A7.9966,7.9966,0,1,0,22,14ZM11,4a5.0059,5.0059,0,0,1,5,5v6H6V9A5.0059,5.0059,0,0,1,11,4Zm0,24a5.0059,5.0059,0,0,1-5-5V17h9.765a7.9564,7.9564,0,0,0-.7239,8.9319A5.0147,5.0147,0,0,1,11,28Zm11,0a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,22,28Z"
  })), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 21H25V23H19z"
  })), children);
});
var PillsSubtract16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PillsSubtract16(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14a7.94,7.94,0,0,0-4,1.0825V9A7,7,0,0,0,4,9V23a6.9857,6.9857,0,0,0,12.2756,4.5768A7.9966,7.9966,0,1,0,22,14ZM11,4a5.0059,5.0059,0,0,1,5,5v6H6V9A5.0059,5.0059,0,0,1,11,4Zm0,24a5.0059,5.0059,0,0,1-5-5V17h9.765a7.9564,7.9564,0,0,0-.7239,8.9319A5.0147,5.0147,0,0,1,11,28Zm11,0a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,22,28Z"
  })), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 21H25V23H19z"
  })), children);
});
var Pin32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pin32(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.59,13.31,30,11.9,20,2,18.69,3.42,19.87,4.6,8.38,14.32,6.66,12.61,5.25,14l5.66,5.68L2,28.58,3.41,30l8.91-8.91L18,26.75l1.39-1.42-1.71-1.71L27.4,12.13ZM16.26,22.2,9.8,15.74,21.29,6,26,10.71Z"
  })), children);
});
var Pin24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pin24(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.59,13.31,30,11.9,20,2,18.69,3.42,19.87,4.6,8.38,14.32,6.66,12.61,5.25,14l5.66,5.68L2,28.58,3.41,30l8.91-8.91L18,26.75l1.39-1.42-1.71-1.71L27.4,12.13ZM16.26,22.2,9.8,15.74,21.29,6,26,10.71Z"
  })), children);
});
var Pin20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pin20(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.59,13.31,30,11.9,20,2,18.69,3.42,19.87,4.6,8.38,14.32,6.66,12.61,5.25,14l5.66,5.68L2,28.58,3.41,30l8.91-8.91L18,26.75l1.39-1.42-1.71-1.71L27.4,12.13ZM16.26,22.2,9.8,15.74,21.29,6,26,10.71Z"
  })), children);
});
var Pin16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pin16(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.59,13.31,30,11.9,20,2,18.69,3.42,19.87,4.6,8.38,14.32,6.66,12.61,5.25,14l5.66,5.68L2,28.58,3.41,30l8.91-8.91L18,26.75l1.39-1.42-1.71-1.71L27.4,12.13ZM16.26,22.2,9.8,15.74,21.29,6,26,10.71Z"
  })), children);
});
var PinFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PinFilled32(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5858,13.3137,30,11.9,20,2,18.6858,3.415l1.1858,1.1857L8.38,14.3225,6.6641,12.6067,5.25,14l5.6572,5.6773L2,28.5831,3.41,30l8.9111-8.9087L18,26.7482l1.3929-1.414L17.6765,23.618l9.724-11.4895Z"
  })), children);
});
var PinFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PinFilled24(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5858,13.3137,30,11.9,20,2,18.6858,3.415l1.1858,1.1857L8.38,14.3225,6.6641,12.6067,5.25,14l5.6572,5.6773L2,28.5831,3.41,30l8.9111-8.9087L18,26.7482l1.3929-1.414L17.6765,23.618l9.724-11.4895Z"
  })), children);
});
var PinFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PinFilled20(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5858,13.3137,30,11.9,20,2,18.6858,3.415l1.1858,1.1857L8.38,14.3225,6.6641,12.6067,5.25,14l5.6572,5.6773L2,28.5831,3.41,30l8.9111-8.9087L18,26.7482l1.3929-1.414L17.6765,23.618l9.724-11.4895Z"
  })), children);
});
var PinFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PinFilled16(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5858,13.3137,30,11.9,20,2,18.6858,3.415l1.1858,1.1857L8.38,14.3225,6.6641,12.6067,5.25,14l5.6572,5.6773L2,28.5831,3.41,30l8.9111-8.9087L18,26.7482l1.3929-1.414L17.6765,23.618l9.724-11.4895Z"
  })), children);
});
var Plane32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Plane32(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.37,14.75,20,10V6a4,4,0,0,0-8,0v4L2.63,14.75a1,1,0,0,0-.63.93v5a1,1,0,0,0,1,1,1,1,0,0,0,.29-.05L12,18v5L8.55,24.72a1,1,0,0,0-.55.9V29a1,1,0,0,0,1,1,.9.9,0,0,0,.28,0L16,28l6.72,2A.9.9,0,0,0,23,30a1,1,0,0,0,1-1V25.62a1,1,0,0,0-.55-.9L20,23V18l8.71,3.61a1,1,0,0,0,.29.05,1,1,0,0,0,1-1v-5A1,1,0,0,0,29.37,14.75ZM28,19.15,18,15v9.24l4,2v1.43l-6-1.75-6,1.75V26.24l4-2V15L4,19.15V16.3l10-5.07V6a2,2,0,0,1,4,0v5.23L28,16.3Z"
  })), children);
});
var Plane24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Plane24(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.37,14.75,20,10V6a4,4,0,0,0-8,0v4L2.63,14.75a1,1,0,0,0-.63.93v5a1,1,0,0,0,1,1,1,1,0,0,0,.29-.05L12,18v5L8.55,24.72a1,1,0,0,0-.55.9V29a1,1,0,0,0,1,1,.9.9,0,0,0,.28,0L16,28l6.72,2A.9.9,0,0,0,23,30a1,1,0,0,0,1-1V25.62a1,1,0,0,0-.55-.9L20,23V18l8.71,3.61a1,1,0,0,0,.29.05,1,1,0,0,0,1-1v-5A1,1,0,0,0,29.37,14.75ZM28,19.15,18,15v9.24l4,2v1.43l-6-1.75-6,1.75V26.24l4-2V15L4,19.15V16.3l10-5.07V6a2,2,0,0,1,4,0v5.23L28,16.3Z"
  })), children);
});
var Plane20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Plane20(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.37,14.75,20,10V6a4,4,0,0,0-8,0v4L2.63,14.75a1,1,0,0,0-.63.93v5a1,1,0,0,0,1,1,1,1,0,0,0,.29-.05L12,18v5L8.55,24.72a1,1,0,0,0-.55.9V29a1,1,0,0,0,1,1,.9.9,0,0,0,.28,0L16,28l6.72,2A.9.9,0,0,0,23,30a1,1,0,0,0,1-1V25.62a1,1,0,0,0-.55-.9L20,23V18l8.71,3.61a1,1,0,0,0,.29.05,1,1,0,0,0,1-1v-5A1,1,0,0,0,29.37,14.75ZM28,19.15,18,15v9.24l4,2v1.43l-6-1.75-6,1.75V26.24l4-2V15L4,19.15V16.3l10-5.07V6a2,2,0,0,1,4,0v5.23L28,16.3Z"
  })), children);
});
var Plane16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Plane16(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.37,14.75,20,10V6a4,4,0,0,0-8,0v4L2.63,14.75a1,1,0,0,0-.63.93v5a1,1,0,0,0,1,1,1,1,0,0,0,.29-.05L12,18v5L8.55,24.72a1,1,0,0,0-.55.9V29a1,1,0,0,0,1,1,.9.9,0,0,0,.28,0L16,28l6.72,2A.9.9,0,0,0,23,30a1,1,0,0,0,1-1V25.62a1,1,0,0,0-.55-.9L20,23V18l8.71,3.61a1,1,0,0,0,.29.05,1,1,0,0,0,1-1v-5A1,1,0,0,0,29.37,14.75ZM28,19.15,18,15v9.24l4,2v1.43l-6-1.75-6,1.75V26.24l4-2V15L4,19.15V16.3l10-5.07V6a2,2,0,0,1,4,0v5.23L28,16.3Z"
  })), children);
});
var PlanePrivate32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlanePrivate32(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5845,14.585l-3.12-1.8721A4.9951,4.9951,0,0,0,22.8921,12H7.7808L7.16,9.5151A1.9975,1.9975,0,0,0,5.2192,8H4a2.0023,2.0023,0,0,0-2,2v7a3.0033,3.0033,0,0,0,3,3h7v6a2.0023,2.0023,0,0,0,2,2h1.3071A2.0086,2.0086,0,0,0,17.18,26.7021L19.6929,20h7.3916a2.9152,2.9152,0,0,0,1.5-5.415ZM27.0845,18H18.3071l-3,8H14V18H5a1.0009,1.0009,0,0,1-1-1V10H5.2192l1,4H10v2h2V14h3v2h2V14h3v2h2V14h.8921a2.9977,2.9977,0,0,1,1.5434.4277l3.12,1.8721a.9154.9154,0,0,1-.4712,1.7Z"
  })), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,4h1.3228l2.4,6h2.1545L17.18,3.2573A1.9906,1.9906,0,0,0,15.3228,2H14a2.0023,2.0023,0,0,0-2,2v6h2Z"
  })), children);
});
var PlanePrivate24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlanePrivate24(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5845,14.585l-3.12-1.8721A4.9951,4.9951,0,0,0,22.8921,12H7.7808L7.16,9.5151A1.9975,1.9975,0,0,0,5.2192,8H4a2.0023,2.0023,0,0,0-2,2v7a3.0033,3.0033,0,0,0,3,3h7v6a2.0023,2.0023,0,0,0,2,2h1.3071A2.0086,2.0086,0,0,0,17.18,26.7021L19.6929,20h7.3916a2.9152,2.9152,0,0,0,1.5-5.415ZM27.0845,18H18.3071l-3,8H14V18H5a1.0009,1.0009,0,0,1-1-1V10H5.2192l1,4H10v2h2V14h3v2h2V14h3v2h2V14h.8921a2.9977,2.9977,0,0,1,1.5434.4277l3.12,1.8721a.9154.9154,0,0,1-.4712,1.7Z"
  })), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,4h1.3228l2.4,6h2.1545L17.18,3.2573A1.9906,1.9906,0,0,0,15.3228,2H14a2.0023,2.0023,0,0,0-2,2v6h2Z"
  })), children);
});
var PlanePrivate20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlanePrivate20(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5845,14.585l-3.12-1.8721A4.9951,4.9951,0,0,0,22.8921,12H7.7808L7.16,9.5151A1.9975,1.9975,0,0,0,5.2192,8H4a2.0023,2.0023,0,0,0-2,2v7a3.0033,3.0033,0,0,0,3,3h7v6a2.0023,2.0023,0,0,0,2,2h1.3071A2.0086,2.0086,0,0,0,17.18,26.7021L19.6929,20h7.3916a2.9152,2.9152,0,0,0,1.5-5.415ZM27.0845,18H18.3071l-3,8H14V18H5a1.0009,1.0009,0,0,1-1-1V10H5.2192l1,4H10v2h2V14h3v2h2V14h3v2h2V14h.8921a2.9977,2.9977,0,0,1,1.5434.4277l3.12,1.8721a.9154.9154,0,0,1-.4712,1.7Z"
  })), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,4h1.3228l2.4,6h2.1545L17.18,3.2573A1.9906,1.9906,0,0,0,15.3228,2H14a2.0023,2.0023,0,0,0-2,2v6h2Z"
  })), children);
});
var PlanePrivate16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlanePrivate16(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5845,14.585l-3.12-1.8721A4.9951,4.9951,0,0,0,22.8921,12H7.7808L7.16,9.5151A1.9975,1.9975,0,0,0,5.2192,8H4a2.0023,2.0023,0,0,0-2,2v7a3.0033,3.0033,0,0,0,3,3h7v6a2.0023,2.0023,0,0,0,2,2h1.3071A2.0086,2.0086,0,0,0,17.18,26.7021L19.6929,20h7.3916a2.9152,2.9152,0,0,0,1.5-5.415ZM27.0845,18H18.3071l-3,8H14V18H5a1.0009,1.0009,0,0,1-1-1V10H5.2192l1,4H10v2h2V14h3v2h2V14h3v2h2V14h.8921a2.9977,2.9977,0,0,1,1.5434.4277l3.12,1.8721a.9154.9154,0,0,1-.4712,1.7Z"
  })), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,4h1.3228l2.4,6h2.1545L17.18,3.2573A1.9906,1.9906,0,0,0,15.3228,2H14a2.0023,2.0023,0,0,0-2,2v6h2Z"
  })), children);
});
var PlaneSea32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlaneSea32(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H28a4.9316 4.9316 0 01-4-1.9873 5.0192 5.0192 0 01-8 0 5.0192 5.0192 0 01-8 0A4.9316 4.9316 0 014 30H2V28H4a3.44 3.44 0 003.0532-2.3215A.9712.9712 0 018 25a1.0069 1.0069 0 01.9487.6838A3.4381 3.4381 0 0012 28a3.44 3.44 0 003.0532-2.3215A.99.99 0 0116 25a1.0069 1.0069 0 01.9487.6838A3.4381 3.4381 0 0020 28a3.44 3.44 0 003.0532-2.3215 1 1 0 011.8955.0053A3.4381 3.4381 0 0028 28h2zM28 6v4H25.5L23.4 7.2A3.0129 3.0129 0 0021 6H15a3.0033 3.0033 0 00-3 3v1H8.6182L7.8945 8.5527l-1-2A1 1 0 006 6H3A1 1 0 002 7v6a3.0033 3.0033 0 003 3h6.82l-.6666 4H7a1 1 0 000 2H27a1 1 0 000-2H22.847L22.18 16h.1629a4.9662 4.9662 0 003.5351-1.4648L28 12.4141V16h2V6zM14 9a1.0009 1.0009 0 011-1h6a1.0045 1.0045 0 01.8.4L23 10H14zm6.82 11H13.18l.6666-4h6.306zm1.5237-6H5a1.0009 1.0009 0 01-1-1V8H5.3818l.7237 1.4473L7.3818 12h18.204l-1.1214 1.1211A2.9789 2.9789 0 0122.3433 14z"
  })), children);
});
var PlaneSea24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlaneSea24(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H28a4.9316 4.9316 0 01-4-1.9873 5.0192 5.0192 0 01-8 0 5.0192 5.0192 0 01-8 0A4.9316 4.9316 0 014 30H2V28H4a3.44 3.44 0 003.0532-2.3215A.9712.9712 0 018 25a1.0069 1.0069 0 01.9487.6838A3.4381 3.4381 0 0012 28a3.44 3.44 0 003.0532-2.3215A.99.99 0 0116 25a1.0069 1.0069 0 01.9487.6838A3.4381 3.4381 0 0020 28a3.44 3.44 0 003.0532-2.3215 1 1 0 011.8955.0053A3.4381 3.4381 0 0028 28h2zM28 6v4H25.5L23.4 7.2A3.0129 3.0129 0 0021 6H15a3.0033 3.0033 0 00-3 3v1H8.6182L7.8945 8.5527l-1-2A1 1 0 006 6H3A1 1 0 002 7v6a3.0033 3.0033 0 003 3h6.82l-.6666 4H7a1 1 0 000 2H27a1 1 0 000-2H22.847L22.18 16h.1629a4.9662 4.9662 0 003.5351-1.4648L28 12.4141V16h2V6zM14 9a1.0009 1.0009 0 011-1h6a1.0045 1.0045 0 01.8.4L23 10H14zm6.82 11H13.18l.6666-4h6.306zm1.5237-6H5a1.0009 1.0009 0 01-1-1V8H5.3818l.7237 1.4473L7.3818 12h18.204l-1.1214 1.1211A2.9789 2.9789 0 0122.3433 14z"
  })), children);
});
var PlaneSea20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlaneSea20(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H28a4.9316 4.9316 0 01-4-1.9873 5.0192 5.0192 0 01-8 0 5.0192 5.0192 0 01-8 0A4.9316 4.9316 0 014 30H2V28H4a3.44 3.44 0 003.0532-2.3215A.9712.9712 0 018 25a1.0069 1.0069 0 01.9487.6838A3.4381 3.4381 0 0012 28a3.44 3.44 0 003.0532-2.3215A.99.99 0 0116 25a1.0069 1.0069 0 01.9487.6838A3.4381 3.4381 0 0020 28a3.44 3.44 0 003.0532-2.3215 1 1 0 011.8955.0053A3.4381 3.4381 0 0028 28h2zM28 6v4H25.5L23.4 7.2A3.0129 3.0129 0 0021 6H15a3.0033 3.0033 0 00-3 3v1H8.6182L7.8945 8.5527l-1-2A1 1 0 006 6H3A1 1 0 002 7v6a3.0033 3.0033 0 003 3h6.82l-.6666 4H7a1 1 0 000 2H27a1 1 0 000-2H22.847L22.18 16h.1629a4.9662 4.9662 0 003.5351-1.4648L28 12.4141V16h2V6zM14 9a1.0009 1.0009 0 011-1h6a1.0045 1.0045 0 01.8.4L23 10H14zm6.82 11H13.18l.6666-4h6.306zm1.5237-6H5a1.0009 1.0009 0 01-1-1V8H5.3818l.7237 1.4473L7.3818 12h18.204l-1.1214 1.1211A2.9789 2.9789 0 0122.3433 14z"
  })), children);
});
var PlaneSea16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlaneSea16(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H28a4.9316 4.9316 0 01-4-1.9873 5.0192 5.0192 0 01-8 0 5.0192 5.0192 0 01-8 0A4.9316 4.9316 0 014 30H2V28H4a3.44 3.44 0 003.0532-2.3215A.9712.9712 0 018 25a1.0069 1.0069 0 01.9487.6838A3.4381 3.4381 0 0012 28a3.44 3.44 0 003.0532-2.3215A.99.99 0 0116 25a1.0069 1.0069 0 01.9487.6838A3.4381 3.4381 0 0020 28a3.44 3.44 0 003.0532-2.3215 1 1 0 011.8955.0053A3.4381 3.4381 0 0028 28h2zM28 6v4H25.5L23.4 7.2A3.0129 3.0129 0 0021 6H15a3.0033 3.0033 0 00-3 3v1H8.6182L7.8945 8.5527l-1-2A1 1 0 006 6H3A1 1 0 002 7v6a3.0033 3.0033 0 003 3h6.82l-.6666 4H7a1 1 0 000 2H27a1 1 0 000-2H22.847L22.18 16h.1629a4.9662 4.9662 0 003.5351-1.4648L28 12.4141V16h2V6zM14 9a1.0009 1.0009 0 011-1h6a1.0045 1.0045 0 01.8.4L23 10H14zm6.82 11H13.18l.6666-4h6.306zm1.5237-6H5a1.0009 1.0009 0 01-1-1V8H5.3818l.7237 1.4473L7.3818 12h18.204l-1.1214 1.1211A2.9789 2.9789 0 0122.3433 14z"
  })), children);
});
var Play32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Play32(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,28a1,1,0,0,1-1-1V5a1,1,0,0,1,1.4819-.8763l20,11a1,1,0,0,1,0,1.7525l-20,11A1.0005,1.0005,0,0,1,7,28ZM8,6.6909V25.3088L24.9248,16Z"
  })), children);
});
var Play24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Play24(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,28a1,1,0,0,1-1-1V5a1,1,0,0,1,1.4819-.8763l20,11a1,1,0,0,1,0,1.7525l-20,11A1.0005,1.0005,0,0,1,7,28ZM8,6.6909V25.3088L24.9248,16Z"
  })), children);
});
var Play20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Play20(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,28a1,1,0,0,1-1-1V5a1,1,0,0,1,1.4819-.8763l20,11a1,1,0,0,1,0,1.7525l-20,11A1.0005,1.0005,0,0,1,7,28ZM8,6.6909V25.3088L24.9248,16Z"
  })), children);
});
var Play16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Play16(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.5,14C3.2,14,3,13.8,3,13.5v-11c0-0.2,0.1-0.3,0.2-0.4C3.4,2,3.6,2,3.8,2.1l9.5,5.5c0.2,0.1,0.3,0.4,0.2,0.7\tc0,0.1-0.1,0.1-0.2,0.2l-9.5,5.5C3.7,14,3.6,14,3.5,14z M4,3.4v9.3L12,8L4,3.4z"
  })), children);
});
var PlayFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlayFilled32(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11,23a1,1,0,0,1-1-1V10a1,1,0,0,1,1.4473-.8945l12,6a1,1,0,0,1,0,1.789l-12,6A1.001,1.001,0,0,1,11,23Z"
  })), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm7.4473,14.8945-12,6A1,1,0,0,1,10,22V10a1,1,0,0,1,1.4473-.8945l12,6a1,1,0,0,1,0,1.789Z"
  })), children);
});
var PlayFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlayFilled24(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11,23a1,1,0,0,1-1-1V10a1,1,0,0,1,1.4473-.8945l12,6a1,1,0,0,1,0,1.789l-12,6A1.001,1.001,0,0,1,11,23Z"
  })), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm7.4473,14.8945-12,6A1,1,0,0,1,10,22V10a1,1,0,0,1,1.4473-.8945l12,6a1,1,0,0,1,0,1.789Z"
  })), children);
});
var PlayFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlayFilled20(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11,23a1,1,0,0,1-1-1V10a1,1,0,0,1,1.4473-.8945l12,6a1,1,0,0,1,0,1.789l-12,6A1.001,1.001,0,0,1,11,23Z"
  })), _path390 || (_path390 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm7.4473,14.8945-12,6A1,1,0,0,1,10,22V10a1,1,0,0,1,1.4473-.8945l12,6a1,1,0,0,1,0,1.789Z"
  })), children);
});
var PlayFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlayFilled16(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path391 || (_path391 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,1C4.1,1,1,4.1,1,8s3.1,7,7,7s7-3.1,7-7S11.9,1,8,1z M11.7,8.4l-5.5,3c-0.2,0.1-0.3,0.1-0.5,0c-0.2-0.1-0.2-0.3-0.2-0.4V5\tc0-0.2,0.1-0.3,0.2-0.4c0.2-0.1,0.3-0.1,0.5,0l5.5,3C12,7.7,12.1,8,11.9,8.2C11.9,8.3,11.8,8.4,11.7,8.4L11.7,8.4z"
  })), children);
});
var PlayFilledAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlayFilledAlt32(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path392 || (_path392 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,28a1,1,0,0,1-1-1V5a1,1,0,0,1,1.4819-.8763l20,11a1,1,0,0,1,0,1.7525l-20,11A1.0005,1.0005,0,0,1,7,28Z"
  })), children);
});
var PlayFilledAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlayFilledAlt24(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path393 || (_path393 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,28a1,1,0,0,1-1-1V5a1,1,0,0,1,1.4819-.8763l20,11a1,1,0,0,1,0,1.7525l-20,11A1.0005,1.0005,0,0,1,7,28Z"
  })), children);
});
var PlayFilledAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlayFilledAlt20(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path394 || (_path394 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,28a1,1,0,0,1-1-1V5a1,1,0,0,1,1.4819-.8763l20,11a1,1,0,0,1,0,1.7525l-20,11A1.0005,1.0005,0,0,1,7,28Z"
  })), children);
});
var PlayFilledAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlayFilledAlt16(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path395 || (_path395 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,28a1,1,0,0,1-1-1V5a1,1,0,0,1,1.4819-.8763l20,11a1,1,0,0,1,0,1.7525l-20,11A1.0005,1.0005,0,0,1,7,28Z"
  })), children);
});
var PlayOutline32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlayOutline32(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path396 || (_path396 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,23a1,1,0,0,1-1-1V10a1,1,0,0,1,1.4473-.8945l12,6a1,1,0,0,1,0,1.789l-12,6A1.001,1.001,0,0,1,11,23Zm1-11.3821v8.7642L20.7642,16Z"
  })), _path397 || (_path397 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12,12,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), children);
});
var PlayOutline24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlayOutline24(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path398 || (_path398 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,23a1,1,0,0,1-1-1V10a1,1,0,0,1,1.4473-.8945l12,6a1,1,0,0,1,0,1.789l-12,6A1.001,1.001,0,0,1,11,23Zm1-11.3821v8.7642L20.7642,16Z"
  })), _path399 || (_path399 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12,12,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), children);
});
var PlayOutline20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlayOutline20(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path400 || (_path400 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,23a1,1,0,0,1-1-1V10a1,1,0,0,1,1.4473-.8945l12,6a1,1,0,0,1,0,1.789l-12,6A1.001,1.001,0,0,1,11,23Zm1-11.3821v8.7642L20.7642,16Z"
  })), _path401 || (_path401 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12,12,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), children);
});
var PlayOutline16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlayOutline16(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path402 || (_path402 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,2c3.3,0,6,2.7,6,6s-2.7,6-6,6s-6-2.7-6-6S4.7,2,8,2 M8,1C4.1,1,1,4.1,1,8s3.1,7,7,7s7-3.1,7-7S11.9,1,8,1z"
  })), _path403 || (_path403 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,11.5c-0.1,0-0.2,0-0.3-0.1c-0.2-0.1-0.2-0.3-0.2-0.4V5c0-0.2,0.1-0.3,0.2-0.4c0.2-0.1,0.3-0.1,0.5,0l5.5,3\tC12,7.7,12.1,8,11.9,8.2c0,0.1-0.1,0.2-0.2,0.2l-5.5,3C6.2,11.5,6.1,11.5,6,11.5z M6.5,5.8v4.3l4-2.2L6.5,5.8z"
  })), children);
});
var PlayOutlineFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlayOutlineFilled32(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path404 || (_path404 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11,23a1,1,0,0,1-1-1V10a1,1,0,0,1,1.4473-.8945l12,6a1,1,0,0,1,0,1.789l-12,6A1.001,1.001,0,0,1,11,23Zm1-11.3821v8.7642L20.7642,16Z"
  })), _path405 || (_path405 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 20.382L20.764 16 12 11.618 12 20.382z"
  })), _path406 || (_path406 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm7.4473,14.8945-12,6A1,1,0,0,1,10,22V10a1,1,0,0,1,1.4473-.8945l12,6a1,1,0,0,1,0,1.789Z"
  })), children);
});
var PlayOutlineFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlayOutlineFilled24(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path407 || (_path407 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11,23a1,1,0,0,1-1-1V10a1,1,0,0,1,1.4473-.8945l12,6a1,1,0,0,1,0,1.789l-12,6A1.001,1.001,0,0,1,11,23Zm1-11.3821v8.7642L20.7642,16Z"
  })), _path408 || (_path408 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 20.382L20.764 16 12 11.618 12 20.382z"
  })), _path409 || (_path409 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm7.4473,14.8945-12,6A1,1,0,0,1,10,22V10a1,1,0,0,1,1.4473-.8945l12,6a1,1,0,0,1,0,1.789Z"
  })), children);
});
var PlayOutlineFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlayOutlineFilled20(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path410 || (_path410 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11,23a1,1,0,0,1-1-1V10a1,1,0,0,1,1.4473-.8945l12,6a1,1,0,0,1,0,1.789l-12,6A1.001,1.001,0,0,1,11,23Zm1-11.3821v8.7642L20.7642,16Z"
  })), _path411 || (_path411 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 20.382L20.764 16 12 11.618 12 20.382z"
  })), _path412 || (_path412 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm7.4473,14.8945-12,6A1,1,0,0,1,10,22V10a1,1,0,0,1,1.4473-.8945l12,6a1,1,0,0,1,0,1.789Z"
  })), children);
});
var PlayOutlineFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlayOutlineFilled16(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path413 || (_path413 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,1C4.1,1,1,4.1,1,8s3.1,7,7,7s7-3.1,7-7S11.9,1,8,1z M11.7,8.4l-5.5,3c-0.2,0.1-0.3,0.1-0.5,0c-0.2-0.1-0.2-0.3-0.2-0.4V5\tc0-0.2,0.1-0.3,0.2-0.4c0.2-0.1,0.3-0.1,0.5,0l5.5,3C12,7.7,12.1,8,11.9,8.2C11.9,8.3,11.8,8.4,11.7,8.4L11.7,8.4z"
  })), _path414 || (_path414 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.5 10.2L10.5 8 6.5 5.8z"
  })), children);
});
var Playlist32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Playlist32(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path415 || (_path415 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 6H22V8H4zM4 12H22V14H4zM4 18H16V20H4zM21 18L28 23 21 28 21 18z"
  })), children);
});
var Playlist24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Playlist24(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path416 || (_path416 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 6H22V8H4zM4 12H22V14H4zM4 18H16V20H4zM21 18L28 23 21 28 21 18z"
  })), children);
});
var Playlist20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Playlist20(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path417 || (_path417 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 6H22V8H4zM4 12H22V14H4zM4 18H16V20H4zM21 18L28 23 21 28 21 18z"
  })), children);
});
var Playlist16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Playlist16(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path418 || (_path418 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 6H22V8H4zM4 12H22V14H4zM4 18H16V20H4zM21 18L28 23 21 28 21 18z"
  })), children);
});
var Plug32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Plug32(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path419 || (_path419 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,8H21V2H19V8H13V2H11V8H10a2,2,0,0,0-2,2v6a8.0073,8.0073,0,0,0,7,7.9307V30h2V23.9307A8.0073,8.0073,0,0,0,24,16V10A2,2,0,0,0,22,8Zm0,8a6,6,0,0,1-12,0V10H22Z"
  })), children);
});
var Plug24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Plug24(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path420 || (_path420 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,8H21V2H19V8H13V2H11V8H10a2,2,0,0,0-2,2v6a8.0073,8.0073,0,0,0,7,7.9307V30h2V23.9307A8.0073,8.0073,0,0,0,24,16V10A2,2,0,0,0,22,8Zm0,8a6,6,0,0,1-12,0V10H22Z"
  })), children);
});
var Plug20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Plug20(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path421 || (_path421 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,8H21V2H19V8H13V2H11V8H10a2,2,0,0,0-2,2v6a8.0073,8.0073,0,0,0,7,7.9307V30h2V23.9307A8.0073,8.0073,0,0,0,24,16V10A2,2,0,0,0,22,8Zm0,8a6,6,0,0,1-12,0V10H22Z"
  })), children);
});
var Plug16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Plug16(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path422 || (_path422 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,8H21V2H19V8H13V2H11V8H10a2,2,0,0,0-2,2v6a8.0073,8.0073,0,0,0,7,7.9307V30h2V23.9307A8.0073,8.0073,0,0,0,24,16V10A2,2,0,0,0,22,8Zm0,8a6,6,0,0,1-12,0V10H22Z"
  })), children);
});
var PlugFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlugFilled32(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path423 || (_path423 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,8H21V2H19V8H13V2H11V8H10a2,2,0,0,0-2,2v6a8.0073,8.0073,0,0,0,7,7.9307V30h2V23.9307A8.0073,8.0073,0,0,0,24,16V10A2,2,0,0,0,22,8Z"
  })), children);
});
var PlugFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlugFilled24(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path424 || (_path424 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,8H21V2H19V8H13V2H11V8H10a2,2,0,0,0-2,2v6a8.0073,8.0073,0,0,0,7,7.9307V30h2V23.9307A8.0073,8.0073,0,0,0,24,16V10A2,2,0,0,0,22,8Z"
  })), children);
});
var PlugFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlugFilled20(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path425 || (_path425 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,8H21V2H19V8H13V2H11V8H10a2,2,0,0,0-2,2v6a8.0073,8.0073,0,0,0,7,7.9307V30h2V23.9307A8.0073,8.0073,0,0,0,24,16V10A2,2,0,0,0,22,8Z"
  })), children);
});
var PlugFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PlugFilled16(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path426 || (_path426 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,8H21V2H19V8H13V2H11V8H10a2,2,0,0,0-2,2v6a8.0073,8.0073,0,0,0,7,7.9307V30h2V23.9307A8.0073,8.0073,0,0,0,24,16V10A2,2,0,0,0,22,8Z"
  })), children);
});
var Png32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Png32(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path427 || (_path427 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2 2 0 01-2-2V11a2 2 0 012-2h6v2H24V21h4V17H26V15h4zM18 19L14.32 9 12 9 12 23 14 23 14 13 17.68 23 20 23 20 9 18 9 18 19zM4 23H2V9H8a2 2 0 012 2v5a2 2 0 01-2 2H4zm0-7H8V11H4z"
  })), children);
});
var Png24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Png24(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path428 || (_path428 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2 2 0 01-2-2V11a2 2 0 012-2h6v2H24V21h4V17H26V15h4zM18 19L14.32 9 12 9 12 23 14 23 14 13 17.68 23 20 23 20 9 18 9 18 19zM4 23H2V9H8a2 2 0 012 2v5a2 2 0 01-2 2H4zm0-7H8V11H4z"
  })), children);
});
var Png20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Png20(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path429 || (_path429 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2 2 0 01-2-2V11a2 2 0 012-2h6v2H24V21h4V17H26V15h4zM18 19L14.32 9 12 9 12 23 14 23 14 13 17.68 23 20 23 20 9 18 9 18 19zM4 23H2V9H8a2 2 0 012 2v5a2 2 0 01-2 2H4zm0-7H8V11H4z"
  })), children);
});
var Png16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Png16(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path430 || (_path430 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2 2 0 01-2-2V11a2 2 0 012-2h6v2H24V21h4V17H26V15h4zM18 19L14.32 9 12 9 12 23 14 23 14 13 17.68 23 20 23 20 9 18 9 18 19zM4 23H2V9H8a2 2 0 012 2v5a2 2 0 01-2 2H4zm0-7H8V11H4z"
  })), children);
});
var PointOfPresence32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PointOfPresence32(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path431 || (_path431 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H18a2.0021 2.0021 0 01-2-2V18a2.0021 2.0021 0 012-2h2v2H18V28H28V18H26V16h2a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0128 30zM14 16H4a2.0021 2.0021 0 01-2-2V4A2.0021 2.0021 0 014 2H14a2.0021 2.0021 0 012 2V6H14V4H4V14H14V12h2v2A2.0021 2.0021 0 0114 16z"
  })), _path432 || (_path432 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,9a2.9926,2.9926,0,0,0-5.8157-1H9v2H20.1843A2.9939,2.9939,0,0,0,22,11.8154V23h2V11.8159A2.9958,2.9958,0,0,0,26,9Zm-3,1a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,23,10Z"
  })), children);
});
var PointOfPresence24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PointOfPresence24(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path433 || (_path433 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H18a2.0021 2.0021 0 01-2-2V18a2.0021 2.0021 0 012-2h2v2H18V28H28V18H26V16h2a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0128 30zM14 16H4a2.0021 2.0021 0 01-2-2V4A2.0021 2.0021 0 014 2H14a2.0021 2.0021 0 012 2V6H14V4H4V14H14V12h2v2A2.0021 2.0021 0 0114 16z"
  })), _path434 || (_path434 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,9a2.9926,2.9926,0,0,0-5.8157-1H9v2H20.1843A2.9939,2.9939,0,0,0,22,11.8154V23h2V11.8159A2.9958,2.9958,0,0,0,26,9Zm-3,1a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,23,10Z"
  })), children);
});
var PointOfPresence20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PointOfPresence20(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path435 || (_path435 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H18a2.0021 2.0021 0 01-2-2V18a2.0021 2.0021 0 012-2h2v2H18V28H28V18H26V16h2a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0128 30zM14 16H4a2.0021 2.0021 0 01-2-2V4A2.0021 2.0021 0 014 2H14a2.0021 2.0021 0 012 2V6H14V4H4V14H14V12h2v2A2.0021 2.0021 0 0114 16z"
  })), _path436 || (_path436 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,9a2.9926,2.9926,0,0,0-5.8157-1H9v2H20.1843A2.9939,2.9939,0,0,0,22,11.8154V23h2V11.8159A2.9958,2.9958,0,0,0,26,9Zm-3,1a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,23,10Z"
  })), children);
});
var PointOfPresence16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PointOfPresence16(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path437 || (_path437 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H18a2.0021 2.0021 0 01-2-2V18a2.0021 2.0021 0 012-2h2v2H18V28H28V18H26V16h2a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0128 30zM14 16H4a2.0021 2.0021 0 01-2-2V4A2.0021 2.0021 0 014 2H14a2.0021 2.0021 0 012 2V6H14V4H4V14H14V12h2v2A2.0021 2.0021 0 0114 16z"
  })), _path438 || (_path438 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,9a2.9926,2.9926,0,0,0-5.8157-1H9v2H20.1843A2.9939,2.9939,0,0,0,22,11.8154V23h2V11.8159A2.9958,2.9958,0,0,0,26,9Zm-3,1a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,23,10Z"
  })), children);
});
var WatsonHealthPointerText32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthPointerText32(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path439 || (_path439 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.71 12.29L7.41 6 13 6 13 4 4 4 4 13 6 13 6 7.41 12.29 13.71 13.71 12.29zM28 30H12a2 2 0 01-2-2V18h2V28H28V12H18V10H28a2 2 0 012 2V28A2 2 0 0128 30z"
  })), _path440 || (_path440 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,15H17v2h5v2H18a2,2,0,0,0-2,2v2a2,2,0,0,0,2,2h6V17A2,2,0,0,0,22,15Zm0,8H18V21h4Z"
  })), children);
});
var WatsonHealthPointerText24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthPointerText24(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path441 || (_path441 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.71 12.29L7.41 6 13 6 13 4 4 4 4 13 6 13 6 7.41 12.29 13.71 13.71 12.29zM28 30H12a2 2 0 01-2-2V18h2V28H28V12H18V10H28a2 2 0 012 2V28A2 2 0 0128 30z"
  })), _path442 || (_path442 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,15H17v2h5v2H18a2,2,0,0,0-2,2v2a2,2,0,0,0,2,2h6V17A2,2,0,0,0,22,15Zm0,8H18V21h4Z"
  })), children);
});
var WatsonHealthPointerText20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthPointerText20(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path443 || (_path443 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.71 12.29L7.41 6 13 6 13 4 4 4 4 13 6 13 6 7.41 12.29 13.71 13.71 12.29zM28 30H12a2 2 0 01-2-2V18h2V28H28V12H18V10H28a2 2 0 012 2V28A2 2 0 0128 30z"
  })), _path444 || (_path444 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,15H17v2h5v2H18a2,2,0,0,0-2,2v2a2,2,0,0,0,2,2h6V17A2,2,0,0,0,22,15Zm0,8H18V21h4Z"
  })), children);
});
var WatsonHealthPointerText16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthPointerText16(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path445 || (_path445 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.71 12.29L7.41 6 13 6 13 4 4 4 4 13 6 13 6 7.41 12.29 13.71 13.71 12.29zM28 30H12a2 2 0 01-2-2V18h2V28H28V12H18V10H28a2 2 0 012 2V28A2 2 0 0128 30z"
  })), _path446 || (_path446 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,15H17v2h5v2H18a2,2,0,0,0-2,2v2a2,2,0,0,0,2,2h6V17A2,2,0,0,0,22,15Zm0,8H18V21h4Z"
  })), children);
});
var Police32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Police32(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path447 || (_path447 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 24H12V30H10z"
  })), _path448 || (_path448 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,20H7a3.0033,3.0033,0,0,1-3-3V6H2V17a5.0059,5.0059,0,0,0,5,5H21a4.9419,4.9419,0,0,1,2.105.481L17,28.5859,18.4141,30l6.3071-6.3071A4.96,4.96,0,0,1,26,27v3h2V27A7.0078,7.0078,0,0,0,21,20Z"
  })), _path449 || (_path449 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.2746,4.0386l-7-2a1.0013,1.0013,0,0,0-.55,0l-7,2A.9993.9993,0,0,0,10.03,5.2422L11,9.123V11A7,7,0,1,0,25,11V9.123l.97-3.8808A.9993.9993,0,0,0,25.2746,4.0386ZM18,4.04l5.7952,1.6558L23.219,8H19V6H17V8H12.781l-.5762-2.3042ZM18,16a5.0058,5.0058,0,0,1-5-5V10H23v1A5.0058,5.0058,0,0,1,18,16Z"
  })), children);
});
var Police24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Police24(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path450 || (_path450 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 24H12V30H10z"
  })), _path451 || (_path451 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,20H7a3.0033,3.0033,0,0,1-3-3V6H2V17a5.0059,5.0059,0,0,0,5,5H21a4.9419,4.9419,0,0,1,2.105.481L17,28.5859,18.4141,30l6.3071-6.3071A4.96,4.96,0,0,1,26,27v3h2V27A7.0078,7.0078,0,0,0,21,20Z"
  })), _path452 || (_path452 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.2746,4.0386l-7-2a1.0013,1.0013,0,0,0-.55,0l-7,2A.9993.9993,0,0,0,10.03,5.2422L11,9.123V11A7,7,0,1,0,25,11V9.123l.97-3.8808A.9993.9993,0,0,0,25.2746,4.0386ZM18,4.04l5.7952,1.6558L23.219,8H19V6H17V8H12.781l-.5762-2.3042ZM18,16a5.0058,5.0058,0,0,1-5-5V10H23v1A5.0058,5.0058,0,0,1,18,16Z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-21.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-21.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Police16": () => (/* binding */ Police16),
/* harmony export */   "Police20": () => (/* binding */ Police20),
/* harmony export */   "Policy16": () => (/* binding */ Policy16),
/* harmony export */   "Policy20": () => (/* binding */ Policy20),
/* harmony export */   "Policy24": () => (/* binding */ Policy24),
/* harmony export */   "Policy32": () => (/* binding */ Policy32),
/* harmony export */   "Popup16": () => (/* binding */ Popup16),
/* harmony export */   "Popup20": () => (/* binding */ Popup20),
/* harmony export */   "Popup24": () => (/* binding */ Popup24),
/* harmony export */   "Popup32": () => (/* binding */ Popup32),
/* harmony export */   "Portfolio16": () => (/* binding */ Portfolio16),
/* harmony export */   "Portfolio20": () => (/* binding */ Portfolio20),
/* harmony export */   "Portfolio24": () => (/* binding */ Portfolio24),
/* harmony export */   "Portfolio32": () => (/* binding */ Portfolio32),
/* harmony export */   "Power16": () => (/* binding */ Power16),
/* harmony export */   "Power20": () => (/* binding */ Power20),
/* harmony export */   "Power24": () => (/* binding */ Power24),
/* harmony export */   "Power32": () => (/* binding */ Power32),
/* harmony export */   "Ppt16": () => (/* binding */ Ppt16),
/* harmony export */   "Ppt20": () => (/* binding */ Ppt20),
/* harmony export */   "Ppt24": () => (/* binding */ Ppt24),
/* harmony export */   "Ppt32": () => (/* binding */ Ppt32),
/* harmony export */   "PresentationFile16": () => (/* binding */ PresentationFile16),
/* harmony export */   "PresentationFile20": () => (/* binding */ PresentationFile20),
/* harmony export */   "PresentationFile24": () => (/* binding */ PresentationFile24),
/* harmony export */   "PresentationFile32": () => (/* binding */ PresentationFile32),
/* harmony export */   "Pressure16": () => (/* binding */ Pressure16),
/* harmony export */   "Pressure20": () => (/* binding */ Pressure20),
/* harmony export */   "Pressure24": () => (/* binding */ Pressure24),
/* harmony export */   "Pressure32": () => (/* binding */ Pressure32),
/* harmony export */   "PressureFilled16": () => (/* binding */ PressureFilled16),
/* harmony export */   "PressureFilled20": () => (/* binding */ PressureFilled20),
/* harmony export */   "PressureFilled24": () => (/* binding */ PressureFilled24),
/* harmony export */   "PressureFilled32": () => (/* binding */ PressureFilled32),
/* harmony export */   "PreviousFilled16": () => (/* binding */ PreviousFilled16),
/* harmony export */   "PreviousFilled20": () => (/* binding */ PreviousFilled20),
/* harmony export */   "PreviousFilled24": () => (/* binding */ PreviousFilled24),
/* harmony export */   "PreviousFilled32": () => (/* binding */ PreviousFilled32),
/* harmony export */   "PreviousOutline16": () => (/* binding */ PreviousOutline16),
/* harmony export */   "PreviousOutline20": () => (/* binding */ PreviousOutline20),
/* harmony export */   "PreviousOutline24": () => (/* binding */ PreviousOutline24),
/* harmony export */   "PreviousOutline32": () => (/* binding */ PreviousOutline32),
/* harmony export */   "Printer16": () => (/* binding */ Printer16),
/* harmony export */   "Printer20": () => (/* binding */ Printer20),
/* harmony export */   "Printer24": () => (/* binding */ Printer24),
/* harmony export */   "Printer32": () => (/* binding */ Printer32),
/* harmony export */   "Product16": () => (/* binding */ Product16),
/* harmony export */   "Product20": () => (/* binding */ Product20),
/* harmony export */   "Product24": () => (/* binding */ Product24),
/* harmony export */   "Product32": () => (/* binding */ Product32),
/* harmony export */   "ProgressBar16": () => (/* binding */ ProgressBar16),
/* harmony export */   "ProgressBar20": () => (/* binding */ ProgressBar20),
/* harmony export */   "ProgressBar24": () => (/* binding */ ProgressBar24),
/* harmony export */   "ProgressBar32": () => (/* binding */ ProgressBar32),
/* harmony export */   "ProgressBarRound16": () => (/* binding */ ProgressBarRound16),
/* harmony export */   "ProgressBarRound20": () => (/* binding */ ProgressBarRound20),
/* harmony export */   "ProgressBarRound24": () => (/* binding */ ProgressBarRound24),
/* harmony export */   "ProgressBarRound32": () => (/* binding */ ProgressBarRound32),
/* harmony export */   "PropertyRelationship16": () => (/* binding */ PropertyRelationship16),
/* harmony export */   "PropertyRelationship20": () => (/* binding */ PropertyRelationship20),
/* harmony export */   "PropertyRelationship24": () => (/* binding */ PropertyRelationship24),
/* harmony export */   "PropertyRelationship32": () => (/* binding */ PropertyRelationship32),
/* harmony export */   "Purchase16": () => (/* binding */ Purchase16),
/* harmony export */   "Purchase20": () => (/* binding */ Purchase20),
/* harmony export */   "Purchase24": () => (/* binding */ Purchase24),
/* harmony export */   "Purchase32": () => (/* binding */ Purchase32),
/* harmony export */   "QqPlot16": () => (/* binding */ QqPlot16),
/* harmony export */   "QqPlot20": () => (/* binding */ QqPlot20),
/* harmony export */   "QqPlot24": () => (/* binding */ QqPlot24),
/* harmony export */   "QqPlot32": () => (/* binding */ QqPlot32),
/* harmony export */   "QrCode16": () => (/* binding */ QrCode16),
/* harmony export */   "QrCode20": () => (/* binding */ QrCode20),
/* harmony export */   "QrCode24": () => (/* binding */ QrCode24),
/* harmony export */   "QrCode32": () => (/* binding */ QrCode32),
/* harmony export */   "QuadrantPlot16": () => (/* binding */ QuadrantPlot16),
/* harmony export */   "QuadrantPlot20": () => (/* binding */ QuadrantPlot20),
/* harmony export */   "QuadrantPlot24": () => (/* binding */ QuadrantPlot24),
/* harmony export */   "QuadrantPlot32": () => (/* binding */ QuadrantPlot32),
/* harmony export */   "Query16": () => (/* binding */ Query16),
/* harmony export */   "Query20": () => (/* binding */ Query20),
/* harmony export */   "Query24": () => (/* binding */ Query24),
/* harmony export */   "Query32": () => (/* binding */ Query32),
/* harmony export */   "QueryQueue16": () => (/* binding */ QueryQueue16),
/* harmony export */   "QueryQueue20": () => (/* binding */ QueryQueue20),
/* harmony export */   "QueryQueue24": () => (/* binding */ QueryQueue24),
/* harmony export */   "QueryQueue32": () => (/* binding */ QueryQueue32),
/* harmony export */   "Queued16": () => (/* binding */ Queued16),
/* harmony export */   "Queued20": () => (/* binding */ Queued20),
/* harmony export */   "Queued24": () => (/* binding */ Queued24),
/* harmony export */   "Queued32": () => (/* binding */ Queued32),
/* harmony export */   "Quotes16": () => (/* binding */ Quotes16),
/* harmony export */   "Quotes20": () => (/* binding */ Quotes20),
/* harmony export */   "Quotes24": () => (/* binding */ Quotes24),
/* harmony export */   "Quotes32": () => (/* binding */ Quotes32),
/* harmony export */   "Radar16": () => (/* binding */ Radar16),
/* harmony export */   "Radar20": () => (/* binding */ Radar20),
/* harmony export */   "Radar24": () => (/* binding */ Radar24),
/* harmony export */   "Radar32": () => (/* binding */ Radar32),
/* harmony export */   "RadarEnhanced16": () => (/* binding */ RadarEnhanced16),
/* harmony export */   "RadarEnhanced20": () => (/* binding */ RadarEnhanced20),
/* harmony export */   "RadarEnhanced24": () => (/* binding */ RadarEnhanced24),
/* harmony export */   "RadarEnhanced32": () => (/* binding */ RadarEnhanced32),
/* harmony export */   "RadarWeather16": () => (/* binding */ RadarWeather16),
/* harmony export */   "RadarWeather20": () => (/* binding */ RadarWeather20),
/* harmony export */   "RadarWeather24": () => (/* binding */ RadarWeather24),
/* harmony export */   "RadarWeather32": () => (/* binding */ RadarWeather32),
/* harmony export */   "Radio16": () => (/* binding */ Radio16),
/* harmony export */   "Radio20": () => (/* binding */ Radio20),
/* harmony export */   "Radio24": () => (/* binding */ Radio24),
/* harmony export */   "Radio32": () => (/* binding */ Radio32),
/* harmony export */   "RadioButton16": () => (/* binding */ RadioButton16),
/* harmony export */   "RadioButton20": () => (/* binding */ RadioButton20),
/* harmony export */   "RadioButton24": () => (/* binding */ RadioButton24),
/* harmony export */   "RadioButton32": () => (/* binding */ RadioButton32),
/* harmony export */   "RadioButtonChecked16": () => (/* binding */ RadioButtonChecked16),
/* harmony export */   "RadioButtonChecked20": () => (/* binding */ RadioButtonChecked20),
/* harmony export */   "RadioButtonChecked24": () => (/* binding */ RadioButtonChecked24),
/* harmony export */   "RadioButtonChecked32": () => (/* binding */ RadioButtonChecked32),
/* harmony export */   "RadioCombat16": () => (/* binding */ RadioCombat16),
/* harmony export */   "RadioCombat20": () => (/* binding */ RadioCombat20),
/* harmony export */   "RadioCombat24": () => (/* binding */ RadioCombat24),
/* harmony export */   "RadioCombat32": () => (/* binding */ RadioCombat32),
/* harmony export */   "RadioPushToTalk16": () => (/* binding */ RadioPushToTalk16),
/* harmony export */   "RadioPushToTalk20": () => (/* binding */ RadioPushToTalk20),
/* harmony export */   "RadioPushToTalk24": () => (/* binding */ RadioPushToTalk24),
/* harmony export */   "RadioPushToTalk32": () => (/* binding */ RadioPushToTalk32),
/* harmony export */   "Rain16": () => (/* binding */ Rain16),
/* harmony export */   "Rain20": () => (/* binding */ Rain20),
/* harmony export */   "Rain24": () => (/* binding */ Rain24),
/* harmony export */   "Rain32": () => (/* binding */ Rain32),
/* harmony export */   "RainDrizzle16": () => (/* binding */ RainDrizzle16),
/* harmony export */   "RainDrizzle20": () => (/* binding */ RainDrizzle20),
/* harmony export */   "RainDrizzle24": () => (/* binding */ RainDrizzle24),
/* harmony export */   "RainDrizzle32": () => (/* binding */ RainDrizzle32),
/* harmony export */   "RainDrop16": () => (/* binding */ RainDrop16),
/* harmony export */   "RainDrop20": () => (/* binding */ RainDrop20),
/* harmony export */   "RainDrop24": () => (/* binding */ RainDrop24),
/* harmony export */   "RainDrop32": () => (/* binding */ RainDrop32),
/* harmony export */   "RainHeavy16": () => (/* binding */ RainHeavy16),
/* harmony export */   "RainHeavy20": () => (/* binding */ RainHeavy20),
/* harmony export */   "RainHeavy24": () => (/* binding */ RainHeavy24),
/* harmony export */   "RainHeavy32": () => (/* binding */ RainHeavy32),
/* harmony export */   "RainScattered16": () => (/* binding */ RainScattered16),
/* harmony export */   "RainScattered20": () => (/* binding */ RainScattered20),
/* harmony export */   "RainScattered24": () => (/* binding */ RainScattered24),
/* harmony export */   "RainScattered32": () => (/* binding */ RainScattered32),
/* harmony export */   "RainScatteredNight16": () => (/* binding */ RainScatteredNight16),
/* harmony export */   "RainScatteredNight20": () => (/* binding */ RainScatteredNight20),
/* harmony export */   "RainScatteredNight24": () => (/* binding */ RainScatteredNight24),
/* harmony export */   "RainScatteredNight32": () => (/* binding */ RainScatteredNight32),
/* harmony export */   "Raw16": () => (/* binding */ Raw16),
/* harmony export */   "Raw20": () => (/* binding */ Raw20),
/* harmony export */   "Raw24": () => (/* binding */ Raw24),
/* harmony export */   "Raw32": () => (/* binding */ Raw32),
/* harmony export */   "Receipt16": () => (/* binding */ Receipt16),
/* harmony export */   "Receipt20": () => (/* binding */ Receipt20),
/* harmony export */   "Receipt24": () => (/* binding */ Receipt24),
/* harmony export */   "Receipt32": () => (/* binding */ Receipt32),
/* harmony export */   "RecentlyViewed16": () => (/* binding */ RecentlyViewed16),
/* harmony export */   "RecentlyViewed20": () => (/* binding */ RecentlyViewed20),
/* harmony export */   "RecentlyViewed24": () => (/* binding */ RecentlyViewed24),
/* harmony export */   "RecentlyViewed32": () => (/* binding */ RecentlyViewed32),
/* harmony export */   "Recommend16": () => (/* binding */ Recommend16),
/* harmony export */   "Recommend20": () => (/* binding */ Recommend20),
/* harmony export */   "Recommend24": () => (/* binding */ Recommend24),
/* harmony export */   "Recommend32": () => (/* binding */ Recommend32),
/* harmony export */   "Recording16": () => (/* binding */ Recording16),
/* harmony export */   "Recording20": () => (/* binding */ Recording20),
/* harmony export */   "Recording24": () => (/* binding */ Recording24),
/* harmony export */   "Recording32": () => (/* binding */ Recording32),
/* harmony export */   "RecordingFilled16": () => (/* binding */ RecordingFilled16),
/* harmony export */   "RecordingFilled20": () => (/* binding */ RecordingFilled20),
/* harmony export */   "RecordingFilled24": () => (/* binding */ RecordingFilled24),
/* harmony export */   "RecordingFilled32": () => (/* binding */ RecordingFilled32),
/* harmony export */   "RecordingFilledAlt16": () => (/* binding */ RecordingFilledAlt16),
/* harmony export */   "RecordingFilledAlt20": () => (/* binding */ RecordingFilledAlt20),
/* harmony export */   "RecordingFilledAlt24": () => (/* binding */ RecordingFilledAlt24),
/* harmony export */   "RecordingFilledAlt32": () => (/* binding */ RecordingFilledAlt32),
/* harmony export */   "Redo16": () => (/* binding */ Redo16),
/* harmony export */   "Redo20": () => (/* binding */ Redo20),
/* harmony export */   "Redo24": () => (/* binding */ Redo24),
/* harmony export */   "Redo32": () => (/* binding */ Redo32),
/* harmony export */   "RefEvapotranspiration16": () => (/* binding */ RefEvapotranspiration16),
/* harmony export */   "RefEvapotranspiration20": () => (/* binding */ RefEvapotranspiration20),
/* harmony export */   "RefEvapotranspiration24": () => (/* binding */ RefEvapotranspiration24),
/* harmony export */   "RefEvapotranspiration32": () => (/* binding */ RefEvapotranspiration32),
/* harmony export */   "ReflectHorizontal16": () => (/* binding */ ReflectHorizontal16),
/* harmony export */   "ReflectHorizontal20": () => (/* binding */ ReflectHorizontal20),
/* harmony export */   "ReflectHorizontal24": () => (/* binding */ ReflectHorizontal24),
/* harmony export */   "ReflectHorizontal32": () => (/* binding */ ReflectHorizontal32),
/* harmony export */   "ReflectVertical16": () => (/* binding */ ReflectVertical16),
/* harmony export */   "ReflectVertical20": () => (/* binding */ ReflectVertical20),
/* harmony export */   "ReflectVertical24": () => (/* binding */ ReflectVertical24),
/* harmony export */   "ReflectVertical32": () => (/* binding */ ReflectVertical32),
/* harmony export */   "Reminder16": () => (/* binding */ Reminder16),
/* harmony export */   "Reminder20": () => (/* binding */ Reminder20),
/* harmony export */   "Reminder24": () => (/* binding */ Reminder24),
/* harmony export */   "Reminder32": () => (/* binding */ Reminder32),
/* harmony export */   "ReminderMedical16": () => (/* binding */ ReminderMedical16),
/* harmony export */   "ReminderMedical20": () => (/* binding */ ReminderMedical20),
/* harmony export */   "ReminderMedical24": () => (/* binding */ ReminderMedical24),
/* harmony export */   "ReminderMedical32": () => (/* binding */ ReminderMedical32),
/* harmony export */   "Renew16": () => (/* binding */ Renew16),
/* harmony export */   "Renew20": () => (/* binding */ Renew20),
/* harmony export */   "Renew24": () => (/* binding */ Renew24),
/* harmony export */   "Renew32": () => (/* binding */ Renew32),
/* harmony export */   "Repeat16": () => (/* binding */ Repeat16),
/* harmony export */   "Repeat20": () => (/* binding */ Repeat20),
/* harmony export */   "Repeat24": () => (/* binding */ Repeat24),
/* harmony export */   "Repeat32": () => (/* binding */ Repeat32),
/* harmony export */   "RepeatOne16": () => (/* binding */ RepeatOne16),
/* harmony export */   "RepeatOne20": () => (/* binding */ RepeatOne20),
/* harmony export */   "RepeatOne24": () => (/* binding */ RepeatOne24),
/* harmony export */   "RepeatOne32": () => (/* binding */ RepeatOne32),
/* harmony export */   "Replicate16": () => (/* binding */ Replicate16),
/* harmony export */   "Replicate20": () => (/* binding */ Replicate20),
/* harmony export */   "Replicate24": () => (/* binding */ Replicate24),
/* harmony export */   "Replicate32": () => (/* binding */ Replicate32),
/* harmony export */   "Reply16": () => (/* binding */ Reply16),
/* harmony export */   "Reply20": () => (/* binding */ Reply20),
/* harmony export */   "Reply24": () => (/* binding */ Reply24),
/* harmony export */   "Reply32": () => (/* binding */ Reply32),
/* harmony export */   "ReplyAll16": () => (/* binding */ ReplyAll16),
/* harmony export */   "ReplyAll20": () => (/* binding */ ReplyAll20),
/* harmony export */   "ReplyAll24": () => (/* binding */ ReplyAll24),
/* harmony export */   "ReplyAll32": () => (/* binding */ ReplyAll32),
/* harmony export */   "Report16": () => (/* binding */ Report16),
/* harmony export */   "Report20": () => (/* binding */ Report20),
/* harmony export */   "Report24": () => (/* binding */ Report24),
/* harmony export */   "Report32": () => (/* binding */ Report32),
/* harmony export */   "ReportData16": () => (/* binding */ ReportData16),
/* harmony export */   "ReportData20": () => (/* binding */ ReportData20),
/* harmony export */   "ReportData24": () => (/* binding */ ReportData24),
/* harmony export */   "ReportData32": () => (/* binding */ ReportData32),
/* harmony export */   "WatsonHealthQcLaunch16": () => (/* binding */ WatsonHealthQcLaunch16),
/* harmony export */   "WatsonHealthQcLaunch20": () => (/* binding */ WatsonHealthQcLaunch20),
/* harmony export */   "WatsonHealthQcLaunch24": () => (/* binding */ WatsonHealthQcLaunch24),
/* harmony export */   "WatsonHealthQcLaunch32": () => (/* binding */ WatsonHealthQcLaunch32),
/* harmony export */   "WatsonHealthRegionAnalysisArea16": () => (/* binding */ WatsonHealthRegionAnalysisArea16),
/* harmony export */   "WatsonHealthRegionAnalysisArea20": () => (/* binding */ WatsonHealthRegionAnalysisArea20),
/* harmony export */   "WatsonHealthRegionAnalysisArea24": () => (/* binding */ WatsonHealthRegionAnalysisArea24),
/* harmony export */   "WatsonHealthRegionAnalysisArea32": () => (/* binding */ WatsonHealthRegionAnalysisArea32),
/* harmony export */   "WatsonHealthRegionAnalysisVolume16": () => (/* binding */ WatsonHealthRegionAnalysisVolume16),
/* harmony export */   "WatsonHealthRegionAnalysisVolume20": () => (/* binding */ WatsonHealthRegionAnalysisVolume20),
/* harmony export */   "WatsonHealthRegionAnalysisVolume24": () => (/* binding */ WatsonHealthRegionAnalysisVolume24),
/* harmony export */   "WatsonHealthRegionAnalysisVolume32": () => (/* binding */ WatsonHealthRegionAnalysisVolume32),
/* harmony export */   "WatsonHealthRegistration16": () => (/* binding */ WatsonHealthRegistration16),
/* harmony export */   "WatsonHealthRegistration20": () => (/* binding */ WatsonHealthRegistration20),
/* harmony export */   "WatsonHealthRegistration24": () => (/* binding */ WatsonHealthRegistration24),
/* harmony export */   "WatsonHealthRegistration32": () => (/* binding */ WatsonHealthRegistration32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _path65, _path66, _path67, _path68, _path69, _path70, _path71, _path72, _path73, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _circle, _circle2, _circle3, _circle4, _circle5, _path123, _circle6, _circle7, _circle8, _circle9, _circle10, _path124, _circle11, _circle12, _circle13, _circle14, _circle15, _path125, _circle16, _circle17, _circle18, _circle19, _circle20, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _circle21, _circle22, _circle23, _circle24, _circle25, _circle26, _circle27, _path169, _path170, _circle28, _circle29, _circle30, _circle31, _circle32, _circle33, _circle34, _path171, _path172, _circle35, _circle36, _circle37, _circle38, _circle39, _circle40, _circle41, _path173, _path174, _circle42, _circle43, _circle44, _circle45, _circle46, _circle47, _circle48, _circle49, _path175, _path176, _circle50, _path177, _path178, _circle51, _path179, _path180, _circle52, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _circle53, _path224, _path225, _circle54, _path226, _path227, _circle55, _path228, _path229, _circle56, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _circle57, _path335, _circle58, _path336, _circle59, _path337, _circle60, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388, _path389, _path390, _path391, _path392, _path393, _path394, _path395, _path396, _path397, _path398, _path399, _path400, _path401, _path402, _path403, _path404, _path405, _path406, _path407, _path408, _path409, _path410, _path411, _path412, _path413, _path414, _path415, _path416, _path417, _path418, _path419, _path420, _path421, _path422, _path423, _path424, _path425, _path426, _path427, _path428, _path429, _path430, _path431, _path432, _path433, _path434, _path435, _path436, _path437, _path438, _path439, _path440, _path441, _path442, _path443, _path444, _path445, _path446, _path447, _path448, _path449, _path450, _path451, _path452, _path453, _path454, _path455, _path456, _path457, _path458, _path459, _path460, _path461, _path462, _path463, _path464, _path465, _path466;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var Police20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Police20(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 24H12V30H10z"
  })), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,20H7a3.0033,3.0033,0,0,1-3-3V6H2V17a5.0059,5.0059,0,0,0,5,5H21a4.9419,4.9419,0,0,1,2.105.481L17,28.5859,18.4141,30l6.3071-6.3071A4.96,4.96,0,0,1,26,27v3h2V27A7.0078,7.0078,0,0,0,21,20Z"
  })), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.2746,4.0386l-7-2a1.0013,1.0013,0,0,0-.55,0l-7,2A.9993.9993,0,0,0,10.03,5.2422L11,9.123V11A7,7,0,1,0,25,11V9.123l.97-3.8808A.9993.9993,0,0,0,25.2746,4.0386ZM18,4.04l5.7952,1.6558L23.219,8H19V6H17V8H12.781l-.5762-2.3042ZM18,16a5.0058,5.0058,0,0,1-5-5V10H23v1A5.0058,5.0058,0,0,1,18,16Z"
  })), children);
});
var Police16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Police16(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 24H12V30H10z"
  })), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,20H7a3.0033,3.0033,0,0,1-3-3V6H2V17a5.0059,5.0059,0,0,0,5,5H21a4.9419,4.9419,0,0,1,2.105.481L17,28.5859,18.4141,30l6.3071-6.3071A4.96,4.96,0,0,1,26,27v3h2V27A7.0078,7.0078,0,0,0,21,20Z"
  })), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.2746,4.0386l-7-2a1.0013,1.0013,0,0,0-.55,0l-7,2A.9993.9993,0,0,0,10.03,5.2422L11,9.123V11A7,7,0,1,0,25,11V9.123l.97-3.8808A.9993.9993,0,0,0,25.2746,4.0386ZM18,4.04l5.7952,1.6558L23.219,8H19V6H17V8H12.781l-.5762-2.3042ZM18,16a5.0058,5.0058,0,0,1-5-5V10H23v1A5.0058,5.0058,0,0,1,18,16Z"
  })), children);
});
var Policy32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Policy32(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 18A6 6 0 1020 22.46v7.54l4-1.8926 4 1.8926V22.46A5.98 5.98 0 0030 18zm-4 8.84l-2-.9467L22 26.84V23.65a5.8877 5.8877 0 004 0zM24 22a4 4 0 114-4A4.0045 4.0045 0 0124 22zM9 14H16V16H9zM9 8H19V10H9z"
  })), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V8H22V4H6V28H16v2Z"
  })), children);
});
var Policy24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Policy24(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 18A6 6 0 1020 22.46v7.54l4-1.8926 4 1.8926V22.46A5.98 5.98 0 0030 18zm-4 8.84l-2-.9467L22 26.84V23.65a5.8877 5.8877 0 004 0zM24 22a4 4 0 114-4A4.0045 4.0045 0 0124 22zM9 14H16V16H9zM9 8H19V10H9z"
  })), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V8H22V4H6V28H16v2Z"
  })), children);
});
var Policy20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Policy20(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 18A6 6 0 1020 22.46v7.54l4-1.8926 4 1.8926V22.46A5.98 5.98 0 0030 18zm-4 8.84l-2-.9467L22 26.84V23.65a5.8877 5.8877 0 004 0zM24 22a4 4 0 114-4A4.0045 4.0045 0 0124 22zM9 14H16V16H9zM9 8H19V10H9z"
  })), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V8H22V4H6V28H16v2Z"
  })), children);
});
var Policy16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Policy16(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 18A6 6 0 1020 22.46v7.54l4-1.8926 4 1.8926V22.46A5.98 5.98 0 0030 18zm-4 8.84l-2-.9467L22 26.84V23.65a5.8877 5.8877 0 004 0zM24 22a4 4 0 114-4A4.0045 4.0045 0 0124 22zM9 14H16V16H9zM9 8H19V10H9z"
  })), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V8H22V4H6V28H16v2Z"
  })), children);
});
var Popup32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Popup32(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H10A2.0059,2.0059,0,0,0,8,6V20a2.0059,2.0059,0,0,0,2,2H28a2.0059,2.0059,0,0,0,2-2V6A2.0059,2.0059,0,0,0,28,4Zm0,16H10V6H28Z"
  })), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,26H4V16H6V14H4a2.0059,2.0059,0,0,0-2,2V26a2.0059,2.0059,0,0,0,2,2H18a2.0059,2.0059,0,0,0,2-2V24H18Z"
  })), children);
});
var Popup24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Popup24(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H10A2.0059,2.0059,0,0,0,8,6V20a2.0059,2.0059,0,0,0,2,2H28a2.0059,2.0059,0,0,0,2-2V6A2.0059,2.0059,0,0,0,28,4Zm0,16H10V6H28Z"
  })), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,26H4V16H6V14H4a2.0059,2.0059,0,0,0-2,2V26a2.0059,2.0059,0,0,0,2,2H18a2.0059,2.0059,0,0,0,2-2V24H18Z"
  })), children);
});
var Popup20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Popup20(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H10A2.0059,2.0059,0,0,0,8,6V20a2.0059,2.0059,0,0,0,2,2H28a2.0059,2.0059,0,0,0,2-2V6A2.0059,2.0059,0,0,0,28,4Zm0,16H10V6H28Z"
  })), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,26H4V16H6V14H4a2.0059,2.0059,0,0,0-2,2V26a2.0059,2.0059,0,0,0,2,2H18a2.0059,2.0059,0,0,0,2-2V24H18Z"
  })), children);
});
var Popup16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Popup16(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H10A2.0059,2.0059,0,0,0,8,6V20a2.0059,2.0059,0,0,0,2,2H28a2.0059,2.0059,0,0,0,2-2V6A2.0059,2.0059,0,0,0,28,4Zm0,16H10V6H28Z"
  })), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,26H4V16H6V14H4a2.0059,2.0059,0,0,0-2,2V26a2.0059,2.0059,0,0,0,2,2H18a2.0059,2.0059,0,0,0,2-2V24H18Z"
  })), children);
});
var Portfolio32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Portfolio32(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V6a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2v4H4a2,2,0,0,0-2,2V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10ZM12,6h8v4H12ZM4,26V12H28V26Z"
  })), children);
});
var Portfolio24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Portfolio24(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V6a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2v4H4a2,2,0,0,0-2,2V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10ZM12,6h8v4H12ZM4,26V12H28V26Z"
  })), children);
});
var Portfolio20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Portfolio20(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V6a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2v4H4a2,2,0,0,0-2,2V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10ZM12,6h8v4H12ZM4,26V12H28V26Z"
  })), children);
});
var Portfolio16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Portfolio16(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V6a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2v4H4a2,2,0,0,0-2,2V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10ZM12,6h8v4H12ZM4,26V12H28V26Z"
  })), children);
});
var Power32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Power32(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.5,5.74l-1,1.73a11,11,0,1,1-11,0l-1-1.73a13,13,0,1,0,13,0Z"
  })), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V16H15z"
  })), children);
});
var Power24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Power24(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.5,5.74l-1,1.73a11,11,0,1,1-11,0l-1-1.73a13,13,0,1,0,13,0Z"
  })), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V16H15z"
  })), children);
});
var Power20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Power20(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.5,5.74l-1,1.73a11,11,0,1,1-11,0l-1-1.73a13,13,0,1,0,13,0Z"
  })), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V16H15z"
  })), children);
});
var Power16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Power16(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.2,2.9l-0.5,0.9c2.6,1.5,3.5,4.9,2,7.5s-4.9,3.5-7.5,2s-3.5-4.9-2-7.5c0.5-0.8,1.2-1.5,2-2L4.8,2.9\tc-3.1,1.8-4.2,5.8-2.4,8.9s5.8,4.2,8.9,2.4s4.2-5.8,2.4-8.9C13.1,4.3,12.2,3.4,11.2,2.9z"
  })), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.5 1H8.5V8H7.5z"
  })), children);
});
var Ppt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Ppt32(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 11L25 11 25 23 27 23 27 11 30 11 30 9 22 9 22 11zM14 23H12V9h6a2.002 2.002 0 012 2v5a2.002 2.002 0 01-2 2H14zm0-7h4V10.9985H14zM4 23H2V9H8a2.002 2.002 0 012 2v5a2.002 2.002 0 01-2 2H4zm0-7H8V10.9985H4z"
  })), children);
});
var Ppt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Ppt24(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 11L25 11 25 23 27 23 27 11 30 11 30 9 22 9 22 11zM14 23H12V9h6a2.002 2.002 0 012 2v5a2.002 2.002 0 01-2 2H14zm0-7h4V10.9985H14zM4 23H2V9H8a2.002 2.002 0 012 2v5a2.002 2.002 0 01-2 2H4zm0-7H8V10.9985H4z"
  })), children);
});
var Ppt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Ppt20(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 11L25 11 25 23 27 23 27 11 30 11 30 9 22 9 22 11zM14 23H12V9h6a2.002 2.002 0 012 2v5a2.002 2.002 0 01-2 2H14zm0-7h4V10.9985H14zM4 23H2V9H8a2.002 2.002 0 012 2v5a2.002 2.002 0 01-2 2H4zm0-7H8V10.9985H4z"
  })), children);
});
var Ppt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Ppt16(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 11L25 11 25 23 27 23 27 11 30 11 30 9 22 9 22 11zM14 23H12V9h6a2.002 2.002 0 012 2v5a2.002 2.002 0 01-2 2H14zm0-7h4V10.9985H14zM4 23H2V9H8a2.002 2.002 0 012 2v5a2.002 2.002 0 01-2 2H4zm0-7H8V10.9985H4z"
  })), children);
});
var PresentationFile32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PresentationFile32(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 10H17V18H15zM20 14H22V18H20zM10 12H12V18H10z"
  })), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,4H17V2H15V4H7A2,2,0,0,0,5,6V20a2,2,0,0,0,2,2h8v6H11v2H21V28H17V22h8a2,2,0,0,0,2-2V6A2,2,0,0,0,25,4Zm0,16H7V6H25Z"
  })), children);
});
var PresentationFile24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PresentationFile24(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 10H17V18H15zM20 14H22V18H20zM10 12H12V18H10z"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,4H17V2H15V4H7A2,2,0,0,0,5,6V20a2,2,0,0,0,2,2h8v6H11v2H21V28H17V22h8a2,2,0,0,0,2-2V6A2,2,0,0,0,25,4Zm0,16H7V6H25Z"
  })), children);
});
var PresentationFile20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PresentationFile20(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 10H17V18H15zM20 14H22V18H20zM10 12H12V18H10z"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,4H17V2H15V4H7A2,2,0,0,0,5,6V20a2,2,0,0,0,2,2h8v6H11v2H21V28H17V22h8a2,2,0,0,0,2-2V6A2,2,0,0,0,25,4Zm0,16H7V6H25Z"
  })), children);
});
var PresentationFile16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PresentationFile16(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 10H17V18H15zM20 14H22V18H20zM10 12H12V18H10z"
  })), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,4H17V2H15V4H7A2,2,0,0,0,5,6V20a2,2,0,0,0,2,2h8v6H11v2H21V28H17V22h8a2,2,0,0,0,2-2V6A2,2,0,0,0,25,4Zm0,16H7V6H25Z"
  })), children);
});
var Pressure32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pressure32(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.5053,16l8.1591-7.2529A1,1,0,0,0,25,7H22V2H20V9h2.37L16,14.6621,9.63,9H12V2H10V7H7a1,1,0,0,0-.6646,1.7471L14.4945,16,6.3353,23.2529A1,1,0,0,0,7,25h3v5h2V23H9.63L16,17.3379,22.37,23H20v7h2V25h3a1,1,0,0,0,.6645-1.7471Z"
  })), children);
});
var Pressure24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pressure24(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.5053,16l8.1591-7.2529A1,1,0,0,0,25,7H22V2H20V9h2.37L16,14.6621,9.63,9H12V2H10V7H7a1,1,0,0,0-.6646,1.7471L14.4945,16,6.3353,23.2529A1,1,0,0,0,7,25h3v5h2V23H9.63L16,17.3379,22.37,23H20v7h2V25h3a1,1,0,0,0,.6645-1.7471Z"
  })), children);
});
var Pressure20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pressure20(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.5053,16l8.1591-7.2529A1,1,0,0,0,25,7H22V2H20V9h2.37L16,14.6621,9.63,9H12V2H10V7H7a1,1,0,0,0-.6646,1.7471L14.4945,16,6.3353,23.2529A1,1,0,0,0,7,25h3v5h2V23H9.63L16,17.3379,22.37,23H20v7h2V25h3a1,1,0,0,0,.6645-1.7471Z"
  })), children);
});
var Pressure16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Pressure16(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.5053,16l8.1591-7.2529A1,1,0,0,0,25,7H22V2H20V9h2.37L16,14.6621,9.63,9H12V2H10V7H7a1,1,0,0,0-.6646,1.7471L14.4945,16,6.3353,23.2529A1,1,0,0,0,7,25h3v5h2V23H9.63L16,17.3379,22.37,23H20v7h2V25h3a1,1,0,0,0,.6645-1.7471Z"
  })), children);
});
var PressureFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PressureFilled32(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 30H10V25H6l10-9 10 9H22zM16 16L6 7h4V2H22V7h4z"
  })), children);
});
var PressureFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PressureFilled24(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 30H10V25H6l10-9 10 9H22zM16 16L6 7h4V2H22V7h4z"
  })), children);
});
var PressureFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PressureFilled20(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 30H10V25H6l10-9 10 9H22zM16 16L6 7h4V2H22V7h4z"
  })), children);
});
var PressureFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PressureFilled16(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 30H10V25H6l10-9 10 9H22zM16 16L6 7h4V2H22V7h4z"
  })), children);
});
var PreviousFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PreviousFilled32(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm8,15H11.85l5.58,5.5728L16,24,8,16l8-8,1.43,1.3926L11.85,15H24Z"
  })), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16 8L17.43 9.393 11.85 15 24 15 24 17 11.85 17 17.43 22.573 16 24 8 16 16 8z",
    "data-icon-path": "inner-path"
  })), children);
});
var PreviousFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PreviousFilled24(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm8,15H11.85l5.58,5.5728L16,24,8,16l8-8,1.43,1.3926L11.85,15H24Z"
  })), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16 8L17.43 9.393 11.85 15 24 15 24 17 11.85 17 17.43 22.573 16 24 8 16 16 8z",
    "data-icon-path": "inner-path"
  })), children);
});
var PreviousFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PreviousFilled20(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm8,15H11.85l5.58,5.5728L16,24,8,16l8-8,1.43,1.3926L11.85,15H24Z"
  })), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16 8L17.43 9.393 11.85 15 24 15 24 17 11.85 17 17.43 22.573 16 24 8 16 16 8z",
    "data-icon-path": "inner-path"
  })), children);
});
var PreviousFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PreviousFilled16(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm8,15H11.85l5.58,5.5728L16,24,8,16l8-8,1.43,1.3926L11.85,15H24Z"
  })), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16 8L17.43 9.393 11.85 15 24 15 24 17 11.85 17 17.43 22.573 16 24 8 16 16 8z",
    "data-icon-path": "inner-path"
  })), children);
});
var PreviousOutline32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PreviousOutline32(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8L17.43 9.393 11.85 15 24 15 24 17 11.85 17 17.43 22.573 16 24 8 16 16 8z"
  })), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var PreviousOutline24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PreviousOutline24(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8L17.43 9.393 11.85 15 24 15 24 17 11.85 17 17.43 22.573 16 24 8 16 16 8z"
  })), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var PreviousOutline20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PreviousOutline20(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8L17.43 9.393 11.85 15 24 15 24 17 11.85 17 17.43 22.573 16 24 8 16 16 8z"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var PreviousOutline16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PreviousOutline16(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8L17.43 9.393 11.85 15 24 15 24 17 11.85 17 17.43 22.573 16 24 8 16 16 8z"
  })), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var Printer32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Printer32(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,9H25V3H7V9H4a2,2,0,0,0-2,2V21a2,2,0,0,0,2,2H7v6H25V23h3a2,2,0,0,0,2-2V11A2,2,0,0,0,28,9ZM9,5H23V9H9ZM23,27H9V17H23Zm5-6H25V15H7v6H4V11H28Z"
  })), children);
});
var Printer24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Printer24(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,9H25V3H7V9H4a2,2,0,0,0-2,2V21a2,2,0,0,0,2,2H7v6H25V23h3a2,2,0,0,0,2-2V11A2,2,0,0,0,28,9ZM9,5H23V9H9ZM23,27H9V17H23Zm5-6H25V15H7v6H4V11H28Z"
  })), children);
});
var Printer20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Printer20(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,9H25V3H7V9H4a2,2,0,0,0-2,2V21a2,2,0,0,0,2,2H7v6H25V23h3a2,2,0,0,0,2-2V11A2,2,0,0,0,28,9ZM9,5H23V9H9ZM23,27H9V17H23Zm5-6H25V15H7v6H4V11H28Z"
  })), children);
});
var Printer16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Printer16(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,9H25V3H7V9H4a2,2,0,0,0-2,2V21a2,2,0,0,0,2,2H7v6H25V23h3a2,2,0,0,0,2-2V11A2,2,0,0,0,28,9ZM9,5H23V9H9ZM23,27H9V17H23Zm5-6H25V15H7v6H4V11H28Z"
  })), children);
});
var Product32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Product32(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 18H14V20H8zM8 22H18V24H8z"
  })), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0025,2.0025,0,0,0,4,6V26a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V6A2.0025,2.0025,0,0,0,26,4ZM18,6v4H14V6ZM6,26V6h6v6h8V6h6l.0012,20Z"
  })), children);
});
var Product24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Product24(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 18H14V20H8zM8 22H18V24H8z"
  })), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0025,2.0025,0,0,0,4,6V26a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V6A2.0025,2.0025,0,0,0,26,4ZM18,6v4H14V6ZM6,26V6h6v6h8V6h6l.0012,20Z"
  })), children);
});
var Product20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Product20(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 18H14V20H8zM8 22H18V24H8z"
  })), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0025,2.0025,0,0,0,4,6V26a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V6A2.0025,2.0025,0,0,0,26,4ZM18,6v4H14V6ZM6,26V6h6v6h8V6h6l.0012,20Z"
  })), children);
});
var Product16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Product16(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 18H14V20H8zM8 22H18V24H8z"
  })), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0025,2.0025,0,0,0,4,6V26a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V6A2.0025,2.0025,0,0,0,26,4ZM18,6v4H14V6ZM6,26V6h6v6h8V6h6l.0012,20Z"
  })), children);
});
var ProgressBar32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ProgressBar32(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,21H4a2.0021,2.0021,0,0,1-2-2V13a2.0021,2.0021,0,0,1,2-2H28a2.0021,2.0021,0,0,1,2,2v6A2.0021,2.0021,0,0,1,28,21ZM4,13v6H28V13Z"
  })), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 15H20V17H6z"
  })), children);
});
var ProgressBar24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ProgressBar24(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,21H4a2.0021,2.0021,0,0,1-2-2V13a2.0021,2.0021,0,0,1,2-2H28a2.0021,2.0021,0,0,1,2,2v6A2.0021,2.0021,0,0,1,28,21ZM4,13v6H28V13Z"
  })), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 15H20V17H6z"
  })), children);
});
var ProgressBar20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ProgressBar20(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,21H4a2.0021,2.0021,0,0,1-2-2V13a2.0021,2.0021,0,0,1,2-2H28a2.0021,2.0021,0,0,1,2,2v6A2.0021,2.0021,0,0,1,28,21ZM4,13v6H28V13Z"
  })), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 15H20V17H6z"
  })), children);
});
var ProgressBar16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ProgressBar16(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,21H4a2.0021,2.0021,0,0,1-2-2V13a2.0021,2.0021,0,0,1,2-2H28a2.0021,2.0021,0,0,1,2,2v6A2.0021,2.0021,0,0,1,28,21ZM4,13v6H28V13Z"
  })), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 15H20V17H6z"
  })), children);
});
var ProgressBarRound32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ProgressBarRound32(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A6.0067,6.0067,0,0,1,16,22Zm0-10a4,4,0,1,0,4,4A4.0045,4.0045,0,0,0,16,12Z"
  })), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,26a10.0162,10.0162,0,0,1-7.4531-3.3325l1.49-1.334A8,8,0,1,0,16,8V6a10,10,0,0,1,0,20Z"
  })), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var ProgressBarRound24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ProgressBarRound24(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A6.0067,6.0067,0,0,1,16,22Zm0-10a4,4,0,1,0,4,4A4.0045,4.0045,0,0,0,16,12Z"
  })), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,26a10.0162,10.0162,0,0,1-7.4531-3.3325l1.49-1.334A8,8,0,1,0,16,8V6a10,10,0,0,1,0,20Z"
  })), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var ProgressBarRound20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ProgressBarRound20(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A6.0067,6.0067,0,0,1,16,22Zm0-10a4,4,0,1,0,4,4A4.0045,4.0045,0,0,0,16,12Z"
  })), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,26a10.0162,10.0162,0,0,1-7.4531-3.3325l1.49-1.334A8,8,0,1,0,16,8V6a10,10,0,0,1,0,20Z"
  })), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var ProgressBarRound16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ProgressBarRound16(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A6.0067,6.0067,0,0,1,16,22Zm0-10a4,4,0,1,0,4,4A4.0045,4.0045,0,0,0,16,12Z"
  })), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,26a10.0162,10.0162,0,0,1-7.4531-3.3325l1.49-1.334A8,8,0,1,0,16,8V6a10,10,0,0,1,0,20Z"
  })), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var PropertyRelationship32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PropertyRelationship32(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 16L22 24 20.6 22.6 27.2 16 20.6 9.4 22 8zM12 15H20V17H12zM2 16L10 8 11.4 9.4 4.8 16 11.4 22.6 10 24z"
  })), children);
});
var PropertyRelationship24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PropertyRelationship24(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 16L22 24 20.6 22.6 27.2 16 20.6 9.4 22 8zM12 15H20V17H12zM2 16L10 8 11.4 9.4 4.8 16 11.4 22.6 10 24z"
  })), children);
});
var PropertyRelationship20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PropertyRelationship20(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 16L22 24 20.6 22.6 27.2 16 20.6 9.4 22 8zM12 15H20V17H12zM2 16L10 8 11.4 9.4 4.8 16 11.4 22.6 10 24z"
  })), children);
});
var PropertyRelationship16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function PropertyRelationship16(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 16L22 24 20.6 22.6 27.2 16 20.6 9.4 22 8zM12 15H20V17H12zM2 16L10 8 11.4 9.4 4.8 16 11.4 22.6 10 24z"
  })), children);
});
var Purchase32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Purchase32(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6Zm0,2v3H4V8ZM4,24V13H28V24Z"
  })), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 20H16V22H6z"
  })), children);
});
var Purchase24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Purchase24(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6Zm0,2v3H4V8ZM4,24V13H28V24Z"
  })), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 20H16V22H6z"
  })), children);
});
var Purchase20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Purchase20(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6Zm0,2v3H4V8ZM4,24V13H28V24Z"
  })), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 20H16V22H6z"
  })), children);
});
var Purchase16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Purchase16(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6Zm0,2v3H4V8ZM4,24V13H28V24Z"
  })), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 20H16V22H6z"
  })), children);
});
var WatsonHealthQcLaunch32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthQcLaunch32(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 22H19a2.0023 2.0023 0 01-2-2V10a2.002 2.002 0 012-2h6v2H19V20h6zM13 8H9a2.002 2.002 0 00-2 2V20a2.0023 2.0023 0 002 2h1v2a2.0023 2.0023 0 002 2h2V24H12V22h1a2.0023 2.0023 0 002-2V10A2.002 2.002 0 0013 8zM9 20V10h4V20z"
  })), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0023,2.0023,0,0,1-2-2V4A2.002,2.002,0,0,1,4,2H28a2.0023,2.0023,0,0,1,2,2V28A2.0027,2.0027,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var WatsonHealthQcLaunch24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthQcLaunch24(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 22H19a2.0023 2.0023 0 01-2-2V10a2.002 2.002 0 012-2h6v2H19V20h6zM13 8H9a2.002 2.002 0 00-2 2V20a2.0023 2.0023 0 002 2h1v2a2.0023 2.0023 0 002 2h2V24H12V22h1a2.0023 2.0023 0 002-2V10A2.002 2.002 0 0013 8zM9 20V10h4V20z"
  })), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0023,2.0023,0,0,1-2-2V4A2.002,2.002,0,0,1,4,2H28a2.0023,2.0023,0,0,1,2,2V28A2.0027,2.0027,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var WatsonHealthQcLaunch20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthQcLaunch20(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 22H19a2.0023 2.0023 0 01-2-2V10a2.002 2.002 0 012-2h6v2H19V20h6zM13 8H9a2.002 2.002 0 00-2 2V20a2.0023 2.0023 0 002 2h1v2a2.0023 2.0023 0 002 2h2V24H12V22h1a2.0023 2.0023 0 002-2V10A2.002 2.002 0 0013 8zM9 20V10h4V20z"
  })), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0023,2.0023,0,0,1-2-2V4A2.002,2.002,0,0,1,4,2H28a2.0023,2.0023,0,0,1,2,2V28A2.0027,2.0027,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var WatsonHealthQcLaunch16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthQcLaunch16(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 22H19a2.0023 2.0023 0 01-2-2V10a2.002 2.002 0 012-2h6v2H19V20h6zM13 8H9a2.002 2.002 0 00-2 2V20a2.0023 2.0023 0 002 2h1v2a2.0023 2.0023 0 002 2h2V24H12V22h1a2.0023 2.0023 0 002-2V10A2.002 2.002 0 0013 8zM9 20V10h4V20z"
  })), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0023,2.0023,0,0,1-2-2V4A2.002,2.002,0,0,1,4,2H28a2.0023,2.0023,0,0,1,2,2V28A2.0027,2.0027,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var QqPlot32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QqPlot32(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20",
    cy: "4",
    r: "2"
  })), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "2"
  })), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "12",
    r: "2"
  })), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "7",
    r: "2"
  })), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "24",
    r: "2"
  })), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4131,28.5859,2,4,26.585V2H2V28a2,2,0,0,0,2,2H30V28H5.4131Z"
  })), children);
});
var QqPlot24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QqPlot24(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20",
    cy: "4",
    r: "2"
  })), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "2"
  })), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "12",
    r: "2"
  })), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "7",
    r: "2"
  })), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "24",
    r: "2"
  })), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4131,28.5859,2,4,26.585V2H2V28a2,2,0,0,0,2,2H30V28H5.4131Z"
  })), children);
});
var QqPlot20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QqPlot20(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20",
    cy: "4",
    r: "2"
  })), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "2"
  })), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "12",
    r: "2"
  })), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "7",
    r: "2"
  })), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "24",
    r: "2"
  })), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4131,28.5859,2,4,26.585V2H2V28a2,2,0,0,0,2,2H30V28H5.4131Z"
  })), children);
});
var QqPlot16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QqPlot16(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20",
    cy: "4",
    r: "2"
  })), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "2"
  })), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "12",
    r: "2"
  })), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "7",
    r: "2"
  })), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "24",
    r: "2"
  })), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4131,28.5859,2,4,26.585V2H2V28a2,2,0,0,0,2,2H30V28H5.4131Z"
  })), children);
});
var QrCode32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QrCode32(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 26H26V28H24z",
    transform: "rotate(-90 25 27)"
  })), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 22H20V24H18z",
    transform: "rotate(-90 19 23)"
  })), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 30L22 30 22 28 20 28 20 26 18 26 18 30z"
  })), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23H29V25H25z",
    transform: "rotate(-90 27 24)"
  })), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 26L30 26 30 30 26 30 26 28 28 28 28 26zM26 20L26 18 30 18 30 22 28 22 28 20 26 20zM24 20L22 20 22 24 20 24 20 26 24 26 24 20z"
  })), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 17H21V21H19z",
    transform: "rotate(-90 20 19)"
  })), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 22H10V26H6z"
  })), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 30H2V18H14zM4 28h8V20H4zM22 6H26V10H22z"
  })), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 14H18V2H30zM20 12h8V4H20zM6 6H10V10H6z"
  })), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,14H2V2H14ZM4,12h8V4H4Z"
  })), children);
});
var QrCode24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QrCode24(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 26H26V28H24z",
    transform: "rotate(-90 25 27)"
  })), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 22H20V24H18z",
    transform: "rotate(-90 19 23)"
  })), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 30L22 30 22 28 20 28 20 26 18 26 18 30z"
  })), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23H29V25H25z",
    transform: "rotate(-90 27 24)"
  })), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 26L30 26 30 30 26 30 26 28 28 28 28 26zM26 20L26 18 30 18 30 22 28 22 28 20 26 20zM24 20L22 20 22 24 20 24 20 26 24 26 24 20z"
  })), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 17H21V21H19z",
    transform: "rotate(-90 20 19)"
  })), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 22H10V26H6z"
  })), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 30H2V18H14zM4 28h8V20H4zM22 6H26V10H22z"
  })), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 14H18V2H30zM20 12h8V4H20zM6 6H10V10H6z"
  })), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,14H2V2H14ZM4,12h8V4H4Z"
  })), children);
});
var QrCode20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QrCode20(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 26H26V28H24z",
    transform: "rotate(-90 25 27)"
  })), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 22H20V24H18z",
    transform: "rotate(-90 19 23)"
  })), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 30L22 30 22 28 20 28 20 26 18 26 18 30z"
  })), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23H29V25H25z",
    transform: "rotate(-90 27 24)"
  })), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 26L30 26 30 30 26 30 26 28 28 28 28 26zM26 20L26 18 30 18 30 22 28 22 28 20 26 20zM24 20L22 20 22 24 20 24 20 26 24 26 24 20z"
  })), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 17H21V21H19z",
    transform: "rotate(-90 20 19)"
  })), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 22H10V26H6z"
  })), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 30H2V18H14zM4 28h8V20H4zM22 6H26V10H22z"
  })), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 14H18V2H30zM20 12h8V4H20zM6 6H10V10H6z"
  })), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,14H2V2H14ZM4,12h8V4H4Z"
  })), children);
});
var QrCode16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QrCode16(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 26H26V28H24z",
    transform: "rotate(-90 25 27)"
  })), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 22H20V24H18z",
    transform: "rotate(-90 19 23)"
  })), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 30L22 30 22 28 20 28 20 26 18 26 18 30z"
  })), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23H29V25H25z",
    transform: "rotate(-90 27 24)"
  })), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 26L30 26 30 30 26 30 26 28 28 28 28 26zM26 20L26 18 30 18 30 22 28 22 28 20 26 20zM24 20L22 20 22 24 20 24 20 26 24 26 24 20z"
  })), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 17H21V21H19z",
    transform: "rotate(-90 20 19)"
  })), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 22H10V26H6z"
  })), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 30H2V18H14zM4 28h8V20H4zM22 6H26V10H22z"
  })), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 14H18V2H30zM20 12h8V4H20zM6 6H10V10H6z"
  })), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,14H2V2H14ZM4,12h8V4H4Z"
  })), children);
});
var QuadrantPlot32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QuadrantPlot32(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 15L17 15 17 2 15 2 15 15 2 15 2 17 15 17 15 30 17 30 17 17 30 17 30 15z"
  })), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 30a3 3 0 113-3A3.0033 3.0033 0 015 30zm0-4a1 1 0 101 1A1.001 1.001 0 005 26zM8 8a3 3 0 113-3A3.0033 3.0033 0 018 8zM8 4A1 1 0 109 5 1.001 1.001 0 008 4zM22 13a3 3 0 113-3A3.0033 3.0033 0 0122 13zm0-4a1 1 0 101 1A1.001 1.001 0 0022 9z"
  })), _circle21 || (_circle21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "11",
    r: "2"
  })), _circle22 || (_circle22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "21",
    r: "2"
  })), _circle23 || (_circle23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "21",
    r: "2"
  })), _circle24 || (_circle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "28",
    r: "2"
  })), _circle25 || (_circle25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "24",
    r: "2"
  })), _circle26 || (_circle26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4",
    cy: "11",
    r: "2"
  })), _circle27 || (_circle27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "4",
    r: "2"
  })), children);
});
var QuadrantPlot24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QuadrantPlot24(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 15L17 15 17 2 15 2 15 15 2 15 2 17 15 17 15 30 17 30 17 17 30 17 30 15z"
  })), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 30a3 3 0 113-3A3.0033 3.0033 0 015 30zm0-4a1 1 0 101 1A1.001 1.001 0 005 26zM8 8a3 3 0 113-3A3.0033 3.0033 0 018 8zM8 4A1 1 0 109 5 1.001 1.001 0 008 4zM22 13a3 3 0 113-3A3.0033 3.0033 0 0122 13zm0-4a1 1 0 101 1A1.001 1.001 0 0022 9z"
  })), _circle28 || (_circle28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "11",
    r: "2"
  })), _circle29 || (_circle29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "21",
    r: "2"
  })), _circle30 || (_circle30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "21",
    r: "2"
  })), _circle31 || (_circle31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "28",
    r: "2"
  })), _circle32 || (_circle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "24",
    r: "2"
  })), _circle33 || (_circle33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4",
    cy: "11",
    r: "2"
  })), _circle34 || (_circle34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "4",
    r: "2"
  })), children);
});
var QuadrantPlot20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QuadrantPlot20(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 15L17 15 17 2 15 2 15 15 2 15 2 17 15 17 15 30 17 30 17 17 30 17 30 15z"
  })), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 30a3 3 0 113-3A3.0033 3.0033 0 015 30zm0-4a1 1 0 101 1A1.001 1.001 0 005 26zM8 8a3 3 0 113-3A3.0033 3.0033 0 018 8zM8 4A1 1 0 109 5 1.001 1.001 0 008 4zM22 13a3 3 0 113-3A3.0033 3.0033 0 0122 13zm0-4a1 1 0 101 1A1.001 1.001 0 0022 9z"
  })), _circle35 || (_circle35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "11",
    r: "2"
  })), _circle36 || (_circle36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "21",
    r: "2"
  })), _circle37 || (_circle37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "21",
    r: "2"
  })), _circle38 || (_circle38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "28",
    r: "2"
  })), _circle39 || (_circle39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "24",
    r: "2"
  })), _circle40 || (_circle40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4",
    cy: "11",
    r: "2"
  })), _circle41 || (_circle41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "4",
    r: "2"
  })), children);
});
var QuadrantPlot16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QuadrantPlot16(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 15L17 15 17 2 15 2 15 15 2 15 2 17 15 17 15 30 17 30 17 17 30 17 30 15z"
  })), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 30a3 3 0 113-3A3.0033 3.0033 0 015 30zm0-4a1 1 0 101 1A1.001 1.001 0 005 26zM8 8a3 3 0 113-3A3.0033 3.0033 0 018 8zM8 4A1 1 0 109 5 1.001 1.001 0 008 4zM22 13a3 3 0 113-3A3.0033 3.0033 0 0122 13zm0-4a1 1 0 101 1A1.001 1.001 0 0022 9z"
  })), _circle42 || (_circle42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "11",
    r: "2"
  })), _circle43 || (_circle43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "21",
    r: "2"
  })), _circle44 || (_circle44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "21",
    r: "2"
  })), _circle45 || (_circle45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "28",
    r: "2"
  })), _circle46 || (_circle46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "24",
    r: "2"
  })), _circle47 || (_circle47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4",
    cy: "11",
    r: "2"
  })), _circle48 || (_circle48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "4",
    r: "2"
  })), children);
});
var Query32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Query32(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle49 || (_circle49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "15.5",
    r: "1.5"
  })), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,12H10V8h2a2,2,0,0,0,0-4H10A2.0023,2.0023,0,0,0,8,6v.5H6V6a4.0045,4.0045,0,0,1,4-4h2a4,4,0,0,1,0,8Z"
  })), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.4479,21.0337A10.971,10.971,0,0,0,19.9211,4.7446l-.999,1.73A8.9967,8.9967,0,1,1,5,14H3a10.9916,10.9916,0,0,0,18.0338,8.4478L28.5859,30,30,28.5859Z"
  })), children);
});
var Query24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Query24(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle50 || (_circle50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "15.5",
    r: "1.5"
  })), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,12H10V8h2a2,2,0,0,0,0-4H10A2.0023,2.0023,0,0,0,8,6v.5H6V6a4.0045,4.0045,0,0,1,4-4h2a4,4,0,0,1,0,8Z"
  })), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.4479,21.0337A10.971,10.971,0,0,0,19.9211,4.7446l-.999,1.73A8.9967,8.9967,0,1,1,5,14H3a10.9916,10.9916,0,0,0,18.0338,8.4478L28.5859,30,30,28.5859Z"
  })), children);
});
var Query20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Query20(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle51 || (_circle51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "15.5",
    r: "1.5"
  })), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,12H10V8h2a2,2,0,0,0,0-4H10A2.0023,2.0023,0,0,0,8,6v.5H6V6a4.0045,4.0045,0,0,1,4-4h2a4,4,0,0,1,0,8Z"
  })), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.4479,21.0337A10.971,10.971,0,0,0,19.9211,4.7446l-.999,1.73A8.9967,8.9967,0,1,1,5,14H3a10.9916,10.9916,0,0,0,18.0338,8.4478L28.5859,30,30,28.5859Z"
  })), children);
});
var Query16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Query16(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle52 || (_circle52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "15.5",
    r: "1.5"
  })), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,12H10V8h2a2,2,0,0,0,0-4H10A2.0023,2.0023,0,0,0,8,6v.5H6V6a4.0045,4.0045,0,0,1,4-4h2a4,4,0,0,1,0,8Z"
  })), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.4479,21.0337A10.971,10.971,0,0,0,19.9211,4.7446l-.999,1.73A8.9967,8.9967,0,1,1,5,14H3a10.9916,10.9916,0,0,0,18.0338,8.4478L28.5859,30,30,28.5859Z"
  })), children);
});
var QueryQueue32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QueryQueue32(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6H28V8H10zM10 12H28V14H10zM15 18H28V20H15zM10 24H28V26H10zM4 14L11 19 4 24 4 14z"
  })), children);
});
var QueryQueue24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QueryQueue24(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6H28V8H10zM10 12H28V14H10zM15 18H28V20H15zM10 24H28V26H10zM4 14L11 19 4 24 4 14z"
  })), children);
});
var QueryQueue20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QueryQueue20(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6H28V8H10zM10 12H28V14H10zM15 18H28V20H15zM10 24H28V26H10zM4 14L11 19 4 24 4 14z"
  })), children);
});
var QueryQueue16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QueryQueue16(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 6H28V8H10zM10 12H28V14H10zM15 18H28V20H15zM10 24H28V26H10zM4 14L11 19 4 24 4 14z"
  })), children);
});
var Queued32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Queued32(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 20H30V22H22zM22 24H30V26H22zM22 28H30V30H22zM18 24H20V26H18zM18 20H20V22H18zM18 28H20V30H18zM6.8149 8.293A12.0777 12.0777 0 0110.0068 5.62L9.0079 3.89A14.0845 14.0845 0 005.2841 7.0083zM25.1851 8.293l1.5308-1.2847A14.0845 14.0845 0 0022.9921 3.89l-.9989 1.73A12.0777 12.0777 0 0125.1851 8.293zM4.7366 11.9l-1.8772-.6831A13.9019 13.9019 0 002 16H4A11.917 11.917 0 014.7366 11.9zM6.8149 23.707A11.9975 11.9975 0 014.7366 20.1l-1.8772.6831a13.99 13.99 0 002.4247 4.209zM27.2634 11.9A11.917 11.917 0 0128 16h2a13.8971 13.8971 0 00-.8594-4.7827zM13.9182 27.8066A11.8894 11.8894 0 0110.0068 26.38l-.9989 1.73a13.8673 13.8673 0 004.5633 1.664zM13.9182 4.1934a11.3012 11.3012 0 014.1636 0l.347-1.9678a13.187 13.187 0 00-4.8576 0z"
  })), children);
});
var Queued24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Queued24(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 20H30V22H22zM22 24H30V26H22zM22 28H30V30H22zM18 24H20V26H18zM18 20H20V22H18zM18 28H20V30H18zM6.8149 8.293A12.0777 12.0777 0 0110.0068 5.62L9.0079 3.89A14.0845 14.0845 0 005.2841 7.0083zM25.1851 8.293l1.5308-1.2847A14.0845 14.0845 0 0022.9921 3.89l-.9989 1.73A12.0777 12.0777 0 0125.1851 8.293zM4.7366 11.9l-1.8772-.6831A13.9019 13.9019 0 002 16H4A11.917 11.917 0 014.7366 11.9zM6.8149 23.707A11.9975 11.9975 0 014.7366 20.1l-1.8772.6831a13.99 13.99 0 002.4247 4.209zM27.2634 11.9A11.917 11.917 0 0128 16h2a13.8971 13.8971 0 00-.8594-4.7827zM13.9182 27.8066A11.8894 11.8894 0 0110.0068 26.38l-.9989 1.73a13.8673 13.8673 0 004.5633 1.664zM13.9182 4.1934a11.3012 11.3012 0 014.1636 0l.347-1.9678a13.187 13.187 0 00-4.8576 0z"
  })), children);
});
var Queued20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Queued20(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 20H30V22H22zM22 24H30V26H22zM22 28H30V30H22zM18 24H20V26H18zM18 20H20V22H18zM18 28H20V30H18zM6.8149 8.293A12.0777 12.0777 0 0110.0068 5.62L9.0079 3.89A14.0845 14.0845 0 005.2841 7.0083zM25.1851 8.293l1.5308-1.2847A14.0845 14.0845 0 0022.9921 3.89l-.9989 1.73A12.0777 12.0777 0 0125.1851 8.293zM4.7366 11.9l-1.8772-.6831A13.9019 13.9019 0 002 16H4A11.917 11.917 0 014.7366 11.9zM6.8149 23.707A11.9975 11.9975 0 014.7366 20.1l-1.8772.6831a13.99 13.99 0 002.4247 4.209zM27.2634 11.9A11.917 11.917 0 0128 16h2a13.8971 13.8971 0 00-.8594-4.7827zM13.9182 27.8066A11.8894 11.8894 0 0110.0068 26.38l-.9989 1.73a13.8673 13.8673 0 004.5633 1.664zM13.9182 4.1934a11.3012 11.3012 0 014.1636 0l.347-1.9678a13.187 13.187 0 00-4.8576 0z"
  })), children);
});
var Queued16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Queued16(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 20H30V22H22zM22 24H30V26H22zM22 28H30V30H22zM18 24H20V26H18zM18 20H20V22H18zM18 28H20V30H18zM6.8149 8.293A12.0777 12.0777 0 0110.0068 5.62L9.0079 3.89A14.0845 14.0845 0 005.2841 7.0083zM25.1851 8.293l1.5308-1.2847A14.0845 14.0845 0 0022.9921 3.89l-.9989 1.73A12.0777 12.0777 0 0125.1851 8.293zM4.7366 11.9l-1.8772-.6831A13.9019 13.9019 0 002 16H4A11.917 11.917 0 014.7366 11.9zM6.8149 23.707A11.9975 11.9975 0 014.7366 20.1l-1.8772.6831a13.99 13.99 0 002.4247 4.209zM27.2634 11.9A11.917 11.917 0 0128 16h2a13.8971 13.8971 0 00-.8594-4.7827zM13.9182 27.8066A11.8894 11.8894 0 0110.0068 26.38l-.9989 1.73a13.8673 13.8673 0 004.5633 1.664zM13.9182 4.1934a11.3012 11.3012 0 014.1636 0l.347-1.9678a13.187 13.187 0 00-4.8576 0z"
  })), children);
});
var Quotes32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Quotes32(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 15H6.11A9 9 0 0110 8.86l1.79-1.2L10.69 6 8.9 7.2A11 11 0 004 16.35V23a2 2 0 002 2h6a2 2 0 002-2V17A2 2 0 0012 15zM26 15H20.11A9 9 0 0124 8.86l1.79-1.2L24.7 6 22.9 7.2A11 11 0 0018 16.35V23a2 2 0 002 2h6a2 2 0 002-2V17A2 2 0 0026 15z"
  })), children);
});
var Quotes24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Quotes24(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 15H6.11A9 9 0 0110 8.86l1.79-1.2L10.69 6 8.9 7.2A11 11 0 004 16.35V23a2 2 0 002 2h6a2 2 0 002-2V17A2 2 0 0012 15zM26 15H20.11A9 9 0 0124 8.86l1.79-1.2L24.7 6 22.9 7.2A11 11 0 0018 16.35V23a2 2 0 002 2h6a2 2 0 002-2V17A2 2 0 0026 15z"
  })), children);
});
var Quotes20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Quotes20(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 15H6.11A9 9 0 0110 8.86l1.79-1.2L10.69 6 8.9 7.2A11 11 0 004 16.35V23a2 2 0 002 2h6a2 2 0 002-2V17A2 2 0 0012 15zM26 15H20.11A9 9 0 0124 8.86l1.79-1.2L24.7 6 22.9 7.2A11 11 0 0018 16.35V23a2 2 0 002 2h6a2 2 0 002-2V17A2 2 0 0026 15z"
  })), children);
});
var Quotes16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Quotes16(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 15H6.11A9 9 0 0110 8.86l1.79-1.2L10.69 6 8.9 7.2A11 11 0 004 16.35V23a2 2 0 002 2h6a2 2 0 002-2V17A2 2 0 0012 15zM26 15H20.11A9 9 0 0124 8.86l1.79-1.2L24.7 6 22.9 7.2A11 11 0 0018 16.35V23a2 2 0 002 2h6a2 2 0 002-2V17A2 2 0 0026 15z"
  })), children);
});
var Radar32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Radar32(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4141,28.5859,2,15.293,15.293a1,1,0,0,0,1.414,1.414l4.18-4.1792A5.9956,5.9956,0,1,1,16,10V8a8.011,8.011,0,1,0,6.3164,3.0977L25.1631,8.251A11.881,11.881,0,0,1,28,16,12,12,0,1,1,16,4V2A14,14,0,1,0,30,16a13.8572,13.8572,0,0,0-3.4224-9.1636Z"
  })), children);
});
var Radar24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Radar24(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4141,28.5859,2,15.293,15.293a1,1,0,0,0,1.414,1.414l4.18-4.1792A5.9956,5.9956,0,1,1,16,10V8a8.011,8.011,0,1,0,6.3164,3.0977L25.1631,8.251A11.881,11.881,0,0,1,28,16,12,12,0,1,1,16,4V2A14,14,0,1,0,30,16a13.8572,13.8572,0,0,0-3.4224-9.1636Z"
  })), children);
});
var Radar20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Radar20(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4141,28.5859,2,15.293,15.293a1,1,0,0,0,1.414,1.414l4.18-4.1792A5.9956,5.9956,0,1,1,16,10V8a8.011,8.011,0,1,0,6.3164,3.0977L25.1631,8.251A11.881,11.881,0,0,1,28,16,12,12,0,1,1,16,4V2A14,14,0,1,0,30,16a13.8572,13.8572,0,0,0-3.4224-9.1636Z"
  })), children);
});
var Radar16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Radar16(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4141,28.5859,2,15.293,15.293a1,1,0,0,0,1.414,1.414l4.18-4.1792A5.9956,5.9956,0,1,1,16,10V8a8.011,8.011,0,1,0,6.3164,3.0977L25.1631,8.251A11.881,11.881,0,0,1,28,16,12,12,0,1,1,16,4V2A14,14,0,1,0,30,16a13.8572,13.8572,0,0,0-3.4224-9.1636Z"
  })), children);
});
var RadarEnhanced32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadarEnhanced32(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4146,28.5854,2,17.2932,13.2925a1,1,0,1,0,1.4141,1.414l3.4543-3.4541A4.9817,4.9817,0,0,1,18,19a5.0385,5.0385,0,0,1-.6074-.05,8.0432,8.0432,0,0,0-4.3421-4.3423A4.9,4.9,0,0,1,18,9V7a7.0078,7.0078,0,0,0-7,7c0,.0234.0056.0469.0059.07A8.0469,8.0469,0,0,0,10,14a7.95,7.95,0,0,0-1.9883.26C8.0095,14.1729,8,14.0879,8,14A10.0114,10.0114,0,0,1,18,4V2A12.0137,12.0137,0,0,0,6,14c0,.355.0171.7061.0471,1.0537A7.9943,7.9943,0,1,0,16.9465,25.9521c.35.03.7019.0479,1.0535.0479A11.9853,11.9853,0,0,0,27.1538,6.2607ZM15.91,21H13.9563a12.029,12.029,0,0,0-1.218-4.332A6.01,6.01,0,0,1,15.91,21ZM4.09,23H6.0435a12.0318,12.0318,0,0,0,1.2182,4.3325A6.01,6.01,0,0,1,4.09,23Zm1.9532-2H4.09a6.01,6.01,0,0,1,3.1714-4.332A12.0321,12.0321,0,0,0,6.0435,21ZM10,27.9858A10.0149,10.0149,0,0,1,8.0552,23h3.89A10.0149,10.0149,0,0,1,10,27.9858ZM8.0552,21A10.0118,10.0118,0,0,1,10,16.0151,10.01,10.01,0,0,1,11.9448,21Zm4.6831,6.3325A12.0318,12.0318,0,0,0,13.9565,23H15.91A6.01,6.01,0,0,1,12.7383,27.3325ZM28,14A10.0114,10.0114,0,0,1,18,24c-.0869,0-.1733-.01-.26-.0117a7.5527,7.5527,0,0,0,.19-2.9942c.0237,0,.0466.0059.07.0059A6.9991,6.9991,0,0,0,23.6055,9.8086l2.1313-2.1314A9.95,9.95,0,0,1,28,14Z"
  })), children);
});
var RadarEnhanced24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadarEnhanced24(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4146,28.5854,2,17.2932,13.2925a1,1,0,1,0,1.4141,1.414l3.4543-3.4541A4.9817,4.9817,0,0,1,18,19a5.0385,5.0385,0,0,1-.6074-.05,8.0432,8.0432,0,0,0-4.3421-4.3423A4.9,4.9,0,0,1,18,9V7a7.0078,7.0078,0,0,0-7,7c0,.0234.0056.0469.0059.07A8.0469,8.0469,0,0,0,10,14a7.95,7.95,0,0,0-1.9883.26C8.0095,14.1729,8,14.0879,8,14A10.0114,10.0114,0,0,1,18,4V2A12.0137,12.0137,0,0,0,6,14c0,.355.0171.7061.0471,1.0537A7.9943,7.9943,0,1,0,16.9465,25.9521c.35.03.7019.0479,1.0535.0479A11.9853,11.9853,0,0,0,27.1538,6.2607ZM15.91,21H13.9563a12.029,12.029,0,0,0-1.218-4.332A6.01,6.01,0,0,1,15.91,21ZM4.09,23H6.0435a12.0318,12.0318,0,0,0,1.2182,4.3325A6.01,6.01,0,0,1,4.09,23Zm1.9532-2H4.09a6.01,6.01,0,0,1,3.1714-4.332A12.0321,12.0321,0,0,0,6.0435,21ZM10,27.9858A10.0149,10.0149,0,0,1,8.0552,23h3.89A10.0149,10.0149,0,0,1,10,27.9858ZM8.0552,21A10.0118,10.0118,0,0,1,10,16.0151,10.01,10.01,0,0,1,11.9448,21Zm4.6831,6.3325A12.0318,12.0318,0,0,0,13.9565,23H15.91A6.01,6.01,0,0,1,12.7383,27.3325ZM28,14A10.0114,10.0114,0,0,1,18,24c-.0869,0-.1733-.01-.26-.0117a7.5527,7.5527,0,0,0,.19-2.9942c.0237,0,.0466.0059.07.0059A6.9991,6.9991,0,0,0,23.6055,9.8086l2.1313-2.1314A9.95,9.95,0,0,1,28,14Z"
  })), children);
});
var RadarEnhanced20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadarEnhanced20(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4146,28.5854,2,17.2932,13.2925a1,1,0,1,0,1.4141,1.414l3.4543-3.4541A4.9817,4.9817,0,0,1,18,19a5.0385,5.0385,0,0,1-.6074-.05,8.0432,8.0432,0,0,0-4.3421-4.3423A4.9,4.9,0,0,1,18,9V7a7.0078,7.0078,0,0,0-7,7c0,.0234.0056.0469.0059.07A8.0469,8.0469,0,0,0,10,14a7.95,7.95,0,0,0-1.9883.26C8.0095,14.1729,8,14.0879,8,14A10.0114,10.0114,0,0,1,18,4V2A12.0137,12.0137,0,0,0,6,14c0,.355.0171.7061.0471,1.0537A7.9943,7.9943,0,1,0,16.9465,25.9521c.35.03.7019.0479,1.0535.0479A11.9853,11.9853,0,0,0,27.1538,6.2607ZM15.91,21H13.9563a12.029,12.029,0,0,0-1.218-4.332A6.01,6.01,0,0,1,15.91,21ZM4.09,23H6.0435a12.0318,12.0318,0,0,0,1.2182,4.3325A6.01,6.01,0,0,1,4.09,23Zm1.9532-2H4.09a6.01,6.01,0,0,1,3.1714-4.332A12.0321,12.0321,0,0,0,6.0435,21ZM10,27.9858A10.0149,10.0149,0,0,1,8.0552,23h3.89A10.0149,10.0149,0,0,1,10,27.9858ZM8.0552,21A10.0118,10.0118,0,0,1,10,16.0151,10.01,10.01,0,0,1,11.9448,21Zm4.6831,6.3325A12.0318,12.0318,0,0,0,13.9565,23H15.91A6.01,6.01,0,0,1,12.7383,27.3325ZM28,14A10.0114,10.0114,0,0,1,18,24c-.0869,0-.1733-.01-.26-.0117a7.5527,7.5527,0,0,0,.19-2.9942c.0237,0,.0466.0059.07.0059A6.9991,6.9991,0,0,0,23.6055,9.8086l2.1313-2.1314A9.95,9.95,0,0,1,28,14Z"
  })), children);
});
var RadarEnhanced16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadarEnhanced16(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4146,28.5854,2,17.2932,13.2925a1,1,0,1,0,1.4141,1.414l3.4543-3.4541A4.9817,4.9817,0,0,1,18,19a5.0385,5.0385,0,0,1-.6074-.05,8.0432,8.0432,0,0,0-4.3421-4.3423A4.9,4.9,0,0,1,18,9V7a7.0078,7.0078,0,0,0-7,7c0,.0234.0056.0469.0059.07A8.0469,8.0469,0,0,0,10,14a7.95,7.95,0,0,0-1.9883.26C8.0095,14.1729,8,14.0879,8,14A10.0114,10.0114,0,0,1,18,4V2A12.0137,12.0137,0,0,0,6,14c0,.355.0171.7061.0471,1.0537A7.9943,7.9943,0,1,0,16.9465,25.9521c.35.03.7019.0479,1.0535.0479A11.9853,11.9853,0,0,0,27.1538,6.2607ZM15.91,21H13.9563a12.029,12.029,0,0,0-1.218-4.332A6.01,6.01,0,0,1,15.91,21ZM4.09,23H6.0435a12.0318,12.0318,0,0,0,1.2182,4.3325A6.01,6.01,0,0,1,4.09,23Zm1.9532-2H4.09a6.01,6.01,0,0,1,3.1714-4.332A12.0321,12.0321,0,0,0,6.0435,21ZM10,27.9858A10.0149,10.0149,0,0,1,8.0552,23h3.89A10.0149,10.0149,0,0,1,10,27.9858ZM8.0552,21A10.0118,10.0118,0,0,1,10,16.0151,10.01,10.01,0,0,1,11.9448,21Zm4.6831,6.3325A12.0318,12.0318,0,0,0,13.9565,23H15.91A6.01,6.01,0,0,1,12.7383,27.3325ZM28,14A10.0114,10.0114,0,0,1,18,24c-.0869,0-.1733-.01-.26-.0117a7.5527,7.5527,0,0,0,.19-2.9942c.0237,0,.0466.0059.07.0059A6.9991,6.9991,0,0,0,23.6055,9.8086l2.1313-2.1314A9.95,9.95,0,0,1,28,14Z"
  })), children);
});
var RadarWeather32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadarWeather32(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4146,28.5854,2,17.2932,13.2925a1,1,0,1,0,1.4141,1.414l3.4543-3.4541a4.9646,4.9646,0,0,1-3.8811,7.7193,7.0485,7.0485,0,0,0-5.1438-3.8731A4.9431,4.9431,0,0,1,18,9V7a6.9551,6.9551,0,0,0-6.9087,8.0791,6.93,6.93,0,0,0-2.8525,1.06A9.97,9.97,0,0,1,18,4V2A11.9756,11.9756,0,0,0,6.573,17.6357a6.9293,6.9293,0,0,0-1.3674,2.7061A4.9948,4.9948,0,0,0,7,30H17a4.9921,4.9921,0,0,0,4.9678-4.68A12.0391,12.0391,0,0,0,30,14a11.8678,11.8678,0,0,0-2.8389-7.7466ZM17,28H7a2.9945,2.9945,0,0,1-.6963-5.9082l.6587-.1572.0986-.67a4.9923,4.9923,0,0,1,9.878,0l.0986.6695.6587.1572A2.9945,2.9945,0,0,1,17,28ZM28,14a10.0346,10.0346,0,0,1-6.3118,9.291,4.9577,4.9577,0,0,0-2.0207-2.5,6.9922,6.9922,0,0,0,3.938-10.9824l2.132-2.1318A9.8873,9.8873,0,0,1,28,14Z"
  })), children);
});
var RadarWeather24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadarWeather24(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4146,28.5854,2,17.2932,13.2925a1,1,0,1,0,1.4141,1.414l3.4543-3.4541a4.9646,4.9646,0,0,1-3.8811,7.7193,7.0485,7.0485,0,0,0-5.1438-3.8731A4.9431,4.9431,0,0,1,18,9V7a6.9551,6.9551,0,0,0-6.9087,8.0791,6.93,6.93,0,0,0-2.8525,1.06A9.97,9.97,0,0,1,18,4V2A11.9756,11.9756,0,0,0,6.573,17.6357a6.9293,6.9293,0,0,0-1.3674,2.7061A4.9948,4.9948,0,0,0,7,30H17a4.9921,4.9921,0,0,0,4.9678-4.68A12.0391,12.0391,0,0,0,30,14a11.8678,11.8678,0,0,0-2.8389-7.7466ZM17,28H7a2.9945,2.9945,0,0,1-.6963-5.9082l.6587-.1572.0986-.67a4.9923,4.9923,0,0,1,9.878,0l.0986.6695.6587.1572A2.9945,2.9945,0,0,1,17,28ZM28,14a10.0346,10.0346,0,0,1-6.3118,9.291,4.9577,4.9577,0,0,0-2.0207-2.5,6.9922,6.9922,0,0,0,3.938-10.9824l2.132-2.1318A9.8873,9.8873,0,0,1,28,14Z"
  })), children);
});
var RadarWeather20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadarWeather20(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4146,28.5854,2,17.2932,13.2925a1,1,0,1,0,1.4141,1.414l3.4543-3.4541a4.9646,4.9646,0,0,1-3.8811,7.7193,7.0485,7.0485,0,0,0-5.1438-3.8731A4.9431,4.9431,0,0,1,18,9V7a6.9551,6.9551,0,0,0-6.9087,8.0791,6.93,6.93,0,0,0-2.8525,1.06A9.97,9.97,0,0,1,18,4V2A11.9756,11.9756,0,0,0,6.573,17.6357a6.9293,6.9293,0,0,0-1.3674,2.7061A4.9948,4.9948,0,0,0,7,30H17a4.9921,4.9921,0,0,0,4.9678-4.68A12.0391,12.0391,0,0,0,30,14a11.8678,11.8678,0,0,0-2.8389-7.7466ZM17,28H7a2.9945,2.9945,0,0,1-.6963-5.9082l.6587-.1572.0986-.67a4.9923,4.9923,0,0,1,9.878,0l.0986.6695.6587.1572A2.9945,2.9945,0,0,1,17,28ZM28,14a10.0346,10.0346,0,0,1-6.3118,9.291,4.9577,4.9577,0,0,0-2.0207-2.5,6.9922,6.9922,0,0,0,3.938-10.9824l2.132-2.1318A9.8873,9.8873,0,0,1,28,14Z"
  })), children);
});
var RadarWeather16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadarWeather16(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4146,28.5854,2,17.2932,13.2925a1,1,0,1,0,1.4141,1.414l3.4543-3.4541a4.9646,4.9646,0,0,1-3.8811,7.7193,7.0485,7.0485,0,0,0-5.1438-3.8731A4.9431,4.9431,0,0,1,18,9V7a6.9551,6.9551,0,0,0-6.9087,8.0791,6.93,6.93,0,0,0-2.8525,1.06A9.97,9.97,0,0,1,18,4V2A11.9756,11.9756,0,0,0,6.573,17.6357a6.9293,6.9293,0,0,0-1.3674,2.7061A4.9948,4.9948,0,0,0,7,30H17a4.9921,4.9921,0,0,0,4.9678-4.68A12.0391,12.0391,0,0,0,30,14a11.8678,11.8678,0,0,0-2.8389-7.7466ZM17,28H7a2.9945,2.9945,0,0,1-.6963-5.9082l.6587-.1572.0986-.67a4.9923,4.9923,0,0,1,9.878,0l.0986.6695.6587.1572A2.9945,2.9945,0,0,1,17,28ZM28,14a10.0346,10.0346,0,0,1-6.3118,9.291,4.9577,4.9577,0,0,0-2.0207-2.5,6.9922,6.9922,0,0,0,3.938-10.9824l2.132-2.1318A9.8873,9.8873,0,0,1,28,14Z"
  })), children);
});
var Radio32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Radio32(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H24V2H22v8H13V8H11v2H8V8H6v2H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10ZM4,28V12H28V28Z"
  })), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 26a4 4 0 114-4A4 4 0 0110 26zm0-6a2 2 0 102 2A2 2 0 0010 20zM7 14H13V16H7zM17 16H26V18H17zM17 20H26V22H17zM17 24H26V26H17z"
  })), children);
});
var Radio24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Radio24(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H24V2H22v8H13V8H11v2H8V8H6v2H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10ZM4,28V12H28V28Z"
  })), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 26a4 4 0 114-4A4 4 0 0110 26zm0-6a2 2 0 102 2A2 2 0 0010 20zM7 14H13V16H7zM17 16H26V18H17zM17 20H26V22H17zM17 24H26V26H17z"
  })), children);
});
var Radio20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Radio20(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H24V2H22v8H13V8H11v2H8V8H6v2H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10ZM4,28V12H28V28Z"
  })), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 26a4 4 0 114-4A4 4 0 0110 26zm0-6a2 2 0 102 2A2 2 0 0010 20zM7 14H13V16H7zM17 16H26V18H17zM17 20H26V22H17zM17 24H26V26H17z"
  })), children);
});
var Radio16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Radio16(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H24V2H22v8H13V8H11v2H8V8H6v2H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10ZM4,28V12H28V28Z"
  })), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 26a4 4 0 114-4A4 4 0 0110 26zm0-6a2 2 0 102 2A2 2 0 0010 20zM7 14H13V16H7zM17 16H26V18H17zM17 20H26V22H17zM17 24H26V26H17z"
  })), children);
});
var RadioCombat32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadioCombat32(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 26a4 4 0 114-4A4.0045 4.0045 0 0110 26zm0-6a2 2 0 102 2A2.0021 2.0021 0 0010 20zM17 20H26V22H17zM17 24H26V26H17z"
  })), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,12h8a2.0023,2.0023,0,0,0,2-2V6a2.0023,2.0023,0,0,0-2-2H20a2.0023,2.0023,0,0,0-2,2V7H12a4.0045,4.0045,0,0,0-4,4v3H6V4H4V14a2.0023,2.0023,0,0,0-2,2V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V16a2.0023,2.0023,0,0,0-2-2H10V11a2.0023,2.0023,0,0,1,2-2h6v1A2.0023,2.0023,0,0,0,20,12Zm4-6h4v4H24ZM20,6h2v4H20Zm8,22H4V16H28Z"
  })), children);
});
var RadioCombat24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadioCombat24(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 26a4 4 0 114-4A4.0045 4.0045 0 0110 26zm0-6a2 2 0 102 2A2.0021 2.0021 0 0010 20zM17 20H26V22H17zM17 24H26V26H17z"
  })), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,12h8a2.0023,2.0023,0,0,0,2-2V6a2.0023,2.0023,0,0,0-2-2H20a2.0023,2.0023,0,0,0-2,2V7H12a4.0045,4.0045,0,0,0-4,4v3H6V4H4V14a2.0023,2.0023,0,0,0-2,2V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V16a2.0023,2.0023,0,0,0-2-2H10V11a2.0023,2.0023,0,0,1,2-2h6v1A2.0023,2.0023,0,0,0,20,12Zm4-6h4v4H24ZM20,6h2v4H20Zm8,22H4V16H28Z"
  })), children);
});
var RadioCombat20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadioCombat20(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 26a4 4 0 114-4A4.0045 4.0045 0 0110 26zm0-6a2 2 0 102 2A2.0021 2.0021 0 0010 20zM17 20H26V22H17zM17 24H26V26H17z"
  })), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,12h8a2.0023,2.0023,0,0,0,2-2V6a2.0023,2.0023,0,0,0-2-2H20a2.0023,2.0023,0,0,0-2,2V7H12a4.0045,4.0045,0,0,0-4,4v3H6V4H4V14a2.0023,2.0023,0,0,0-2,2V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V16a2.0023,2.0023,0,0,0-2-2H10V11a2.0023,2.0023,0,0,1,2-2h6v1A2.0023,2.0023,0,0,0,20,12Zm4-6h4v4H24ZM20,6h2v4H20Zm8,22H4V16H28Z"
  })), children);
});
var RadioCombat16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadioCombat16(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 26a4 4 0 114-4A4.0045 4.0045 0 0110 26zm0-6a2 2 0 102 2A2.0021 2.0021 0 0010 20zM17 20H26V22H17zM17 24H26V26H17z"
  })), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,12h8a2.0023,2.0023,0,0,0,2-2V6a2.0023,2.0023,0,0,0-2-2H20a2.0023,2.0023,0,0,0-2,2V7H12a4.0045,4.0045,0,0,0-4,4v3H6V4H4V14a2.0023,2.0023,0,0,0-2,2V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V16a2.0023,2.0023,0,0,0-2-2H10V11a2.0023,2.0023,0,0,1,2-2h6v1A2.0023,2.0023,0,0,0,20,12Zm4-6h4v4H24ZM20,6h2v4H20Zm8,22H4V16H28Z"
  })), children);
});
var RadioPushToTalk32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadioPushToTalk32(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 11H19V13H13zM13 15H19V17H13z"
  })), _circle53 || (_circle53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "23",
    r: "2"
  })), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,7H21V2H19V7H10A2.0023,2.0023,0,0,0,8,9v2H6v2H8v2H6v2H8V28a2.0023,2.0023,0,0,0,2,2H22a2.0023,2.0023,0,0,0,2-2V9A2.0023,2.0023,0,0,0,22,7ZM10,28V9H22V28Z"
  })), children);
});
var RadioPushToTalk24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadioPushToTalk24(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 11H19V13H13zM13 15H19V17H13z"
  })), _circle54 || (_circle54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "23",
    r: "2"
  })), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,7H21V2H19V7H10A2.0023,2.0023,0,0,0,8,9v2H6v2H8v2H6v2H8V28a2.0023,2.0023,0,0,0,2,2H22a2.0023,2.0023,0,0,0,2-2V9A2.0023,2.0023,0,0,0,22,7ZM10,28V9H22V28Z"
  })), children);
});
var RadioPushToTalk20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadioPushToTalk20(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 11H19V13H13zM13 15H19V17H13z"
  })), _circle55 || (_circle55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "23",
    r: "2"
  })), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,7H21V2H19V7H10A2.0023,2.0023,0,0,0,8,9v2H6v2H8v2H6v2H8V28a2.0023,2.0023,0,0,0,2,2H22a2.0023,2.0023,0,0,0,2-2V9A2.0023,2.0023,0,0,0,22,7ZM10,28V9H22V28Z"
  })), children);
});
var RadioPushToTalk16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadioPushToTalk16(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 11H19V13H13zM13 15H19V17H13z"
  })), _circle56 || (_circle56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "23",
    r: "2"
  })), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,7H21V2H19V7H10A2.0023,2.0023,0,0,0,8,9v2H6v2H8v2H6v2H8V28a2.0023,2.0023,0,0,0,2,2H22a2.0023,2.0023,0,0,0,2-2V9A2.0023,2.0023,0,0,0,22,7ZM10,28V9H22V28Z"
  })), children);
});
var RadioButton32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadioButton32(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), children);
});
var RadioButton24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadioButton24(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), children);
});
var RadioButton20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadioButton20(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), children);
});
var RadioButton16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadioButton16(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), children);
});
var RadioButtonChecked32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadioButtonChecked32(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a6,6,0,1,0,6,6A6,6,0,0,0,16,10Z"
  })), children);
});
var RadioButtonChecked24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadioButtonChecked24(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a6,6,0,1,0,6,6A6,6,0,0,0,16,10Z"
  })), children);
});
var RadioButtonChecked20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadioButtonChecked20(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a6,6,0,1,0,6,6A6,6,0,0,0,16,10Z"
  })), children);
});
var RadioButtonChecked16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RadioButtonChecked16(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a6,6,0,1,0,6,6A6,6,0,0,0,16,10Z"
  })), children);
});
var Rain32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rain32(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 22H8.5A6.5 6.5 0 017.2 9.14a9 9 0 0117.6 0A6.5 6.5 0 0123.5 22zM16 4a7 7 0 00-6.94 6.14L9 11 8.14 11a4.5 4.5 0 00.36 9h15a4.5 4.5 0 00.36-9L23 11l-.1-.82A7 7 0 0016 4zM14 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 0114 30zM20 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 0120 30zM8 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 018 30z"
  })), children);
});
var Rain24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rain24(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 22H8.5A6.5 6.5 0 017.2 9.14a9 9 0 0117.6 0A6.5 6.5 0 0123.5 22zM16 4a7 7 0 00-6.94 6.14L9 11 8.14 11a4.5 4.5 0 00.36 9h15a4.5 4.5 0 00.36-9L23 11l-.1-.82A7 7 0 0016 4zM14 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 0114 30zM20 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 0120 30zM8 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 018 30z"
  })), children);
});
var Rain20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rain20(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 22H8.5A6.5 6.5 0 017.2 9.14a9 9 0 0117.6 0A6.5 6.5 0 0123.5 22zM16 4a7 7 0 00-6.94 6.14L9 11 8.14 11a4.5 4.5 0 00.36 9h15a4.5 4.5 0 00.36-9L23 11l-.1-.82A7 7 0 0016 4zM14 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 0114 30zM20 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 0120 30zM8 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 018 30z"
  })), children);
});
var Rain16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rain16(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 22H8.5A6.5 6.5 0 017.2 9.14a9 9 0 0117.6 0A6.5 6.5 0 0123.5 22zM16 4a7 7 0 00-6.94 6.14L9 11 8.14 11a4.5 4.5 0 00.36 9h15a4.5 4.5 0 00.36-9L23 11l-.1-.82A7 7 0 0016 4zM14 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 0114 30zM20 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 0120 30zM8 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 018 30z"
  })), children);
});
var RainDrizzle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainDrizzle32(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,30a1,1,0,0,1-.8944-1.4474l2-4a1,1,0,1,1,1.7887.8946l-2,4A.9979.9979,0,0,1,11,30Z"
  })), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0A6.4973,6.4973,0,0,0,8.5,22H19.3813L18.105,24.5527a1,1,0,0,0,1.789.8946L21.6177,22H23.5A6.4974,6.4974,0,0,0,24.8008,9.1362ZM23.5,20H8.5a4.4975,4.4975,0,0,1-.356-8.981l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4975,4.4975,0,0,1,23.5,20Z"
  })), children);
});
var RainDrizzle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainDrizzle24(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,30a1,1,0,0,1-.8944-1.4474l2-4a1,1,0,1,1,1.7887.8946l-2,4A.9979.9979,0,0,1,11,30Z"
  })), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0A6.4973,6.4973,0,0,0,8.5,22H19.3813L18.105,24.5527a1,1,0,0,0,1.789.8946L21.6177,22H23.5A6.4974,6.4974,0,0,0,24.8008,9.1362ZM23.5,20H8.5a4.4975,4.4975,0,0,1-.356-8.981l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4975,4.4975,0,0,1,23.5,20Z"
  })), children);
});
var RainDrizzle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainDrizzle20(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,30a1,1,0,0,1-.8944-1.4474l2-4a1,1,0,1,1,1.7887.8946l-2,4A.9979.9979,0,0,1,11,30Z"
  })), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0A6.4973,6.4973,0,0,0,8.5,22H19.3813L18.105,24.5527a1,1,0,0,0,1.789.8946L21.6177,22H23.5A6.4974,6.4974,0,0,0,24.8008,9.1362ZM23.5,20H8.5a4.4975,4.4975,0,0,1-.356-8.981l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4975,4.4975,0,0,1,23.5,20Z"
  })), children);
});
var RainDrizzle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainDrizzle16(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,30a1,1,0,0,1-.8944-1.4474l2-4a1,1,0,1,1,1.7887.8946l-2,4A.9979.9979,0,0,1,11,30Z"
  })), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0A6.4973,6.4973,0,0,0,8.5,22H19.3813L18.105,24.5527a1,1,0,0,0,1.789.8946L21.6177,22H23.5A6.4974,6.4974,0,0,0,24.8008,9.1362ZM23.5,20H8.5a4.4975,4.4975,0,0,1-.356-8.981l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4975,4.4975,0,0,1,23.5,20Z"
  })), children);
});
var RainHeavy32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainHeavy32(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 0117 30zM8 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 018 30z"
  })), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15.5a6.5323,6.5323,0,0,0-5.1992-6.3638,8.9943,8.9943,0,0,0-17.6006,0A6.4905,6.4905,0,0,0,5.7026,21.3584L4.106,24.5527a1,1,0,1,0,1.7885.8946L7.6174,22l6.7644,0L13.106,24.5527a1,1,0,1,0,1.7885.8946L16.6177,22h6.7641L22.106,24.5527a1,1,0,1,0,1.7885.8946l1.9444-3.89A6.5058,6.5058,0,0,0,30,15.5ZM23.5,20H8.5a4.4975,4.4975,0,0,1-.356-8.981l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4975,4.4975,0,0,1,23.5,20Z"
  })), children);
});
var RainHeavy24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainHeavy24(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 0117 30zM8 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 018 30z"
  })), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15.5a6.5323,6.5323,0,0,0-5.1992-6.3638,8.9943,8.9943,0,0,0-17.6006,0A6.4905,6.4905,0,0,0,5.7026,21.3584L4.106,24.5527a1,1,0,1,0,1.7885.8946L7.6174,22l6.7644,0L13.106,24.5527a1,1,0,1,0,1.7885.8946L16.6177,22h6.7641L22.106,24.5527a1,1,0,1,0,1.7885.8946l1.9444-3.89A6.5058,6.5058,0,0,0,30,15.5ZM23.5,20H8.5a4.4975,4.4975,0,0,1-.356-8.981l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4975,4.4975,0,0,1,23.5,20Z"
  })), children);
});
var RainHeavy20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainHeavy20(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 0117 30zM8 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 018 30z"
  })), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15.5a6.5323,6.5323,0,0,0-5.1992-6.3638,8.9943,8.9943,0,0,0-17.6006,0A6.4905,6.4905,0,0,0,5.7026,21.3584L4.106,24.5527a1,1,0,1,0,1.7885.8946L7.6174,22l6.7644,0L13.106,24.5527a1,1,0,1,0,1.7885.8946L16.6177,22h6.7641L22.106,24.5527a1,1,0,1,0,1.7885.8946l1.9444-3.89A6.5058,6.5058,0,0,0,30,15.5ZM23.5,20H8.5a4.4975,4.4975,0,0,1-.356-8.981l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4975,4.4975,0,0,1,23.5,20Z"
  })), children);
});
var RainHeavy16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainHeavy16(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 0117 30zM8 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 018 30z"
  })), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15.5a6.5323,6.5323,0,0,0-5.1992-6.3638,8.9943,8.9943,0,0,0-17.6006,0A6.4905,6.4905,0,0,0,5.7026,21.3584L4.106,24.5527a1,1,0,1,0,1.7885.8946L7.6174,22l6.7644,0L13.106,24.5527a1,1,0,1,0,1.7885.8946L16.6177,22h6.7641L22.106,24.5527a1,1,0,1,0,1.7885.8946l1.9444-3.89A6.5058,6.5058,0,0,0,30,15.5ZM23.5,20H8.5a4.4975,4.4975,0,0,1-.356-8.981l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4975,4.4975,0,0,1,23.5,20Z"
  })), children);
});
var RainScattered32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainScattered32(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.5084,32a1.0127,1.0127,0,0,1-.4485-.1054.9986.9986,0,0,1-.4486-1.3418l1.4934-3.0005a1.0025,1.0025,0,0,1,1.7943.8945l-1.4934,3A1.0013,1.0013,0,0,1,8.5084,32Z"
  })), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.232 15.733H29.232V18.733H27.232z",
    transform: "rotate(-45.009 28.232 17.233)"
  })), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 10H32V12H29z"
  })), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 3.768H29.732V5.768H26.732z",
    transform: "rotate(-45 28.232 4.768)"
  })), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 0H22V3H20z"
  })), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.768 3.268H14.768V6.268H12.768z",
    transform: "rotate(-45 13.768 4.768)"
  })), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,11A5.9955,5.9955,0,0,0,15.6335,8.3311,7.3494,7.3494,0,0,0,13.5,8a7.5509,7.5509,0,0,0-7.1492,5.2441A5.9926,5.9926,0,0,0,8,25h7.3818L14.106,27.5527a1,1,0,1,0,1.7885.8946L17.6177,25H19a5.9853,5.9853,0,0,0,5.2163-8.9463A5.9941,5.9941,0,0,0,27,11ZM19,23H8a3.9925,3.9925,0,0,1-.6731-7.9292L7.99,14.958l.1458-.6562a5.496,5.496,0,0,1,10.7294,0l.1458.6562.6626.1128A3.9925,3.9925,0,0,1,19,23Zm3.9268-8.5107a5.96,5.96,0,0,0-2.2776-1.2452,7.5157,7.5157,0,0,0-3.1853-4.0688,3.9869,3.9869,0,1,1,5.4629,5.314Z"
  })), children);
});
var RainScattered24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainScattered24(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.5084,32a1.0127,1.0127,0,0,1-.4485-.1054.9986.9986,0,0,1-.4486-1.3418l1.4934-3.0005a1.0025,1.0025,0,0,1,1.7943.8945l-1.4934,3A1.0013,1.0013,0,0,1,8.5084,32Z"
  })), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.232 15.733H29.232V18.733H27.232z",
    transform: "rotate(-45.009 28.232 17.233)"
  })), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 10H32V12H29z"
  })), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 3.768H29.732V5.768H26.732z",
    transform: "rotate(-45 28.232 4.768)"
  })), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 0H22V3H20z"
  })), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.768 3.268H14.768V6.268H12.768z",
    transform: "rotate(-45 13.768 4.768)"
  })), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,11A5.9955,5.9955,0,0,0,15.6335,8.3311,7.3494,7.3494,0,0,0,13.5,8a7.5509,7.5509,0,0,0-7.1492,5.2441A5.9926,5.9926,0,0,0,8,25h7.3818L14.106,27.5527a1,1,0,1,0,1.7885.8946L17.6177,25H19a5.9853,5.9853,0,0,0,5.2163-8.9463A5.9941,5.9941,0,0,0,27,11ZM19,23H8a3.9925,3.9925,0,0,1-.6731-7.9292L7.99,14.958l.1458-.6562a5.496,5.496,0,0,1,10.7294,0l.1458.6562.6626.1128A3.9925,3.9925,0,0,1,19,23Zm3.9268-8.5107a5.96,5.96,0,0,0-2.2776-1.2452,7.5157,7.5157,0,0,0-3.1853-4.0688,3.9869,3.9869,0,1,1,5.4629,5.314Z"
  })), children);
});
var RainScattered20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainScattered20(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.5084,32a1.0127,1.0127,0,0,1-.4485-.1054.9986.9986,0,0,1-.4486-1.3418l1.4934-3.0005a1.0025,1.0025,0,0,1,1.7943.8945l-1.4934,3A1.0013,1.0013,0,0,1,8.5084,32Z"
  })), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.232 15.733H29.232V18.733H27.232z",
    transform: "rotate(-45.009 28.232 17.233)"
  })), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 10H32V12H29z"
  })), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 3.768H29.732V5.768H26.732z",
    transform: "rotate(-45 28.232 4.768)"
  })), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 0H22V3H20z"
  })), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.768 3.268H14.768V6.268H12.768z",
    transform: "rotate(-45 13.768 4.768)"
  })), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,11A5.9955,5.9955,0,0,0,15.6335,8.3311,7.3494,7.3494,0,0,0,13.5,8a7.5509,7.5509,0,0,0-7.1492,5.2441A5.9926,5.9926,0,0,0,8,25h7.3818L14.106,27.5527a1,1,0,1,0,1.7885.8946L17.6177,25H19a5.9853,5.9853,0,0,0,5.2163-8.9463A5.9941,5.9941,0,0,0,27,11ZM19,23H8a3.9925,3.9925,0,0,1-.6731-7.9292L7.99,14.958l.1458-.6562a5.496,5.496,0,0,1,10.7294,0l.1458.6562.6626.1128A3.9925,3.9925,0,0,1,19,23Zm3.9268-8.5107a5.96,5.96,0,0,0-2.2776-1.2452,7.5157,7.5157,0,0,0-3.1853-4.0688,3.9869,3.9869,0,1,1,5.4629,5.314Z"
  })), children);
});
var RainScattered16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainScattered16(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.5084,32a1.0127,1.0127,0,0,1-.4485-.1054.9986.9986,0,0,1-.4486-1.3418l1.4934-3.0005a1.0025,1.0025,0,0,1,1.7943.8945l-1.4934,3A1.0013,1.0013,0,0,1,8.5084,32Z"
  })), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.232 15.733H29.232V18.733H27.232z",
    transform: "rotate(-45.009 28.232 17.233)"
  })), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 10H32V12H29z"
  })), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 3.768H29.732V5.768H26.732z",
    transform: "rotate(-45 28.232 4.768)"
  })), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 0H22V3H20z"
  })), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.768 3.268H14.768V6.268H12.768z",
    transform: "rotate(-45 13.768 4.768)"
  })), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,11A5.9955,5.9955,0,0,0,15.6335,8.3311,7.3494,7.3494,0,0,0,13.5,8a7.5509,7.5509,0,0,0-7.1492,5.2441A5.9926,5.9926,0,0,0,8,25h7.3818L14.106,27.5527a1,1,0,1,0,1.7885.8946L17.6177,25H19a5.9853,5.9853,0,0,0,5.2163-8.9463A5.9941,5.9941,0,0,0,27,11ZM19,23H8a3.9925,3.9925,0,0,1-.6731-7.9292L7.99,14.958l.1458-.6562a5.496,5.496,0,0,1,10.7294,0l.1458.6562.6626.1128A3.9925,3.9925,0,0,1,19,23Zm3.9268-8.5107a5.96,5.96,0,0,0-2.2776-1.2452,7.5157,7.5157,0,0,0-3.1853-4.0688,3.9869,3.9869,0,1,1,5.4629,5.314Z"
  })), children);
});
var RainScatteredNight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainScatteredNight32(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.5084 32a1.0115 1.0115 0 01-.4485-.1055.9986.9986 0 01-.4486-1.3418l1.4934-3a1.0025 1.0025 0 011.7943.8945l-1.4934 3A1.0015 1.0015 0 018.5084 32zM29.8442 13.0347a1.5184 1.5184 0 00-1.2309-.8658 5.3587 5.3587 0 01-3.4094-1.7163 6.4648 6.4648 0 01-1.285-6.393 1.6031 1.6031 0 00-.3-1.5459 1.4535 1.4535 0 00-1.3594-.4922l-.0191.0029a7.8549 7.8549 0 00-6.1054 6.48A7.3725 7.3725 0 0013.5 8a7.5511 7.5511 0 00-7.1494 5.2441A5.9926 5.9926 0 008 25h7.3818L14.106 27.5527a1 1 0 101.7885.8946L17.6177 25H19a5.9549 5.9549 0 005.88-7.1455 7.5 7.5 0 004.8672-3.3A1.5381 1.5381 0 0029.8442 13.0347zM19 23H8a3.9926 3.9926 0 01-.6733-7.9292l.663-.1128.1456-.6562a5.496 5.496 0 0110.7294 0l.1456.6562.6626.1128A3.9925 3.9925 0 0119 23zm5.1509-7.0479a5.9639 5.9639 0 00-3.5015-2.708A7.5076 7.5076 0 0018.0286 9.55a6.01 6.01 0 013.77-5.334 8.4581 8.4581 0 001.9395 7.5972A7.4007 7.4007 0 0027.64 14.041 5.4392 5.4392 0 0124.1509 15.9521z"
  })), children);
});
var RainScatteredNight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainScatteredNight24(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.5084 32a1.0115 1.0115 0 01-.4485-.1055.9986.9986 0 01-.4486-1.3418l1.4934-3a1.0025 1.0025 0 011.7943.8945l-1.4934 3A1.0015 1.0015 0 018.5084 32zM29.8442 13.0347a1.5184 1.5184 0 00-1.2309-.8658 5.3587 5.3587 0 01-3.4094-1.7163 6.4648 6.4648 0 01-1.285-6.393 1.6031 1.6031 0 00-.3-1.5459 1.4535 1.4535 0 00-1.3594-.4922l-.0191.0029a7.8549 7.8549 0 00-6.1054 6.48A7.3725 7.3725 0 0013.5 8a7.5511 7.5511 0 00-7.1494 5.2441A5.9926 5.9926 0 008 25h7.3818L14.106 27.5527a1 1 0 101.7885.8946L17.6177 25H19a5.9549 5.9549 0 005.88-7.1455 7.5 7.5 0 004.8672-3.3A1.5381 1.5381 0 0029.8442 13.0347zM19 23H8a3.9926 3.9926 0 01-.6733-7.9292l.663-.1128.1456-.6562a5.496 5.496 0 0110.7294 0l.1456.6562.6626.1128A3.9925 3.9925 0 0119 23zm5.1509-7.0479a5.9639 5.9639 0 00-3.5015-2.708A7.5076 7.5076 0 0018.0286 9.55a6.01 6.01 0 013.77-5.334 8.4581 8.4581 0 001.9395 7.5972A7.4007 7.4007 0 0027.64 14.041 5.4392 5.4392 0 0124.1509 15.9521z"
  })), children);
});
var RainScatteredNight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainScatteredNight20(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.5084 32a1.0115 1.0115 0 01-.4485-.1055.9986.9986 0 01-.4486-1.3418l1.4934-3a1.0025 1.0025 0 011.7943.8945l-1.4934 3A1.0015 1.0015 0 018.5084 32zM29.8442 13.0347a1.5184 1.5184 0 00-1.2309-.8658 5.3587 5.3587 0 01-3.4094-1.7163 6.4648 6.4648 0 01-1.285-6.393 1.6031 1.6031 0 00-.3-1.5459 1.4535 1.4535 0 00-1.3594-.4922l-.0191.0029a7.8549 7.8549 0 00-6.1054 6.48A7.3725 7.3725 0 0013.5 8a7.5511 7.5511 0 00-7.1494 5.2441A5.9926 5.9926 0 008 25h7.3818L14.106 27.5527a1 1 0 101.7885.8946L17.6177 25H19a5.9549 5.9549 0 005.88-7.1455 7.5 7.5 0 004.8672-3.3A1.5381 1.5381 0 0029.8442 13.0347zM19 23H8a3.9926 3.9926 0 01-.6733-7.9292l.663-.1128.1456-.6562a5.496 5.496 0 0110.7294 0l.1456.6562.6626.1128A3.9925 3.9925 0 0119 23zm5.1509-7.0479a5.9639 5.9639 0 00-3.5015-2.708A7.5076 7.5076 0 0018.0286 9.55a6.01 6.01 0 013.77-5.334 8.4581 8.4581 0 001.9395 7.5972A7.4007 7.4007 0 0027.64 14.041 5.4392 5.4392 0 0124.1509 15.9521z"
  })), children);
});
var RainScatteredNight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainScatteredNight16(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.5084 32a1.0115 1.0115 0 01-.4485-.1055.9986.9986 0 01-.4486-1.3418l1.4934-3a1.0025 1.0025 0 011.7943.8945l-1.4934 3A1.0015 1.0015 0 018.5084 32zM29.8442 13.0347a1.5184 1.5184 0 00-1.2309-.8658 5.3587 5.3587 0 01-3.4094-1.7163 6.4648 6.4648 0 01-1.285-6.393 1.6031 1.6031 0 00-.3-1.5459 1.4535 1.4535 0 00-1.3594-.4922l-.0191.0029a7.8549 7.8549 0 00-6.1054 6.48A7.3725 7.3725 0 0013.5 8a7.5511 7.5511 0 00-7.1494 5.2441A5.9926 5.9926 0 008 25h7.3818L14.106 27.5527a1 1 0 101.7885.8946L17.6177 25H19a5.9549 5.9549 0 005.88-7.1455 7.5 7.5 0 004.8672-3.3A1.5381 1.5381 0 0029.8442 13.0347zM19 23H8a3.9926 3.9926 0 01-.6733-7.9292l.663-.1128.1456-.6562a5.496 5.496 0 0110.7294 0l.1456.6562.6626.1128A3.9925 3.9925 0 0119 23zm5.1509-7.0479a5.9639 5.9639 0 00-3.5015-2.708A7.5076 7.5076 0 0018.0286 9.55a6.01 6.01 0 013.77-5.334 8.4581 8.4581 0 001.9395 7.5972A7.4007 7.4007 0 0027.64 14.041 5.4392 5.4392 0 0124.1509 15.9521z"
  })), children);
});
var RainDrop32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainDrop32(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24V22a3.2965,3.2965,0,0,0,3-3h2A5.2668,5.2668,0,0,1,16,24Z"
  })), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28a9.0114,9.0114,0,0,1-9-9,9.9843,9.9843,0,0,1,1.4941-4.9554L15.1528,3.4367a1.04,1.04,0,0,1,1.6944,0l6.6289,10.5564A10.0633,10.0633,0,0,1,25,19,9.0114,9.0114,0,0,1,16,28ZM16,5.8483l-5.7817,9.2079A7.9771,7.9771,0,0,0,9,19a7,7,0,0,0,14,0,8.0615,8.0615,0,0,0-1.248-3.9953Z"
  })), children);
});
var RainDrop24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainDrop24(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24V22a3.2965,3.2965,0,0,0,3-3h2A5.2668,5.2668,0,0,1,16,24Z"
  })), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28a9.0114,9.0114,0,0,1-9-9,9.9843,9.9843,0,0,1,1.4941-4.9554L15.1528,3.4367a1.04,1.04,0,0,1,1.6944,0l6.6289,10.5564A10.0633,10.0633,0,0,1,25,19,9.0114,9.0114,0,0,1,16,28ZM16,5.8483l-5.7817,9.2079A7.9771,7.9771,0,0,0,9,19a7,7,0,0,0,14,0,8.0615,8.0615,0,0,0-1.248-3.9953Z"
  })), children);
});
var RainDrop20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainDrop20(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24V22a3.2965,3.2965,0,0,0,3-3h2A5.2668,5.2668,0,0,1,16,24Z"
  })), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28a9.0114,9.0114,0,0,1-9-9,9.9843,9.9843,0,0,1,1.4941-4.9554L15.1528,3.4367a1.04,1.04,0,0,1,1.6944,0l6.6289,10.5564A10.0633,10.0633,0,0,1,25,19,9.0114,9.0114,0,0,1,16,28ZM16,5.8483l-5.7817,9.2079A7.9771,7.9771,0,0,0,9,19a7,7,0,0,0,14,0,8.0615,8.0615,0,0,0-1.248-3.9953Z"
  })), children);
});
var RainDrop16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RainDrop16(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24V22a3.2965,3.2965,0,0,0,3-3h2A5.2668,5.2668,0,0,1,16,24Z"
  })), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28a9.0114,9.0114,0,0,1-9-9,9.9843,9.9843,0,0,1,1.4941-4.9554L15.1528,3.4367a1.04,1.04,0,0,1,1.6944,0l6.6289,10.5564A10.0633,10.0633,0,0,1,25,19,9.0114,9.0114,0,0,1,16,28ZM16,5.8483l-5.7817,9.2079A7.9771,7.9771,0,0,0,9,19a7,7,0,0,0,14,0,8.0615,8.0615,0,0,0-1.248-3.9953Z"
  })), children);
});
var Raw32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Raw32(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.2 9L28.86 17 28.6 21.54 28.19 18 27.51 12.54 25.49 12.54 24.81 18 24.4 21.54 24.14 17 23.8 9 22 9 23 23 25.27 23 26.03 18.07 26.49 14 26.5 13.97 26.51 14 26.97 18.07 27.73 23 30 23 31 9 29.2 9zM18 9H14a2 2 0 00-2 2V23h2V18h4v5h2V11A2 2 0 0018 9zm-4 7V11h4v5zM10 15V11A2 2 0 008 9H2V23H4V17H5.48l2.34 6H10L7.63 17H8A2 2 0 0010 15zM4 11H8v4H4z"
  })), children);
});
var Raw24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Raw24(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.2 9L28.86 17 28.6 21.54 28.19 18 27.51 12.54 25.49 12.54 24.81 18 24.4 21.54 24.14 17 23.8 9 22 9 23 23 25.27 23 26.03 18.07 26.49 14 26.5 13.97 26.51 14 26.97 18.07 27.73 23 30 23 31 9 29.2 9zM18 9H14a2 2 0 00-2 2V23h2V18h4v5h2V11A2 2 0 0018 9zm-4 7V11h4v5zM10 15V11A2 2 0 008 9H2V23H4V17H5.48l2.34 6H10L7.63 17H8A2 2 0 0010 15zM4 11H8v4H4z"
  })), children);
});
var Raw20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Raw20(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.2 9L28.86 17 28.6 21.54 28.19 18 27.51 12.54 25.49 12.54 24.81 18 24.4 21.54 24.14 17 23.8 9 22 9 23 23 25.27 23 26.03 18.07 26.49 14 26.5 13.97 26.51 14 26.97 18.07 27.73 23 30 23 31 9 29.2 9zM18 9H14a2 2 0 00-2 2V23h2V18h4v5h2V11A2 2 0 0018 9zm-4 7V11h4v5zM10 15V11A2 2 0 008 9H2V23H4V17H5.48l2.34 6H10L7.63 17H8A2 2 0 0010 15zM4 11H8v4H4z"
  })), children);
});
var Raw16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Raw16(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.2 9L28.86 17 28.6 21.54 28.19 18 27.51 12.54 25.49 12.54 24.81 18 24.4 21.54 24.14 17 23.8 9 22 9 23 23 25.27 23 26.03 18.07 26.49 14 26.5 13.97 26.51 14 26.97 18.07 27.73 23 30 23 31 9 29.2 9zM18 9H14a2 2 0 00-2 2V23h2V18h4v5h2V11A2 2 0 0018 9zm-4 7V11h4v5zM10 15V11A2 2 0 008 9H2V23H4V17H5.48l2.34 6H10L7.63 17H8A2 2 0 0010 15zM4 11H8v4H4z"
  })), children);
});
var Receipt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Receipt32(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 16H23V18H21zM9 16H17V18H9zM21 12H23V14H21zM9 12H17V14H9zM9 8H23V10H9z"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,2H7A2.002,2.002,0,0,0,5,4V29a1,1,0,0,0,1,1H7a.9987.9987,0,0,0,.8-.4L10,26.667,12.2,29.6a1.0353,1.0353,0,0,0,1.6,0L16,26.667,18.2,29.6a1.0353,1.0353,0,0,0,1.6,0L22,26.667,24.2,29.6a.9993.9993,0,0,0,.8.4h1a1,1,0,0,0,1-1V4A2.0023,2.0023,0,0,0,25,2Zm0,25.333L22.8,24.4a1.0353,1.0353,0,0,0-1.6,0L19,27.333,16.8,24.4a1.0353,1.0353,0,0,0-1.6,0L13,27.333,10.8,24.4a1.0353,1.0353,0,0,0-1.6,0L7,27.333V4H25Z"
  })), children);
});
var Receipt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Receipt24(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 16H23V18H21zM9 16H17V18H9zM21 12H23V14H21zM9 12H17V14H9zM9 8H23V10H9z"
  })), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,2H7A2.002,2.002,0,0,0,5,4V29a1,1,0,0,0,1,1H7a.9987.9987,0,0,0,.8-.4L10,26.667,12.2,29.6a1.0353,1.0353,0,0,0,1.6,0L16,26.667,18.2,29.6a1.0353,1.0353,0,0,0,1.6,0L22,26.667,24.2,29.6a.9993.9993,0,0,0,.8.4h1a1,1,0,0,0,1-1V4A2.0023,2.0023,0,0,0,25,2Zm0,25.333L22.8,24.4a1.0353,1.0353,0,0,0-1.6,0L19,27.333,16.8,24.4a1.0353,1.0353,0,0,0-1.6,0L13,27.333,10.8,24.4a1.0353,1.0353,0,0,0-1.6,0L7,27.333V4H25Z"
  })), children);
});
var Receipt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Receipt20(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 16H23V18H21zM9 16H17V18H9zM21 12H23V14H21zM9 12H17V14H9zM9 8H23V10H9z"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,2H7A2.002,2.002,0,0,0,5,4V29a1,1,0,0,0,1,1H7a.9987.9987,0,0,0,.8-.4L10,26.667,12.2,29.6a1.0353,1.0353,0,0,0,1.6,0L16,26.667,18.2,29.6a1.0353,1.0353,0,0,0,1.6,0L22,26.667,24.2,29.6a.9993.9993,0,0,0,.8.4h1a1,1,0,0,0,1-1V4A2.0023,2.0023,0,0,0,25,2Zm0,25.333L22.8,24.4a1.0353,1.0353,0,0,0-1.6,0L19,27.333,16.8,24.4a1.0353,1.0353,0,0,0-1.6,0L13,27.333,10.8,24.4a1.0353,1.0353,0,0,0-1.6,0L7,27.333V4H25Z"
  })), children);
});
var Receipt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Receipt16(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 16H23V18H21zM9 16H17V18H9zM21 12H23V14H21zM9 12H17V14H9zM9 8H23V10H9z"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,2H7A2.002,2.002,0,0,0,5,4V29a1,1,0,0,0,1,1H7a.9987.9987,0,0,0,.8-.4L10,26.667,12.2,29.6a1.0353,1.0353,0,0,0,1.6,0L16,26.667,18.2,29.6a1.0353,1.0353,0,0,0,1.6,0L22,26.667,24.2,29.6a.9993.9993,0,0,0,.8.4h1a1,1,0,0,0,1-1V4A2.0023,2.0023,0,0,0,25,2Zm0,25.333L22.8,24.4a1.0353,1.0353,0,0,0-1.6,0L19,27.333,16.8,24.4a1.0353,1.0353,0,0,0-1.6,0L13,27.333,10.8,24.4a1.0353,1.0353,0,0,0-1.6,0L7,27.333V4H25Z"
  })), children);
});
var RecentlyViewed32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RecentlyViewed32(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.59 22L15 16.41 15 7 17 7 17 15.58 22 20.59 20.59 22z"
  })), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.94,13.94,0,0,0,6,6.23V2H4v8h8V8H7.08A12,12,0,1,1,4,16H2A14,14,0,1,0,16,2Z"
  })), children);
});
var RecentlyViewed24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RecentlyViewed24(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.59 22L15 16.41 15 7 17 7 17 15.58 22 20.59 20.59 22z"
  })), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.94,13.94,0,0,0,6,6.23V2H4v8h8V8H7.08A12,12,0,1,1,4,16H2A14,14,0,1,0,16,2Z"
  })), children);
});
var RecentlyViewed20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RecentlyViewed20(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.59 22L15 16.41 15 7 17 7 17 15.58 22 20.59 20.59 22z"
  })), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.94,13.94,0,0,0,6,6.23V2H4v8h8V8H7.08A12,12,0,1,1,4,16H2A14,14,0,1,0,16,2Z"
  })), children);
});
var RecentlyViewed16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RecentlyViewed16(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.59 22L15 16.41 15 7 17 7 17 15.58 22 20.59 20.59 22z"
  })), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.94,13.94,0,0,0,6,6.23V2H4v8h8V8H7.08A12,12,0,1,1,4,16H2A14,14,0,1,0,16,2Z"
  })), children);
});
var Recommend32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Recommend32(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2a9,9,0,0,0-6,15.69V30l6-4,6,4V17.69A9,9,0,0,0,16,2Zm4,24.26-2.89-1.92L16,23.6l-1.11.74L12,26.26V19.05a8.88,8.88,0,0,0,8,0ZM20.89,16A7,7,0,1,1,23,11,7,7,0,0,1,20.89,16Z"
  })), children);
});
var Recommend24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Recommend24(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2a9,9,0,0,0-6,15.69V30l6-4,6,4V17.69A9,9,0,0,0,16,2Zm4,24.26-2.89-1.92L16,23.6l-1.11.74L12,26.26V19.05a8.88,8.88,0,0,0,8,0ZM20.89,16A7,7,0,1,1,23,11,7,7,0,0,1,20.89,16Z"
  })), children);
});
var Recommend20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Recommend20(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2a9,9,0,0,0-6,15.69V30l6-4,6,4V17.69A9,9,0,0,0,16,2Zm4,24.26-2.89-1.92L16,23.6l-1.11.74L12,26.26V19.05a8.88,8.88,0,0,0,8,0ZM20.89,16A7,7,0,1,1,23,11,7,7,0,0,1,20.89,16Z"
  })), children);
});
var Recommend16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Recommend16(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2a9,9,0,0,0-6,15.69V30l6-4,6,4V17.69A9,9,0,0,0,16,2Zm4,24.26-2.89-1.92L16,23.6l-1.11.74L12,26.26V19.05a8.88,8.88,0,0,0,8,0ZM20.89,16A7,7,0,1,1,23,11,7,7,0,0,1,20.89,16Z"
  })), children);
});
var Recording32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Recording32(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12,12,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4,4,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z"
  })), children);
});
var Recording24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Recording24(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12,12,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4,4,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z"
  })), children);
});
var Recording20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Recording20(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12,12,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4,4,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z"
  })), children);
});
var Recording16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Recording16(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12,12,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4,4,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z"
  })), children);
});
var RecordingFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RecordingFilled32(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle57 || (_circle57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "4"
  })), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2C8.3,2,2,8.3,2,16s6.3,14,14,14s14-6.3,14-14S23.7,2,16,2z M16,22c-3.3,0-6-2.7-6-6s2.7-6,6-6s6,2.7,6,6 S19.3,22,16,22z"
  })), children);
});
var RecordingFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RecordingFilled24(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle58 || (_circle58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "4"
  })), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2C8.3,2,2,8.3,2,16s6.3,14,14,14s14-6.3,14-14S23.7,2,16,2z M16,22c-3.3,0-6-2.7-6-6s2.7-6,6-6s6,2.7,6,6 S19.3,22,16,22z"
  })), children);
});
var RecordingFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RecordingFilled20(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle59 || (_circle59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "4"
  })), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2C8.3,2,2,8.3,2,16s6.3,14,14,14s14-6.3,14-14S23.7,2,16,2z M16,22c-3.3,0-6-2.7-6-6s2.7-6,6-6s6,2.7,6,6 S19.3,22,16,22z"
  })), children);
});
var RecordingFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RecordingFilled16(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle60 || (_circle60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "4"
  })), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2C8.3,2,2,8.3,2,16s6.3,14,14,14s14-6.3,14-14S23.7,2,16,2z M16,22c-3.3,0-6-2.7-6-6s2.7-6,6-6s6,2.7,6,6 S19.3,22,16,22z"
  })), children);
});
var RecordingFilledAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RecordingFilledAlt32(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2C8.3,2,2,8.3,2,16s6.3,14,14,14s14-6.3,14-14S23.7,2,16,2z M16,22c-3.3,0-6-2.7-6-6s2.7-6,6-6s6,2.7,6,6S19.3,22,16,22\tz"
  })), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10c-3.3,0-6,2.7-6,6s2.7,6,6,6s6-2.7,6-6S19.3,10,16,10z",
    "data-icon-path": "inner-path",
    opacity: "0"
  })), children);
});
var RecordingFilledAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RecordingFilledAlt24(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2C8.3,2,2,8.3,2,16s6.3,14,14,14s14-6.3,14-14S23.7,2,16,2z M16,22c-3.3,0-6-2.7-6-6s2.7-6,6-6s6,2.7,6,6S19.3,22,16,22\tz"
  })), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10c-3.3,0-6,2.7-6,6s2.7,6,6,6s6-2.7,6-6S19.3,10,16,10z",
    "data-icon-path": "inner-path",
    opacity: "0"
  })), children);
});
var RecordingFilledAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RecordingFilledAlt20(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2C8.3,2,2,8.3,2,16s6.3,14,14,14s14-6.3,14-14S23.7,2,16,2z M16,22c-3.3,0-6-2.7-6-6s2.7-6,6-6s6,2.7,6,6S19.3,22,16,22\tz"
  })), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10c-3.3,0-6,2.7-6,6s2.7,6,6,6s6-2.7,6-6S19.3,10,16,10z",
    "data-icon-path": "inner-path",
    opacity: "0"
  })), children);
});
var RecordingFilledAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RecordingFilledAlt16(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2C8.3,2,2,8.3,2,16s6.3,14,14,14s14-6.3,14-14S23.7,2,16,2z M16,22c-3.3,0-6-2.7-6-6s2.7-6,6-6s6,2.7,6,6S19.3,22,16,22\tz"
  })), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10c-3.3,0-6,2.7-6,6s2.7,6,6,6s6-2.7,6-6S19.3,10,16,10z",
    "data-icon-path": "inner-path",
    opacity: "0"
  })), children);
});
var Redo32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Redo32(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,10H24.1851L20.5977,6.4141,22,5,28,11,22,17l-1.4023-1.4146L24.1821,12H12a6,6,0,0,0,0,12h8v2H12a8,8,0,0,1,0-16Z"
  })), children);
});
var Redo24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Redo24(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 24 24",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.8,11.2c-1.8,0-3.2,1.7-3.2,3.3c0,1.5,1.5,3.2,3.2,3.2H10v1.5H6.8C4.6,19.2,2,17,2,14.5s2-4.8,4.8-4.8\th12.4l-3-3l1.1-1.1l4.8,4.8l-4.8,4.8l-1.1-1.1l3-3H6.8z"
  })), children);
});
var Redo20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Redo20(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 20 20",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5,9.3c-1.5,0-2.8,1.3-2.8,2.7c0,1.5,1.3,2.7,2.8,2.7h4V16H5c-2.3,0-4-1.7-4-4c0-2.2,1.8-4,4-4h11.6\tl-2.5-2.5L15,4.6l4,4l-4,4l-0.9-0.9l2.5-2.5H5z"
  })), children);
});
var Redo16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Redo16(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,8c-1.2,0-2,0.8-2,2c0,1.2,0.8,2,2,2h3v1H4c-1.7,0-3-1.2-3-3c0-1.7,1.3-3,3-3l9.1,0l-2-2l0.7-0.7\tL15,7.5l-3.2,3.2L11.1,10l2-2L4,8z"
  })), children);
});
var RefEvapotranspiration32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RefEvapotranspiration32(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 12a3.8978 3.8978 0 01-4-3.777 3.9017 3.9017 0 01.6533-2.0639L13.17 2.4141a1.0381 1.0381 0 011.6592 0L17.3154 6.11A3.9693 3.9693 0 0118 8.223 3.8978 3.8978 0 0114 12zm.0005-7.2368L12.3438 7.2257A1.89 1.89 0 0012 8.223 1.9 1.9 0 0014 10a1.9 1.9 0 002-1.777 1.98 1.98 0 00-.375-1.0466zM7.5 26A5.385 5.385 0 012 20.751 5.3837 5.3837 0 012.874 17.92L6.49 12.5383a1.2168 1.2168 0 012.02-.0006l3.55 5.2777A5.4923 5.4923 0 0113 20.751 5.385 5.385 0 017.5 26zm0-11.38L4.5649 18.9868A3.3586 3.3586 0 004 20.751 3.3855 3.3855 0 007.5 24 3.3855 3.3855 0 0011 20.751a3.4354 3.4354 0 00-.63-1.867zM25 2L20 7l1.4141 1.4141L24 5.8281V16a4.0045 4.0045 0 01-4 4H16v2h4a6.0066 6.0066 0 006-6V5.8281l2.5859 2.586L30 7zM2 28H30V30H2z"
  })), children);
});
var RefEvapotranspiration24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RefEvapotranspiration24(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 12a3.8978 3.8978 0 01-4-3.777 3.9017 3.9017 0 01.6533-2.0639L13.17 2.4141a1.0381 1.0381 0 011.6592 0L17.3154 6.11A3.9693 3.9693 0 0118 8.223 3.8978 3.8978 0 0114 12zm.0005-7.2368L12.3438 7.2257A1.89 1.89 0 0012 8.223 1.9 1.9 0 0014 10a1.9 1.9 0 002-1.777 1.98 1.98 0 00-.375-1.0466zM7.5 26A5.385 5.385 0 012 20.751 5.3837 5.3837 0 012.874 17.92L6.49 12.5383a1.2168 1.2168 0 012.02-.0006l3.55 5.2777A5.4923 5.4923 0 0113 20.751 5.385 5.385 0 017.5 26zm0-11.38L4.5649 18.9868A3.3586 3.3586 0 004 20.751 3.3855 3.3855 0 007.5 24 3.3855 3.3855 0 0011 20.751a3.4354 3.4354 0 00-.63-1.867zM25 2L20 7l1.4141 1.4141L24 5.8281V16a4.0045 4.0045 0 01-4 4H16v2h4a6.0066 6.0066 0 006-6V5.8281l2.5859 2.586L30 7zM2 28H30V30H2z"
  })), children);
});
var RefEvapotranspiration20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RefEvapotranspiration20(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 12a3.8978 3.8978 0 01-4-3.777 3.9017 3.9017 0 01.6533-2.0639L13.17 2.4141a1.0381 1.0381 0 011.6592 0L17.3154 6.11A3.9693 3.9693 0 0118 8.223 3.8978 3.8978 0 0114 12zm.0005-7.2368L12.3438 7.2257A1.89 1.89 0 0012 8.223 1.9 1.9 0 0014 10a1.9 1.9 0 002-1.777 1.98 1.98 0 00-.375-1.0466zM7.5 26A5.385 5.385 0 012 20.751 5.3837 5.3837 0 012.874 17.92L6.49 12.5383a1.2168 1.2168 0 012.02-.0006l3.55 5.2777A5.4923 5.4923 0 0113 20.751 5.385 5.385 0 017.5 26zm0-11.38L4.5649 18.9868A3.3586 3.3586 0 004 20.751 3.3855 3.3855 0 007.5 24 3.3855 3.3855 0 0011 20.751a3.4354 3.4354 0 00-.63-1.867zM25 2L20 7l1.4141 1.4141L24 5.8281V16a4.0045 4.0045 0 01-4 4H16v2h4a6.0066 6.0066 0 006-6V5.8281l2.5859 2.586L30 7zM2 28H30V30H2z"
  })), children);
});
var RefEvapotranspiration16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RefEvapotranspiration16(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 12a3.8978 3.8978 0 01-4-3.777 3.9017 3.9017 0 01.6533-2.0639L13.17 2.4141a1.0381 1.0381 0 011.6592 0L17.3154 6.11A3.9693 3.9693 0 0118 8.223 3.8978 3.8978 0 0114 12zm.0005-7.2368L12.3438 7.2257A1.89 1.89 0 0012 8.223 1.9 1.9 0 0014 10a1.9 1.9 0 002-1.777 1.98 1.98 0 00-.375-1.0466zM7.5 26A5.385 5.385 0 012 20.751 5.3837 5.3837 0 012.874 17.92L6.49 12.5383a1.2168 1.2168 0 012.02-.0006l3.55 5.2777A5.4923 5.4923 0 0113 20.751 5.385 5.385 0 017.5 26zm0-11.38L4.5649 18.9868A3.3586 3.3586 0 004 20.751 3.3855 3.3855 0 007.5 24 3.3855 3.3855 0 0011 20.751a3.4354 3.4354 0 00-.63-1.867zM25 2L20 7l1.4141 1.4141L24 5.8281V16a4.0045 4.0045 0 01-4 4H16v2h4a6.0066 6.0066 0 006-6V5.8281l2.5859 2.586L30 7zM2 28H30V30H2z"
  })), children);
});
var ReflectHorizontal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReflectHorizontal32(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.386,15.2105l9-7A1,1,0,0,1,30,9V23a1,1,0,0,1-1.614.79l-9-7a1,1,0,0,1,0-1.5791Z"
  })), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V30H15z",
    transform: "rotate(-180 16 16)"
  })), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,16a1.001,1.001,0,0,1-.386.79l-9,7A1,1,0,0,1,2,23V9a1,1,0,0,1,1.614-.79l9,7A1.001,1.001,0,0,1,13,16ZM4,20.9556,10.3711,16,4,11.0444Z"
  })), children);
});
var ReflectHorizontal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReflectHorizontal24(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.386,15.2105l9-7A1,1,0,0,1,30,9V23a1,1,0,0,1-1.614.79l-9-7a1,1,0,0,1,0-1.5791Z"
  })), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V30H15z",
    transform: "rotate(-180 16 16)"
  })), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,16a1.001,1.001,0,0,1-.386.79l-9,7A1,1,0,0,1,2,23V9a1,1,0,0,1,1.614-.79l9,7A1.001,1.001,0,0,1,13,16ZM4,20.9556,10.3711,16,4,11.0444Z"
  })), children);
});
var ReflectHorizontal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReflectHorizontal20(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.386,15.2105l9-7A1,1,0,0,1,30,9V23a1,1,0,0,1-1.614.79l-9-7a1,1,0,0,1,0-1.5791Z"
  })), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V30H15z",
    transform: "rotate(-180 16 16)"
  })), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,16a1.001,1.001,0,0,1-.386.79l-9,7A1,1,0,0,1,2,23V9a1,1,0,0,1,1.614-.79l9,7A1.001,1.001,0,0,1,13,16ZM4,20.9556,10.3711,16,4,11.0444Z"
  })), children);
});
var ReflectHorizontal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReflectHorizontal16(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.386,15.2105l9-7A1,1,0,0,1,30,9V23a1,1,0,0,1-1.614.79l-9-7a1,1,0,0,1,0-1.5791Z"
  })), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V30H15z",
    transform: "rotate(-180 16 16)"
  })), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,16a1.001,1.001,0,0,1-.386.79l-9,7A1,1,0,0,1,2,23V9a1,1,0,0,1,1.614-.79l9,7A1.001,1.001,0,0,1,13,16ZM4,20.9556,10.3711,16,4,11.0444Z"
  })), children);
});
var ReflectVertical32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReflectVertical32(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.79,19.386l7,9A1,1,0,0,1,23,30H9a1,1,0,0,1-.79-1.614l7-9a1,1,0,0,1,1.5791,0Z"
  })), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V30H15z",
    transform: "rotate(-90 16 16)"
  })), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,13a1.001,1.001,0,0,1-.79-.386l-7-9A1,1,0,0,1,9,2H23a1,1,0,0,1,.79,1.614l-7,9A1.001,1.001,0,0,1,16,13ZM11.0444,4,16,10.3711,20.9556,4Z"
  })), children);
});
var ReflectVertical24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReflectVertical24(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.79,19.386l7,9A1,1,0,0,1,23,30H9a1,1,0,0,1-.79-1.614l7-9a1,1,0,0,1,1.5791,0Z"
  })), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V30H15z",
    transform: "rotate(-90 16 16)"
  })), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,13a1.001,1.001,0,0,1-.79-.386l-7-9A1,1,0,0,1,9,2H23a1,1,0,0,1,.79,1.614l-7,9A1.001,1.001,0,0,1,16,13ZM11.0444,4,16,10.3711,20.9556,4Z"
  })), children);
});
var ReflectVertical20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReflectVertical20(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.79,19.386l7,9A1,1,0,0,1,23,30H9a1,1,0,0,1-.79-1.614l7-9a1,1,0,0,1,1.5791,0Z"
  })), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V30H15z",
    transform: "rotate(-90 16 16)"
  })), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,13a1.001,1.001,0,0,1-.79-.386l-7-9A1,1,0,0,1,9,2H23a1,1,0,0,1,.79,1.614l-7,9A1.001,1.001,0,0,1,16,13ZM11.0444,4,16,10.3711,20.9556,4Z"
  })), children);
});
var ReflectVertical16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReflectVertical16(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.79,19.386l7,9A1,1,0,0,1,23,30H9a1,1,0,0,1-.79-1.614l7-9a1,1,0,0,1,1.5791,0Z"
  })), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V30H15z",
    transform: "rotate(-90 16 16)"
  })), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,13a1.001,1.001,0,0,1-.79-.386l-7-9A1,1,0,0,1,9,2H23a1,1,0,0,1,.79,1.614l-7,9A1.001,1.001,0,0,1,16,13ZM11.0444,4,16,10.3711,20.9556,4Z"
  })), children);
});
var WatsonHealthRegionAnalysisArea32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRegionAnalysisArea32(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,23V21H28V19H26v2H23V19H21v2H19v2h2v3H19v2h2v2h2V28h3v2h2V28h2V26H28V23Zm-4,3H23V23h3Z"
  })), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16H28A12,12,0,1,0,16,28Z"
  })), children);
});
var WatsonHealthRegionAnalysisArea24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRegionAnalysisArea24(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,23V21H28V19H26v2H23V19H21v2H19v2h2v3H19v2h2v2h2V28h3v2h2V28h2V26H28V23Zm-4,3H23V23h3Z"
  })), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16H28A12,12,0,1,0,16,28Z"
  })), children);
});
var WatsonHealthRegionAnalysisArea20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRegionAnalysisArea20(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,23V21H28V19H26v2H23V19H21v2H19v2h2v3H19v2h2v2h2V28h3v2h2V28h2V26H28V23Zm-4,3H23V23h3Z"
  })), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16H28A12,12,0,1,0,16,28Z"
  })), children);
});
var WatsonHealthRegionAnalysisArea16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRegionAnalysisArea16(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,23V21H28V19H26v2H23V19H21v2H19v2h2v3H19v2h2v2h2V28h3v2h2V28h2V26H28V23Zm-4,3H23V23h3Z"
  })), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16H28A12,12,0,1,0,16,28Z"
  })), children);
});
var WatsonHealthRegionAnalysisVolume32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRegionAnalysisVolume32(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,23V21H28V19H26v2H23V19H21v2H19v2h2v3H19v2h2v2h2V28h3v2h2V28h2V26H28V23Zm-4,3H23V23h3Z"
  })), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.8305,20.3555A24.9534,24.9534,0,0,0,15,22.9644v-2A22.9014,22.9014,0,0,1,4.1335,17.6919,11.979,11.979,0,0,1,4,16a11.9847,11.9847,0,0,1,.1332-1.69,22.9282,22.9282,0,0,1,23.7336,0A11.9847,11.9847,0,0,1,28,16h2A14,14,0,1,0,16,30V28A12.01,12.01,0,0,1,4.8305,20.3555ZM16,4a12.01,12.01,0,0,1,11.17,7.6465,24.8982,24.8982,0,0,0-22.3406,0A12.01,12.01,0,0,1,16,4Z"
  })), children);
});
var WatsonHealthRegionAnalysisVolume24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRegionAnalysisVolume24(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,23V21H28V19H26v2H23V19H21v2H19v2h2v3H19v2h2v2h2V28h3v2h2V28h2V26H28V23Zm-4,3H23V23h3Z"
  })), _path390 || (_path390 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.8305,20.3555A24.9534,24.9534,0,0,0,15,22.9644v-2A22.9014,22.9014,0,0,1,4.1335,17.6919,11.979,11.979,0,0,1,4,16a11.9847,11.9847,0,0,1,.1332-1.69,22.9282,22.9282,0,0,1,23.7336,0A11.9847,11.9847,0,0,1,28,16h2A14,14,0,1,0,16,30V28A12.01,12.01,0,0,1,4.8305,20.3555ZM16,4a12.01,12.01,0,0,1,11.17,7.6465,24.8982,24.8982,0,0,0-22.3406,0A12.01,12.01,0,0,1,16,4Z"
  })), children);
});
var WatsonHealthRegionAnalysisVolume20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRegionAnalysisVolume20(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path391 || (_path391 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,23V21H28V19H26v2H23V19H21v2H19v2h2v3H19v2h2v2h2V28h3v2h2V28h2V26H28V23Zm-4,3H23V23h3Z"
  })), _path392 || (_path392 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.8305,20.3555A24.9534,24.9534,0,0,0,15,22.9644v-2A22.9014,22.9014,0,0,1,4.1335,17.6919,11.979,11.979,0,0,1,4,16a11.9847,11.9847,0,0,1,.1332-1.69,22.9282,22.9282,0,0,1,23.7336,0A11.9847,11.9847,0,0,1,28,16h2A14,14,0,1,0,16,30V28A12.01,12.01,0,0,1,4.8305,20.3555ZM16,4a12.01,12.01,0,0,1,11.17,7.6465,24.8982,24.8982,0,0,0-22.3406,0A12.01,12.01,0,0,1,16,4Z"
  })), children);
});
var WatsonHealthRegionAnalysisVolume16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRegionAnalysisVolume16(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path393 || (_path393 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,23V21H28V19H26v2H23V19H21v2H19v2h2v3H19v2h2v2h2V28h3v2h2V28h2V26H28V23Zm-4,3H23V23h3Z"
  })), _path394 || (_path394 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.8305,20.3555A24.9534,24.9534,0,0,0,15,22.9644v-2A22.9014,22.9014,0,0,1,4.1335,17.6919,11.979,11.979,0,0,1,4,16a11.9847,11.9847,0,0,1,.1332-1.69,22.9282,22.9282,0,0,1,23.7336,0A11.9847,11.9847,0,0,1,28,16h2A14,14,0,1,0,16,30V28A12.01,12.01,0,0,1,4.8305,20.3555ZM16,4a12.01,12.01,0,0,1,11.17,7.6465,24.8982,24.8982,0,0,0-22.3406,0A12.01,12.01,0,0,1,16,4Z"
  })), children);
});
var WatsonHealthRegistration32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRegistration32(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path395 || (_path395 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 25H20a2.0027 2.0027 0 01-2-2V20h2v3h8V9H20v3H18V9a2.0023 2.0023 0 012-2h8a2.0023 2.0023 0 012 2V23A2.0027 2.0027 0 0128 25zM8 15H12V17H8z"
  })), _path396 || (_path396 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 15H24V17H20zM14 15H18V17H14zM12 25H4a2.0023 2.0023 0 01-2-2V9A2.002 2.002 0 014 7h8a2.002 2.002 0 012 2v3H12V9H4V23h8V20h2v3A2.0023 2.0023 0 0112 25z"
  })), children);
});
var WatsonHealthRegistration24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRegistration24(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path397 || (_path397 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 25H20a2.0027 2.0027 0 01-2-2V20h2v3h8V9H20v3H18V9a2.0023 2.0023 0 012-2h8a2.0023 2.0023 0 012 2V23A2.0027 2.0027 0 0128 25zM8 15H12V17H8z"
  })), _path398 || (_path398 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 15H24V17H20zM14 15H18V17H14zM12 25H4a2.0023 2.0023 0 01-2-2V9A2.002 2.002 0 014 7h8a2.002 2.002 0 012 2v3H12V9H4V23h8V20h2v3A2.0023 2.0023 0 0112 25z"
  })), children);
});
var WatsonHealthRegistration20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRegistration20(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path399 || (_path399 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 25H20a2.0027 2.0027 0 01-2-2V20h2v3h8V9H20v3H18V9a2.0023 2.0023 0 012-2h8a2.0023 2.0023 0 012 2V23A2.0027 2.0027 0 0128 25zM8 15H12V17H8z"
  })), _path400 || (_path400 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 15H24V17H20zM14 15H18V17H14zM12 25H4a2.0023 2.0023 0 01-2-2V9A2.002 2.002 0 014 7h8a2.002 2.002 0 012 2v3H12V9H4V23h8V20h2v3A2.0023 2.0023 0 0112 25z"
  })), children);
});
var WatsonHealthRegistration16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRegistration16(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path401 || (_path401 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 25H20a2.0027 2.0027 0 01-2-2V20h2v3h8V9H20v3H18V9a2.0023 2.0023 0 012-2h8a2.0023 2.0023 0 012 2V23A2.0027 2.0027 0 0128 25zM8 15H12V17H8z"
  })), _path402 || (_path402 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 15H24V17H20zM14 15H18V17H14zM12 25H4a2.0023 2.0023 0 01-2-2V9A2.002 2.002 0 014 7h8a2.002 2.002 0 012 2v3H12V9H4V23h8V20h2v3A2.0023 2.0023 0 0112 25z"
  })), children);
});
var Reminder32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Reminder32(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path403 || (_path403 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,23.3818l-2-1V20a6.0046,6.0046,0,0,0-5-5.91V12H21v2.09A6.0046,6.0046,0,0,0,16,20v2.3818l-2,1V28h6v2h4V28h6ZM28,26H16V24.6182l2-1V20a4,4,0,0,1,8,0v3.6182l2,1Z"
  })), _path404 || (_path404 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6a2,2,0,0,0-2-2H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V6h4V8h2V6h8V8h2V6h4v6h2Z"
  })), children);
});
var Reminder24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Reminder24(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path405 || (_path405 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,23.3818l-2-1V20a6.0046,6.0046,0,0,0-5-5.91V12H21v2.09A6.0046,6.0046,0,0,0,16,20v2.3818l-2,1V28h6v2h4V28h6ZM28,26H16V24.6182l2-1V20a4,4,0,0,1,8,0v3.6182l2,1Z"
  })), _path406 || (_path406 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6a2,2,0,0,0-2-2H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V6h4V8h2V6h8V8h2V6h4v6h2Z"
  })), children);
});
var Reminder20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Reminder20(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path407 || (_path407 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,23.3818l-2-1V20a6.0046,6.0046,0,0,0-5-5.91V12H21v2.09A6.0046,6.0046,0,0,0,16,20v2.3818l-2,1V28h6v2h4V28h6ZM28,26H16V24.6182l2-1V20a4,4,0,0,1,8,0v3.6182l2,1Z"
  })), _path408 || (_path408 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6a2,2,0,0,0-2-2H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V6h4V8h2V6h8V8h2V6h4v6h2Z"
  })), children);
});
var Reminder16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Reminder16(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path409 || (_path409 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,23.3818l-2-1V20a6.0046,6.0046,0,0,0-5-5.91V12H21v2.09A6.0046,6.0046,0,0,0,16,20v2.3818l-2,1V28h6v2h4V28h6ZM28,26H16V24.6182l2-1V20a4,4,0,0,1,8,0v3.6182l2,1Z"
  })), _path410 || (_path410 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6a2,2,0,0,0-2-2H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V6h4V8h2V6h8V8h2V6h4v6h2Z"
  })), children);
});
var ReminderMedical32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReminderMedical32(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path411 || (_path411 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,12v2h1v4a3,3,0,0,1-6,0V14h1V12H20v6a5.0083,5.0083,0,0,0,4,4.8989V24a4,4,0,0,1-8,0V21.8157a3,3,0,1,0-2,0V24a6,6,0,0,0,12,0V22.8989A5.0083,5.0083,0,0,0,30,18V12ZM15,18a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,15,18Z"
  })), _path412 || (_path412 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2l4,0V26L6,26V6h4V8h2V6h8V8h2V6h4v4h2V6A2,2,0,0,0,26,4Z"
  })), children);
});
var ReminderMedical24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReminderMedical24(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path413 || (_path413 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,12v2h1v4a3,3,0,0,1-6,0V14h1V12H20v6a5.0083,5.0083,0,0,0,4,4.8989V24a4,4,0,0,1-8,0V21.8157a3,3,0,1,0-2,0V24a6,6,0,0,0,12,0V22.8989A5.0083,5.0083,0,0,0,30,18V12ZM15,18a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,15,18Z"
  })), _path414 || (_path414 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2l4,0V26L6,26V6h4V8h2V6h8V8h2V6h4v4h2V6A2,2,0,0,0,26,4Z"
  })), children);
});
var ReminderMedical20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReminderMedical20(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path415 || (_path415 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,12v2h1v4a3,3,0,0,1-6,0V14h1V12H20v6a5.0083,5.0083,0,0,0,4,4.8989V24a4,4,0,0,1-8,0V21.8157a3,3,0,1,0-2,0V24a6,6,0,0,0,12,0V22.8989A5.0083,5.0083,0,0,0,30,18V12ZM15,18a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,15,18Z"
  })), _path416 || (_path416 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2l4,0V26L6,26V6h4V8h2V6h8V8h2V6h4v4h2V6A2,2,0,0,0,26,4Z"
  })), children);
});
var ReminderMedical16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReminderMedical16(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path417 || (_path417 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,12v2h1v4a3,3,0,0,1-6,0V14h1V12H20v6a5.0083,5.0083,0,0,0,4,4.8989V24a4,4,0,0,1-8,0V21.8157a3,3,0,1,0-2,0V24a6,6,0,0,0,12,0V22.8989A5.0083,5.0083,0,0,0,30,18V12ZM15,18a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,15,18Z"
  })), _path418 || (_path418 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2l4,0V26L6,26V6h4V8h2V6h8V8h2V6h4v4h2V6A2,2,0,0,0,26,4Z"
  })), children);
});
var Renew32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Renew32(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path419 || (_path419 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 10H6.78A11 11 0 0127 16h2A13 13 0 006 7.68V4H4v8h8zM20 22h5.22A11 11 0 015 16H3a13 13 0 0023 8.32V28h2V20H20z"
  })), children);
});
var Renew24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Renew24(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path420 || (_path420 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 10H6.78A11 11 0 0127 16h2A13 13 0 006 7.68V4H4v8h8zM20 22h5.22A11 11 0 015 16H3a13 13 0 0023 8.32V28h2V20H20z"
  })), children);
});
var Renew20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Renew20(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path421 || (_path421 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 10H6.78A11 11 0 0127 16h2A13 13 0 006 7.68V4H4v8h8zM20 22h5.22A11 11 0 015 16H3a13 13 0 0023 8.32V28h2V20H20z"
  })), children);
});
var Renew16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Renew16(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path422 || (_path422 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 10H6.78A11 11 0 0127 16h2A13 13 0 006 7.68V4H4v8h8zM20 22h5.22A11 11 0 015 16H3a13 13 0 0023 8.32V28h2V20H20z"
  })), children);
});
var Repeat32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Repeat32(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path423 || (_path423 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 6H26.1719l-3.586-3.5859L24 1l6 6-6 6-1.4141-1.4141L26.1719 8H6v7H4V8A2.0024 2.0024 0 016 6zM9.4141 20.4141L5.8281 24H26V17h2v7a2.0024 2.0024 0 01-2 2H5.8281L9.414 29.5859 8 31 2 25l6-6z"
  })), children);
});
var Repeat24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Repeat24(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path424 || (_path424 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 6H26.1719l-3.586-3.5859L24 1l6 6-6 6-1.4141-1.4141L26.1719 8H6v7H4V8A2.0024 2.0024 0 016 6zM9.4141 20.4141L5.8281 24H26V17h2v7a2.0024 2.0024 0 01-2 2H5.8281L9.414 29.5859 8 31 2 25l6-6z"
  })), children);
});
var Repeat20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Repeat20(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path425 || (_path425 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 6H26.1719l-3.586-3.5859L24 1l6 6-6 6-1.4141-1.4141L26.1719 8H6v7H4V8A2.0024 2.0024 0 016 6zM9.4141 20.4141L5.8281 24H26V17h2v7a2.0024 2.0024 0 01-2 2H5.8281L9.414 29.5859 8 31 2 25l6-6z"
  })), children);
});
var Repeat16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Repeat16(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path426 || (_path426 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 6H26.1719l-3.586-3.5859L24 1l6 6-6 6-1.4141-1.4141L26.1719 8H6v7H4V8A2.0024 2.0024 0 016 6zM9.4141 20.4141L5.8281 24H26V17h2v7a2.0024 2.0024 0 01-2 2H5.8281L9.414 29.5859 8 31 2 25l6-6z"
  })), children);
});
var RepeatOne32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RepeatOne32(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path427 || (_path427 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 6H26.1719l-3.586-3.5859L24 1l6 6-6 6-1.4141-1.4141L26.1719 8H6v7H4V8A2.0024 2.0024 0 016 6zM9.4141 20.4141L5.8281 24H26V17h2v7a2.0024 2.0024 0 01-2 2H5.8281L9.414 29.5859 8 31 2 25l6-6z"
  })), _path428 || (_path428 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 19L17 11 15 11 15 12 13 12 13 14 15 14 15 19 13 19 13 21 19 21 19 19 17 19z"
  })), children);
});
var RepeatOne24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RepeatOne24(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path429 || (_path429 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 6H26.1719l-3.586-3.5859L24 1l6 6-6 6-1.4141-1.4141L26.1719 8H6v7H4V8A2.0024 2.0024 0 016 6zM9.4141 20.4141L5.8281 24H26V17h2v7a2.0024 2.0024 0 01-2 2H5.8281L9.414 29.5859 8 31 2 25l6-6z"
  })), _path430 || (_path430 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 19L17 11 15 11 15 12 13 12 13 14 15 14 15 19 13 19 13 21 19 21 19 19 17 19z"
  })), children);
});
var RepeatOne20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RepeatOne20(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path431 || (_path431 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 6H26.1719l-3.586-3.5859L24 1l6 6-6 6-1.4141-1.4141L26.1719 8H6v7H4V8A2.0024 2.0024 0 016 6zM9.4141 20.4141L5.8281 24H26V17h2v7a2.0024 2.0024 0 01-2 2H5.8281L9.414 29.5859 8 31 2 25l6-6z"
  })), _path432 || (_path432 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 19L17 11 15 11 15 12 13 12 13 14 15 14 15 19 13 19 13 21 19 21 19 19 17 19z"
  })), children);
});
var RepeatOne16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RepeatOne16(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path433 || (_path433 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 6H26.1719l-3.586-3.5859L24 1l6 6-6 6-1.4141-1.4141L26.1719 8H6v7H4V8A2.0024 2.0024 0 016 6zM9.4141 20.4141L5.8281 24H26V17h2v7a2.0024 2.0024 0 01-2 2H5.8281L9.414 29.5859 8 31 2 25l6-6z"
  })), _path434 || (_path434 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 19L17 11 15 11 15 12 13 12 13 14 15 14 15 19 13 19 13 21 19 21 19 19 17 19z"
  })), children);
});
var Replicate32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Replicate32(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path435 || (_path435 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 8h2V4a2.0021 2.0021 0 00-2-2H24V4h4zM17 2H21V4H17zM28 11H30V15H28zM28 18v4H24V10a2.0023 2.0023 0 00-2-2H10V4h4V2H10A2.0023 2.0023 0 008 4V8H4a2.0023 2.0023 0 00-2 2V28a2.0023 2.0023 0 002 2H22a2.0023 2.0023 0 002-2V24h4a2.0023 2.0023 0 002-2V18zM22 28H4V10H22z"
  })), children);
});
var Replicate24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Replicate24(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path436 || (_path436 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 8h2V4a2.0021 2.0021 0 00-2-2H24V4h4zM17 2H21V4H17zM28 11H30V15H28zM28 18v4H24V10a2.0023 2.0023 0 00-2-2H10V4h4V2H10A2.0023 2.0023 0 008 4V8H4a2.0023 2.0023 0 00-2 2V28a2.0023 2.0023 0 002 2H22a2.0023 2.0023 0 002-2V24h4a2.0023 2.0023 0 002-2V18zM22 28H4V10H22z"
  })), children);
});
var Replicate20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Replicate20(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path437 || (_path437 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 8h2V4a2.0021 2.0021 0 00-2-2H24V4h4zM17 2H21V4H17zM28 11H30V15H28zM28 18v4H24V10a2.0023 2.0023 0 00-2-2H10V4h4V2H10A2.0023 2.0023 0 008 4V8H4a2.0023 2.0023 0 00-2 2V28a2.0023 2.0023 0 002 2H22a2.0023 2.0023 0 002-2V24h4a2.0023 2.0023 0 002-2V18zM22 28H4V10H22z"
  })), children);
});
var Replicate16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Replicate16(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path438 || (_path438 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 8h2V4a2.0021 2.0021 0 00-2-2H24V4h4zM17 2H21V4H17zM28 11H30V15H28zM28 18v4H24V10a2.0023 2.0023 0 00-2-2H10V4h4V2H10A2.0023 2.0023 0 008 4V8H4a2.0023 2.0023 0 00-2 2V28a2.0023 2.0023 0 002 2H22a2.0023 2.0023 0 002-2V24h4a2.0023 2.0023 0 002-2V18zM22 28H4V10H22z"
  })), children);
});
var Reply32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Reply32(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path439 || (_path439 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.88,30a1,1,0,0,1-.88-.5A15.19,15.19,0,0,0,15,22v6a1,1,0,0,1-.62.92,1,1,0,0,1-1.09-.21l-12-12a1,1,0,0,1,0-1.42l12-12a1,1,0,0,1,1.09-.21A1,1,0,0,1,15,4v6.11a17.19,17.19,0,0,1,15,17,16.34,16.34,0,0,1-.13,2,1,1,0,0,1-.79.86ZM14.5,20A17.62,17.62,0,0,1,28,26,15.31,15.31,0,0,0,13.91,12,1,1,0,0,1,13,11V6.41L3.41,16,13,25.59V21a1,1,0,0,1,1-1h.54Z"
  })), children);
});
var Reply24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Reply24(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path440 || (_path440 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.88,30a1,1,0,0,1-.88-.5A15.19,15.19,0,0,0,15,22v6a1,1,0,0,1-.62.92,1,1,0,0,1-1.09-.21l-12-12a1,1,0,0,1,0-1.42l12-12a1,1,0,0,1,1.09-.21A1,1,0,0,1,15,4v6.11a17.19,17.19,0,0,1,15,17,16.34,16.34,0,0,1-.13,2,1,1,0,0,1-.79.86ZM14.5,20A17.62,17.62,0,0,1,28,26,15.31,15.31,0,0,0,13.91,12,1,1,0,0,1,13,11V6.41L3.41,16,13,25.59V21a1,1,0,0,1,1-1h.54Z"
  })), children);
});
var Reply20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Reply20(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path441 || (_path441 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.88,30a1,1,0,0,1-.88-.5A15.19,15.19,0,0,0,15,22v6a1,1,0,0,1-.62.92,1,1,0,0,1-1.09-.21l-12-12a1,1,0,0,1,0-1.42l12-12a1,1,0,0,1,1.09-.21A1,1,0,0,1,15,4v6.11a17.19,17.19,0,0,1,15,17,16.34,16.34,0,0,1-.13,2,1,1,0,0,1-.79.86ZM14.5,20A17.62,17.62,0,0,1,28,26,15.31,15.31,0,0,0,13.91,12,1,1,0,0,1,13,11V6.41L3.41,16,13,25.59V21a1,1,0,0,1,1-1h.54Z"
  })), children);
});
var Reply16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Reply16(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path442 || (_path442 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.88,30a1,1,0,0,1-.88-.5A15.19,15.19,0,0,0,15,22v6a1,1,0,0,1-.62.92,1,1,0,0,1-1.09-.21l-12-12a1,1,0,0,1,0-1.42l12-12a1,1,0,0,1,1.09-.21A1,1,0,0,1,15,4v6.11a17.19,17.19,0,0,1,15,17,16.34,16.34,0,0,1-.13,2,1,1,0,0,1-.79.86ZM14.5,20A17.62,17.62,0,0,1,28,26,15.31,15.31,0,0,0,13.91,12,1,1,0,0,1,13,11V6.41L3.41,16,13,25.59V21a1,1,0,0,1,1-1h.54Z"
  })), children);
});
var ReplyAll32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReplyAll32(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path443 || (_path443 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,29a.9989.9989,0,0,1-.768-.36l-10-12a1,1,0,0,1,0-1.28l10-12A1,1,0,0,1,20,4v7.0325c7.0074.4629,11,5.86,11,14.9677a1,1,0,0,1-1.8.6c-2.8218-3.7623-5.3912-5.3463-9.2-5.5716V28a1,1,0,0,1-1,1ZM10.3016,16,18,25.238V20a1,1,0,0,1,1-1,12.7127,12.7127,0,0,1,9.8414,4.0909C28.0864,16.5553,24.6587,13,19,13a1,1,0,0,1-1-1V6.7618Z"
  })), _path444 || (_path444 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.4639,28.9182,1.2318,16.64a1,1,0,0,1,0-1.28L11.4638,3.0792,13,4.36,3.3016,16,13,27.638Z"
  })), children);
});
var ReplyAll24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReplyAll24(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path445 || (_path445 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,29a.9989.9989,0,0,1-.768-.36l-10-12a1,1,0,0,1,0-1.28l10-12A1,1,0,0,1,20,4v7.0325c7.0074.4629,11,5.86,11,14.9677a1,1,0,0,1-1.8.6c-2.8218-3.7623-5.3912-5.3463-9.2-5.5716V28a1,1,0,0,1-1,1ZM10.3016,16,18,25.238V20a1,1,0,0,1,1-1,12.7127,12.7127,0,0,1,9.8414,4.0909C28.0864,16.5553,24.6587,13,19,13a1,1,0,0,1-1-1V6.7618Z"
  })), _path446 || (_path446 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.4639,28.9182,1.2318,16.64a1,1,0,0,1,0-1.28L11.4638,3.0792,13,4.36,3.3016,16,13,27.638Z"
  })), children);
});
var ReplyAll20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReplyAll20(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path447 || (_path447 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,29a.9989.9989,0,0,1-.768-.36l-10-12a1,1,0,0,1,0-1.28l10-12A1,1,0,0,1,20,4v7.0325c7.0074.4629,11,5.86,11,14.9677a1,1,0,0,1-1.8.6c-2.8218-3.7623-5.3912-5.3463-9.2-5.5716V28a1,1,0,0,1-1,1ZM10.3016,16,18,25.238V20a1,1,0,0,1,1-1,12.7127,12.7127,0,0,1,9.8414,4.0909C28.0864,16.5553,24.6587,13,19,13a1,1,0,0,1-1-1V6.7618Z"
  })), _path448 || (_path448 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.4639,28.9182,1.2318,16.64a1,1,0,0,1,0-1.28L11.4638,3.0792,13,4.36,3.3016,16,13,27.638Z"
  })), children);
});
var ReplyAll16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReplyAll16(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path449 || (_path449 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,29a.9989.9989,0,0,1-.768-.36l-10-12a1,1,0,0,1,0-1.28l10-12A1,1,0,0,1,20,4v7.0325c7.0074.4629,11,5.86,11,14.9677a1,1,0,0,1-1.8.6c-2.8218-3.7623-5.3912-5.3463-9.2-5.5716V28a1,1,0,0,1-1,1ZM10.3016,16,18,25.238V20a1,1,0,0,1,1-1,12.7127,12.7127,0,0,1,9.8414,4.0909C28.0864,16.5553,24.6587,13,19,13a1,1,0,0,1-1-1V6.7618Z"
  })), _path450 || (_path450 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.4639,28.9182,1.2318,16.64a1,1,0,0,1,0-1.28L11.4638,3.0792,13,4.36,3.3016,16,13,27.638Z"
  })), children);
});
var Report32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Report32(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path451 || (_path451 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 18H18V20H10zM10 13H22V15H10zM10 23H15V25H10z"
  })), _path452 || (_path452 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,5H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H25a2,2,0,0,0,2-2V7A2,2,0,0,0,25,5ZM12,4h8V8H12ZM25,28H7V7h3v3H22V7h3Z"
  })), children);
});
var Report24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Report24(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path453 || (_path453 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 18H18V20H10zM10 13H22V15H10zM10 23H15V25H10z"
  })), _path454 || (_path454 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,5H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H25a2,2,0,0,0,2-2V7A2,2,0,0,0,25,5ZM12,4h8V8H12ZM25,28H7V7h3v3H22V7h3Z"
  })), children);
});
var Report20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Report20(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path455 || (_path455 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 18H18V20H10zM10 13H22V15H10zM10 23H15V25H10z"
  })), _path456 || (_path456 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,5H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H25a2,2,0,0,0,2-2V7A2,2,0,0,0,25,5ZM12,4h8V8H12ZM25,28H7V7h3v3H22V7h3Z"
  })), children);
});
var Report16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Report16(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path457 || (_path457 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 18H18V20H10zM10 13H22V15H10zM10 23H15V25H10z"
  })), _path458 || (_path458 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,5H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H25a2,2,0,0,0,2-2V7A2,2,0,0,0,25,5ZM12,4h8V8H12ZM25,28H7V7h3v3H22V7h3Z"
  })), children);
});
var ReportData32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReportData32(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path459 || (_path459 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 20H17V24H15zM20 18H22V24H20zM10 14H12V24H10z"
  })), _path460 || (_path460 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,5H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H25a2,2,0,0,0,2-2V7A2,2,0,0,0,25,5ZM12,4h8V8H12ZM25,28H7V7h3v3H22V7h3Z"
  })), children);
});
var ReportData24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReportData24(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path461 || (_path461 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 20H17V24H15zM20 18H22V24H20zM10 14H12V24H10z"
  })), _path462 || (_path462 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,5H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H25a2,2,0,0,0,2-2V7A2,2,0,0,0,25,5ZM12,4h8V8H12ZM25,28H7V7h3v3H22V7h3Z"
  })), children);
});
var ReportData20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReportData20(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path463 || (_path463 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 20H17V24H15zM20 18H22V24H20zM10 14H12V24H10z"
  })), _path464 || (_path464 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,5H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H25a2,2,0,0,0,2-2V7A2,2,0,0,0,25,5ZM12,4h8V8H12ZM25,28H7V7h3v3H22V7h3Z"
  })), children);
});
var ReportData16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ReportData16(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path465 || (_path465 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 20H17V24H15zM20 18H22V24H20zM10 14H12V24H10z"
  })), _path466 || (_path466 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,5H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H25a2,2,0,0,0,2-2V7A2,2,0,0,0,25,5ZM12,4h8V8H12ZM25,28H7V7h3v3H22V7h3Z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-22.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-22.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "QS16": () => (/* binding */ QS16),
/* harmony export */   "QS20": () => (/* binding */ QS20),
/* harmony export */   "QS24": () => (/* binding */ QS24),
/* harmony export */   "QS32": () => (/* binding */ QS32),
/* harmony export */   "QSAlt16": () => (/* binding */ QSAlt16),
/* harmony export */   "QSAlt20": () => (/* binding */ QSAlt20),
/* harmony export */   "QSAlt24": () => (/* binding */ QSAlt24),
/* harmony export */   "QSAlt32": () => (/* binding */ QSAlt32),
/* harmony export */   "RequestQuote16": () => (/* binding */ RequestQuote16),
/* harmony export */   "RequestQuote20": () => (/* binding */ RequestQuote20),
/* harmony export */   "RequestQuote24": () => (/* binding */ RequestQuote24),
/* harmony export */   "RequestQuote32": () => (/* binding */ RequestQuote32),
/* harmony export */   "ResearchBlochSphere16": () => (/* binding */ ResearchBlochSphere16),
/* harmony export */   "ResearchBlochSphere20": () => (/* binding */ ResearchBlochSphere20),
/* harmony export */   "ResearchBlochSphere24": () => (/* binding */ ResearchBlochSphere24),
/* harmony export */   "ResearchBlochSphere32": () => (/* binding */ ResearchBlochSphere32),
/* harmony export */   "ResearchHintonPlot16": () => (/* binding */ ResearchHintonPlot16),
/* harmony export */   "ResearchHintonPlot20": () => (/* binding */ ResearchHintonPlot20),
/* harmony export */   "ResearchHintonPlot24": () => (/* binding */ ResearchHintonPlot24),
/* harmony export */   "ResearchHintonPlot32": () => (/* binding */ ResearchHintonPlot32),
/* harmony export */   "ResearchMatrix16": () => (/* binding */ ResearchMatrix16),
/* harmony export */   "ResearchMatrix20": () => (/* binding */ ResearchMatrix20),
/* harmony export */   "ResearchMatrix24": () => (/* binding */ ResearchMatrix24),
/* harmony export */   "ResearchMatrix32": () => (/* binding */ ResearchMatrix32),
/* harmony export */   "Reset16": () => (/* binding */ Reset16),
/* harmony export */   "Reset20": () => (/* binding */ Reset20),
/* harmony export */   "Reset24": () => (/* binding */ Reset24),
/* harmony export */   "Reset32": () => (/* binding */ Reset32),
/* harmony export */   "ResetAlt16": () => (/* binding */ ResetAlt16),
/* harmony export */   "ResetAlt20": () => (/* binding */ ResetAlt20),
/* harmony export */   "ResetAlt24": () => (/* binding */ ResetAlt24),
/* harmony export */   "ResetAlt32": () => (/* binding */ ResetAlt32),
/* harmony export */   "Restart16": () => (/* binding */ Restart16),
/* harmony export */   "Restart20": () => (/* binding */ Restart20),
/* harmony export */   "Restart24": () => (/* binding */ Restart24),
/* harmony export */   "Restart32": () => (/* binding */ Restart32),
/* harmony export */   "Restaurant16": () => (/* binding */ Restaurant16),
/* harmony export */   "Restaurant20": () => (/* binding */ Restaurant20),
/* harmony export */   "Restaurant24": () => (/* binding */ Restaurant24),
/* harmony export */   "Restaurant32": () => (/* binding */ Restaurant32),
/* harmony export */   "RestaurantFine16": () => (/* binding */ RestaurantFine16),
/* harmony export */   "RestaurantFine20": () => (/* binding */ RestaurantFine20),
/* harmony export */   "RestaurantFine24": () => (/* binding */ RestaurantFine24),
/* harmony export */   "RestaurantFine32": () => (/* binding */ RestaurantFine32),
/* harmony export */   "Result16": () => (/* binding */ Result16),
/* harmony export */   "Result20": () => (/* binding */ Result20),
/* harmony export */   "Result24": () => (/* binding */ Result24),
/* harmony export */   "Result32": () => (/* binding */ Result32),
/* harmony export */   "ResultNew16": () => (/* binding */ ResultNew16),
/* harmony export */   "ResultNew20": () => (/* binding */ ResultNew20),
/* harmony export */   "ResultNew24": () => (/* binding */ ResultNew24),
/* harmony export */   "ResultNew32": () => (/* binding */ ResultNew32),
/* harmony export */   "ResultOld16": () => (/* binding */ ResultOld16),
/* harmony export */   "ResultOld20": () => (/* binding */ ResultOld20),
/* harmony export */   "ResultOld24": () => (/* binding */ ResultOld24),
/* harmony export */   "ResultOld32": () => (/* binding */ ResultOld32),
/* harmony export */   "RetryFailed16": () => (/* binding */ RetryFailed16),
/* harmony export */   "RetryFailed20": () => (/* binding */ RetryFailed20),
/* harmony export */   "RetryFailed24": () => (/* binding */ RetryFailed24),
/* harmony export */   "RetryFailed32": () => (/* binding */ RetryFailed32),
/* harmony export */   "Review16": () => (/* binding */ Review16),
/* harmony export */   "Review20": () => (/* binding */ Review20),
/* harmony export */   "Review24": () => (/* binding */ Review24),
/* harmony export */   "Review32": () => (/* binding */ Review32),
/* harmony export */   "Rewind_1016": () => (/* binding */ Rewind_1016),
/* harmony export */   "Rewind_1020": () => (/* binding */ Rewind_1020),
/* harmony export */   "Rewind_1024": () => (/* binding */ Rewind_1024),
/* harmony export */   "Rewind_1032": () => (/* binding */ Rewind_1032),
/* harmony export */   "Rewind_3016": () => (/* binding */ Rewind_3016),
/* harmony export */   "Rewind_3020": () => (/* binding */ Rewind_3020),
/* harmony export */   "Rewind_3024": () => (/* binding */ Rewind_3024),
/* harmony export */   "Rewind_3032": () => (/* binding */ Rewind_3032),
/* harmony export */   "Rewind_516": () => (/* binding */ Rewind_516),
/* harmony export */   "Rewind_520": () => (/* binding */ Rewind_520),
/* harmony export */   "Rewind_524": () => (/* binding */ Rewind_524),
/* harmony export */   "Rewind_532": () => (/* binding */ Rewind_532),
/* harmony export */   "Road16": () => (/* binding */ Road16),
/* harmony export */   "Road20": () => (/* binding */ Road20),
/* harmony export */   "Road24": () => (/* binding */ Road24),
/* harmony export */   "Road32": () => (/* binding */ Road32),
/* harmony export */   "RoadWeather16": () => (/* binding */ RoadWeather16),
/* harmony export */   "RoadWeather20": () => (/* binding */ RoadWeather20),
/* harmony export */   "RoadWeather24": () => (/* binding */ RoadWeather24),
/* harmony export */   "RoadWeather32": () => (/* binding */ RoadWeather32),
/* harmony export */   "Roadmap16": () => (/* binding */ Roadmap16),
/* harmony export */   "Roadmap20": () => (/* binding */ Roadmap20),
/* harmony export */   "Roadmap24": () => (/* binding */ Roadmap24),
/* harmony export */   "Roadmap32": () => (/* binding */ Roadmap32),
/* harmony export */   "Rocket16": () => (/* binding */ Rocket16),
/* harmony export */   "Rocket20": () => (/* binding */ Rocket20),
/* harmony export */   "Rocket24": () => (/* binding */ Rocket24),
/* harmony export */   "Rocket32": () => (/* binding */ Rocket32),
/* harmony export */   "Rotate16": () => (/* binding */ Rotate16),
/* harmony export */   "Rotate20": () => (/* binding */ Rotate20),
/* harmony export */   "Rotate24": () => (/* binding */ Rotate24),
/* harmony export */   "Rotate32": () => (/* binding */ Rotate32),
/* harmony export */   "RotateClockwise16": () => (/* binding */ RotateClockwise16),
/* harmony export */   "RotateClockwise20": () => (/* binding */ RotateClockwise20),
/* harmony export */   "RotateClockwise24": () => (/* binding */ RotateClockwise24),
/* harmony export */   "RotateClockwise32": () => (/* binding */ RotateClockwise32),
/* harmony export */   "RotateClockwiseAlt16": () => (/* binding */ RotateClockwiseAlt16),
/* harmony export */   "RotateClockwiseAlt20": () => (/* binding */ RotateClockwiseAlt20),
/* harmony export */   "RotateClockwiseAlt24": () => (/* binding */ RotateClockwiseAlt24),
/* harmony export */   "RotateClockwiseAlt32": () => (/* binding */ RotateClockwiseAlt32),
/* harmony export */   "RotateClockwiseAltFilled16": () => (/* binding */ RotateClockwiseAltFilled16),
/* harmony export */   "RotateClockwiseAltFilled20": () => (/* binding */ RotateClockwiseAltFilled20),
/* harmony export */   "RotateClockwiseAltFilled24": () => (/* binding */ RotateClockwiseAltFilled24),
/* harmony export */   "RotateClockwiseAltFilled32": () => (/* binding */ RotateClockwiseAltFilled32),
/* harmony export */   "RotateClockwiseFilled16": () => (/* binding */ RotateClockwiseFilled16),
/* harmony export */   "RotateClockwiseFilled20": () => (/* binding */ RotateClockwiseFilled20),
/* harmony export */   "RotateClockwiseFilled24": () => (/* binding */ RotateClockwiseFilled24),
/* harmony export */   "RotateClockwiseFilled32": () => (/* binding */ RotateClockwiseFilled32),
/* harmony export */   "RotateCounterclockwise16": () => (/* binding */ RotateCounterclockwise16),
/* harmony export */   "RotateCounterclockwise20": () => (/* binding */ RotateCounterclockwise20),
/* harmony export */   "RotateCounterclockwise24": () => (/* binding */ RotateCounterclockwise24),
/* harmony export */   "RotateCounterclockwise32": () => (/* binding */ RotateCounterclockwise32),
/* harmony export */   "RotateCounterclockwiseAlt16": () => (/* binding */ RotateCounterclockwiseAlt16),
/* harmony export */   "RotateCounterclockwiseAlt20": () => (/* binding */ RotateCounterclockwiseAlt20),
/* harmony export */   "RotateCounterclockwiseAlt24": () => (/* binding */ RotateCounterclockwiseAlt24),
/* harmony export */   "RotateCounterclockwiseAlt32": () => (/* binding */ RotateCounterclockwiseAlt32),
/* harmony export */   "RotateCounterclockwiseAltFilled16": () => (/* binding */ RotateCounterclockwiseAltFilled16),
/* harmony export */   "RotateCounterclockwiseAltFilled20": () => (/* binding */ RotateCounterclockwiseAltFilled20),
/* harmony export */   "RotateCounterclockwiseAltFilled24": () => (/* binding */ RotateCounterclockwiseAltFilled24),
/* harmony export */   "RotateCounterclockwiseAltFilled32": () => (/* binding */ RotateCounterclockwiseAltFilled32),
/* harmony export */   "RotateCounterclockwiseFilled16": () => (/* binding */ RotateCounterclockwiseFilled16),
/* harmony export */   "RotateCounterclockwiseFilled20": () => (/* binding */ RotateCounterclockwiseFilled20),
/* harmony export */   "RotateCounterclockwiseFilled24": () => (/* binding */ RotateCounterclockwiseFilled24),
/* harmony export */   "RotateCounterclockwiseFilled32": () => (/* binding */ RotateCounterclockwiseFilled32),
/* harmony export */   "Router16": () => (/* binding */ Router16),
/* harmony export */   "Router20": () => (/* binding */ Router20),
/* harmony export */   "Router24": () => (/* binding */ Router24),
/* harmony export */   "Router32": () => (/* binding */ Router32),
/* harmony export */   "RouterVoice16": () => (/* binding */ RouterVoice16),
/* harmony export */   "RouterVoice20": () => (/* binding */ RouterVoice20),
/* harmony export */   "RouterVoice24": () => (/* binding */ RouterVoice24),
/* harmony export */   "RouterVoice32": () => (/* binding */ RouterVoice32),
/* harmony export */   "RouterWifi16": () => (/* binding */ RouterWifi16),
/* harmony export */   "RouterWifi20": () => (/* binding */ RouterWifi20),
/* harmony export */   "RouterWifi24": () => (/* binding */ RouterWifi24),
/* harmony export */   "RouterWifi32": () => (/* binding */ RouterWifi32),
/* harmony export */   "Row16": () => (/* binding */ Row16),
/* harmony export */   "Row20": () => (/* binding */ Row20),
/* harmony export */   "Row24": () => (/* binding */ Row24),
/* harmony export */   "Row32": () => (/* binding */ Row32),
/* harmony export */   "RowCollapse16": () => (/* binding */ RowCollapse16),
/* harmony export */   "RowCollapse20": () => (/* binding */ RowCollapse20),
/* harmony export */   "RowCollapse24": () => (/* binding */ RowCollapse24),
/* harmony export */   "RowCollapse32": () => (/* binding */ RowCollapse32),
/* harmony export */   "RowDelete16": () => (/* binding */ RowDelete16),
/* harmony export */   "RowDelete20": () => (/* binding */ RowDelete20),
/* harmony export */   "RowDelete24": () => (/* binding */ RowDelete24),
/* harmony export */   "RowDelete32": () => (/* binding */ RowDelete32),
/* harmony export */   "RowExpand16": () => (/* binding */ RowExpand16),
/* harmony export */   "RowExpand20": () => (/* binding */ RowExpand20),
/* harmony export */   "RowExpand24": () => (/* binding */ RowExpand24),
/* harmony export */   "RowExpand32": () => (/* binding */ RowExpand32),
/* harmony export */   "RowInsert16": () => (/* binding */ RowInsert16),
/* harmony export */   "RowInsert20": () => (/* binding */ RowInsert20),
/* harmony export */   "RowInsert24": () => (/* binding */ RowInsert24),
/* harmony export */   "RowInsert32": () => (/* binding */ RowInsert32),
/* harmony export */   "Rss16": () => (/* binding */ Rss16),
/* harmony export */   "Rss20": () => (/* binding */ Rss20),
/* harmony export */   "Rss24": () => (/* binding */ Rss24),
/* harmony export */   "Rss32": () => (/* binding */ Rss32),
/* harmony export */   "Rule16": () => (/* binding */ Rule16),
/* harmony export */   "Rule20": () => (/* binding */ Rule20),
/* harmony export */   "Rule24": () => (/* binding */ Rule24),
/* harmony export */   "Rule32": () => (/* binding */ Rule32),
/* harmony export */   "RuleCancelled16": () => (/* binding */ RuleCancelled16),
/* harmony export */   "RuleCancelled20": () => (/* binding */ RuleCancelled20),
/* harmony export */   "RuleCancelled24": () => (/* binding */ RuleCancelled24),
/* harmony export */   "RuleCancelled32": () => (/* binding */ RuleCancelled32),
/* harmony export */   "RuleDraft16": () => (/* binding */ RuleDraft16),
/* harmony export */   "RuleDraft20": () => (/* binding */ RuleDraft20),
/* harmony export */   "RuleDraft24": () => (/* binding */ RuleDraft24),
/* harmony export */   "RuleDraft32": () => (/* binding */ RuleDraft32),
/* harmony export */   "RuleFilled16": () => (/* binding */ RuleFilled16),
/* harmony export */   "RuleFilled20": () => (/* binding */ RuleFilled20),
/* harmony export */   "RuleFilled24": () => (/* binding */ RuleFilled24),
/* harmony export */   "RuleFilled32": () => (/* binding */ RuleFilled32),
/* harmony export */   "RuleTest16": () => (/* binding */ RuleTest16),
/* harmony export */   "RuleTest20": () => (/* binding */ RuleTest20),
/* harmony export */   "RuleTest24": () => (/* binding */ RuleTest24),
/* harmony export */   "RuleTest32": () => (/* binding */ RuleTest32),
/* harmony export */   "Ruler16": () => (/* binding */ Ruler16),
/* harmony export */   "Ruler20": () => (/* binding */ Ruler20),
/* harmony export */   "Ruler24": () => (/* binding */ Ruler24),
/* harmony export */   "Ruler32": () => (/* binding */ Ruler32),
/* harmony export */   "RulerAlt16": () => (/* binding */ RulerAlt16),
/* harmony export */   "RulerAlt20": () => (/* binding */ RulerAlt20),
/* harmony export */   "RulerAlt24": () => (/* binding */ RulerAlt24),
/* harmony export */   "RulerAlt32": () => (/* binding */ RulerAlt32),
/* harmony export */   "Run16": () => (/* binding */ Run16),
/* harmony export */   "Run20": () => (/* binding */ Run20),
/* harmony export */   "Run24": () => (/* binding */ Run24),
/* harmony export */   "Run32": () => (/* binding */ Run32),
/* harmony export */   "SailboatCoastal16": () => (/* binding */ SailboatCoastal16),
/* harmony export */   "SailboatCoastal20": () => (/* binding */ SailboatCoastal20),
/* harmony export */   "SailboatCoastal24": () => (/* binding */ SailboatCoastal24),
/* harmony export */   "SailboatCoastal32": () => (/* binding */ SailboatCoastal32),
/* harmony export */   "SailboatOffshore16": () => (/* binding */ SailboatOffshore16),
/* harmony export */   "SailboatOffshore20": () => (/* binding */ SailboatOffshore20),
/* harmony export */   "SailboatOffshore24": () => (/* binding */ SailboatOffshore24),
/* harmony export */   "SailboatOffshore32": () => (/* binding */ SailboatOffshore32),
/* harmony export */   "SankeyDiagram16": () => (/* binding */ SankeyDiagram16),
/* harmony export */   "SankeyDiagram20": () => (/* binding */ SankeyDiagram20),
/* harmony export */   "SankeyDiagram24": () => (/* binding */ SankeyDiagram24),
/* harmony export */   "SankeyDiagram32": () => (/* binding */ SankeyDiagram32),
/* harmony export */   "SankeyDiagramAlt16": () => (/* binding */ SankeyDiagramAlt16),
/* harmony export */   "SankeyDiagramAlt20": () => (/* binding */ SankeyDiagramAlt20),
/* harmony export */   "SankeyDiagramAlt24": () => (/* binding */ SankeyDiagramAlt24),
/* harmony export */   "SankeyDiagramAlt32": () => (/* binding */ SankeyDiagramAlt32),
/* harmony export */   "Satellite16": () => (/* binding */ Satellite16),
/* harmony export */   "Satellite20": () => (/* binding */ Satellite20),
/* harmony export */   "Satellite24": () => (/* binding */ Satellite24),
/* harmony export */   "Satellite32": () => (/* binding */ Satellite32),
/* harmony export */   "SatelliteRadar16": () => (/* binding */ SatelliteRadar16),
/* harmony export */   "SatelliteRadar20": () => (/* binding */ SatelliteRadar20),
/* harmony export */   "SatelliteRadar24": () => (/* binding */ SatelliteRadar24),
/* harmony export */   "SatelliteRadar32": () => (/* binding */ SatelliteRadar32),
/* harmony export */   "SatelliteWeather16": () => (/* binding */ SatelliteWeather16),
/* harmony export */   "SatelliteWeather20": () => (/* binding */ SatelliteWeather20),
/* harmony export */   "SatelliteWeather24": () => (/* binding */ SatelliteWeather24),
/* harmony export */   "SatelliteWeather32": () => (/* binding */ SatelliteWeather32),
/* harmony export */   "Save16": () => (/* binding */ Save16),
/* harmony export */   "Save20": () => (/* binding */ Save20),
/* harmony export */   "Save24": () => (/* binding */ Save24),
/* harmony export */   "Save32": () => (/* binding */ Save32),
/* harmony export */   "SaveModel16": () => (/* binding */ SaveModel16),
/* harmony export */   "SaveModel20": () => (/* binding */ SaveModel20),
/* harmony export */   "SaveModel24": () => (/* binding */ SaveModel24),
/* harmony export */   "SaveModel32": () => (/* binding */ SaveModel32),
/* harmony export */   "WatsonHealthRotate_18016": () => (/* binding */ WatsonHealthRotate_18016),
/* harmony export */   "WatsonHealthRotate_18020": () => (/* binding */ WatsonHealthRotate_18020),
/* harmony export */   "WatsonHealthRotate_18024": () => (/* binding */ WatsonHealthRotate_18024),
/* harmony export */   "WatsonHealthRotate_18032": () => (/* binding */ WatsonHealthRotate_18032),
/* harmony export */   "WatsonHealthRotate_36016": () => (/* binding */ WatsonHealthRotate_36016),
/* harmony export */   "WatsonHealthRotate_36020": () => (/* binding */ WatsonHealthRotate_36020),
/* harmony export */   "WatsonHealthRotate_36024": () => (/* binding */ WatsonHealthRotate_36024),
/* harmony export */   "WatsonHealthRotate_36032": () => (/* binding */ WatsonHealthRotate_36032),
/* harmony export */   "WatsonHealthSaveAnnotation16": () => (/* binding */ WatsonHealthSaveAnnotation16),
/* harmony export */   "WatsonHealthSaveAnnotation20": () => (/* binding */ WatsonHealthSaveAnnotation20),
/* harmony export */   "WatsonHealthSaveAnnotation24": () => (/* binding */ WatsonHealthSaveAnnotation24),
/* harmony export */   "WatsonHealthSaveAnnotation32": () => (/* binding */ WatsonHealthSaveAnnotation32),
/* harmony export */   "WatsonHealthSaveImage16": () => (/* binding */ WatsonHealthSaveImage16),
/* harmony export */   "WatsonHealthSaveImage20": () => (/* binding */ WatsonHealthSaveImage20),
/* harmony export */   "WatsonHealthSaveImage24": () => (/* binding */ WatsonHealthSaveImage24),
/* harmony export */   "WatsonHealthSaveImage32": () => (/* binding */ WatsonHealthSaveImage32),
/* harmony export */   "WatsonHealthSaveSeries24": () => (/* binding */ WatsonHealthSaveSeries24),
/* harmony export */   "WatsonHealthSaveSeries32": () => (/* binding */ WatsonHealthSaveSeries32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _circle, _path61, _path62, _circle2, _path63, _path64, _circle3, _path65, _path66, _circle4, _path67, _path68, _path69, _path70, _path71, _path72, _path73, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _circle5, _path201, _path202, _circle6, _path203, _path204, _circle7, _path205, _path206, _circle8, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _path224, _path225, _path226, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388, _path389, _path390;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var didWarnAboutDeprecation = {};
var RequestQuote32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RequestQuote32(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,22v6H6V4H16V2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H22a2,2,0,0,0,2-2V22Z"
  })), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.54,5.76l-3.3-3.3a1.6,1.6,0,0,0-2.24,0l-14,14V22h5.53l14-14a1.6,1.6,0,0,0,0-2.24ZM14.7,20H12V17.3l9.44-9.45,2.71,2.71ZM25.56,9.15,22.85,6.44l2.27-2.27,2.71,2.71Z"
  })), children);
});
var RequestQuote24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RequestQuote24(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,22v6H6V4H16V2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H22a2,2,0,0,0,2-2V22Z"
  })), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.54,5.76l-3.3-3.3a1.6,1.6,0,0,0-2.24,0l-14,14V22h5.53l14-14a1.6,1.6,0,0,0,0-2.24ZM14.7,20H12V17.3l9.44-9.45,2.71,2.71ZM25.56,9.15,22.85,6.44l2.27-2.27,2.71,2.71Z"
  })), children);
});
var RequestQuote20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RequestQuote20(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,22v6H6V4H16V2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H22a2,2,0,0,0,2-2V22Z"
  })), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.54,5.76l-3.3-3.3a1.6,1.6,0,0,0-2.24,0l-14,14V22h5.53l14-14a1.6,1.6,0,0,0,0-2.24ZM14.7,20H12V17.3l9.44-9.45,2.71,2.71ZM25.56,9.15,22.85,6.44l2.27-2.27,2.71,2.71Z"
  })), children);
});
var RequestQuote16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RequestQuote16(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,22v6H6V4H16V2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H22a2,2,0,0,0,2-2V22Z"
  })), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.54,5.76l-3.3-3.3a1.6,1.6,0,0,0-2.24,0l-14,14V22h5.53l14-14a1.6,1.6,0,0,0,0-2.24ZM14.7,20H12V17.3l9.44-9.45,2.71,2.71ZM25.56,9.15,22.85,6.44l2.27-2.27,2.71,2.71Z"
  })), children);
});
var ResearchBlochSphere32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResearchBlochSphere32(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  if (true) {
    if (!didWarnAboutDeprecation['ResearchBlochSphere32']) {
      didWarnAboutDeprecation['ResearchBlochSphere32'] = true;
      console.warn("The ResearchBlochSphere32 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.87,7.84l-1.74-1L16,14h0a2,2,0,1,0,2,2,2,2,0,0,0-.27-1Z"
  })), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,2a12,12,0,0,1,11.17,7.65,25.69,25.69,0,0,0-3.69-1.5l-1,1.77a22.7,22.7,0,0,1,5.41,2.39,11.05,11.05,0,0,1,0,3.38A22.92,22.92,0,0,1,16,21,22.92,22.92,0,0,1,4.13,17.69a11.05,11.05,0,0,1,0-3.38A22.8,22.8,0,0,1,15,11V9a25,25,0,0,0-10.17,2.6A12,12,0,0,1,16,4Zm0,24A12,12,0,0,1,4.83,20.35,24.88,24.88,0,0,0,16,23a24.88,24.88,0,0,0,11.17-2.65A12,12,0,0,1,16,28Z"
  })), children);
});
var ResearchBlochSphere24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResearchBlochSphere24(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  if (true) {
    if (!didWarnAboutDeprecation['ResearchBlochSphere24']) {
      didWarnAboutDeprecation['ResearchBlochSphere24'] = true;
      console.warn("The ResearchBlochSphere24 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.87,7.84l-1.74-1L16,14h0a2,2,0,1,0,2,2,2,2,0,0,0-.27-1Z"
  })), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,2a12,12,0,0,1,11.17,7.65,25.69,25.69,0,0,0-3.69-1.5l-1,1.77a22.7,22.7,0,0,1,5.41,2.39,11.05,11.05,0,0,1,0,3.38A22.92,22.92,0,0,1,16,21,22.92,22.92,0,0,1,4.13,17.69a11.05,11.05,0,0,1,0-3.38A22.8,22.8,0,0,1,15,11V9a25,25,0,0,0-10.17,2.6A12,12,0,0,1,16,4Zm0,24A12,12,0,0,1,4.83,20.35,24.88,24.88,0,0,0,16,23a24.88,24.88,0,0,0,11.17-2.65A12,12,0,0,1,16,28Z"
  })), children);
});
var ResearchBlochSphere20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResearchBlochSphere20(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  if (true) {
    if (!didWarnAboutDeprecation['ResearchBlochSphere20']) {
      didWarnAboutDeprecation['ResearchBlochSphere20'] = true;
      console.warn("The ResearchBlochSphere20 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.87,7.84l-1.74-1L16,14h0a2,2,0,1,0,2,2,2,2,0,0,0-.27-1Z"
  })), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,2a12,12,0,0,1,11.17,7.65,25.69,25.69,0,0,0-3.69-1.5l-1,1.77a22.7,22.7,0,0,1,5.41,2.39,11.05,11.05,0,0,1,0,3.38A22.92,22.92,0,0,1,16,21,22.92,22.92,0,0,1,4.13,17.69a11.05,11.05,0,0,1,0-3.38A22.8,22.8,0,0,1,15,11V9a25,25,0,0,0-10.17,2.6A12,12,0,0,1,16,4Zm0,24A12,12,0,0,1,4.83,20.35,24.88,24.88,0,0,0,16,23a24.88,24.88,0,0,0,11.17-2.65A12,12,0,0,1,16,28Z"
  })), children);
});
var ResearchBlochSphere16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResearchBlochSphere16(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  if (true) {
    if (!didWarnAboutDeprecation['ResearchBlochSphere16']) {
      didWarnAboutDeprecation['ResearchBlochSphere16'] = true;
      console.warn("The ResearchBlochSphere16 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.87,7.84l-1.74-1L16,14h0a2,2,0,1,0,2,2,2,2,0,0,0-.27-1Z"
  })), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,2a12,12,0,0,1,11.17,7.65,25.69,25.69,0,0,0-3.69-1.5l-1,1.77a22.7,22.7,0,0,1,5.41,2.39,11.05,11.05,0,0,1,0,3.38A22.92,22.92,0,0,1,16,21,22.92,22.92,0,0,1,4.13,17.69a11.05,11.05,0,0,1,0-3.38A22.8,22.8,0,0,1,15,11V9a25,25,0,0,0-10.17,2.6A12,12,0,0,1,16,4Zm0,24A12,12,0,0,1,4.83,20.35,24.88,24.88,0,0,0,16,23a24.88,24.88,0,0,0,11.17-2.65A12,12,0,0,1,16,28Z"
  })), children);
});
var ResearchHintonPlot32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResearchHintonPlot32(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  if (true) {
    if (!didWarnAboutDeprecation['ResearchHintonPlot32']) {
      didWarnAboutDeprecation['ResearchHintonPlot32'] = true;
      console.warn("The ResearchHintonPlot32 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 2H6V6H2zM10 2H14V6H10zM18 2H22V6H18zM26 2H30V6H26zM2 10H6V14H2zM10 10H14V14H10zM18 10H22V14H18zM26 10H30V14H26zM2 18H6V22H2zM10 18H14V22H10zM18 18H22V22H18zM26 18H30V22H26zM2 26H6V30H2zM10 26H14V30H10zM18 26H22V30H18zM26 26H30V30H26z"
  })), children);
});
var ResearchHintonPlot24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResearchHintonPlot24(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  if (true) {
    if (!didWarnAboutDeprecation['ResearchHintonPlot24']) {
      didWarnAboutDeprecation['ResearchHintonPlot24'] = true;
      console.warn("The ResearchHintonPlot24 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 2H6V6H2zM10 2H14V6H10zM18 2H22V6H18zM26 2H30V6H26zM2 10H6V14H2zM10 10H14V14H10zM18 10H22V14H18zM26 10H30V14H26zM2 18H6V22H2zM10 18H14V22H10zM18 18H22V22H18zM26 18H30V22H26zM2 26H6V30H2zM10 26H14V30H10zM18 26H22V30H18zM26 26H30V30H26z"
  })), children);
});
var ResearchHintonPlot20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResearchHintonPlot20(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  if (true) {
    if (!didWarnAboutDeprecation['ResearchHintonPlot20']) {
      didWarnAboutDeprecation['ResearchHintonPlot20'] = true;
      console.warn("The ResearchHintonPlot20 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 2H6V6H2zM10 2H14V6H10zM18 2H22V6H18zM26 2H30V6H26zM2 10H6V14H2zM10 10H14V14H10zM18 10H22V14H18zM26 10H30V14H26zM2 18H6V22H2zM10 18H14V22H10zM18 18H22V22H18zM26 18H30V22H26zM2 26H6V30H2zM10 26H14V30H10zM18 26H22V30H18zM26 26H30V30H26z"
  })), children);
});
var ResearchHintonPlot16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResearchHintonPlot16(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  if (true) {
    if (!didWarnAboutDeprecation['ResearchHintonPlot16']) {
      didWarnAboutDeprecation['ResearchHintonPlot16'] = true;
      console.warn("The ResearchHintonPlot16 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 2H6V6H2zM10 2H14V6H10zM18 2H22V6H18zM26 2H30V6H26zM2 10H6V14H2zM10 10H14V14H10zM18 10H22V14H18zM26 10H30V14H26zM2 18H6V22H2zM10 18H14V22H10zM18 18H22V22H18zM26 18H30V22H26zM2 26H6V30H2zM10 26H14V30H10zM18 26H22V30H18zM26 26H30V30H26z"
  })), children);
});
var ResearchMatrix32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResearchMatrix32(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  if (true) {
    if (!didWarnAboutDeprecation['ResearchMatrix32']) {
      didWarnAboutDeprecation['ResearchMatrix32'] = true;
      console.warn("The ResearchMatrix32 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 13L18 4 16 4 16 6 13 6 13 8 16 8 16 13 13 13 13 15 21 15 21 13 18 13zM16.5 20A3.5 3.5 0 1113 23.5 3.5 3.5 0 0116.5 20m0-2A5.5 5.5 0 1022 23.5 5.5 5.5 0 0016.5 18zM8 30L2 30 2 2 8 2 8 4 4 4 4 28 8 28 8 30zM30 30L24 30 24 28 28 28 28 4 24 4 24 2 30 2 30 30z"
  })), children);
});
var ResearchMatrix24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResearchMatrix24(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  if (true) {
    if (!didWarnAboutDeprecation['ResearchMatrix24']) {
      didWarnAboutDeprecation['ResearchMatrix24'] = true;
      console.warn("The ResearchMatrix24 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 13L18 4 16 4 16 6 13 6 13 8 16 8 16 13 13 13 13 15 21 15 21 13 18 13zM16.5 20A3.5 3.5 0 1113 23.5 3.5 3.5 0 0116.5 20m0-2A5.5 5.5 0 1022 23.5 5.5 5.5 0 0016.5 18zM8 30L2 30 2 2 8 2 8 4 4 4 4 28 8 28 8 30zM30 30L24 30 24 28 28 28 28 4 24 4 24 2 30 2 30 30z"
  })), children);
});
var ResearchMatrix20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResearchMatrix20(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  if (true) {
    if (!didWarnAboutDeprecation['ResearchMatrix20']) {
      didWarnAboutDeprecation['ResearchMatrix20'] = true;
      console.warn("The ResearchMatrix20 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 13L18 4 16 4 16 6 13 6 13 8 16 8 16 13 13 13 13 15 21 15 21 13 18 13zM16.5 20A3.5 3.5 0 1113 23.5 3.5 3.5 0 0116.5 20m0-2A5.5 5.5 0 1022 23.5 5.5 5.5 0 0016.5 18zM8 30L2 30 2 2 8 2 8 4 4 4 4 28 8 28 8 30zM30 30L24 30 24 28 28 28 28 4 24 4 24 2 30 2 30 30z"
  })), children);
});
var ResearchMatrix16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResearchMatrix16(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  if (true) {
    if (!didWarnAboutDeprecation['ResearchMatrix16']) {
      didWarnAboutDeprecation['ResearchMatrix16'] = true;
      console.warn("The ResearchMatrix16 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 13L18 4 16 4 16 6 13 6 13 8 16 8 16 13 13 13 13 15 21 15 21 13 18 13zM16.5 20A3.5 3.5 0 1113 23.5 3.5 3.5 0 0116.5 20m0-2A5.5 5.5 0 1022 23.5 5.5 5.5 0 0016.5 18zM8 30L2 30 2 2 8 2 8 4 4 4 4 28 8 28 8 30zM30 30L24 30 24 28 28 28 28 4 24 4 24 2 30 2 30 30z"
  })), children);
});
var Reset32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Reset32(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28A12,12,0,1,0,6,16v6.2L2.4,18.6,1,20l6,6,6-6-1.4-1.4L8,22.2V16H8A10,10,0,1,1,18,26Z"
  })), children);
});
var Reset24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Reset24(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28A12,12,0,1,0,6,16v6.2L2.4,18.6,1,20l6,6,6-6-1.4-1.4L8,22.2V16H8A10,10,0,1,1,18,26Z"
  })), children);
});
var Reset20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Reset20(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28A12,12,0,1,0,6,16v6.2L2.4,18.6,1,20l6,6,6-6-1.4-1.4L8,22.2V16H8A10,10,0,1,1,18,26Z"
  })), children);
});
var Reset16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Reset16(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28A12,12,0,1,0,6,16v6.2L2.4,18.6,1,20l6,6,6-6-1.4-1.4L8,22.2V16H8A10,10,0,1,1,18,26Z"
  })), children);
});
var ResetAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResetAlt32(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,8H6.83l3.58-3.59L9,3,3,9l6,6,1.41-1.41L6.83,10H27V26H7V19H5v7a2,2,0,0,0,2,2H27a2,2,0,0,0,2-2V10A2,2,0,0,0,27,8Z"
  })), children);
});
var ResetAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResetAlt24(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,8H6.83l3.58-3.59L9,3,3,9l6,6,1.41-1.41L6.83,10H27V26H7V19H5v7a2,2,0,0,0,2,2H27a2,2,0,0,0,2-2V10A2,2,0,0,0,27,8Z"
  })), children);
});
var ResetAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResetAlt20(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,8H6.83l3.58-3.59L9,3,3,9l6,6,1.41-1.41L6.83,10H27V26H7V19H5v7a2,2,0,0,0,2,2H27a2,2,0,0,0,2-2V10A2,2,0,0,0,27,8Z"
  })), children);
});
var ResetAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResetAlt16(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,8H6.83l3.58-3.59L9,3,3,9l6,6,1.41-1.41L6.83,10H27V26H7V19H5v7a2,2,0,0,0,2,2H27a2,2,0,0,0,2-2V10A2,2,0,0,0,27,8Z"
  })), children);
});
var Restart32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Restart32(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,18A10,10,0,1,1,16,8h6.1821l-3.5844,3.5854L20,13l6-6L20,1,18.5977,2.414,22.1851,6H16A12,12,0,1,0,28,18Z"
  })), children);
});
var Restart24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Restart24(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,18A10,10,0,1,1,16,8h6.1821l-3.5844,3.5854L20,13l6-6L20,1,18.5977,2.414,22.1851,6H16A12,12,0,1,0,28,18Z"
  })), children);
});
var Restart20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Restart20(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,18A10,10,0,1,1,16,8h6.1821l-3.5844,3.5854L20,13l6-6L20,1,18.5977,2.414,22.1851,6H16A12,12,0,1,0,28,18Z"
  })), children);
});
var Restart16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Restart16(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,9c0,2.8-2.2,5-5,5s-5-2.2-5-5s2.2-5,5-5h3.1L9.3,5.8L10,6.5l3-3l-3-3L9.3,1.2L11.1,3H8C4.7,3,2,5.7,2,9s2.7,6,6,6\ts6-2.7,6-6H13z"
  })), children);
});
var Restaurant32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Restaurant32(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 2H11V12H9z"
  })), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 11a4 4 0 01-8 0V2H4v9a6 6 0 005 5.91V30h2V16.91A6 6 0 0016 11V2H14zM22 2H21V30h2V20h3a2 2 0 002-2V8A5.78 5.78 0 0022 2zm4 16H23V4.09c2.88.56 3 3.54 3 3.91z"
  })), children);
});
var Restaurant24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Restaurant24(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 2H11V12H9z"
  })), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 11a4 4 0 01-8 0V2H4v9a6 6 0 005 5.91V30h2V16.91A6 6 0 0016 11V2H14zM22 2H21V30h2V20h3a2 2 0 002-2V8A5.78 5.78 0 0022 2zm4 16H23V4.09c2.88.56 3 3.54 3 3.91z"
  })), children);
});
var Restaurant20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Restaurant20(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 2H11V12H9z"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 11a4 4 0 01-8 0V2H4v9a6 6 0 005 5.91V30h2V16.91A6 6 0 0016 11V2H14zM22 2H21V30h2V20h3a2 2 0 002-2V8A5.78 5.78 0 0022 2zm4 16H23V4.09c2.88.56 3 3.54 3 3.91z"
  })), children);
});
var Restaurant16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Restaurant16(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 2H11V12H9z"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 11a4 4 0 01-8 0V2H4v9a6 6 0 005 5.91V30h2V16.91A6 6 0 0016 11V2H14zM22 2H21V30h2V20h3a2 2 0 002-2V8A5.78 5.78 0 0022 2zm4 16H23V4.09c2.88.56 3 3.54 3 3.91z"
  })), children);
});
var RestaurantFine32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RestaurantFine32(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 11.0005v-8a1 1 0 00-1-1H19a1 1 0 00-1 1v8A6.0039 6.0039 0 0023 16.91V28H19v2H29V28H25V16.91A6.0039 6.0039 0 0030 11.0005zm-10 0V4h8v7.0005a4 4 0 11-8 0zM12 2v9.02a3.9644 3.9644 0 01-3.96 3.96A4.0052 4.0052 0 014 11.02V2H2v9.02a5.9888 5.9888 0 005 5.8652V30H9V16.8953A5.9646 5.9646 0 0014 11.02V2z"
  })), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 2H9V11.98H7z"
  })), children);
});
var RestaurantFine24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RestaurantFine24(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 11.0005v-8a1 1 0 00-1-1H19a1 1 0 00-1 1v8A6.0039 6.0039 0 0023 16.91V28H19v2H29V28H25V16.91A6.0039 6.0039 0 0030 11.0005zm-10 0V4h8v7.0005a4 4 0 11-8 0zM12 2v9.02a3.9644 3.9644 0 01-3.96 3.96A4.0052 4.0052 0 014 11.02V2H2v9.02a5.9888 5.9888 0 005 5.8652V30H9V16.8953A5.9646 5.9646 0 0014 11.02V2z"
  })), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 2H9V11.98H7z"
  })), children);
});
var RestaurantFine20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RestaurantFine20(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 11.0005v-8a1 1 0 00-1-1H19a1 1 0 00-1 1v8A6.0039 6.0039 0 0023 16.91V28H19v2H29V28H25V16.91A6.0039 6.0039 0 0030 11.0005zm-10 0V4h8v7.0005a4 4 0 11-8 0zM12 2v9.02a3.9644 3.9644 0 01-3.96 3.96A4.0052 4.0052 0 014 11.02V2H2v9.02a5.9888 5.9888 0 005 5.8652V30H9V16.8953A5.9646 5.9646 0 0014 11.02V2z"
  })), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 2H9V11.98H7z"
  })), children);
});
var RestaurantFine16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RestaurantFine16(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 11.0005v-8a1 1 0 00-1-1H19a1 1 0 00-1 1v8A6.0039 6.0039 0 0023 16.91V28H19v2H29V28H25V16.91A6.0039 6.0039 0 0030 11.0005zm-10 0V4h8v7.0005a4 4 0 11-8 0zM12 2v9.02a3.9644 3.9644 0 01-3.96 3.96A4.0052 4.0052 0 014 11.02V2H2v9.02a5.9888 5.9888 0 005 5.8652V30H9V16.8953A5.9646 5.9646 0 0014 11.02V2z"
  })), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 2H9V11.98H7z"
  })), children);
});
var Result32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Result32(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 23H22V25H14zM10 23H12V25H10zM14 18H22V20H14zM10 18H12V20H10zM14 13H22V15H14zM10 13H12V15H10z"
  })), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,5H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H25a2,2,0,0,0,2-2V7A2,2,0,0,0,25,5ZM12,4h8V8H12ZM25,28H7V7h3v3H22V7h3Z"
  })), children);
});
var Result24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Result24(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 23H22V25H14zM10 23H12V25H10zM14 18H22V20H14zM10 18H12V20H10zM14 13H22V15H14zM10 13H12V15H10z"
  })), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,5H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H25a2,2,0,0,0,2-2V7A2,2,0,0,0,25,5ZM12,4h8V8H12ZM25,28H7V7h3v3H22V7h3Z"
  })), children);
});
var Result20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Result20(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 23H22V25H14zM10 23H12V25H10zM14 18H22V20H14zM10 18H12V20H10zM14 13H22V15H14zM10 13H12V15H10z"
  })), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,5H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H25a2,2,0,0,0,2-2V7A2,2,0,0,0,25,5ZM12,4h8V8H12ZM25,28H7V7h3v3H22V7h3Z"
  })), children);
});
var Result16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Result16(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 23H22V25H14zM10 23H12V25H10zM14 18H22V20H14zM10 18H12V20H10zM14 13H22V15H14zM10 13H12V15H10z"
  })), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,5H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H25a2,2,0,0,0,2-2V7A2,2,0,0,0,25,5ZM12,4h8V8H12ZM25,28H7V7h3v3H22V7h3Z"
  })), children);
});
var ResultNew32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResultNew32(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "26",
    r: "4"
  })), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 13H12V15H10zM10 18H12V20H10zM10 23H12V25H10zM14 13H22V15H14zM14 18H22V20H14zM14 23H18V25H14z"
  })), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,28V7h3v3H22V7h3V18h2V7a2,2,0,0,0-2-2H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H18V28ZM12,4h8V8H12Z"
  })), children);
});
var ResultNew24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResultNew24(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "26",
    r: "4"
  })), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 13H12V15H10zM10 18H12V20H10zM10 23H12V25H10zM14 13H22V15H14zM14 18H22V20H14zM14 23H18V25H14z"
  })), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,28V7h3v3H22V7h3V18h2V7a2,2,0,0,0-2-2H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H18V28ZM12,4h8V8H12Z"
  })), children);
});
var ResultNew20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResultNew20(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "26",
    r: "4"
  })), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 13H12V15H10zM10 18H12V20H10zM10 23H12V25H10zM14 13H22V15H14zM14 18H22V20H14zM14 23H18V25H14z"
  })), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,28V7h3v3H22V7h3V18h2V7a2,2,0,0,0-2-2H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H18V28ZM12,4h8V8H12Z"
  })), children);
});
var ResultNew16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResultNew16(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "26",
    r: "4"
  })), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 13H12V15H10zM10 18H12V20H10zM10 23H12V25H10zM14 13H22V15H14zM14 18H22V20H14zM14 23H18V25H14z"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,28V7h3v3H22V7h3V18h2V7a2,2,0,0,0-2-2H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2H18V28ZM12,4h8V8H12Z"
  })), children);
});
var ResultOld32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResultOld32(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 13H12V15H10zM14 13H22V15H14zM10 18H12V20H10zM10 23H12V25H10z"
  })), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,28V7h3v3H22V7h3v8h2V7a2,2,0,0,0-2-2H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2h9V28ZM12,4h8V8H12Z"
  })), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,19v2.4131A6.996,6.996,0,1,1,24,32V30a5,5,0,1,0-4.5762-7H22v2H16V19Z"
  })), children);
});
var ResultOld24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResultOld24(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 13H12V15H10zM14 13H22V15H14zM10 18H12V20H10zM10 23H12V25H10z"
  })), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,28V7h3v3H22V7h3v8h2V7a2,2,0,0,0-2-2H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2h9V28ZM12,4h8V8H12Z"
  })), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,19v2.4131A6.996,6.996,0,1,1,24,32V30a5,5,0,1,0-4.5762-7H22v2H16V19Z"
  })), children);
});
var ResultOld20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResultOld20(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 13H12V15H10zM14 13H22V15H14zM10 18H12V20H10zM10 23H12V25H10z"
  })), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,28V7h3v3H22V7h3v8h2V7a2,2,0,0,0-2-2H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2h9V28ZM12,4h8V8H12Z"
  })), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,19v2.4131A6.996,6.996,0,1,1,24,32V30a5,5,0,1,0-4.5762-7H22v2H16V19Z"
  })), children);
});
var ResultOld16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ResultOld16(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 13H12V15H10zM14 13H22V15H14zM10 18H12V20H10zM10 23H12V25H10z"
  })), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,28V7h3v3H22V7h3v8h2V7a2,2,0,0,0-2-2H22V4a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2V5H7A2,2,0,0,0,5,7V28a2,2,0,0,0,2,2h9V28ZM12,4h8V8H12Z"
  })), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,19v2.4131A6.996,6.996,0,1,1,24,32V30a5,5,0,1,0-4.5762-7H22v2H16V19Z"
  })), children);
});
var RetryFailed32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RetryFailed32(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.41 25L30 21.41 28.59 20 25 23.59 21.41 20 20 21.41 23.59 25 20 28.59 21.41 30 25 26.41 28.59 30 30 28.59 26.41 25zM18 2A12.0351 12.0351 0 006 14v6.2L2.4 16.6 1 18l6 6 6-6-1.4-1.4L8 20.2V14a10 10 0 0120 0v3h2V14A12.0351 12.0351 0 0018 2z"
  })), children);
});
var RetryFailed24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RetryFailed24(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.41 25L30 21.41 28.59 20 25 23.59 21.41 20 20 21.41 23.59 25 20 28.59 21.41 30 25 26.41 28.59 30 30 28.59 26.41 25zM18 2A12.0351 12.0351 0 006 14v6.2L2.4 16.6 1 18l6 6 6-6-1.4-1.4L8 20.2V14a10 10 0 0120 0v3h2V14A12.0351 12.0351 0 0018 2z"
  })), children);
});
var RetryFailed20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RetryFailed20(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.41 25L30 21.41 28.59 20 25 23.59 21.41 20 20 21.41 23.59 25 20 28.59 21.41 30 25 26.41 28.59 30 30 28.59 26.41 25zM18 2A12.0351 12.0351 0 006 14v6.2L2.4 16.6 1 18l6 6 6-6-1.4-1.4L8 20.2V14a10 10 0 0120 0v3h2V14A12.0351 12.0351 0 0018 2z"
  })), children);
});
var RetryFailed16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RetryFailed16(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.41 25L30 21.41 28.59 20 25 23.59 21.41 20 20 21.41 23.59 25 20 28.59 21.41 30 25 26.41 28.59 30 30 28.59 26.41 25zM18 2A12.0351 12.0351 0 006 14v6.2L2.4 16.6 1 18l6 6 6-6-1.4-1.4L8 20.2V14a10 10 0 0120 0v3h2V14A12.0351 12.0351 0 0018 2z"
  })), children);
});
var Review32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Review32(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8L17.912 11.703 22 12.297 19 15 20 19 16 16.75 12 19 13 15 10 12.297 14.2 11.703 16 8z"
  })), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V8a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,8V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V8A3.9988,3.9988,0,0,1,6,4H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var Review24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Review24(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8L17.912 11.703 22 12.297 19 15 20 19 16 16.75 12 19 13 15 10 12.297 14.2 11.703 16 8z"
  })), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V8a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,8V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V8A3.9988,3.9988,0,0,1,6,4H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var Review20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Review20(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8L17.912 11.703 22 12.297 19 15 20 19 16 16.75 12 19 13 15 10 12.297 14.2 11.703 16 8z"
  })), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V8a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,8V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V8A3.9988,3.9988,0,0,1,6,4H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var Review16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Review16(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 8L17.912 11.703 22 12.297 19 15 20 19 16 16.75 12 19 13 15 10 12.297 14.2 11.703 16 8z"
  })), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V8a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,8V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V8A3.9988,3.9988,0,0,1,6,4H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var Rewind_1032 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rewind_1032(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.63 22.13a2.84 2.84 0 01-1.28-.27 2.44 2.44 0 01-.89-.77 3.57 3.57 0 01-.52-1.25 7.69 7.69 0 01-.17-1.68 7.83 7.83 0 01.17-1.68 3.65 3.65 0 01.52-1.25 2.44 2.44 0 01.89-.77 2.84 2.84 0 011.28-.27 2.44 2.44 0 012.16 1 5.23 5.23 0 01.7 2.93 5.23 5.23 0 01-.7 2.93A2.44 2.44 0 0119.63 22.13zm0-1.22a1.07 1.07 0 001-.55A3.38 3.38 0 0021 18.85V17.47a3.31 3.31 0 00-.29-1.5 1.23 1.23 0 00-2.06 0 3.31 3.31 0 00-.29 1.5v1.38a3.38 3.38 0 00.29 1.51A1.06 1.06 0 0019.63 20.91zM10.63 22V20.82h2V15.63l-1.86 1-.55-1.06 2.32-1.3H14v6.5h1.78V22z"
  })), children);
});
var Rewind_1024 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rewind_1024(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.63 22.13a2.84 2.84 0 01-1.28-.27 2.44 2.44 0 01-.89-.77 3.57 3.57 0 01-.52-1.25 7.69 7.69 0 01-.17-1.68 7.83 7.83 0 01.17-1.68 3.65 3.65 0 01.52-1.25 2.44 2.44 0 01.89-.77 2.84 2.84 0 011.28-.27 2.44 2.44 0 012.16 1 5.23 5.23 0 01.7 2.93 5.23 5.23 0 01-.7 2.93A2.44 2.44 0 0119.63 22.13zm0-1.22a1.07 1.07 0 001-.55A3.38 3.38 0 0021 18.85V17.47a3.31 3.31 0 00-.29-1.5 1.23 1.23 0 00-2.06 0 3.31 3.31 0 00-.29 1.5v1.38a3.38 3.38 0 00.29 1.51A1.06 1.06 0 0019.63 20.91zM10.63 22V20.82h2V15.63l-1.86 1-.55-1.06 2.32-1.3H14v6.5h1.78V22z"
  })), children);
});
var Rewind_1020 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rewind_1020(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.63 22.13a2.84 2.84 0 01-1.28-.27 2.44 2.44 0 01-.89-.77 3.57 3.57 0 01-.52-1.25 7.69 7.69 0 01-.17-1.68 7.83 7.83 0 01.17-1.68 3.65 3.65 0 01.52-1.25 2.44 2.44 0 01.89-.77 2.84 2.84 0 011.28-.27 2.44 2.44 0 012.16 1 5.23 5.23 0 01.7 2.93 5.23 5.23 0 01-.7 2.93A2.44 2.44 0 0119.63 22.13zm0-1.22a1.07 1.07 0 001-.55A3.38 3.38 0 0021 18.85V17.47a3.31 3.31 0 00-.29-1.5 1.23 1.23 0 00-2.06 0 3.31 3.31 0 00-.29 1.5v1.38a3.38 3.38 0 00.29 1.51A1.06 1.06 0 0019.63 20.91zM10.63 22V20.82h2V15.63l-1.86 1-.55-1.06 2.32-1.3H14v6.5h1.78V22z"
  })), children);
});
var Rewind_1016 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rewind_1016(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.63 22.13a2.84 2.84 0 01-1.28-.27 2.44 2.44 0 01-.89-.77 3.57 3.57 0 01-.52-1.25 7.69 7.69 0 01-.17-1.68 7.83 7.83 0 01.17-1.68 3.65 3.65 0 01.52-1.25 2.44 2.44 0 01.89-.77 2.84 2.84 0 011.28-.27 2.44 2.44 0 012.16 1 5.23 5.23 0 01.7 2.93 5.23 5.23 0 01-.7 2.93A2.44 2.44 0 0119.63 22.13zm0-1.22a1.07 1.07 0 001-.55A3.38 3.38 0 0021 18.85V17.47a3.31 3.31 0 00-.29-1.5 1.23 1.23 0 00-2.06 0 3.31 3.31 0 00-.29 1.5v1.38a3.38 3.38 0 00.29 1.51A1.06 1.06 0 0019.63 20.91zM10.63 22V20.82h2V15.63l-1.86 1-.55-1.06 2.32-1.3H14v6.5h1.78V22z"
  })), children);
});
var Rewind_3032 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rewind_3032(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.64 22.13a2.81 2.81 0 01-1.28-.27 2.36 2.36 0 01-.89-.77A3.39 3.39 0 0117 19.84a7.12 7.12 0 01-.17-1.68A7.24 7.24 0 0117 16.48a3.46 3.46 0 01.52-1.25 2.36 2.36 0 01.89-.77 2.81 2.81 0 011.28-.27 2.44 2.44 0 012.16 1 5.31 5.31 0 01.7 2.93 5.31 5.31 0 01-.7 2.93A2.44 2.44 0 0119.64 22.13zm0-1.22a1 1 0 001-.55 3.24 3.24 0 00.3-1.51V17.47a3.17 3.17 0 00-.3-1.5 1.22 1.22 0 00-2.05 0 3.18 3.18 0 00-.29 1.5v1.38a3.25 3.25 0 00.29 1.51A1 1 0 0019.64 20.91zM12.62 17.42a1.46 1.46 0 001-.27.84.84 0 00.31-.68v-.08a.94.94 0 00-.3-.74 1.2 1.2 0 00-.83-.27 1.65 1.65 0 00-.89.24 2.1 2.1 0 00-.68.68l-.93-.83a5.37 5.37 0 01.44-.51 2.7 2.7 0 01.54-.4 2.55 2.55 0 01.7-.27 3.25 3.25 0 01.87-.1 3.94 3.94 0 011.06.14 2.33 2.33 0 01.82.4 1.91 1.91 0 01.54.63 1.87 1.87 0 01.18.83 2 2 0 01-.11.67 1.82 1.82 0 01-.32.52 1.79 1.79 0 01-.47.36 2.27 2.27 0 01-.57.2V18a2.34 2.34 0 01.63.21 1.7 1.7 0 01.51.38 1.89 1.89 0 01.34.55 2.07 2.07 0 01.12.73 2 2 0 01-.2.92 2 2 0 01-.58.72 2.66 2.66 0 01-.89.45 3.76 3.76 0 01-1.15.16 4.1 4.1 0 01-1-.11A3.1 3.1 0 0111 21.7a2.76 2.76 0 01-.56-.45A4.22 4.22 0 0110 20.7l1.07-.81a3.07 3.07 0 00.28.42 1.94 1.94 0 00.36.34 1.57 1.57 0 00.45.22 2 2 0 00.57.07 1.45 1.45 0 001-.3 1.12 1.12 0 00.34-.85v-.08a1 1 0 00-.37-.8 1.78 1.78 0 00-1.06-.28h-.76V17.42z"
  })), children);
});
var Rewind_3024 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rewind_3024(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.64 22.13a2.81 2.81 0 01-1.28-.27 2.36 2.36 0 01-.89-.77A3.39 3.39 0 0117 19.84a7.12 7.12 0 01-.17-1.68A7.24 7.24 0 0117 16.48a3.46 3.46 0 01.52-1.25 2.36 2.36 0 01.89-.77 2.81 2.81 0 011.28-.27 2.44 2.44 0 012.16 1 5.31 5.31 0 01.7 2.93 5.31 5.31 0 01-.7 2.93A2.44 2.44 0 0119.64 22.13zm0-1.22a1 1 0 001-.55 3.24 3.24 0 00.3-1.51V17.47a3.17 3.17 0 00-.3-1.5 1.22 1.22 0 00-2.05 0 3.18 3.18 0 00-.29 1.5v1.38a3.25 3.25 0 00.29 1.51A1 1 0 0019.64 20.91zM12.62 17.42a1.46 1.46 0 001-.27.84.84 0 00.31-.68v-.08a.94.94 0 00-.3-.74 1.2 1.2 0 00-.83-.27 1.65 1.65 0 00-.89.24 2.1 2.1 0 00-.68.68l-.93-.83a5.37 5.37 0 01.44-.51 2.7 2.7 0 01.54-.4 2.55 2.55 0 01.7-.27 3.25 3.25 0 01.87-.1 3.94 3.94 0 011.06.14 2.33 2.33 0 01.82.4 1.91 1.91 0 01.54.63 1.87 1.87 0 01.18.83 2 2 0 01-.11.67 1.82 1.82 0 01-.32.52 1.79 1.79 0 01-.47.36 2.27 2.27 0 01-.57.2V18a2.34 2.34 0 01.63.21 1.7 1.7 0 01.51.38 1.89 1.89 0 01.34.55 2.07 2.07 0 01.12.73 2 2 0 01-.2.92 2 2 0 01-.58.72 2.66 2.66 0 01-.89.45 3.76 3.76 0 01-1.15.16 4.1 4.1 0 01-1-.11A3.1 3.1 0 0111 21.7a2.76 2.76 0 01-.56-.45A4.22 4.22 0 0110 20.7l1.07-.81a3.07 3.07 0 00.28.42 1.94 1.94 0 00.36.34 1.57 1.57 0 00.45.22 2 2 0 00.57.07 1.45 1.45 0 001-.3 1.12 1.12 0 00.34-.85v-.08a1 1 0 00-.37-.8 1.78 1.78 0 00-1.06-.28h-.76V17.42z"
  })), children);
});
var Rewind_3020 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rewind_3020(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.64 22.13a2.81 2.81 0 01-1.28-.27 2.36 2.36 0 01-.89-.77A3.39 3.39 0 0117 19.84a7.12 7.12 0 01-.17-1.68A7.24 7.24 0 0117 16.48a3.46 3.46 0 01.52-1.25 2.36 2.36 0 01.89-.77 2.81 2.81 0 011.28-.27 2.44 2.44 0 012.16 1 5.31 5.31 0 01.7 2.93 5.31 5.31 0 01-.7 2.93A2.44 2.44 0 0119.64 22.13zm0-1.22a1 1 0 001-.55 3.24 3.24 0 00.3-1.51V17.47a3.17 3.17 0 00-.3-1.5 1.22 1.22 0 00-2.05 0 3.18 3.18 0 00-.29 1.5v1.38a3.25 3.25 0 00.29 1.51A1 1 0 0019.64 20.91zM12.62 17.42a1.46 1.46 0 001-.27.84.84 0 00.31-.68v-.08a.94.94 0 00-.3-.74 1.2 1.2 0 00-.83-.27 1.65 1.65 0 00-.89.24 2.1 2.1 0 00-.68.68l-.93-.83a5.37 5.37 0 01.44-.51 2.7 2.7 0 01.54-.4 2.55 2.55 0 01.7-.27 3.25 3.25 0 01.87-.1 3.94 3.94 0 011.06.14 2.33 2.33 0 01.82.4 1.91 1.91 0 01.54.63 1.87 1.87 0 01.18.83 2 2 0 01-.11.67 1.82 1.82 0 01-.32.52 1.79 1.79 0 01-.47.36 2.27 2.27 0 01-.57.2V18a2.34 2.34 0 01.63.21 1.7 1.7 0 01.51.38 1.89 1.89 0 01.34.55 2.07 2.07 0 01.12.73 2 2 0 01-.2.92 2 2 0 01-.58.72 2.66 2.66 0 01-.89.45 3.76 3.76 0 01-1.15.16 4.1 4.1 0 01-1-.11A3.1 3.1 0 0111 21.7a2.76 2.76 0 01-.56-.45A4.22 4.22 0 0110 20.7l1.07-.81a3.07 3.07 0 00.28.42 1.94 1.94 0 00.36.34 1.57 1.57 0 00.45.22 2 2 0 00.57.07 1.45 1.45 0 001-.3 1.12 1.12 0 00.34-.85v-.08a1 1 0 00-.37-.8 1.78 1.78 0 00-1.06-.28h-.76V17.42z"
  })), children);
});
var Rewind_3016 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rewind_3016(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.64 22.13a2.81 2.81 0 01-1.28-.27 2.36 2.36 0 01-.89-.77A3.39 3.39 0 0117 19.84a7.12 7.12 0 01-.17-1.68A7.24 7.24 0 0117 16.48a3.46 3.46 0 01.52-1.25 2.36 2.36 0 01.89-.77 2.81 2.81 0 011.28-.27 2.44 2.44 0 012.16 1 5.31 5.31 0 01.7 2.93 5.31 5.31 0 01-.7 2.93A2.44 2.44 0 0119.64 22.13zm0-1.22a1 1 0 001-.55 3.24 3.24 0 00.3-1.51V17.47a3.17 3.17 0 00-.3-1.5 1.22 1.22 0 00-2.05 0 3.18 3.18 0 00-.29 1.5v1.38a3.25 3.25 0 00.29 1.51A1 1 0 0019.64 20.91zM12.62 17.42a1.46 1.46 0 001-.27.84.84 0 00.31-.68v-.08a.94.94 0 00-.3-.74 1.2 1.2 0 00-.83-.27 1.65 1.65 0 00-.89.24 2.1 2.1 0 00-.68.68l-.93-.83a5.37 5.37 0 01.44-.51 2.7 2.7 0 01.54-.4 2.55 2.55 0 01.7-.27 3.25 3.25 0 01.87-.1 3.94 3.94 0 011.06.14 2.33 2.33 0 01.82.4 1.91 1.91 0 01.54.63 1.87 1.87 0 01.18.83 2 2 0 01-.11.67 1.82 1.82 0 01-.32.52 1.79 1.79 0 01-.47.36 2.27 2.27 0 01-.57.2V18a2.34 2.34 0 01.63.21 1.7 1.7 0 01.51.38 1.89 1.89 0 01.34.55 2.07 2.07 0 01.12.73 2 2 0 01-.2.92 2 2 0 01-.58.72 2.66 2.66 0 01-.89.45 3.76 3.76 0 01-1.15.16 4.1 4.1 0 01-1-.11A3.1 3.1 0 0111 21.7a2.76 2.76 0 01-.56-.45A4.22 4.22 0 0110 20.7l1.07-.81a3.07 3.07 0 00.28.42 1.94 1.94 0 00.36.34 1.57 1.57 0 00.45.22 2 2 0 00.57.07 1.45 1.45 0 001-.3 1.12 1.12 0 00.34-.85v-.08a1 1 0 00-.37-.8 1.78 1.78 0 00-1.06-.28h-.76V17.42z"
  })), children);
});
var Rewind_532 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rewind_532(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.58,15.58H15.13L15,18.15H15a4.83,4.83,0,0,1,.26-.45,1.59,1.59,0,0,1,.33-.35,1.53,1.53,0,0,1,.44-.23,2,2,0,0,1,.6-.08,2.54,2.54,0,0,1,.92.16,2.06,2.06,0,0,1,.74.48,2.28,2.28,0,0,1,.5.77,2.73,2.73,0,0,1,.18,1,2.87,2.87,0,0,1-.19,1.07,2.36,2.36,0,0,1-.55.84,2.44,2.44,0,0,1-.89.55,3.23,3.23,0,0,1-1.21.2,3.79,3.79,0,0,1-.94-.11,3,3,0,0,1-.74-.32,2.45,2.45,0,0,1-.55-.45,4.13,4.13,0,0,1-.41-.55l1.06-.81.27.41a1.82,1.82,0,0,0,.34.34,1.59,1.59,0,0,0,.43.22,1.52,1.52,0,0,0,.55.08,1.29,1.29,0,0,0,1-.36,1.41,1.41,0,0,0,.33-1V19.5a1.18,1.18,0,0,0-1.28-1.27,1.44,1.44,0,0,0-.77.18,1.94,1.94,0,0,0-.48.39l-1.19-.17.29-4.31h4.52Z"
  })), children);
});
var Rewind_524 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rewind_524(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.58,15.58H15.13L15,18.15H15a4.83,4.83,0,0,1,.26-.45,1.59,1.59,0,0,1,.33-.35,1.53,1.53,0,0,1,.44-.23,2,2,0,0,1,.6-.08,2.54,2.54,0,0,1,.92.16,2.06,2.06,0,0,1,.74.48,2.28,2.28,0,0,1,.5.77,2.73,2.73,0,0,1,.18,1,2.87,2.87,0,0,1-.19,1.07,2.36,2.36,0,0,1-.55.84,2.44,2.44,0,0,1-.89.55,3.23,3.23,0,0,1-1.21.2,3.79,3.79,0,0,1-.94-.11,3,3,0,0,1-.74-.32,2.45,2.45,0,0,1-.55-.45,4.13,4.13,0,0,1-.41-.55l1.06-.81.27.41a1.82,1.82,0,0,0,.34.34,1.59,1.59,0,0,0,.43.22,1.52,1.52,0,0,0,.55.08,1.29,1.29,0,0,0,1-.36,1.41,1.41,0,0,0,.33-1V19.5a1.18,1.18,0,0,0-1.28-1.27,1.44,1.44,0,0,0-.77.18,1.94,1.94,0,0,0-.48.39l-1.19-.17.29-4.31h4.52Z"
  })), children);
});
var Rewind_520 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rewind_520(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.58,15.58H15.13L15,18.15H15a4.83,4.83,0,0,1,.26-.45,1.59,1.59,0,0,1,.33-.35,1.53,1.53,0,0,1,.44-.23,2,2,0,0,1,.6-.08,2.54,2.54,0,0,1,.92.16,2.06,2.06,0,0,1,.74.48,2.28,2.28,0,0,1,.5.77,2.73,2.73,0,0,1,.18,1,2.87,2.87,0,0,1-.19,1.07,2.36,2.36,0,0,1-.55.84,2.44,2.44,0,0,1-.89.55,3.23,3.23,0,0,1-1.21.2,3.79,3.79,0,0,1-.94-.11,3,3,0,0,1-.74-.32,2.45,2.45,0,0,1-.55-.45,4.13,4.13,0,0,1-.41-.55l1.06-.81.27.41a1.82,1.82,0,0,0,.34.34,1.59,1.59,0,0,0,.43.22,1.52,1.52,0,0,0,.55.08,1.29,1.29,0,0,0,1-.36,1.41,1.41,0,0,0,.33-1V19.5a1.18,1.18,0,0,0-1.28-1.27,1.44,1.44,0,0,0-.77.18,1.94,1.94,0,0,0-.48.39l-1.19-.17.29-4.31h4.52Z"
  })), children);
});
var Rewind_516 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rewind_516(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18A12,12,0,1,0,16,6H12V1L6,7l6,6V8h4A10,10,0,1,1,6,18Z"
  })), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.58,15.58H15.13L15,18.15H15a4.83,4.83,0,0,1,.26-.45,1.59,1.59,0,0,1,.33-.35,1.53,1.53,0,0,1,.44-.23,2,2,0,0,1,.6-.08,2.54,2.54,0,0,1,.92.16,2.06,2.06,0,0,1,.74.48,2.28,2.28,0,0,1,.5.77,2.73,2.73,0,0,1,.18,1,2.87,2.87,0,0,1-.19,1.07,2.36,2.36,0,0,1-.55.84,2.44,2.44,0,0,1-.89.55,3.23,3.23,0,0,1-1.21.2,3.79,3.79,0,0,1-.94-.11,3,3,0,0,1-.74-.32,2.45,2.45,0,0,1-.55-.45,4.13,4.13,0,0,1-.41-.55l1.06-.81.27.41a1.82,1.82,0,0,0,.34.34,1.59,1.59,0,0,0,.43.22,1.52,1.52,0,0,0,.55.08,1.29,1.29,0,0,0,1-.36,1.41,1.41,0,0,0,.33-1V19.5a1.18,1.18,0,0,0-1.28-1.27,1.44,1.44,0,0,0-.77.18,1.94,1.94,0,0,0-.48.39l-1.19-.17.29-4.31h4.52Z"
  })), children);
});
var Road32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Road32(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 13H19V15H13z"
  })), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.4409 8L24.1687 3.45A2.009 2.009 0 0022.2456 2H9.7544A2.0089 2.0089 0 007.8313 3.4507L6.5315 8H4v2H6v7a2.0025 2.0025 0 002 2v3h2V19H22v3h2V19a2.0025 2.0025 0 002-2V10h2V8zM9.7544 4H22.2458l1.4285 5H8.3257zM24 13H22v2h2v2H8V15h2V13H8V11H24zM2 16H4V30H2zM28 16H30V30H28z"
  })), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 21H17V24H15zM15 26H17V30H15z"
  })), children);
});
var Road24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Road24(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 13H19V15H13z"
  })), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.4409 8L24.1687 3.45A2.009 2.009 0 0022.2456 2H9.7544A2.0089 2.0089 0 007.8313 3.4507L6.5315 8H4v2H6v7a2.0025 2.0025 0 002 2v3h2V19H22v3h2V19a2.0025 2.0025 0 002-2V10h2V8zM9.7544 4H22.2458l1.4285 5H8.3257zM24 13H22v2h2v2H8V15h2V13H8V11H24zM2 16H4V30H2zM28 16H30V30H28z"
  })), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 21H17V24H15zM15 26H17V30H15z"
  })), children);
});
var Road20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Road20(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 13H19V15H13z"
  })), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.4409 8L24.1687 3.45A2.009 2.009 0 0022.2456 2H9.7544A2.0089 2.0089 0 007.8313 3.4507L6.5315 8H4v2H6v7a2.0025 2.0025 0 002 2v3h2V19H22v3h2V19a2.0025 2.0025 0 002-2V10h2V8zM9.7544 4H22.2458l1.4285 5H8.3257zM24 13H22v2h2v2H8V15h2V13H8V11H24zM2 16H4V30H2zM28 16H30V30H28z"
  })), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 21H17V24H15zM15 26H17V30H15z"
  })), children);
});
var Road16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Road16(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 13H19V15H13z"
  })), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.4409 8L24.1687 3.45A2.009 2.009 0 0022.2456 2H9.7544A2.0089 2.0089 0 007.8313 3.4507L6.5315 8H4v2H6v7a2.0025 2.0025 0 002 2v3h2V19H22v3h2V19a2.0025 2.0025 0 002-2V10h2V8zM9.7544 4H22.2458l1.4285 5H8.3257zM24 13H22v2h2v2H8V15h2V13H8V11H24zM2 16H4V30H2zM28 16H30V30H28z"
  })), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 21H17V24H15zM15 26H17V30H15z"
  })), children);
});
var RoadWeather32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RoadWeather32(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 31H14v-.228a3.0135 3.0135 0 00-1.9468-2.8091L8.5215 26.6384A3.9034 3.9034 0 016 23H8a1.8946 1.8946 0 001.2236 1.7659L12.7554 26.09A5.0226 5.0226 0 0116 30.772zM30 31H28v-.228a3.0135 3.0135 0 00-1.9468-2.8091l-3.5317-1.3245A3.9034 3.9034 0 0120 23h2a1.8946 1.8946 0 001.2236 1.7659L26.7554 26.09A5.0226 5.0226 0 0130 30.772zM11 13H17V15H11z"
  })), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.4409,8,22.1687,3.45A2.009,2.009,0,0,0,20.2456,2H7.7544A2.0089,2.0089,0,0,0,5.8313,3.4507L4.5315,8H2v2H4v7a2.0025,2.0025,0,0,0,2,2v2H8V19H20v2h2V19a2.0025,2.0025,0,0,0,2-2V10h2V8ZM7.7544,4H20.2458l1.4285,5H6.3257ZM22,13H20v2h2v2H6V15H8V13H6V11H22Z"
  })), children);
});
var RoadWeather24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RoadWeather24(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 31H14v-.228a3.0135 3.0135 0 00-1.9468-2.8091L8.5215 26.6384A3.9034 3.9034 0 016 23H8a1.8946 1.8946 0 001.2236 1.7659L12.7554 26.09A5.0226 5.0226 0 0116 30.772zM30 31H28v-.228a3.0135 3.0135 0 00-1.9468-2.8091l-3.5317-1.3245A3.9034 3.9034 0 0120 23h2a1.8946 1.8946 0 001.2236 1.7659L26.7554 26.09A5.0226 5.0226 0 0130 30.772zM11 13H17V15H11z"
  })), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.4409,8,22.1687,3.45A2.009,2.009,0,0,0,20.2456,2H7.7544A2.0089,2.0089,0,0,0,5.8313,3.4507L4.5315,8H2v2H4v7a2.0025,2.0025,0,0,0,2,2v2H8V19H20v2h2V19a2.0025,2.0025,0,0,0,2-2V10h2V8ZM7.7544,4H20.2458l1.4285,5H6.3257ZM22,13H20v2h2v2H6V15H8V13H6V11H22Z"
  })), children);
});
var RoadWeather20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RoadWeather20(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 31H14v-.228a3.0135 3.0135 0 00-1.9468-2.8091L8.5215 26.6384A3.9034 3.9034 0 016 23H8a1.8946 1.8946 0 001.2236 1.7659L12.7554 26.09A5.0226 5.0226 0 0116 30.772zM30 31H28v-.228a3.0135 3.0135 0 00-1.9468-2.8091l-3.5317-1.3245A3.9034 3.9034 0 0120 23h2a1.8946 1.8946 0 001.2236 1.7659L26.7554 26.09A5.0226 5.0226 0 0130 30.772zM11 13H17V15H11z"
  })), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.4409,8,22.1687,3.45A2.009,2.009,0,0,0,20.2456,2H7.7544A2.0089,2.0089,0,0,0,5.8313,3.4507L4.5315,8H2v2H4v7a2.0025,2.0025,0,0,0,2,2v2H8V19H20v2h2V19a2.0025,2.0025,0,0,0,2-2V10h2V8ZM7.7544,4H20.2458l1.4285,5H6.3257ZM22,13H20v2h2v2H6V15H8V13H6V11H22Z"
  })), children);
});
var RoadWeather16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RoadWeather16(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 31H14v-.228a3.0135 3.0135 0 00-1.9468-2.8091L8.5215 26.6384A3.9034 3.9034 0 016 23H8a1.8946 1.8946 0 001.2236 1.7659L12.7554 26.09A5.0226 5.0226 0 0116 30.772zM30 31H28v-.228a3.0135 3.0135 0 00-1.9468-2.8091l-3.5317-1.3245A3.9034 3.9034 0 0120 23h2a1.8946 1.8946 0 001.2236 1.7659L26.7554 26.09A5.0226 5.0226 0 0130 30.772zM11 13H17V15H11z"
  })), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.4409,8,22.1687,3.45A2.009,2.009,0,0,0,20.2456,2H7.7544A2.0089,2.0089,0,0,0,5.8313,3.4507L4.5315,8H2v2H4v7a2.0025,2.0025,0,0,0,2,2v2H8V19H20v2h2V19a2.0025,2.0025,0,0,0,2-2V10h2V8ZM7.7544,4H20.2458l1.4285,5H6.3257ZM22,13H20v2h2v2H6V15H8V13H6V11H22Z"
  })), children);
});
var Roadmap32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Roadmap32(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 30H4a2.0023 2.0023 0 01-2-2V24a2.0023 2.0023 0 012-2h8a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0112 30zM4 24v4h8V24zM28 20H12a2.0023 2.0023 0 01-2-2V14a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0128 20zM12 14v4H28V14zM16 10H4A2.0023 2.0023 0 012 8V4A2.0023 2.0023 0 014 2H16a2.0023 2.0023 0 012 2V8A2.0023 2.0023 0 0116 10zM4 4V8H16V4z"
  })), children);
});
var Roadmap24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Roadmap24(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 30H4a2.0023 2.0023 0 01-2-2V24a2.0023 2.0023 0 012-2h8a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0112 30zM4 24v4h8V24zM28 20H12a2.0023 2.0023 0 01-2-2V14a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0128 20zM12 14v4H28V14zM16 10H4A2.0023 2.0023 0 012 8V4A2.0023 2.0023 0 014 2H16a2.0023 2.0023 0 012 2V8A2.0023 2.0023 0 0116 10zM4 4V8H16V4z"
  })), children);
});
var Roadmap20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Roadmap20(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 30H4a2.0023 2.0023 0 01-2-2V24a2.0023 2.0023 0 012-2h8a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0112 30zM4 24v4h8V24zM28 20H12a2.0023 2.0023 0 01-2-2V14a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0128 20zM12 14v4H28V14zM16 10H4A2.0023 2.0023 0 012 8V4A2.0023 2.0023 0 014 2H16a2.0023 2.0023 0 012 2V8A2.0023 2.0023 0 0116 10zM4 4V8H16V4z"
  })), children);
});
var Roadmap16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Roadmap16(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 30H4a2.0023 2.0023 0 01-2-2V24a2.0023 2.0023 0 012-2h8a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0112 30zM4 24v4h8V24zM28 20H12a2.0023 2.0023 0 01-2-2V14a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2v4A2.0023 2.0023 0 0128 20zM12 14v4H28V14zM16 10H4A2.0023 2.0023 0 012 8V4A2.0023 2.0023 0 014 2H16a2.0023 2.0023 0 012 2V8A2.0023 2.0023 0 0116 10zM4 4V8H16V4z"
  })), children);
});
var Rocket32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rocket32(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.34 19H17.65V21H6.34z",
    transform: "rotate(-45 11.995 20.002)"
  })), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,30a1,1,0,0,1-.37-.07,1,1,0,0,1-.62-.79l-1-7,2-.28.75,5.27L21,24.52V17a1,1,0,0,1,.29-.71l4.07-4.07A8.94,8.94,0,0,0,28,5.86V4H26.14a8.94,8.94,0,0,0-6.36,2.64l-4.07,4.07A1,1,0,0,1,15,11H7.48L4.87,14.26l5.27.75-.28,2-7-1a1,1,0,0,1-.79-.62,1,1,0,0,1,.15-1l4-5A1,1,0,0,1,7,9h7.59l3.77-3.78A10.92,10.92,0,0,1,26.14,2H28a2,2,0,0,1,2,2V5.86a10.92,10.92,0,0,1-3.22,7.78L23,17.41V25a1,1,0,0,1-.38.78l-5,4A1,1,0,0,1,17,30Z"
  })), children);
});
var Rocket24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rocket24(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.34 19H17.65V21H6.34z",
    transform: "rotate(-45 11.995 20.002)"
  })), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,30a1,1,0,0,1-.37-.07,1,1,0,0,1-.62-.79l-1-7,2-.28.75,5.27L21,24.52V17a1,1,0,0,1,.29-.71l4.07-4.07A8.94,8.94,0,0,0,28,5.86V4H26.14a8.94,8.94,0,0,0-6.36,2.64l-4.07,4.07A1,1,0,0,1,15,11H7.48L4.87,14.26l5.27.75-.28,2-7-1a1,1,0,0,1-.79-.62,1,1,0,0,1,.15-1l4-5A1,1,0,0,1,7,9h7.59l3.77-3.78A10.92,10.92,0,0,1,26.14,2H28a2,2,0,0,1,2,2V5.86a10.92,10.92,0,0,1-3.22,7.78L23,17.41V25a1,1,0,0,1-.38.78l-5,4A1,1,0,0,1,17,30Z"
  })), children);
});
var Rocket20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rocket20(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.34 19H17.65V21H6.34z",
    transform: "rotate(-45 11.995 20.002)"
  })), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,30a1,1,0,0,1-.37-.07,1,1,0,0,1-.62-.79l-1-7,2-.28.75,5.27L21,24.52V17a1,1,0,0,1,.29-.71l4.07-4.07A8.94,8.94,0,0,0,28,5.86V4H26.14a8.94,8.94,0,0,0-6.36,2.64l-4.07,4.07A1,1,0,0,1,15,11H7.48L4.87,14.26l5.27.75-.28,2-7-1a1,1,0,0,1-.79-.62,1,1,0,0,1,.15-1l4-5A1,1,0,0,1,7,9h7.59l3.77-3.78A10.92,10.92,0,0,1,26.14,2H28a2,2,0,0,1,2,2V5.86a10.92,10.92,0,0,1-3.22,7.78L23,17.41V25a1,1,0,0,1-.38.78l-5,4A1,1,0,0,1,17,30Z"
  })), children);
});
var Rocket16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rocket16(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.34 19H17.65V21H6.34z",
    transform: "rotate(-45 11.995 20.002)"
  })), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,30a1,1,0,0,1-.37-.07,1,1,0,0,1-.62-.79l-1-7,2-.28.75,5.27L21,24.52V17a1,1,0,0,1,.29-.71l4.07-4.07A8.94,8.94,0,0,0,28,5.86V4H26.14a8.94,8.94,0,0,0-6.36,2.64l-4.07,4.07A1,1,0,0,1,15,11H7.48L4.87,14.26l5.27.75-.28,2-7-1a1,1,0,0,1-.79-.62,1,1,0,0,1,.15-1l4-5A1,1,0,0,1,7,9h7.59l3.77-3.78A10.92,10.92,0,0,1,26.14,2H28a2,2,0,0,1,2,2V5.86a10.92,10.92,0,0,1-3.22,7.78L23,17.41V25a1,1,0,0,1-.38.78l-5,4A1,1,0,0,1,17,30Z"
  })), children);
});
var Rotate32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rotate32(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.91 26.82l.35 2a12.9 12.9 0 004.24-1.54l-1-1.73A10.88 10.88 0 0117.91 26.82zM24.42 23.07L26 24.35a13 13 0 002.24-3.91l-1.87-.68A11 11 0 0124.42 23.07zM9.5 27.25a12.9 12.9 0 004.24 1.54l.35-2a10.88 10.88 0 01-3.59-1.3zM5.67 19.76l-1.87.68A13 13 0 006 24.35l.32-.26 1.22-1h0a11 11 0 01-1.91-3.31zM29 16a12.85 12.85 0 00-.8-4.44l-1.87.68A11.18 11.18 0 0127 16zM26 7.65a13 13 0 00-20 0V4H4v8h8V10H6.81A11 11 0 0124.42 8.93z"
  })), children);
});
var Rotate24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rotate24(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.91 26.82l.35 2a12.9 12.9 0 004.24-1.54l-1-1.73A10.88 10.88 0 0117.91 26.82zM24.42 23.07L26 24.35a13 13 0 002.24-3.91l-1.87-.68A11 11 0 0124.42 23.07zM9.5 27.25a12.9 12.9 0 004.24 1.54l.35-2a10.88 10.88 0 01-3.59-1.3zM5.67 19.76l-1.87.68A13 13 0 006 24.35l.32-.26 1.22-1h0a11 11 0 01-1.91-3.31zM29 16a12.85 12.85 0 00-.8-4.44l-1.87.68A11.18 11.18 0 0127 16zM26 7.65a13 13 0 00-20 0V4H4v8h8V10H6.81A11 11 0 0124.42 8.93z"
  })), children);
});
var Rotate20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rotate20(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.91 26.82l.35 2a12.9 12.9 0 004.24-1.54l-1-1.73A10.88 10.88 0 0117.91 26.82zM24.42 23.07L26 24.35a13 13 0 002.24-3.91l-1.87-.68A11 11 0 0124.42 23.07zM9.5 27.25a12.9 12.9 0 004.24 1.54l.35-2a10.88 10.88 0 01-3.59-1.3zM5.67 19.76l-1.87.68A13 13 0 006 24.35l.32-.26 1.22-1h0a11 11 0 01-1.91-3.31zM29 16a12.85 12.85 0 00-.8-4.44l-1.87.68A11.18 11.18 0 0127 16zM26 7.65a13 13 0 00-20 0V4H4v8h8V10H6.81A11 11 0 0124.42 8.93z"
  })), children);
});
var Rotate16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rotate16(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.91 26.82l.35 2a12.9 12.9 0 004.24-1.54l-1-1.73A10.88 10.88 0 0117.91 26.82zM24.42 23.07L26 24.35a13 13 0 002.24-3.91l-1.87-.68A11 11 0 0124.42 23.07zM9.5 27.25a12.9 12.9 0 004.24 1.54l.35-2a10.88 10.88 0 01-3.59-1.3zM5.67 19.76l-1.87.68A13 13 0 006 24.35l.32-.26 1.22-1h0a11 11 0 01-1.91-3.31zM29 16a12.85 12.85 0 00-.8-4.44l-1.87.68A11.18 11.18 0 0127 16zM26 7.65a13 13 0 00-20 0V4H4v8h8V10H6.81A11 11 0 0124.42 8.93z"
  })), children);
});
var WatsonHealthRotate_18032 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRotate_18032(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.0913 26.8235l-.3467 1.968a12.8956 12.8956 0 01-4.24-1.5418l1-1.7307A10.9086 10.9086 0 0014.0913 26.8235zM7.5767 23.0682L6.0449 24.3533a12.9811 12.9811 0 01-2.25-3.9112l1.8775-.6834A10.9808 10.9808 0 007.5767 23.0682zM22.4951 27.25a12.8956 12.8956 0 01-4.24 1.5418l-.3467-1.968a10.9086 10.9086 0 003.5869-1.3045zM26.3271 19.7587l1.8775.6834a12.9811 12.9811 0 01-2.2495 3.9112l-.3115-.2614-1.22-1.0237h0a10.9822 10.9822 0 001.9038-3.3093zM13.6616 5.2559c-.1592.0346-.3144.08-.4712.1215-.2131.0562-.4258.1138-.6335.1822-.1643.0547-.325.1167-.4859.1782-.1926.0742-.3835.1509-.57.2349-.1611.0727-.3193.15-.4763.23q-.2677.1363-.5262.2867c-.153.0893-.3046.18-.4531.2758-.1679.1089-.3308.2242-.4922.3413-.1406.1026-.2817.2037-.417.3125-.1616.1294-.3156.2676-.47.4063-.1225.11-.2478.2168-.3652.332-.1668.1636-.3223.3379-.4785.5117A10.9438 10.9438 0 005 16H3A12.9363 12.9363 0 016.05 7.65l-.0047-.0039c.0918-.1094.197-.2061.2925-.3125.1841-.2051.3672-.41.5635-.603.1382-.1358.2856-.2613.43-.3907.1831-.1645.3657-.3286.5581-.4824.1592-.1279.3244-.2466.4895-.3667.1921-.14.3855-.2768.5854-.4062.1743-.1128.3523-.2188.5322-.3238q.3081-.1786.6253-.3408c.1846-.0942.37-.1846.56-.27.2224-.1.449-.1914.678-.2793.1894-.0723.3777-.1455.5713-.209.2463-.0815.498-.1494.7507-.2163.1848-.0493.3674-.1025.5554-.1431.29-.0634.5865-.1074.8833-.1508.159-.023.3145-.0552.4754-.0728A12.9331 12.9331 0 0126 7.7031V4h2v8H20V10h5.1885A10.961 10.961 0 0016 5a11.1114 11.1114 0 00-1.189.0669c-.1362.0146-.268.042-.4026.0615C14.1575 5.165 13.907 5.2026 13.6616 5.2559z"
  })), children);
});
var WatsonHealthRotate_18024 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRotate_18024(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.0913 26.8235l-.3467 1.968a12.8956 12.8956 0 01-4.24-1.5418l1-1.7307A10.9086 10.9086 0 0014.0913 26.8235zM7.5767 23.0682L6.0449 24.3533a12.9811 12.9811 0 01-2.25-3.9112l1.8775-.6834A10.9808 10.9808 0 007.5767 23.0682zM22.4951 27.25a12.8956 12.8956 0 01-4.24 1.5418l-.3467-1.968a10.9086 10.9086 0 003.5869-1.3045zM26.3271 19.7587l1.8775.6834a12.9811 12.9811 0 01-2.2495 3.9112l-.3115-.2614-1.22-1.0237h0a10.9822 10.9822 0 001.9038-3.3093zM13.6616 5.2559c-.1592.0346-.3144.08-.4712.1215-.2131.0562-.4258.1138-.6335.1822-.1643.0547-.325.1167-.4859.1782-.1926.0742-.3835.1509-.57.2349-.1611.0727-.3193.15-.4763.23q-.2677.1363-.5262.2867c-.153.0893-.3046.18-.4531.2758-.1679.1089-.3308.2242-.4922.3413-.1406.1026-.2817.2037-.417.3125-.1616.1294-.3156.2676-.47.4063-.1225.11-.2478.2168-.3652.332-.1668.1636-.3223.3379-.4785.5117A10.9438 10.9438 0 005 16H3A12.9363 12.9363 0 016.05 7.65l-.0047-.0039c.0918-.1094.197-.2061.2925-.3125.1841-.2051.3672-.41.5635-.603.1382-.1358.2856-.2613.43-.3907.1831-.1645.3657-.3286.5581-.4824.1592-.1279.3244-.2466.4895-.3667.1921-.14.3855-.2768.5854-.4062.1743-.1128.3523-.2188.5322-.3238q.3081-.1786.6253-.3408c.1846-.0942.37-.1846.56-.27.2224-.1.449-.1914.678-.2793.1894-.0723.3777-.1455.5713-.209.2463-.0815.498-.1494.7507-.2163.1848-.0493.3674-.1025.5554-.1431.29-.0634.5865-.1074.8833-.1508.159-.023.3145-.0552.4754-.0728A12.9331 12.9331 0 0126 7.7031V4h2v8H20V10h5.1885A10.961 10.961 0 0016 5a11.1114 11.1114 0 00-1.189.0669c-.1362.0146-.268.042-.4026.0615C14.1575 5.165 13.907 5.2026 13.6616 5.2559z"
  })), children);
});
var WatsonHealthRotate_18020 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRotate_18020(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.0913 26.8235l-.3467 1.968a12.8956 12.8956 0 01-4.24-1.5418l1-1.7307A10.9086 10.9086 0 0014.0913 26.8235zM7.5767 23.0682L6.0449 24.3533a12.9811 12.9811 0 01-2.25-3.9112l1.8775-.6834A10.9808 10.9808 0 007.5767 23.0682zM22.4951 27.25a12.8956 12.8956 0 01-4.24 1.5418l-.3467-1.968a10.9086 10.9086 0 003.5869-1.3045zM26.3271 19.7587l1.8775.6834a12.9811 12.9811 0 01-2.2495 3.9112l-.3115-.2614-1.22-1.0237h0a10.9822 10.9822 0 001.9038-3.3093zM13.6616 5.2559c-.1592.0346-.3144.08-.4712.1215-.2131.0562-.4258.1138-.6335.1822-.1643.0547-.325.1167-.4859.1782-.1926.0742-.3835.1509-.57.2349-.1611.0727-.3193.15-.4763.23q-.2677.1363-.5262.2867c-.153.0893-.3046.18-.4531.2758-.1679.1089-.3308.2242-.4922.3413-.1406.1026-.2817.2037-.417.3125-.1616.1294-.3156.2676-.47.4063-.1225.11-.2478.2168-.3652.332-.1668.1636-.3223.3379-.4785.5117A10.9438 10.9438 0 005 16H3A12.9363 12.9363 0 016.05 7.65l-.0047-.0039c.0918-.1094.197-.2061.2925-.3125.1841-.2051.3672-.41.5635-.603.1382-.1358.2856-.2613.43-.3907.1831-.1645.3657-.3286.5581-.4824.1592-.1279.3244-.2466.4895-.3667.1921-.14.3855-.2768.5854-.4062.1743-.1128.3523-.2188.5322-.3238q.3081-.1786.6253-.3408c.1846-.0942.37-.1846.56-.27.2224-.1.449-.1914.678-.2793.1894-.0723.3777-.1455.5713-.209.2463-.0815.498-.1494.7507-.2163.1848-.0493.3674-.1025.5554-.1431.29-.0634.5865-.1074.8833-.1508.159-.023.3145-.0552.4754-.0728A12.9331 12.9331 0 0126 7.7031V4h2v8H20V10h5.1885A10.961 10.961 0 0016 5a11.1114 11.1114 0 00-1.189.0669c-.1362.0146-.268.042-.4026.0615C14.1575 5.165 13.907 5.2026 13.6616 5.2559z"
  })), children);
});
var WatsonHealthRotate_18016 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRotate_18016(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.0913 26.8235l-.3467 1.968a12.8956 12.8956 0 01-4.24-1.5418l1-1.7307A10.9086 10.9086 0 0014.0913 26.8235zM7.5767 23.0682L6.0449 24.3533a12.9811 12.9811 0 01-2.25-3.9112l1.8775-.6834A10.9808 10.9808 0 007.5767 23.0682zM22.4951 27.25a12.8956 12.8956 0 01-4.24 1.5418l-.3467-1.968a10.9086 10.9086 0 003.5869-1.3045zM26.3271 19.7587l1.8775.6834a12.9811 12.9811 0 01-2.2495 3.9112l-.3115-.2614-1.22-1.0237h0a10.9822 10.9822 0 001.9038-3.3093zM13.6616 5.2559c-.1592.0346-.3144.08-.4712.1215-.2131.0562-.4258.1138-.6335.1822-.1643.0547-.325.1167-.4859.1782-.1926.0742-.3835.1509-.57.2349-.1611.0727-.3193.15-.4763.23q-.2677.1363-.5262.2867c-.153.0893-.3046.18-.4531.2758-.1679.1089-.3308.2242-.4922.3413-.1406.1026-.2817.2037-.417.3125-.1616.1294-.3156.2676-.47.4063-.1225.11-.2478.2168-.3652.332-.1668.1636-.3223.3379-.4785.5117A10.9438 10.9438 0 005 16H3A12.9363 12.9363 0 016.05 7.65l-.0047-.0039c.0918-.1094.197-.2061.2925-.3125.1841-.2051.3672-.41.5635-.603.1382-.1358.2856-.2613.43-.3907.1831-.1645.3657-.3286.5581-.4824.1592-.1279.3244-.2466.4895-.3667.1921-.14.3855-.2768.5854-.4062.1743-.1128.3523-.2188.5322-.3238q.3081-.1786.6253-.3408c.1846-.0942.37-.1846.56-.27.2224-.1.449-.1914.678-.2793.1894-.0723.3777-.1455.5713-.209.2463-.0815.498-.1494.7507-.2163.1848-.0493.3674-.1025.5554-.1431.29-.0634.5865-.1074.8833-.1508.159-.023.3145-.0552.4754-.0728A12.9331 12.9331 0 0126 7.7031V4h2v8H20V10h5.1885A10.961 10.961 0 0016 5a11.1114 11.1114 0 00-1.189.0669c-.1362.0146-.268.042-.4026.0615C14.1575 5.165 13.907 5.2026 13.6616 5.2559z"
  })), children);
});
var WatsonHealthRotate_36032 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRotate_36032(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.95,7.65l.0047-.0039c-.0918-.1094-.197-.2061-.2925-.3125-.1841-.2051-.3672-.41-.5635-.603-.1382-.1358-.2856-.2613-.43-.3907-.1831-.1645-.3657-.3286-.5581-.4824-.1592-.1279-.3244-.2466-.4895-.3667-.1921-.14-.3855-.2768-.5854-.4062-.1743-.1128-.3523-.2188-.5322-.3238q-.3081-.1786-.6253-.3408c-.1846-.0942-.37-.1846-.56-.27-.2224-.1-.449-.1914-.678-.2793-.1894-.0723-.3777-.1455-.5713-.209-.2463-.0815-.498-.1494-.7507-.2163-.1848-.0493-.3674-.1025-.5554-.1431-.29-.0634-.5865-.1074-.8833-.1508-.159-.023-.3145-.0552-.4754-.0728A12.9331,12.9331,0,0,0,6,7.7031V4H4v8h8V10H6.8115A10.961,10.961,0,0,1,16,5a11.1114,11.1114,0,0,1,1.189.0669c.1362.0146.268.042.4026.0615.2509.0366.5014.0742.7468.1275.1592.0346.3144.08.4712.1215.2131.0562.4258.1138.6335.1822.1643.0547.325.1167.4859.1782.1926.0742.3835.1509.5705.2349.1611.0727.3193.15.4763.23q.2677.1363.5262.2867c.153.0893.3046.18.4531.2758.1679.1089.3308.2242.4922.3413.1406.1026.2817.2037.417.3125.1616.1294.3156.2676.47.4063.1225.11.2478.2168.3652.332.1668.1636.3223.3379.4785.5117A10.9928,10.9928,0,1,1,5,16H3A13,13,0,1,0,25.95,7.65Z"
  })), children);
});
var WatsonHealthRotate_36024 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRotate_36024(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.95,7.65l.0047-.0039c-.0918-.1094-.197-.2061-.2925-.3125-.1841-.2051-.3672-.41-.5635-.603-.1382-.1358-.2856-.2613-.43-.3907-.1831-.1645-.3657-.3286-.5581-.4824-.1592-.1279-.3244-.2466-.4895-.3667-.1921-.14-.3855-.2768-.5854-.4062-.1743-.1128-.3523-.2188-.5322-.3238q-.3081-.1786-.6253-.3408c-.1846-.0942-.37-.1846-.56-.27-.2224-.1-.449-.1914-.678-.2793-.1894-.0723-.3777-.1455-.5713-.209-.2463-.0815-.498-.1494-.7507-.2163-.1848-.0493-.3674-.1025-.5554-.1431-.29-.0634-.5865-.1074-.8833-.1508-.159-.023-.3145-.0552-.4754-.0728A12.9331,12.9331,0,0,0,6,7.7031V4H4v8h8V10H6.8115A10.961,10.961,0,0,1,16,5a11.1114,11.1114,0,0,1,1.189.0669c.1362.0146.268.042.4026.0615.2509.0366.5014.0742.7468.1275.1592.0346.3144.08.4712.1215.2131.0562.4258.1138.6335.1822.1643.0547.325.1167.4859.1782.1926.0742.3835.1509.5705.2349.1611.0727.3193.15.4763.23q.2677.1363.5262.2867c.153.0893.3046.18.4531.2758.1679.1089.3308.2242.4922.3413.1406.1026.2817.2037.417.3125.1616.1294.3156.2676.47.4063.1225.11.2478.2168.3652.332.1668.1636.3223.3379.4785.5117A10.9928,10.9928,0,1,1,5,16H3A13,13,0,1,0,25.95,7.65Z"
  })), children);
});
var WatsonHealthRotate_36020 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRotate_36020(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.95,7.65l.0047-.0039c-.0918-.1094-.197-.2061-.2925-.3125-.1841-.2051-.3672-.41-.5635-.603-.1382-.1358-.2856-.2613-.43-.3907-.1831-.1645-.3657-.3286-.5581-.4824-.1592-.1279-.3244-.2466-.4895-.3667-.1921-.14-.3855-.2768-.5854-.4062-.1743-.1128-.3523-.2188-.5322-.3238q-.3081-.1786-.6253-.3408c-.1846-.0942-.37-.1846-.56-.27-.2224-.1-.449-.1914-.678-.2793-.1894-.0723-.3777-.1455-.5713-.209-.2463-.0815-.498-.1494-.7507-.2163-.1848-.0493-.3674-.1025-.5554-.1431-.29-.0634-.5865-.1074-.8833-.1508-.159-.023-.3145-.0552-.4754-.0728A12.9331,12.9331,0,0,0,6,7.7031V4H4v8h8V10H6.8115A10.961,10.961,0,0,1,16,5a11.1114,11.1114,0,0,1,1.189.0669c.1362.0146.268.042.4026.0615.2509.0366.5014.0742.7468.1275.1592.0346.3144.08.4712.1215.2131.0562.4258.1138.6335.1822.1643.0547.325.1167.4859.1782.1926.0742.3835.1509.5705.2349.1611.0727.3193.15.4763.23q.2677.1363.5262.2867c.153.0893.3046.18.4531.2758.1679.1089.3308.2242.4922.3413.1406.1026.2817.2037.417.3125.1616.1294.3156.2676.47.4063.1225.11.2478.2168.3652.332.1668.1636.3223.3379.4785.5117A10.9928,10.9928,0,1,1,5,16H3A13,13,0,1,0,25.95,7.65Z"
  })), children);
});
var WatsonHealthRotate_36016 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthRotate_36016(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.95,7.65l.0047-.0039c-.0918-.1094-.197-.2061-.2925-.3125-.1841-.2051-.3672-.41-.5635-.603-.1382-.1358-.2856-.2613-.43-.3907-.1831-.1645-.3657-.3286-.5581-.4824-.1592-.1279-.3244-.2466-.4895-.3667-.1921-.14-.3855-.2768-.5854-.4062-.1743-.1128-.3523-.2188-.5322-.3238q-.3081-.1786-.6253-.3408c-.1846-.0942-.37-.1846-.56-.27-.2224-.1-.449-.1914-.678-.2793-.1894-.0723-.3777-.1455-.5713-.209-.2463-.0815-.498-.1494-.7507-.2163-.1848-.0493-.3674-.1025-.5554-.1431-.29-.0634-.5865-.1074-.8833-.1508-.159-.023-.3145-.0552-.4754-.0728A12.9331,12.9331,0,0,0,6,7.7031V4H4v8h8V10H6.8115A10.961,10.961,0,0,1,16,5a11.1114,11.1114,0,0,1,1.189.0669c.1362.0146.268.042.4026.0615.2509.0366.5014.0742.7468.1275.1592.0346.3144.08.4712.1215.2131.0562.4258.1138.6335.1822.1643.0547.325.1167.4859.1782.1926.0742.3835.1509.5705.2349.1611.0727.3193.15.4763.23q.2677.1363.5262.2867c.153.0893.3046.18.4531.2758.1679.1089.3308.2242.4922.3413.1406.1026.2817.2037.417.3125.1616.1294.3156.2676.47.4063.1225.11.2478.2168.3652.332.1668.1636.3223.3379.4785.5117A10.9928,10.9928,0,1,1,5,16H3A13,13,0,1,0,25.95,7.65Z"
  })), children);
});
var RotateClockwise32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateClockwise32(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H16a2.0023 2.0023 0 01-2-2V16a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0128 30zM16 16V28H28.0012L28 16zM15 2L13.59 3.41 16.17 6H11a7.0078 7.0078 0 00-7 7v5H6V13a5.0057 5.0057 0 015-5h5.17l-2.58 2.59L15 12l5-5z"
  })), children);
});
var RotateClockwise24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateClockwise24(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H16a2.0023 2.0023 0 01-2-2V16a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0128 30zM16 16V28H28.0012L28 16zM15 2L13.59 3.41 16.17 6H11a7.0078 7.0078 0 00-7 7v5H6V13a5.0057 5.0057 0 015-5h5.17l-2.58 2.59L15 12l5-5z"
  })), children);
});
var RotateClockwise20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateClockwise20(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H16a2.0023 2.0023 0 01-2-2V16a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0128 30zM16 16V28H28.0012L28 16zM15 2L13.59 3.41 16.17 6H11a7.0078 7.0078 0 00-7 7v5H6V13a5.0057 5.0057 0 015-5h5.17l-2.58 2.59L15 12l5-5z"
  })), children);
});
var RotateClockwise16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateClockwise16(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H16a2.0023 2.0023 0 01-2-2V16a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0128 30zM16 16V28H28.0012L28 16zM15 2L13.59 3.41 16.17 6H11a7.0078 7.0078 0 00-7 7v5H6V13a5.0057 5.0057 0 015-5h5.17l-2.58 2.59L15 12l5-5z"
  })), children);
});
var RotateClockwiseAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateClockwiseAlt32(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30H4a2.0023 2.0023 0 01-2-2V16a2.0023 2.0023 0 012-2H16a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0116 30zM4 16V28H16.0012L16 16zM30 15l-1.41-1.41L26 16.17V11a7.0078 7.0078 0 00-7-7H14V6h5a5.0057 5.0057 0 015 5v5.17l-2.59-2.58L20 15l5 5z"
  })), children);
});
var RotateClockwiseAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateClockwiseAlt24(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30H4a2.0023 2.0023 0 01-2-2V16a2.0023 2.0023 0 012-2H16a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0116 30zM4 16V28H16.0012L16 16zM30 15l-1.41-1.41L26 16.17V11a7.0078 7.0078 0 00-7-7H14V6h5a5.0057 5.0057 0 015 5v5.17l-2.59-2.58L20 15l5 5z"
  })), children);
});
var RotateClockwiseAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateClockwiseAlt20(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30H4a2.0023 2.0023 0 01-2-2V16a2.0023 2.0023 0 012-2H16a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0116 30zM4 16V28H16.0012L16 16zM30 15l-1.41-1.41L26 16.17V11a7.0078 7.0078 0 00-7-7H14V6h5a5.0057 5.0057 0 015 5v5.17l-2.59-2.58L20 15l5 5z"
  })), children);
});
var RotateClockwiseAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateClockwiseAlt16(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30H4a2.0023 2.0023 0 01-2-2V16a2.0023 2.0023 0 012-2H16a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0116 30zM4 16V28H16.0012L16 16zM30 15l-1.41-1.41L26 16.17V11a7.0078 7.0078 0 00-7-7H14V6h5a5.0057 5.0057 0 015 5v5.17l-2.59-2.58L20 15l5 5z"
  })), children);
});
var RotateClockwiseAltFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateClockwiseAltFilled32(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30H4a2.0023 2.0023 0 01-2-2V16a2.0023 2.0023 0 012-2H16a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0116 30zM30 15l-1.41-1.41L26 16.17V11a7.0078 7.0078 0 00-7-7H14V6h5a5.0057 5.0057 0 015 5v5.17l-2.59-2.58L20 15l5 5z"
  })), children);
});
var RotateClockwiseAltFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateClockwiseAltFilled24(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30H4a2.0023 2.0023 0 01-2-2V16a2.0023 2.0023 0 012-2H16a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0116 30zM30 15l-1.41-1.41L26 16.17V11a7.0078 7.0078 0 00-7-7H14V6h5a5.0057 5.0057 0 015 5v5.17l-2.59-2.58L20 15l5 5z"
  })), children);
});
var RotateClockwiseAltFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateClockwiseAltFilled20(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30H4a2.0023 2.0023 0 01-2-2V16a2.0023 2.0023 0 012-2H16a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0116 30zM30 15l-1.41-1.41L26 16.17V11a7.0078 7.0078 0 00-7-7H14V6h5a5.0057 5.0057 0 015 5v5.17l-2.59-2.58L20 15l5 5z"
  })), children);
});
var RotateClockwiseAltFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateClockwiseAltFilled16(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30H4a2.0023 2.0023 0 01-2-2V16a2.0023 2.0023 0 012-2H16a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0116 30zM30 15l-1.41-1.41L26 16.17V11a7.0078 7.0078 0 00-7-7H14V6h5a5.0057 5.0057 0 015 5v5.17l-2.59-2.58L20 15l5 5z"
  })), children);
});
var RotateClockwiseFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateClockwiseFilled32(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H16a2.0023 2.0023 0 01-2-2V16a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0128 30zM15 2L13.59 3.41 16.17 6H11a7.0078 7.0078 0 00-7 7v5H6V13a5.0057 5.0057 0 015-5h5.17l-2.58 2.59L15 12l5-5z"
  })), children);
});
var RotateClockwiseFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateClockwiseFilled24(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H16a2.0023 2.0023 0 01-2-2V16a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0128 30zM15 2L13.59 3.41 16.17 6H11a7.0078 7.0078 0 00-7 7v5H6V13a5.0057 5.0057 0 015-5h5.17l-2.58 2.59L15 12l5-5z"
  })), children);
});
var RotateClockwiseFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateClockwiseFilled20(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H16a2.0023 2.0023 0 01-2-2V16a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0128 30zM15 2L13.59 3.41 16.17 6H11a7.0078 7.0078 0 00-7 7v5H6V13a5.0057 5.0057 0 015-5h5.17l-2.58 2.59L15 12l5-5z"
  })), children);
});
var RotateClockwiseFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateClockwiseFilled16(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H16a2.0023 2.0023 0 01-2-2V16a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0128 30zM15 2L13.59 3.41 16.17 6H11a7.0078 7.0078 0 00-7 7v5H6V13a5.0057 5.0057 0 015-5h5.17l-2.58 2.59L15 12l5-5z"
  })), children);
});
var RotateCounterclockwise32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateCounterclockwise32(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28V16a2.0023 2.0023 0 012-2H16a2.0023 2.0023 0 012 2V28a2.0023 2.0023 0 01-2 2H4A2.0023 2.0023 0 012 28zM4 16L3.9988 28H16V16zM17 2l1.41 1.41L15.83 6H21a7.0078 7.0078 0 017 7v5H26V13a5.0057 5.0057 0 00-5-5H15.83l2.58 2.59L17 12 12 7z"
  })), children);
});
var RotateCounterclockwise24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateCounterclockwise24(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28V16a2.0023 2.0023 0 012-2H16a2.0023 2.0023 0 012 2V28a2.0023 2.0023 0 01-2 2H4A2.0023 2.0023 0 012 28zM4 16L3.9988 28H16V16zM17 2l1.41 1.41L15.83 6H21a7.0078 7.0078 0 017 7v5H26V13a5.0057 5.0057 0 00-5-5H15.83l2.58 2.59L17 12 12 7z"
  })), children);
});
var RotateCounterclockwise20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateCounterclockwise20(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28V16a2.0023 2.0023 0 012-2H16a2.0023 2.0023 0 012 2V28a2.0023 2.0023 0 01-2 2H4A2.0023 2.0023 0 012 28zM4 16L3.9988 28H16V16zM17 2l1.41 1.41L15.83 6H21a7.0078 7.0078 0 017 7v5H26V13a5.0057 5.0057 0 00-5-5H15.83l2.58 2.59L17 12 12 7z"
  })), children);
});
var RotateCounterclockwise16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateCounterclockwise16(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28V16a2.0023 2.0023 0 012-2H16a2.0023 2.0023 0 012 2V28a2.0023 2.0023 0 01-2 2H4A2.0023 2.0023 0 012 28zM4 16L3.9988 28H16V16zM17 2l1.41 1.41L15.83 6H21a7.0078 7.0078 0 017 7v5H26V13a5.0057 5.0057 0 00-5-5H15.83l2.58 2.59L17 12 12 7z"
  })), children);
});
var RotateCounterclockwiseAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateCounterclockwiseAlt32(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 28V16a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28a2.0023 2.0023 0 01-2 2H16A2.0023 2.0023 0 0114 28zm2-12l-.0012 12H28V16zM2 15l1.41-1.41L6 16.17V11a7.0078 7.0078 0 017-7h5V6H13a5.0057 5.0057 0 00-5 5v5.17l2.59-2.58L12 15 7 20z"
  })), children);
});
var RotateCounterclockwiseAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateCounterclockwiseAlt24(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 28V16a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28a2.0023 2.0023 0 01-2 2H16A2.0023 2.0023 0 0114 28zm2-12l-.0012 12H28V16zM2 15l1.41-1.41L6 16.17V11a7.0078 7.0078 0 017-7h5V6H13a5.0057 5.0057 0 00-5 5v5.17l2.59-2.58L12 15 7 20z"
  })), children);
});
var RotateCounterclockwiseAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateCounterclockwiseAlt20(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 28V16a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28a2.0023 2.0023 0 01-2 2H16A2.0023 2.0023 0 0114 28zm2-12l-.0012 12H28V16zM2 15l1.41-1.41L6 16.17V11a7.0078 7.0078 0 017-7h5V6H13a5.0057 5.0057 0 00-5 5v5.17l2.59-2.58L12 15 7 20z"
  })), children);
});
var RotateCounterclockwiseAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateCounterclockwiseAlt16(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 28V16a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28a2.0023 2.0023 0 01-2 2H16A2.0023 2.0023 0 0114 28zm2-12l-.0012 12H28V16zM2 15l1.41-1.41L6 16.17V11a7.0078 7.0078 0 017-7h5V6H13a5.0057 5.0057 0 00-5 5v5.17l2.59-2.58L12 15 7 20z"
  })), children);
});
var RotateCounterclockwiseAltFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateCounterclockwiseAltFilled32(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 28V16a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28a2.0023 2.0023 0 01-2 2H16A2.0023 2.0023 0 0114 28zM2 15l1.41-1.41L6 16.17V11a7.0078 7.0078 0 017-7h5V6H13a5.0057 5.0057 0 00-5 5v5.17l2.59-2.58L12 15 7 20z"
  })), children);
});
var RotateCounterclockwiseAltFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateCounterclockwiseAltFilled24(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 28V16a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28a2.0023 2.0023 0 01-2 2H16A2.0023 2.0023 0 0114 28zM2 15l1.41-1.41L6 16.17V11a7.0078 7.0078 0 017-7h5V6H13a5.0057 5.0057 0 00-5 5v5.17l2.59-2.58L12 15 7 20z"
  })), children);
});
var RotateCounterclockwiseAltFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateCounterclockwiseAltFilled20(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 28V16a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28a2.0023 2.0023 0 01-2 2H16A2.0023 2.0023 0 0114 28zM2 15l1.41-1.41L6 16.17V11a7.0078 7.0078 0 017-7h5V6H13a5.0057 5.0057 0 00-5 5v5.17l2.59-2.58L12 15 7 20z"
  })), children);
});
var RotateCounterclockwiseAltFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateCounterclockwiseAltFilled16(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 28V16a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28a2.0023 2.0023 0 01-2 2H16A2.0023 2.0023 0 0114 28zM2 15l1.41-1.41L6 16.17V11a7.0078 7.0078 0 017-7h5V6H13a5.0057 5.0057 0 00-5 5v5.17l2.59-2.58L12 15 7 20z"
  })), children);
});
var RotateCounterclockwiseFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateCounterclockwiseFilled32(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28V16a2.0023 2.0023 0 012-2H16a2.0023 2.0023 0 012 2V28a2.0023 2.0023 0 01-2 2H4A2.0023 2.0023 0 012 28zM17 2l1.41 1.41L15.83 6H21a7.0078 7.0078 0 017 7v5H26V13a5.0057 5.0057 0 00-5-5H15.83l2.58 2.59L17 12 12 7z"
  })), children);
});
var RotateCounterclockwiseFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateCounterclockwiseFilled24(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28V16a2.0023 2.0023 0 012-2H16a2.0023 2.0023 0 012 2V28a2.0023 2.0023 0 01-2 2H4A2.0023 2.0023 0 012 28zM17 2l1.41 1.41L15.83 6H21a7.0078 7.0078 0 017 7v5H26V13a5.0057 5.0057 0 00-5-5H15.83l2.58 2.59L17 12 12 7z"
  })), children);
});
var RotateCounterclockwiseFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateCounterclockwiseFilled20(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28V16a2.0023 2.0023 0 012-2H16a2.0023 2.0023 0 012 2V28a2.0023 2.0023 0 01-2 2H4A2.0023 2.0023 0 012 28zM17 2l1.41 1.41L15.83 6H21a7.0078 7.0078 0 017 7v5H26V13a5.0057 5.0057 0 00-5-5H15.83l2.58 2.59L17 12 12 7z"
  })), children);
});
var RotateCounterclockwiseFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RotateCounterclockwiseFilled16(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28V16a2.0023 2.0023 0 012-2H16a2.0023 2.0023 0 012 2V28a2.0023 2.0023 0 01-2 2H4A2.0023 2.0023 0 012 28zM17 2l1.41 1.41L15.83 6H21a7.0078 7.0078 0 017 7v5H26V13a5.0057 5.0057 0 00-5-5H15.83l2.58 2.59L17 12 12 7z"
  })), children);
});
var Router32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Router32(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 7L16 2 11 7 12.409 8.419 15 5.847 15 13 17 13 17 5.794 19.591 8.419 21 7zM21 25L16 30 11 25 12.409 23.581 15 26.153 15 19 17 19 17 26.206 19.591 23.581 21 25zM24 11L19 16 24 21 25.419 19.591 22.847 17 30 17 30 15 22.794 15 25.419 12.409 24 11zM8 11L13 16 8 21 6.581 19.591 9.153 17 2 17 2 15 9.206 15 6.581 12.409 8 11z"
  })), children);
});
var Router24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Router24(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 7L16 2 11 7 12.409 8.419 15 5.847 15 13 17 13 17 5.794 19.591 8.419 21 7zM21 25L16 30 11 25 12.409 23.581 15 26.153 15 19 17 19 17 26.206 19.591 23.581 21 25zM24 11L19 16 24 21 25.419 19.591 22.847 17 30 17 30 15 22.794 15 25.419 12.409 24 11zM8 11L13 16 8 21 6.581 19.591 9.153 17 2 17 2 15 9.206 15 6.581 12.409 8 11z"
  })), children);
});
var Router20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Router20(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 7L16 2 11 7 12.409 8.419 15 5.847 15 13 17 13 17 5.794 19.591 8.419 21 7zM21 25L16 30 11 25 12.409 23.581 15 26.153 15 19 17 19 17 26.206 19.591 23.581 21 25zM24 11L19 16 24 21 25.419 19.591 22.847 17 30 17 30 15 22.794 15 25.419 12.409 24 11zM8 11L13 16 8 21 6.581 19.591 9.153 17 2 17 2 15 9.206 15 6.581 12.409 8 11z"
  })), children);
});
var Router16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Router16(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 7L16 2 11 7 12.409 8.419 15 5.847 15 13 17 13 17 5.794 19.591 8.419 21 7zM21 25L16 30 11 25 12.409 23.581 15 26.153 15 19 17 19 17 26.206 19.591 23.581 21 25zM24 11L19 16 24 21 25.419 19.591 22.847 17 30 17 30 15 22.794 15 25.419 12.409 24 11zM8 11L13 16 8 21 6.581 19.591 9.153 17 2 17 2 15 9.206 15 6.581 12.409 8 11z"
  })), children);
});
var RouterVoice32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RouterVoice32(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 25L16 30 11 25 12.409 23.581 15 26.153 15 19 17 19 17 26.206 19.591 23.581 21 25zM24 11L19 16 24 21 25.419 19.591 22.847 17 30 17 30 15 22.794 15 25.419 12.409 24 11zM8 11L13 16 8 21 6.581 19.591 9.153 17 2 17 2 15 9.206 15 6.581 12.409 8 11zM12.4289 5.8227v1.63a1.1269 1.1269 0 01-.6767 1.026l-1.39.5967A1.1218 1.1218 0 019.14 8.8424L7.3208 7.0233a1.1165 1.1165 0 01.0125-1.579l.0348-.0328c7.393-6.527 14.6913-2.0374 17.2127-.0473a1.1166 1.1166 0 01.1746 1.5693 1.1011 1.1011 0 01-.0873.0971L22.9108 8.7878a1.1114 1.1114 0 01-1.2225.2329l-1.39-.5967a1.1112 1.1112 0 01-.68-1.0223v-1.63S15.9726 3.0648 12.4289 5.8227z"
  })), children);
});
var RouterVoice24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RouterVoice24(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 25L16 30 11 25 12.409 23.581 15 26.153 15 19 17 19 17 26.206 19.591 23.581 21 25zM24 11L19 16 24 21 25.419 19.591 22.847 17 30 17 30 15 22.794 15 25.419 12.409 24 11zM8 11L13 16 8 21 6.581 19.591 9.153 17 2 17 2 15 9.206 15 6.581 12.409 8 11zM12.4289 5.8227v1.63a1.1269 1.1269 0 01-.6767 1.026l-1.39.5967A1.1218 1.1218 0 019.14 8.8424L7.3208 7.0233a1.1165 1.1165 0 01.0125-1.579l.0348-.0328c7.393-6.527 14.6913-2.0374 17.2127-.0473a1.1166 1.1166 0 01.1746 1.5693 1.1011 1.1011 0 01-.0873.0971L22.9108 8.7878a1.1114 1.1114 0 01-1.2225.2329l-1.39-.5967a1.1112 1.1112 0 01-.68-1.0223v-1.63S15.9726 3.0648 12.4289 5.8227z"
  })), children);
});
var RouterVoice20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RouterVoice20(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 25L16 30 11 25 12.409 23.581 15 26.153 15 19 17 19 17 26.206 19.591 23.581 21 25zM24 11L19 16 24 21 25.419 19.591 22.847 17 30 17 30 15 22.794 15 25.419 12.409 24 11zM8 11L13 16 8 21 6.581 19.591 9.153 17 2 17 2 15 9.206 15 6.581 12.409 8 11zM12.4289 5.8227v1.63a1.1269 1.1269 0 01-.6767 1.026l-1.39.5967A1.1218 1.1218 0 019.14 8.8424L7.3208 7.0233a1.1165 1.1165 0 01.0125-1.579l.0348-.0328c7.393-6.527 14.6913-2.0374 17.2127-.0473a1.1166 1.1166 0 01.1746 1.5693 1.1011 1.1011 0 01-.0873.0971L22.9108 8.7878a1.1114 1.1114 0 01-1.2225.2329l-1.39-.5967a1.1112 1.1112 0 01-.68-1.0223v-1.63S15.9726 3.0648 12.4289 5.8227z"
  })), children);
});
var RouterVoice16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RouterVoice16(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 25L16 30 11 25 12.409 23.581 15 26.153 15 19 17 19 17 26.206 19.591 23.581 21 25zM24 11L19 16 24 21 25.419 19.591 22.847 17 30 17 30 15 22.794 15 25.419 12.409 24 11zM8 11L13 16 8 21 6.581 19.591 9.153 17 2 17 2 15 9.206 15 6.581 12.409 8 11zM12.4289 5.8227v1.63a1.1269 1.1269 0 01-.6767 1.026l-1.39.5967A1.1218 1.1218 0 019.14 8.8424L7.3208 7.0233a1.1165 1.1165 0 01.0125-1.579l.0348-.0328c7.393-6.527 14.6913-2.0374 17.2127-.0473a1.1166 1.1166 0 01.1746 1.5693 1.1011 1.1011 0 01-.0873.0971L22.9108 8.7878a1.1114 1.1114 0 01-1.2225.2329l-1.39-.5967a1.1112 1.1112 0 01-.68-1.0223v-1.63S15.9726 3.0648 12.4289 5.8227z"
  })), children);
});
var RouterWifi32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RouterWifi32(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "13.5",
    r: "1.5"
  })), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.5356,10.4648a5,5,0,0,0-7.0717,0L11.05,9.0508a6.9992,6.9992,0,0,1,9.9,0Z"
  })), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.0713 6.929a10 10 0 00-14.1426 0L7.5146 5.5144a12.0011 12.0011 0 0116.9708 0zM21 25L16 30 11 25 12.409 23.581 15 26.153 15 19 17 19 17 26.206 19.591 23.581 21 25zM24 11L19 16 24 21 25.419 19.591 22.847 17 30 17 30 15 22.794 15 25.419 12.409 24 11zM8 11L13 16 8 21 6.581 19.591 9.153 17 2 17 2 15 9.206 15 6.581 12.409 8 11z"
  })), children);
});
var RouterWifi24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RouterWifi24(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "13.5",
    r: "1.5"
  })), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.5356,10.4648a5,5,0,0,0-7.0717,0L11.05,9.0508a6.9992,6.9992,0,0,1,9.9,0Z"
  })), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.0713 6.929a10 10 0 00-14.1426 0L7.5146 5.5144a12.0011 12.0011 0 0116.9708 0zM21 25L16 30 11 25 12.409 23.581 15 26.153 15 19 17 19 17 26.206 19.591 23.581 21 25zM24 11L19 16 24 21 25.419 19.591 22.847 17 30 17 30 15 22.794 15 25.419 12.409 24 11zM8 11L13 16 8 21 6.581 19.591 9.153 17 2 17 2 15 9.206 15 6.581 12.409 8 11z"
  })), children);
});
var RouterWifi20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RouterWifi20(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "13.5",
    r: "1.5"
  })), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.5356,10.4648a5,5,0,0,0-7.0717,0L11.05,9.0508a6.9992,6.9992,0,0,1,9.9,0Z"
  })), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.0713 6.929a10 10 0 00-14.1426 0L7.5146 5.5144a12.0011 12.0011 0 0116.9708 0zM21 25L16 30 11 25 12.409 23.581 15 26.153 15 19 17 19 17 26.206 19.591 23.581 21 25zM24 11L19 16 24 21 25.419 19.591 22.847 17 30 17 30 15 22.794 15 25.419 12.409 24 11zM8 11L13 16 8 21 6.581 19.591 9.153 17 2 17 2 15 9.206 15 6.581 12.409 8 11z"
  })), children);
});
var RouterWifi16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RouterWifi16(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "13.5",
    r: "1.5"
  })), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.5356,10.4648a5,5,0,0,0-7.0717,0L11.05,9.0508a6.9992,6.9992,0,0,1,9.9,0Z"
  })), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.0713 6.929a10 10 0 00-14.1426 0L7.5146 5.5144a12.0011 12.0011 0 0116.9708 0zM21 25L16 30 11 25 12.409 23.581 15 26.153 15 19 17 19 17 26.206 19.591 23.581 21 25zM24 11L19 16 24 21 25.419 19.591 22.847 17 30 17 30 15 22.794 15 25.419 12.409 24 11zM8 11L13 16 8 21 6.581 19.591 9.153 17 2 17 2 15 9.206 15 6.581 12.409 8 11z"
  })), children);
});
var Row32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Row32(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 24H28V26H4zM26 18H6V14H26v4m2 0V14a2 2 0 00-2-2H6a2 2 0 00-2 2v4a2 2 0 002 2H26a2 2 0 002-2zM4 6H28V8H4z"
  })), children);
});
var Row24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Row24(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 24H28V26H4zM26 18H6V14H26v4m2 0V14a2 2 0 00-2-2H6a2 2 0 00-2 2v4a2 2 0 002 2H26a2 2 0 002-2zM4 6H28V8H4z"
  })), children);
});
var Row20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Row20(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 24H28V26H4zM26 18H6V14H26v4m2 0V14a2 2 0 00-2-2H6a2 2 0 00-2 2v4a2 2 0 002 2H26a2 2 0 002-2zM4 6H28V8H4z"
  })), children);
});
var Row16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Row16(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 24H28V26H4zM26 18H6V14H26v4m2 0V14a2 2 0 00-2-2H6a2 2 0 00-2 2v4a2 2 0 002 2H26a2 2 0 002-2zM4 6H28V8H4z"
  })), children);
});
var RowCollapse32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RowCollapse32(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 20H6a2 2 0 00-2 2v4a2 2 0 002 2H26a2 2 0 002-2V22A2 2 0 0026 20zm0 6H6V22H26zM17 7.828L19.586 10.414 21 9 16 4 11 9 12.414 10.414 15 7.828 15 14 4 14 4 16 28 16 28 14 17 14 17 7.828z"
  })), children);
});
var RowCollapse24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RowCollapse24(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 20H6a2 2 0 00-2 2v4a2 2 0 002 2H26a2 2 0 002-2V22A2 2 0 0026 20zm0 6H6V22H26zM17 7.828L19.586 10.414 21 9 16 4 11 9 12.414 10.414 15 7.828 15 14 4 14 4 16 28 16 28 14 17 14 17 7.828z"
  })), children);
});
var RowCollapse20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RowCollapse20(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 20H6a2 2 0 00-2 2v4a2 2 0 002 2H26a2 2 0 002-2V22A2 2 0 0026 20zm0 6H6V22H26zM17 7.828L19.586 10.414 21 9 16 4 11 9 12.414 10.414 15 7.828 15 14 4 14 4 16 28 16 28 14 17 14 17 7.828z"
  })), children);
});
var RowCollapse16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RowCollapse16(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 20H6a2 2 0 00-2 2v4a2 2 0 002 2H26a2 2 0 002-2V22A2 2 0 0026 20zm0 6H6V22H26zM17 7.828L19.586 10.414 21 9 16 4 11 9 12.414 10.414 15 7.828 15 14 4 14 4 16 28 16 28 14 17 14 17 7.828z"
  })), children);
});
var RowDelete32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RowDelete32(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30H4a2.0021 2.0021 0 01-2-2V22a2.0021 2.0021 0 012-2H24a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0124 30zM4 22H3.9985L4 28H24V22zM30 3.41L28.59 2 25 5.59 21.41 2 20 3.41 23.59 7 20 10.59 21.41 12 25 8.41 28.59 12 30 10.59 26.41 7 30 3.41z"
  })), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,14V8H18V6H4A2.0023,2.0023,0,0,0,2,8v6a2.0023,2.0023,0,0,0,2,2H26V14Z"
  })), children);
});
var RowDelete24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RowDelete24(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30H4a2.0021 2.0021 0 01-2-2V22a2.0021 2.0021 0 012-2H24a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0124 30zM4 22H3.9985L4 28H24V22zM30 3.41L28.59 2 25 5.59 21.41 2 20 3.41 23.59 7 20 10.59 21.41 12 25 8.41 28.59 12 30 10.59 26.41 7 30 3.41z"
  })), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,14V8H18V6H4A2.0023,2.0023,0,0,0,2,8v6a2.0023,2.0023,0,0,0,2,2H26V14Z"
  })), children);
});
var RowDelete20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RowDelete20(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30H4a2.0021 2.0021 0 01-2-2V22a2.0021 2.0021 0 012-2H24a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0124 30zM4 22H3.9985L4 28H24V22zM30 3.41L28.59 2 25 5.59 21.41 2 20 3.41 23.59 7 20 10.59 21.41 12 25 8.41 28.59 12 30 10.59 26.41 7 30 3.41z"
  })), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,14V8H18V6H4A2.0023,2.0023,0,0,0,2,8v6a2.0023,2.0023,0,0,0,2,2H26V14Z"
  })), children);
});
var RowDelete16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RowDelete16(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30H4a2.0021 2.0021 0 01-2-2V22a2.0021 2.0021 0 012-2H24a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0124 30zM4 22H3.9985L4 28H24V22zM30 3.41L28.59 2 25 5.59 21.41 2 20 3.41 23.59 7 20 10.59 21.41 12 25 8.41 28.59 12 30 10.59 26.41 7 30 3.41z"
  })), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,14V8H18V6H4A2.0023,2.0023,0,0,0,2,8v6a2.0023,2.0023,0,0,0,2,2H26V14Z"
  })), children);
});
var RowExpand32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RowExpand32(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 18L15 18 15 24.172 12.414 21.586 11 23 16 28 21 23 19.586 21.586 17 24.172 17 18 28 18 28 16 4 16 4 18zM26 4H6A2 2 0 004 6v4a2 2 0 002 2H26a2 2 0 002-2V6A2 2 0 0026 4zm0 6H6V6H26z"
  })), children);
});
var RowExpand24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RowExpand24(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 18L15 18 15 24.172 12.414 21.586 11 23 16 28 21 23 19.586 21.586 17 24.172 17 18 28 18 28 16 4 16 4 18zM26 4H6A2 2 0 004 6v4a2 2 0 002 2H26a2 2 0 002-2V6A2 2 0 0026 4zm0 6H6V6H26z"
  })), children);
});
var RowExpand20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RowExpand20(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 18L15 18 15 24.172 12.414 21.586 11 23 16 28 21 23 19.586 21.586 17 24.172 17 18 28 18 28 16 4 16 4 18zM26 4H6A2 2 0 004 6v4a2 2 0 002 2H26a2 2 0 002-2V6A2 2 0 0026 4zm0 6H6V6H26z"
  })), children);
});
var RowExpand16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RowExpand16(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 18L15 18 15 24.172 12.414 21.586 11 23 16 28 21 23 19.586 21.586 17 24.172 17 18 28 18 28 16 4 16 4 18zM26 4H6A2 2 0 004 6v4a2 2 0 002 2H26a2 2 0 002-2V6A2 2 0 0026 4zm0 6H6V6H26z"
  })), children);
});
var RowInsert32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RowInsert32(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 12H10a2.0021 2.0021 0 01-2-2V4a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0128 12zM10 4v6H28V4zM28 30H10a2.0021 2.0021 0 01-2-2V22a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0128 30zM10 22v6H28V22zM9 16L3.414 10.414 2 11.828 6.172 16 2 20.172 3.414 21.586 9 16z"
  })), children);
});
var RowInsert24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RowInsert24(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 12H10a2.0021 2.0021 0 01-2-2V4a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0128 12zM10 4v6H28V4zM28 30H10a2.0021 2.0021 0 01-2-2V22a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0128 30zM10 22v6H28V22zM9 16L3.414 10.414 2 11.828 6.172 16 2 20.172 3.414 21.586 9 16z"
  })), children);
});
var RowInsert20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RowInsert20(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 12H10a2.0021 2.0021 0 01-2-2V4a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0128 12zM10 4v6H28V4zM28 30H10a2.0021 2.0021 0 01-2-2V22a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0128 30zM10 22v6H28V22zM9 16L3.414 10.414 2 11.828 6.172 16 2 20.172 3.414 21.586 9 16z"
  })), children);
});
var RowInsert16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RowInsert16(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 12H10a2.0021 2.0021 0 01-2-2V4a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0128 12zM10 4v6H28V4zM28 30H10a2.0021 2.0021 0 01-2-2V22a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0128 30zM10 22v6H28V22zM9 16L3.414 10.414 2 11.828 6.172 16 2 20.172 3.414 21.586 9 16z"
  })), children);
});
var Rss32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rss32(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 18c-3.3 0-6 2.7-6 6s2.7 6 6 6 6-2.7 6-6C14 20.7 11.3 18 8 18zM8 28c-2.2 0-4-1.8-4-4s1.8-4 4-4 4 1.8 4 4C12 26.2 10.2 28 8 28zM30 24h-2C28 13 19 4 8 4V2C20.1 2 30 11.9 30 24z"
  })), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,24h-2c0-6.6-5.4-12-12-12v-2C15.7,10,22,16.3,22,24z"
  })), children);
});
var Rss24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rss24(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 18c-3.3 0-6 2.7-6 6s2.7 6 6 6 6-2.7 6-6C14 20.7 11.3 18 8 18zM8 28c-2.2 0-4-1.8-4-4s1.8-4 4-4 4 1.8 4 4C12 26.2 10.2 28 8 28zM30 24h-2C28 13 19 4 8 4V2C20.1 2 30 11.9 30 24z"
  })), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,24h-2c0-6.6-5.4-12-12-12v-2C15.7,10,22,16.3,22,24z"
  })), children);
});
var Rss20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rss20(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 18c-3.3 0-6 2.7-6 6s2.7 6 6 6 6-2.7 6-6C14 20.7 11.3 18 8 18zM8 28c-2.2 0-4-1.8-4-4s1.8-4 4-4 4 1.8 4 4C12 26.2 10.2 28 8 28zM30 24h-2C28 13 19 4 8 4V2C20.1 2 30 11.9 30 24z"
  })), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,24h-2c0-6.6-5.4-12-12-12v-2C15.7,10,22,16.3,22,24z"
  })), children);
});
var Rss16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rss16(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 18c-3.3 0-6 2.7-6 6s2.7 6 6 6 6-2.7 6-6C14 20.7 11.3 18 8 18zM8 28c-2.2 0-4-1.8-4-4s1.8-4 4-4 4 1.8 4 4C12 26.2 10.2 28 8 28zM30 24h-2C28 13 19 4 8 4V2C20.1 2 30 11.9 30 24z"
  })), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,24h-2c0-6.6-5.4-12-12-12v-2C15.7,10,22,16.3,22,24z"
  })), children);
});
var Rule32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rule32(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16H22V18H10zM10 10H22V12H10z"
  })), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,9.8242,26.7071A10.9815,10.9815,0,0,1,4,17V4A2.0022,2.0022,0,0,1,6,2H26a2.0022,2.0022,0,0,1,2,2V17a10.9815,10.9815,0,0,1-5.8242,9.7069ZM6,4V17a8.9852,8.9852,0,0,0,4.7656,7.9423L16,27.7333l5.2344-2.791A8.9852,8.9852,0,0,0,26,17V4Z"
  })), children);
});
var Rule24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rule24(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16H22V18H10zM10 10H22V12H10z"
  })), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,9.8242,26.7071A10.9815,10.9815,0,0,1,4,17V4A2.0022,2.0022,0,0,1,6,2H26a2.0022,2.0022,0,0,1,2,2V17a10.9815,10.9815,0,0,1-5.8242,9.7069ZM6,4V17a8.9852,8.9852,0,0,0,4.7656,7.9423L16,27.7333l5.2344-2.791A8.9852,8.9852,0,0,0,26,17V4Z"
  })), children);
});
var Rule20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rule20(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16H22V18H10zM10 10H22V12H10z"
  })), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,9.8242,26.7071A10.9815,10.9815,0,0,1,4,17V4A2.0022,2.0022,0,0,1,6,2H26a2.0022,2.0022,0,0,1,2,2V17a10.9815,10.9815,0,0,1-5.8242,9.7069ZM6,4V17a8.9852,8.9852,0,0,0,4.7656,7.9423L16,27.7333l5.2344-2.791A8.9852,8.9852,0,0,0,26,17V4Z"
  })), children);
});
var Rule16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Rule16(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16H22V18H10zM10 10H22V12H10z"
  })), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,9.8242,26.7071A10.9815,10.9815,0,0,1,4,17V4A2.0022,2.0022,0,0,1,6,2H26a2.0022,2.0022,0,0,1,2,2V17a10.9815,10.9815,0,0,1-5.8242,9.7069ZM6,4V17a8.9852,8.9852,0,0,0,4.7656,7.9423L16,27.7333l5.2344-2.791A8.9852,8.9852,0,0,0,26,17V4Z"
  })), children);
});
var RuleCancelled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RuleCancelled32(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 24a6 6 0 10-6 6A6.0066 6.0066 0 0030 24zm-2 0a3.9521 3.9521 0 01-.5669 2.019L21.981 20.5669A3.9529 3.9529 0 0124 20 4.0045 4.0045 0 0128 24zm-8 0a3.9521 3.9521 0 01.5669-2.019l5.4521 5.4521A3.9529 3.9529 0 0124 28 4.0045 4.0045 0 0120 24zM8 16H18V18H8zM8 10H20V12H8z"
  })), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,27.7334l-5.2344-2.791A8.9858,8.9858,0,0,1,4,17V4H24l0,11h2L26,4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L14,30Z"
  })), children);
});
var RuleCancelled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RuleCancelled24(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 24a6 6 0 10-6 6A6.0066 6.0066 0 0030 24zm-2 0a3.9521 3.9521 0 01-.5669 2.019L21.981 20.5669A3.9529 3.9529 0 0124 20 4.0045 4.0045 0 0128 24zm-8 0a3.9521 3.9521 0 01.5669-2.019l5.4521 5.4521A3.9529 3.9529 0 0124 28 4.0045 4.0045 0 0120 24zM8 16H18V18H8zM8 10H20V12H8z"
  })), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,27.7334l-5.2344-2.791A8.9858,8.9858,0,0,1,4,17V4H24l0,11h2L26,4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L14,30Z"
  })), children);
});
var RuleCancelled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RuleCancelled20(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 24a6 6 0 10-6 6A6.0066 6.0066 0 0030 24zm-2 0a3.9521 3.9521 0 01-.5669 2.019L21.981 20.5669A3.9529 3.9529 0 0124 20 4.0045 4.0045 0 0128 24zm-8 0a3.9521 3.9521 0 01.5669-2.019l5.4521 5.4521A3.9529 3.9529 0 0124 28 4.0045 4.0045 0 0120 24zM8 16H18V18H8zM8 10H20V12H8z"
  })), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,27.7334l-5.2344-2.791A8.9858,8.9858,0,0,1,4,17V4H24l0,11h2L26,4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L14,30Z"
  })), children);
});
var RuleCancelled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RuleCancelled16(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 24a6 6 0 10-6 6A6.0066 6.0066 0 0030 24zm-2 0a3.9521 3.9521 0 01-.5669 2.019L21.981 20.5669A3.9529 3.9529 0 0124 20 4.0045 4.0045 0 0128 24zm-8 0a3.9521 3.9521 0 01.5669-2.019l5.4521 5.4521A3.9529 3.9529 0 0124 28 4.0045 4.0045 0 0120 24zM8 16H18V18H8zM8 10H20V12H8z"
  })), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,27.7334l-5.2344-2.791A8.9858,8.9858,0,0,1,4,17V4H24l0,11h2L26,4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L14,30Z"
  })), children);
});
var RuleDraft32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RuleDraft32(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM8 16H18V18H8zM8 10H20V12H8z"
  })), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L13,29.4668V27.2L8.7656,24.9424A8.9858,8.9858,0,0,1,4,17V4H24v9h2Z"
  })), children);
});
var RuleDraft24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RuleDraft24(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM8 16H18V18H8zM8 10H20V12H8z"
  })), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L13,29.4668V27.2L8.7656,24.9424A8.9858,8.9858,0,0,1,4,17V4H24v9h2Z"
  })), children);
});
var RuleDraft20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RuleDraft20(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM8 16H18V18H8zM8 10H20V12H8z"
  })), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L13,29.4668V27.2L8.7656,24.9424A8.9858,8.9858,0,0,1,4,17V4H24v9h2Z"
  })), children);
});
var RuleDraft16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RuleDraft16(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707 19.293l-3-3a.9994.9994 0 00-1.414 0L16 25.5859V30h4.4141l9.2929-9.293A.9994.9994 0 0029.707 19.293zM19.5859 28H18V26.4141l5-5L24.5859 23zM26 21.5859L24.4141 20 26 18.4141 27.5859 20zM8 16H18V18H8zM8 10H20V12H8z"
  })), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L13,29.4668V27.2L8.7656,24.9424A8.9858,8.9858,0,0,1,4,17V4H24v9h2Z"
  })), children);
});
var RuleFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RuleFilled32(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M9 16H23V18H9z",
    "data-icon-path": "inner-path"
  })), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M9 10H23V12H9z"
  })), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2H6A2.0023,2.0023,0,0,0,4,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L16,30l6.1758-3.293A10.9814,10.9814,0,0,0,28,17V4A2.0023,2.0023,0,0,0,26,2ZM23,18H9V16H23Zm0-6H9V10H23Z"
  })), children);
});
var RuleFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RuleFilled24(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M9 16H23V18H9z",
    "data-icon-path": "inner-path"
  })), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M9 10H23V12H9z"
  })), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2H6A2.0023,2.0023,0,0,0,4,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L16,30l6.1758-3.293A10.9814,10.9814,0,0,0,28,17V4A2.0023,2.0023,0,0,0,26,2ZM23,18H9V16H23Zm0-6H9V10H23Z"
  })), children);
});
var RuleFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RuleFilled20(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M9 16H23V18H9z",
    "data-icon-path": "inner-path"
  })), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M9 10H23V12H9z"
  })), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2H6A2.0023,2.0023,0,0,0,4,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L16,30l6.1758-3.293A10.9814,10.9814,0,0,0,28,17V4A2.0023,2.0023,0,0,0,26,2ZM23,18H9V16H23Zm0-6H9V10H23Z"
  })), children);
});
var RuleFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RuleFilled16(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M9 16H23V18H9z",
    "data-icon-path": "inner-path"
  })), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M9 10H23V12H9z"
  })), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2H6A2.0023,2.0023,0,0,0,4,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L16,30l6.1758-3.293A10.9814,10.9814,0,0,0,28,17V4A2.0023,2.0023,0,0,0,26,2ZM23,18H9V16H23Zm0-6H9V10H23Z"
  })), children);
});
var RuleTest32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RuleTest32(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,30a7,7,0,1,1,7-7A7.0078,7.0078,0,0,1,23,30Zm0-12a5,5,0,1,0,5,5A5.0055,5.0055,0,0,0,23,18Z"
  })), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 24.586L24 22.586 24 20 22 20 22 23.414 24.586 26 26 24.586zM8 16H14V18H8zM8 10H20V12H8z"
  })), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L13,29.4668V27.2L8.7656,24.9424A8.9858,8.9858,0,0,1,4,17V4H24v9h2Z"
  })), children);
});
var RuleTest24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RuleTest24(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,30a7,7,0,1,1,7-7A7.0078,7.0078,0,0,1,23,30Zm0-12a5,5,0,1,0,5,5A5.0055,5.0055,0,0,0,23,18Z"
  })), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 24.586L24 22.586 24 20 22 20 22 23.414 24.586 26 26 24.586zM8 16H14V18H8zM8 10H20V12H8z"
  })), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L13,29.4668V27.2L8.7656,24.9424A8.9858,8.9858,0,0,1,4,17V4H24v9h2Z"
  })), children);
});
var RuleTest20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RuleTest20(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,30a7,7,0,1,1,7-7A7.0078,7.0078,0,0,1,23,30Zm0-12a5,5,0,1,0,5,5A5.0055,5.0055,0,0,0,23,18Z"
  })), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 24.586L24 22.586 24 20 22 20 22 23.414 24.586 26 26 24.586zM8 16H14V18H8zM8 10H20V12H8z"
  })), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L13,29.4668V27.2L8.7656,24.9424A8.9858,8.9858,0,0,1,4,17V4H24v9h2Z"
  })), children);
});
var RuleTest16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RuleTest16(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,30a7,7,0,1,1,7-7A7.0078,7.0078,0,0,1,23,30Zm0-12a5,5,0,1,0,5,5A5.0055,5.0055,0,0,0,23,18Z"
  })), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 24.586L24 22.586 24 20 22 20 22 23.414 24.586 26 26 24.586zM8 16H14V18H8zM8 10H20V12H8z"
  })), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L13,29.4668V27.2L8.7656,24.9424A8.9858,8.9858,0,0,1,4,17V4H24v9h2Z"
  })), children);
});
var Ruler32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Ruler32(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,10H3a1,1,0,0,0-1,1V21a1,1,0,0,0,1,1H29a1,1,0,0,0,1-1V11A1,1,0,0,0,29,10ZM28,20H4V12H8v4h2V12h5v4h2V12h5v4h2V12h4Z"
  })), children);
});
var Ruler24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Ruler24(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,10H3a1,1,0,0,0-1,1V21a1,1,0,0,0,1,1H29a1,1,0,0,0,1-1V11A1,1,0,0,0,29,10ZM28,20H4V12H8v4h2V12h5v4h2V12h5v4h2V12h4Z"
  })), children);
});
var Ruler20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Ruler20(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,10H3a1,1,0,0,0-1,1V21a1,1,0,0,0,1,1H29a1,1,0,0,0,1-1V11A1,1,0,0,0,29,10ZM28,20H4V12H8v4h2V12h5v4h2V12h5v4h2V12h4Z"
  })), children);
});
var Ruler16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Ruler16(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,10H3a1,1,0,0,0-1,1V21a1,1,0,0,0,1,1H29a1,1,0,0,0,1-1V11A1,1,0,0,0,29,10ZM28,20H4V12H8v4h2V12h5v4h2V12h5v4h2V12h4Z"
  })), children);
});
var RulerAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RulerAlt32(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.41,21.67,10.34,2.58a2,2,0,0,0-2.83,0L2.59,7.51a2,2,0,0,0,0,2.82L21.66,29.42a2,2,0,0,0,1.42.58,2,2,0,0,0,1.41-.58l4.92-4.93A2,2,0,0,0,29.41,21.67ZM23.08,28,4,8.92,8.92,4l3.79,3.79L10.46,10l1.41,1.41L14.12,9.2l4.13,4.13L16,15.58,17.42,17l2.25-2.25,4.13,4.13-2.25,2.25L23,22.54l2.25-2.25L28,23.08Z"
  })), children);
});
var RulerAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RulerAlt24(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.41,21.67,10.34,2.58a2,2,0,0,0-2.83,0L2.59,7.51a2,2,0,0,0,0,2.82L21.66,29.42a2,2,0,0,0,1.42.58,2,2,0,0,0,1.41-.58l4.92-4.93A2,2,0,0,0,29.41,21.67ZM23.08,28,4,8.92,8.92,4l3.79,3.79L10.46,10l1.41,1.41L14.12,9.2l4.13,4.13L16,15.58,17.42,17l2.25-2.25,4.13,4.13-2.25,2.25L23,22.54l2.25-2.25L28,23.08Z"
  })), children);
});
var RulerAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RulerAlt20(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.41,21.67,10.34,2.58a2,2,0,0,0-2.83,0L2.59,7.51a2,2,0,0,0,0,2.82L21.66,29.42a2,2,0,0,0,1.42.58,2,2,0,0,0,1.41-.58l4.92-4.93A2,2,0,0,0,29.41,21.67ZM23.08,28,4,8.92,8.92,4l3.79,3.79L10.46,10l1.41,1.41L14.12,9.2l4.13,4.13L16,15.58,17.42,17l2.25-2.25,4.13,4.13-2.25,2.25L23,22.54l2.25-2.25L28,23.08Z"
  })), children);
});
var RulerAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function RulerAlt16(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.41,21.67,10.34,2.58a2,2,0,0,0-2.83,0L2.59,7.51a2,2,0,0,0,0,2.82L21.66,29.42a2,2,0,0,0,1.42.58,2,2,0,0,0,1.41-.58l4.92-4.93A2,2,0,0,0,29.41,21.67ZM23.08,28,4,8.92,8.92,4l3.79,3.79L10.46,10l1.41,1.41L14.12,9.2l4.13,4.13L16,15.58,17.42,17l2.25-2.25,4.13,4.13-2.25,2.25L23,22.54l2.25-2.25L28,23.08Z"
  })), children);
});
var Run32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Run32(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,16a6,6,0,1,1-6,6,6,6,0,0,1,6-6m0-2a8,8,0,1,0,8,8,8,8,0,0,0-8-8Z"
  })), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V12H28V6A2,2,0,0,0,26,4ZM6,10V6H26v4Z"
  })), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 19L19 25 24 22 19 19z"
  })), children);
});
var Run24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Run24(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,16a6,6,0,1,1-6,6,6,6,0,0,1,6-6m0-2a8,8,0,1,0,8,8,8,8,0,0,0-8-8Z"
  })), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V12H28V6A2,2,0,0,0,26,4ZM6,10V6H26v4Z"
  })), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 19L19 25 24 22 19 19z"
  })), children);
});
var Run20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Run20(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,16a6,6,0,1,1-6,6,6,6,0,0,1,6-6m0-2a8,8,0,1,0,8,8,8,8,0,0,0-8-8Z"
  })), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V12H28V6A2,2,0,0,0,26,4ZM6,10V6H26v4Z"
  })), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 19L19 25 24 22 19 19z"
  })), children);
});
var Run16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Run16(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,16a6,6,0,1,1-6,6,6,6,0,0,1,6-6m0-2a8,8,0,1,0,8,8,8,8,0,0,0-8-8Z"
  })), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V12H28V6A2,2,0,0,0,26,4ZM6,10V6H26v4Z"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 19L19 25 24 22 19 19z"
  })), children);
});
var QS32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QS32(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,23H12V21h6V17H14a2,2,0,0,1-2-2V11a2,2,0,0,1,2-2h6v2H14v4h4a2,2,0,0,1,2,2v4A2,2,0,0,1,18,23Z"
  })), children);
});
var QS24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QS24(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,23H12V21h6V17H14a2,2,0,0,1-2-2V11a2,2,0,0,1,2-2h6v2H14v4h4a2,2,0,0,1,2,2v4A2,2,0,0,1,18,23Z"
  })), children);
});
var QS20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QS20(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,23H12V21h6V17H14a2,2,0,0,1-2-2V11a2,2,0,0,1,2-2h6v2H14v4h4a2,2,0,0,1,2,2v4A2,2,0,0,1,18,23Z"
  })), children);
});
var QS16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QS16(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,23H12V21h6V17H14a2,2,0,0,1-2-2V11a2,2,0,0,1,2-2h6v2H14v4h4a2,2,0,0,1,2,2v4A2,2,0,0,1,18,23Z"
  })), children);
});
var QSAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QSAlt32(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 9L22 9 22 7 20 7 20 9 18 9 18 11 20 11 20 17 22 17 22 11 24 11 24 9zM14 23H8V21h6V17H10a2 2 0 01-2-2V11a2 2 0 012-2h6v2H10v4h4a2 2 0 012 2v4A2 2 0 0114 23z"
  })), children);
});
var QSAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QSAlt24(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 9L22 9 22 7 20 7 20 9 18 9 18 11 20 11 20 17 22 17 22 11 24 11 24 9zM14 23H8V21h6V17H10a2 2 0 01-2-2V11a2 2 0 012-2h6v2H10v4h4a2 2 0 012 2v4A2 2 0 0114 23z"
  })), children);
});
var QSAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QSAlt20(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 9L22 9 22 7 20 7 20 9 18 9 18 11 20 11 20 17 22 17 22 11 24 11 24 9zM14 23H8V21h6V17H10a2 2 0 01-2-2V11a2 2 0 012-2h6v2H10v4h4a2 2 0 012 2v4A2 2 0 0114 23z"
  })), children);
});
var QSAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QSAlt16(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 9L22 9 22 7 20 7 20 9 18 9 18 11 20 11 20 17 22 17 22 11 24 11 24 9zM14 23H8V21h6V17H10a2 2 0 01-2-2V11a2 2 0 012-2h6v2H10v4h4a2 2 0 012 2v4A2 2 0 0114 23z"
  })), children);
});
var SailboatCoastal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SailboatCoastal32(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.7808,26,25.97,21.2422A1,1,0,0,0,25,20H20V17h5a1,1,0,0,0,.9082-1.4189l-6-13a1.0006,1.0006,0,0,0-1.7021-.19L8.2075,15.3906A1,1,0,0,0,9,17h9v3H7a1,1,0,0,0-.97,1.2422L7.2192,26H2v2H30V26ZM20,7.5527,23.437,15H20ZM11.0308,15,18,5.94V15ZM22.7192,26H9.2808l-1-4H23.7192Z"
  })), children);
});
var SailboatCoastal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SailboatCoastal24(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.7808,26,25.97,21.2422A1,1,0,0,0,25,20H20V17h5a1,1,0,0,0,.9082-1.4189l-6-13a1.0006,1.0006,0,0,0-1.7021-.19L8.2075,15.3906A1,1,0,0,0,9,17h9v3H7a1,1,0,0,0-.97,1.2422L7.2192,26H2v2H30V26ZM20,7.5527,23.437,15H20ZM11.0308,15,18,5.94V15ZM22.7192,26H9.2808l-1-4H23.7192Z"
  })), children);
});
var SailboatCoastal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SailboatCoastal20(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.7808,26,25.97,21.2422A1,1,0,0,0,25,20H20V17h5a1,1,0,0,0,.9082-1.4189l-6-13a1.0006,1.0006,0,0,0-1.7021-.19L8.2075,15.3906A1,1,0,0,0,9,17h9v3H7a1,1,0,0,0-.97,1.2422L7.2192,26H2v2H30V26ZM20,7.5527,23.437,15H20ZM11.0308,15,18,5.94V15ZM22.7192,26H9.2808l-1-4H23.7192Z"
  })), children);
});
var SailboatCoastal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SailboatCoastal16(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.7808,26,25.97,21.2422A1,1,0,0,0,25,20H20V17h5a1,1,0,0,0,.9082-1.4189l-6-13a1.0006,1.0006,0,0,0-1.7021-.19L8.2075,15.3906A1,1,0,0,0,9,17h9v3H7a1,1,0,0,0-.97,1.2422L7.2192,26H2v2H30V26ZM20,7.5527,23.437,15H20ZM11.0308,15,18,5.94V15ZM22.7192,26H9.2808l-1-4H23.7192Z"
  })), children);
});
var SailboatOffshore32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SailboatOffshore32(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.9692,25H9.0308l-.75-3H23.7192l-.75,3h2.0616l.9394-3.7578A1,1,0,0,0,25,20H20V17h5a1,1,0,0,0,.9082-1.4189l-6-13a1.0006,1.0006,0,0,0-1.7021-.19L8.2075,15.3906A1,1,0,0,0,9,17h9v3H7a1,1,0,0,0-.97,1.2422ZM20,7.5527,23.437,15H20ZM11.0308,15,18,5.94V15Z"
  })), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.9058,25.751A2.998,2.998,0,0,1,24,28a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,20,25a.9894.9894,0,0,0-.9468.6787A3.44,3.44,0,0,1,16,28a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,12,25a.971.971,0,0,0-.9468.6787A3.44,3.44,0,0,1,8,28a2.998,2.998,0,0,1-2.9058-2.249l-1.9365.498A4.9965,4.9965,0,0,0,8,30a4.9316,4.9316,0,0,0,4-1.9873,5.0192,5.0192,0,0,0,8,0A4.9316,4.9316,0,0,0,24,30a4.9965,4.9965,0,0,0,4.8423-3.751Z"
  })), children);
});
var SailboatOffshore24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SailboatOffshore24(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.9692,25H9.0308l-.75-3H23.7192l-.75,3h2.0616l.9394-3.7578A1,1,0,0,0,25,20H20V17h5a1,1,0,0,0,.9082-1.4189l-6-13a1.0006,1.0006,0,0,0-1.7021-.19L8.2075,15.3906A1,1,0,0,0,9,17h9v3H7a1,1,0,0,0-.97,1.2422ZM20,7.5527,23.437,15H20ZM11.0308,15,18,5.94V15Z"
  })), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.9058,25.751A2.998,2.998,0,0,1,24,28a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,20,25a.9894.9894,0,0,0-.9468.6787A3.44,3.44,0,0,1,16,28a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,12,25a.971.971,0,0,0-.9468.6787A3.44,3.44,0,0,1,8,28a2.998,2.998,0,0,1-2.9058-2.249l-1.9365.498A4.9965,4.9965,0,0,0,8,30a4.9316,4.9316,0,0,0,4-1.9873,5.0192,5.0192,0,0,0,8,0A4.9316,4.9316,0,0,0,24,30a4.9965,4.9965,0,0,0,4.8423-3.751Z"
  })), children);
});
var SailboatOffshore20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SailboatOffshore20(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.9692,25H9.0308l-.75-3H23.7192l-.75,3h2.0616l.9394-3.7578A1,1,0,0,0,25,20H20V17h5a1,1,0,0,0,.9082-1.4189l-6-13a1.0006,1.0006,0,0,0-1.7021-.19L8.2075,15.3906A1,1,0,0,0,9,17h9v3H7a1,1,0,0,0-.97,1.2422ZM20,7.5527,23.437,15H20ZM11.0308,15,18,5.94V15Z"
  })), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.9058,25.751A2.998,2.998,0,0,1,24,28a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,20,25a.9894.9894,0,0,0-.9468.6787A3.44,3.44,0,0,1,16,28a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,12,25a.971.971,0,0,0-.9468.6787A3.44,3.44,0,0,1,8,28a2.998,2.998,0,0,1-2.9058-2.249l-1.9365.498A4.9965,4.9965,0,0,0,8,30a4.9316,4.9316,0,0,0,4-1.9873,5.0192,5.0192,0,0,0,8,0A4.9316,4.9316,0,0,0,24,30a4.9965,4.9965,0,0,0,4.8423-3.751Z"
  })), children);
});
var SailboatOffshore16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SailboatOffshore16(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.9692,25H9.0308l-.75-3H23.7192l-.75,3h2.0616l.9394-3.7578A1,1,0,0,0,25,20H20V17h5a1,1,0,0,0,.9082-1.4189l-6-13a1.0006,1.0006,0,0,0-1.7021-.19L8.2075,15.3906A1,1,0,0,0,9,17h9v3H7a1,1,0,0,0-.97,1.2422ZM20,7.5527,23.437,15H20ZM11.0308,15,18,5.94V15Z"
  })), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.9058,25.751A2.998,2.998,0,0,1,24,28a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,20,25a.9894.9894,0,0,0-.9468.6787A3.44,3.44,0,0,1,16,28a3.4376,3.4376,0,0,1-3.0513-2.3164A1.007,1.007,0,0,0,12,25a.971.971,0,0,0-.9468.6787A3.44,3.44,0,0,1,8,28a2.998,2.998,0,0,1-2.9058-2.249l-1.9365.498A4.9965,4.9965,0,0,0,8,30a4.9316,4.9316,0,0,0,4-1.9873,5.0192,5.0192,0,0,0,8,0A4.9316,4.9316,0,0,0,24,30a4.9965,4.9965,0,0,0,4.8423-3.751Z"
  })), children);
});
var SankeyDiagram32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SankeyDiagram32(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2V8.0439c-1.9634.1968-6.3162,1.2325-10.5637,6.2764-.198-.2768-.3982-.5464-.5882-.8506C11.9736,5.6714,6.3191,4.2759,4,4.042V2H2V30H4V26.0464a14.8661,14.8661,0,0,0,9.9185-3.96C18.47,27.46,25.2363,28.0381,27.9341,28.0381c.0244,0,.0422-.001.0659-.001V30h2V2Zm0,8.0552v9.99a12.8834,12.8834,0,0,1-9.2756-4.1328C22.5032,11.2666,26.2915,10.26,28,10.0552ZM15.1519,14.53c.3242.5185.663.9907,1.0078,1.4409-.3384.4741-.6753.9707-1.0078,1.5029a16.1346,16.1346,0,0,1-1.0313,1.4531c-.0825-.1372-.1675-.27-.2466-.4126C9.3279,10.3315,5.7871,8.4438,4,8.0684V6.0508C5.9932,6.2905,10.8228,7.6035,15.1519,14.53ZM4,24.0488V10.1406c1.3254.4644,4.2034,2.2847,8.126,9.3448.1894.3413.396.6523.6.9667A12.8784,12.8784,0,0,1,4,24.0488Zm11.3179-3.4209a18.0563,18.0563,0,0,0,1.53-2.0937c.2212-.354.4454-.67.6687-.9951A14.8686,14.8686,0,0,0,28,22.0425v3.9863C25.67,26.019,19.374,25.5088,15.3179,20.6279Z"
  })), children);
});
var SankeyDiagram24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SankeyDiagram24(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2V8.0439c-1.9634.1968-6.3162,1.2325-10.5637,6.2764-.198-.2768-.3982-.5464-.5882-.8506C11.9736,5.6714,6.3191,4.2759,4,4.042V2H2V30H4V26.0464a14.8661,14.8661,0,0,0,9.9185-3.96C18.47,27.46,25.2363,28.0381,27.9341,28.0381c.0244,0,.0422-.001.0659-.001V30h2V2Zm0,8.0552v9.99a12.8834,12.8834,0,0,1-9.2756-4.1328C22.5032,11.2666,26.2915,10.26,28,10.0552ZM15.1519,14.53c.3242.5185.663.9907,1.0078,1.4409-.3384.4741-.6753.9707-1.0078,1.5029a16.1346,16.1346,0,0,1-1.0313,1.4531c-.0825-.1372-.1675-.27-.2466-.4126C9.3279,10.3315,5.7871,8.4438,4,8.0684V6.0508C5.9932,6.2905,10.8228,7.6035,15.1519,14.53ZM4,24.0488V10.1406c1.3254.4644,4.2034,2.2847,8.126,9.3448.1894.3413.396.6523.6.9667A12.8784,12.8784,0,0,1,4,24.0488Zm11.3179-3.4209a18.0563,18.0563,0,0,0,1.53-2.0937c.2212-.354.4454-.67.6687-.9951A14.8686,14.8686,0,0,0,28,22.0425v3.9863C25.67,26.019,19.374,25.5088,15.3179,20.6279Z"
  })), children);
});
var SankeyDiagram20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SankeyDiagram20(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2V8.0439c-1.9634.1968-6.3162,1.2325-10.5637,6.2764-.198-.2768-.3982-.5464-.5882-.8506C11.9736,5.6714,6.3191,4.2759,4,4.042V2H2V30H4V26.0464a14.8661,14.8661,0,0,0,9.9185-3.96C18.47,27.46,25.2363,28.0381,27.9341,28.0381c.0244,0,.0422-.001.0659-.001V30h2V2Zm0,8.0552v9.99a12.8834,12.8834,0,0,1-9.2756-4.1328C22.5032,11.2666,26.2915,10.26,28,10.0552ZM15.1519,14.53c.3242.5185.663.9907,1.0078,1.4409-.3384.4741-.6753.9707-1.0078,1.5029a16.1346,16.1346,0,0,1-1.0313,1.4531c-.0825-.1372-.1675-.27-.2466-.4126C9.3279,10.3315,5.7871,8.4438,4,8.0684V6.0508C5.9932,6.2905,10.8228,7.6035,15.1519,14.53ZM4,24.0488V10.1406c1.3254.4644,4.2034,2.2847,8.126,9.3448.1894.3413.396.6523.6.9667A12.8784,12.8784,0,0,1,4,24.0488Zm11.3179-3.4209a18.0563,18.0563,0,0,0,1.53-2.0937c.2212-.354.4454-.67.6687-.9951A14.8686,14.8686,0,0,0,28,22.0425v3.9863C25.67,26.019,19.374,25.5088,15.3179,20.6279Z"
  })), children);
});
var SankeyDiagram16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SankeyDiagram16(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2V8.0439c-1.9634.1968-6.3162,1.2325-10.5637,6.2764-.198-.2768-.3982-.5464-.5882-.8506C11.9736,5.6714,6.3191,4.2759,4,4.042V2H2V30H4V26.0464a14.8661,14.8661,0,0,0,9.9185-3.96C18.47,27.46,25.2363,28.0381,27.9341,28.0381c.0244,0,.0422-.001.0659-.001V30h2V2Zm0,8.0552v9.99a12.8834,12.8834,0,0,1-9.2756-4.1328C22.5032,11.2666,26.2915,10.26,28,10.0552ZM15.1519,14.53c.3242.5185.663.9907,1.0078,1.4409-.3384.4741-.6753.9707-1.0078,1.5029a16.1346,16.1346,0,0,1-1.0313,1.4531c-.0825-.1372-.1675-.27-.2466-.4126C9.3279,10.3315,5.7871,8.4438,4,8.0684V6.0508C5.9932,6.2905,10.8228,7.6035,15.1519,14.53ZM4,24.0488V10.1406c1.3254.4644,4.2034,2.2847,8.126,9.3448.1894.3413.396.6523.6.9667A12.8784,12.8784,0,0,1,4,24.0488Zm11.3179-3.4209a18.0563,18.0563,0,0,0,1.53-2.0937c.2212-.354.4454-.67.6687-.9951A14.8686,14.8686,0,0,0,28,22.0425v3.9863C25.67,26.019,19.374,25.5088,15.3179,20.6279Z"
  })), children);
});
var SankeyDiagramAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SankeyDiagramAlt32(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,2H2V16H8.1113a7.0359,7.0359,0,0,1,3.13.7393L15.7637,19l-4.522,2.2607A7.0359,7.0359,0,0,1,8.1113,22H2v8H9.2231a9.0446,9.0446,0,0,0,4.0249-.95L21.87,24.7393A7.0359,7.0359,0,0,1,25,24h5V14H25a7.0359,7.0359,0,0,1-3.13-.7393L15.3481,10H30ZM8,4H24V8H8ZM4,4H6V14H4ZM4,24H6v4H4Zm16.9751-1.05-8.6216,4.3105A7.0359,7.0359,0,0,1,9.2231,28H8V24h.1113a9.0446,9.0446,0,0,0,4.0249-.95L18,20.1182l1.8638.9316a9.0446,9.0446,0,0,0,4.0249.95H24v.0586A9.0515,9.0515,0,0,0,20.9751,22.95ZM28,22H26V16h2ZM12.3535,10.7393l8.6216,4.31A9.0515,9.0515,0,0,0,24,15.9414V20h-.1113a7.0359,7.0359,0,0,1-3.13-.7393l-8.6221-4.31A9.0446,9.0446,0,0,0,8.1113,14H8V10H9.2231A7.0359,7.0359,0,0,1,12.3535,10.7393ZM28,8H26V4h2Z"
  })), children);
});
var SankeyDiagramAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SankeyDiagramAlt24(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,2H2V16H8.1113a7.0359,7.0359,0,0,1,3.13.7393L15.7637,19l-4.522,2.2607A7.0359,7.0359,0,0,1,8.1113,22H2v8H9.2231a9.0446,9.0446,0,0,0,4.0249-.95L21.87,24.7393A7.0359,7.0359,0,0,1,25,24h5V14H25a7.0359,7.0359,0,0,1-3.13-.7393L15.3481,10H30ZM8,4H24V8H8ZM4,4H6V14H4ZM4,24H6v4H4Zm16.9751-1.05-8.6216,4.3105A7.0359,7.0359,0,0,1,9.2231,28H8V24h.1113a9.0446,9.0446,0,0,0,4.0249-.95L18,20.1182l1.8638.9316a9.0446,9.0446,0,0,0,4.0249.95H24v.0586A9.0515,9.0515,0,0,0,20.9751,22.95ZM28,22H26V16h2ZM12.3535,10.7393l8.6216,4.31A9.0515,9.0515,0,0,0,24,15.9414V20h-.1113a7.0359,7.0359,0,0,1-3.13-.7393l-8.6221-4.31A9.0446,9.0446,0,0,0,8.1113,14H8V10H9.2231A7.0359,7.0359,0,0,1,12.3535,10.7393ZM28,8H26V4h2Z"
  })), children);
});
var SankeyDiagramAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SankeyDiagramAlt20(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,2H2V16H8.1113a7.0359,7.0359,0,0,1,3.13.7393L15.7637,19l-4.522,2.2607A7.0359,7.0359,0,0,1,8.1113,22H2v8H9.2231a9.0446,9.0446,0,0,0,4.0249-.95L21.87,24.7393A7.0359,7.0359,0,0,1,25,24h5V14H25a7.0359,7.0359,0,0,1-3.13-.7393L15.3481,10H30ZM8,4H24V8H8ZM4,4H6V14H4ZM4,24H6v4H4Zm16.9751-1.05-8.6216,4.3105A7.0359,7.0359,0,0,1,9.2231,28H8V24h.1113a9.0446,9.0446,0,0,0,4.0249-.95L18,20.1182l1.8638.9316a9.0446,9.0446,0,0,0,4.0249.95H24v.0586A9.0515,9.0515,0,0,0,20.9751,22.95ZM28,22H26V16h2ZM12.3535,10.7393l8.6216,4.31A9.0515,9.0515,0,0,0,24,15.9414V20h-.1113a7.0359,7.0359,0,0,1-3.13-.7393l-8.6221-4.31A9.0446,9.0446,0,0,0,8.1113,14H8V10H9.2231A7.0359,7.0359,0,0,1,12.3535,10.7393ZM28,8H26V4h2Z"
  })), children);
});
var SankeyDiagramAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SankeyDiagramAlt16(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,2H2V16H8.1113a7.0359,7.0359,0,0,1,3.13.7393L15.7637,19l-4.522,2.2607A7.0359,7.0359,0,0,1,8.1113,22H2v8H9.2231a9.0446,9.0446,0,0,0,4.0249-.95L21.87,24.7393A7.0359,7.0359,0,0,1,25,24h5V14H25a7.0359,7.0359,0,0,1-3.13-.7393L15.3481,10H30ZM8,4H24V8H8ZM4,4H6V14H4ZM4,24H6v4H4Zm16.9751-1.05-8.6216,4.3105A7.0359,7.0359,0,0,1,9.2231,28H8V24h.1113a9.0446,9.0446,0,0,0,4.0249-.95L18,20.1182l1.8638.9316a9.0446,9.0446,0,0,0,4.0249.95H24v.0586A9.0515,9.0515,0,0,0,20.9751,22.95ZM28,22H26V16h2ZM12.3535,10.7393l8.6216,4.31A9.0515,9.0515,0,0,0,24,15.9414V20h-.1113a7.0359,7.0359,0,0,1-3.13-.7393l-8.6221-4.31A9.0446,9.0446,0,0,0,8.1113,14H8V10H9.2231A7.0359,7.0359,0,0,1,12.3535,10.7393ZM28,8H26V4h2Z"
  })), children);
});
var Satellite32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Satellite32(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.9141,16.5l2.7929-2.793a.9994.9994,0,0,0,0-1.414L23.4141,10,25.5,7.9141,28.5859,11,30,9.5859,22.4141,2,21,3.4141,24.0859,6.5,22,8.5859,19.707,6.293a.9994.9994,0,0,0-1.414,0L15.5,9.0859,8.707,2.293a.9994.9994,0,0,0-1.414,0l-5,5a.9994.9994,0,0,0,0,1.414L9.0859,15.5,6.293,18.293a.9994.9994,0,0,0,0,1.414L8.5859,22,6.5,24.0859,3.4141,21,2,22.4141,9.5859,30,11,28.5859,7.9141,25.5,10,23.4141l2.293,2.2929a.9995.9995,0,0,0,1.414,0L16.5,22.9141l6.793,6.7929a.9995.9995,0,0,0,1.414,0l5-5a.9994.9994,0,0,0,0-1.414ZM4.4141,8,8,4.4141,10.0859,6.5,6.5,10.0859Zm3.5,3.5L11.5,7.9141,14.0859,10.5,10.5,14.0859ZM13,23.5859,8.4141,19,19,8.4141,23.5859,13ZM17.9141,21.5,21.5,17.9141,24.0859,20.5,20.5,24.0859ZM24,27.5859,21.9141,25.5,25.5,21.9141,27.5859,24Z"
  })), children);
});
var Satellite24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Satellite24(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.9141,16.5l2.7929-2.793a.9994.9994,0,0,0,0-1.414L23.4141,10,25.5,7.9141,28.5859,11,30,9.5859,22.4141,2,21,3.4141,24.0859,6.5,22,8.5859,19.707,6.293a.9994.9994,0,0,0-1.414,0L15.5,9.0859,8.707,2.293a.9994.9994,0,0,0-1.414,0l-5,5a.9994.9994,0,0,0,0,1.414L9.0859,15.5,6.293,18.293a.9994.9994,0,0,0,0,1.414L8.5859,22,6.5,24.0859,3.4141,21,2,22.4141,9.5859,30,11,28.5859,7.9141,25.5,10,23.4141l2.293,2.2929a.9995.9995,0,0,0,1.414,0L16.5,22.9141l6.793,6.7929a.9995.9995,0,0,0,1.414,0l5-5a.9994.9994,0,0,0,0-1.414ZM4.4141,8,8,4.4141,10.0859,6.5,6.5,10.0859Zm3.5,3.5L11.5,7.9141,14.0859,10.5,10.5,14.0859ZM13,23.5859,8.4141,19,19,8.4141,23.5859,13ZM17.9141,21.5,21.5,17.9141,24.0859,20.5,20.5,24.0859ZM24,27.5859,21.9141,25.5,25.5,21.9141,27.5859,24Z"
  })), children);
});
var Satellite20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Satellite20(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.9141,16.5l2.7929-2.793a.9994.9994,0,0,0,0-1.414L23.4141,10,25.5,7.9141,28.5859,11,30,9.5859,22.4141,2,21,3.4141,24.0859,6.5,22,8.5859,19.707,6.293a.9994.9994,0,0,0-1.414,0L15.5,9.0859,8.707,2.293a.9994.9994,0,0,0-1.414,0l-5,5a.9994.9994,0,0,0,0,1.414L9.0859,15.5,6.293,18.293a.9994.9994,0,0,0,0,1.414L8.5859,22,6.5,24.0859,3.4141,21,2,22.4141,9.5859,30,11,28.5859,7.9141,25.5,10,23.4141l2.293,2.2929a.9995.9995,0,0,0,1.414,0L16.5,22.9141l6.793,6.7929a.9995.9995,0,0,0,1.414,0l5-5a.9994.9994,0,0,0,0-1.414ZM4.4141,8,8,4.4141,10.0859,6.5,6.5,10.0859Zm3.5,3.5L11.5,7.9141,14.0859,10.5,10.5,14.0859ZM13,23.5859,8.4141,19,19,8.4141,23.5859,13ZM17.9141,21.5,21.5,17.9141,24.0859,20.5,20.5,24.0859ZM24,27.5859,21.9141,25.5,25.5,21.9141,27.5859,24Z"
  })), children);
});
var Satellite16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Satellite16(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.9141,16.5l2.7929-2.793a.9994.9994,0,0,0,0-1.414L23.4141,10,25.5,7.9141,28.5859,11,30,9.5859,22.4141,2,21,3.4141,24.0859,6.5,22,8.5859,19.707,6.293a.9994.9994,0,0,0-1.414,0L15.5,9.0859,8.707,2.293a.9994.9994,0,0,0-1.414,0l-5,5a.9994.9994,0,0,0,0,1.414L9.0859,15.5,6.293,18.293a.9994.9994,0,0,0,0,1.414L8.5859,22,6.5,24.0859,3.4141,21,2,22.4141,9.5859,30,11,28.5859,7.9141,25.5,10,23.4141l2.293,2.2929a.9995.9995,0,0,0,1.414,0L16.5,22.9141l6.793,6.7929a.9995.9995,0,0,0,1.414,0l5-5a.9994.9994,0,0,0,0-1.414ZM4.4141,8,8,4.4141,10.0859,6.5,6.5,10.0859Zm3.5,3.5L11.5,7.9141,14.0859,10.5,10.5,14.0859ZM13,23.5859,8.4141,19,19,8.4141,23.5859,13ZM17.9141,21.5,21.5,17.9141,24.0859,20.5,20.5,24.0859ZM24,27.5859,21.9141,25.5,25.5,21.9141,27.5859,24Z"
  })), children);
});
var SatelliteRadar32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SatelliteRadar32(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,14H28A10.0113,10.0113,0,0,0,18,4V2A12.0137,12.0137,0,0,1,30,14Z"
  })), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 14H24a6.0067 6.0067 0 00-6-6V6A8.0092 8.0092 0 0126 14zM16 28V24.96a9.9124 9.9124 0 007.3179-2.208 1.8482 1.8482 0 00.6777-1.3344 1.8 1.8 0 00-.5239-1.36L18.4141 15 21 12.4141 19.5859 11 17 13.5859 11.9419 8.5273a1.8145 1.8145 0 00-1.36-.5229 1.845 1.845 0 00-1.3339.6782 9.9566 9.9566 0 00-.5127 11.95L6.2793 28H2v2H30V28zM10.68 10.0938L21.9058 21.32A8.0011 8.0011 0 0110.68 10.0938zM14 28H8.3875l1.8757-5.627A9.9894 9.9894 0 0014 24.5435z"
  })), children);
});
var SatelliteRadar24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SatelliteRadar24(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,14H28A10.0113,10.0113,0,0,0,18,4V2A12.0137,12.0137,0,0,1,30,14Z"
  })), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 14H24a6.0067 6.0067 0 00-6-6V6A8.0092 8.0092 0 0126 14zM16 28V24.96a9.9124 9.9124 0 007.3179-2.208 1.8482 1.8482 0 00.6777-1.3344 1.8 1.8 0 00-.5239-1.36L18.4141 15 21 12.4141 19.5859 11 17 13.5859 11.9419 8.5273a1.8145 1.8145 0 00-1.36-.5229 1.845 1.845 0 00-1.3339.6782 9.9566 9.9566 0 00-.5127 11.95L6.2793 28H2v2H30V28zM10.68 10.0938L21.9058 21.32A8.0011 8.0011 0 0110.68 10.0938zM14 28H8.3875l1.8757-5.627A9.9894 9.9894 0 0014 24.5435z"
  })), children);
});
var SatelliteRadar20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SatelliteRadar20(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,14H28A10.0113,10.0113,0,0,0,18,4V2A12.0137,12.0137,0,0,1,30,14Z"
  })), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 14H24a6.0067 6.0067 0 00-6-6V6A8.0092 8.0092 0 0126 14zM16 28V24.96a9.9124 9.9124 0 007.3179-2.208 1.8482 1.8482 0 00.6777-1.3344 1.8 1.8 0 00-.5239-1.36L18.4141 15 21 12.4141 19.5859 11 17 13.5859 11.9419 8.5273a1.8145 1.8145 0 00-1.36-.5229 1.845 1.845 0 00-1.3339.6782 9.9566 9.9566 0 00-.5127 11.95L6.2793 28H2v2H30V28zM10.68 10.0938L21.9058 21.32A8.0011 8.0011 0 0110.68 10.0938zM14 28H8.3875l1.8757-5.627A9.9894 9.9894 0 0014 24.5435z"
  })), children);
});
var SatelliteRadar16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SatelliteRadar16(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,14H28A10.0113,10.0113,0,0,0,18,4V2A12.0137,12.0137,0,0,1,30,14Z"
  })), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 14H24a6.0067 6.0067 0 00-6-6V6A8.0092 8.0092 0 0126 14zM16 28V24.96a9.9124 9.9124 0 007.3179-2.208 1.8482 1.8482 0 00.6777-1.3344 1.8 1.8 0 00-.5239-1.36L18.4141 15 21 12.4141 19.5859 11 17 13.5859 11.9419 8.5273a1.8145 1.8145 0 00-1.36-.5229 1.845 1.845 0 00-1.3339.6782 9.9566 9.9566 0 00-.5127 11.95L6.2793 28H2v2H30V28zM10.68 10.0938L21.9058 21.32A8.0011 8.0011 0 0110.68 10.0938zM14 28H8.3875l1.8757-5.627A9.9894 9.9894 0 0014 24.5435z"
  })), children);
});
var SatelliteWeather32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SatelliteWeather32(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5 12H19a4 4 0 010-8h.0835A4.7864 4.7864 0 0123 2a4.9816 4.9816 0 014.6543 3.2034A3.4667 3.4667 0 0130 8.5 3.5041 3.5041 0 0126.5 12zM19 6a2 2 0 000 4h7.5A1.5017 1.5017 0 0028 8.5a1.4855 1.4855 0 00-1.2778-1.4739L26.061 6.927l-.1616-.6487a2.9568 2.9568 0 00-5.4873-.7121L20.1143 6zM13 28V24.8882a7.9363 7.9363 0 004.707-2.2818.9995.9995 0 000-1.414L13.4644 16.95 16 14.4141 14.5859 13 12.05 15.5356 7.8076 11.293a.9994.9994 0 00-1.414 0 7.9993 7.9993 0 000 11.3134c.1621.1622.3327.3125.5058.459L4.4321 28H2v2H30V28zm-2 0H6.6685L8.59 24.1567A7.8927 7.8927 0 0011 24.873zM7.8076 21.1924a6.0036 6.0036 0 01-.6489-7.72l8.3686 8.3681a6.0026 6.0026 0 01-7.72-.6484z"
  })), children);
});
var SatelliteWeather24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SatelliteWeather24(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5 12H19a4 4 0 010-8h.0835A4.7864 4.7864 0 0123 2a4.9816 4.9816 0 014.6543 3.2034A3.4667 3.4667 0 0130 8.5 3.5041 3.5041 0 0126.5 12zM19 6a2 2 0 000 4h7.5A1.5017 1.5017 0 0028 8.5a1.4855 1.4855 0 00-1.2778-1.4739L26.061 6.927l-.1616-.6487a2.9568 2.9568 0 00-5.4873-.7121L20.1143 6zM13 28V24.8882a7.9363 7.9363 0 004.707-2.2818.9995.9995 0 000-1.414L13.4644 16.95 16 14.4141 14.5859 13 12.05 15.5356 7.8076 11.293a.9994.9994 0 00-1.414 0 7.9993 7.9993 0 000 11.3134c.1621.1622.3327.3125.5058.459L4.4321 28H2v2H30V28zm-2 0H6.6685L8.59 24.1567A7.8927 7.8927 0 0011 24.873zM7.8076 21.1924a6.0036 6.0036 0 01-.6489-7.72l8.3686 8.3681a6.0026 6.0026 0 01-7.72-.6484z"
  })), children);
});
var SatelliteWeather20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SatelliteWeather20(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5 12H19a4 4 0 010-8h.0835A4.7864 4.7864 0 0123 2a4.9816 4.9816 0 014.6543 3.2034A3.4667 3.4667 0 0130 8.5 3.5041 3.5041 0 0126.5 12zM19 6a2 2 0 000 4h7.5A1.5017 1.5017 0 0028 8.5a1.4855 1.4855 0 00-1.2778-1.4739L26.061 6.927l-.1616-.6487a2.9568 2.9568 0 00-5.4873-.7121L20.1143 6zM13 28V24.8882a7.9363 7.9363 0 004.707-2.2818.9995.9995 0 000-1.414L13.4644 16.95 16 14.4141 14.5859 13 12.05 15.5356 7.8076 11.293a.9994.9994 0 00-1.414 0 7.9993 7.9993 0 000 11.3134c.1621.1622.3327.3125.5058.459L4.4321 28H2v2H30V28zm-2 0H6.6685L8.59 24.1567A7.8927 7.8927 0 0011 24.873zM7.8076 21.1924a6.0036 6.0036 0 01-.6489-7.72l8.3686 8.3681a6.0026 6.0026 0 01-7.72-.6484z"
  })), children);
});
var SatelliteWeather16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SatelliteWeather16(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5 12H19a4 4 0 010-8h.0835A4.7864 4.7864 0 0123 2a4.9816 4.9816 0 014.6543 3.2034A3.4667 3.4667 0 0130 8.5 3.5041 3.5041 0 0126.5 12zM19 6a2 2 0 000 4h7.5A1.5017 1.5017 0 0028 8.5a1.4855 1.4855 0 00-1.2778-1.4739L26.061 6.927l-.1616-.6487a2.9568 2.9568 0 00-5.4873-.7121L20.1143 6zM13 28V24.8882a7.9363 7.9363 0 004.707-2.2818.9995.9995 0 000-1.414L13.4644 16.95 16 14.4141 14.5859 13 12.05 15.5356 7.8076 11.293a.9994.9994 0 00-1.414 0 7.9993 7.9993 0 000 11.3134c.1621.1622.3327.3125.5058.459L4.4321 28H2v2H30V28zm-2 0H6.6685L8.59 24.1567A7.8927 7.8927 0 0011 24.873zM7.8076 21.1924a6.0036 6.0036 0 01-.6489-7.72l8.3686 8.3681a6.0026 6.0026 0 01-7.72-.6484z"
  })), children);
});
var Save32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Save32(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.71,9.29l-5-5A1,1,0,0,0,22,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V10A1,1,0,0,0,27.71,9.29ZM12,6h8v4H12Zm8,20H12V18h8Zm2,0V18a2,2,0,0,0-2-2H12a2,2,0,0,0-2,2v8H6V6h4v4a2,2,0,0,0,2,2h8a2,2,0,0,0,2-2V6.41l4,4V26Z"
  })), children);
});
var Save24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Save24(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 24 24",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.8,7L17,3.2C16.9,3.1,16.7,3,16.5,3h-12C3.7,3,3,3.7,3,4.5v15C3,20.3,3.7,21,4.5,21h15c0.8,0,1.5-0.7,1.5-1.5v-12\tC21,7.3,20.9,7.1,20.8,7z M9,4.5h6v3H9V4.5z M15,19.5H9v-6h6V19.5z M16.5,19.5v-6c0-0.8-0.7-1.5-1.5-1.5H9c-0.8,0-1.5,0.7-1.5,1.5v6\th-3v-15h3v3C7.5,8.3,8.2,9,9,9h6c0.8,0,1.5-0.7,1.5-1.5V4.8l3,3v11.7H16.5z"
  })), children);
});
var Save20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Save20(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 20 20",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.8,5.5l-3.3-3.3C14.3,2.1,14.2,2,14,2H3.3C2.6,2,2,2.6,2,3.3v13.3C2,17.4,2.6,18,3.3,18h13.3c0.7,0,1.4-0.5,1.4-1.2V6.1\tC18,5.7,17.9,5.7,17.8,5.5z M7.3,3.3h5.3v3.3H7.3V3.3z M12.7,16.7H7.3v-5.3h5.3L12.7,16.7L12.7,16.7z M14,16.7v-5.3\tc0-0.7-0.6-1.3-1.3-1.3H7.3C6.6,10,6,10.6,6,11.3v5.3H3.3V3.3H6v3.3C6,7.4,6.6,8,7.3,8h5.3C13.4,8,14,7.4,14,6.7v-3l2.7,2.7v10.4\tL14,16.7L14,16.7z"
  })), children);
});
var Save16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Save16(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.9,4.6l-2.5-2.5C11.3,2.1,11.1,2,11,2H3C2.4,2,2,2.4,2,3v10c0,0.6,0.4,1,1,1h10c0.6,0,1-0.4,1-1V5\tC14,4.9,13.9,4.7,13.9,4.6z M6,3h4v2H6V3z M10,13H6V9h4V13z M11,13V9c0-0.6-0.4-1-1-1H6C5.4,8,5,8.4,5,9v4H3V3h2v2c0,0.6,0.4,1,1,1\th4c0.6,0,1-0.4,1-1V3.2l2,2V13H11z"
  })), children);
});
var WatsonHealthSaveAnnotation32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSaveAnnotation32(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.56,15.1l-3.48-4.35A2,2,0,0,0,16.52,10H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V16.35A2,2,0,0,0,21.56,15.1ZM9,12h6v3H9Zm6,16H9V22h6Zm2,0V22a2,2,0,0,0-2-2H9a2,2,0,0,0-2,2v6H4V12H7v3a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V12.6l3,3.75V28Z"
  })), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H25V18h3V4H8V7H6V4A2,2,0,0,1,8,2H28a2,2,0,0,1,2,2V18A2,2,0,0,1,28,20Z"
  })), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 6H26V8H20zM22 10H26V12H22z"
  })), children);
});
var WatsonHealthSaveAnnotation24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSaveAnnotation24(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.56,15.1l-3.48-4.35A2,2,0,0,0,16.52,10H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V16.35A2,2,0,0,0,21.56,15.1ZM9,12h6v3H9Zm6,16H9V22h6Zm2,0V22a2,2,0,0,0-2-2H9a2,2,0,0,0-2,2v6H4V12H7v3a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V12.6l3,3.75V28Z"
  })), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H25V18h3V4H8V7H6V4A2,2,0,0,1,8,2H28a2,2,0,0,1,2,2V18A2,2,0,0,1,28,20Z"
  })), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 6H26V8H20zM22 10H26V12H22z"
  })), children);
});
var WatsonHealthSaveAnnotation20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSaveAnnotation20(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.56,15.1l-3.48-4.35A2,2,0,0,0,16.52,10H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V16.35A2,2,0,0,0,21.56,15.1ZM9,12h6v3H9Zm6,16H9V22h6Zm2,0V22a2,2,0,0,0-2-2H9a2,2,0,0,0-2,2v6H4V12H7v3a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V12.6l3,3.75V28Z"
  })), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H25V18h3V4H8V7H6V4A2,2,0,0,1,8,2H28a2,2,0,0,1,2,2V18A2,2,0,0,1,28,20Z"
  })), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 6H26V8H20zM22 10H26V12H22z"
  })), children);
});
var WatsonHealthSaveAnnotation16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSaveAnnotation16(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.56,15.1l-3.48-4.35A2,2,0,0,0,16.52,10H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V16.35A2,2,0,0,0,21.56,15.1ZM9,12h6v3H9Zm6,16H9V22h6Zm2,0V22a2,2,0,0,0-2-2H9a2,2,0,0,0-2,2v6H4V12H7v3a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V12.6l3,3.75V28Z"
  })), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H25V18h3V4H8V7H6V4A2,2,0,0,1,8,2H28a2,2,0,0,1,2,2V18A2,2,0,0,1,28,20Z"
  })), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 6H26V8H20zM22 10H26V12H22z"
  })), children);
});
var WatsonHealthSaveImage32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSaveImage32(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.56,15.1l-3.48-4.35A2,2,0,0,0,16.52,10H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V16.35A2,2,0,0,0,21.56,15.1ZM9,12h6v3H9Zm6,16H9V22h6Zm2,0V22a2,2,0,0,0-2-2H9a2,2,0,0,0-2,2v6H4V12H7v3a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V12.6l3,3.75V28Z"
  })), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H25V18h3V4H14V7H12V4a2,2,0,0,1,2-2H28a2,2,0,0,1,2,2V18A2,2,0,0,1,28,20Z"
  })), children);
});
var WatsonHealthSaveImage24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSaveImage24(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.56,15.1l-3.48-4.35A2,2,0,0,0,16.52,10H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V16.35A2,2,0,0,0,21.56,15.1ZM9,12h6v3H9Zm6,16H9V22h6Zm2,0V22a2,2,0,0,0-2-2H9a2,2,0,0,0-2,2v6H4V12H7v3a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V12.6l3,3.75V28Z"
  })), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H25V18h3V4H14V7H12V4a2,2,0,0,1,2-2H28a2,2,0,0,1,2,2V18A2,2,0,0,1,28,20Z"
  })), children);
});
var WatsonHealthSaveImage20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSaveImage20(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.56,15.1l-3.48-4.35A2,2,0,0,0,16.52,10H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V16.35A2,2,0,0,0,21.56,15.1ZM9,12h6v3H9Zm6,16H9V22h6Zm2,0V22a2,2,0,0,0-2-2H9a2,2,0,0,0-2,2v6H4V12H7v3a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V12.6l3,3.75V28Z"
  })), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H25V18h3V4H14V7H12V4a2,2,0,0,1,2-2H28a2,2,0,0,1,2,2V18A2,2,0,0,1,28,20Z"
  })), children);
});
var WatsonHealthSaveImage16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSaveImage16(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.56,15.1l-3.48-4.35A2,2,0,0,0,16.52,10H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V16.35A2,2,0,0,0,21.56,15.1ZM9,12h6v3H9Zm6,16H9V22h6Zm2,0V22a2,2,0,0,0-2-2H9a2,2,0,0,0-2,2v6H4V12H7v3a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V12.6l3,3.75V28Z"
  })), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H25V18h3V4H14V7H12V4a2,2,0,0,1,2-2H28a2,2,0,0,1,2,2V18A2,2,0,0,1,28,20Z"
  })), children);
});
var SaveModel32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SaveModel32(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20l1.4272,1.9028L23,26.9629l-4.4272-5.06L20,20h6m1-2H19l-3,4,7,8,7-8-3-4Z"
  })), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,26H12V18h2V16H12a2,2,0,0,0-2,2v8H6V6h4v4a2,2,0,0,0,2,2h8a2,2,0,0,0,2-2V6.41l4,4V16h2V10a1,1,0,0,0-.29-.71l-5-5A.9989.9989,0,0,0,22,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H16ZM12,6h8v4H12Z"
  })), children);
});
var SaveModel24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SaveModel24(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20l1.4272,1.9028L23,26.9629l-4.4272-5.06L20,20h6m1-2H19l-3,4,7,8,7-8-3-4Z"
  })), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,26H12V18h2V16H12a2,2,0,0,0-2,2v8H6V6h4v4a2,2,0,0,0,2,2h8a2,2,0,0,0,2-2V6.41l4,4V16h2V10a1,1,0,0,0-.29-.71l-5-5A.9989.9989,0,0,0,22,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H16ZM12,6h8v4H12Z"
  })), children);
});
var SaveModel20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SaveModel20(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20l1.4272,1.9028L23,26.9629l-4.4272-5.06L20,20h6m1-2H19l-3,4,7,8,7-8-3-4Z"
  })), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,26H12V18h2V16H12a2,2,0,0,0-2,2v8H6V6h4v4a2,2,0,0,0,2,2h8a2,2,0,0,0,2-2V6.41l4,4V16h2V10a1,1,0,0,0-.29-.71l-5-5A.9989.9989,0,0,0,22,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H16ZM12,6h8v4H12Z"
  })), children);
});
var SaveModel16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SaveModel16(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20l1.4272,1.9028L23,26.9629l-4.4272-5.06L20,20h6m1-2H19l-3,4,7,8,7-8-3-4Z"
  })), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,26H12V18h2V16H12a2,2,0,0,0-2,2v8H6V6h4v4a2,2,0,0,0,2,2h8a2,2,0,0,0,2-2V6.41l4,4V16h2V10a1,1,0,0,0-.29-.71l-5-5A.9989.9989,0,0,0,22,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H16ZM12,6h8v4H12Z"
  })), children);
});
var WatsonHealthSaveSeries32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSaveSeries32(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.56,15.1l-3.48-4.35A2,2,0,0,0,16.52,10H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V16.35A2,2,0,0,0,21.56,15.1ZM9,12h6v3H9Zm6,16H9V22h6Zm2,0V22a2,2,0,0,0-2-2H9a2,2,0,0,0-2,2v6H4V12H7v3a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V12.6l3,3.75V28Z"
  })), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,21H25V7H11V5H25a2,2,0,0,1,2,2Z"
  })), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32,14H30V2H18V0H30a2,2,0,0,1,2,2Z"
  })), children);
});
var WatsonHealthSaveSeries24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSaveSeries24(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.56,15.1l-3.48-4.35A2,2,0,0,0,16.52,10H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V16.35A2,2,0,0,0,21.56,15.1ZM9,12h6v3H9Zm6,16H9V22h6Zm2,0V22a2,2,0,0,0-2-2H9a2,2,0,0,0-2,2v6H4V12H7v3a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V12.6l3,3.75V28Z"
  })), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,21H25V7H11V5H25a2,2,0,0,1,2,2Z"
  })), _path390 || (_path390 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32,14H30V2H18V0H30a2,2,0,0,1,2,2Z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-23.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-23.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Scale16": () => (/* binding */ Scale16),
/* harmony export */   "Scale20": () => (/* binding */ Scale20),
/* harmony export */   "Scale24": () => (/* binding */ Scale24),
/* harmony export */   "Scale32": () => (/* binding */ Scale32),
/* harmony export */   "Scales16": () => (/* binding */ Scales16),
/* harmony export */   "Scales20": () => (/* binding */ Scales20),
/* harmony export */   "Scales24": () => (/* binding */ Scales24),
/* harmony export */   "Scales32": () => (/* binding */ Scales32),
/* harmony export */   "ScalesTipped16": () => (/* binding */ ScalesTipped16),
/* harmony export */   "ScalesTipped20": () => (/* binding */ ScalesTipped20),
/* harmony export */   "ScalesTipped24": () => (/* binding */ ScalesTipped24),
/* harmony export */   "ScalesTipped32": () => (/* binding */ ScalesTipped32),
/* harmony export */   "Scalpel16": () => (/* binding */ Scalpel16),
/* harmony export */   "Scalpel20": () => (/* binding */ Scalpel20),
/* harmony export */   "Scalpel24": () => (/* binding */ Scalpel24),
/* harmony export */   "Scalpel32": () => (/* binding */ Scalpel32),
/* harmony export */   "Scan16": () => (/* binding */ Scan16),
/* harmony export */   "Scan20": () => (/* binding */ Scan20),
/* harmony export */   "Scan24": () => (/* binding */ Scan24),
/* harmony export */   "Scan32": () => (/* binding */ Scan32),
/* harmony export */   "ScanAlt16": () => (/* binding */ ScanAlt16),
/* harmony export */   "ScanAlt20": () => (/* binding */ ScanAlt20),
/* harmony export */   "ScanAlt24": () => (/* binding */ ScanAlt24),
/* harmony export */   "ScanAlt32": () => (/* binding */ ScanAlt32),
/* harmony export */   "ScanDisabled16": () => (/* binding */ ScanDisabled16),
/* harmony export */   "ScanDisabled20": () => (/* binding */ ScanDisabled20),
/* harmony export */   "ScanDisabled24": () => (/* binding */ ScanDisabled24),
/* harmony export */   "ScanDisabled32": () => (/* binding */ ScanDisabled32),
/* harmony export */   "ScatterMatrix16": () => (/* binding */ ScatterMatrix16),
/* harmony export */   "ScatterMatrix20": () => (/* binding */ ScatterMatrix20),
/* harmony export */   "ScatterMatrix24": () => (/* binding */ ScatterMatrix24),
/* harmony export */   "ScatterMatrix32": () => (/* binding */ ScatterMatrix32),
/* harmony export */   "Schematics16": () => (/* binding */ Schematics16),
/* harmony export */   "Schematics20": () => (/* binding */ Schematics20),
/* harmony export */   "Schematics24": () => (/* binding */ Schematics24),
/* harmony export */   "Schematics32": () => (/* binding */ Schematics32),
/* harmony export */   "ScisControlTower16": () => (/* binding */ ScisControlTower16),
/* harmony export */   "ScisControlTower20": () => (/* binding */ ScisControlTower20),
/* harmony export */   "ScisControlTower24": () => (/* binding */ ScisControlTower24),
/* harmony export */   "ScisControlTower32": () => (/* binding */ ScisControlTower32),
/* harmony export */   "ScisTransparentSupply16": () => (/* binding */ ScisTransparentSupply16),
/* harmony export */   "ScisTransparentSupply20": () => (/* binding */ ScisTransparentSupply20),
/* harmony export */   "ScisTransparentSupply24": () => (/* binding */ ScisTransparentSupply24),
/* harmony export */   "ScisTransparentSupply32": () => (/* binding */ ScisTransparentSupply32),
/* harmony export */   "Scooter16": () => (/* binding */ Scooter16),
/* harmony export */   "Scooter20": () => (/* binding */ Scooter20),
/* harmony export */   "Scooter24": () => (/* binding */ Scooter24),
/* harmony export */   "Scooter32": () => (/* binding */ Scooter32),
/* harmony export */   "ScooterFront16": () => (/* binding */ ScooterFront16),
/* harmony export */   "ScooterFront20": () => (/* binding */ ScooterFront20),
/* harmony export */   "ScooterFront24": () => (/* binding */ ScooterFront24),
/* harmony export */   "ScooterFront32": () => (/* binding */ ScooterFront32),
/* harmony export */   "Screen16": () => (/* binding */ Screen16),
/* harmony export */   "Screen20": () => (/* binding */ Screen20),
/* harmony export */   "Screen24": () => (/* binding */ Screen24),
/* harmony export */   "Screen32": () => (/* binding */ Screen32),
/* harmony export */   "ScreenOff16": () => (/* binding */ ScreenOff16),
/* harmony export */   "ScreenOff20": () => (/* binding */ ScreenOff20),
/* harmony export */   "ScreenOff24": () => (/* binding */ ScreenOff24),
/* harmony export */   "ScreenOff32": () => (/* binding */ ScreenOff32),
/* harmony export */   "Script16": () => (/* binding */ Script16),
/* harmony export */   "Script20": () => (/* binding */ Script20),
/* harmony export */   "Script24": () => (/* binding */ Script24),
/* harmony export */   "Script32": () => (/* binding */ Script32),
/* harmony export */   "ScriptReference16": () => (/* binding */ ScriptReference16),
/* harmony export */   "ScriptReference20": () => (/* binding */ ScriptReference20),
/* harmony export */   "ScriptReference24": () => (/* binding */ ScriptReference24),
/* harmony export */   "ScriptReference32": () => (/* binding */ ScriptReference32),
/* harmony export */   "Sdk16": () => (/* binding */ Sdk16),
/* harmony export */   "Sdk20": () => (/* binding */ Sdk20),
/* harmony export */   "Sdk24": () => (/* binding */ Sdk24),
/* harmony export */   "Sdk32": () => (/* binding */ Sdk32),
/* harmony export */   "Search16": () => (/* binding */ Search16),
/* harmony export */   "Search20": () => (/* binding */ Search20),
/* harmony export */   "Search24": () => (/* binding */ Search24),
/* harmony export */   "Search32": () => (/* binding */ Search32),
/* harmony export */   "SearchAdvanced16": () => (/* binding */ SearchAdvanced16),
/* harmony export */   "SearchAdvanced20": () => (/* binding */ SearchAdvanced20),
/* harmony export */   "SearchAdvanced24": () => (/* binding */ SearchAdvanced24),
/* harmony export */   "SearchAdvanced32": () => (/* binding */ SearchAdvanced32),
/* harmony export */   "SearchLocate16": () => (/* binding */ SearchLocate16),
/* harmony export */   "SearchLocate20": () => (/* binding */ SearchLocate20),
/* harmony export */   "SearchLocate24": () => (/* binding */ SearchLocate24),
/* harmony export */   "SearchLocate32": () => (/* binding */ SearchLocate32),
/* harmony export */   "Security16": () => (/* binding */ Security16),
/* harmony export */   "Security20": () => (/* binding */ Security20),
/* harmony export */   "Security24": () => (/* binding */ Security24),
/* harmony export */   "Security32": () => (/* binding */ Security32),
/* harmony export */   "SecurityServices16": () => (/* binding */ SecurityServices16),
/* harmony export */   "SecurityServices20": () => (/* binding */ SecurityServices20),
/* harmony export */   "SecurityServices24": () => (/* binding */ SecurityServices24),
/* harmony export */   "SecurityServices32": () => (/* binding */ SecurityServices32),
/* harmony export */   "SelectWindow16": () => (/* binding */ SelectWindow16),
/* harmony export */   "SelectWindow20": () => (/* binding */ SelectWindow20),
/* harmony export */   "SelectWindow24": () => (/* binding */ SelectWindow24),
/* harmony export */   "SelectWindow32": () => (/* binding */ SelectWindow32),
/* harmony export */   "Select_0116": () => (/* binding */ Select_0116),
/* harmony export */   "Select_0120": () => (/* binding */ Select_0120),
/* harmony export */   "Select_0124": () => (/* binding */ Select_0124),
/* harmony export */   "Select_0132": () => (/* binding */ Select_0132),
/* harmony export */   "Select_0216": () => (/* binding */ Select_0216),
/* harmony export */   "Select_0220": () => (/* binding */ Select_0220),
/* harmony export */   "Select_0224": () => (/* binding */ Select_0224),
/* harmony export */   "Select_0232": () => (/* binding */ Select_0232),
/* harmony export */   "Send16": () => (/* binding */ Send16),
/* harmony export */   "Send20": () => (/* binding */ Send20),
/* harmony export */   "Send24": () => (/* binding */ Send24),
/* harmony export */   "Send32": () => (/* binding */ Send32),
/* harmony export */   "SendAlt16": () => (/* binding */ SendAlt16),
/* harmony export */   "SendAlt20": () => (/* binding */ SendAlt20),
/* harmony export */   "SendAlt24": () => (/* binding */ SendAlt24),
/* harmony export */   "SendAlt32": () => (/* binding */ SendAlt32),
/* harmony export */   "SendAltFilled16": () => (/* binding */ SendAltFilled16),
/* harmony export */   "SendAltFilled20": () => (/* binding */ SendAltFilled20),
/* harmony export */   "SendAltFilled24": () => (/* binding */ SendAltFilled24),
/* harmony export */   "SendAltFilled32": () => (/* binding */ SendAltFilled32),
/* harmony export */   "SendBackward16": () => (/* binding */ SendBackward16),
/* harmony export */   "SendBackward20": () => (/* binding */ SendBackward20),
/* harmony export */   "SendBackward24": () => (/* binding */ SendBackward24),
/* harmony export */   "SendBackward32": () => (/* binding */ SendBackward32),
/* harmony export */   "SendFilled16": () => (/* binding */ SendFilled16),
/* harmony export */   "SendFilled20": () => (/* binding */ SendFilled20),
/* harmony export */   "SendFilled24": () => (/* binding */ SendFilled24),
/* harmony export */   "SendFilled32": () => (/* binding */ SendFilled32),
/* harmony export */   "SendToBack16": () => (/* binding */ SendToBack16),
/* harmony export */   "SendToBack20": () => (/* binding */ SendToBack20),
/* harmony export */   "SendToBack24": () => (/* binding */ SendToBack24),
/* harmony export */   "SendToBack32": () => (/* binding */ SendToBack32),
/* harmony export */   "ServerDns16": () => (/* binding */ ServerDns16),
/* harmony export */   "ServerDns20": () => (/* binding */ ServerDns20),
/* harmony export */   "ServerDns24": () => (/* binding */ ServerDns24),
/* harmony export */   "ServerDns32": () => (/* binding */ ServerDns32),
/* harmony export */   "ServerProxy16": () => (/* binding */ ServerProxy16),
/* harmony export */   "ServerProxy20": () => (/* binding */ ServerProxy20),
/* harmony export */   "ServerProxy24": () => (/* binding */ ServerProxy24),
/* harmony export */   "ServerProxy32": () => (/* binding */ ServerProxy32),
/* harmony export */   "ServerTime16": () => (/* binding */ ServerTime16),
/* harmony export */   "ServerTime20": () => (/* binding */ ServerTime20),
/* harmony export */   "ServerTime24": () => (/* binding */ ServerTime24),
/* harmony export */   "ServerTime32": () => (/* binding */ ServerTime32),
/* harmony export */   "ServiceDesk16": () => (/* binding */ ServiceDesk16),
/* harmony export */   "ServiceDesk20": () => (/* binding */ ServiceDesk20),
/* harmony export */   "ServiceDesk24": () => (/* binding */ ServiceDesk24),
/* harmony export */   "ServiceDesk32": () => (/* binding */ ServiceDesk32),
/* harmony export */   "SessionBorderControl16": () => (/* binding */ SessionBorderControl16),
/* harmony export */   "SessionBorderControl20": () => (/* binding */ SessionBorderControl20),
/* harmony export */   "SessionBorderControl24": () => (/* binding */ SessionBorderControl24),
/* harmony export */   "SessionBorderControl32": () => (/* binding */ SessionBorderControl32),
/* harmony export */   "Settings16": () => (/* binding */ Settings16),
/* harmony export */   "Settings20": () => (/* binding */ Settings20),
/* harmony export */   "Settings24": () => (/* binding */ Settings24),
/* harmony export */   "Settings32": () => (/* binding */ Settings32),
/* harmony export */   "SettingsAdjust16": () => (/* binding */ SettingsAdjust16),
/* harmony export */   "SettingsAdjust20": () => (/* binding */ SettingsAdjust20),
/* harmony export */   "SettingsAdjust24": () => (/* binding */ SettingsAdjust24),
/* harmony export */   "SettingsAdjust32": () => (/* binding */ SettingsAdjust32),
/* harmony export */   "SettingsCheck16": () => (/* binding */ SettingsCheck16),
/* harmony export */   "SettingsCheck20": () => (/* binding */ SettingsCheck20),
/* harmony export */   "SettingsCheck24": () => (/* binding */ SettingsCheck24),
/* harmony export */   "SettingsCheck32": () => (/* binding */ SettingsCheck32),
/* harmony export */   "SettingsServices16": () => (/* binding */ SettingsServices16),
/* harmony export */   "SettingsServices20": () => (/* binding */ SettingsServices20),
/* harmony export */   "SettingsServices24": () => (/* binding */ SettingsServices24),
/* harmony export */   "SettingsServices32": () => (/* binding */ SettingsServices32),
/* harmony export */   "SettingsView16": () => (/* binding */ SettingsView16),
/* harmony export */   "SettingsView20": () => (/* binding */ SettingsView20),
/* harmony export */   "SettingsView24": () => (/* binding */ SettingsView24),
/* harmony export */   "SettingsView32": () => (/* binding */ SettingsView32),
/* harmony export */   "ShapeExcept16": () => (/* binding */ ShapeExcept16),
/* harmony export */   "ShapeExcept20": () => (/* binding */ ShapeExcept20),
/* harmony export */   "ShapeExcept24": () => (/* binding */ ShapeExcept24),
/* harmony export */   "ShapeExcept32": () => (/* binding */ ShapeExcept32),
/* harmony export */   "ShapeExclude16": () => (/* binding */ ShapeExclude16),
/* harmony export */   "ShapeExclude20": () => (/* binding */ ShapeExclude20),
/* harmony export */   "ShapeExclude24": () => (/* binding */ ShapeExclude24),
/* harmony export */   "ShapeExclude32": () => (/* binding */ ShapeExclude32),
/* harmony export */   "ShapeIntersect16": () => (/* binding */ ShapeIntersect16),
/* harmony export */   "ShapeIntersect20": () => (/* binding */ ShapeIntersect20),
/* harmony export */   "ShapeIntersect24": () => (/* binding */ ShapeIntersect24),
/* harmony export */   "ShapeIntersect32": () => (/* binding */ ShapeIntersect32),
/* harmony export */   "ShapeJoin16": () => (/* binding */ ShapeJoin16),
/* harmony export */   "ShapeJoin20": () => (/* binding */ ShapeJoin20),
/* harmony export */   "ShapeJoin24": () => (/* binding */ ShapeJoin24),
/* harmony export */   "ShapeJoin32": () => (/* binding */ ShapeJoin32),
/* harmony export */   "ShapeUnite16": () => (/* binding */ ShapeUnite16),
/* harmony export */   "ShapeUnite20": () => (/* binding */ ShapeUnite20),
/* harmony export */   "ShapeUnite24": () => (/* binding */ ShapeUnite24),
/* harmony export */   "ShapeUnite32": () => (/* binding */ ShapeUnite32),
/* harmony export */   "Share16": () => (/* binding */ Share16),
/* harmony export */   "Share20": () => (/* binding */ Share20),
/* harmony export */   "Share24": () => (/* binding */ Share24),
/* harmony export */   "Share32": () => (/* binding */ Share32),
/* harmony export */   "ShareKnowledge16": () => (/* binding */ ShareKnowledge16),
/* harmony export */   "ShareKnowledge20": () => (/* binding */ ShareKnowledge20),
/* harmony export */   "ShareKnowledge24": () => (/* binding */ ShareKnowledge24),
/* harmony export */   "ShareKnowledge32": () => (/* binding */ ShareKnowledge32),
/* harmony export */   "ShoppingBag16": () => (/* binding */ ShoppingBag16),
/* harmony export */   "ShoppingBag20": () => (/* binding */ ShoppingBag20),
/* harmony export */   "ShoppingBag24": () => (/* binding */ ShoppingBag24),
/* harmony export */   "ShoppingBag32": () => (/* binding */ ShoppingBag32),
/* harmony export */   "ShoppingCart16": () => (/* binding */ ShoppingCart16),
/* harmony export */   "ShoppingCart20": () => (/* binding */ ShoppingCart20),
/* harmony export */   "ShoppingCart24": () => (/* binding */ ShoppingCart24),
/* harmony export */   "ShoppingCart32": () => (/* binding */ ShoppingCart32),
/* harmony export */   "ShoppingCartArrowDown16": () => (/* binding */ ShoppingCartArrowDown16),
/* harmony export */   "ShoppingCartArrowDown20": () => (/* binding */ ShoppingCartArrowDown20),
/* harmony export */   "ShoppingCartArrowDown24": () => (/* binding */ ShoppingCartArrowDown24),
/* harmony export */   "ShoppingCartArrowDown32": () => (/* binding */ ShoppingCartArrowDown32),
/* harmony export */   "ShoppingCartArrowUp16": () => (/* binding */ ShoppingCartArrowUp16),
/* harmony export */   "ShoppingCartArrowUp20": () => (/* binding */ ShoppingCartArrowUp20),
/* harmony export */   "ShoppingCartArrowUp24": () => (/* binding */ ShoppingCartArrowUp24),
/* harmony export */   "ShoppingCartArrowUp32": () => (/* binding */ ShoppingCartArrowUp32),
/* harmony export */   "ShoppingCartClear16": () => (/* binding */ ShoppingCartClear16),
/* harmony export */   "ShoppingCartClear20": () => (/* binding */ ShoppingCartClear20),
/* harmony export */   "ShoppingCartClear24": () => (/* binding */ ShoppingCartClear24),
/* harmony export */   "ShoppingCartClear32": () => (/* binding */ ShoppingCartClear32),
/* harmony export */   "ShoppingCartError16": () => (/* binding */ ShoppingCartError16),
/* harmony export */   "ShoppingCartError20": () => (/* binding */ ShoppingCartError20),
/* harmony export */   "ShoppingCartError24": () => (/* binding */ ShoppingCartError24),
/* harmony export */   "ShoppingCartError32": () => (/* binding */ ShoppingCartError32),
/* harmony export */   "ShoppingCartMinus16": () => (/* binding */ ShoppingCartMinus16),
/* harmony export */   "ShoppingCartMinus20": () => (/* binding */ ShoppingCartMinus20),
/* harmony export */   "ShoppingCartMinus24": () => (/* binding */ ShoppingCartMinus24),
/* harmony export */   "ShoppingCartMinus32": () => (/* binding */ ShoppingCartMinus32),
/* harmony export */   "ShoppingCartPlus16": () => (/* binding */ ShoppingCartPlus16),
/* harmony export */   "ShoppingCartPlus20": () => (/* binding */ ShoppingCartPlus20),
/* harmony export */   "ShoppingCartPlus24": () => (/* binding */ ShoppingCartPlus24),
/* harmony export */   "ShoppingCartPlus32": () => (/* binding */ ShoppingCartPlus32),
/* harmony export */   "ShoppingCatalog16": () => (/* binding */ ShoppingCatalog16),
/* harmony export */   "ShoppingCatalog20": () => (/* binding */ ShoppingCatalog20),
/* harmony export */   "ShoppingCatalog24": () => (/* binding */ ShoppingCatalog24),
/* harmony export */   "ShoppingCatalog32": () => (/* binding */ ShoppingCatalog32),
/* harmony export */   "ShowDataCards16": () => (/* binding */ ShowDataCards16),
/* harmony export */   "ShowDataCards20": () => (/* binding */ ShowDataCards20),
/* harmony export */   "ShowDataCards24": () => (/* binding */ ShowDataCards24),
/* harmony export */   "ShowDataCards32": () => (/* binding */ ShowDataCards32),
/* harmony export */   "WatsonHealthSaveSeries16": () => (/* binding */ WatsonHealthSaveSeries16),
/* harmony export */   "WatsonHealthSaveSeries20": () => (/* binding */ WatsonHealthSaveSeries20),
/* harmony export */   "WatsonHealthScalpelCursor16": () => (/* binding */ WatsonHealthScalpelCursor16),
/* harmony export */   "WatsonHealthScalpelCursor20": () => (/* binding */ WatsonHealthScalpelCursor20),
/* harmony export */   "WatsonHealthScalpelCursor24": () => (/* binding */ WatsonHealthScalpelCursor24),
/* harmony export */   "WatsonHealthScalpelCursor32": () => (/* binding */ WatsonHealthScalpelCursor32),
/* harmony export */   "WatsonHealthScalpelLasso16": () => (/* binding */ WatsonHealthScalpelLasso16),
/* harmony export */   "WatsonHealthScalpelLasso20": () => (/* binding */ WatsonHealthScalpelLasso20),
/* harmony export */   "WatsonHealthScalpelLasso24": () => (/* binding */ WatsonHealthScalpelLasso24),
/* harmony export */   "WatsonHealthScalpelLasso32": () => (/* binding */ WatsonHealthScalpelLasso32),
/* harmony export */   "WatsonHealthScalpelSelect16": () => (/* binding */ WatsonHealthScalpelSelect16),
/* harmony export */   "WatsonHealthScalpelSelect20": () => (/* binding */ WatsonHealthScalpelSelect20),
/* harmony export */   "WatsonHealthScalpelSelect24": () => (/* binding */ WatsonHealthScalpelSelect24),
/* harmony export */   "WatsonHealthScalpelSelect32": () => (/* binding */ WatsonHealthScalpelSelect32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _circle, _circle2, _circle3, _path55, _circle4, _circle5, _circle6, _path56, _circle7, _circle8, _circle9, _path57, _circle10, _circle11, _circle12, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _path65, _path66, _path67, _path68, _path69, _path70, _path71, _path72, _path73, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _circle13, _path180, _circle14, _path181, _circle15, _path182, _circle16, _path183, _circle17, _path184, _path185, _circle18, _path186, _path187, _circle19, _path188, _path189, _circle20, _path190, _path191, _circle21, _path192, _path193, _path194, _circle22, _path195, _path196, _path197, _circle23, _path198, _path199, _path200, _circle24, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _path224, _path225, _path226, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _circle25, _path247, _path248, _circle26, _path249, _path250, _circle27, _path251, _path252, _circle28, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _circle29, _circle30, _path291, _circle31, _circle32, _path292, _circle33, _circle34, _path293, _circle35, _circle36, _path294, _circle37, _circle38, _path295, _path296, _circle39, _circle40, _path297, _path298, _circle41, _circle42, _path299, _path300, _circle43, _circle44, _path301, _path302, _circle45, _circle46, _path303, _path304, _circle47, _circle48, _path305, _path306, _circle49, _circle50, _path307, _path308, _circle51, _circle52, _path309, _path310, _circle53, _circle54, _path311, _path312, _circle55, _circle56, _path313, _path314, _circle57, _circle58, _path315, _path316, _circle59, _circle60, _path317, _path318, _circle61, _circle62, _path319, _path320, _circle63, _circle64, _path321, _path322, _circle65, _circle66, _path323, _path324, _circle67, _circle68, _path325, _path326, _circle69, _circle70, _path327, _path328, _circle71, _circle72, _path329, _path330, _circle73, _circle74, _path331, _path332, _circle75, _circle76, _path333, _path334, _circle77, _circle78, _path335, _path336, _circle79, _circle80, _path337, _path338, _circle81, _circle82, _path339, _path340, _circle83, _circle84, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var WatsonHealthSaveSeries20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSaveSeries20(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.56,15.1l-3.48-4.35A2,2,0,0,0,16.52,10H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V16.35A2,2,0,0,0,21.56,15.1ZM9,12h6v3H9Zm6,16H9V22h6Zm2,0V22a2,2,0,0,0-2-2H9a2,2,0,0,0-2,2v6H4V12H7v3a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V12.6l3,3.75V28Z"
  })), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,21H25V7H11V5H25a2,2,0,0,1,2,2Z"
  })), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32,14H30V2H18V0H30a2,2,0,0,1,2,2Z"
  })), children);
});
var WatsonHealthSaveSeries16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSaveSeries16(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.56,15.1l-3.48-4.35A2,2,0,0,0,16.52,10H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V16.35A2,2,0,0,0,21.56,15.1ZM9,12h6v3H9Zm6,16H9V22h6Zm2,0V22a2,2,0,0,0-2-2H9a2,2,0,0,0-2,2v6H4V12H7v3a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V12.6l3,3.75V28Z"
  })), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,21H25V7H11V5H25a2,2,0,0,1,2,2Z"
  })), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32,14H30V2H18V0H30a2,2,0,0,1,2,2Z"
  })), children);
});
var Scale32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scale32(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,17H7a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V19A2,2,0,0,0,13,17ZM7,25V19h6v6Z"
  })), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,21v2h6a2,2,0,0,0,2-2V7a2,2,0,0,0-2-2H11A2,2,0,0,0,9,7v6h2V7H25V21"
  })), children);
});
var Scale24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scale24(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,17H7a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V19A2,2,0,0,0,13,17ZM7,25V19h6v6Z"
  })), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,21v2h6a2,2,0,0,0,2-2V7a2,2,0,0,0-2-2H11A2,2,0,0,0,9,7v6h2V7H25V21"
  })), children);
});
var Scale20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scale20(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,17H7a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V19A2,2,0,0,0,13,17ZM7,25V19h6v6Z"
  })), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,21v2h6a2,2,0,0,0,2-2V7a2,2,0,0,0-2-2H11A2,2,0,0,0,9,7v6h2V7H25V21"
  })), children);
});
var Scale16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scale16(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,17H7a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V19A2,2,0,0,0,13,17ZM7,25V19h6v6Z"
  })), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,21v2h6a2,2,0,0,0,2-2V7a2,2,0,0,0-2-2H11A2,2,0,0,0,9,7v6h2V7H25V21"
  })), children);
});
var Scales32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scales32(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,16a5,5,0,0,0,10,0,1,1,0,0,0-.1055-.4473L25.896,7.5562a.8913.8913,0,0,0-.0454-.0816A1,1,0,0,0,25,7H18.8218A3.0155,3.0155,0,0,0,17,5.1841V2H15V5.1841A3.0155,3.0155,0,0,0,13.1782,7H7a1,1,0,0,0-.8945.5527l-4,8A1,1,0,0,0,2,16a5,5,0,0,0,10,0,1,1,0,0,0-.1055-.4473L8.6182,9h4.56A3.0147,3.0147,0,0,0,15,10.8154V28H6v2H26V28H17V10.8159A3.0155,3.0155,0,0,0,18.8218,9h4.56l-3.2763,6.5527A1,1,0,0,0,20,16ZM7,19a2.9958,2.9958,0,0,1-2.8152-2h5.63A2.9956,2.9956,0,0,1,7,19Zm2.3821-4H4.6179L7,10.2363ZM16,9a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,16,9Zm9,10a2.9958,2.9958,0,0,1-2.8152-2h5.63A2.9956,2.9956,0,0,1,25,19Zm0-8.7637L27.3821,15H22.6179Z"
  })), children);
});
var Scales24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scales24(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,16a5,5,0,0,0,10,0,1,1,0,0,0-.1055-.4473L25.896,7.5562a.8913.8913,0,0,0-.0454-.0816A1,1,0,0,0,25,7H18.8218A3.0155,3.0155,0,0,0,17,5.1841V2H15V5.1841A3.0155,3.0155,0,0,0,13.1782,7H7a1,1,0,0,0-.8945.5527l-4,8A1,1,0,0,0,2,16a5,5,0,0,0,10,0,1,1,0,0,0-.1055-.4473L8.6182,9h4.56A3.0147,3.0147,0,0,0,15,10.8154V28H6v2H26V28H17V10.8159A3.0155,3.0155,0,0,0,18.8218,9h4.56l-3.2763,6.5527A1,1,0,0,0,20,16ZM7,19a2.9958,2.9958,0,0,1-2.8152-2h5.63A2.9956,2.9956,0,0,1,7,19Zm2.3821-4H4.6179L7,10.2363ZM16,9a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,16,9Zm9,10a2.9958,2.9958,0,0,1-2.8152-2h5.63A2.9956,2.9956,0,0,1,25,19Zm0-8.7637L27.3821,15H22.6179Z"
  })), children);
});
var Scales20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scales20(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,16a5,5,0,0,0,10,0,1,1,0,0,0-.1055-.4473L25.896,7.5562a.8913.8913,0,0,0-.0454-.0816A1,1,0,0,0,25,7H18.8218A3.0155,3.0155,0,0,0,17,5.1841V2H15V5.1841A3.0155,3.0155,0,0,0,13.1782,7H7a1,1,0,0,0-.8945.5527l-4,8A1,1,0,0,0,2,16a5,5,0,0,0,10,0,1,1,0,0,0-.1055-.4473L8.6182,9h4.56A3.0147,3.0147,0,0,0,15,10.8154V28H6v2H26V28H17V10.8159A3.0155,3.0155,0,0,0,18.8218,9h4.56l-3.2763,6.5527A1,1,0,0,0,20,16ZM7,19a2.9958,2.9958,0,0,1-2.8152-2h5.63A2.9956,2.9956,0,0,1,7,19Zm2.3821-4H4.6179L7,10.2363ZM16,9a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,16,9Zm9,10a2.9958,2.9958,0,0,1-2.8152-2h5.63A2.9956,2.9956,0,0,1,25,19Zm0-8.7637L27.3821,15H22.6179Z"
  })), children);
});
var Scales16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scales16(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,16a5,5,0,0,0,10,0,1,1,0,0,0-.1055-.4473L25.896,7.5562a.8913.8913,0,0,0-.0454-.0816A1,1,0,0,0,25,7H18.8218A3.0155,3.0155,0,0,0,17,5.1841V2H15V5.1841A3.0155,3.0155,0,0,0,13.1782,7H7a1,1,0,0,0-.8945.5527l-4,8A1,1,0,0,0,2,16a5,5,0,0,0,10,0,1,1,0,0,0-.1055-.4473L8.6182,9h4.56A3.0147,3.0147,0,0,0,15,10.8154V28H6v2H26V28H17V10.8159A3.0155,3.0155,0,0,0,18.8218,9h4.56l-3.2763,6.5527A1,1,0,0,0,20,16ZM7,19a2.9958,2.9958,0,0,1-2.8152-2h5.63A2.9956,2.9956,0,0,1,7,19Zm2.3821-4H4.6179L7,10.2363ZM16,9a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,16,9Zm9,10a2.9958,2.9958,0,0,1-2.8152-2h5.63A2.9956,2.9956,0,0,1,25,19Zm0-8.7637L27.3821,15H22.6179Z"
  })), children);
});
var ScalesTipped32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScalesTipped32(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,13a5,5,0,0,0,10,0,1,1,0,0,0-.1055-.4473l-4-8a1,1,0,0,0-1.2109-.5014l-6.3308,2.11A3.0322,3.0322,0,0,0,17,5.1841V2H15V5.1841a2.9949,2.9949,0,0,0-1.9956,2.76l-6.3208,2.107a1,1,0,0,0-.5781.5014l-4,8A1,1,0,0,0,2,19a5,5,0,0,0,10,0,1,1,0,0,0-.1055-.4473L8.41,11.584l5.237-1.7456A3.0285,3.0285,0,0,0,15,10.8154V28H6v2H26V28H17V10.8159a2.9951,2.9951,0,0,0,1.9956-2.76l4.03-1.3438-2.92,5.8408A1,1,0,0,0,20,13ZM7,22a2.9956,2.9956,0,0,1-2.8152-2h5.63A2.9956,2.9956,0,0,1,7,22Zm2.3821-4H4.6179L7,13.2363ZM16,9a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,16,9Zm9,7a2.9958,2.9958,0,0,1-2.8152-2h5.63A2.9956,2.9956,0,0,1,25,16Zm0-8.7637L27.3821,12H22.6179Z"
  })), children);
});
var ScalesTipped24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScalesTipped24(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,13a5,5,0,0,0,10,0,1,1,0,0,0-.1055-.4473l-4-8a1,1,0,0,0-1.2109-.5014l-6.3308,2.11A3.0322,3.0322,0,0,0,17,5.1841V2H15V5.1841a2.9949,2.9949,0,0,0-1.9956,2.76l-6.3208,2.107a1,1,0,0,0-.5781.5014l-4,8A1,1,0,0,0,2,19a5,5,0,0,0,10,0,1,1,0,0,0-.1055-.4473L8.41,11.584l5.237-1.7456A3.0285,3.0285,0,0,0,15,10.8154V28H6v2H26V28H17V10.8159a2.9951,2.9951,0,0,0,1.9956-2.76l4.03-1.3438-2.92,5.8408A1,1,0,0,0,20,13ZM7,22a2.9956,2.9956,0,0,1-2.8152-2h5.63A2.9956,2.9956,0,0,1,7,22Zm2.3821-4H4.6179L7,13.2363ZM16,9a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,16,9Zm9,7a2.9958,2.9958,0,0,1-2.8152-2h5.63A2.9956,2.9956,0,0,1,25,16Zm0-8.7637L27.3821,12H22.6179Z"
  })), children);
});
var ScalesTipped20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScalesTipped20(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,13a5,5,0,0,0,10,0,1,1,0,0,0-.1055-.4473l-4-8a1,1,0,0,0-1.2109-.5014l-6.3308,2.11A3.0322,3.0322,0,0,0,17,5.1841V2H15V5.1841a2.9949,2.9949,0,0,0-1.9956,2.76l-6.3208,2.107a1,1,0,0,0-.5781.5014l-4,8A1,1,0,0,0,2,19a5,5,0,0,0,10,0,1,1,0,0,0-.1055-.4473L8.41,11.584l5.237-1.7456A3.0285,3.0285,0,0,0,15,10.8154V28H6v2H26V28H17V10.8159a2.9951,2.9951,0,0,0,1.9956-2.76l4.03-1.3438-2.92,5.8408A1,1,0,0,0,20,13ZM7,22a2.9956,2.9956,0,0,1-2.8152-2h5.63A2.9956,2.9956,0,0,1,7,22Zm2.3821-4H4.6179L7,13.2363ZM16,9a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,16,9Zm9,7a2.9958,2.9958,0,0,1-2.8152-2h5.63A2.9956,2.9956,0,0,1,25,16Zm0-8.7637L27.3821,12H22.6179Z"
  })), children);
});
var ScalesTipped16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScalesTipped16(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,13a5,5,0,0,0,10,0,1,1,0,0,0-.1055-.4473l-4-8a1,1,0,0,0-1.2109-.5014l-6.3308,2.11A3.0322,3.0322,0,0,0,17,5.1841V2H15V5.1841a2.9949,2.9949,0,0,0-1.9956,2.76l-6.3208,2.107a1,1,0,0,0-.5781.5014l-4,8A1,1,0,0,0,2,19a5,5,0,0,0,10,0,1,1,0,0,0-.1055-.4473L8.41,11.584l5.237-1.7456A3.0285,3.0285,0,0,0,15,10.8154V28H6v2H26V28H17V10.8159a2.9951,2.9951,0,0,0,1.9956-2.76l4.03-1.3438-2.92,5.8408A1,1,0,0,0,20,13ZM7,22a2.9956,2.9956,0,0,1-2.8152-2h5.63A2.9956,2.9956,0,0,1,7,22Zm2.3821-4H4.6179L7,13.2363ZM16,9a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,16,9Zm9,7a2.9958,2.9958,0,0,1-2.8152-2h5.63A2.9956,2.9956,0,0,1,25,16Zm0-8.7637L27.3821,12H22.6179Z"
  })), children);
});
var Scalpel32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scalpel32(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.83,5.17a4.1,4.1,0,0,0-5.66,0L.34,28H9.59a5,5,0,0,0,3.53-1.46L28.83,10.83a4,4,0,0,0,0-5.66ZM12.29,18.88l2.09-2.09,2.83,2.83-2.09,2.09Zm-.58,6.24A3,3,0,0,1,9.59,26H5.17l5.71-5.71,2.83,2.83ZM27.41,9.41l-8.79,8.8-2.83-2.83,8.8-8.79a2,2,0,0,1,2.82,0,2,2,0,0,1,0,2.82Z"
  })), children);
});
var Scalpel24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scalpel24(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.83,5.17a4.1,4.1,0,0,0-5.66,0L.34,28H9.59a5,5,0,0,0,3.53-1.46L28.83,10.83a4,4,0,0,0,0-5.66ZM12.29,18.88l2.09-2.09,2.83,2.83-2.09,2.09Zm-.58,6.24A3,3,0,0,1,9.59,26H5.17l5.71-5.71,2.83,2.83ZM27.41,9.41l-8.79,8.8-2.83-2.83,8.8-8.79a2,2,0,0,1,2.82,0,2,2,0,0,1,0,2.82Z"
  })), children);
});
var Scalpel20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scalpel20(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.83,5.17a4.1,4.1,0,0,0-5.66,0L.34,28H9.59a5,5,0,0,0,3.53-1.46L28.83,10.83a4,4,0,0,0,0-5.66ZM12.29,18.88l2.09-2.09,2.83,2.83-2.09,2.09Zm-.58,6.24A3,3,0,0,1,9.59,26H5.17l5.71-5.71,2.83,2.83ZM27.41,9.41l-8.79,8.8-2.83-2.83,8.8-8.79a2,2,0,0,1,2.82,0,2,2,0,0,1,0,2.82Z"
  })), children);
});
var Scalpel16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scalpel16(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.83,5.17a4.1,4.1,0,0,0-5.66,0L.34,28H9.59a5,5,0,0,0,3.53-1.46L28.83,10.83a4,4,0,0,0,0-5.66ZM12.29,18.88l2.09-2.09,2.83,2.83-2.09,2.09Zm-.58,6.24A3,3,0,0,1,9.59,26H5.17l5.71-5.71,2.83,2.83ZM27.41,9.41l-8.79,8.8-2.83-2.83,8.8-8.79a2,2,0,0,1,2.82,0,2,2,0,0,1,0,2.82Z"
  })), children);
});
var WatsonHealthScalpelCursor32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthScalpelCursor32(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8281 7.1338a4.0941 4.0941 0 00-5.6562 0L.3433 29.9619H9.5889a4.9682 4.9682 0 003.5356-1.4648L28.8281 12.79a3.9984 3.9984 0 000-5.6562zM12.2928 20.8406l2.086-2.0858 2.8293 2.8293L15.1224 23.67zM11.71 27.083a2.9824 2.9824 0 01-2.1215.8789H5.1714l5.7073-5.7072 2.83 2.83zM27.4141 11.376L18.6221 20.17l-2.8293-2.8292 8.7931-8.7928a2.0471 2.0471 0 012.8282 0 1.9993 1.9993 0 010 2.8281zM13 4L4 4 4 13 6 13 6 6 13 6 13 4z"
  })), children);
});
var WatsonHealthScalpelCursor24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthScalpelCursor24(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8281 7.1338a4.0941 4.0941 0 00-5.6562 0L.3433 29.9619H9.5889a4.9682 4.9682 0 003.5356-1.4648L28.8281 12.79a3.9984 3.9984 0 000-5.6562zM12.2928 20.8406l2.086-2.0858 2.8293 2.8293L15.1224 23.67zM11.71 27.083a2.9824 2.9824 0 01-2.1215.8789H5.1714l5.7073-5.7072 2.83 2.83zM27.4141 11.376L18.6221 20.17l-2.8293-2.8292 8.7931-8.7928a2.0471 2.0471 0 012.8282 0 1.9993 1.9993 0 010 2.8281zM13 4L4 4 4 13 6 13 6 6 13 6 13 4z"
  })), children);
});
var WatsonHealthScalpelCursor20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthScalpelCursor20(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8281 7.1338a4.0941 4.0941 0 00-5.6562 0L.3433 29.9619H9.5889a4.9682 4.9682 0 003.5356-1.4648L28.8281 12.79a3.9984 3.9984 0 000-5.6562zM12.2928 20.8406l2.086-2.0858 2.8293 2.8293L15.1224 23.67zM11.71 27.083a2.9824 2.9824 0 01-2.1215.8789H5.1714l5.7073-5.7072 2.83 2.83zM27.4141 11.376L18.6221 20.17l-2.8293-2.8292 8.7931-8.7928a2.0471 2.0471 0 012.8282 0 1.9993 1.9993 0 010 2.8281zM13 4L4 4 4 13 6 13 6 6 13 6 13 4z"
  })), children);
});
var WatsonHealthScalpelCursor16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthScalpelCursor16(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8281 7.1338a4.0941 4.0941 0 00-5.6562 0L.3433 29.9619H9.5889a4.9682 4.9682 0 003.5356-1.4648L28.8281 12.79a3.9984 3.9984 0 000-5.6562zM12.2928 20.8406l2.086-2.0858 2.8293 2.8293L15.1224 23.67zM11.71 27.083a2.9824 2.9824 0 01-2.1215.8789H5.1714l5.7073-5.7072 2.83 2.83zM27.4141 11.376L18.6221 20.17l-2.8293-2.8292 8.7931-8.7928a2.0471 2.0471 0 012.8282 0 1.9993 1.9993 0 010 2.8281zM13 4L4 4 4 13 6 13 6 6 13 6 13 4z"
  })), children);
});
var WatsonHealthScalpelLasso32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthScalpelLasso32(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8281 7.1338a4.0941 4.0941 0 00-5.6562 0L.3433 29.9619H9.5889a4.9682 4.9682 0 003.5356-1.4648L28.8281 12.79a3.9984 3.9984 0 000-5.6562zM12.2928 20.8406l2.086-2.0858 2.8293 2.8293L15.1224 23.67zM11.71 27.083a2.9824 2.9824 0 01-2.1215.8789H5.1714l5.7073-5.7072 2.83 2.83zM27.4141 11.376L18.6221 20.17l-2.8293-2.8292 8.7931-8.7928a2.0471 2.0471 0 012.8282 0 1.9993 1.9993 0 010 2.8281zM11 2H7a4.9843 4.9843 0 00-3.8633 8.1528A2.9586 2.9586 0 003 11a2.9945 2.9945 0 002 2.8154V14a2.0025 2.0025 0 01-2 2H2v2H3a4.0045 4.0045 0 004-4v-.1841A2.9959 2.9959 0 008.8157 12H11A5 5 0 0011 2zM6 12a1 1 0 111-1A1.0009 1.0009 0 016 12zm5-2H8.8157A2.974 2.974 0 004.394 8.4746 2.9908 2.9908 0 017 4h4a3 3 0 010 6z"
  })), children);
});
var WatsonHealthScalpelLasso24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthScalpelLasso24(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8281 7.1338a4.0941 4.0941 0 00-5.6562 0L.3433 29.9619H9.5889a4.9682 4.9682 0 003.5356-1.4648L28.8281 12.79a3.9984 3.9984 0 000-5.6562zM12.2928 20.8406l2.086-2.0858 2.8293 2.8293L15.1224 23.67zM11.71 27.083a2.9824 2.9824 0 01-2.1215.8789H5.1714l5.7073-5.7072 2.83 2.83zM27.4141 11.376L18.6221 20.17l-2.8293-2.8292 8.7931-8.7928a2.0471 2.0471 0 012.8282 0 1.9993 1.9993 0 010 2.8281zM11 2H7a4.9843 4.9843 0 00-3.8633 8.1528A2.9586 2.9586 0 003 11a2.9945 2.9945 0 002 2.8154V14a2.0025 2.0025 0 01-2 2H2v2H3a4.0045 4.0045 0 004-4v-.1841A2.9959 2.9959 0 008.8157 12H11A5 5 0 0011 2zM6 12a1 1 0 111-1A1.0009 1.0009 0 016 12zm5-2H8.8157A2.974 2.974 0 004.394 8.4746 2.9908 2.9908 0 017 4h4a3 3 0 010 6z"
  })), children);
});
var WatsonHealthScalpelLasso20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthScalpelLasso20(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8281 7.1338a4.0941 4.0941 0 00-5.6562 0L.3433 29.9619H9.5889a4.9682 4.9682 0 003.5356-1.4648L28.8281 12.79a3.9984 3.9984 0 000-5.6562zM12.2928 20.8406l2.086-2.0858 2.8293 2.8293L15.1224 23.67zM11.71 27.083a2.9824 2.9824 0 01-2.1215.8789H5.1714l5.7073-5.7072 2.83 2.83zM27.4141 11.376L18.6221 20.17l-2.8293-2.8292 8.7931-8.7928a2.0471 2.0471 0 012.8282 0 1.9993 1.9993 0 010 2.8281zM11 2H7a4.9843 4.9843 0 00-3.8633 8.1528A2.9586 2.9586 0 003 11a2.9945 2.9945 0 002 2.8154V14a2.0025 2.0025 0 01-2 2H2v2H3a4.0045 4.0045 0 004-4v-.1841A2.9959 2.9959 0 008.8157 12H11A5 5 0 0011 2zM6 12a1 1 0 111-1A1.0009 1.0009 0 016 12zm5-2H8.8157A2.974 2.974 0 004.394 8.4746 2.9908 2.9908 0 017 4h4a3 3 0 010 6z"
  })), children);
});
var WatsonHealthScalpelLasso16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthScalpelLasso16(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8281 7.1338a4.0941 4.0941 0 00-5.6562 0L.3433 29.9619H9.5889a4.9682 4.9682 0 003.5356-1.4648L28.8281 12.79a3.9984 3.9984 0 000-5.6562zM12.2928 20.8406l2.086-2.0858 2.8293 2.8293L15.1224 23.67zM11.71 27.083a2.9824 2.9824 0 01-2.1215.8789H5.1714l5.7073-5.7072 2.83 2.83zM27.4141 11.376L18.6221 20.17l-2.8293-2.8292 8.7931-8.7928a2.0471 2.0471 0 012.8282 0 1.9993 1.9993 0 010 2.8281zM11 2H7a4.9843 4.9843 0 00-3.8633 8.1528A2.9586 2.9586 0 003 11a2.9945 2.9945 0 002 2.8154V14a2.0025 2.0025 0 01-2 2H2v2H3a4.0045 4.0045 0 004-4v-.1841A2.9959 2.9959 0 008.8157 12H11A5 5 0 0011 2zM6 12a1 1 0 111-1A1.0009 1.0009 0 016 12zm5-2H8.8157A2.974 2.974 0 004.394 8.4746 2.9908 2.9908 0 017 4h4a3 3 0 010 6z"
  })), children);
});
var WatsonHealthScalpelSelect32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthScalpelSelect32(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8281 7.1719a4.0941 4.0941 0 00-5.6562 0L.3433 30H9.5889a4.9682 4.9682 0 003.5356-1.4648L28.8281 12.8281a3.9984 3.9984 0 000-5.6562zM12.2928 20.8787l2.086-2.0859 2.8293 2.8294-2.0857 2.0862zM11.71 27.1211A2.9824 2.9824 0 019.5889 28H5.1714l5.7073-5.7072 2.83 2.83zm15.7037-15.707l-8.792 8.7939-2.8293-2.8292 8.7931-8.7929a2.0473 2.0473 0 012.8282 0 1.9995 1.9995 0 010 2.8282zM15 2a2.9948 2.9948 0 00-2.8157 2H7.8156A2.9925 2.9925 0 104 7.8154v4.3687a3 3 0 102 0V7.8159A2.9959 2.9959 0 007.8156 6h4.3686A2.9947 2.9947 0 1015 2zM5 16a1 1 0 111-1A1.0008 1.0008 0 015 16zM5 6A1 1 0 116 5 1.0008 1.0008 0 015 6zM15 6a1 1 0 111-1A1.0008 1.0008 0 0115 6z"
  })), children);
});
var WatsonHealthScalpelSelect24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthScalpelSelect24(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8281 7.1719a4.0941 4.0941 0 00-5.6562 0L.3433 30H9.5889a4.9682 4.9682 0 003.5356-1.4648L28.8281 12.8281a3.9984 3.9984 0 000-5.6562zM12.2928 20.8787l2.086-2.0859 2.8293 2.8294-2.0857 2.0862zM11.71 27.1211A2.9824 2.9824 0 019.5889 28H5.1714l5.7073-5.7072 2.83 2.83zm15.7037-15.707l-8.792 8.7939-2.8293-2.8292 8.7931-8.7929a2.0473 2.0473 0 012.8282 0 1.9995 1.9995 0 010 2.8282zM15 2a2.9948 2.9948 0 00-2.8157 2H7.8156A2.9925 2.9925 0 104 7.8154v4.3687a3 3 0 102 0V7.8159A2.9959 2.9959 0 007.8156 6h4.3686A2.9947 2.9947 0 1015 2zM5 16a1 1 0 111-1A1.0008 1.0008 0 015 16zM5 6A1 1 0 116 5 1.0008 1.0008 0 015 6zM15 6a1 1 0 111-1A1.0008 1.0008 0 0115 6z"
  })), children);
});
var WatsonHealthScalpelSelect20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthScalpelSelect20(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8281 7.1719a4.0941 4.0941 0 00-5.6562 0L.3433 30H9.5889a4.9682 4.9682 0 003.5356-1.4648L28.8281 12.8281a3.9984 3.9984 0 000-5.6562zM12.2928 20.8787l2.086-2.0859 2.8293 2.8294-2.0857 2.0862zM11.71 27.1211A2.9824 2.9824 0 019.5889 28H5.1714l5.7073-5.7072 2.83 2.83zm15.7037-15.707l-8.792 8.7939-2.8293-2.8292 8.7931-8.7929a2.0473 2.0473 0 012.8282 0 1.9995 1.9995 0 010 2.8282zM15 2a2.9948 2.9948 0 00-2.8157 2H7.8156A2.9925 2.9925 0 104 7.8154v4.3687a3 3 0 102 0V7.8159A2.9959 2.9959 0 007.8156 6h4.3686A2.9947 2.9947 0 1015 2zM5 16a1 1 0 111-1A1.0008 1.0008 0 015 16zM5 6A1 1 0 116 5 1.0008 1.0008 0 015 6zM15 6a1 1 0 111-1A1.0008 1.0008 0 0115 6z"
  })), children);
});
var WatsonHealthScalpelSelect16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthScalpelSelect16(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.8281 7.1719a4.0941 4.0941 0 00-5.6562 0L.3433 30H9.5889a4.9682 4.9682 0 003.5356-1.4648L28.8281 12.8281a3.9984 3.9984 0 000-5.6562zM12.2928 20.8787l2.086-2.0859 2.8293 2.8294-2.0857 2.0862zM11.71 27.1211A2.9824 2.9824 0 019.5889 28H5.1714l5.7073-5.7072 2.83 2.83zm15.7037-15.707l-8.792 8.7939-2.8293-2.8292 8.7931-8.7929a2.0473 2.0473 0 012.8282 0 1.9995 1.9995 0 010 2.8282zM15 2a2.9948 2.9948 0 00-2.8157 2H7.8156A2.9925 2.9925 0 104 7.8154v4.3687a3 3 0 102 0V7.8159A2.9959 2.9959 0 007.8156 6h4.3686A2.9947 2.9947 0 1015 2zM5 16a1 1 0 111-1A1.0008 1.0008 0 015 16zM5 6A1 1 0 116 5 1.0008 1.0008 0 015 6zM15 6a1 1 0 111-1A1.0008 1.0008 0 0115 6z"
  })), children);
});
var Scan32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scan32(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,29H5a2,2,0,0,1-2-2V5A2,2,0,0,1,5,3H21V5H5V27H21Z"
  })), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 9H17V23H15zM27 9H29V23H27zM21 9H23V23H21z"
  })), children);
});
var Scan24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scan24(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,29H5a2,2,0,0,1-2-2V5A2,2,0,0,1,5,3H21V5H5V27H21Z"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 9H17V23H15zM27 9H29V23H27zM21 9H23V23H21z"
  })), children);
});
var Scan20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scan20(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,29H5a2,2,0,0,1-2-2V5A2,2,0,0,1,5,3H21V5H5V27H21Z"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 9H17V23H15zM27 9H29V23H27zM21 9H23V23H21z"
  })), children);
});
var Scan16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scan16(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,29H5a2,2,0,0,1-2-2V5A2,2,0,0,1,5,3H21V5H5V27H21Z"
  })), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 9H17V23H15zM27 9H29V23H27zM21 9H23V23H21z"
  })), children);
});
var ScanAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScanAlt32(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 24H10a2 2 0 01-2-2V19h2v3H22V19h2v3A2 2 0 0122 24zM2 15H30V17H2zM24 13H22V10H10v3H8V10a2 2 0 012-2H22a2 2 0 012 2zM30 10L28 10 28 4 22 4 22 2 30 2 30 10zM4 10L2 10 2 2 10 2 10 4 4 4 4 10zM10 30L2 30 2 22 4 22 4 28 10 28 10 30zM30 30L22 30 22 28 28 28 28 22 30 22 30 30z"
  })), children);
});
var ScanAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScanAlt24(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 24H10a2 2 0 01-2-2V19h2v3H22V19h2v3A2 2 0 0122 24zM2 15H30V17H2zM24 13H22V10H10v3H8V10a2 2 0 012-2H22a2 2 0 012 2zM30 10L28 10 28 4 22 4 22 2 30 2 30 10zM4 10L2 10 2 2 10 2 10 4 4 4 4 10zM10 30L2 30 2 22 4 22 4 28 10 28 10 30zM30 30L22 30 22 28 28 28 28 22 30 22 30 30z"
  })), children);
});
var ScanAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScanAlt20(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 24H10a2 2 0 01-2-2V19h2v3H22V19h2v3A2 2 0 0122 24zM2 15H30V17H2zM24 13H22V10H10v3H8V10a2 2 0 012-2H22a2 2 0 012 2zM30 10L28 10 28 4 22 4 22 2 30 2 30 10zM4 10L2 10 2 2 10 2 10 4 4 4 4 10zM10 30L2 30 2 22 4 22 4 28 10 28 10 30zM30 30L22 30 22 28 28 28 28 22 30 22 30 30z"
  })), children);
});
var ScanAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScanAlt16(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 24H10a2 2 0 01-2-2V19h2v3H22V19h2v3A2 2 0 0122 24zM2 15H30V17H2zM24 13H22V10H10v3H8V10a2 2 0 012-2H22a2 2 0 012 2zM30 10L28 10 28 4 22 4 22 2 30 2 30 10zM4 10L2 10 2 2 10 2 10 4 4 4 4 10zM10 30L2 30 2 22 4 22 4 28 10 28 10 30zM30 30L22 30 22 28 28 28 28 22 30 22 30 30z"
  })), children);
});
var ScanDisabled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScanDisabled32(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3826 2.0762a.9993.9993 0 00-1.09.2168l-26 26A1 1 0 003 30h8V28H5.4143l4-4H22a2.0021 2.0021 0 002-2V9.4146l4-4V11h2V3A1 1 0 0029.3826 2.0762zM22 22H11.4143L22 11.4146zM10 17.7554V10h7.7554l2-2H10a2.0025 2.0025 0 00-2 2v9.7554zM11 2L2 2 2 11 4 11 4 4 11 4 11 2zM21 30L30 30 30 21 28 21 28 28 21 28 21 30zM4 23.755L4 21 2 21 2 25.754 4 23.755zM25.755 2L21 2 21 4 23.755 4 25.755 2z"
  })), children);
});
var ScanDisabled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScanDisabled24(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3826 2.0762a.9993.9993 0 00-1.09.2168l-26 26A1 1 0 003 30h8V28H5.4143l4-4H22a2.0021 2.0021 0 002-2V9.4146l4-4V11h2V3A1 1 0 0029.3826 2.0762zM22 22H11.4143L22 11.4146zM10 17.7554V10h7.7554l2-2H10a2.0025 2.0025 0 00-2 2v9.7554zM11 2L2 2 2 11 4 11 4 4 11 4 11 2zM21 30L30 30 30 21 28 21 28 28 21 28 21 30zM4 23.755L4 21 2 21 2 25.754 4 23.755zM25.755 2L21 2 21 4 23.755 4 25.755 2z"
  })), children);
});
var ScanDisabled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScanDisabled20(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3826 2.0762a.9993.9993 0 00-1.09.2168l-26 26A1 1 0 003 30h8V28H5.4143l4-4H22a2.0021 2.0021 0 002-2V9.4146l4-4V11h2V3A1 1 0 0029.3826 2.0762zM22 22H11.4143L22 11.4146zM10 17.7554V10h7.7554l2-2H10a2.0025 2.0025 0 00-2 2v9.7554zM11 2L2 2 2 11 4 11 4 4 11 4 11 2zM21 30L30 30 30 21 28 21 28 28 21 28 21 30zM4 23.755L4 21 2 21 2 25.754 4 23.755zM25.755 2L21 2 21 4 23.755 4 25.755 2z"
  })), children);
});
var ScanDisabled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScanDisabled16(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3826 2.0762a.9993.9993 0 00-1.09.2168l-26 26A1 1 0 003 30h8V28H5.4143l4-4H22a2.0021 2.0021 0 002-2V9.4146l4-4V11h2V3A1 1 0 0029.3826 2.0762zM22 22H11.4143L22 11.4146zM10 17.7554V10h7.7554l2-2H10a2.0025 2.0025 0 00-2 2v9.7554zM11 2L2 2 2 11 4 11 4 4 11 4 11 2zM21 30L30 30 30 21 28 21 28 28 21 28 21 30zM4 23.755L4 21 2 21 2 25.754 4 23.755zM25.755 2L21 2 21 4 23.755 4 25.755 2z"
  })), children);
});
var ScatterMatrix32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScatterMatrix32(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9.5",
    cy: "9.5",
    r: "2.5"
  })), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9.5",
    cy: "22.5",
    r: "2.5"
  })), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22.5",
    cy: "22.5",
    r: "2.5"
  })), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2.0023,2.0023,0,0,0,2,4V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2Zm0,13H17V4H28ZM15,4V15H4V4ZM4,17H15V28H4ZM17,28V17H28V28Z"
  })), children);
});
var ScatterMatrix24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScatterMatrix24(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9.5",
    cy: "9.5",
    r: "2.5"
  })), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9.5",
    cy: "22.5",
    r: "2.5"
  })), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22.5",
    cy: "22.5",
    r: "2.5"
  })), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2.0023,2.0023,0,0,0,2,4V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2Zm0,13H17V4H28ZM15,4V15H4V4ZM4,17H15V28H4ZM17,28V17H28V28Z"
  })), children);
});
var ScatterMatrix20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScatterMatrix20(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9.5",
    cy: "9.5",
    r: "2.5"
  })), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9.5",
    cy: "22.5",
    r: "2.5"
  })), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22.5",
    cy: "22.5",
    r: "2.5"
  })), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2.0023,2.0023,0,0,0,2,4V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2Zm0,13H17V4H28ZM15,4V15H4V4ZM4,17H15V28H4ZM17,28V17H28V28Z"
  })), children);
});
var ScatterMatrix16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScatterMatrix16(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9.5",
    cy: "9.5",
    r: "2.5"
  })), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9.5",
    cy: "22.5",
    r: "2.5"
  })), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22.5",
    cy: "22.5",
    r: "2.5"
  })), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2.0023,2.0023,0,0,0,2,4V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2Zm0,13H17V4H28ZM15,4V15H4V4ZM4,17H15V28H4ZM17,28V17H28V28Z"
  })), children);
});
var Schematics32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Schematics32(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,19.001A4.0056,4.0056,0,0,0,22.9991,15H9.0011A2.0031,2.0031,0,0,1,7,12.9991V9.858A3.9949,3.9949,0,0,0,9.8581,7h12.284a4,4,0,1,0,0-2H9.8581A3.9916,3.9916,0,1,0,5,9.858v3.1411A4.0057,4.0057,0,0,0,9.0011,17h13.998A2.003,2.003,0,0,1,25,19.001V22H22v3H9.8581a4,4,0,1,0,0,2H22v3h8V22H27ZM26,4a2,2,0,1,1-2,2A2.0019,2.0019,0,0,1,26,4ZM4,6A2,2,0,1,1,6,8,2.0019,2.0019,0,0,1,4,6ZM6,28a2,2,0,1,1,2-2A2.002,2.002,0,0,1,6,28Zm22-4v4H24V24Z"
  })), children);
});
var Schematics24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Schematics24(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,19.001A4.0056,4.0056,0,0,0,22.9991,15H9.0011A2.0031,2.0031,0,0,1,7,12.9991V9.858A3.9949,3.9949,0,0,0,9.8581,7h12.284a4,4,0,1,0,0-2H9.8581A3.9916,3.9916,0,1,0,5,9.858v3.1411A4.0057,4.0057,0,0,0,9.0011,17h13.998A2.003,2.003,0,0,1,25,19.001V22H22v3H9.8581a4,4,0,1,0,0,2H22v3h8V22H27ZM26,4a2,2,0,1,1-2,2A2.0019,2.0019,0,0,1,26,4ZM4,6A2,2,0,1,1,6,8,2.0019,2.0019,0,0,1,4,6ZM6,28a2,2,0,1,1,2-2A2.002,2.002,0,0,1,6,28Zm22-4v4H24V24Z"
  })), children);
});
var Schematics20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Schematics20(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,19.001A4.0056,4.0056,0,0,0,22.9991,15H9.0011A2.0031,2.0031,0,0,1,7,12.9991V9.858A3.9949,3.9949,0,0,0,9.8581,7h12.284a4,4,0,1,0,0-2H9.8581A3.9916,3.9916,0,1,0,5,9.858v3.1411A4.0057,4.0057,0,0,0,9.0011,17h13.998A2.003,2.003,0,0,1,25,19.001V22H22v3H9.8581a4,4,0,1,0,0,2H22v3h8V22H27ZM26,4a2,2,0,1,1-2,2A2.0019,2.0019,0,0,1,26,4ZM4,6A2,2,0,1,1,6,8,2.0019,2.0019,0,0,1,4,6ZM6,28a2,2,0,1,1,2-2A2.002,2.002,0,0,1,6,28Zm22-4v4H24V24Z"
  })), children);
});
var Schematics16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Schematics16(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,19.001A4.0056,4.0056,0,0,0,22.9991,15H9.0011A2.0031,2.0031,0,0,1,7,12.9991V9.858A3.9949,3.9949,0,0,0,9.8581,7h12.284a4,4,0,1,0,0-2H9.8581A3.9916,3.9916,0,1,0,5,9.858v3.1411A4.0057,4.0057,0,0,0,9.0011,17h13.998A2.003,2.003,0,0,1,25,19.001V22H22v3H9.8581a4,4,0,1,0,0,2H22v3h8V22H27ZM26,4a2,2,0,1,1-2,2A2.0019,2.0019,0,0,1,26,4ZM4,6A2,2,0,1,1,6,8,2.0019,2.0019,0,0,1,4,6ZM6,28a2,2,0,1,1,2-2A2.002,2.002,0,0,1,6,28Zm22-4v4H24V24Z"
  })), children);
});
var ScisControlTower32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScisControlTower32(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,19c-0.3,0-0.7,0.1-1,0.2L20.4,12c1-1.1,1.6-2.5,1.6-4c0-3.3-2.7-6-6-6s-6,2.7-6,6c0,1.6,0.6,3,1.6,4L6,19.2\tC5.7,19.1,5.3,19,5,19c-1.7,0-3,1.3-3,3s1.3,3,3,3s3-1.3,3-3c0-0.6-0.2-1.1-0.5-1.6l5.6-7.1c0.6,0.3,1.2,0.5,1.9,0.6v10.3\tc-1.2,0.4-2,1.5-2,2.8c0,1.7,1.3,3,3,3s3-1.3,3-3c0-1.3-0.8-2.4-2-2.8V13.9c0.7-0.1,1.3-0.3,1.9-0.6l5.6,7.1c-0.3,0.5-0.5,1-0.5,1.6\tc0,1.7,1.3,3,3,3s3-1.3,3-3S28.7,19,27,19z M16,4c2.2,0,4,1.8,4,4s-1.8,4-4,4s-4-1.8-4-4S13.8,4,16,4z M5,23c-0.6,0-1-0.4-1-1\ts0.4-1,1-1s1,0.4,1,1S5.6,23,5,23z M16,28c-0.6,0-1-0.4-1-1s0.4-1,1-1s1,0.4,1,1S16.6,28,16,28z M27,23c-0.6,0-1-0.4-1-1s0.4-1,1-1\ts1,0.4,1,1S27.6,23,27,23z"
  })), children);
});
var ScisControlTower24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScisControlTower24(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,19c-0.3,0-0.7,0.1-1,0.2L20.4,12c1-1.1,1.6-2.5,1.6-4c0-3.3-2.7-6-6-6s-6,2.7-6,6c0,1.6,0.6,3,1.6,4L6,19.2\tC5.7,19.1,5.3,19,5,19c-1.7,0-3,1.3-3,3s1.3,3,3,3s3-1.3,3-3c0-0.6-0.2-1.1-0.5-1.6l5.6-7.1c0.6,0.3,1.2,0.5,1.9,0.6v10.3\tc-1.2,0.4-2,1.5-2,2.8c0,1.7,1.3,3,3,3s3-1.3,3-3c0-1.3-0.8-2.4-2-2.8V13.9c0.7-0.1,1.3-0.3,1.9-0.6l5.6,7.1c-0.3,0.5-0.5,1-0.5,1.6\tc0,1.7,1.3,3,3,3s3-1.3,3-3S28.7,19,27,19z M16,4c2.2,0,4,1.8,4,4s-1.8,4-4,4s-4-1.8-4-4S13.8,4,16,4z M5,23c-0.6,0-1-0.4-1-1\ts0.4-1,1-1s1,0.4,1,1S5.6,23,5,23z M16,28c-0.6,0-1-0.4-1-1s0.4-1,1-1s1,0.4,1,1S16.6,28,16,28z M27,23c-0.6,0-1-0.4-1-1s0.4-1,1-1\ts1,0.4,1,1S27.6,23,27,23z"
  })), children);
});
var ScisControlTower20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScisControlTower20(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,19c-0.3,0-0.7,0.1-1,0.2L20.4,12c1-1.1,1.6-2.5,1.6-4c0-3.3-2.7-6-6-6s-6,2.7-6,6c0,1.6,0.6,3,1.6,4L6,19.2\tC5.7,19.1,5.3,19,5,19c-1.7,0-3,1.3-3,3s1.3,3,3,3s3-1.3,3-3c0-0.6-0.2-1.1-0.5-1.6l5.6-7.1c0.6,0.3,1.2,0.5,1.9,0.6v10.3\tc-1.2,0.4-2,1.5-2,2.8c0,1.7,1.3,3,3,3s3-1.3,3-3c0-1.3-0.8-2.4-2-2.8V13.9c0.7-0.1,1.3-0.3,1.9-0.6l5.6,7.1c-0.3,0.5-0.5,1-0.5,1.6\tc0,1.7,1.3,3,3,3s3-1.3,3-3S28.7,19,27,19z M16,4c2.2,0,4,1.8,4,4s-1.8,4-4,4s-4-1.8-4-4S13.8,4,16,4z M5,23c-0.6,0-1-0.4-1-1\ts0.4-1,1-1s1,0.4,1,1S5.6,23,5,23z M16,28c-0.6,0-1-0.4-1-1s0.4-1,1-1s1,0.4,1,1S16.6,28,16,28z M27,23c-0.6,0-1-0.4-1-1s0.4-1,1-1\ts1,0.4,1,1S27.6,23,27,23z"
  })), children);
});
var ScisControlTower16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScisControlTower16(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,19c-0.3,0-0.7,0.1-1,0.2L20.4,12c1-1.1,1.6-2.5,1.6-4c0-3.3-2.7-6-6-6s-6,2.7-6,6c0,1.6,0.6,3,1.6,4L6,19.2\tC5.7,19.1,5.3,19,5,19c-1.7,0-3,1.3-3,3s1.3,3,3,3s3-1.3,3-3c0-0.6-0.2-1.1-0.5-1.6l5.6-7.1c0.6,0.3,1.2,0.5,1.9,0.6v10.3\tc-1.2,0.4-2,1.5-2,2.8c0,1.7,1.3,3,3,3s3-1.3,3-3c0-1.3-0.8-2.4-2-2.8V13.9c0.7-0.1,1.3-0.3,1.9-0.6l5.6,7.1c-0.3,0.5-0.5,1-0.5,1.6\tc0,1.7,1.3,3,3,3s3-1.3,3-3S28.7,19,27,19z M16,4c2.2,0,4,1.8,4,4s-1.8,4-4,4s-4-1.8-4-4S13.8,4,16,4z M5,23c-0.6,0-1-0.4-1-1\ts0.4-1,1-1s1,0.4,1,1S5.6,23,5,23z M16,28c-0.6,0-1-0.4-1-1s0.4-1,1-1s1,0.4,1,1S16.6,28,16,28z M27,23c-0.6,0-1-0.4-1-1s0.4-1,1-1\ts1,0.4,1,1S27.6,23,27,23z"
  })), children);
});
var ScisTransparentSupply32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScisTransparentSupply32(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,23v3H8.5a4.5,4.5,0,0,1,0-9H9V15H8.5a6.5,6.5,0,0,0,0,13H23v3h8V23Zm6,6H25V25h4Z"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 22H19V19H13v3H11V19a2.0023 2.0023 0 012-2h6a2.0023 2.0023 0 012 2zM16 16a3 3 0 113-3A3.0033 3.0033 0 0116 16zm0-4a1 1 0 101 1A1.0013 1.0013 0 0016 12z"
  })), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,4H9V1H1V9H9V6H23.5a4.5,4.5,0,0,1,0,9H23v2h.5a6.5,6.5,0,0,0,0-13ZM7,7H3V3H7Z"
  })), children);
});
var ScisTransparentSupply24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScisTransparentSupply24(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,23v3H8.5a4.5,4.5,0,0,1,0-9H9V15H8.5a6.5,6.5,0,0,0,0,13H23v3h8V23Zm6,6H25V25h4Z"
  })), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 22H19V19H13v3H11V19a2.0023 2.0023 0 012-2h6a2.0023 2.0023 0 012 2zM16 16a3 3 0 113-3A3.0033 3.0033 0 0116 16zm0-4a1 1 0 101 1A1.0013 1.0013 0 0016 12z"
  })), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,4H9V1H1V9H9V6H23.5a4.5,4.5,0,0,1,0,9H23v2h.5a6.5,6.5,0,0,0,0-13ZM7,7H3V3H7Z"
  })), children);
});
var ScisTransparentSupply20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScisTransparentSupply20(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,23v3H8.5a4.5,4.5,0,0,1,0-9H9V15H8.5a6.5,6.5,0,0,0,0,13H23v3h8V23Zm6,6H25V25h4Z"
  })), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 22H19V19H13v3H11V19a2.0023 2.0023 0 012-2h6a2.0023 2.0023 0 012 2zM16 16a3 3 0 113-3A3.0033 3.0033 0 0116 16zm0-4a1 1 0 101 1A1.0013 1.0013 0 0016 12z"
  })), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,4H9V1H1V9H9V6H23.5a4.5,4.5,0,0,1,0,9H23v2h.5a6.5,6.5,0,0,0,0-13ZM7,7H3V3H7Z"
  })), children);
});
var ScisTransparentSupply16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScisTransparentSupply16(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,23v3H8.5a4.5,4.5,0,0,1,0-9H9V15H8.5a6.5,6.5,0,0,0,0,13H23v3h8V23Zm6,6H25V25h4Z"
  })), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 22H19V19H13v3H11V19a2.0023 2.0023 0 012-2h6a2.0023 2.0023 0 012 2zM16 16a3 3 0 113-3A3.0033 3.0033 0 0116 16zm0-4a1 1 0 101 1A1.0013 1.0013 0 0016 12z"
  })), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,4H9V1H1V9H9V6H23.5a4.5,4.5,0,0,1,0,9H23v2h.5a6.5,6.5,0,0,0,0-13ZM7,7H3V3H7Z"
  })), children);
});
var Scooter32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scooter32(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 28a4 4 0 114-4A4.0045 4.0045 0 0126 28zm0-6a2 2 0 102 2A2.0023 2.0023 0 0026 22zM24 8H18v2h6a1 1 0 010 2H21a1 1 0 00-.98 1.1963l.9241 4.6211L18.4338 22h-2.69l-2.5723-8.5752A1.988 1.988 0 0011.2559 12H6v2h5.2561l.6 2H7a5.0057 5.0057 0 00-5 5v2a1 1 0 001 1H4a4 4 0 008 0h7a1 1 0 00.8574-.4854l3-5a1 1 0 00.1231-.7109L22.22 14H24a3 3 0 000-6zM8 26a2.0025 2.0025 0 01-2-2h4A2.0025 2.0025 0 018 26zM4 22V21a3.0033 3.0033 0 013-3h5.4561l1.2 4z"
  })), children);
});
var Scooter24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scooter24(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 28a4 4 0 114-4A4.0045 4.0045 0 0126 28zm0-6a2 2 0 102 2A2.0023 2.0023 0 0026 22zM24 8H18v2h6a1 1 0 010 2H21a1 1 0 00-.98 1.1963l.9241 4.6211L18.4338 22h-2.69l-2.5723-8.5752A1.988 1.988 0 0011.2559 12H6v2h5.2561l.6 2H7a5.0057 5.0057 0 00-5 5v2a1 1 0 001 1H4a4 4 0 008 0h7a1 1 0 00.8574-.4854l3-5a1 1 0 00.1231-.7109L22.22 14H24a3 3 0 000-6zM8 26a2.0025 2.0025 0 01-2-2h4A2.0025 2.0025 0 018 26zM4 22V21a3.0033 3.0033 0 013-3h5.4561l1.2 4z"
  })), children);
});
var Scooter20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scooter20(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 28a4 4 0 114-4A4.0045 4.0045 0 0126 28zm0-6a2 2 0 102 2A2.0023 2.0023 0 0026 22zM24 8H18v2h6a1 1 0 010 2H21a1 1 0 00-.98 1.1963l.9241 4.6211L18.4338 22h-2.69l-2.5723-8.5752A1.988 1.988 0 0011.2559 12H6v2h5.2561l.6 2H7a5.0057 5.0057 0 00-5 5v2a1 1 0 001 1H4a4 4 0 008 0h7a1 1 0 00.8574-.4854l3-5a1 1 0 00.1231-.7109L22.22 14H24a3 3 0 000-6zM8 26a2.0025 2.0025 0 01-2-2h4A2.0025 2.0025 0 018 26zM4 22V21a3.0033 3.0033 0 013-3h5.4561l1.2 4z"
  })), children);
});
var Scooter16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Scooter16(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 28a4 4 0 114-4A4.0045 4.0045 0 0126 28zm0-6a2 2 0 102 2A2.0023 2.0023 0 0026 22zM24 8H18v2h6a1 1 0 010 2H21a1 1 0 00-.98 1.1963l.9241 4.6211L18.4338 22h-2.69l-2.5723-8.5752A1.988 1.988 0 0011.2559 12H6v2h5.2561l.6 2H7a5.0057 5.0057 0 00-5 5v2a1 1 0 001 1H4a4 4 0 008 0h7a1 1 0 00.8574-.4854l3-5a1 1 0 00.1231-.7109L22.22 14H24a3 3 0 000-6zM8 26a2.0025 2.0025 0 01-2-2h4A2.0025 2.0025 0 018 26zM4 22V21a3.0033 3.0033 0 013-3h5.4561l1.2 4z"
  })), children);
});
var ScooterFront32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScooterFront32(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 19H17V28H15z"
  })), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,10V8H20a2.0025,2.0025,0,0,0-2-2H14a2.0025,2.0025,0,0,0-2,2H9v2h3v4.1841A2.9957,2.9957,0,0,0,10,17v7h2V17a1.0008,1.0008,0,0,1,1-1h6a1.0008,1.0008,0,0,1,1,1v7h2V17a2.9957,2.9957,0,0,0-2-2.8159V10ZM18,8v6H14V8Z"
  })), children);
});
var ScooterFront24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScooterFront24(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 19H17V28H15z"
  })), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,10V8H20a2.0025,2.0025,0,0,0-2-2H14a2.0025,2.0025,0,0,0-2,2H9v2h3v4.1841A2.9957,2.9957,0,0,0,10,17v7h2V17a1.0008,1.0008,0,0,1,1-1h6a1.0008,1.0008,0,0,1,1,1v7h2V17a2.9957,2.9957,0,0,0-2-2.8159V10ZM18,8v6H14V8Z"
  })), children);
});
var ScooterFront20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScooterFront20(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 19H17V28H15z"
  })), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,10V8H20a2.0025,2.0025,0,0,0-2-2H14a2.0025,2.0025,0,0,0-2,2H9v2h3v4.1841A2.9957,2.9957,0,0,0,10,17v7h2V17a1.0008,1.0008,0,0,1,1-1h6a1.0008,1.0008,0,0,1,1,1v7h2V17a2.9957,2.9957,0,0,0-2-2.8159V10ZM18,8v6H14V8Z"
  })), children);
});
var ScooterFront16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScooterFront16(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 19H17V28H15z"
  })), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,10V8H20a2.0025,2.0025,0,0,0-2-2H14a2.0025,2.0025,0,0,0-2,2H9v2h3v4.1841A2.9957,2.9957,0,0,0,10,17v7h2V17a1.0008,1.0008,0,0,1,1-1h6a1.0008,1.0008,0,0,1,1,1v7h2V17a2.9957,2.9957,0,0,0-2-2.8159V10ZM18,8v6H14V8Z"
  })), children);
});
var Screen32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Screen32(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM18,28H14V24h4Zm10-6H4V6H28Z"
  })), children);
});
var Screen24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Screen24(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM18,28H14V24h4Zm10-6H4V6H28Z"
  })), children);
});
var Screen20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Screen20(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM18,28H14V24h4Zm10-6H4V6H28Z"
  })), children);
});
var Screen16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Screen16(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V6A2,2,0,0,0,28,4ZM18,28H14V24h4Zm10-6H4V6H28Z"
  })), children);
});
var ScreenOff32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScreenOff32(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,22H11.41L30,3.41,28.59,2l-2,2H4A2,2,0,0,0,2,6V22H4V6H24.59L2,28.59,3.41,30l6-6H12v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V9H28ZM18,28H14V24h4Z"
  })), children);
});
var ScreenOff24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScreenOff24(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,22H11.41L30,3.41,28.59,2l-2,2H4A2,2,0,0,0,2,6V22H4V6H24.59L2,28.59,3.41,30l6-6H12v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V9H28ZM18,28H14V24h4Z"
  })), children);
});
var ScreenOff20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScreenOff20(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,22H11.41L30,3.41,28.59,2l-2,2H4A2,2,0,0,0,2,6V22H4V6H24.59L2,28.59,3.41,30l6-6H12v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V9H28ZM18,28H14V24h4Z"
  })), children);
});
var ScreenOff16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScreenOff16(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,22H11.41L30,3.41,28.59,2l-2,2H4A2,2,0,0,0,2,6V22H4V6H24.59L2,28.59,3.41,30l6-6H12v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V9H28ZM18,28H14V24h4Z"
  })), children);
});
var Script32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Script32(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.83 26L21.41 23.42 20 22 16 26 20 30 21.42 28.59 18.83 26zM27.17 26L24.59 28.58 26 30 30 26 26 22 24.58 23.41 27.17 26z"
  })), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v6h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h6ZM18,4.4,23.6,10H18Z"
  })), children);
});
var Script24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Script24(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.83 26L21.41 23.42 20 22 16 26 20 30 21.42 28.59 18.83 26zM27.17 26L24.59 28.58 26 30 30 26 26 22 24.58 23.41 27.17 26z"
  })), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v6h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h6ZM18,4.4,23.6,10H18Z"
  })), children);
});
var Script20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Script20(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.83 26L21.41 23.42 20 22 16 26 20 30 21.42 28.59 18.83 26zM27.17 26L24.59 28.58 26 30 30 26 26 22 24.58 23.41 27.17 26z"
  })), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v6h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h6ZM18,4.4,23.6,10H18Z"
  })), children);
});
var Script16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Script16(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.83 26L21.41 23.42 20 22 16 26 20 30 21.42 28.59 18.83 26zM27.17 26L24.59 28.58 26 30 30 26 26 22 24.58 23.41 27.17 26z"
  })), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v6h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h6ZM18,4.4,23.6,10H18Z"
  })), children);
});
var ScriptReference32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScriptReference32(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM27.17 26L24.59 28.58 26 30 30 26 26 22 24.58 23.41 27.17 26zM18.83 26L21.41 23.42 20 22 16 26 20 30 21.42 28.59 18.83 26zM25.7 9.3l-7-7A.9087.9087 0 0018 2H8A2.0058 2.0058 0 006 4V16H8V4h8v6a2.0058 2.0058 0 002 2h6v6h2V10A.9092.9092 0 0025.7 9.3zM18 10V4.4L23.6 10z"
  })), children);
});
var ScriptReference24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScriptReference24(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM27.17 26L24.59 28.58 26 30 30 26 26 22 24.58 23.41 27.17 26zM18.83 26L21.41 23.42 20 22 16 26 20 30 21.42 28.59 18.83 26zM25.7 9.3l-7-7A.9087.9087 0 0018 2H8A2.0058 2.0058 0 006 4V16H8V4h8v6a2.0058 2.0058 0 002 2h6v6h2V10A.9092.9092 0 0025.7 9.3zM18 10V4.4L23.6 10z"
  })), children);
});
var ScriptReference20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScriptReference20(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM27.17 26L24.59 28.58 26 30 30 26 26 22 24.58 23.41 27.17 26zM18.83 26L21.41 23.42 20 22 16 26 20 30 21.42 28.59 18.83 26zM25.7 9.3l-7-7A.9087.9087 0 0018 2H8A2.0058 2.0058 0 006 4V16H8V4h8v6a2.0058 2.0058 0 002 2h6v6h2V10A.9092.9092 0 0025.7 9.3zM18 10V4.4L23.6 10z"
  })), children);
});
var ScriptReference16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ScriptReference16(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM27.17 26L24.59 28.58 26 30 30 26 26 22 24.58 23.41 27.17 26zM18.83 26L21.41 23.42 20 22 16 26 20 30 21.42 28.59 18.83 26zM25.7 9.3l-7-7A.9087.9087 0 0018 2H8A2.0058 2.0058 0 006 4V16H8V4h8v6a2.0058 2.0058 0 002 2h6v6h2V10A.9092.9092 0 0025.7 9.3zM18 10V4.4L23.6 10z"
  })), children);
});
var Sdk32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sdk32(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 9L27.9 9 24 15.6 24 9 22 9 22 23 24 23 24 18.7 24.9 17.2 27.9 23 30 23 26.1 15.4 30 9zM16 23H12V9h4a4.0118 4.0118 0 014 4v6A4.0118 4.0118 0 0116 23zm-2-2h2a2.0059 2.0059 0 002-2V13a2.0059 2.0059 0 00-2-2H14zM8 23H2V21H8V17H4a2.0059 2.0059 0 01-2-2V11A2.0059 2.0059 0 014 9h6v2H4v4H8a2.0059 2.0059 0 012 2v4A2.0059 2.0059 0 018 23z"
  })), children);
});
var Sdk24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sdk24(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 9L27.9 9 24 15.6 24 9 22 9 22 23 24 23 24 18.7 24.9 17.2 27.9 23 30 23 26.1 15.4 30 9zM16 23H12V9h4a4.0118 4.0118 0 014 4v6A4.0118 4.0118 0 0116 23zm-2-2h2a2.0059 2.0059 0 002-2V13a2.0059 2.0059 0 00-2-2H14zM8 23H2V21H8V17H4a2.0059 2.0059 0 01-2-2V11A2.0059 2.0059 0 014 9h6v2H4v4H8a2.0059 2.0059 0 012 2v4A2.0059 2.0059 0 018 23z"
  })), children);
});
var Sdk20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sdk20(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 9L27.9 9 24 15.6 24 9 22 9 22 23 24 23 24 18.7 24.9 17.2 27.9 23 30 23 26.1 15.4 30 9zM16 23H12V9h4a4.0118 4.0118 0 014 4v6A4.0118 4.0118 0 0116 23zm-2-2h2a2.0059 2.0059 0 002-2V13a2.0059 2.0059 0 00-2-2H14zM8 23H2V21H8V17H4a2.0059 2.0059 0 01-2-2V11A2.0059 2.0059 0 014 9h6v2H4v4H8a2.0059 2.0059 0 012 2v4A2.0059 2.0059 0 018 23z"
  })), children);
});
var Sdk16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sdk16(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 9L27.9 9 24 15.6 24 9 22 9 22 23 24 23 24 18.7 24.9 17.2 27.9 23 30 23 26.1 15.4 30 9zM16 23H12V9h4a4.0118 4.0118 0 014 4v6A4.0118 4.0118 0 0116 23zm-2-2h2a2.0059 2.0059 0 002-2V13a2.0059 2.0059 0 00-2-2H14zM8 23H2V21H8V17H4a2.0059 2.0059 0 01-2-2V11A2.0059 2.0059 0 014 9h6v2H4v4H8a2.0059 2.0059 0 012 2v4A2.0059 2.0059 0 018 23z"
  })), children);
});
var Search32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Search32(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,27.5859l-7.5521-7.5521a11.0177,11.0177,0,1,0-1.4141,1.4141L27.5859,29ZM4,13a9,9,0,1,1,9,9A9.01,9.01,0,0,1,4,13Z"
  })), children);
});
var Search24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Search24(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,27.5859l-7.5521-7.5521a11.0177,11.0177,0,1,0-1.4141,1.4141L27.5859,29ZM4,13a9,9,0,1,1,9,9A9.01,9.01,0,0,1,4,13Z"
  })), children);
});
var Search20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Search20(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,27.5859l-7.5521-7.5521a11.0177,11.0177,0,1,0-1.4141,1.4141L27.5859,29ZM4,13a9,9,0,1,1,9,9A9.01,9.01,0,0,1,4,13Z"
  })), children);
});
var Search16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Search16(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,14.3L10.7,10c1.9-2.3,1.6-5.8-0.7-7.7S4.2,0.7,2.3,3S0.7,8.8,3,10.7c2,1.7,5,1.7,7,0l4.3,4.3L15,14.3z M2,6.5\tC2,4,4,2,6.5,2S11,4,11,6.5S9,11,6.5,11S2,9,2,6.5z"
  })), children);
});
var SearchAdvanced32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SearchAdvanced32(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 6L26 6 26 2 24 2 24 6 20 6 20 8 24 8 24 12 26 12 26 8 30 8 30 6zM24 28.5859l-5.9751-5.9751a9.0234 9.0234 0 10-1.4141 1.4141L22.5859 30zM4 17a7 7 0 117 7A7.0078 7.0078 0 014 17z"
  })), children);
});
var SearchAdvanced24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SearchAdvanced24(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 6L26 6 26 2 24 2 24 6 20 6 20 8 24 8 24 12 26 12 26 8 30 8 30 6zM24 28.5859l-5.9751-5.9751a9.0234 9.0234 0 10-1.4141 1.4141L22.5859 30zM4 17a7 7 0 117 7A7.0078 7.0078 0 014 17z"
  })), children);
});
var SearchAdvanced20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SearchAdvanced20(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 6L26 6 26 2 24 2 24 6 20 6 20 8 24 8 24 12 26 12 26 8 30 8 30 6zM24 28.5859l-5.9751-5.9751a9.0234 9.0234 0 10-1.4141 1.4141L22.5859 30zM4 17a7 7 0 117 7A7.0078 7.0078 0 014 17z"
  })), children);
});
var SearchAdvanced16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SearchAdvanced16(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 6L26 6 26 2 24 2 24 6 20 6 20 8 24 8 24 12 26 12 26 8 30 8 30 6zM24 28.5859l-5.9751-5.9751a9.0234 9.0234 0 10-1.4141 1.4141L22.5859 30zM4 17a7 7 0 117 7A7.0078 7.0078 0 014 17z"
  })), children);
});
var SearchLocate32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SearchLocate32(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 28.5859l-4.6885-4.6884a8.028 8.028 0 10-1.414 1.414L28.5859 30zM19 25a6 6 0 116-6A6.0066 6.0066 0 0119 25zM2 12H10V14H2zM2 2H18V4H2zM2 7H18V9H2z"
  })), children);
});
var SearchLocate24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SearchLocate24(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 28.5859l-4.6885-4.6884a8.028 8.028 0 10-1.414 1.414L28.5859 30zM19 25a6 6 0 116-6A6.0066 6.0066 0 0119 25zM2 12H10V14H2zM2 2H18V4H2zM2 7H18V9H2z"
  })), children);
});
var SearchLocate20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SearchLocate20(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 28.5859l-4.6885-4.6884a8.028 8.028 0 10-1.414 1.414L28.5859 30zM19 25a6 6 0 116-6A6.0066 6.0066 0 0119 25zM2 12H10V14H2zM2 2H18V4H2zM2 7H18V9H2z"
  })), children);
});
var SearchLocate16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SearchLocate16(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 28.5859l-4.6885-4.6884a8.028 8.028 0 10-1.414 1.414L28.5859 30zM19 25a6 6 0 116-6A6.0066 6.0066 0 0119 25zM2 12H10V14H2zM2 2H18V4H2zM2 7H18V9H2z"
  })), children);
});
var Security32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Security32(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 16.59L11.41 14 10 15.41 14 19.41 22 11.41 20.59 10 14 16.59z"
  })), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,9.8242,26.7071A10.9818,10.9818,0,0,1,4,17V4A2.0021,2.0021,0,0,1,6,2H26a2.0021,2.0021,0,0,1,2,2V17a10.9818,10.9818,0,0,1-5.8242,9.7071ZM6,4V17a8.9852,8.9852,0,0,0,4.7656,7.9423L16,27.7333l5.2344-2.791A8.9852,8.9852,0,0,0,26,17V4Z"
  })), children);
});
var Security24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Security24(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 16.59L11.41 14 10 15.41 14 19.41 22 11.41 20.59 10 14 16.59z"
  })), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,9.8242,26.7071A10.9818,10.9818,0,0,1,4,17V4A2.0021,2.0021,0,0,1,6,2H26a2.0021,2.0021,0,0,1,2,2V17a10.9818,10.9818,0,0,1-5.8242,9.7071ZM6,4V17a8.9852,8.9852,0,0,0,4.7656,7.9423L16,27.7333l5.2344-2.791A8.9852,8.9852,0,0,0,26,17V4Z"
  })), children);
});
var Security20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Security20(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 16.59L11.41 14 10 15.41 14 19.41 22 11.41 20.59 10 14 16.59z"
  })), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,9.8242,26.7071A10.9818,10.9818,0,0,1,4,17V4A2.0021,2.0021,0,0,1,6,2H26a2.0021,2.0021,0,0,1,2,2V17a10.9818,10.9818,0,0,1-5.8242,9.7071ZM6,4V17a8.9852,8.9852,0,0,0,4.7656,7.9423L16,27.7333l5.2344-2.791A8.9852,8.9852,0,0,0,26,17V4Z"
  })), children);
});
var Security16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Security16(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 16.59L11.41 14 10 15.41 14 19.41 22 11.41 20.59 10 14 16.59z"
  })), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,9.8242,26.7071A10.9818,10.9818,0,0,1,4,17V4A2.0021,2.0021,0,0,1,6,2H26a2.0021,2.0021,0,0,1,2,2V17a10.9818,10.9818,0,0,1-5.8242,9.7071ZM6,4V17a8.9852,8.9852,0,0,0,4.7656,7.9423L16,27.7333l5.2344-2.791A8.9852,8.9852,0,0,0,26,17V4Z"
  })), children);
});
var SecurityServices32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SecurityServices32(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,24V22H27.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,24,18.1011V16H22v2.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,18.1011,22H16v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,22,27.8989V30h2V27.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,27.8989,24Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,23,26Z"
  })), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,26.667l-3.2344-1.7246A8.9858,8.9858,0,0,1,6,17V4H26V14h2V4a2.0023,2.0023,0,0,0-2-2H6A2.0023,2.0023,0,0,0,4,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L14,28.9336Z"
  })), children);
});
var SecurityServices24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SecurityServices24(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,24V22H27.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,24,18.1011V16H22v2.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,18.1011,22H16v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,22,27.8989V30h2V27.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,27.8989,24Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,23,26Z"
  })), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,26.667l-3.2344-1.7246A8.9858,8.9858,0,0,1,6,17V4H26V14h2V4a2.0023,2.0023,0,0,0-2-2H6A2.0023,2.0023,0,0,0,4,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L14,28.9336Z"
  })), children);
});
var SecurityServices20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SecurityServices20(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,24V22H27.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,24,18.1011V16H22v2.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,18.1011,22H16v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,22,27.8989V30h2V27.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,27.8989,24Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,23,26Z"
  })), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,26.667l-3.2344-1.7246A8.9858,8.9858,0,0,1,6,17V4H26V14h2V4a2.0023,2.0023,0,0,0-2-2H6A2.0023,2.0023,0,0,0,4,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L14,28.9336Z"
  })), children);
});
var SecurityServices16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SecurityServices16(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,24V22H27.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,24,18.1011V16H22v2.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,18.1011,22H16v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,22,27.8989V30h2V27.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,27.8989,24Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,23,26Z"
  })), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,26.667l-3.2344-1.7246A8.9858,8.9858,0,0,1,6,17V4H26V14h2V4a2.0023,2.0023,0,0,0-2-2H6A2.0023,2.0023,0,0,0,4,4V17a10.9814,10.9814,0,0,0,5.8242,9.707L14,28.9336Z"
  })), children);
});
var Select_0132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Select_0132(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6L8 6 8 2 6 2 6 6 2 6 2 8 6 8 6 12 8 12 8 8 12 8 12 6zM16 6H20V8H16zM24 6V8h4v4h2V8a2 2 0 00-2-2zM6 16H8V20H6zM8 28V24H6v4a2 2 0 002 2h4V28zM28 16H30V20H28zM16 28H20V30H16zM28 24v4H24v2h4a2 2 0 002-2V24z"
  })), children);
});
var Select_0124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Select_0124(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6L8 6 8 2 6 2 6 6 2 6 2 8 6 8 6 12 8 12 8 8 12 8 12 6zM16 6H20V8H16zM24 6V8h4v4h2V8a2 2 0 00-2-2zM6 16H8V20H6zM8 28V24H6v4a2 2 0 002 2h4V28zM28 16H30V20H28zM16 28H20V30H16zM28 24v4H24v2h4a2 2 0 002-2V24z"
  })), children);
});
var Select_0120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Select_0120(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6L8 6 8 2 6 2 6 6 2 6 2 8 6 8 6 12 8 12 8 8 12 8 12 6zM16 6H20V8H16zM24 6V8h4v4h2V8a2 2 0 00-2-2zM6 16H8V20H6zM8 28V24H6v4a2 2 0 002 2h4V28zM28 16H30V20H28zM16 28H20V30H16zM28 24v4H24v2h4a2 2 0 002-2V24z"
  })), children);
});
var Select_0116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Select_0116(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6L8 6 8 2 6 2 6 6 2 6 2 8 6 8 6 12 8 12 8 8 12 8 12 6zM16 6H20V8H16zM24 6V8h4v4h2V8a2 2 0 00-2-2zM6 16H8V20H6zM8 28V24H6v4a2 2 0 002 2h4V28zM28 16H30V20H28zM16 28H20V30H16zM28 24v4H24v2h4a2 2 0 002-2V24z"
  })), children);
});
var Select_0232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Select_0232(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6L8 6 8 2 6 2 6 6 2 6 2 8 6 8 6 12 8 12 8 8 12 8 12 6zM30 10V4H24V6H16V8h8v2h2V24H24v2H10V24H8V16H6v8H4v6h6V28H24v2h6V24H28V10zM8 28H6V26H8zm20 0H26V26h2zM26 6h2V8H26z"
  })), children);
});
var Select_0224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Select_0224(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6L8 6 8 2 6 2 6 6 2 6 2 8 6 8 6 12 8 12 8 8 12 8 12 6zM30 10V4H24V6H16V8h8v2h2V24H24v2H10V24H8V16H6v8H4v6h6V28H24v2h6V24H28V10zM8 28H6V26H8zm20 0H26V26h2zM26 6h2V8H26z"
  })), children);
});
var Select_0220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Select_0220(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6L8 6 8 2 6 2 6 6 2 6 2 8 6 8 6 12 8 12 8 8 12 8 12 6zM30 10V4H24V6H16V8h8v2h2V24H24v2H10V24H8V16H6v8H4v6h6V28H24v2h6V24H28V10zM8 28H6V26H8zm20 0H26V26h2zM26 6h2V8H26z"
  })), children);
});
var Select_0216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Select_0216(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6L8 6 8 2 6 2 6 6 2 6 2 8 6 8 6 12 8 12 8 8 12 8 12 6zM30 10V4H24V6H16V8h8v2h2V24H24v2H10V24H8V16H6v8H4v6h6V28H24v2h6V24H28V10zM8 28H6V26H8zm20 0H26V26h2zM26 6h2V8H26z"
  })), children);
});
var SelectWindow32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SelectWindow32(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 26H4a2.0021 2.0021 0 01-2-2V20H4v4H8zM2 12H4V16H2zM26 8H24V4H20V2h4a2.0021 2.0021 0 012 2zM12 2H16V4H12zM4 8H2V4A2.0021 2.0021 0 014 2H8V4H4zM27 32a.9967.9967 0 01-.707-.293l-6.1377-6.1377L16.832 30.5547a1 1 0 01-1.79-.2676l-6-20A1 1 0 0110.2871 9.042l20 6a1 1 0 01.2676 1.79l-4.9854 3.3233L31.707 26.293a.9994.9994 0 010 1.414l-4 4A.9967.9967 0 0127 32zm0-2.4141L29.5859 27 22.431 19.845l5.2458-3.4978L11.4917 11.4917l4.8555 16.1851L19.845 22.431z"
  })), children);
});
var SelectWindow24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SelectWindow24(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 26H4a2.0021 2.0021 0 01-2-2V20H4v4H8zM2 12H4V16H2zM26 8H24V4H20V2h4a2.0021 2.0021 0 012 2zM12 2H16V4H12zM4 8H2V4A2.0021 2.0021 0 014 2H8V4H4zM27 32a.9967.9967 0 01-.707-.293l-6.1377-6.1377L16.832 30.5547a1 1 0 01-1.79-.2676l-6-20A1 1 0 0110.2871 9.042l20 6a1 1 0 01.2676 1.79l-4.9854 3.3233L31.707 26.293a.9994.9994 0 010 1.414l-4 4A.9967.9967 0 0127 32zm0-2.4141L29.5859 27 22.431 19.845l5.2458-3.4978L11.4917 11.4917l4.8555 16.1851L19.845 22.431z"
  })), children);
});
var SelectWindow20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SelectWindow20(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 26H4a2.0021 2.0021 0 01-2-2V20H4v4H8zM2 12H4V16H2zM26 8H24V4H20V2h4a2.0021 2.0021 0 012 2zM12 2H16V4H12zM4 8H2V4A2.0021 2.0021 0 014 2H8V4H4zM27 32a.9967.9967 0 01-.707-.293l-6.1377-6.1377L16.832 30.5547a1 1 0 01-1.79-.2676l-6-20A1 1 0 0110.2871 9.042l20 6a1 1 0 01.2676 1.79l-4.9854 3.3233L31.707 26.293a.9994.9994 0 010 1.414l-4 4A.9967.9967 0 0127 32zm0-2.4141L29.5859 27 22.431 19.845l5.2458-3.4978L11.4917 11.4917l4.8555 16.1851L19.845 22.431z"
  })), children);
});
var SelectWindow16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SelectWindow16(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 26H4a2.0021 2.0021 0 01-2-2V20H4v4H8zM2 12H4V16H2zM26 8H24V4H20V2h4a2.0021 2.0021 0 012 2zM12 2H16V4H12zM4 8H2V4A2.0021 2.0021 0 014 2H8V4H4zM27 32a.9967.9967 0 01-.707-.293l-6.1377-6.1377L16.832 30.5547a1 1 0 01-1.79-.2676l-6-20A1 1 0 0110.2871 9.042l20 6a1 1 0 01.2676 1.79l-4.9854 3.3233L31.707 26.293a.9994.9994 0 010 1.414l-4 4A.9967.9967 0 0127 32zm0-2.4141L29.5859 27 22.431 19.845l5.2458-3.4978L11.4917 11.4917l4.8555 16.1851L19.845 22.431z"
  })), children);
});
var Send32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Send32(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.45,15.11l-22-11a1,1,0,0,0-1.08.12,1,1,0,0,0-.33,1L7,16,4,26.74A1,1,0,0,0,5,28a1,1,0,0,0,.45-.11l22-11a1,1,0,0,0,0-1.78Zm-20.9,10L8.76,17H18V15H8.76L6.55,6.89,24.76,16Z"
  })), children);
});
var Send24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Send24(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.45,15.11l-22-11a1,1,0,0,0-1.08.12,1,1,0,0,0-.33,1L7,16,4,26.74A1,1,0,0,0,5,28a1,1,0,0,0,.45-.11l22-11a1,1,0,0,0,0-1.78Zm-20.9,10L8.76,17H18V15H8.76L6.55,6.89,24.76,16Z"
  })), children);
});
var Send20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Send20(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.45,15.11l-22-11a1,1,0,0,0-1.08.12,1,1,0,0,0-.33,1L7,16,4,26.74A1,1,0,0,0,5,28a1,1,0,0,0,.45-.11l22-11a1,1,0,0,0,0-1.78Zm-20.9,10L8.76,17H18V15H8.76L6.55,6.89,24.76,16Z"
  })), children);
});
var Send16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Send16(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.45,15.11l-22-11a1,1,0,0,0-1.08.12,1,1,0,0,0-.33,1L7,16,4,26.74A1,1,0,0,0,5,28a1,1,0,0,0,.45-.11l22-11a1,1,0,0,0,0-1.78Zm-20.9,10L8.76,17H18V15H8.76L6.55,6.89,24.76,16Z"
  })), children);
});
var SendAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendAlt32(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.71,4.29a1,1,0,0,0-1.05-.23l-22,8a1,1,0,0,0,0,1.87l9.6,3.84,3.84,9.6A1,1,0,0,0,19,28h0a1,1,0,0,0,.92-.66l8-22A1,1,0,0,0,27.71,4.29ZM19,24.2l-2.79-7L21,12.41,19.59,11l-4.83,4.83L7.8,13,25.33,6.67Z"
  })), children);
});
var SendAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendAlt24(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.71,4.29a1,1,0,0,0-1.05-.23l-22,8a1,1,0,0,0,0,1.87l9.6,3.84,3.84,9.6A1,1,0,0,0,19,28h0a1,1,0,0,0,.92-.66l8-22A1,1,0,0,0,27.71,4.29ZM19,24.2l-2.79-7L21,12.41,19.59,11l-4.83,4.83L7.8,13,25.33,6.67Z"
  })), children);
});
var SendAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendAlt20(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.71,4.29a1,1,0,0,0-1.05-.23l-22,8a1,1,0,0,0,0,1.87l9.6,3.84,3.84,9.6A1,1,0,0,0,19,28h0a1,1,0,0,0,.92-.66l8-22A1,1,0,0,0,27.71,4.29ZM19,24.2l-2.79-7L21,12.41,19.59,11l-4.83,4.83L7.8,13,25.33,6.67Z"
  })), children);
});
var SendAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendAlt16(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.71,4.29a1,1,0,0,0-1.05-.23l-22,8a1,1,0,0,0,0,1.87l9.6,3.84,3.84,9.6A1,1,0,0,0,19,28h0a1,1,0,0,0,.92-.66l8-22A1,1,0,0,0,27.71,4.29ZM19,24.2l-2.79-7L21,12.41,19.59,11l-4.83,4.83L7.8,13,25.33,6.67Z"
  })), children);
});
var SendAltFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendAltFilled32(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.71,4.29a1,1,0,0,0-1.05-.23l-22,8a1,1,0,0,0,0,1.87l8.59,3.43L19.59,11,21,12.41l-6.37,6.37,3.44,8.59A1,1,0,0,0,19,28h0a1,1,0,0,0,.92-.66l8-22A1,1,0,0,0,27.71,4.29Z"
  })), children);
});
var SendAltFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendAltFilled24(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.71,4.29a1,1,0,0,0-1.05-.23l-22,8a1,1,0,0,0,0,1.87l8.59,3.43L19.59,11,21,12.41l-6.37,6.37,3.44,8.59A1,1,0,0,0,19,28h0a1,1,0,0,0,.92-.66l8-22A1,1,0,0,0,27.71,4.29Z"
  })), children);
});
var SendAltFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendAltFilled20(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.71,4.29a1,1,0,0,0-1.05-.23l-22,8a1,1,0,0,0,0,1.87l8.59,3.43L19.59,11,21,12.41l-6.37,6.37,3.44,8.59A1,1,0,0,0,19,28h0a1,1,0,0,0,.92-.66l8-22A1,1,0,0,0,27.71,4.29Z"
  })), children);
});
var SendAltFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendAltFilled16(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.71,4.29a1,1,0,0,0-1.05-.23l-22,8a1,1,0,0,0,0,1.87l8.59,3.43L19.59,11,21,12.41l-6.37,6.37,3.44,8.59A1,1,0,0,0,19,28h0a1,1,0,0,0,.92-.66l8-22A1,1,0,0,0,27.71,4.29Z"
  })), children);
});
var SendFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendFilled32(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.45,15.11l-22-11a1,1,0,0,0-1.08.12,1,1,0,0,0-.33,1L6.69,15H18v2H6.69L4,26.74A1,1,0,0,0,5,28a1,1,0,0,0,.45-.11l22-11a1,1,0,0,0,0-1.78Z"
  })), children);
});
var SendFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendFilled24(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.45,15.11l-22-11a1,1,0,0,0-1.08.12,1,1,0,0,0-.33,1L6.69,15H18v2H6.69L4,26.74A1,1,0,0,0,5,28a1,1,0,0,0,.45-.11l22-11a1,1,0,0,0,0-1.78Z"
  })), children);
});
var SendFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendFilled20(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.45,15.11l-22-11a1,1,0,0,0-1.08.12,1,1,0,0,0-.33,1L6.69,15H18v2H6.69L4,26.74A1,1,0,0,0,5,28a1,1,0,0,0,.45-.11l22-11a1,1,0,0,0,0-1.78Z"
  })), children);
});
var SendFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendFilled16(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.45,15.11l-22-11a1,1,0,0,0-1.08.12,1,1,0,0,0-.33,1L6.69,15H18v2H6.69L4,26.74A1,1,0,0,0,5,28a1,1,0,0,0,.45-.11l22-11a1,1,0,0,0,0-1.78Z"
  })), children);
});
var SendBackward32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendBackward32(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 7H2V4A2.0023 2.0023 0 014 2H7V4H4zM7 22H4a2.0023 2.0023 0 01-2-2V17H4v3H7zM2 10H4V14H2zM22 7H20V4H17V2h3a2.0023 2.0023 0 012 2zM10 2H14V4H10zM28 30H12a2.0023 2.0023 0 01-2-2V12a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0128 30zM12 12V28H28V12z"
  })), children);
});
var SendBackward24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendBackward24(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 7H2V4A2.0023 2.0023 0 014 2H7V4H4zM7 22H4a2.0023 2.0023 0 01-2-2V17H4v3H7zM2 10H4V14H2zM22 7H20V4H17V2h3a2.0023 2.0023 0 012 2zM10 2H14V4H10zM28 30H12a2.0023 2.0023 0 01-2-2V12a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0128 30zM12 12V28H28V12z"
  })), children);
});
var SendBackward20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendBackward20(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 7H2V4A2.0023 2.0023 0 014 2H7V4H4zM7 22H4a2.0023 2.0023 0 01-2-2V17H4v3H7zM2 10H4V14H2zM22 7H20V4H17V2h3a2.0023 2.0023 0 012 2zM10 2H14V4H10zM28 30H12a2.0023 2.0023 0 01-2-2V12a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0128 30zM12 12V28H28V12z"
  })), children);
});
var SendBackward16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendBackward16(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 7H2V4A2.0023 2.0023 0 014 2H7V4H4zM7 22H4a2.0023 2.0023 0 01-2-2V17H4v3H7zM2 10H4V14H2zM22 7H20V4H17V2h3a2.0023 2.0023 0 012 2zM10 2H14V4H10zM28 30H12a2.0023 2.0023 0 01-2-2V12a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 0128 30zM12 12V28H28V12z"
  })), children);
});
var SendToBack32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendToBack32(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V20a2,2,0,0,0,2,2h6v6a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V12A2.0023,2.0023,0,0,0,28,10ZM12,28V12H28l.0015,16Z"
  })), children);
});
var SendToBack24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendToBack24(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V20a2,2,0,0,0,2,2h6v6a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V12A2.0023,2.0023,0,0,0,28,10ZM12,28V12H28l.0015,16Z"
  })), children);
});
var SendToBack20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendToBack20(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V20a2,2,0,0,0,2,2h6v6a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V12A2.0023,2.0023,0,0,0,28,10ZM12,28V12H28l.0015,16Z"
  })), children);
});
var SendToBack16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SendToBack16(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V20a2,2,0,0,0,2,2h6v6a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V12A2.0023,2.0023,0,0,0,28,10ZM12,28V12H28l.0015,16Z"
  })), children);
});
var ServerDns32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ServerDns32(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 2a8 8 0 108 8A8.0092 8.0092 0 0016 2zm5.91 7H19.4724a15.2457 15.2457 0 00-.7917-4.36A6.0088 6.0088 0 0121.91 9zM16.022 15.999h-.0076c-.3813-.1206-1.3091-1.8213-1.479-4.999h2.9292C17.2952 14.1763 16.3711 15.877 16.022 15.999zM14.5354 9c.1694-3.1763 1.0935-4.877 1.4426-4.999h.0076c.3813.1206 1.3091 1.8213 1.479 4.999zM13.3193 4.64A15.2457 15.2457 0 0012.5276 9H10.09A6.0088 6.0088 0 0113.3193 4.64zM10.09 11h2.4373a15.2457 15.2457 0 00.7917 4.36A6.0088 6.0088 0 0110.09 11zm8.59 4.36A15.2457 15.2457 0 0019.4724 11H21.91A6.0088 6.0088 0 0118.6807 15.36zM28 30H4a2.0021 2.0021 0 01-2-2V22a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0128 30zM4 22v6H28V22z"
  })), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), children);
});
var ServerDns24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ServerDns24(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 2a8 8 0 108 8A8.0092 8.0092 0 0016 2zm5.91 7H19.4724a15.2457 15.2457 0 00-.7917-4.36A6.0088 6.0088 0 0121.91 9zM16.022 15.999h-.0076c-.3813-.1206-1.3091-1.8213-1.479-4.999h2.9292C17.2952 14.1763 16.3711 15.877 16.022 15.999zM14.5354 9c.1694-3.1763 1.0935-4.877 1.4426-4.999h.0076c.3813.1206 1.3091 1.8213 1.479 4.999zM13.3193 4.64A15.2457 15.2457 0 0012.5276 9H10.09A6.0088 6.0088 0 0113.3193 4.64zM10.09 11h2.4373a15.2457 15.2457 0 00.7917 4.36A6.0088 6.0088 0 0110.09 11zm8.59 4.36A15.2457 15.2457 0 0019.4724 11H21.91A6.0088 6.0088 0 0118.6807 15.36zM28 30H4a2.0021 2.0021 0 01-2-2V22a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0128 30zM4 22v6H28V22z"
  })), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), children);
});
var ServerDns20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ServerDns20(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 2a8 8 0 108 8A8.0092 8.0092 0 0016 2zm5.91 7H19.4724a15.2457 15.2457 0 00-.7917-4.36A6.0088 6.0088 0 0121.91 9zM16.022 15.999h-.0076c-.3813-.1206-1.3091-1.8213-1.479-4.999h2.9292C17.2952 14.1763 16.3711 15.877 16.022 15.999zM14.5354 9c.1694-3.1763 1.0935-4.877 1.4426-4.999h.0076c.3813.1206 1.3091 1.8213 1.479 4.999zM13.3193 4.64A15.2457 15.2457 0 0012.5276 9H10.09A6.0088 6.0088 0 0113.3193 4.64zM10.09 11h2.4373a15.2457 15.2457 0 00.7917 4.36A6.0088 6.0088 0 0110.09 11zm8.59 4.36A15.2457 15.2457 0 0019.4724 11H21.91A6.0088 6.0088 0 0118.6807 15.36zM28 30H4a2.0021 2.0021 0 01-2-2V22a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0128 30zM4 22v6H28V22z"
  })), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), children);
});
var ServerDns16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ServerDns16(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 2a8 8 0 108 8A8.0092 8.0092 0 0016 2zm5.91 7H19.4724a15.2457 15.2457 0 00-.7917-4.36A6.0088 6.0088 0 0121.91 9zM16.022 15.999h-.0076c-.3813-.1206-1.3091-1.8213-1.479-4.999h2.9292C17.2952 14.1763 16.3711 15.877 16.022 15.999zM14.5354 9c.1694-3.1763 1.0935-4.877 1.4426-4.999h.0076c.3813.1206 1.3091 1.8213 1.479 4.999zM13.3193 4.64A15.2457 15.2457 0 0012.5276 9H10.09A6.0088 6.0088 0 0113.3193 4.64zM10.09 11h2.4373a15.2457 15.2457 0 00.7917 4.36A6.0088 6.0088 0 0110.09 11zm8.59 4.36A15.2457 15.2457 0 0019.4724 11H21.91A6.0088 6.0088 0 0118.6807 15.36zM28 30H4a2.0021 2.0021 0 01-2-2V22a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v6A2.0021 2.0021 0 0128 30zM4 22v6H28V22z"
  })), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), children);
});
var ServerProxy32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ServerProxy32(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H26a2,2,0,0,0,2-2V22a2,2,0,0,0-2-2H6a2,2,0,0,0-2,2v6A2,2,0,0,0,6,30Zm0-8H26v6H6Z"
  })), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "25",
    r: "1"
  })), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2,24.59,3.41,27.17,6H22.315A6.9835,6.9835,0,0,0,9.08,10H4.83L7.41,7.41,6,6,1,11l5,5,1.41-1.41L4.83,12H9.685A6.9835,6.9835,0,0,0,22.92,8h4.25l-2.58,2.59L26,12l5-5ZM21,9a4.983,4.983,0,0,1-8.9745,3H16V10H11.1011a4.9852,4.9852,0,0,1,8.8734-4H16V8h4.8989A5.0019,5.0019,0,0,1,21,9Z"
  })), children);
});
var ServerProxy24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ServerProxy24(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H26a2,2,0,0,0,2-2V22a2,2,0,0,0-2-2H6a2,2,0,0,0-2,2v6A2,2,0,0,0,6,30Zm0-8H26v6H6Z"
  })), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "25",
    r: "1"
  })), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2,24.59,3.41,27.17,6H22.315A6.9835,6.9835,0,0,0,9.08,10H4.83L7.41,7.41,6,6,1,11l5,5,1.41-1.41L4.83,12H9.685A6.9835,6.9835,0,0,0,22.92,8h4.25l-2.58,2.59L26,12l5-5ZM21,9a4.983,4.983,0,0,1-8.9745,3H16V10H11.1011a4.9852,4.9852,0,0,1,8.8734-4H16V8h4.8989A5.0019,5.0019,0,0,1,21,9Z"
  })), children);
});
var ServerProxy20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ServerProxy20(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H26a2,2,0,0,0,2-2V22a2,2,0,0,0-2-2H6a2,2,0,0,0-2,2v6A2,2,0,0,0,6,30Zm0-8H26v6H6Z"
  })), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "25",
    r: "1"
  })), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2,24.59,3.41,27.17,6H22.315A6.9835,6.9835,0,0,0,9.08,10H4.83L7.41,7.41,6,6,1,11l5,5,1.41-1.41L4.83,12H9.685A6.9835,6.9835,0,0,0,22.92,8h4.25l-2.58,2.59L26,12l5-5ZM21,9a4.983,4.983,0,0,1-8.9745,3H16V10H11.1011a4.9852,4.9852,0,0,1,8.8734-4H16V8h4.8989A5.0019,5.0019,0,0,1,21,9Z"
  })), children);
});
var ServerProxy16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ServerProxy16(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H26a2,2,0,0,0,2-2V22a2,2,0,0,0-2-2H6a2,2,0,0,0-2,2v6A2,2,0,0,0,6,30Zm0-8H26v6H6Z"
  })), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "25",
    r: "1"
  })), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2,24.59,3.41,27.17,6H22.315A6.9835,6.9835,0,0,0,9.08,10H4.83L7.41,7.41,6,6,1,11l5,5,1.41-1.41L4.83,12H9.685A6.9835,6.9835,0,0,0,22.92,8h4.25l-2.58,2.59L26,12l5-5ZM21,9a4.983,4.983,0,0,1-8.9745,3H16V10H11.1011a4.9852,4.9852,0,0,1,8.8734-4H16V8h4.8989A5.0019,5.0019,0,0,1,21,9Z"
  })), children);
});
var ServerTime32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ServerTime32(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V22a2.0021,2.0021,0,0,1,2-2H28a2.0021,2.0021,0,0,1,2,2v6A2.0021,2.0021,0,0,1,28,30ZM4,22v6H28V22Z"
  })), _circle21 || (_circle21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 11.586L17 9.586 17 6 15 6 15 10.414 17.586 13 19 11.586z"
  })), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,18a8,8,0,1,1,8-8A8.0092,8.0092,0,0,1,16,18ZM16,4a6,6,0,1,0,6,6A6.0067,6.0067,0,0,0,16,4Z"
  })), children);
});
var ServerTime24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ServerTime24(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V22a2.0021,2.0021,0,0,1,2-2H28a2.0021,2.0021,0,0,1,2,2v6A2.0021,2.0021,0,0,1,28,30ZM4,22v6H28V22Z"
  })), _circle22 || (_circle22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 11.586L17 9.586 17 6 15 6 15 10.414 17.586 13 19 11.586z"
  })), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,18a8,8,0,1,1,8-8A8.0092,8.0092,0,0,1,16,18ZM16,4a6,6,0,1,0,6,6A6.0067,6.0067,0,0,0,16,4Z"
  })), children);
});
var ServerTime20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ServerTime20(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V22a2.0021,2.0021,0,0,1,2-2H28a2.0021,2.0021,0,0,1,2,2v6A2.0021,2.0021,0,0,1,28,30ZM4,22v6H28V22Z"
  })), _circle23 || (_circle23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 11.586L17 9.586 17 6 15 6 15 10.414 17.586 13 19 11.586z"
  })), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,18a8,8,0,1,1,8-8A8.0092,8.0092,0,0,1,16,18ZM16,4a6,6,0,1,0,6,6A6.0067,6.0067,0,0,0,16,4Z"
  })), children);
});
var ServerTime16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ServerTime16(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V22a2.0021,2.0021,0,0,1,2-2H28a2.0021,2.0021,0,0,1,2,2v6A2.0021,2.0021,0,0,1,28,30ZM4,22v6H28V22Z"
  })), _circle24 || (_circle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 11.586L17 9.586 17 6 15 6 15 10.414 17.586 13 19 11.586z"
  })), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,18a8,8,0,1,1,8-8A8.0092,8.0092,0,0,1,16,18ZM16,4a6,6,0,1,0,6,6A6.0067,6.0067,0,0,0,16,4Z"
  })), children);
});
var ServiceDesk32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ServiceDesk32(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24V22A12.01,12.01,0,0,0,17,10.0507V8h3V6H12V8h3v2.0507A12.01,12.01,0,0,0,4,22v2H2v2H30V24ZM16,12a10.0167,10.0167,0,0,1,9.7984,8H6.2015A10.0165,10.0165,0,0,1,16,12ZM6,22H26v2H6Z",
    transform: "translate(0 .005)"
  })), children);
});
var ServiceDesk24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ServiceDesk24(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24V22A12.01,12.01,0,0,0,17,10.0507V8h3V6H12V8h3v2.0507A12.01,12.01,0,0,0,4,22v2H2v2H30V24ZM16,12a10.0167,10.0167,0,0,1,9.7984,8H6.2015A10.0165,10.0165,0,0,1,16,12ZM6,22H26v2H6Z",
    transform: "translate(0 .005)"
  })), children);
});
var ServiceDesk20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ServiceDesk20(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24V22A12.01,12.01,0,0,0,17,10.0507V8h3V6H12V8h3v2.0507A12.01,12.01,0,0,0,4,22v2H2v2H30V24ZM16,12a10.0167,10.0167,0,0,1,9.7984,8H6.2015A10.0165,10.0165,0,0,1,16,12ZM6,22H26v2H6Z",
    transform: "translate(0 .005)"
  })), children);
});
var ServiceDesk16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ServiceDesk16(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24V22A12.01,12.01,0,0,0,17,10.0507V8h3V6H12V8h3v2.0507A12.01,12.01,0,0,0,4,22v2H2v2H30V24ZM16,12a10.0167,10.0167,0,0,1,9.7984,8H6.2015A10.0165,10.0165,0,0,1,16,12ZM6,22H26v2H6Z",
    transform: "translate(0 .005)"
  })), children);
});
var SessionBorderControl32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SessionBorderControl32(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,8,24.59,9.41,27.17,12H16a5.967,5.967,0,0,0-4,1.54V6.83l2.59,2.58L16,8,11,3,6,8,7.41,9.41,10,6.83V18a5.969,5.969,0,0,0,1.54,4H4.83l2.58-2.59L6,18,1,23l5,5,1.41-1.41L4.83,24H16A5.99,5.99,0,0,0,20.46,14h6.71l-2.58,2.59L26,18l5-5ZM20,18a4,4,0,1,1-4-4A4.0045,4.0045,0,0,1,20,18Z"
  })), children);
});
var SessionBorderControl24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SessionBorderControl24(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,8,24.59,9.41,27.17,12H16a5.967,5.967,0,0,0-4,1.54V6.83l2.59,2.58L16,8,11,3,6,8,7.41,9.41,10,6.83V18a5.969,5.969,0,0,0,1.54,4H4.83l2.58-2.59L6,18,1,23l5,5,1.41-1.41L4.83,24H16A5.99,5.99,0,0,0,20.46,14h6.71l-2.58,2.59L26,18l5-5ZM20,18a4,4,0,1,1-4-4A4.0045,4.0045,0,0,1,20,18Z"
  })), children);
});
var SessionBorderControl20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SessionBorderControl20(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,8,24.59,9.41,27.17,12H16a5.967,5.967,0,0,0-4,1.54V6.83l2.59,2.58L16,8,11,3,6,8,7.41,9.41,10,6.83V18a5.969,5.969,0,0,0,1.54,4H4.83l2.58-2.59L6,18,1,23l5,5,1.41-1.41L4.83,24H16A5.99,5.99,0,0,0,20.46,14h6.71l-2.58,2.59L26,18l5-5ZM20,18a4,4,0,1,1-4-4A4.0045,4.0045,0,0,1,20,18Z"
  })), children);
});
var SessionBorderControl16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SessionBorderControl16(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,8,24.59,9.41,27.17,12H16a5.967,5.967,0,0,0-4,1.54V6.83l2.59,2.58L16,8,11,3,6,8,7.41,9.41,10,6.83V18a5.969,5.969,0,0,0,1.54,4H4.83l2.58-2.59L6,18,1,23l5,5,1.41-1.41L4.83,24H16A5.99,5.99,0,0,0,20.46,14h6.71l-2.58,2.59L26,18l5-5ZM20,18a4,4,0,1,1-4-4A4.0045,4.0045,0,0,1,20,18Z"
  })), children);
});
var Settings32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Settings32(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,16.76c0-.25,0-.5,0-.76s0-.51,0-.77l1.92-1.68A2,2,0,0,0,29.3,11L26.94,7a2,2,0,0,0-1.73-1,2,2,0,0,0-.64.1l-2.43.82a11.35,11.35,0,0,0-1.31-.75l-.51-2.52a2,2,0,0,0-2-1.61H13.64a2,2,0,0,0-2,1.61l-.51,2.52a11.48,11.48,0,0,0-1.32.75L7.43,6.06A2,2,0,0,0,6.79,6,2,2,0,0,0,5.06,7L2.7,11a2,2,0,0,0,.41,2.51L5,15.24c0,.25,0,.5,0,.76s0,.51,0,.77L3.11,18.45A2,2,0,0,0,2.7,21L5.06,25a2,2,0,0,0,1.73,1,2,2,0,0,0,.64-.1l2.43-.82a11.35,11.35,0,0,0,1.31.75l.51,2.52a2,2,0,0,0,2,1.61h4.72a2,2,0,0,0,2-1.61l.51-2.52a11.48,11.48,0,0,0,1.32-.75l2.42.82a2,2,0,0,0,.64.1,2,2,0,0,0,1.73-1L29.3,21a2,2,0,0,0-.41-2.51ZM25.21,24l-3.43-1.16a8.86,8.86,0,0,1-2.71,1.57L18.36,28H13.64l-.71-3.55a9.36,9.36,0,0,1-2.7-1.57L6.79,24,4.43,20l2.72-2.4a8.9,8.9,0,0,1,0-3.13L4.43,12,6.79,8l3.43,1.16a8.86,8.86,0,0,1,2.71-1.57L13.64,4h4.72l.71,3.55a9.36,9.36,0,0,1,2.7,1.57L25.21,8,27.57,12l-2.72,2.4a8.9,8.9,0,0,1,0,3.13L27.57,20Z"
  })), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A5.94,5.94,0,0,1,16,22Zm0-10a3.91,3.91,0,0,0-4,4,3.91,3.91,0,0,0,4,4,3.91,3.91,0,0,0,4-4A3.91,3.91,0,0,0,16,12Z"
  })), children);
});
var Settings24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Settings24(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,16.76c0-.25,0-.5,0-.76s0-.51,0-.77l1.92-1.68A2,2,0,0,0,29.3,11L26.94,7a2,2,0,0,0-1.73-1,2,2,0,0,0-.64.1l-2.43.82a11.35,11.35,0,0,0-1.31-.75l-.51-2.52a2,2,0,0,0-2-1.61H13.64a2,2,0,0,0-2,1.61l-.51,2.52a11.48,11.48,0,0,0-1.32.75L7.43,6.06A2,2,0,0,0,6.79,6,2,2,0,0,0,5.06,7L2.7,11a2,2,0,0,0,.41,2.51L5,15.24c0,.25,0,.5,0,.76s0,.51,0,.77L3.11,18.45A2,2,0,0,0,2.7,21L5.06,25a2,2,0,0,0,1.73,1,2,2,0,0,0,.64-.1l2.43-.82a11.35,11.35,0,0,0,1.31.75l.51,2.52a2,2,0,0,0,2,1.61h4.72a2,2,0,0,0,2-1.61l.51-2.52a11.48,11.48,0,0,0,1.32-.75l2.42.82a2,2,0,0,0,.64.1,2,2,0,0,0,1.73-1L29.3,21a2,2,0,0,0-.41-2.51ZM25.21,24l-3.43-1.16a8.86,8.86,0,0,1-2.71,1.57L18.36,28H13.64l-.71-3.55a9.36,9.36,0,0,1-2.7-1.57L6.79,24,4.43,20l2.72-2.4a8.9,8.9,0,0,1,0-3.13L4.43,12,6.79,8l3.43,1.16a8.86,8.86,0,0,1,2.71-1.57L13.64,4h4.72l.71,3.55a9.36,9.36,0,0,1,2.7,1.57L25.21,8,27.57,12l-2.72,2.4a8.9,8.9,0,0,1,0,3.13L27.57,20Z"
  })), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A5.94,5.94,0,0,1,16,22Zm0-10a3.91,3.91,0,0,0-4,4,3.91,3.91,0,0,0,4,4,3.91,3.91,0,0,0,4-4A3.91,3.91,0,0,0,16,12Z"
  })), children);
});
var Settings20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Settings20(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,16.76c0-.25,0-.5,0-.76s0-.51,0-.77l1.92-1.68A2,2,0,0,0,29.3,11L26.94,7a2,2,0,0,0-1.73-1,2,2,0,0,0-.64.1l-2.43.82a11.35,11.35,0,0,0-1.31-.75l-.51-2.52a2,2,0,0,0-2-1.61H13.64a2,2,0,0,0-2,1.61l-.51,2.52a11.48,11.48,0,0,0-1.32.75L7.43,6.06A2,2,0,0,0,6.79,6,2,2,0,0,0,5.06,7L2.7,11a2,2,0,0,0,.41,2.51L5,15.24c0,.25,0,.5,0,.76s0,.51,0,.77L3.11,18.45A2,2,0,0,0,2.7,21L5.06,25a2,2,0,0,0,1.73,1,2,2,0,0,0,.64-.1l2.43-.82a11.35,11.35,0,0,0,1.31.75l.51,2.52a2,2,0,0,0,2,1.61h4.72a2,2,0,0,0,2-1.61l.51-2.52a11.48,11.48,0,0,0,1.32-.75l2.42.82a2,2,0,0,0,.64.1,2,2,0,0,0,1.73-1L29.3,21a2,2,0,0,0-.41-2.51ZM25.21,24l-3.43-1.16a8.86,8.86,0,0,1-2.71,1.57L18.36,28H13.64l-.71-3.55a9.36,9.36,0,0,1-2.7-1.57L6.79,24,4.43,20l2.72-2.4a8.9,8.9,0,0,1,0-3.13L4.43,12,6.79,8l3.43,1.16a8.86,8.86,0,0,1,2.71-1.57L13.64,4h4.72l.71,3.55a9.36,9.36,0,0,1,2.7,1.57L25.21,8,27.57,12l-2.72,2.4a8.9,8.9,0,0,1,0,3.13L27.57,20Z"
  })), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A5.94,5.94,0,0,1,16,22Zm0-10a3.91,3.91,0,0,0-4,4,3.91,3.91,0,0,0,4,4,3.91,3.91,0,0,0,4-4A3.91,3.91,0,0,0,16,12Z"
  })), children);
});
var Settings16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Settings16(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.5,8.4c0-0.1,0-0.3,0-0.4c0-0.1,0-0.3,0-0.4l1-0.8c0.4-0.3,0.4-0.9,0.2-1.3l-1.2-2C13.3,3.2,13,3,12.6,3\tc-0.1,0-0.2,0-0.3,0.1l-1.2,0.4c-0.2-0.1-0.4-0.3-0.7-0.4l-0.3-1.3C10.1,1.3,9.7,1,9.2,1H6.8c-0.5,0-0.9,0.3-1,0.8L5.6,3.1\tC5.3,3.2,5.1,3.3,4.9,3.4L3.7,3C3.6,3,3.5,3,3.4,3C3,3,2.7,3.2,2.5,3.5l-1.2,2C1.1,5.9,1.2,6.4,1.6,6.8l0.9,0.9c0,0.1,0,0.3,0,0.4\tc0,0.1,0,0.3,0,0.4L1.6,9.2c-0.4,0.3-0.5,0.9-0.2,1.3l1.2,2C2.7,12.8,3,13,3.4,13c0.1,0,0.2,0,0.3-0.1l1.2-0.4\tc0.2,0.1,0.4,0.3,0.7,0.4l0.3,1.3c0.1,0.5,0.5,0.8,1,0.8h2.4c0.5,0,0.9-0.3,1-0.8l0.3-1.3c0.2-0.1,0.4-0.2,0.7-0.4l1.2,0.4\tc0.1,0,0.2,0.1,0.3,0.1c0.4,0,0.7-0.2,0.9-0.5l1.1-2c0.2-0.4,0.2-0.9-0.2-1.3L13.5,8.4z M12.6,12l-1.7-0.6c-0.4,0.3-0.9,0.6-1.4,0.8\tL9.2,14H6.8l-0.4-1.8c-0.5-0.2-0.9-0.5-1.4-0.8L3.4,12l-1.2-2l1.4-1.2c-0.1-0.5-0.1-1.1,0-1.6L2.2,6l1.2-2l1.7,0.6\tC5.5,4.2,6,4,6.5,3.8L6.8,2h2.4l0.4,1.8c0.5,0.2,0.9,0.5,1.4,0.8L12.6,4l1.2,2l-1.4,1.2c0.1,0.5,0.1,1.1,0,1.6l1.4,1.2L12.6,12z"
  })), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,11c-1.7,0-3-1.3-3-3s1.3-3,3-3s3,1.3,3,3C11,9.6,9.7,11,8,11C8,11,8,11,8,11z M8,6C6.9,6,6,6.8,6,7.9C6,7.9,6,8,6,8\tc0,1.1,0.8,2,1.9,2c0,0,0.1,0,0.1,0c1.1,0,2-0.8,2-1.9c0,0,0-0.1,0-0.1C10,6.9,9.2,6,8,6C8.1,6,8,6,8,6z"
  })), children);
});
var SettingsAdjust32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SettingsAdjust32(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 8h-4.1c-.5-2.3-2.5-4-4.9-4s-4.4 1.7-4.9 4H2v2h14.1c.5 2.3 2.5 4 4.9 4s4.4-1.7 4.9-4H30V8zM21 12c-1.7 0-3-1.3-3-3s1.3-3 3-3 3 1.3 3 3S22.7 12 21 12zM2 24h4.1c.5 2.3 2.5 4 4.9 4s4.4-1.7 4.9-4H30v-2H15.9c-.5-2.3-2.5-4-4.9-4s-4.4 1.7-4.9 4H2V24zM11 20c1.7 0 3 1.3 3 3s-1.3 3-3 3-3-1.3-3-3S9.3 20 11 20z"
  })), children);
});
var SettingsAdjust24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SettingsAdjust24(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 8h-4.1c-.5-2.3-2.5-4-4.9-4s-4.4 1.7-4.9 4H2v2h14.1c.5 2.3 2.5 4 4.9 4s4.4-1.7 4.9-4H30V8zM21 12c-1.7 0-3-1.3-3-3s1.3-3 3-3 3 1.3 3 3S22.7 12 21 12zM2 24h4.1c.5 2.3 2.5 4 4.9 4s4.4-1.7 4.9-4H30v-2H15.9c-.5-2.3-2.5-4-4.9-4s-4.4 1.7-4.9 4H2V24zM11 20c1.7 0 3 1.3 3 3s-1.3 3-3 3-3-1.3-3-3S9.3 20 11 20z"
  })), children);
});
var SettingsAdjust20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SettingsAdjust20(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 8h-4.1c-.5-2.3-2.5-4-4.9-4s-4.4 1.7-4.9 4H2v2h14.1c.5 2.3 2.5 4 4.9 4s4.4-1.7 4.9-4H30V8zM21 12c-1.7 0-3-1.3-3-3s1.3-3 3-3 3 1.3 3 3S22.7 12 21 12zM2 24h4.1c.5 2.3 2.5 4 4.9 4s4.4-1.7 4.9-4H30v-2H15.9c-.5-2.3-2.5-4-4.9-4s-4.4 1.7-4.9 4H2V24zM11 20c1.7 0 3 1.3 3 3s-1.3 3-3 3-3-1.3-3-3S9.3 20 11 20z"
  })), children);
});
var SettingsAdjust16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SettingsAdjust16(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 8h-4.1c-.5-2.3-2.5-4-4.9-4s-4.4 1.7-4.9 4H2v2h14.1c.5 2.3 2.5 4 4.9 4s4.4-1.7 4.9-4H30V8zM21 12c-1.7 0-3-1.3-3-3s1.3-3 3-3 3 1.3 3 3S22.7 12 21 12zM2 24h4.1c.5 2.3 2.5 4 4.9 4s4.4-1.7 4.9-4H30v-2H15.9c-.5-2.3-2.5-4-4.9-4s-4.4 1.7-4.9 4H2V24zM11 20c1.7 0 3 1.3 3 3s-1.3 3-3 3-3-1.3-3-3S9.3 20 11 20z"
  })), children);
});
var SettingsCheck32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SettingsCheck32(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A5.9364,5.9364,0,0,1,16,22Zm0-10a3.9123,3.9123,0,0,0-4,4,3.9123,3.9123,0,0,0,4,4,3.9123,3.9123,0,0,0,4-4A3.9123,3.9123,0,0,0,16,12Z"
  })), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3047,11.044,26.9441,6.9562a1.9977,1.9977,0,0,0-2.3728-.8946l-2.4341.8233a11.0419,11.0419,0,0,0-1.312-.7583L20.3215,3.608A2,2,0,0,0,18.36,2H13.64A2,2,0,0,0,11.6785,3.608l-.5037,2.5186A10.9666,10.9666,0,0,0,9.8481,6.88L7.4287,6.0616a1.9977,1.9977,0,0,0-2.3728.8946L2.6953,11.044a2.0006,2.0006,0,0,0,.4119,2.5025l1.9309,1.6968C5.021,15.4947,5,15.7447,5,16c0,.2578.01.5127.0278.7656l-1.9206,1.688a2.0006,2.0006,0,0,0-.4119,2.5025L5.0559,25.044a1.9977,1.9977,0,0,0,2.3728.8946l2.4341-.8233a10.9736,10.9736,0,0,0,1.312.7583l.5037,2.5186A2,2,0,0,0,13.64,30H18V28H13.64l-.71-3.5508a9.0953,9.0953,0,0,1-2.6948-1.5713L6.7878,24.044l-2.36-4.0878,2.7253-2.3951a8.9263,8.9263,0,0,1-.007-3.1279L4.4275,12.044,6.7886,7.9562l3.4267,1.1591a9.0305,9.0305,0,0,1,2.7141-1.5644L13.64,4H18.36l.71,3.5508a9.0978,9.0978,0,0,1,2.6948,1.5713l3.4468-1.166,2.36,4.0878-2.7978,2.4522L26.0923,16l2.8-2.4536A2.0006,2.0006,0,0,0,29.3047,11.044Z"
  })), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 26.18L20.41 23.59 19 25 23 29 30 22 28.59 20.59 23 26.18z"
  })), children);
});
var SettingsCheck24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SettingsCheck24(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A5.9364,5.9364,0,0,1,16,22Zm0-10a3.9123,3.9123,0,0,0-4,4,3.9123,3.9123,0,0,0,4,4,3.9123,3.9123,0,0,0,4-4A3.9123,3.9123,0,0,0,16,12Z"
  })), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3047,11.044,26.9441,6.9562a1.9977,1.9977,0,0,0-2.3728-.8946l-2.4341.8233a11.0419,11.0419,0,0,0-1.312-.7583L20.3215,3.608A2,2,0,0,0,18.36,2H13.64A2,2,0,0,0,11.6785,3.608l-.5037,2.5186A10.9666,10.9666,0,0,0,9.8481,6.88L7.4287,6.0616a1.9977,1.9977,0,0,0-2.3728.8946L2.6953,11.044a2.0006,2.0006,0,0,0,.4119,2.5025l1.9309,1.6968C5.021,15.4947,5,15.7447,5,16c0,.2578.01.5127.0278.7656l-1.9206,1.688a2.0006,2.0006,0,0,0-.4119,2.5025L5.0559,25.044a1.9977,1.9977,0,0,0,2.3728.8946l2.4341-.8233a10.9736,10.9736,0,0,0,1.312.7583l.5037,2.5186A2,2,0,0,0,13.64,30H18V28H13.64l-.71-3.5508a9.0953,9.0953,0,0,1-2.6948-1.5713L6.7878,24.044l-2.36-4.0878,2.7253-2.3951a8.9263,8.9263,0,0,1-.007-3.1279L4.4275,12.044,6.7886,7.9562l3.4267,1.1591a9.0305,9.0305,0,0,1,2.7141-1.5644L13.64,4H18.36l.71,3.5508a9.0978,9.0978,0,0,1,2.6948,1.5713l3.4468-1.166,2.36,4.0878-2.7978,2.4522L26.0923,16l2.8-2.4536A2.0006,2.0006,0,0,0,29.3047,11.044Z"
  })), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 26.18L20.41 23.59 19 25 23 29 30 22 28.59 20.59 23 26.18z"
  })), children);
});
var SettingsCheck20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SettingsCheck20(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A5.9364,5.9364,0,0,1,16,22Zm0-10a3.9123,3.9123,0,0,0-4,4,3.9123,3.9123,0,0,0,4,4,3.9123,3.9123,0,0,0,4-4A3.9123,3.9123,0,0,0,16,12Z"
  })), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3047,11.044,26.9441,6.9562a1.9977,1.9977,0,0,0-2.3728-.8946l-2.4341.8233a11.0419,11.0419,0,0,0-1.312-.7583L20.3215,3.608A2,2,0,0,0,18.36,2H13.64A2,2,0,0,0,11.6785,3.608l-.5037,2.5186A10.9666,10.9666,0,0,0,9.8481,6.88L7.4287,6.0616a1.9977,1.9977,0,0,0-2.3728.8946L2.6953,11.044a2.0006,2.0006,0,0,0,.4119,2.5025l1.9309,1.6968C5.021,15.4947,5,15.7447,5,16c0,.2578.01.5127.0278.7656l-1.9206,1.688a2.0006,2.0006,0,0,0-.4119,2.5025L5.0559,25.044a1.9977,1.9977,0,0,0,2.3728.8946l2.4341-.8233a10.9736,10.9736,0,0,0,1.312.7583l.5037,2.5186A2,2,0,0,0,13.64,30H18V28H13.64l-.71-3.5508a9.0953,9.0953,0,0,1-2.6948-1.5713L6.7878,24.044l-2.36-4.0878,2.7253-2.3951a8.9263,8.9263,0,0,1-.007-3.1279L4.4275,12.044,6.7886,7.9562l3.4267,1.1591a9.0305,9.0305,0,0,1,2.7141-1.5644L13.64,4H18.36l.71,3.5508a9.0978,9.0978,0,0,1,2.6948,1.5713l3.4468-1.166,2.36,4.0878-2.7978,2.4522L26.0923,16l2.8-2.4536A2.0006,2.0006,0,0,0,29.3047,11.044Z"
  })), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 26.18L20.41 23.59 19 25 23 29 30 22 28.59 20.59 23 26.18z"
  })), children);
});
var SettingsCheck16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SettingsCheck16(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A5.9364,5.9364,0,0,1,16,22Zm0-10a3.9123,3.9123,0,0,0-4,4,3.9123,3.9123,0,0,0,4,4,3.9123,3.9123,0,0,0,4-4A3.9123,3.9123,0,0,0,16,12Z"
  })), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3047,11.044,26.9441,6.9562a1.9977,1.9977,0,0,0-2.3728-.8946l-2.4341.8233a11.0419,11.0419,0,0,0-1.312-.7583L20.3215,3.608A2,2,0,0,0,18.36,2H13.64A2,2,0,0,0,11.6785,3.608l-.5037,2.5186A10.9666,10.9666,0,0,0,9.8481,6.88L7.4287,6.0616a1.9977,1.9977,0,0,0-2.3728.8946L2.6953,11.044a2.0006,2.0006,0,0,0,.4119,2.5025l1.9309,1.6968C5.021,15.4947,5,15.7447,5,16c0,.2578.01.5127.0278.7656l-1.9206,1.688a2.0006,2.0006,0,0,0-.4119,2.5025L5.0559,25.044a1.9977,1.9977,0,0,0,2.3728.8946l2.4341-.8233a10.9736,10.9736,0,0,0,1.312.7583l.5037,2.5186A2,2,0,0,0,13.64,30H18V28H13.64l-.71-3.5508a9.0953,9.0953,0,0,1-2.6948-1.5713L6.7878,24.044l-2.36-4.0878,2.7253-2.3951a8.9263,8.9263,0,0,1-.007-3.1279L4.4275,12.044,6.7886,7.9562l3.4267,1.1591a9.0305,9.0305,0,0,1,2.7141-1.5644L13.64,4H18.36l.71,3.5508a9.0978,9.0978,0,0,1,2.6948,1.5713l3.4468-1.166,2.36,4.0878-2.7978,2.4522L26.0923,16l2.8-2.4536A2.0006,2.0006,0,0,0,29.3047,11.044Z"
  })), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 26.18L20.41 23.59 19 25 23 29 30 22 28.59 20.59 23 26.18z"
  })), children);
});
var SettingsServices32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SettingsServices32(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,25H27V23h1V19H24v1H22V18a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1v6A1,1,0,0,1,29,25Z"
  })), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30H18a1 1 0 01-1-1V23a1 1 0 011-1h6a1 1 0 011 1v6A1 1 0 0124 30zm-5-2h4V24H19zM15 19.8579A3.9934 3.9934 0 1120 16h2a6 6 0 10-7 5.91z"
  })), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.89,13.55l-2.31,2.03-1.42-1.42,2.41-2.12L25.21,7.96,21.77,9.12a9.3684,9.3684,0,0,0-2.7-1.57L18.36,4H13.64l-.71,3.55a8.8609,8.8609,0,0,0-2.71,1.57L6.79,7.96,4.43,12.04l2.72,2.39a8.8948,8.8948,0,0,0,0,3.13l-2.72,2.4,2.36,4.08,3.44-1.16a9.3684,9.3684,0,0,0,2.7,1.57L13.64,28H15v2H13.64a2.0007,2.0007,0,0,1-1.96-1.61l-.51-2.52a11.412,11.412,0,0,1-1.31-.75l-2.43.82a2.038,2.038,0,0,1-.64.1,1.973,1.973,0,0,1-1.73-1L2.7,20.96a2,2,0,0,1,.41-2.51l1.92-1.68C5.01,16.51,5,16.26,5,16s.02-.51.04-.76L3.11,13.55a2,2,0,0,1-.41-2.51L5.06,6.96a1.973,1.973,0,0,1,1.73-1,2.038,2.038,0,0,1,.64.1l2.42.82a11.5416,11.5416,0,0,1,1.32-.75l.51-2.52A2.0007,2.0007,0,0,1,13.64,2h4.72a2.0007,2.0007,0,0,1,1.96,1.61l.51,2.52a11.412,11.412,0,0,1,1.31.75l2.43-.82a2.038,2.038,0,0,1,.64-.1,1.973,1.973,0,0,1,1.73,1l2.36,4.08A2,2,0,0,1,28.89,13.55Z"
  })), children);
});
var SettingsServices24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SettingsServices24(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,25H27V23h1V19H24v1H22V18a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1v6A1,1,0,0,1,29,25Z"
  })), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30H18a1 1 0 01-1-1V23a1 1 0 011-1h6a1 1 0 011 1v6A1 1 0 0124 30zm-5-2h4V24H19zM15 19.8579A3.9934 3.9934 0 1120 16h2a6 6 0 10-7 5.91z"
  })), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.89,13.55l-2.31,2.03-1.42-1.42,2.41-2.12L25.21,7.96,21.77,9.12a9.3684,9.3684,0,0,0-2.7-1.57L18.36,4H13.64l-.71,3.55a8.8609,8.8609,0,0,0-2.71,1.57L6.79,7.96,4.43,12.04l2.72,2.39a8.8948,8.8948,0,0,0,0,3.13l-2.72,2.4,2.36,4.08,3.44-1.16a9.3684,9.3684,0,0,0,2.7,1.57L13.64,28H15v2H13.64a2.0007,2.0007,0,0,1-1.96-1.61l-.51-2.52a11.412,11.412,0,0,1-1.31-.75l-2.43.82a2.038,2.038,0,0,1-.64.1,1.973,1.973,0,0,1-1.73-1L2.7,20.96a2,2,0,0,1,.41-2.51l1.92-1.68C5.01,16.51,5,16.26,5,16s.02-.51.04-.76L3.11,13.55a2,2,0,0,1-.41-2.51L5.06,6.96a1.973,1.973,0,0,1,1.73-1,2.038,2.038,0,0,1,.64.1l2.42.82a11.5416,11.5416,0,0,1,1.32-.75l.51-2.52A2.0007,2.0007,0,0,1,13.64,2h4.72a2.0007,2.0007,0,0,1,1.96,1.61l.51,2.52a11.412,11.412,0,0,1,1.31.75l2.43-.82a2.038,2.038,0,0,1,.64-.1,1.973,1.973,0,0,1,1.73,1l2.36,4.08A2,2,0,0,1,28.89,13.55Z"
  })), children);
});
var SettingsServices20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SettingsServices20(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,25H27V23h1V19H24v1H22V18a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1v6A1,1,0,0,1,29,25Z"
  })), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30H18a1 1 0 01-1-1V23a1 1 0 011-1h6a1 1 0 011 1v6A1 1 0 0124 30zm-5-2h4V24H19zM15 19.8579A3.9934 3.9934 0 1120 16h2a6 6 0 10-7 5.91z"
  })), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.89,13.55l-2.31,2.03-1.42-1.42,2.41-2.12L25.21,7.96,21.77,9.12a9.3684,9.3684,0,0,0-2.7-1.57L18.36,4H13.64l-.71,3.55a8.8609,8.8609,0,0,0-2.71,1.57L6.79,7.96,4.43,12.04l2.72,2.39a8.8948,8.8948,0,0,0,0,3.13l-2.72,2.4,2.36,4.08,3.44-1.16a9.3684,9.3684,0,0,0,2.7,1.57L13.64,28H15v2H13.64a2.0007,2.0007,0,0,1-1.96-1.61l-.51-2.52a11.412,11.412,0,0,1-1.31-.75l-2.43.82a2.038,2.038,0,0,1-.64.1,1.973,1.973,0,0,1-1.73-1L2.7,20.96a2,2,0,0,1,.41-2.51l1.92-1.68C5.01,16.51,5,16.26,5,16s.02-.51.04-.76L3.11,13.55a2,2,0,0,1-.41-2.51L5.06,6.96a1.973,1.973,0,0,1,1.73-1,2.038,2.038,0,0,1,.64.1l2.42.82a11.5416,11.5416,0,0,1,1.32-.75l.51-2.52A2.0007,2.0007,0,0,1,13.64,2h4.72a2.0007,2.0007,0,0,1,1.96,1.61l.51,2.52a11.412,11.412,0,0,1,1.31.75l2.43-.82a2.038,2.038,0,0,1,.64-.1,1.973,1.973,0,0,1,1.73,1l2.36,4.08A2,2,0,0,1,28.89,13.55Z"
  })), children);
});
var SettingsServices16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SettingsServices16(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,25H27V23h1V19H24v1H22V18a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1v6A1,1,0,0,1,29,25Z"
  })), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30H18a1 1 0 01-1-1V23a1 1 0 011-1h6a1 1 0 011 1v6A1 1 0 0124 30zm-5-2h4V24H19zM15 19.8579A3.9934 3.9934 0 1120 16h2a6 6 0 10-7 5.91z"
  })), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.89,13.55l-2.31,2.03-1.42-1.42,2.41-2.12L25.21,7.96,21.77,9.12a9.3684,9.3684,0,0,0-2.7-1.57L18.36,4H13.64l-.71,3.55a8.8609,8.8609,0,0,0-2.71,1.57L6.79,7.96,4.43,12.04l2.72,2.39a8.8948,8.8948,0,0,0,0,3.13l-2.72,2.4,2.36,4.08,3.44-1.16a9.3684,9.3684,0,0,0,2.7,1.57L13.64,28H15v2H13.64a2.0007,2.0007,0,0,1-1.96-1.61l-.51-2.52a11.412,11.412,0,0,1-1.31-.75l-2.43.82a2.038,2.038,0,0,1-.64.1,1.973,1.973,0,0,1-1.73-1L2.7,20.96a2,2,0,0,1,.41-2.51l1.92-1.68C5.01,16.51,5,16.26,5,16s.02-.51.04-.76L3.11,13.55a2,2,0,0,1-.41-2.51L5.06,6.96a1.973,1.973,0,0,1,1.73-1,2.038,2.038,0,0,1,.64.1l2.42.82a11.5416,11.5416,0,0,1,1.32-.75l.51-2.52A2.0007,2.0007,0,0,1,13.64,2h4.72a2.0007,2.0007,0,0,1,1.96,1.61l.51,2.52a11.412,11.412,0,0,1,1.31.75l2.43-.82a2.038,2.038,0,0,1,.64-.1,1.973,1.973,0,0,1,1.73,1l2.36,4.08A2,2,0,0,1,28.89,13.55Z"
  })), children);
});
var SettingsView32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SettingsView32(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle25 || (_circle25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "24",
    r: "2"
  })), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.7769 23.4785A8.64 8.64 0 0023 18a8.64 8.64 0 00-7.7769 5.4785L15 24l.2231.5215A8.64 8.64 0 0023 30a8.64 8.64 0 007.7769-5.4785L31 24zM23 28a4 4 0 114-4A4.0045 4.0045 0 0123 28zM12.3989 20.8A6 6 0 1122 16H20a4 4 0 10-6.4 3.2z"
  })), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3047,11.0439,26.9441,6.9561a1.9977,1.9977,0,0,0-2.3728-.8946l-2.4341.8233a11.0419,11.0419,0,0,0-1.312-.7583l-.5037-2.5186A2,2,0,0,0,18.36,2H13.64a2,2,0,0,0-1.9611,1.6079l-.5037,2.5186A10.9666,10.9666,0,0,0,9.8481,6.88L7.4287,6.0615a1.9977,1.9977,0,0,0-2.3728.8946L2.6953,11.0439a2.0006,2.0006,0,0,0,.4119,2.5025l1.9309,1.6968C5.021,15.4946,5,15.7446,5,16c0,.2578.01.5127.0278.7656l-1.9206,1.688a2.0006,2.0006,0,0,0-.4119,2.5025l2.3606,4.0878a1.9977,1.9977,0,0,0,2.3728.8946l2.4341-.8233a10.9736,10.9736,0,0,0,1.312.7583l.5037,2.5186A2,2,0,0,0,13.64,30H15V28H13.64l-.71-3.5508a9.0953,9.0953,0,0,1-2.6948-1.5713l-3.4468,1.166-2.36-4.0878L7.1528,17.561a8.9263,8.9263,0,0,1-.007-3.1279L4.4275,12.0439,6.7886,7.9561l3.4267,1.1591a9.0305,9.0305,0,0,1,2.7141-1.5644L13.64,4H18.36l.71,3.5508a9.0978,9.0978,0,0,1,2.6948,1.5713l3.4468-1.166,2.36,4.0878-2.7978,2.4522L26.0923,16l2.8-2.4536A2.0006,2.0006,0,0,0,29.3047,11.0439Z"
  })), children);
});
var SettingsView24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SettingsView24(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle26 || (_circle26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "24",
    r: "2"
  })), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.7769 23.4785A8.64 8.64 0 0023 18a8.64 8.64 0 00-7.7769 5.4785L15 24l.2231.5215A8.64 8.64 0 0023 30a8.64 8.64 0 007.7769-5.4785L31 24zM23 28a4 4 0 114-4A4.0045 4.0045 0 0123 28zM12.3989 20.8A6 6 0 1122 16H20a4 4 0 10-6.4 3.2z"
  })), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3047,11.0439,26.9441,6.9561a1.9977,1.9977,0,0,0-2.3728-.8946l-2.4341.8233a11.0419,11.0419,0,0,0-1.312-.7583l-.5037-2.5186A2,2,0,0,0,18.36,2H13.64a2,2,0,0,0-1.9611,1.6079l-.5037,2.5186A10.9666,10.9666,0,0,0,9.8481,6.88L7.4287,6.0615a1.9977,1.9977,0,0,0-2.3728.8946L2.6953,11.0439a2.0006,2.0006,0,0,0,.4119,2.5025l1.9309,1.6968C5.021,15.4946,5,15.7446,5,16c0,.2578.01.5127.0278.7656l-1.9206,1.688a2.0006,2.0006,0,0,0-.4119,2.5025l2.3606,4.0878a1.9977,1.9977,0,0,0,2.3728.8946l2.4341-.8233a10.9736,10.9736,0,0,0,1.312.7583l.5037,2.5186A2,2,0,0,0,13.64,30H15V28H13.64l-.71-3.5508a9.0953,9.0953,0,0,1-2.6948-1.5713l-3.4468,1.166-2.36-4.0878L7.1528,17.561a8.9263,8.9263,0,0,1-.007-3.1279L4.4275,12.0439,6.7886,7.9561l3.4267,1.1591a9.0305,9.0305,0,0,1,2.7141-1.5644L13.64,4H18.36l.71,3.5508a9.0978,9.0978,0,0,1,2.6948,1.5713l3.4468-1.166,2.36,4.0878-2.7978,2.4522L26.0923,16l2.8-2.4536A2.0006,2.0006,0,0,0,29.3047,11.0439Z"
  })), children);
});
var SettingsView20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SettingsView20(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle27 || (_circle27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "24",
    r: "2"
  })), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.7769 23.4785A8.64 8.64 0 0023 18a8.64 8.64 0 00-7.7769 5.4785L15 24l.2231.5215A8.64 8.64 0 0023 30a8.64 8.64 0 007.7769-5.4785L31 24zM23 28a4 4 0 114-4A4.0045 4.0045 0 0123 28zM12.3989 20.8A6 6 0 1122 16H20a4 4 0 10-6.4 3.2z"
  })), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3047,11.0439,26.9441,6.9561a1.9977,1.9977,0,0,0-2.3728-.8946l-2.4341.8233a11.0419,11.0419,0,0,0-1.312-.7583l-.5037-2.5186A2,2,0,0,0,18.36,2H13.64a2,2,0,0,0-1.9611,1.6079l-.5037,2.5186A10.9666,10.9666,0,0,0,9.8481,6.88L7.4287,6.0615a1.9977,1.9977,0,0,0-2.3728.8946L2.6953,11.0439a2.0006,2.0006,0,0,0,.4119,2.5025l1.9309,1.6968C5.021,15.4946,5,15.7446,5,16c0,.2578.01.5127.0278.7656l-1.9206,1.688a2.0006,2.0006,0,0,0-.4119,2.5025l2.3606,4.0878a1.9977,1.9977,0,0,0,2.3728.8946l2.4341-.8233a10.9736,10.9736,0,0,0,1.312.7583l.5037,2.5186A2,2,0,0,0,13.64,30H15V28H13.64l-.71-3.5508a9.0953,9.0953,0,0,1-2.6948-1.5713l-3.4468,1.166-2.36-4.0878L7.1528,17.561a8.9263,8.9263,0,0,1-.007-3.1279L4.4275,12.0439,6.7886,7.9561l3.4267,1.1591a9.0305,9.0305,0,0,1,2.7141-1.5644L13.64,4H18.36l.71,3.5508a9.0978,9.0978,0,0,1,2.6948,1.5713l3.4468-1.166,2.36,4.0878-2.7978,2.4522L26.0923,16l2.8-2.4536A2.0006,2.0006,0,0,0,29.3047,11.0439Z"
  })), children);
});
var SettingsView16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SettingsView16(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle28 || (_circle28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "24",
    r: "2"
  })), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.7769 23.4785A8.64 8.64 0 0023 18a8.64 8.64 0 00-7.7769 5.4785L15 24l.2231.5215A8.64 8.64 0 0023 30a8.64 8.64 0 007.7769-5.4785L31 24zM23 28a4 4 0 114-4A4.0045 4.0045 0 0123 28zM12.3989 20.8A6 6 0 1122 16H20a4 4 0 10-6.4 3.2z"
  })), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3047,11.0439,26.9441,6.9561a1.9977,1.9977,0,0,0-2.3728-.8946l-2.4341.8233a11.0419,11.0419,0,0,0-1.312-.7583l-.5037-2.5186A2,2,0,0,0,18.36,2H13.64a2,2,0,0,0-1.9611,1.6079l-.5037,2.5186A10.9666,10.9666,0,0,0,9.8481,6.88L7.4287,6.0615a1.9977,1.9977,0,0,0-2.3728.8946L2.6953,11.0439a2.0006,2.0006,0,0,0,.4119,2.5025l1.9309,1.6968C5.021,15.4946,5,15.7446,5,16c0,.2578.01.5127.0278.7656l-1.9206,1.688a2.0006,2.0006,0,0,0-.4119,2.5025l2.3606,4.0878a1.9977,1.9977,0,0,0,2.3728.8946l2.4341-.8233a10.9736,10.9736,0,0,0,1.312.7583l.5037,2.5186A2,2,0,0,0,13.64,30H15V28H13.64l-.71-3.5508a9.0953,9.0953,0,0,1-2.6948-1.5713l-3.4468,1.166-2.36-4.0878L7.1528,17.561a8.9263,8.9263,0,0,1-.007-3.1279L4.4275,12.0439,6.7886,7.9561l3.4267,1.1591a9.0305,9.0305,0,0,1,2.7141-1.5644L13.64,4H18.36l.71,3.5508a9.0978,9.0978,0,0,1,2.6948,1.5713l3.4468-1.166,2.36,4.0878-2.7978,2.4522L26.0923,16l2.8-2.4536A2.0006,2.0006,0,0,0,29.3047,11.0439Z"
  })), children);
});
var ShapeExcept32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeExcept32(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2.0023,2.0023,0,0,0-2-2H4A2.0025,2.0025,0,0,0,2,4V20a2.0025,2.0025,0,0,0,2,2h6v6a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10ZM12,20V12h8v8ZM3.9988,4H20v6H12a2.0023,2.0023,0,0,0-2,2v8H4Z"
  })), children);
});
var ShapeExcept24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeExcept24(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2.0023,2.0023,0,0,0-2-2H4A2.0025,2.0025,0,0,0,2,4V20a2.0025,2.0025,0,0,0,2,2h6v6a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10ZM12,20V12h8v8ZM3.9988,4H20v6H12a2.0023,2.0023,0,0,0-2,2v8H4Z"
  })), children);
});
var ShapeExcept20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeExcept20(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2.0023,2.0023,0,0,0-2-2H4A2.0025,2.0025,0,0,0,2,4V20a2.0025,2.0025,0,0,0,2,2h6v6a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10ZM12,20V12h8v8ZM3.9988,4H20v6H12a2.0023,2.0023,0,0,0-2,2v8H4Z"
  })), children);
});
var ShapeExcept16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeExcept16(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2.0023,2.0023,0,0,0-2-2H4A2.0025,2.0025,0,0,0,2,4V20a2.0025,2.0025,0,0,0,2,2h6v6a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10ZM12,20V12h8v8ZM3.9988,4H20v6H12a2.0023,2.0023,0,0,0-2,2v8H4Z"
  })), children);
});
var ShapeExclude32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeExclude32(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,10H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V20a2,2,0,0,0,2,2h6V12A2,2,0,0,1,12,10Z"
  })), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V20a2,2,0,0,1-2,2H10v6a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10Z"
  })), children);
});
var ShapeExclude24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeExclude24(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,10H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V20a2,2,0,0,0,2,2h6V12A2,2,0,0,1,12,10Z"
  })), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V20a2,2,0,0,1-2,2H10v6a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10Z"
  })), children);
});
var ShapeExclude20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeExclude20(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,10H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V20a2,2,0,0,0,2,2h6V12A2,2,0,0,1,12,10Z"
  })), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V20a2,2,0,0,1-2,2H10v6a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10Z"
  })), children);
});
var ShapeExclude16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeExclude16(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,10H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V20a2,2,0,0,0,2,2h6V12A2,2,0,0,1,12,10Z"
  })), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V20a2,2,0,0,1-2,2H10v6a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10Z"
  })), children);
});
var ShapeIntersect32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeIntersect32(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2.0025,2.0025,0,0,0-2-2H4A2.0025,2.0025,0,0,0,2,4V20a2.0025,2.0025,0,0,0,2,2h6v6a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V12A2.0025,2.0025,0,0,0,28,10ZM4,20V4H20v6H12a2.0025,2.0025,0,0,0-2,2v8Zm8,8V22h8a2.0025,2.0025,0,0,0,2-2V12h6V28Z"
  })), children);
});
var ShapeIntersect24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeIntersect24(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2.0025,2.0025,0,0,0-2-2H4A2.0025,2.0025,0,0,0,2,4V20a2.0025,2.0025,0,0,0,2,2h6v6a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V12A2.0025,2.0025,0,0,0,28,10ZM4,20V4H20v6H12a2.0025,2.0025,0,0,0-2,2v8Zm8,8V22h8a2.0025,2.0025,0,0,0,2-2V12h6V28Z"
  })), children);
});
var ShapeIntersect20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeIntersect20(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2.0025,2.0025,0,0,0-2-2H4A2.0025,2.0025,0,0,0,2,4V20a2.0025,2.0025,0,0,0,2,2h6v6a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V12A2.0025,2.0025,0,0,0,28,10ZM4,20V4H20v6H12a2.0025,2.0025,0,0,0-2,2v8Zm8,8V22h8a2.0025,2.0025,0,0,0,2-2V12h6V28Z"
  })), children);
});
var ShapeIntersect16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeIntersect16(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2.0025,2.0025,0,0,0-2-2H4A2.0025,2.0025,0,0,0,2,4V20a2.0025,2.0025,0,0,0,2,2h6v6a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V12A2.0025,2.0025,0,0,0,28,10ZM4,20V4H20v6H12a2.0025,2.0025,0,0,0-2,2v8Zm8,8V22h8a2.0025,2.0025,0,0,0,2-2V12h6V28Z"
  })), children);
});
var ShapeJoin32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeJoin32(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2.0025,2.0025,0,0,0-2-2H4A2.0025,2.0025,0,0,0,2,4V20a2.0025,2.0025,0,0,0,2,2h6v6a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V12A2.0025,2.0025,0,0,0,28,10ZM4,20V4h6V20Zm18,8V12h6V28Z"
  })), children);
});
var ShapeJoin24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeJoin24(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2.0025,2.0025,0,0,0-2-2H4A2.0025,2.0025,0,0,0,2,4V20a2.0025,2.0025,0,0,0,2,2h6v6a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V12A2.0025,2.0025,0,0,0,28,10ZM4,20V4h6V20Zm18,8V12h6V28Z"
  })), children);
});
var ShapeJoin20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeJoin20(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2.0025,2.0025,0,0,0-2-2H4A2.0025,2.0025,0,0,0,2,4V20a2.0025,2.0025,0,0,0,2,2h6v6a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V12A2.0025,2.0025,0,0,0,28,10ZM4,20V4h6V20Zm18,8V12h6V28Z"
  })), children);
});
var ShapeJoin16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeJoin16(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2.0025,2.0025,0,0,0-2-2H4A2.0025,2.0025,0,0,0,2,4V20a2.0025,2.0025,0,0,0,2,2h6v6a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V12A2.0025,2.0025,0,0,0,28,10ZM4,20V4h6V20Zm18,8V12h6V28Z"
  })), children);
});
var ShapeUnite32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeUnite32(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V20a2,2,0,0,0,2,2h6v6a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10Z"
  })), children);
});
var ShapeUnite24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeUnite24(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V20a2,2,0,0,0,2,2h6v6a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10Z"
  })), children);
});
var ShapeUnite20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeUnite20(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V20a2,2,0,0,0,2,2h6v6a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10Z"
  })), children);
});
var ShapeUnite16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShapeUnite16(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V20a2,2,0,0,0,2,2h6v6a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A2,2,0,0,0,28,10Z"
  })), children);
});
var Share32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Share32(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,20a5,5,0,0,0-3.89,1.89L11.8,17.32a4.46,4.46,0,0,0,0-2.64l7.31-4.57A5,5,0,1,0,18,7a4.79,4.79,0,0,0,.2,1.32l-7.31,4.57a5,5,0,1,0,0,6.22l7.31,4.57A4.79,4.79,0,0,0,18,25a5,5,0,1,0,5-5ZM23,4a3,3,0,1,1-3,3A3,3,0,0,1,23,4ZM7,19a3,3,0,1,1,3-3A3,3,0,0,1,7,19Zm16,9a3,3,0,1,1,3-3A3,3,0,0,1,23,28Z"
  })), children);
});
var Share24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Share24(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,20a5,5,0,0,0-3.89,1.89L11.8,17.32a4.46,4.46,0,0,0,0-2.64l7.31-4.57A5,5,0,1,0,18,7a4.79,4.79,0,0,0,.2,1.32l-7.31,4.57a5,5,0,1,0,0,6.22l7.31,4.57A4.79,4.79,0,0,0,18,25a5,5,0,1,0,5-5ZM23,4a3,3,0,1,1-3,3A3,3,0,0,1,23,4ZM7,19a3,3,0,1,1,3-3A3,3,0,0,1,7,19Zm16,9a3,3,0,1,1,3-3A3,3,0,0,1,23,28Z"
  })), children);
});
var Share20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Share20(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,20a5,5,0,0,0-3.89,1.89L11.8,17.32a4.46,4.46,0,0,0,0-2.64l7.31-4.57A5,5,0,1,0,18,7a4.79,4.79,0,0,0,.2,1.32l-7.31,4.57a5,5,0,1,0,0,6.22l7.31,4.57A4.79,4.79,0,0,0,18,25a5,5,0,1,0,5-5ZM23,4a3,3,0,1,1-3,3A3,3,0,0,1,23,4ZM7,19a3,3,0,1,1,3-3A3,3,0,0,1,7,19Zm16,9a3,3,0,1,1,3-3A3,3,0,0,1,23,28Z"
  })), children);
});
var Share16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Share16(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,20a5,5,0,0,0-3.89,1.89L11.8,17.32a4.46,4.46,0,0,0,0-2.64l7.31-4.57A5,5,0,1,0,18,7a4.79,4.79,0,0,0,.2,1.32l-7.31,4.57a5,5,0,1,0,0,6.22l7.31,4.57A4.79,4.79,0,0,0,18,25a5,5,0,1,0,5-5ZM23,4a3,3,0,1,1-3,3A3,3,0,0,1,23,4ZM7,19a3,3,0,1,1,3-3A3,3,0,0,1,7,19Zm16,9a3,3,0,1,1,3-3A3,3,0,0,1,23,28Z"
  })), children);
});
var ShareKnowledge32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShareKnowledge32(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 25H21a3 3 0 00-3 3v2h2V28a1 1 0 011-1h6a1 1 0 011 1v2h2V28A3 3 0 0027 25zM20 20a4 4 0 104-4A4 4 0 0020 20zm6 0a2 2 0 11-2-2A2 2 0 0126 20zM6 21V20H4v1a7 7 0 007 7h3V26H11A5 5 0 016 21zM19 10H26V12H19zM19 6H29V8H19zM19 2H29V4H19zM11 11H5a3 3 0 00-3 3v2H4V14a1 1 0 011-1h6a1 1 0 011 1v2h2V14A3 3 0 0011 11zM8 10A4 4 0 104 6 4 4 0 008 10zM8 4A2 2 0 116 6 2 2 0 018 4z"
  })), children);
});
var ShareKnowledge24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShareKnowledge24(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 25H21a3 3 0 00-3 3v2h2V28a1 1 0 011-1h6a1 1 0 011 1v2h2V28A3 3 0 0027 25zM20 20a4 4 0 104-4A4 4 0 0020 20zm6 0a2 2 0 11-2-2A2 2 0 0126 20zM6 21V20H4v1a7 7 0 007 7h3V26H11A5 5 0 016 21zM19 10H26V12H19zM19 6H29V8H19zM19 2H29V4H19zM11 11H5a3 3 0 00-3 3v2H4V14a1 1 0 011-1h6a1 1 0 011 1v2h2V14A3 3 0 0011 11zM8 10A4 4 0 104 6 4 4 0 008 10zM8 4A2 2 0 116 6 2 2 0 018 4z"
  })), children);
});
var ShareKnowledge20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShareKnowledge20(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 25H21a3 3 0 00-3 3v2h2V28a1 1 0 011-1h6a1 1 0 011 1v2h2V28A3 3 0 0027 25zM20 20a4 4 0 104-4A4 4 0 0020 20zm6 0a2 2 0 11-2-2A2 2 0 0126 20zM6 21V20H4v1a7 7 0 007 7h3V26H11A5 5 0 016 21zM19 10H26V12H19zM19 6H29V8H19zM19 2H29V4H19zM11 11H5a3 3 0 00-3 3v2H4V14a1 1 0 011-1h6a1 1 0 011 1v2h2V14A3 3 0 0011 11zM8 10A4 4 0 104 6 4 4 0 008 10zM8 4A2 2 0 116 6 2 2 0 018 4z"
  })), children);
});
var ShareKnowledge16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShareKnowledge16(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 25H21a3 3 0 00-3 3v2h2V28a1 1 0 011-1h6a1 1 0 011 1v2h2V28A3 3 0 0027 25zM20 20a4 4 0 104-4A4 4 0 0020 20zm6 0a2 2 0 11-2-2A2 2 0 0126 20zM6 21V20H4v1a7 7 0 007 7h3V26H11A5 5 0 016 21zM19 10H26V12H19zM19 6H29V8H19zM19 2H29V4H19zM11 11H5a3 3 0 00-3 3v2H4V14a1 1 0 011-1h6a1 1 0 011 1v2h2V14A3 3 0 0011 11zM8 10A4 4 0 104 6 4 4 0 008 10zM8 4A2 2 0 116 6 2 2 0 018 4z"
  })), children);
});
var ShoppingBag32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingBag32(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.76,11.35A1,1,0,0,0,28,11H22V7a3,3,0,0,0-3-3H13a3,3,0,0,0-3,3v4H4a1,1,0,0,0-1,1.15L4.88,24.3a2,2,0,0,0,2,1.7H25.14a2,2,0,0,0,2-1.7L29,12.15A1,1,0,0,0,28.76,11.35ZM12,7a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1v4H12ZM25.14,24H6.86L5.17,13H26.83Z"
  })), children);
});
var ShoppingBag24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingBag24(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.76,11.35A1,1,0,0,0,28,11H22V7a3,3,0,0,0-3-3H13a3,3,0,0,0-3,3v4H4a1,1,0,0,0-1,1.15L4.88,24.3a2,2,0,0,0,2,1.7H25.14a2,2,0,0,0,2-1.7L29,12.15A1,1,0,0,0,28.76,11.35ZM12,7a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1v4H12ZM25.14,24H6.86L5.17,13H26.83Z"
  })), children);
});
var ShoppingBag20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingBag20(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.76,11.35A1,1,0,0,0,28,11H22V7a3,3,0,0,0-3-3H13a3,3,0,0,0-3,3v4H4a1,1,0,0,0-1,1.15L4.88,24.3a2,2,0,0,0,2,1.7H25.14a2,2,0,0,0,2-1.7L29,12.15A1,1,0,0,0,28.76,11.35ZM12,7a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1v4H12ZM25.14,24H6.86L5.17,13H26.83Z"
  })), children);
});
var ShoppingBag16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingBag16(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.76,11.35A1,1,0,0,0,28,11H22V7a3,3,0,0,0-3-3H13a3,3,0,0,0-3,3v4H4a1,1,0,0,0-1,1.15L4.88,24.3a2,2,0,0,0,2,1.7H25.14a2,2,0,0,0,2-1.7L29,12.15A1,1,0,0,0,28.76,11.35ZM12,7a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1v4H12ZM25.14,24H6.86L5.17,13H26.83Z"
  })), children);
});
var ShoppingCart32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCart32(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle29 || (_circle29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle30 || (_circle30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,7H5.82L5,2.8A1,1,0,0,0,4,2H0V4H3.18L7,23.2A1,1,0,0,0,8,24H26V22H8.82L8,18H26a1,1,0,0,0,1-.78l2-9A1,1,0,0,0,28,7Zm-2.8,9H7.62L6.22,9H26.75Z"
  })), children);
});
var ShoppingCart24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCart24(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle31 || (_circle31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle32 || (_circle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,7H5.82L5,2.8A1,1,0,0,0,4,2H0V4H3.18L7,23.2A1,1,0,0,0,8,24H26V22H8.82L8,18H26a1,1,0,0,0,1-.78l2-9A1,1,0,0,0,28,7Zm-2.8,9H7.62L6.22,9H26.75Z"
  })), children);
});
var ShoppingCart20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCart20(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle33 || (_circle33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle34 || (_circle34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,7H5.82L5,2.8A1,1,0,0,0,4,2H0V4H3.18L7,23.2A1,1,0,0,0,8,24H26V22H8.82L8,18H26a1,1,0,0,0,1-.78l2-9A1,1,0,0,0,28,7Zm-2.8,9H7.62L6.22,9H26.75Z"
  })), children);
});
var ShoppingCart16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCart16(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle35 || (_circle35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle36 || (_circle36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,7H5.82L5,2.8A1,1,0,0,0,4,2H0V4H3.18L7,23.2A1,1,0,0,0,8,24H26V22H8.82L8,18H26a1,1,0,0,0,1-.78l2-9A1,1,0,0,0,28,7Zm-2.8,9H7.62L6.22,9H26.75Z"
  })), children);
});
var ShoppingCartArrowDown32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartArrowDown32(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle37 || (_circle37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle38 || (_circle38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.586 6.586L18 10.172 18 2 16 2 16 10.172 12.414 6.586 11 8 17 14 23 8 21.586 6.586z"
  })), children);
});
var ShoppingCartArrowDown24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartArrowDown24(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle39 || (_circle39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle40 || (_circle40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.586 6.586L18 10.172 18 2 16 2 16 10.172 12.414 6.586 11 8 17 14 23 8 21.586 6.586z"
  })), children);
});
var ShoppingCartArrowDown20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartArrowDown20(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle41 || (_circle41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle42 || (_circle42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.586 6.586L18 10.172 18 2 16 2 16 10.172 12.414 6.586 11 8 17 14 23 8 21.586 6.586z"
  })), children);
});
var ShoppingCartArrowDown16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartArrowDown16(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle43 || (_circle43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle44 || (_circle44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.586 6.586L18 10.172 18 2 16 2 16 10.172 12.414 6.586 11 8 17 14 23 8 21.586 6.586z"
  })), children);
});
var ShoppingCartArrowUp32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartArrowUp32(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle45 || (_circle45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle46 || (_circle46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.586 9.414L18 5.828 18 14 16 14 16 5.828 12.414 9.414 11 8 17 2 23 8 21.586 9.414z"
  })), children);
});
var ShoppingCartArrowUp24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartArrowUp24(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle47 || (_circle47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle48 || (_circle48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.586 9.414L18 5.828 18 14 16 14 16 5.828 12.414 9.414 11 8 17 2 23 8 21.586 9.414z"
  })), children);
});
var ShoppingCartArrowUp20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartArrowUp20(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle49 || (_circle49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle50 || (_circle50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.586 9.414L18 5.828 18 14 16 14 16 5.828 12.414 9.414 11 8 17 2 23 8 21.586 9.414z"
  })), children);
});
var ShoppingCartArrowUp16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartArrowUp16(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle51 || (_circle51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle52 || (_circle52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.586 9.414L18 5.828 18 14 16 14 16 5.828 12.414 9.414 11 8 17 2 23 8 21.586 9.414z"
  })), children);
});
var ShoppingCartClear32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartClear32(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle53 || (_circle53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle54 || (_circle54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.41 8L22 4.41 20.59 3 17 6.59 13.41 3 12 4.41 15.59 8 12 11.59 13.41 13 17 9.41 20.59 13 22 11.59 18.41 8z"
  })), children);
});
var ShoppingCartClear24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartClear24(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle55 || (_circle55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle56 || (_circle56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.41 8L22 4.41 20.59 3 17 6.59 13.41 3 12 4.41 15.59 8 12 11.59 13.41 13 17 9.41 20.59 13 22 11.59 18.41 8z"
  })), children);
});
var ShoppingCartClear20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartClear20(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle57 || (_circle57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle58 || (_circle58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.41 8L22 4.41 20.59 3 17 6.59 13.41 3 12 4.41 15.59 8 12 11.59 13.41 13 17 9.41 20.59 13 22 11.59 18.41 8z"
  })), children);
});
var ShoppingCartClear16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartClear16(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle59 || (_circle59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle60 || (_circle60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.41 8L22 4.41 20.59 3 17 6.59 13.41 3 12 4.41 15.59 8 12 11.59 13.41 13 17 9.41 20.59 13 22 11.59 18.41 8z"
  })), children);
});
var ShoppingCartError32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartError32(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle61 || (_circle61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle62 || (_circle62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,2a6,6,0,1,0,6,6A6.0066,6.0066,0,0,0,17,2Zm0,2a3.9521,3.9521,0,0,1,2.019.5669L13.5669,10.019A3.9529,3.9529,0,0,1,13,8,4.0045,4.0045,0,0,1,17,4Zm0,8a3.9521,3.9521,0,0,1-2.019-.5669L20.4331,5.981A3.9529,3.9529,0,0,1,21,8,4.0045,4.0045,0,0,1,17,12Z"
  })), children);
});
var ShoppingCartError24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartError24(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle63 || (_circle63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle64 || (_circle64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,2a6,6,0,1,0,6,6A6.0066,6.0066,0,0,0,17,2Zm0,2a3.9521,3.9521,0,0,1,2.019.5669L13.5669,10.019A3.9529,3.9529,0,0,1,13,8,4.0045,4.0045,0,0,1,17,4Zm0,8a3.9521,3.9521,0,0,1-2.019-.5669L20.4331,5.981A3.9529,3.9529,0,0,1,21,8,4.0045,4.0045,0,0,1,17,12Z"
  })), children);
});
var ShoppingCartError20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartError20(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle65 || (_circle65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle66 || (_circle66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,2a6,6,0,1,0,6,6A6.0066,6.0066,0,0,0,17,2Zm0,2a3.9521,3.9521,0,0,1,2.019.5669L13.5669,10.019A3.9529,3.9529,0,0,1,13,8,4.0045,4.0045,0,0,1,17,4Zm0,8a3.9521,3.9521,0,0,1-2.019-.5669L20.4331,5.981A3.9529,3.9529,0,0,1,21,8,4.0045,4.0045,0,0,1,17,12Z"
  })), children);
});
var ShoppingCartError16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartError16(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle67 || (_circle67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle68 || (_circle68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,2a6,6,0,1,0,6,6A6.0066,6.0066,0,0,0,17,2Zm0,2a3.9521,3.9521,0,0,1,2.019.5669L13.5669,10.019A3.9529,3.9529,0,0,1,13,8,4.0045,4.0045,0,0,1,17,4Zm0,8a3.9521,3.9521,0,0,1-2.019-.5669L20.4331,5.981A3.9529,3.9529,0,0,1,21,8,4.0045,4.0045,0,0,1,17,12Z"
  })), children);
});
var ShoppingCartMinus32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartMinus32(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle69 || (_circle69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle70 || (_circle70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6L12 8 22 8 22 6 12 6z"
  })), children);
});
var ShoppingCartMinus24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartMinus24(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle71 || (_circle71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle72 || (_circle72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6L12 8 22 8 22 6 12 6z"
  })), children);
});
var ShoppingCartMinus20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartMinus20(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle73 || (_circle73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle74 || (_circle74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6L12 8 22 8 22 6 12 6z"
  })), children);
});
var ShoppingCartMinus16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartMinus16(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle75 || (_circle75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle76 || (_circle76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 6L12 8 22 8 22 6 12 6z"
  })), children);
});
var ShoppingCartPlus32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartPlus32(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle77 || (_circle77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle78 || (_circle78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 6L18 2 16 2 16 6 12 6 12 8 16 8 16 12 18 12 18 8 22 8 22 6 18 6z"
  })), children);
});
var ShoppingCartPlus24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartPlus24(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle79 || (_circle79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle80 || (_circle80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 6L18 2 16 2 16 6 12 6 12 8 16 8 16 12 18 12 18 8 22 8 22 6 18 6z"
  })), children);
});
var ShoppingCartPlus20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartPlus20(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle81 || (_circle81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle82 || (_circle82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 6L18 2 16 2 16 6 12 6 12 8 16 8 16 12 18 12 18 8 22 8 22 6 18 6z"
  })), children);
});
var ShoppingCartPlus16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCartPlus16(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle83 || (_circle83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle84 || (_circle84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "28",
    r: "2"
  })), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9806,2.8039A1,1,0,0,0,4,2H0V4H3.18L7.0194,23.1961A1,1,0,0,0,8,24H26V22H8.82l-.8-4H26a1,1,0,0,0,.9762-.783L29.2445,7H27.1971l-1.9989,9H7.62Z"
  })), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 6L18 2 16 2 16 6 12 6 12 8 16 8 16 12 18 12 18 8 22 8 22 6 18 6z"
  })), children);
});
var ShoppingCatalog32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCatalog32(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 24H21V28H17zM24 24H28V28H24zM17 17H21V21H17zM24 17H28V21H24z"
  })), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,11h-6V7c0-1.7-1.3-3-3-3h-6c-1.7,0-3,1.3-3,3v4H4c-0.6,0-1,0.4-1,1c0,0.1,0,0.1,0,0.2l1.9,12.1c0.1,1,1,1.7,2,1.7H15v-2\tH6.9L5.2,13H28V11z M12,7c0-0.6,0.4-1,1-1h6c0.6,0,1,0.4,1,1v4h-8V7z"
  })), children);
});
var ShoppingCatalog24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCatalog24(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 24H21V28H17zM24 24H28V28H24zM17 17H21V21H17zM24 17H28V21H24z"
  })), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,11h-6V7c0-1.7-1.3-3-3-3h-6c-1.7,0-3,1.3-3,3v4H4c-0.6,0-1,0.4-1,1c0,0.1,0,0.1,0,0.2l1.9,12.1c0.1,1,1,1.7,2,1.7H15v-2\tH6.9L5.2,13H28V11z M12,7c0-0.6,0.4-1,1-1h6c0.6,0,1,0.4,1,1v4h-8V7z"
  })), children);
});
var ShoppingCatalog20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCatalog20(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 24H21V28H17zM24 24H28V28H24zM17 17H21V21H17zM24 17H28V21H24z"
  })), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,11h-6V7c0-1.7-1.3-3-3-3h-6c-1.7,0-3,1.3-3,3v4H4c-0.6,0-1,0.4-1,1c0,0.1,0,0.1,0,0.2l1.9,12.1c0.1,1,1,1.7,2,1.7H15v-2\tH6.9L5.2,13H28V11z M12,7c0-0.6,0.4-1,1-1h6c0.6,0,1,0.4,1,1v4h-8V7z"
  })), children);
});
var ShoppingCatalog16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShoppingCatalog16(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 24H21V28H17zM24 24H28V28H24zM17 17H21V21H17zM24 17H28V21H24z"
  })), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,11h-6V7c0-1.7-1.3-3-3-3h-6c-1.7,0-3,1.3-3,3v4H4c-0.6,0-1,0.4-1,1c0,0.1,0,0.1,0,0.2l1.9,12.1c0.1,1,1,1.7,2,1.7H15v-2\tH6.9L5.2,13H28V11z M12,7c0-0.6,0.4-1,1-1h6c0.6,0,1,0.4,1,1v4h-8V7z"
  })), children);
});
var ShowDataCards32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShowDataCards32(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 10H4A2.0022 2.0022 0 012 8V4A2.0021 2.0021 0 014 2H28a2.0021 2.0021 0 012 2V8A2.0022 2.0022 0 0128 10zM4 4V8H28V4zM28 30H4a2.0022 2.0022 0 01-2-2V24a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v4A2.0022 2.0022 0 0128 30zM4 24v4H28V24zM28 20H4a2.0022 2.0022 0 01-2-2V14a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v4A2.0022 2.0022 0 0128 20zM4 14v4H28V14z"
  })), children);
});
var ShowDataCards24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShowDataCards24(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 10H4A2.0022 2.0022 0 012 8V4A2.0021 2.0021 0 014 2H28a2.0021 2.0021 0 012 2V8A2.0022 2.0022 0 0128 10zM4 4V8H28V4zM28 30H4a2.0022 2.0022 0 01-2-2V24a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v4A2.0022 2.0022 0 0128 30zM4 24v4H28V24zM28 20H4a2.0022 2.0022 0 01-2-2V14a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v4A2.0022 2.0022 0 0128 20zM4 14v4H28V14z"
  })), children);
});
var ShowDataCards20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShowDataCards20(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 10H4A2.0022 2.0022 0 012 8V4A2.0021 2.0021 0 014 2H28a2.0021 2.0021 0 012 2V8A2.0022 2.0022 0 0128 10zM4 4V8H28V4zM28 30H4a2.0022 2.0022 0 01-2-2V24a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v4A2.0022 2.0022 0 0128 30zM4 24v4H28V24zM28 20H4a2.0022 2.0022 0 01-2-2V14a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v4A2.0022 2.0022 0 0128 20zM4 14v4H28V14z"
  })), children);
});
var ShowDataCards16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShowDataCards16(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 10H4A2.0022 2.0022 0 012 8V4A2.0021 2.0021 0 014 2H28a2.0021 2.0021 0 012 2V8A2.0022 2.0022 0 0128 10zM4 4V8H28V4zM28 30H4a2.0022 2.0022 0 01-2-2V24a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v4A2.0022 2.0022 0 0128 30zM4 24v4H28V24zM28 20H4a2.0022 2.0022 0 01-2-2V14a2.0021 2.0021 0 012-2H28a2.0021 2.0021 0 012 2v4A2.0022 2.0022 0 0128 20zM4 14v4H28V14z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-24.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-24.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "ShrinkScreen16": () => (/* binding */ ShrinkScreen16),
/* harmony export */   "ShrinkScreen20": () => (/* binding */ ShrinkScreen20),
/* harmony export */   "ShrinkScreen24": () => (/* binding */ ShrinkScreen24),
/* harmony export */   "ShrinkScreen32": () => (/* binding */ ShrinkScreen32),
/* harmony export */   "ShrinkScreenFilled16": () => (/* binding */ ShrinkScreenFilled16),
/* harmony export */   "ShrinkScreenFilled20": () => (/* binding */ ShrinkScreenFilled20),
/* harmony export */   "ShrinkScreenFilled24": () => (/* binding */ ShrinkScreenFilled24),
/* harmony export */   "ShrinkScreenFilled32": () => (/* binding */ ShrinkScreenFilled32),
/* harmony export */   "Shuffle16": () => (/* binding */ Shuffle16),
/* harmony export */   "Shuffle20": () => (/* binding */ Shuffle20),
/* harmony export */   "Shuffle24": () => (/* binding */ Shuffle24),
/* harmony export */   "Shuffle32": () => (/* binding */ Shuffle32),
/* harmony export */   "Shuttle16": () => (/* binding */ Shuttle16),
/* harmony export */   "Shuttle20": () => (/* binding */ Shuttle20),
/* harmony export */   "Shuttle24": () => (/* binding */ Shuttle24),
/* harmony export */   "Shuttle32": () => (/* binding */ Shuttle32),
/* harmony export */   "Sight16": () => (/* binding */ Sight16),
/* harmony export */   "Sight20": () => (/* binding */ Sight20),
/* harmony export */   "Sight24": () => (/* binding */ Sight24),
/* harmony export */   "Sight32": () => (/* binding */ Sight32),
/* harmony export */   "Sigma16": () => (/* binding */ Sigma16),
/* harmony export */   "Sigma20": () => (/* binding */ Sigma20),
/* harmony export */   "Sigma24": () => (/* binding */ Sigma24),
/* harmony export */   "Sigma32": () => (/* binding */ Sigma32),
/* harmony export */   "SignalStrength16": () => (/* binding */ SignalStrength16),
/* harmony export */   "SignalStrength20": () => (/* binding */ SignalStrength20),
/* harmony export */   "SignalStrength24": () => (/* binding */ SignalStrength24),
/* harmony export */   "SignalStrength32": () => (/* binding */ SignalStrength32),
/* harmony export */   "SimCard16": () => (/* binding */ SimCard16),
/* harmony export */   "SimCard20": () => (/* binding */ SimCard20),
/* harmony export */   "SimCard24": () => (/* binding */ SimCard24),
/* harmony export */   "SimCard32": () => (/* binding */ SimCard32),
/* harmony export */   "SkillLevel16": () => (/* binding */ SkillLevel16),
/* harmony export */   "SkillLevel20": () => (/* binding */ SkillLevel20),
/* harmony export */   "SkillLevel24": () => (/* binding */ SkillLevel24),
/* harmony export */   "SkillLevel32": () => (/* binding */ SkillLevel32),
/* harmony export */   "SkillLevelAdvanced16": () => (/* binding */ SkillLevelAdvanced16),
/* harmony export */   "SkillLevelAdvanced20": () => (/* binding */ SkillLevelAdvanced20),
/* harmony export */   "SkillLevelAdvanced24": () => (/* binding */ SkillLevelAdvanced24),
/* harmony export */   "SkillLevelAdvanced32": () => (/* binding */ SkillLevelAdvanced32),
/* harmony export */   "SkillLevelBasic16": () => (/* binding */ SkillLevelBasic16),
/* harmony export */   "SkillLevelBasic20": () => (/* binding */ SkillLevelBasic20),
/* harmony export */   "SkillLevelBasic24": () => (/* binding */ SkillLevelBasic24),
/* harmony export */   "SkillLevelBasic32": () => (/* binding */ SkillLevelBasic32),
/* harmony export */   "SkillLevelIntermediate16": () => (/* binding */ SkillLevelIntermediate16),
/* harmony export */   "SkillLevelIntermediate20": () => (/* binding */ SkillLevelIntermediate20),
/* harmony export */   "SkillLevelIntermediate24": () => (/* binding */ SkillLevelIntermediate24),
/* harmony export */   "SkillLevelIntermediate32": () => (/* binding */ SkillLevelIntermediate32),
/* harmony export */   "SkipBack16": () => (/* binding */ SkipBack16),
/* harmony export */   "SkipBack20": () => (/* binding */ SkipBack20),
/* harmony export */   "SkipBack24": () => (/* binding */ SkipBack24),
/* harmony export */   "SkipBack32": () => (/* binding */ SkipBack32),
/* harmony export */   "SkipBackFilled16": () => (/* binding */ SkipBackFilled16),
/* harmony export */   "SkipBackFilled20": () => (/* binding */ SkipBackFilled20),
/* harmony export */   "SkipBackFilled24": () => (/* binding */ SkipBackFilled24),
/* harmony export */   "SkipBackFilled32": () => (/* binding */ SkipBackFilled32),
/* harmony export */   "SkipBackOutline16": () => (/* binding */ SkipBackOutline16),
/* harmony export */   "SkipBackOutline20": () => (/* binding */ SkipBackOutline20),
/* harmony export */   "SkipBackOutline24": () => (/* binding */ SkipBackOutline24),
/* harmony export */   "SkipBackOutline32": () => (/* binding */ SkipBackOutline32),
/* harmony export */   "SkipBackOutlineFilled16": () => (/* binding */ SkipBackOutlineFilled16),
/* harmony export */   "SkipBackOutlineFilled20": () => (/* binding */ SkipBackOutlineFilled20),
/* harmony export */   "SkipBackOutlineFilled24": () => (/* binding */ SkipBackOutlineFilled24),
/* harmony export */   "SkipBackOutlineFilled32": () => (/* binding */ SkipBackOutlineFilled32),
/* harmony export */   "SkipBackOutlineSolid16": () => (/* binding */ SkipBackOutlineSolid16),
/* harmony export */   "SkipBackOutlineSolid20": () => (/* binding */ SkipBackOutlineSolid20),
/* harmony export */   "SkipBackOutlineSolid24": () => (/* binding */ SkipBackOutlineSolid24),
/* harmony export */   "SkipBackOutlineSolid32": () => (/* binding */ SkipBackOutlineSolid32),
/* harmony export */   "SkipBackSolidFilled16": () => (/* binding */ SkipBackSolidFilled16),
/* harmony export */   "SkipBackSolidFilled20": () => (/* binding */ SkipBackSolidFilled20),
/* harmony export */   "SkipBackSolidFilled24": () => (/* binding */ SkipBackSolidFilled24),
/* harmony export */   "SkipBackSolidFilled32": () => (/* binding */ SkipBackSolidFilled32),
/* harmony export */   "SkipForward16": () => (/* binding */ SkipForward16),
/* harmony export */   "SkipForward20": () => (/* binding */ SkipForward20),
/* harmony export */   "SkipForward24": () => (/* binding */ SkipForward24),
/* harmony export */   "SkipForward32": () => (/* binding */ SkipForward32),
/* harmony export */   "SkipForwardFilled16": () => (/* binding */ SkipForwardFilled16),
/* harmony export */   "SkipForwardFilled20": () => (/* binding */ SkipForwardFilled20),
/* harmony export */   "SkipForwardFilled24": () => (/* binding */ SkipForwardFilled24),
/* harmony export */   "SkipForwardFilled32": () => (/* binding */ SkipForwardFilled32),
/* harmony export */   "SkipForwardOutline16": () => (/* binding */ SkipForwardOutline16),
/* harmony export */   "SkipForwardOutline20": () => (/* binding */ SkipForwardOutline20),
/* harmony export */   "SkipForwardOutline24": () => (/* binding */ SkipForwardOutline24),
/* harmony export */   "SkipForwardOutline32": () => (/* binding */ SkipForwardOutline32),
/* harmony export */   "SkipForwardOutlineFilled16": () => (/* binding */ SkipForwardOutlineFilled16),
/* harmony export */   "SkipForwardOutlineFilled20": () => (/* binding */ SkipForwardOutlineFilled20),
/* harmony export */   "SkipForwardOutlineFilled24": () => (/* binding */ SkipForwardOutlineFilled24),
/* harmony export */   "SkipForwardOutlineFilled32": () => (/* binding */ SkipForwardOutlineFilled32),
/* harmony export */   "SkipForwardOutlineSolid16": () => (/* binding */ SkipForwardOutlineSolid16),
/* harmony export */   "SkipForwardOutlineSolid20": () => (/* binding */ SkipForwardOutlineSolid20),
/* harmony export */   "SkipForwardOutlineSolid24": () => (/* binding */ SkipForwardOutlineSolid24),
/* harmony export */   "SkipForwardOutlineSolid32": () => (/* binding */ SkipForwardOutlineSolid32),
/* harmony export */   "SkipForwardSolidFilled16": () => (/* binding */ SkipForwardSolidFilled16),
/* harmony export */   "SkipForwardSolidFilled20": () => (/* binding */ SkipForwardSolidFilled20),
/* harmony export */   "SkipForwardSolidFilled24": () => (/* binding */ SkipForwardSolidFilled24),
/* harmony export */   "SkipForwardSolidFilled32": () => (/* binding */ SkipForwardSolidFilled32),
/* harmony export */   "Sleet16": () => (/* binding */ Sleet16),
/* harmony export */   "Sleet20": () => (/* binding */ Sleet20),
/* harmony export */   "Sleet24": () => (/* binding */ Sleet24),
/* harmony export */   "Sleet32": () => (/* binding */ Sleet32),
/* harmony export */   "Slisor16": () => (/* binding */ Slisor16),
/* harmony export */   "Slisor20": () => (/* binding */ Slisor20),
/* harmony export */   "Slisor24": () => (/* binding */ Slisor24),
/* harmony export */   "Slisor32": () => (/* binding */ Slisor32),
/* harmony export */   "Smell16": () => (/* binding */ Smell16),
/* harmony export */   "Smell20": () => (/* binding */ Smell20),
/* harmony export */   "Smell24": () => (/* binding */ Smell24),
/* harmony export */   "Smell32": () => (/* binding */ Smell32),
/* harmony export */   "Smoke16": () => (/* binding */ Smoke16),
/* harmony export */   "Smoke20": () => (/* binding */ Smoke20),
/* harmony export */   "Smoke24": () => (/* binding */ Smoke24),
/* harmony export */   "Smoke32": () => (/* binding */ Smoke32),
/* harmony export */   "Snooze16": () => (/* binding */ Snooze16),
/* harmony export */   "Snooze20": () => (/* binding */ Snooze20),
/* harmony export */   "Snooze24": () => (/* binding */ Snooze24),
/* harmony export */   "Snooze32": () => (/* binding */ Snooze32),
/* harmony export */   "Snow16": () => (/* binding */ Snow16),
/* harmony export */   "Snow20": () => (/* binding */ Snow20),
/* harmony export */   "Snow24": () => (/* binding */ Snow24),
/* harmony export */   "Snow32": () => (/* binding */ Snow32),
/* harmony export */   "SnowBlizzard16": () => (/* binding */ SnowBlizzard16),
/* harmony export */   "SnowBlizzard20": () => (/* binding */ SnowBlizzard20),
/* harmony export */   "SnowBlizzard24": () => (/* binding */ SnowBlizzard24),
/* harmony export */   "SnowBlizzard32": () => (/* binding */ SnowBlizzard32),
/* harmony export */   "SnowDensity16": () => (/* binding */ SnowDensity16),
/* harmony export */   "SnowDensity20": () => (/* binding */ SnowDensity20),
/* harmony export */   "SnowDensity24": () => (/* binding */ SnowDensity24),
/* harmony export */   "SnowDensity32": () => (/* binding */ SnowDensity32),
/* harmony export */   "SnowHeavy16": () => (/* binding */ SnowHeavy16),
/* harmony export */   "SnowHeavy20": () => (/* binding */ SnowHeavy20),
/* harmony export */   "SnowHeavy24": () => (/* binding */ SnowHeavy24),
/* harmony export */   "SnowHeavy32": () => (/* binding */ SnowHeavy32),
/* harmony export */   "SnowScattered16": () => (/* binding */ SnowScattered16),
/* harmony export */   "SnowScattered20": () => (/* binding */ SnowScattered20),
/* harmony export */   "SnowScattered24": () => (/* binding */ SnowScattered24),
/* harmony export */   "SnowScattered32": () => (/* binding */ SnowScattered32),
/* harmony export */   "SnowScatteredNight16": () => (/* binding */ SnowScatteredNight16),
/* harmony export */   "SnowScatteredNight20": () => (/* binding */ SnowScatteredNight20),
/* harmony export */   "SnowScatteredNight24": () => (/* binding */ SnowScatteredNight24),
/* harmony export */   "SnowScatteredNight32": () => (/* binding */ SnowScatteredNight32),
/* harmony export */   "Snowflake16": () => (/* binding */ Snowflake16),
/* harmony export */   "Snowflake20": () => (/* binding */ Snowflake20),
/* harmony export */   "Snowflake24": () => (/* binding */ Snowflake24),
/* harmony export */   "Snowflake32": () => (/* binding */ Snowflake32),
/* harmony export */   "Soccer16": () => (/* binding */ Soccer16),
/* harmony export */   "Soccer20": () => (/* binding */ Soccer20),
/* harmony export */   "Soccer24": () => (/* binding */ Soccer24),
/* harmony export */   "Soccer32": () => (/* binding */ Soccer32),
/* harmony export */   "SoftwareResource16": () => (/* binding */ SoftwareResource16),
/* harmony export */   "SoftwareResource20": () => (/* binding */ SoftwareResource20),
/* harmony export */   "SoftwareResource24": () => (/* binding */ SoftwareResource24),
/* harmony export */   "SoftwareResource32": () => (/* binding */ SoftwareResource32),
/* harmony export */   "SoftwareResourceCluster16": () => (/* binding */ SoftwareResourceCluster16),
/* harmony export */   "SoftwareResourceCluster20": () => (/* binding */ SoftwareResourceCluster20),
/* harmony export */   "SoftwareResourceCluster24": () => (/* binding */ SoftwareResourceCluster24),
/* harmony export */   "SoftwareResourceCluster32": () => (/* binding */ SoftwareResourceCluster32),
/* harmony export */   "SoftwareResourceResource16": () => (/* binding */ SoftwareResourceResource16),
/* harmony export */   "SoftwareResourceResource20": () => (/* binding */ SoftwareResourceResource20),
/* harmony export */   "SoftwareResourceResource24": () => (/* binding */ SoftwareResourceResource24),
/* harmony export */   "SoftwareResourceResource32": () => (/* binding */ SoftwareResourceResource32),
/* harmony export */   "SoilMoisture16": () => (/* binding */ SoilMoisture16),
/* harmony export */   "SoilMoisture20": () => (/* binding */ SoilMoisture20),
/* harmony export */   "SoilMoisture24": () => (/* binding */ SoilMoisture24),
/* harmony export */   "SoilMoisture32": () => (/* binding */ SoilMoisture32),
/* harmony export */   "SoilMoistureField16": () => (/* binding */ SoilMoistureField16),
/* harmony export */   "SoilMoistureField20": () => (/* binding */ SoilMoistureField20),
/* harmony export */   "SoilMoistureField24": () => (/* binding */ SoilMoistureField24),
/* harmony export */   "SoilMoistureField32": () => (/* binding */ SoilMoistureField32),
/* harmony export */   "SoilMoistureGlobal16": () => (/* binding */ SoilMoistureGlobal16),
/* harmony export */   "SoilMoistureGlobal20": () => (/* binding */ SoilMoistureGlobal20),
/* harmony export */   "SoilMoistureGlobal24": () => (/* binding */ SoilMoistureGlobal24),
/* harmony export */   "SoilMoistureGlobal32": () => (/* binding */ SoilMoistureGlobal32),
/* harmony export */   "SoilTemperature16": () => (/* binding */ SoilTemperature16),
/* harmony export */   "SoilTemperature20": () => (/* binding */ SoilTemperature20),
/* harmony export */   "SoilTemperature24": () => (/* binding */ SoilTemperature24),
/* harmony export */   "SoilTemperature32": () => (/* binding */ SoilTemperature32),
/* harmony export */   "SoilTemperatureField16": () => (/* binding */ SoilTemperatureField16),
/* harmony export */   "SoilTemperatureField20": () => (/* binding */ SoilTemperatureField20),
/* harmony export */   "SoilTemperatureField24": () => (/* binding */ SoilTemperatureField24),
/* harmony export */   "SoilTemperatureField32": () => (/* binding */ SoilTemperatureField32),
/* harmony export */   "SoilTemperatureGlobal16": () => (/* binding */ SoilTemperatureGlobal16),
/* harmony export */   "SoilTemperatureGlobal20": () => (/* binding */ SoilTemperatureGlobal20),
/* harmony export */   "SoilTemperatureGlobal24": () => (/* binding */ SoilTemperatureGlobal24),
/* harmony export */   "SoilTemperatureGlobal32": () => (/* binding */ SoilTemperatureGlobal32),
/* harmony export */   "SolarPanel16": () => (/* binding */ SolarPanel16),
/* harmony export */   "SolarPanel20": () => (/* binding */ SolarPanel20),
/* harmony export */   "SolarPanel24": () => (/* binding */ SolarPanel24),
/* harmony export */   "SolarPanel32": () => (/* binding */ SolarPanel32),
/* harmony export */   "SortAscending16": () => (/* binding */ SortAscending16),
/* harmony export */   "SortAscending20": () => (/* binding */ SortAscending20),
/* harmony export */   "SortAscending24": () => (/* binding */ SortAscending24),
/* harmony export */   "SortAscending32": () => (/* binding */ SortAscending32),
/* harmony export */   "SortDescending16": () => (/* binding */ SortDescending16),
/* harmony export */   "SortDescending20": () => (/* binding */ SortDescending20),
/* harmony export */   "SortDescending24": () => (/* binding */ SortDescending24),
/* harmony export */   "SortDescending32": () => (/* binding */ SortDescending32),
/* harmony export */   "SortRemove16": () => (/* binding */ SortRemove16),
/* harmony export */   "SortRemove20": () => (/* binding */ SortRemove20),
/* harmony export */   "SortRemove24": () => (/* binding */ SortRemove24),
/* harmony export */   "SortRemove32": () => (/* binding */ SortRemove32),
/* harmony export */   "SpellCheck16": () => (/* binding */ SpellCheck16),
/* harmony export */   "SpellCheck20": () => (/* binding */ SpellCheck20),
/* harmony export */   "SpellCheck24": () => (/* binding */ SpellCheck24),
/* harmony export */   "SpellCheck32": () => (/* binding */ SpellCheck32),
/* harmony export */   "Split16": () => (/* binding */ Split16),
/* harmony export */   "Split20": () => (/* binding */ Split20),
/* harmony export */   "Split24": () => (/* binding */ Split24),
/* harmony export */   "Split32": () => (/* binding */ Split32),
/* harmony export */   "SplitScreen16": () => (/* binding */ SplitScreen16),
/* harmony export */   "SplitScreen20": () => (/* binding */ SplitScreen20),
/* harmony export */   "SplitScreen24": () => (/* binding */ SplitScreen24),
/* harmony export */   "SplitScreen32": () => (/* binding */ SplitScreen32),
/* harmony export */   "SprayPaint16": () => (/* binding */ SprayPaint16),
/* harmony export */   "SprayPaint20": () => (/* binding */ SprayPaint20),
/* harmony export */   "SprayPaint24": () => (/* binding */ SprayPaint24),
/* harmony export */   "SprayPaint32": () => (/* binding */ SprayPaint32),
/* harmony export */   "Sprout16": () => (/* binding */ Sprout16),
/* harmony export */   "Sprout20": () => (/* binding */ Sprout20),
/* harmony export */   "Sprout24": () => (/* binding */ Sprout24),
/* harmony export */   "Sprout32": () => (/* binding */ Sprout32),
/* harmony export */   "Sql16": () => (/* binding */ Sql16),
/* harmony export */   "Sql20": () => (/* binding */ Sql20),
/* harmony export */   "Sql24": () => (/* binding */ Sql24),
/* harmony export */   "Sql32": () => (/* binding */ Sql32),
/* harmony export */   "SquareFillGlyph": () => (/* binding */ SquareFillGlyph),
/* harmony export */   "StackLimitation16": () => (/* binding */ StackLimitation16),
/* harmony export */   "StackLimitation20": () => (/* binding */ StackLimitation20),
/* harmony export */   "StackLimitation24": () => (/* binding */ StackLimitation24),
/* harmony export */   "StackLimitation32": () => (/* binding */ StackLimitation32),
/* harmony export */   "WatsonHealthSmoothing16": () => (/* binding */ WatsonHealthSmoothing16),
/* harmony export */   "WatsonHealthSmoothing20": () => (/* binding */ WatsonHealthSmoothing20),
/* harmony export */   "WatsonHealthSmoothing24": () => (/* binding */ WatsonHealthSmoothing24),
/* harmony export */   "WatsonHealthSmoothing32": () => (/* binding */ WatsonHealthSmoothing32),
/* harmony export */   "WatsonHealthSmoothingCursor16": () => (/* binding */ WatsonHealthSmoothingCursor16),
/* harmony export */   "WatsonHealthSmoothingCursor20": () => (/* binding */ WatsonHealthSmoothingCursor20),
/* harmony export */   "WatsonHealthSmoothingCursor24": () => (/* binding */ WatsonHealthSmoothingCursor24),
/* harmony export */   "WatsonHealthSmoothingCursor32": () => (/* binding */ WatsonHealthSmoothingCursor32),
/* harmony export */   "WatsonHealthSpineLabel16": () => (/* binding */ WatsonHealthSpineLabel16),
/* harmony export */   "WatsonHealthSpineLabel20": () => (/* binding */ WatsonHealthSpineLabel20),
/* harmony export */   "WatsonHealthSpineLabel24": () => (/* binding */ WatsonHealthSpineLabel24),
/* harmony export */   "WatsonHealthSpineLabel32": () => (/* binding */ WatsonHealthSpineLabel32),
/* harmony export */   "WatsonHealthSplitDiscard16": () => (/* binding */ WatsonHealthSplitDiscard16),
/* harmony export */   "WatsonHealthSplitDiscard20": () => (/* binding */ WatsonHealthSplitDiscard20),
/* harmony export */   "WatsonHealthSplitDiscard24": () => (/* binding */ WatsonHealthSplitDiscard24),
/* harmony export */   "WatsonHealthSplitDiscard32": () => (/* binding */ WatsonHealthSplitDiscard32),
/* harmony export */   "WatsonHealthStackedMove16": () => (/* binding */ WatsonHealthStackedMove16),
/* harmony export */   "WatsonHealthStackedMove20": () => (/* binding */ WatsonHealthStackedMove20),
/* harmony export */   "WatsonHealthStackedMove24": () => (/* binding */ WatsonHealthStackedMove24),
/* harmony export */   "WatsonHealthStackedMove32": () => (/* binding */ WatsonHealthStackedMove32),
/* harmony export */   "WatsonHealthStackedScrolling_132": () => (/* binding */ WatsonHealthStackedScrolling_132)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _rect, _path9, _path10, _rect2, _path11, _path12, _rect3, _path13, _path14, _rect4, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _path65, _path66, _path67, _path68, _path69, _path70, _path71, _path72, _path73, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _circle, _path178, _path179, _path180, _circle2, _path181, _path182, _path183, _circle3, _path184, _path185, _path186, _circle4, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _circle5, _path197, _circle6, _path198, _circle7, _path199, _circle8, _path200, _circle9, _path201, _circle10, _path202, _circle11, _path203, _circle12, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _path224, _path225, _path226, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _circle13, _path277, _path278, _circle14, _path279, _path280, _circle15, _path281, _path282, _circle16, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _circle17, _circle18, _circle19, _circle20, _circle21, _circle22, _circle23, _circle24, _path326, _path327, _circle25, _circle26, _circle27, _circle28, _circle29, _circle30, _circle31, _circle32, _path328, _path329, _circle33, _circle34, _circle35, _circle36, _circle37, _circle38, _circle39, _circle40, _path330, _path331, _circle41, _circle42, _circle43, _circle44, _circle45, _circle46, _circle47, _circle48, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _circle49, _circle50, _circle51, _circle52, _circle53, _circle54, _circle55, _path349, _circle56, _circle57, _circle58, _circle59, _circle60, _circle61, _circle62, _path350, _circle63, _circle64, _circle65, _circle66, _circle67, _circle68, _circle69, _path351, _circle70, _circle71, _circle72, _circle73, _circle74, _circle75, _circle76, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388, _path389, _path390, _path391, _path392, _path393, _path394, _path395, _path396, _path397, _path398, _path399, _path400, _path401, _path402, _path403, _path404, _path405, _path406, _path407, _path408, _path409, _path410, _path411, _path412, _path413, _path414, _path415, _path416, _path417, _path418, _path419, _path420, _path421, _path422, _path423, _path424, _path425, _path426, _path427, _path428, _path429, _path430, _path431, _path432, _path433, _path434, _path435, _path436, _path437, _path438, _path439, _path440, _path441, _path442, _path443, _path444, _path445, _path446, _path447, _path448, _path449, _path450, _path451, _path452;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var ShrinkScreen32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShrinkScreen32(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 28H17a2.0023 2.0023 0 01-2-2V20a2.0023 2.0023 0 012-2H28a2.0027 2.0027 0 012 2v6A2.0027 2.0027 0 0128 28zM17 20v6H28.002L28 20zM12 10L12 13.586 7.707 9.293 6.293 10.707 10.586 15 7 15 7 17 14 17 14 10 12 10z"
  })), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,22H4a2.0023,2.0023,0,0,1-2-2V7A2.002,2.002,0,0,1,4,5H26a2.0023,2.0023,0,0,1,2,2v9H26V7H4V20h9Z"
  })), children);
});
var ShrinkScreen24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShrinkScreen24(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 28H17a2.0023 2.0023 0 01-2-2V20a2.0023 2.0023 0 012-2H28a2.0027 2.0027 0 012 2v6A2.0027 2.0027 0 0128 28zM17 20v6H28.002L28 20zM12 10L12 13.586 7.707 9.293 6.293 10.707 10.586 15 7 15 7 17 14 17 14 10 12 10z"
  })), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,22H4a2.0023,2.0023,0,0,1-2-2V7A2.002,2.002,0,0,1,4,5H26a2.0023,2.0023,0,0,1,2,2v9H26V7H4V20h9Z"
  })), children);
});
var ShrinkScreen20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShrinkScreen20(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 28H17a2.0023 2.0023 0 01-2-2V20a2.0023 2.0023 0 012-2H28a2.0027 2.0027 0 012 2v6A2.0027 2.0027 0 0128 28zM17 20v6H28.002L28 20zM12 10L12 13.586 7.707 9.293 6.293 10.707 10.586 15 7 15 7 17 14 17 14 10 12 10z"
  })), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,22H4a2.0023,2.0023,0,0,1-2-2V7A2.002,2.002,0,0,1,4,5H26a2.0023,2.0023,0,0,1,2,2v9H26V7H4V20h9Z"
  })), children);
});
var ShrinkScreen16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShrinkScreen16(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 28H17a2.0023 2.0023 0 01-2-2V20a2.0023 2.0023 0 012-2H28a2.0027 2.0027 0 012 2v6A2.0027 2.0027 0 0128 28zM17 20v6H28.002L28 20zM12 10L12 13.586 7.707 9.293 6.293 10.707 10.586 15 7 15 7 17 14 17 14 10 12 10z"
  })), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,22H4a2.0023,2.0023,0,0,1-2-2V7A2.002,2.002,0,0,1,4,5H26a2.0023,2.0023,0,0,1,2,2v9H26V7H4V20h9Z"
  })), children);
});
var ShrinkScreenFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShrinkScreenFilled32(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _rect || (_rect = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("rect", {
    width: "15",
    height: "10",
    x: "15",
    y: "18",
    rx: "2"
  })), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 10L12 13.586 7.707 9.293 6.293 10.707 10.586 15 7 15 7 17 14 17 14 10 12 10z"
  })), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,22H4a2.0023,2.0023,0,0,1-2-2V7A2.002,2.002,0,0,1,4,5H26a2.0023,2.0023,0,0,1,2,2v9H26V7H4V20h9Z"
  })), children);
});
var ShrinkScreenFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShrinkScreenFilled24(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _rect2 || (_rect2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("rect", {
    width: "15",
    height: "10",
    x: "15",
    y: "18",
    rx: "2"
  })), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 10L12 13.586 7.707 9.293 6.293 10.707 10.586 15 7 15 7 17 14 17 14 10 12 10z"
  })), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,22H4a2.0023,2.0023,0,0,1-2-2V7A2.002,2.002,0,0,1,4,5H26a2.0023,2.0023,0,0,1,2,2v9H26V7H4V20h9Z"
  })), children);
});
var ShrinkScreenFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShrinkScreenFilled20(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _rect3 || (_rect3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("rect", {
    width: "15",
    height: "10",
    x: "15",
    y: "18",
    rx: "2"
  })), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 10L12 13.586 7.707 9.293 6.293 10.707 10.586 15 7 15 7 17 14 17 14 10 12 10z"
  })), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,22H4a2.0023,2.0023,0,0,1-2-2V7A2.002,2.002,0,0,1,4,5H26a2.0023,2.0023,0,0,1,2,2v9H26V7H4V20h9Z"
  })), children);
});
var ShrinkScreenFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ShrinkScreenFilled16(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _rect4 || (_rect4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("rect", {
    width: "15",
    height: "10",
    x: "15",
    y: "18",
    rx: "2"
  })), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 10L12 13.586 7.707 9.293 6.293 10.707 10.586 15 7 15 7 17 14 17 14 10 12 10z"
  })), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,22H4a2.0023,2.0023,0,0,1-2-2V7A2.002,2.002,0,0,1,4,5H26a2.0023,2.0023,0,0,1,2,2v9H26V7H4V20h9Z"
  })), children);
});
var Shuffle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Shuffle32(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.59,19.41,26.17,23H19.55l-4.37-7,4.37-7h6.62l-3.58,3.59L24,14l6-6L24,2,22.59,3.41,26.17,7H19.55a2,2,0,0,0-1.69.94L14,14.11,10.14,7.94A2,2,0,0,0,8.45,7H2V9H8.45l4.37,7L8.45,23H2v2H8.45a2,2,0,0,0,1.69-.94L14,17.89l3.86,6.17a2,2,0,0,0,1.69.94h6.62l-3.58,3.59L24,30l6-6-6-6Z"
  })), children);
});
var Shuffle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Shuffle24(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.59,19.41,26.17,23H19.55l-4.37-7,4.37-7h6.62l-3.58,3.59L24,14l6-6L24,2,22.59,3.41,26.17,7H19.55a2,2,0,0,0-1.69.94L14,14.11,10.14,7.94A2,2,0,0,0,8.45,7H2V9H8.45l4.37,7L8.45,23H2v2H8.45a2,2,0,0,0,1.69-.94L14,17.89l3.86,6.17a2,2,0,0,0,1.69.94h6.62l-3.58,3.59L24,30l6-6-6-6Z"
  })), children);
});
var Shuffle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Shuffle20(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.59,19.41,26.17,23H19.55l-4.37-7,4.37-7h6.62l-3.58,3.59L24,14l6-6L24,2,22.59,3.41,26.17,7H19.55a2,2,0,0,0-1.69.94L14,14.11,10.14,7.94A2,2,0,0,0,8.45,7H2V9H8.45l4.37,7L8.45,23H2v2H8.45a2,2,0,0,0,1.69-.94L14,17.89l3.86,6.17a2,2,0,0,0,1.69.94h6.62l-3.58,3.59L24,30l6-6-6-6Z"
  })), children);
});
var Shuffle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Shuffle16(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.59,19.41,26.17,23H19.55l-4.37-7,4.37-7h6.62l-3.58,3.59L24,14l6-6L24,2,22.59,3.41,26.17,7H19.55a2,2,0,0,0-1.69.94L14,14.11,10.14,7.94A2,2,0,0,0,8.45,7H2V9H8.45l4.37,7L8.45,23H2v2H8.45a2,2,0,0,0,1.69-.94L14,17.89l3.86,6.17a2,2,0,0,0,1.69.94h6.62l-3.58,3.59L24,30l6-6-6-6Z"
  })), children);
});
var Shuttle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Shuttle32(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.81,16l-7-9.56A1,1,0,0,0,22,6H3A1,1,0,0,0,2,7V24a1,1,0,0,0,1,1H5.14a4,4,0,0,0,7.72,0h6.28a4,4,0,0,0,7.72,0H29a1,1,0,0,0,1-1V16.56A1,1,0,0,0,29.81,16ZM20,8h1.49l5.13,7H20ZM4,8H18v7H4ZM9,26a2,2,0,1,1,2-2A2,2,0,0,1,9,26Zm14,0a2,2,0,1,1,2-2A2,2,0,0,1,23,26Zm5-3H26.86a4,4,0,0,0-7.72,0H12.86a4,4,0,0,0-7.72,0H4V17H28Z"
  })), children);
});
var Shuttle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Shuttle24(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.81,16l-7-9.56A1,1,0,0,0,22,6H3A1,1,0,0,0,2,7V24a1,1,0,0,0,1,1H5.14a4,4,0,0,0,7.72,0h6.28a4,4,0,0,0,7.72,0H29a1,1,0,0,0,1-1V16.56A1,1,0,0,0,29.81,16ZM20,8h1.49l5.13,7H20ZM4,8H18v7H4ZM9,26a2,2,0,1,1,2-2A2,2,0,0,1,9,26Zm14,0a2,2,0,1,1,2-2A2,2,0,0,1,23,26Zm5-3H26.86a4,4,0,0,0-7.72,0H12.86a4,4,0,0,0-7.72,0H4V17H28Z"
  })), children);
});
var Shuttle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Shuttle20(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.81,16l-7-9.56A1,1,0,0,0,22,6H3A1,1,0,0,0,2,7V24a1,1,0,0,0,1,1H5.14a4,4,0,0,0,7.72,0h6.28a4,4,0,0,0,7.72,0H29a1,1,0,0,0,1-1V16.56A1,1,0,0,0,29.81,16ZM20,8h1.49l5.13,7H20ZM4,8H18v7H4ZM9,26a2,2,0,1,1,2-2A2,2,0,0,1,9,26Zm14,0a2,2,0,1,1,2-2A2,2,0,0,1,23,26Zm5-3H26.86a4,4,0,0,0-7.72,0H12.86a4,4,0,0,0-7.72,0H4V17H28Z"
  })), children);
});
var Shuttle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Shuttle16(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.81,16l-7-9.56A1,1,0,0,0,22,6H3A1,1,0,0,0,2,7V24a1,1,0,0,0,1,1H5.14a4,4,0,0,0,7.72,0h6.28a4,4,0,0,0,7.72,0H29a1,1,0,0,0,1-1V16.56A1,1,0,0,0,29.81,16ZM20,8h1.49l5.13,7H20ZM4,8H18v7H4ZM9,26a2,2,0,1,1,2-2A2,2,0,0,1,9,26Zm14,0a2,2,0,1,1,2-2A2,2,0,0,1,23,26Zm5-3H26.86a4,4,0,0,0-7.72,0H12.86a4,4,0,0,0-7.72,0H4V17H28Z"
  })), children);
});
var Sight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sight32(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 12H12V14H10zM6 12H8V14H6zM2 12H4V14H2zM26 30H24V27H20a5.0055 5.0055 0 01-5-5V20.7207l-2.3162-.772a1 1 0 01-.5412-1.4631L15 13.7229V11a9.01 9.01 0 019-9h5V4H24a7.0078 7.0078 0 00-7 7v3a.9991.9991 0 01-.1426.5144l-2.3586 3.9312 1.8174.6057A1 1 0 0117 20v2a3.0033 3.0033 0 003 3h5a1 1 0 011 1z"
  })), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 12H23V14H19z"
  })), children);
});
var Sight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sight24(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 12H12V14H10zM6 12H8V14H6zM2 12H4V14H2zM26 30H24V27H20a5.0055 5.0055 0 01-5-5V20.7207l-2.3162-.772a1 1 0 01-.5412-1.4631L15 13.7229V11a9.01 9.01 0 019-9h5V4H24a7.0078 7.0078 0 00-7 7v3a.9991.9991 0 01-.1426.5144l-2.3586 3.9312 1.8174.6057A1 1 0 0117 20v2a3.0033 3.0033 0 003 3h5a1 1 0 011 1z"
  })), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 12H23V14H19z"
  })), children);
});
var Sight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sight20(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 12H12V14H10zM6 12H8V14H6zM2 12H4V14H2zM26 30H24V27H20a5.0055 5.0055 0 01-5-5V20.7207l-2.3162-.772a1 1 0 01-.5412-1.4631L15 13.7229V11a9.01 9.01 0 019-9h5V4H24a7.0078 7.0078 0 00-7 7v3a.9991.9991 0 01-.1426.5144l-2.3586 3.9312 1.8174.6057A1 1 0 0117 20v2a3.0033 3.0033 0 003 3h5a1 1 0 011 1z"
  })), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 12H23V14H19z"
  })), children);
});
var Sight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sight16(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 12H12V14H10zM6 12H8V14H6zM2 12H4V14H2zM26 30H24V27H20a5.0055 5.0055 0 01-5-5V20.7207l-2.3162-.772a1 1 0 01-.5412-1.4631L15 13.7229V11a9.01 9.01 0 019-9h5V4H24a7.0078 7.0078 0 00-7 7v3a.9991.9991 0 01-.1426.5144l-2.3586 3.9312 1.8174.6057A1 1 0 0117 20v2a3.0033 3.0033 0 003 3h5a1 1 0 011 1z"
  })), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 12H23V14H19z"
  })), children);
});
var Sigma32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sigma32(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 5L7 5 7 7.414 15.586 16 7 24.586 7 27 24 27 24 25 9.414 25 18.414 16 9.414 7 24 7 24 5z"
  })), children);
});
var Sigma24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sigma24(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 5L7 5 7 7.414 15.586 16 7 24.586 7 27 24 27 24 25 9.414 25 18.414 16 9.414 7 24 7 24 5z"
  })), children);
});
var Sigma20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sigma20(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 5L7 5 7 7.414 15.586 16 7 24.586 7 27 24 27 24 25 9.414 25 18.414 16 9.414 7 24 7 24 5z"
  })), children);
});
var Sigma16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sigma16(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 5L7 5 7 7.414 15.586 16 7 24.586 7 27 24 27 24 25 9.414 25 18.414 16 9.414 7 24 7 24 5z"
  })), children);
});
var SignalStrength32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SignalStrength32(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 6H28V26H26zM18 11H20V26H18zM11 16H13V26H11zM4 20H6V26H4z"
  })), children);
});
var SignalStrength24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SignalStrength24(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 6H28V26H26zM18 11H20V26H18zM11 16H13V26H11zM4 20H6V26H4z"
  })), children);
});
var SignalStrength20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SignalStrength20(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 6H28V26H26zM18 11H20V26H18zM11 16H13V26H11zM4 20H6V26H4z"
  })), children);
});
var SignalStrength16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SignalStrength16(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 6H28V26H26zM18 11H20V26H18zM11 16H13V26H11zM4 20H6V26H4z"
  })), children);
});
var SimCard32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SimCard32(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,9H8a2.0023,2.0023,0,0,0-2,2V21a2.0023,2.0023,0,0,0,2,2H21a2.0023,2.0023,0,0,0,2-2V11A2.0023,2.0023,0,0,0,21,9Zm0,4H18V11h3Zm-3,2h3v2H18Zm-2-4V21H13V14a1,1,0,0,0-1-1H8V11Zm-5,6H8V15h3ZM8,19h3v2H8Zm10,2V19h3v2Z"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5317,27H4a2.0021,2.0021,0,0,1-2-2V7A2.0021,2.0021,0,0,1,4,5H28a2.0021,2.0021,0,0,1,2,2V19.6379a2.0044,2.0044,0,0,1-.4639,1.2808L25.0679,26.28A1.9944,1.9944,0,0,1,23.5317,27ZM4,7V25H23.5317L28,19.6379V7Z"
  })), children);
});
var SimCard24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SimCard24(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,9H8a2.0023,2.0023,0,0,0-2,2V21a2.0023,2.0023,0,0,0,2,2H21a2.0023,2.0023,0,0,0,2-2V11A2.0023,2.0023,0,0,0,21,9Zm0,4H18V11h3Zm-3,2h3v2H18Zm-2-4V21H13V14a1,1,0,0,0-1-1H8V11Zm-5,6H8V15h3ZM8,19h3v2H8Zm10,2V19h3v2Z"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5317,27H4a2.0021,2.0021,0,0,1-2-2V7A2.0021,2.0021,0,0,1,4,5H28a2.0021,2.0021,0,0,1,2,2V19.6379a2.0044,2.0044,0,0,1-.4639,1.2808L25.0679,26.28A1.9944,1.9944,0,0,1,23.5317,27ZM4,7V25H23.5317L28,19.6379V7Z"
  })), children);
});
var SimCard20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SimCard20(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,9H8a2.0023,2.0023,0,0,0-2,2V21a2.0023,2.0023,0,0,0,2,2H21a2.0023,2.0023,0,0,0,2-2V11A2.0023,2.0023,0,0,0,21,9Zm0,4H18V11h3Zm-3,2h3v2H18Zm-2-4V21H13V14a1,1,0,0,0-1-1H8V11Zm-5,6H8V15h3ZM8,19h3v2H8Zm10,2V19h3v2Z"
  })), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5317,27H4a2.0021,2.0021,0,0,1-2-2V7A2.0021,2.0021,0,0,1,4,5H28a2.0021,2.0021,0,0,1,2,2V19.6379a2.0044,2.0044,0,0,1-.4639,1.2808L25.0679,26.28A1.9944,1.9944,0,0,1,23.5317,27ZM4,7V25H23.5317L28,19.6379V7Z"
  })), children);
});
var SimCard16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SimCard16(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,9H8a2.0023,2.0023,0,0,0-2,2V21a2.0023,2.0023,0,0,0,2,2H21a2.0023,2.0023,0,0,0,2-2V11A2.0023,2.0023,0,0,0,21,9Zm0,4H18V11h3Zm-3,2h3v2H18Zm-2-4V21H13V14a1,1,0,0,0-1-1H8V11Zm-5,6H8V15h3ZM8,19h3v2H8Zm10,2V19h3v2Z"
  })), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5317,27H4a2.0021,2.0021,0,0,1-2-2V7A2.0021,2.0021,0,0,1,4,5H28a2.0021,2.0021,0,0,1,2,2V19.6379a2.0044,2.0044,0,0,1-.4639,1.2808L25.0679,26.28A1.9944,1.9944,0,0,1,23.5317,27ZM4,7V25H23.5317L28,19.6379V7Z"
  })), children);
});
var SkillLevel32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkillLevel32(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V4h8zm-6-2h4V6H24zM20 30H12V12h8zm-6-2h4V14H14zM10 30H2V18h8zM4 28H8V20H4z"
  })), children);
});
var SkillLevel24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkillLevel24(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V4h8zm-6-2h4V6H24zM20 30H12V12h8zm-6-2h4V14H14zM10 30H2V18h8zM4 28H8V20H4z"
  })), children);
});
var SkillLevel20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkillLevel20(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V4h8zm-6-2h4V6H24zM20 30H12V12h8zm-6-2h4V14H14zM10 30H2V18h8zM4 28H8V20H4z"
  })), children);
});
var SkillLevel16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkillLevel16(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V4h8zm-6-2h4V6H24zM20 30H12V12h8zm-6-2h4V14H14zM10 30H2V18h8zM4 28H8V20H4z"
  })), children);
});
var SkillLevelAdvanced32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkillLevelAdvanced32(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V4h8zM20 30H12V12h8zM10 30H2V18h8z"
  })), children);
});
var SkillLevelAdvanced24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkillLevelAdvanced24(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V4h8zM20 30H12V12h8zM10 30H2V18h8z"
  })), children);
});
var SkillLevelAdvanced20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkillLevelAdvanced20(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V4h8zM20 30H12V12h8zM10 30H2V18h8z"
  })), children);
});
var SkillLevelAdvanced16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkillLevelAdvanced16(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V4h8zM20 30H12V12h8zM10 30H2V18h8z"
  })), children);
});
var SkillLevelBasic32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkillLevelBasic32(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V4h8zm-6-2h4V6H24zM20 30H12V12h8zm-6-2h4V14H14zM10 30H2V18h8z"
  })), children);
});
var SkillLevelBasic24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkillLevelBasic24(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V4h8zm-6-2h4V6H24zM20 30H12V12h8zm-6-2h4V14H14zM10 30H2V18h8z"
  })), children);
});
var SkillLevelBasic20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkillLevelBasic20(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V4h8zm-6-2h4V6H24zM20 30H12V12h8zm-6-2h4V14H14zM10 30H2V18h8z"
  })), children);
});
var SkillLevelBasic16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkillLevelBasic16(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V4h8zm-6-2h4V6H24zM20 30H12V12h8zm-6-2h4V14H14zM10 30H2V18h8z"
  })), children);
});
var SkillLevelIntermediate32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkillLevelIntermediate32(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V4h8zm-6-2h4V6H24zM20 30H12V12h8zM10 30H2V18h8z"
  })), children);
});
var SkillLevelIntermediate24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkillLevelIntermediate24(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V4h8zm-6-2h4V6H24zM20 30H12V12h8zM10 30H2V18h8z"
  })), children);
});
var SkillLevelIntermediate20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkillLevelIntermediate20(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V4h8zm-6-2h4V6H24zM20 30H12V12h8zM10 30H2V18h8z"
  })), children);
});
var SkillLevelIntermediate16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkillLevelIntermediate16(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H22V4h8zm-6-2h4V6H24zM20 30H12V12h8zM10 30H2V18h8z"
  })), children);
});
var SkipBack32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBack32(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 28a1 1 0 01-.5-.13l-19-11a1 1 0 010-1.74l19-11a1 1 0 011 0A1 1 0 0128 5V27a1 1 0 01-1 1zM10 16l16 9.27V6.73zM2 4H4V28H2z"
  })), children);
});
var SkipBack24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBack24(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 28a1 1 0 01-.5-.13l-19-11a1 1 0 010-1.74l19-11a1 1 0 011 0A1 1 0 0128 5V27a1 1 0 01-1 1zM10 16l16 9.27V6.73zM2 4H4V28H2z"
  })), children);
});
var SkipBack20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBack20(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 28a1 1 0 01-.5-.13l-19-11a1 1 0 010-1.74l19-11a1 1 0 011 0A1 1 0 0128 5V27a1 1 0 01-1 1zM10 16l16 9.27V6.73zM2 4H4V28H2z"
  })), children);
});
var SkipBack16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBack16(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 28a1 1 0 01-.5-.13l-19-11a1 1 0 010-1.74l19-11a1 1 0 011 0A1 1 0 0128 5V27a1 1 0 01-1 1zM10 16l16 9.27V6.73zM2 4H4V28H2z"
  })), children);
});
var SkipBackFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackFilled32(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 28a.9975.9975 0 01-.501-.1348l-19-11a1 1 0 010-1.73l19-11A1 1 0 0128 5V27a1 1 0 01-1 1zM2 4H4V28H2z"
  })), children);
});
var SkipBackFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackFilled24(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 28a.9975.9975 0 01-.501-.1348l-19-11a1 1 0 010-1.73l19-11A1 1 0 0128 5V27a1 1 0 01-1 1zM2 4H4V28H2z"
  })), children);
});
var SkipBackFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackFilled20(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 28a.9975.9975 0 01-.501-.1348l-19-11a1 1 0 010-1.73l19-11A1 1 0 0128 5V27a1 1 0 01-1 1zM2 4H4V28H2z"
  })), children);
});
var SkipBackFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackFilled16(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 28a.9975.9975 0 01-.501-.1348l-19-11a1 1 0 010-1.73l19-11A1 1 0 0128 5V27a1 1 0 01-1 1zM2 4H4V28H2z"
  })), children);
});
var SkipBackOutline32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackOutline32(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,22a1.0037,1.0037,0,0,1-.4858-.1257l-9-5a1,1,0,0,1,0-1.7485l9-5A1,1,0,0,1,24,11V21a1,1,0,0,1-1,1Zm-6.9409-6L22,19.3006V12.7Z"
  })), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 10H11V22H9z",
    transform: "rotate(-180 10 16)"
  })), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var SkipBackOutline24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackOutline24(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,22a1.0037,1.0037,0,0,1-.4858-.1257l-9-5a1,1,0,0,1,0-1.7485l9-5A1,1,0,0,1,24,11V21a1,1,0,0,1-1,1Zm-6.9409-6L22,19.3006V12.7Z"
  })), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 10H11V22H9z",
    transform: "rotate(-180 10 16)"
  })), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var SkipBackOutline20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackOutline20(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,22a1.0037,1.0037,0,0,1-.4858-.1257l-9-5a1,1,0,0,1,0-1.7485l9-5A1,1,0,0,1,24,11V21a1,1,0,0,1-1,1Zm-6.9409-6L22,19.3006V12.7Z"
  })), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 10H11V22H9z",
    transform: "rotate(-180 10 16)"
  })), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var SkipBackOutline16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackOutline16(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,22a1.0037,1.0037,0,0,1-.4858-.1257l-9-5a1,1,0,0,1,0-1.7485l9-5A1,1,0,0,1,24,11V21a1,1,0,0,1-1,1Zm-6.9409-6L22,19.3006V12.7Z"
  })), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 10H11V22H9z",
    transform: "rotate(-180 10 16)"
  })), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var SkipBackOutlineFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackOutlineFilled32(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM10,22H8V10h2Zm14-1a1,1,0,0,1-1.4858.874l-9-5a1,1,0,0,1,0-1.748l9-5A1,1,0,0,1,24,11Z"
  })), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 19.301L22 12.699 16.059 16 22 19.301z"
  })), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23,22a1.0037,1.0037,0,0,1-.4858-.1257l-9-5a1,1,0,0,1,0-1.7486l9-5A1,1,0,0,1,24,11V21a1,1,0,0,1-1,1Zm-6.9409-6L22,19.3005V12.7Z"
  })), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M8 10H10V22H8z",
    transform: "rotate(-180 9 16)"
  })), children);
});
var SkipBackOutlineFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackOutlineFilled24(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM10,22H8V10h2Zm14-1a1,1,0,0,1-1.4858.874l-9-5a1,1,0,0,1,0-1.748l9-5A1,1,0,0,1,24,11Z"
  })), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 19.301L22 12.699 16.059 16 22 19.301z"
  })), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23,22a1.0037,1.0037,0,0,1-.4858-.1257l-9-5a1,1,0,0,1,0-1.7486l9-5A1,1,0,0,1,24,11V21a1,1,0,0,1-1,1Zm-6.9409-6L22,19.3005V12.7Z"
  })), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M8 10H10V22H8z",
    transform: "rotate(-180 9 16)"
  })), children);
});
var SkipBackOutlineFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackOutlineFilled20(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM10,22H8V10h2Zm14-1a1,1,0,0,1-1.4858.874l-9-5a1,1,0,0,1,0-1.748l9-5A1,1,0,0,1,24,11Z"
  })), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 19.301L22 12.699 16.059 16 22 19.301z"
  })), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23,22a1.0037,1.0037,0,0,1-.4858-.1257l-9-5a1,1,0,0,1,0-1.7486l9-5A1,1,0,0,1,24,11V21a1,1,0,0,1-1,1Zm-6.9409-6L22,19.3005V12.7Z"
  })), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M8 10H10V22H8z",
    transform: "rotate(-180 9 16)"
  })), children);
});
var SkipBackOutlineFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackOutlineFilled16(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM10,22H8V10h2Zm14-1a1,1,0,0,1-1.4858.874l-9-5a1,1,0,0,1,0-1.748l9-5A1,1,0,0,1,24,11Z"
  })), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 19.301L22 12.699 16.059 16 22 19.301z"
  })), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23,22a1.0037,1.0037,0,0,1-.4858-.1257l-9-5a1,1,0,0,1,0-1.7486l9-5A1,1,0,0,1,24,11V21a1,1,0,0,1-1,1Zm-6.9409-6L22,19.3005V12.7Z"
  })), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M8 10H10V22H8z",
    transform: "rotate(-180 9 16)"
  })), children);
});
var SkipBackOutlineSolid32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackOutlineSolid32(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,22a1.0037,1.0037,0,0,1-.4858-.1257l-9-5a1,1,0,0,1,0-1.7485l9-5A1,1,0,0,1,24,11V21a1,1,0,0,1-1,1Z"
  })), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 10H11V22H9z",
    transform: "rotate(-180 10 16)"
  })), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var SkipBackOutlineSolid24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackOutlineSolid24(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,22a1.0037,1.0037,0,0,1-.4858-.1257l-9-5a1,1,0,0,1,0-1.7485l9-5A1,1,0,0,1,24,11V21a1,1,0,0,1-1,1Z"
  })), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 10H11V22H9z",
    transform: "rotate(-180 10 16)"
  })), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var SkipBackOutlineSolid20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackOutlineSolid20(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,22a1.0037,1.0037,0,0,1-.4858-.1257l-9-5a1,1,0,0,1,0-1.7485l9-5A1,1,0,0,1,24,11V21a1,1,0,0,1-1,1Z"
  })), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 10H11V22H9z",
    transform: "rotate(-180 10 16)"
  })), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var SkipBackOutlineSolid16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackOutlineSolid16(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,22a1.0037,1.0037,0,0,1-.4858-.1257l-9-5a1,1,0,0,1,0-1.7485l9-5A1,1,0,0,1,24,11V21a1,1,0,0,1-1,1Z"
  })), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 10H11V22H9z",
    transform: "rotate(-180 10 16)"
  })), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var SkipBackSolidFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackSolidFilled32(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM10,22H8V10h2Zm14-1a1,1,0,0,1-1.4858.874l-9-5a1,1,0,0,1,0-1.748l9-5A1,1,0,0,1,24,11Z"
  })), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23,22a1.0037,1.0037,0,0,1-.4858-.1257l-9-5a1,1,0,0,1,0-1.7486l9-5A1,1,0,0,1,24,11V21a1,1,0,0,1-1,1Z"
  })), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M8 10H10V22H8z",
    transform: "rotate(-180 9 16)"
  })), children);
});
var SkipBackSolidFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackSolidFilled24(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM10,22H8V10h2Zm14-1a1,1,0,0,1-1.4858.874l-9-5a1,1,0,0,1,0-1.748l9-5A1,1,0,0,1,24,11Z"
  })), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23,22a1.0037,1.0037,0,0,1-.4858-.1257l-9-5a1,1,0,0,1,0-1.7486l9-5A1,1,0,0,1,24,11V21a1,1,0,0,1-1,1Z"
  })), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M8 10H10V22H8z",
    transform: "rotate(-180 9 16)"
  })), children);
});
var SkipBackSolidFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackSolidFilled20(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM10,22H8V10h2Zm14-1a1,1,0,0,1-1.4858.874l-9-5a1,1,0,0,1,0-1.748l9-5A1,1,0,0,1,24,11Z"
  })), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23,22a1.0037,1.0037,0,0,1-.4858-.1257l-9-5a1,1,0,0,1,0-1.7486l9-5A1,1,0,0,1,24,11V21a1,1,0,0,1-1,1Z"
  })), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M8 10H10V22H8z",
    transform: "rotate(-180 9 16)"
  })), children);
});
var SkipBackSolidFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipBackSolidFilled16(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM10,22H8V10h2Zm14-1a1,1,0,0,1-1.4858.874l-9-5a1,1,0,0,1,0-1.748l9-5A1,1,0,0,1,24,11Z"
  })), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23,22a1.0037,1.0037,0,0,1-.4858-.1257l-9-5a1,1,0,0,1,0-1.7486l9-5A1,1,0,0,1,24,11V21a1,1,0,0,1-1,1Z"
  })), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M8 10H10V22H8z",
    transform: "rotate(-180 9 16)"
  })), children);
});
var SkipForward32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForward32(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 28a1 1 0 01-1-1V5a1 1 0 01.5-.87 1 1 0 011 0l19 11a1 1 0 010 1.74l-19 11A1 1 0 015 28zM6 6.73V25.27L22 16zM28 4H30V28H28z"
  })), children);
});
var SkipForward24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForward24(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 28a1 1 0 01-1-1V5a1 1 0 01.5-.87 1 1 0 011 0l19 11a1 1 0 010 1.74l-19 11A1 1 0 015 28zM6 6.73V25.27L22 16zM28 4H30V28H28z"
  })), children);
});
var SkipForward20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForward20(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 28a1 1 0 01-1-1V5a1 1 0 01.5-.87 1 1 0 011 0l19 11a1 1 0 010 1.74l-19 11A1 1 0 015 28zM6 6.73V25.27L22 16zM28 4H30V28H28z"
  })), children);
});
var SkipForward16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForward16(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 28a1 1 0 01-1-1V5a1 1 0 01.5-.87 1 1 0 011 0l19 11a1 1 0 010 1.74l-19 11A1 1 0 015 28zM6 6.73V25.27L22 16zM28 4H30V28H28z"
  })), children);
});
var SkipForwardFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardFilled32(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 4H30V28H28zM5 28a1 1 0 01-1-1V5a1 1 0 011.501-.8652l19 11a1 1 0 010 1.73l-19 11A.9975.9975 0 015 28z"
  })), children);
});
var SkipForwardFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardFilled24(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 4H30V28H28zM5 28a1 1 0 01-1-1V5a1 1 0 011.501-.8652l19 11a1 1 0 010 1.73l-19 11A.9975.9975 0 015 28z"
  })), children);
});
var SkipForwardFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardFilled20(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 4H30V28H28zM5 28a1 1 0 01-1-1V5a1 1 0 011.501-.8652l19 11a1 1 0 010 1.73l-19 11A.9975.9975 0 015 28z"
  })), children);
});
var SkipForwardFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardFilled16(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 4H30V28H28zM5 28a1 1 0 01-1-1V5a1 1 0 011.501-.8652l19 11a1 1 0 010 1.73l-19 11A.9975.9975 0 015 28z"
  })), children);
});
var SkipForwardOutline32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardOutline32(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 10H23V22H21zM8.4927 21.8618A1 1 0 018 21V11a1 1 0 011.4858-.8742l9 5a1 1 0 010 1.7485l-9 5a1.0009 1.0009 0 01-.9931-.0125zM10 12.7v6.6011L15.9409 16z"
  })), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var SkipForwardOutline24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardOutline24(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 10H23V22H21zM8.4927 21.8618A1 1 0 018 21V11a1 1 0 011.4858-.8742l9 5a1 1 0 010 1.7485l-9 5a1.0009 1.0009 0 01-.9931-.0125zM10 12.7v6.6011L15.9409 16z"
  })), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var SkipForwardOutline20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardOutline20(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 10H23V22H21zM8.4927 21.8618A1 1 0 018 21V11a1 1 0 011.4858-.8742l9 5a1 1 0 010 1.7485l-9 5a1.0009 1.0009 0 01-.9931-.0125zM10 12.7v6.6011L15.9409 16z"
  })), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var SkipForwardOutline16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardOutline16(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 10H23V22H21zM8.4927 21.8618A1 1 0 018 21V11a1 1 0 011.4858-.8742l9 5a1 1 0 010 1.7485l-9 5a1.0009 1.0009 0 01-.9931-.0125zM10 12.7v6.6011L15.9409 16z"
  })), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var SkipForwardOutlineFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardOutlineFilled32(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 19.301L15.941 16 10 12.699 10 19.301z"
  })), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm2.4858,14.874-9,5A1,1,0,0,1,8,21V11a1,1,0,0,1,1.4858-.874l9,5a1,1,0,0,1,0,1.748ZM24,22H22V10h2Z"
  })), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M22 10H24V22H22zM8.4927 21.8618A1 1 0 018 21V11a1 1 0 011.4858-.8743l9 5a1 1 0 010 1.7486l-9 5a1.0009 1.0009 0 01-.9931-.0125zM10 12.7v6.601L15.9409 16z"
  })), children);
});
var SkipForwardOutlineFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardOutlineFilled24(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 19.301L15.941 16 10 12.699 10 19.301z"
  })), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm2.4858,14.874-9,5A1,1,0,0,1,8,21V11a1,1,0,0,1,1.4858-.874l9,5a1,1,0,0,1,0,1.748ZM24,22H22V10h2Z"
  })), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M22 10H24V22H22zM8.4927 21.8618A1 1 0 018 21V11a1 1 0 011.4858-.8743l9 5a1 1 0 010 1.7486l-9 5a1.0009 1.0009 0 01-.9931-.0125zM10 12.7v6.601L15.9409 16z"
  })), children);
});
var SkipForwardOutlineFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardOutlineFilled20(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 19.301L15.941 16 10 12.699 10 19.301z"
  })), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm2.4858,14.874-9,5A1,1,0,0,1,8,21V11a1,1,0,0,1,1.4858-.874l9,5a1,1,0,0,1,0,1.748ZM24,22H22V10h2Z"
  })), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M22 10H24V22H22zM8.4927 21.8618A1 1 0 018 21V11a1 1 0 011.4858-.8743l9 5a1 1 0 010 1.7486l-9 5a1.0009 1.0009 0 01-.9931-.0125zM10 12.7v6.601L15.9409 16z"
  })), children);
});
var SkipForwardOutlineFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardOutlineFilled16(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 19.301L15.941 16 10 12.699 10 19.301z"
  })), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm2.4858,14.874-9,5A1,1,0,0,1,8,21V11a1,1,0,0,1,1.4858-.874l9,5a1,1,0,0,1,0,1.748ZM24,22H22V10h2Z"
  })), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M22 10H24V22H22zM8.4927 21.8618A1 1 0 018 21V11a1 1 0 011.4858-.8743l9 5a1 1 0 010 1.7486l-9 5a1.0009 1.0009 0 01-.9931-.0125zM10 12.7v6.601L15.9409 16z"
  })), children);
});
var SkipForwardOutlineSolid32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardOutlineSolid32(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 10H23V22H21zM8.4927 21.8618A1 1 0 018 21V11a1 1 0 011.4858-.8742l9 5a1 1 0 010 1.7485l-9 5a1.0009 1.0009 0 01-.9931-.0125z"
  })), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var SkipForwardOutlineSolid24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardOutlineSolid24(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 10H23V22H21zM8.4927 21.8618A1 1 0 018 21V11a1 1 0 011.4858-.8742l9 5a1 1 0 010 1.7485l-9 5a1.0009 1.0009 0 01-.9931-.0125z"
  })), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var SkipForwardOutlineSolid20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardOutlineSolid20(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 10H23V22H21zM8.4927 21.8618A1 1 0 018 21V11a1 1 0 011.4858-.8742l9 5a1 1 0 010 1.7485l-9 5a1.0009 1.0009 0 01-.9931-.0125z"
  })), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var SkipForwardOutlineSolid16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardOutlineSolid16(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 10H23V22H21zM8.4927 21.8618A1 1 0 018 21V11a1 1 0 011.4858-.8742l9 5a1 1 0 010 1.7485l-9 5a1.0009 1.0009 0 01-.9931-.0125z"
  })), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var SkipForwardSolidFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardSolidFilled32(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm2.4858,14.874-9,5A1,1,0,0,1,8,21V11a1,1,0,0,1,1.4858-.874l9,5a1,1,0,0,1,0,1.748ZM24,22H22V10h2Z"
  })), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M22 10H24V22H22zM8.4927 21.8618A1 1 0 018 21V11a1 1 0 011.4858-.8743l9 5a1 1 0 010 1.7486l-9 5a1.0009 1.0009 0 01-.9931-.0125z"
  })), children);
});
var SkipForwardSolidFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardSolidFilled24(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm2.4858,14.874-9,5A1,1,0,0,1,8,21V11a1,1,0,0,1,1.4858-.874l9,5a1,1,0,0,1,0,1.748ZM24,22H22V10h2Z"
  })), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M22 10H24V22H22zM8.4927 21.8618A1 1 0 018 21V11a1 1 0 011.4858-.8743l9 5a1 1 0 010 1.7486l-9 5a1.0009 1.0009 0 01-.9931-.0125z"
  })), children);
});
var SkipForwardSolidFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardSolidFilled20(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm2.4858,14.874-9,5A1,1,0,0,1,8,21V11a1,1,0,0,1,1.4858-.874l9,5a1,1,0,0,1,0,1.748ZM24,22H22V10h2Z"
  })), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M22 10H24V22H22zM8.4927 21.8618A1 1 0 018 21V11a1 1 0 011.4858-.8743l9 5a1 1 0 010 1.7486l-9 5a1.0009 1.0009 0 01-.9931-.0125z"
  })), children);
});
var SkipForwardSolidFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SkipForwardSolidFilled16(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm2.4858,14.874-9,5A1,1,0,0,1,8,21V11a1,1,0,0,1,1.4858-.874l9,5a1,1,0,0,1,0,1.748ZM24,22H22V10h2Z"
  })), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M22 10H24V22H22zM8.4927 21.8618A1 1 0 018 21V11a1 1 0 011.4858-.8743l9 5a1 1 0 010 1.7486l-9 5a1.0009 1.0009 0 01-.9931-.0125z"
  })), children);
});
var Sleet32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sleet32(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 24H8V26H6zM8 26H10V28H8zM10 28H12V30H10zM10 24H12V26H10zM6 28H8V30H6z"
  })), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 0121 30zM24.8008 9.1362a8.9943 8.9943 0 00-17.6006 0A6.4973 6.4973 0 008.5 22h8.8818L16.106 24.5527a1 1 0 101.7885.8946L19.6177 22H23.5A6.4974 6.4974 0 0024.8008 9.1362zM23.5 20H8.5a4.4975 4.4975 0 01-.356-8.981l.8155-.0639.0991-.812a6.9938 6.9938 0 0113.8838 0l.0986.812.8154.0639A4.4975 4.4975 0 0123.5 20z"
  })), children);
});
var Sleet24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sleet24(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 24H8V26H6zM8 26H10V28H8zM10 28H12V30H10zM10 24H12V26H10zM6 28H8V30H6z"
  })), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 0121 30zM24.8008 9.1362a8.9943 8.9943 0 00-17.6006 0A6.4973 6.4973 0 008.5 22h8.8818L16.106 24.5527a1 1 0 101.7885.8946L19.6177 22H23.5A6.4974 6.4974 0 0024.8008 9.1362zM23.5 20H8.5a4.4975 4.4975 0 01-.356-8.981l.8155-.0639.0991-.812a6.9938 6.9938 0 0113.8838 0l.0986.812.8154.0639A4.4975 4.4975 0 0123.5 20z"
  })), children);
});
var Sleet20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sleet20(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 24H8V26H6zM8 26H10V28H8zM10 28H12V30H10zM10 24H12V26H10zM6 28H8V30H6z"
  })), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 0121 30zM24.8008 9.1362a8.9943 8.9943 0 00-17.6006 0A6.4973 6.4973 0 008.5 22h8.8818L16.106 24.5527a1 1 0 101.7885.8946L19.6177 22H23.5A6.4974 6.4974 0 0024.8008 9.1362zM23.5 20H8.5a4.4975 4.4975 0 01-.356-8.981l.8155-.0639.0991-.812a6.9938 6.9938 0 0113.8838 0l.0986.812.8154.0639A4.4975 4.4975 0 0123.5 20z"
  })), children);
});
var Sleet16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sleet16(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 24H8V26H6zM8 26H10V28H8zM10 28H12V30H10zM10 24H12V26H10zM6 28H8V30H6z"
  })), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 0121 30zM24.8008 9.1362a8.9943 8.9943 0 00-17.6006 0A6.4973 6.4973 0 008.5 22h8.8818L16.106 24.5527a1 1 0 101.7885.8946L19.6177 22H23.5A6.4974 6.4974 0 0024.8008 9.1362zM23.5 20H8.5a4.4975 4.4975 0 01-.356-8.981l.8155-.0639.0991-.812a6.9938 6.9938 0 0113.8838 0l.0986.812.8154.0639A4.4975 4.4975 0 0123.5 20z"
  })), children);
});
var Slisor32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Slisor32(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H6V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a1.0005,1.0005,0,0,1-.4473-.1055l-10-5,.8946-1.789L16,19.8821l9.5527-4.7766.8946,1.789-10,5A1.0005,1.0005,0,0,1,16,22Z"
  })), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,16a1.0005,1.0005,0,0,1-.4473-.1055l-10-5a1,1,0,0,1,0-1.789l10-5a1.0008,1.0008,0,0,1,.8946,0l10,5a1,1,0,0,1,0,1.789l-10,5A1.0005,1.0005,0,0,1,16,16ZM8.2358,10,16,13.8821,23.7642,10,16,6.1179Z"
  })), children);
});
var Slisor24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Slisor24(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H6V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a1.0005,1.0005,0,0,1-.4473-.1055l-10-5,.8946-1.789L16,19.8821l9.5527-4.7766.8946,1.789-10,5A1.0005,1.0005,0,0,1,16,22Z"
  })), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,16a1.0005,1.0005,0,0,1-.4473-.1055l-10-5a1,1,0,0,1,0-1.789l10-5a1.0008,1.0008,0,0,1,.8946,0l10,5a1,1,0,0,1,0,1.789l-10,5A1.0005,1.0005,0,0,1,16,16ZM8.2358,10,16,13.8821,23.7642,10,16,6.1179Z"
  })), children);
});
var Slisor20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Slisor20(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H6V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a1.0005,1.0005,0,0,1-.4473-.1055l-10-5,.8946-1.789L16,19.8821l9.5527-4.7766.8946,1.789-10,5A1.0005,1.0005,0,0,1,16,22Z"
  })), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,16a1.0005,1.0005,0,0,1-.4473-.1055l-10-5a1,1,0,0,1,0-1.789l10-5a1.0008,1.0008,0,0,1,.8946,0l10,5a1,1,0,0,1,0,1.789l-10,5A1.0005,1.0005,0,0,1,16,16ZM8.2358,10,16,13.8821,23.7642,10,16,6.1179Z"
  })), children);
});
var Slisor16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Slisor16(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H6V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a1.0005,1.0005,0,0,1-.4473-.1055l-10-5,.8946-1.789L16,19.8821l9.5527-4.7766.8946,1.789-10,5A1.0005,1.0005,0,0,1,16,22Z"
  })), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,16a1.0005,1.0005,0,0,1-.4473-.1055l-10-5a1,1,0,0,1,0-1.789l10-5a1.0008,1.0008,0,0,1,.8946,0l10,5a1,1,0,0,1,0,1.789l-10,5A1.0005,1.0005,0,0,1,16,16ZM8.2358,10,16,13.8821,23.7642,10,16,6.1179Z"
  })), children);
});
var Smell32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Smell32(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,15V10H20v7h2a3,3,0,0,1,0,6H21V21H19v2a3,3,0,0,1-6,0V21H11v2H10a3,3,0,0,1,0-6h2V9a3,3,0,0,1,3-3h1V4H15a5,5,0,0,0-5,5v6a5,5,0,0,0,0,10h1.42a5,5,0,0,0,9.16,0H22a5,5,0,0,0,0-10Z"
  })), children);
});
var Smell24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Smell24(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,15V10H20v7h2a3,3,0,0,1,0,6H21V21H19v2a3,3,0,0,1-6,0V21H11v2H10a3,3,0,0,1,0-6h2V9a3,3,0,0,1,3-3h1V4H15a5,5,0,0,0-5,5v6a5,5,0,0,0,0,10h1.42a5,5,0,0,0,9.16,0H22a5,5,0,0,0,0-10Z"
  })), children);
});
var Smell20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Smell20(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,15V10H20v7h2a3,3,0,0,1,0,6H21V21H19v2a3,3,0,0,1-6,0V21H11v2H10a3,3,0,0,1,0-6h2V9a3,3,0,0,1,3-3h1V4H15a5,5,0,0,0-5,5v6a5,5,0,0,0,0,10h1.42a5,5,0,0,0,9.16,0H22a5,5,0,0,0,0-10Z"
  })), children);
});
var Smell16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Smell16(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,15V10H20v7h2a3,3,0,0,1,0,6H21V21H19v2a3,3,0,0,1-6,0V21H11v2H10a3,3,0,0,1,0-6h2V9a3,3,0,0,1,3-3h1V4H15a5,5,0,0,0-5,5v6a5,5,0,0,0,0,10h1.42a5,5,0,0,0,9.16,0H22a5,5,0,0,0,0-10Z"
  })), children);
});
var Smoke32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Smoke32(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.001 28a.998.998 0 01-.8008-.4l-.8145-1.086a8.9976 8.9976 0 01-1.6005-7.2856l1.4736-6.8762a6.9956 6.9956 0 00-1.2446-5.6668L23.2 5.6a1 1 0 111.6-1.2l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856l-1.4736 6.8762a6.9956 6.9956 0 001.2446 5.6668L27.8 26.4A1 1 0 0127.001 28zM22.001 28a.998.998 0 01-.8008-.4l-.8145-1.086a8.9976 8.9976 0 01-1.6005-7.2856l1.4736-6.8762a6.9956 6.9956 0 00-1.2446-5.6668L18.2 5.6a1 1 0 111.6-1.2l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856l-1.4736 6.8762a6.9956 6.9956 0 001.2446 5.6668L22.8 26.4A1 1 0 0122.001 28zM17.001 28a.998.998 0 01-.8008-.4l-.8145-1.086a8.9976 8.9976 0 01-1.6005-7.2856l1.4736-6.8762a6.9956 6.9956 0 00-1.2446-5.6668L13.2 5.6a1 1 0 111.6-1.2l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856l-1.4736 6.8762a6.9956 6.9956 0 001.2446 5.6668L17.8 26.4A1 1 0 0117.001 28zM12.001 28a.998.998 0 01-.8008-.4l-.8145-1.086a8.9976 8.9976 0 01-1.6005-7.2856l1.4736-6.8762A6.9956 6.9956 0 009.0142 6.6855L8.2 5.6A1 1 0 119.8 4.4l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856l-1.4736 6.8762a6.9956 6.9956 0 001.2446 5.6668L12.8 26.4A1 1 0 0112.001 28zM7.001 28A.998.998 0 016.2 27.6l-.8145-1.086a8.9976 8.9976 0 01-1.6-7.2856l1.4736-6.8762A6.9956 6.9956 0 004.0142 6.6855L3.2 5.6A1 1 0 114.8 4.4l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856L5.7412 19.6474a6.9956 6.9956 0 001.2446 5.6668L7.8 26.4A1 1 0 017.001 28z"
  })), children);
});
var Smoke24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Smoke24(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.001 28a.998.998 0 01-.8008-.4l-.8145-1.086a8.9976 8.9976 0 01-1.6005-7.2856l1.4736-6.8762a6.9956 6.9956 0 00-1.2446-5.6668L23.2 5.6a1 1 0 111.6-1.2l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856l-1.4736 6.8762a6.9956 6.9956 0 001.2446 5.6668L27.8 26.4A1 1 0 0127.001 28zM22.001 28a.998.998 0 01-.8008-.4l-.8145-1.086a8.9976 8.9976 0 01-1.6005-7.2856l1.4736-6.8762a6.9956 6.9956 0 00-1.2446-5.6668L18.2 5.6a1 1 0 111.6-1.2l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856l-1.4736 6.8762a6.9956 6.9956 0 001.2446 5.6668L22.8 26.4A1 1 0 0122.001 28zM17.001 28a.998.998 0 01-.8008-.4l-.8145-1.086a8.9976 8.9976 0 01-1.6005-7.2856l1.4736-6.8762a6.9956 6.9956 0 00-1.2446-5.6668L13.2 5.6a1 1 0 111.6-1.2l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856l-1.4736 6.8762a6.9956 6.9956 0 001.2446 5.6668L17.8 26.4A1 1 0 0117.001 28zM12.001 28a.998.998 0 01-.8008-.4l-.8145-1.086a8.9976 8.9976 0 01-1.6005-7.2856l1.4736-6.8762A6.9956 6.9956 0 009.0142 6.6855L8.2 5.6A1 1 0 119.8 4.4l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856l-1.4736 6.8762a6.9956 6.9956 0 001.2446 5.6668L12.8 26.4A1 1 0 0112.001 28zM7.001 28A.998.998 0 016.2 27.6l-.8145-1.086a8.9976 8.9976 0 01-1.6-7.2856l1.4736-6.8762A6.9956 6.9956 0 004.0142 6.6855L3.2 5.6A1 1 0 114.8 4.4l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856L5.7412 19.6474a6.9956 6.9956 0 001.2446 5.6668L7.8 26.4A1 1 0 017.001 28z"
  })), children);
});
var Smoke20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Smoke20(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.001 28a.998.998 0 01-.8008-.4l-.8145-1.086a8.9976 8.9976 0 01-1.6005-7.2856l1.4736-6.8762a6.9956 6.9956 0 00-1.2446-5.6668L23.2 5.6a1 1 0 111.6-1.2l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856l-1.4736 6.8762a6.9956 6.9956 0 001.2446 5.6668L27.8 26.4A1 1 0 0127.001 28zM22.001 28a.998.998 0 01-.8008-.4l-.8145-1.086a8.9976 8.9976 0 01-1.6005-7.2856l1.4736-6.8762a6.9956 6.9956 0 00-1.2446-5.6668L18.2 5.6a1 1 0 111.6-1.2l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856l-1.4736 6.8762a6.9956 6.9956 0 001.2446 5.6668L22.8 26.4A1 1 0 0122.001 28zM17.001 28a.998.998 0 01-.8008-.4l-.8145-1.086a8.9976 8.9976 0 01-1.6005-7.2856l1.4736-6.8762a6.9956 6.9956 0 00-1.2446-5.6668L13.2 5.6a1 1 0 111.6-1.2l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856l-1.4736 6.8762a6.9956 6.9956 0 001.2446 5.6668L17.8 26.4A1 1 0 0117.001 28zM12.001 28a.998.998 0 01-.8008-.4l-.8145-1.086a8.9976 8.9976 0 01-1.6005-7.2856l1.4736-6.8762A6.9956 6.9956 0 009.0142 6.6855L8.2 5.6A1 1 0 119.8 4.4l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856l-1.4736 6.8762a6.9956 6.9956 0 001.2446 5.6668L12.8 26.4A1 1 0 0112.001 28zM7.001 28A.998.998 0 016.2 27.6l-.8145-1.086a8.9976 8.9976 0 01-1.6-7.2856l1.4736-6.8762A6.9956 6.9956 0 004.0142 6.6855L3.2 5.6A1 1 0 114.8 4.4l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856L5.7412 19.6474a6.9956 6.9956 0 001.2446 5.6668L7.8 26.4A1 1 0 017.001 28z"
  })), children);
});
var Smoke16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Smoke16(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.001 28a.998.998 0 01-.8008-.4l-.8145-1.086a8.9976 8.9976 0 01-1.6005-7.2856l1.4736-6.8762a6.9956 6.9956 0 00-1.2446-5.6668L23.2 5.6a1 1 0 111.6-1.2l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856l-1.4736 6.8762a6.9956 6.9956 0 001.2446 5.6668L27.8 26.4A1 1 0 0127.001 28zM22.001 28a.998.998 0 01-.8008-.4l-.8145-1.086a8.9976 8.9976 0 01-1.6005-7.2856l1.4736-6.8762a6.9956 6.9956 0 00-1.2446-5.6668L18.2 5.6a1 1 0 111.6-1.2l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856l-1.4736 6.8762a6.9956 6.9956 0 001.2446 5.6668L22.8 26.4A1 1 0 0122.001 28zM17.001 28a.998.998 0 01-.8008-.4l-.8145-1.086a8.9976 8.9976 0 01-1.6005-7.2856l1.4736-6.8762a6.9956 6.9956 0 00-1.2446-5.6668L13.2 5.6a1 1 0 111.6-1.2l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856l-1.4736 6.8762a6.9956 6.9956 0 001.2446 5.6668L17.8 26.4A1 1 0 0117.001 28zM12.001 28a.998.998 0 01-.8008-.4l-.8145-1.086a8.9976 8.9976 0 01-1.6005-7.2856l1.4736-6.8762A6.9956 6.9956 0 009.0142 6.6855L8.2 5.6A1 1 0 119.8 4.4l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856l-1.4736 6.8762a6.9956 6.9956 0 001.2446 5.6668L12.8 26.4A1 1 0 0112.001 28zM7.001 28A.998.998 0 016.2 27.6l-.8145-1.086a8.9976 8.9976 0 01-1.6-7.2856l1.4736-6.8762A6.9956 6.9956 0 004.0142 6.6855L3.2 5.6A1 1 0 114.8 4.4l.8145 1.0857a8.9976 8.9976 0 011.6005 7.2856L5.7412 19.6474a6.9956 6.9956 0 001.2446 5.6668L7.8 26.4A1 1 0 017.001 28z"
  })), children);
});
var WatsonHealthSmoothing32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSmoothing32(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "5"
  })), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.7 4.7a14.7029 14.7029 0 00-3 3.1L6.3 9A13.2634 13.2634 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.5111 12.5111 0 002 16H4A11.4756 11.4756 0 014.6 12.3zM2.7 20.4a14.4029 14.4029 0 002 3.9l1.6-1.2a12.8867 12.8867 0 01-1.7-3.3zM7.8 27.3a14.4029 14.4029 0 003.9 2l.6-1.9A12.8867 12.8867 0 019 25.7zM11.7 2.7l.6 1.9A11.4756 11.4756 0 0116 4V2A12.5111 12.5111 0 0011.7 2.7zM24.2 27.3a15.18 15.18 0 003.1-3.1L25.7 23A11.526 11.526 0 0123 25.7zM27.4 19.7l1.9.6A15.4747 15.4747 0 0030 16H28A11.4756 11.4756 0 0127.4 19.7zM29.2 11.6a14.4029 14.4029 0 00-2-3.9L25.6 8.9a12.8867 12.8867 0 011.7 3.3zM24.1 4.6a14.4029 14.4029 0 00-3.9-2l-.6 1.9a12.8867 12.8867 0 013.3 1.7zM20.3 29.3l-.6-1.9A11.4756 11.4756 0 0116 28v2A21.4206 21.4206 0 0020.3 29.3z"
  })), children);
});
var WatsonHealthSmoothing24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSmoothing24(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "5"
  })), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.7 4.7a14.7029 14.7029 0 00-3 3.1L6.3 9A13.2634 13.2634 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.5111 12.5111 0 002 16H4A11.4756 11.4756 0 014.6 12.3zM2.7 20.4a14.4029 14.4029 0 002 3.9l1.6-1.2a12.8867 12.8867 0 01-1.7-3.3zM7.8 27.3a14.4029 14.4029 0 003.9 2l.6-1.9A12.8867 12.8867 0 019 25.7zM11.7 2.7l.6 1.9A11.4756 11.4756 0 0116 4V2A12.5111 12.5111 0 0011.7 2.7zM24.2 27.3a15.18 15.18 0 003.1-3.1L25.7 23A11.526 11.526 0 0123 25.7zM27.4 19.7l1.9.6A15.4747 15.4747 0 0030 16H28A11.4756 11.4756 0 0127.4 19.7zM29.2 11.6a14.4029 14.4029 0 00-2-3.9L25.6 8.9a12.8867 12.8867 0 011.7 3.3zM24.1 4.6a14.4029 14.4029 0 00-3.9-2l-.6 1.9a12.8867 12.8867 0 013.3 1.7zM20.3 29.3l-.6-1.9A11.4756 11.4756 0 0116 28v2A21.4206 21.4206 0 0020.3 29.3z"
  })), children);
});
var WatsonHealthSmoothing20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSmoothing20(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "5"
  })), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.7 4.7a14.7029 14.7029 0 00-3 3.1L6.3 9A13.2634 13.2634 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.5111 12.5111 0 002 16H4A11.4756 11.4756 0 014.6 12.3zM2.7 20.4a14.4029 14.4029 0 002 3.9l1.6-1.2a12.8867 12.8867 0 01-1.7-3.3zM7.8 27.3a14.4029 14.4029 0 003.9 2l.6-1.9A12.8867 12.8867 0 019 25.7zM11.7 2.7l.6 1.9A11.4756 11.4756 0 0116 4V2A12.5111 12.5111 0 0011.7 2.7zM24.2 27.3a15.18 15.18 0 003.1-3.1L25.7 23A11.526 11.526 0 0123 25.7zM27.4 19.7l1.9.6A15.4747 15.4747 0 0030 16H28A11.4756 11.4756 0 0127.4 19.7zM29.2 11.6a14.4029 14.4029 0 00-2-3.9L25.6 8.9a12.8867 12.8867 0 011.7 3.3zM24.1 4.6a14.4029 14.4029 0 00-3.9-2l-.6 1.9a12.8867 12.8867 0 013.3 1.7zM20.3 29.3l-.6-1.9A11.4756 11.4756 0 0116 28v2A21.4206 21.4206 0 0020.3 29.3z"
  })), children);
});
var WatsonHealthSmoothing16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSmoothing16(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "5"
  })), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.7 4.7a14.7029 14.7029 0 00-3 3.1L6.3 9A13.2634 13.2634 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.5111 12.5111 0 002 16H4A11.4756 11.4756 0 014.6 12.3zM2.7 20.4a14.4029 14.4029 0 002 3.9l1.6-1.2a12.8867 12.8867 0 01-1.7-3.3zM7.8 27.3a14.4029 14.4029 0 003.9 2l.6-1.9A12.8867 12.8867 0 019 25.7zM11.7 2.7l.6 1.9A11.4756 11.4756 0 0116 4V2A12.5111 12.5111 0 0011.7 2.7zM24.2 27.3a15.18 15.18 0 003.1-3.1L25.7 23A11.526 11.526 0 0123 25.7zM27.4 19.7l1.9.6A15.4747 15.4747 0 0030 16H28A11.4756 11.4756 0 0127.4 19.7zM29.2 11.6a14.4029 14.4029 0 00-2-3.9L25.6 8.9a12.8867 12.8867 0 011.7 3.3zM24.1 4.6a14.4029 14.4029 0 00-3.9-2l-.6 1.9a12.8867 12.8867 0 013.3 1.7zM20.3 29.3l-.6-1.9A11.4756 11.4756 0 0116 28v2A21.4206 21.4206 0 0020.3 29.3z"
  })), children);
});
var WatsonHealthSmoothingCursor32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSmoothingCursor32(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18",
    cy: "18",
    r: "4"
  })), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 30a11.8932 11.8932 0 01-4.1035-.72L14.58 27.4A9.9725 9.9725 0 0018 28zM22.1484 29.2637l-.6914-1.877a9.9556 9.9556 0 002.9973-1.748l1.2916 1.5268A11.9525 11.9525 0 0122.1484 29.2637zM10.2893 27.1951A12.0141 12.0141 0 017.61 24.0078l1.73-1.0029a10.0236 10.0236 0 002.2347 2.6584zM28.4133 23.967l-1.7343-.9956a9.9159 9.9159 0 001.176-3.2641l1.9712.3388A11.8956 11.8956 0 0128.4133 23.967zM6.1821 20.0925A12.1282 12.1282 0 016.1777 15.93l1.9707.3423a10.1214 10.1214 0 00.0035 3.4738zM27.8447 16.2339a9.9019 9.9019 0 00-1.1953-3.2564l1.7285-1.0063a11.9029 11.9029 0 011.4361 3.9121zM9.3313 13.0107l-1.7324-.999a12.01 12.01 0 012.6738-3.1931l1.2886 1.53A10.01 10.01 0 009.3313 13.0107zM24.4094 10.3237a9.96 9.96 0 00-3.0088-1.7309l.68-1.8809a11.9491 11.9491 0 013.6118 2.0772zM14.562 8.6064l-.6875-1.8779A12.1031 12.1031 0 0118 6V8A10.0875 10.0875 0 0014.562 8.6064zM11 2L2 2 2 11 4 11 4 4 11 4 11 2z"
  })), children);
});
var WatsonHealthSmoothingCursor24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSmoothingCursor24(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18",
    cy: "18",
    r: "4"
  })), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 30a11.8932 11.8932 0 01-4.1035-.72L14.58 27.4A9.9725 9.9725 0 0018 28zM22.1484 29.2637l-.6914-1.877a9.9556 9.9556 0 002.9973-1.748l1.2916 1.5268A11.9525 11.9525 0 0122.1484 29.2637zM10.2893 27.1951A12.0141 12.0141 0 017.61 24.0078l1.73-1.0029a10.0236 10.0236 0 002.2347 2.6584zM28.4133 23.967l-1.7343-.9956a9.9159 9.9159 0 001.176-3.2641l1.9712.3388A11.8956 11.8956 0 0128.4133 23.967zM6.1821 20.0925A12.1282 12.1282 0 016.1777 15.93l1.9707.3423a10.1214 10.1214 0 00.0035 3.4738zM27.8447 16.2339a9.9019 9.9019 0 00-1.1953-3.2564l1.7285-1.0063a11.9029 11.9029 0 011.4361 3.9121zM9.3313 13.0107l-1.7324-.999a12.01 12.01 0 012.6738-3.1931l1.2886 1.53A10.01 10.01 0 009.3313 13.0107zM24.4094 10.3237a9.96 9.96 0 00-3.0088-1.7309l.68-1.8809a11.9491 11.9491 0 013.6118 2.0772zM14.562 8.6064l-.6875-1.8779A12.1031 12.1031 0 0118 6V8A10.0875 10.0875 0 0014.562 8.6064zM11 2L2 2 2 11 4 11 4 4 11 4 11 2z"
  })), children);
});
var WatsonHealthSmoothingCursor20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSmoothingCursor20(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18",
    cy: "18",
    r: "4"
  })), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 30a11.8932 11.8932 0 01-4.1035-.72L14.58 27.4A9.9725 9.9725 0 0018 28zM22.1484 29.2637l-.6914-1.877a9.9556 9.9556 0 002.9973-1.748l1.2916 1.5268A11.9525 11.9525 0 0122.1484 29.2637zM10.2893 27.1951A12.0141 12.0141 0 017.61 24.0078l1.73-1.0029a10.0236 10.0236 0 002.2347 2.6584zM28.4133 23.967l-1.7343-.9956a9.9159 9.9159 0 001.176-3.2641l1.9712.3388A11.8956 11.8956 0 0128.4133 23.967zM6.1821 20.0925A12.1282 12.1282 0 016.1777 15.93l1.9707.3423a10.1214 10.1214 0 00.0035 3.4738zM27.8447 16.2339a9.9019 9.9019 0 00-1.1953-3.2564l1.7285-1.0063a11.9029 11.9029 0 011.4361 3.9121zM9.3313 13.0107l-1.7324-.999a12.01 12.01 0 012.6738-3.1931l1.2886 1.53A10.01 10.01 0 009.3313 13.0107zM24.4094 10.3237a9.96 9.96 0 00-3.0088-1.7309l.68-1.8809a11.9491 11.9491 0 013.6118 2.0772zM14.562 8.6064l-.6875-1.8779A12.1031 12.1031 0 0118 6V8A10.0875 10.0875 0 0014.562 8.6064zM11 2L2 2 2 11 4 11 4 4 11 4 11 2z"
  })), children);
});
var WatsonHealthSmoothingCursor16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSmoothingCursor16(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18",
    cy: "18",
    r: "4"
  })), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 30a11.8932 11.8932 0 01-4.1035-.72L14.58 27.4A9.9725 9.9725 0 0018 28zM22.1484 29.2637l-.6914-1.877a9.9556 9.9556 0 002.9973-1.748l1.2916 1.5268A11.9525 11.9525 0 0122.1484 29.2637zM10.2893 27.1951A12.0141 12.0141 0 017.61 24.0078l1.73-1.0029a10.0236 10.0236 0 002.2347 2.6584zM28.4133 23.967l-1.7343-.9956a9.9159 9.9159 0 001.176-3.2641l1.9712.3388A11.8956 11.8956 0 0128.4133 23.967zM6.1821 20.0925A12.1282 12.1282 0 016.1777 15.93l1.9707.3423a10.1214 10.1214 0 00.0035 3.4738zM27.8447 16.2339a9.9019 9.9019 0 00-1.1953-3.2564l1.7285-1.0063a11.9029 11.9029 0 011.4361 3.9121zM9.3313 13.0107l-1.7324-.999a12.01 12.01 0 012.6738-3.1931l1.2886 1.53A10.01 10.01 0 009.3313 13.0107zM24.4094 10.3237a9.96 9.96 0 00-3.0088-1.7309l.68-1.8809a11.9491 11.9491 0 013.6118 2.0772zM14.562 8.6064l-.6875-1.8779A12.1031 12.1031 0 0118 6V8A10.0875 10.0875 0 0014.562 8.6064zM11 2L2 2 2 11 4 11 4 4 11 4 11 2z"
  })), children);
});
var Snooze32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Snooze32(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 14L20 12 12 12 12 14 17.5 14 12 20 12 22 20 22 20 20 14.507 20 20 14z"
  })), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 3.965H26.499V9.036999999999999H24.5z",
    transform: "rotate(-44.945 25.5 6.5)"
  })), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A11,11,0,1,1,27,17,11.0125,11.0125,0,0,1,16,28ZM16,8a9,9,0,1,0,9,9A9.01,9.01,0,0,0,16,8Z"
  })), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.965 5.501H9.036999999999999V7.5H3.965z",
    transform: "rotate(-45.055 6.5 6.5)"
  })), children);
});
var Snooze24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Snooze24(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 14L20 12 12 12 12 14 17.5 14 12 20 12 22 20 22 20 20 14.507 20 20 14z"
  })), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 3.965H26.499V9.036999999999999H24.5z",
    transform: "rotate(-44.945 25.5 6.5)"
  })), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A11,11,0,1,1,27,17,11.0125,11.0125,0,0,1,16,28ZM16,8a9,9,0,1,0,9,9A9.01,9.01,0,0,0,16,8Z"
  })), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.965 5.501H9.036999999999999V7.5H3.965z",
    transform: "rotate(-45.055 6.5 6.5)"
  })), children);
});
var Snooze20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Snooze20(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 14L20 12 12 12 12 14 17.5 14 12 20 12 22 20 22 20 20 14.507 20 20 14z"
  })), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 3.965H26.499V9.036999999999999H24.5z",
    transform: "rotate(-44.945 25.5 6.5)"
  })), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A11,11,0,1,1,27,17,11.0125,11.0125,0,0,1,16,28ZM16,8a9,9,0,1,0,9,9A9.01,9.01,0,0,0,16,8Z"
  })), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.965 5.501H9.036999999999999V7.5H3.965z",
    transform: "rotate(-45.055 6.5 6.5)"
  })), children);
});
var Snooze16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Snooze16(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 14L20 12 12 12 12 14 17.5 14 12 20 12 22 20 22 20 20 14.507 20 20 14z"
  })), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 3.965H26.499V9.036999999999999H24.5z",
    transform: "rotate(-44.945 25.5 6.5)"
  })), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A11,11,0,1,1,27,17,11.0125,11.0125,0,0,1,16,28ZM16,8a9,9,0,1,0,9,9A9.01,9.01,0,0,0,16,8Z"
  })), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3.965 5.501H9.036999999999999V7.5H3.965z",
    transform: "rotate(-45.055 6.5 6.5)"
  })), children);
});
var Snow32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Snow32(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 22H8.5A6.5 6.5 0 017.2 9.14a9 9 0 0117.6 0A6.5 6.5 0 0123.5 22zM16 4a7 7 0 00-6.94 6.14L9 11 8.14 11a4.5 4.5 0 00.36 9h15a4.5 4.5 0 00.36-9L23 11l-.1-.82A7 7 0 0016 4zM12 25.05L10.95 24 9.5 25.45 8.05 24 7 25.05 8.45 26.5 7 27.95 8.05 29 9.5 27.55 10.95 29 12 27.95 10.55 26.5 12 25.05zM26 25.05L24.95 24 23.5 25.45 22.05 24 21 25.05 22.45 26.5 21 27.95 22.05 29 23.5 27.55 24.95 29 26 27.95 24.55 26.5 26 25.05zM19 27.05L17.95 26 16.5 27.45 15.05 26 14 27.05 15.45 28.5 14 29.95 15.05 31 16.5 29.55 17.95 31 19 29.95 17.55 28.5 19 27.05z"
  })), children);
});
var Snow24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Snow24(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 22H8.5A6.5 6.5 0 017.2 9.14a9 9 0 0117.6 0A6.5 6.5 0 0123.5 22zM16 4a7 7 0 00-6.94 6.14L9 11 8.14 11a4.5 4.5 0 00.36 9h15a4.5 4.5 0 00.36-9L23 11l-.1-.82A7 7 0 0016 4zM12 25.05L10.95 24 9.5 25.45 8.05 24 7 25.05 8.45 26.5 7 27.95 8.05 29 9.5 27.55 10.95 29 12 27.95 10.55 26.5 12 25.05zM26 25.05L24.95 24 23.5 25.45 22.05 24 21 25.05 22.45 26.5 21 27.95 22.05 29 23.5 27.55 24.95 29 26 27.95 24.55 26.5 26 25.05zM19 27.05L17.95 26 16.5 27.45 15.05 26 14 27.05 15.45 28.5 14 29.95 15.05 31 16.5 29.55 17.95 31 19 29.95 17.55 28.5 19 27.05z"
  })), children);
});
var Snow20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Snow20(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 22H8.5A6.5 6.5 0 017.2 9.14a9 9 0 0117.6 0A6.5 6.5 0 0123.5 22zM16 4a7 7 0 00-6.94 6.14L9 11 8.14 11a4.5 4.5 0 00.36 9h15a4.5 4.5 0 00.36-9L23 11l-.1-.82A7 7 0 0016 4zM12 25.05L10.95 24 9.5 25.45 8.05 24 7 25.05 8.45 26.5 7 27.95 8.05 29 9.5 27.55 10.95 29 12 27.95 10.55 26.5 12 25.05zM26 25.05L24.95 24 23.5 25.45 22.05 24 21 25.05 22.45 26.5 21 27.95 22.05 29 23.5 27.55 24.95 29 26 27.95 24.55 26.5 26 25.05zM19 27.05L17.95 26 16.5 27.45 15.05 26 14 27.05 15.45 28.5 14 29.95 15.05 31 16.5 29.55 17.95 31 19 29.95 17.55 28.5 19 27.05z"
  })), children);
});
var Snow16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Snow16(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 22H8.5A6.5 6.5 0 017.2 9.14a9 9 0 0117.6 0A6.5 6.5 0 0123.5 22zM16 4a7 7 0 00-6.94 6.14L9 11 8.14 11a4.5 4.5 0 00.36 9h15a4.5 4.5 0 00.36-9L23 11l-.1-.82A7 7 0 0016 4zM12 25.05L10.95 24 9.5 25.45 8.05 24 7 25.05 8.45 26.5 7 27.95 8.05 29 9.5 27.55 10.95 29 12 27.95 10.55 26.5 12 25.05zM26 25.05L24.95 24 23.5 25.45 22.05 24 21 25.05 22.45 26.5 21 27.95 22.05 29 23.5 27.55 24.95 29 26 27.95 24.55 26.5 26 25.05zM19 27.05L17.95 26 16.5 27.45 15.05 26 14 27.05 15.45 28.5 14 29.95 15.05 31 16.5 29.55 17.95 31 19 29.95 17.55 28.5 19 27.05z"
  })), children);
});
var SnowBlizzard32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowBlizzard32(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 10H15V12H13zM15 12H17V14H15zM17 14H19V16H17zM17 10H19V12H17zM13 14H15V16H13zM3 26H5V28H3zM5 28H7V30H5zM7 30H9V32H7zM7 26H9V28H7zM3 30H5V32H3zM23 26H25V28H23zM25 28H27V30H25zM27 30H29V32H27zM27 26H29V28H27zM23 30H25V32H23zM8 18H10V20H8zM10 20H12V22H10zM12 22H14V24H12zM12 18H14V20H12zM8 22H10V24H8zM18 18H20V20H18zM20 20H22V22H20zM22 22H24V24H22zM22 18H24V20H22zM18 22H20V24H18zM13 26H15V28H13zM15 28H17V30H15zM17 30H19V32H17zM17 26H19V28H17zM13 30H15V32H13z"
  })), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0A6.4957,6.4957,0,0,0,6,21.4985v-2.26A4.4943,4.4943,0,0,1,8.144,11.019l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4944,4.4944,0,0,1,26,19.2383v2.26A6.4958,6.4958,0,0,0,24.8008,9.1362Z"
  })), children);
});
var SnowBlizzard24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowBlizzard24(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 10H15V12H13zM15 12H17V14H15zM17 14H19V16H17zM17 10H19V12H17zM13 14H15V16H13zM3 26H5V28H3zM5 28H7V30H5zM7 30H9V32H7zM7 26H9V28H7zM3 30H5V32H3zM23 26H25V28H23zM25 28H27V30H25zM27 30H29V32H27zM27 26H29V28H27zM23 30H25V32H23zM8 18H10V20H8zM10 20H12V22H10zM12 22H14V24H12zM12 18H14V20H12zM8 22H10V24H8zM18 18H20V20H18zM20 20H22V22H20zM22 22H24V24H22zM22 18H24V20H22zM18 22H20V24H18zM13 26H15V28H13zM15 28H17V30H15zM17 30H19V32H17zM17 26H19V28H17zM13 30H15V32H13z"
  })), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0A6.4957,6.4957,0,0,0,6,21.4985v-2.26A4.4943,4.4943,0,0,1,8.144,11.019l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4944,4.4944,0,0,1,26,19.2383v2.26A6.4958,6.4958,0,0,0,24.8008,9.1362Z"
  })), children);
});
var SnowBlizzard20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowBlizzard20(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 10H15V12H13zM15 12H17V14H15zM17 14H19V16H17zM17 10H19V12H17zM13 14H15V16H13zM3 26H5V28H3zM5 28H7V30H5zM7 30H9V32H7zM7 26H9V28H7zM3 30H5V32H3zM23 26H25V28H23zM25 28H27V30H25zM27 30H29V32H27zM27 26H29V28H27zM23 30H25V32H23zM8 18H10V20H8zM10 20H12V22H10zM12 22H14V24H12zM12 18H14V20H12zM8 22H10V24H8zM18 18H20V20H18zM20 20H22V22H20zM22 22H24V24H22zM22 18H24V20H22zM18 22H20V24H18zM13 26H15V28H13zM15 28H17V30H15zM17 30H19V32H17zM17 26H19V28H17zM13 30H15V32H13z"
  })), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0A6.4957,6.4957,0,0,0,6,21.4985v-2.26A4.4943,4.4943,0,0,1,8.144,11.019l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4944,4.4944,0,0,1,26,19.2383v2.26A6.4958,6.4958,0,0,0,24.8008,9.1362Z"
  })), children);
});
var SnowBlizzard16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowBlizzard16(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 10H15V12H13zM15 12H17V14H15zM17 14H19V16H17zM17 10H19V12H17zM13 14H15V16H13zM3 26H5V28H3zM5 28H7V30H5zM7 30H9V32H7zM7 26H9V28H7zM3 30H5V32H3zM23 26H25V28H23zM25 28H27V30H25zM27 30H29V32H27zM27 26H29V28H27zM23 30H25V32H23zM8 18H10V20H8zM10 20H12V22H10zM12 22H14V24H12zM12 18H14V20H12zM8 22H10V24H8zM18 18H20V20H18zM20 20H22V22H20zM22 22H24V24H22zM22 18H24V20H22zM18 22H20V24H18zM13 26H15V28H13zM15 28H17V30H15zM17 30H19V32H17zM17 26H19V28H17zM13 30H15V32H13z"
  })), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0A6.4957,6.4957,0,0,0,6,21.4985v-2.26A4.4943,4.4943,0,0,1,8.144,11.019l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4944,4.4944,0,0,1,26,19.2383v2.26A6.4958,6.4958,0,0,0,24.8008,9.1362Z"
  })), children);
});
var SnowHeavy32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowHeavy32(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H6V28H4zM6 28H8V30H6zM8 30H10V32H8zM8 26H10V28H8zM4 30H6V32H4zM8 18H10V20H8zM10 20H12V22H10zM12 22H14V24H12zM12 18H14V20H12zM8 22H10V24H8zM18 18H20V20H18zM20 20H22V22H20zM22 22H24V24H22zM22 18H24V20H22zM18 22H20V24H18zM14 26H16V28H14zM16 28H18V30H16zM18 30H20V32H18zM18 26H20V28H18zM14 30H16V32H14z"
  })), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0A6.4957,6.4957,0,0,0,6,21.4985v-2.26A4.4943,4.4943,0,0,1,8.144,11.019l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4944,4.4944,0,0,1,26,19.2383v2.26A6.4958,6.4958,0,0,0,24.8008,9.1362Z"
  })), children);
});
var SnowHeavy24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowHeavy24(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H6V28H4zM6 28H8V30H6zM8 30H10V32H8zM8 26H10V28H8zM4 30H6V32H4zM8 18H10V20H8zM10 20H12V22H10zM12 22H14V24H12zM12 18H14V20H12zM8 22H10V24H8zM18 18H20V20H18zM20 20H22V22H20zM22 22H24V24H22zM22 18H24V20H22zM18 22H20V24H18zM14 26H16V28H14zM16 28H18V30H16zM18 30H20V32H18zM18 26H20V28H18zM14 30H16V32H14z"
  })), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0A6.4957,6.4957,0,0,0,6,21.4985v-2.26A4.4943,4.4943,0,0,1,8.144,11.019l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4944,4.4944,0,0,1,26,19.2383v2.26A6.4958,6.4958,0,0,0,24.8008,9.1362Z"
  })), children);
});
var SnowHeavy20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowHeavy20(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H6V28H4zM6 28H8V30H6zM8 30H10V32H8zM8 26H10V28H8zM4 30H6V32H4zM8 18H10V20H8zM10 20H12V22H10zM12 22H14V24H12zM12 18H14V20H12zM8 22H10V24H8zM18 18H20V20H18zM20 20H22V22H20zM22 22H24V24H22zM22 18H24V20H22zM18 22H20V24H18zM14 26H16V28H14zM16 28H18V30H16zM18 30H20V32H18zM18 26H20V28H18zM14 30H16V32H14z"
  })), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0A6.4957,6.4957,0,0,0,6,21.4985v-2.26A4.4943,4.4943,0,0,1,8.144,11.019l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4944,4.4944,0,0,1,26,19.2383v2.26A6.4958,6.4958,0,0,0,24.8008,9.1362Z"
  })), children);
});
var SnowHeavy16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowHeavy16(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H6V28H4zM6 28H8V30H6zM8 30H10V32H8zM8 26H10V28H8zM4 30H6V32H4zM8 18H10V20H8zM10 20H12V22H10zM12 22H14V24H12zM12 18H14V20H12zM8 22H10V24H8zM18 18H20V20H18zM20 20H22V22H20zM22 22H24V24H22zM22 18H24V20H22zM18 22H20V24H18zM14 26H16V28H14zM16 28H18V30H16zM18 30H20V32H18zM18 26H20V28H18zM14 30H16V32H14z"
  })), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0A6.4957,6.4957,0,0,0,6,21.4985v-2.26A4.4943,4.4943,0,0,1,8.144,11.019l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4944,4.4944,0,0,1,26,19.2383v2.26A6.4958,6.4958,0,0,0,24.8008,9.1362Z"
  })), children);
});
var SnowScattered32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowScattered32(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26H4V28H2zM4 28H6V30H4zM6 30H8V32H6zM6 26H8V28H6zM2 30H4V32H2zM20 26H22V28H20zM22 28H24V30H22zM24 30H26V32H24zM24 26H26V28H24zM20 30H22V32H20zM11 26H13V28H11zM13 28H15V30H13zM15 30H17V32H15zM15 26H17V28H15zM11 30H13V32H11zM20 0H22V3H20zM29 10.001H32V12.001H29z"
  })), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 3.768H29.732V5.768H26.732z",
    transform: "rotate(-45 28.232 4.768)"
  })), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 16.233H29.732V18.233H26.732z",
    transform: "rotate(-135 28.232 17.233)"
  })), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.268 3.768H15.268V5.768H12.268z",
    transform: "rotate(-135 13.768 4.768)"
  })), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,11A5.9852,5.9852,0,0,0,16.1431,7.5083,7.3737,7.3737,0,0,0,13.5,7a7.5511,7.5511,0,0,0-7.1494,5.2441A5.9926,5.9926,0,0,0,8,24H19a5.9672,5.9672,0,0,0,5.5667-8.2A5.9722,5.9722,0,0,0,27,11ZM19,22H8a3.9926,3.9926,0,0,1-.6733-7.9292l.663-.1128.1456-.6562a5.496,5.496,0,0,1,10.7294,0l.1456.6562.6626.1128A3.9925,3.9925,0,0,1,19,22Zm4.5222-7.9131a5.9592,5.9592,0,0,0-2.8728-1.8428,7.5212,7.5212,0,0,0-2.7224-3.78,3.9869,3.9869,0,1,1,5.5952,5.6225Z"
  })), children);
});
var SnowScattered24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowScattered24(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26H4V28H2zM4 28H6V30H4zM6 30H8V32H6zM6 26H8V28H6zM2 30H4V32H2zM20 26H22V28H20zM22 28H24V30H22zM24 30H26V32H24zM24 26H26V28H24zM20 30H22V32H20zM11 26H13V28H11zM13 28H15V30H13zM15 30H17V32H15zM15 26H17V28H15zM11 30H13V32H11zM20 0H22V3H20zM29 10.001H32V12.001H29z"
  })), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 3.768H29.732V5.768H26.732z",
    transform: "rotate(-45 28.232 4.768)"
  })), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 16.233H29.732V18.233H26.732z",
    transform: "rotate(-135 28.232 17.233)"
  })), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.268 3.768H15.268V5.768H12.268z",
    transform: "rotate(-135 13.768 4.768)"
  })), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,11A5.9852,5.9852,0,0,0,16.1431,7.5083,7.3737,7.3737,0,0,0,13.5,7a7.5511,7.5511,0,0,0-7.1494,5.2441A5.9926,5.9926,0,0,0,8,24H19a5.9672,5.9672,0,0,0,5.5667-8.2A5.9722,5.9722,0,0,0,27,11ZM19,22H8a3.9926,3.9926,0,0,1-.6733-7.9292l.663-.1128.1456-.6562a5.496,5.496,0,0,1,10.7294,0l.1456.6562.6626.1128A3.9925,3.9925,0,0,1,19,22Zm4.5222-7.9131a5.9592,5.9592,0,0,0-2.8728-1.8428,7.5212,7.5212,0,0,0-2.7224-3.78,3.9869,3.9869,0,1,1,5.5952,5.6225Z"
  })), children);
});
var SnowScattered20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowScattered20(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26H4V28H2zM4 28H6V30H4zM6 30H8V32H6zM6 26H8V28H6zM2 30H4V32H2zM20 26H22V28H20zM22 28H24V30H22zM24 30H26V32H24zM24 26H26V28H24zM20 30H22V32H20zM11 26H13V28H11zM13 28H15V30H13zM15 30H17V32H15zM15 26H17V28H15zM11 30H13V32H11zM20 0H22V3H20zM29 10.001H32V12.001H29z"
  })), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 3.768H29.732V5.768H26.732z",
    transform: "rotate(-45 28.232 4.768)"
  })), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 16.233H29.732V18.233H26.732z",
    transform: "rotate(-135 28.232 17.233)"
  })), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.268 3.768H15.268V5.768H12.268z",
    transform: "rotate(-135 13.768 4.768)"
  })), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,11A5.9852,5.9852,0,0,0,16.1431,7.5083,7.3737,7.3737,0,0,0,13.5,7a7.5511,7.5511,0,0,0-7.1494,5.2441A5.9926,5.9926,0,0,0,8,24H19a5.9672,5.9672,0,0,0,5.5667-8.2A5.9722,5.9722,0,0,0,27,11ZM19,22H8a3.9926,3.9926,0,0,1-.6733-7.9292l.663-.1128.1456-.6562a5.496,5.496,0,0,1,10.7294,0l.1456.6562.6626.1128A3.9925,3.9925,0,0,1,19,22Zm4.5222-7.9131a5.9592,5.9592,0,0,0-2.8728-1.8428,7.5212,7.5212,0,0,0-2.7224-3.78,3.9869,3.9869,0,1,1,5.5952,5.6225Z"
  })), children);
});
var SnowScattered16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowScattered16(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26H4V28H2zM4 28H6V30H4zM6 30H8V32H6zM6 26H8V28H6zM2 30H4V32H2zM20 26H22V28H20zM22 28H24V30H22zM24 30H26V32H24zM24 26H26V28H24zM20 30H22V32H20zM11 26H13V28H11zM13 28H15V30H13zM15 30H17V32H15zM15 26H17V28H15zM11 30H13V32H11zM20 0H22V3H20zM29 10.001H32V12.001H29z"
  })), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 3.768H29.732V5.768H26.732z",
    transform: "rotate(-45 28.232 4.768)"
  })), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 16.233H29.732V18.233H26.732z",
    transform: "rotate(-135 28.232 17.233)"
  })), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.268 3.768H15.268V5.768H12.268z",
    transform: "rotate(-135 13.768 4.768)"
  })), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,11A5.9852,5.9852,0,0,0,16.1431,7.5083,7.3737,7.3737,0,0,0,13.5,7a7.5511,7.5511,0,0,0-7.1494,5.2441A5.9926,5.9926,0,0,0,8,24H19a5.9672,5.9672,0,0,0,5.5667-8.2A5.9722,5.9722,0,0,0,27,11ZM19,22H8a3.9926,3.9926,0,0,1-.6733-7.9292l.663-.1128.1456-.6562a5.496,5.496,0,0,1,10.7294,0l.1456.6562.6626.1128A3.9925,3.9925,0,0,1,19,22Zm4.5222-7.9131a5.9592,5.9592,0,0,0-2.8728-1.8428,7.5212,7.5212,0,0,0-2.7224-3.78,3.9869,3.9869,0,1,1,5.5952,5.6225Z"
  })), children);
});
var SnowScatteredNight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowScatteredNight32(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26H4V28H2zM4 28H6V30H4zM6 30H8V32H6zM6 26H8V28H6zM2 30H4V32H2zM20 26H22V28H20zM22 28H24V30H22zM24 30H26V32H24zM24 26H26V28H24zM20 30H22V32H20zM11 26H13V28H11zM13 28H15V30H13zM15 30H17V32H15zM15 26H17V28H15zM11 30H13V32H11zM29.8439 13.0347a1.517 1.517 0 00-1.23-.8658 5.3552 5.3552 0 01-3.4095-1.7158 6.4655 6.4655 0 01-1.286-6.3926 1.6025 1.6025 0 00-.2989-1.5459 1.4543 1.4543 0 00-1.36-.4931l-.0191.0039a7.7685 7.7685 0 00-5.8847 5.5737A7.3706 7.3706 0 0013.5 7a7.5511 7.5511 0 00-7.1494 5.2441A5.9926 5.9926 0 008 24H19a6.0066 6.0066 0 006-6c0-.0571-.0123-.1113-.0139-.1685a7.5076 7.5076 0 004.7611-3.2768A1.5369 1.5369 0 0029.8439 13.0347zM19 22H8a3.9926 3.9926 0 01-.6733-7.9292l.663-.1128.1456-.6562a5.496 5.496 0 0110.7294 0l.1456.6562.6626.1128A3.9925 3.9925 0 0119 22zm5.5974-6.1289a5.9661 5.9661 0 00-3.948-3.627 7.49 7.49 0 00-2.489-3.58 5.9018 5.9018 0 013.6381-4.4473 8.4577 8.4577 0 001.94 7.5967A7.4007 7.4007 0 0027.64 14.041 5.4487 5.4487 0 0124.5974 15.8711z"
  })), children);
});
var SnowScatteredNight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowScatteredNight24(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26H4V28H2zM4 28H6V30H4zM6 30H8V32H6zM6 26H8V28H6zM2 30H4V32H2zM20 26H22V28H20zM22 28H24V30H22zM24 30H26V32H24zM24 26H26V28H24zM20 30H22V32H20zM11 26H13V28H11zM13 28H15V30H13zM15 30H17V32H15zM15 26H17V28H15zM11 30H13V32H11zM29.8439 13.0347a1.517 1.517 0 00-1.23-.8658 5.3552 5.3552 0 01-3.4095-1.7158 6.4655 6.4655 0 01-1.286-6.3926 1.6025 1.6025 0 00-.2989-1.5459 1.4543 1.4543 0 00-1.36-.4931l-.0191.0039a7.7685 7.7685 0 00-5.8847 5.5737A7.3706 7.3706 0 0013.5 7a7.5511 7.5511 0 00-7.1494 5.2441A5.9926 5.9926 0 008 24H19a6.0066 6.0066 0 006-6c0-.0571-.0123-.1113-.0139-.1685a7.5076 7.5076 0 004.7611-3.2768A1.5369 1.5369 0 0029.8439 13.0347zM19 22H8a3.9926 3.9926 0 01-.6733-7.9292l.663-.1128.1456-.6562a5.496 5.496 0 0110.7294 0l.1456.6562.6626.1128A3.9925 3.9925 0 0119 22zm5.5974-6.1289a5.9661 5.9661 0 00-3.948-3.627 7.49 7.49 0 00-2.489-3.58 5.9018 5.9018 0 013.6381-4.4473 8.4577 8.4577 0 001.94 7.5967A7.4007 7.4007 0 0027.64 14.041 5.4487 5.4487 0 0124.5974 15.8711z"
  })), children);
});
var SnowScatteredNight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowScatteredNight20(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26H4V28H2zM4 28H6V30H4zM6 30H8V32H6zM6 26H8V28H6zM2 30H4V32H2zM20 26H22V28H20zM22 28H24V30H22zM24 30H26V32H24zM24 26H26V28H24zM20 30H22V32H20zM11 26H13V28H11zM13 28H15V30H13zM15 30H17V32H15zM15 26H17V28H15zM11 30H13V32H11zM29.8439 13.0347a1.517 1.517 0 00-1.23-.8658 5.3552 5.3552 0 01-3.4095-1.7158 6.4655 6.4655 0 01-1.286-6.3926 1.6025 1.6025 0 00-.2989-1.5459 1.4543 1.4543 0 00-1.36-.4931l-.0191.0039a7.7685 7.7685 0 00-5.8847 5.5737A7.3706 7.3706 0 0013.5 7a7.5511 7.5511 0 00-7.1494 5.2441A5.9926 5.9926 0 008 24H19a6.0066 6.0066 0 006-6c0-.0571-.0123-.1113-.0139-.1685a7.5076 7.5076 0 004.7611-3.2768A1.5369 1.5369 0 0029.8439 13.0347zM19 22H8a3.9926 3.9926 0 01-.6733-7.9292l.663-.1128.1456-.6562a5.496 5.496 0 0110.7294 0l.1456.6562.6626.1128A3.9925 3.9925 0 0119 22zm5.5974-6.1289a5.9661 5.9661 0 00-3.948-3.627 7.49 7.49 0 00-2.489-3.58 5.9018 5.9018 0 013.6381-4.4473 8.4577 8.4577 0 001.94 7.5967A7.4007 7.4007 0 0027.64 14.041 5.4487 5.4487 0 0124.5974 15.8711z"
  })), children);
});
var SnowScatteredNight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowScatteredNight16(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 26H4V28H2zM4 28H6V30H4zM6 30H8V32H6zM6 26H8V28H6zM2 30H4V32H2zM20 26H22V28H20zM22 28H24V30H22zM24 30H26V32H24zM24 26H26V28H24zM20 30H22V32H20zM11 26H13V28H11zM13 28H15V30H13zM15 30H17V32H15zM15 26H17V28H15zM11 30H13V32H11zM29.8439 13.0347a1.517 1.517 0 00-1.23-.8658 5.3552 5.3552 0 01-3.4095-1.7158 6.4655 6.4655 0 01-1.286-6.3926 1.6025 1.6025 0 00-.2989-1.5459 1.4543 1.4543 0 00-1.36-.4931l-.0191.0039a7.7685 7.7685 0 00-5.8847 5.5737A7.3706 7.3706 0 0013.5 7a7.5511 7.5511 0 00-7.1494 5.2441A5.9926 5.9926 0 008 24H19a6.0066 6.0066 0 006-6c0-.0571-.0123-.1113-.0139-.1685a7.5076 7.5076 0 004.7611-3.2768A1.5369 1.5369 0 0029.8439 13.0347zM19 22H8a3.9926 3.9926 0 01-.6733-7.9292l.663-.1128.1456-.6562a5.496 5.496 0 0110.7294 0l.1456.6562.6626.1128A3.9925 3.9925 0 0119 22zm5.5974-6.1289a5.9661 5.9661 0 00-3.948-3.627 7.49 7.49 0 00-2.489-3.58 5.9018 5.9018 0 013.6381-4.4473 8.4577 8.4577 0 001.94 7.5967A7.4007 7.4007 0 0027.64 14.041 5.4487 5.4487 0 0124.5974 15.8711z"
  })), children);
});
var SnowDensity32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowDensity32(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28a9.0114,9.0114,0,0,1-9-9,9.9843,9.9843,0,0,1,1.4941-4.9554L15.1528,3.4367a1.04,1.04,0,0,1,1.6944,0l6.6289,10.5564A10.0633,10.0633,0,0,1,25,19,9.0114,9.0114,0,0,1,16,28ZM16,5.8483l-5.7817,9.2079A7.9771,7.9771,0,0,0,9,19a7,7,0,0,0,14,0,8.0615,8.0615,0,0,0-1.248-3.9953Z"
  })), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.6 16.8L19.4 15.2 17 17 17 14 15 14 15 17 12.6 15.2 11.4 16.8 14.333 19 11.4 21.2 12.6 22.8 15 21 15 24 17 24 17 21 19.4 22.8 20.6 21.2 17.667 19 20.6 16.8z"
  })), children);
});
var SnowDensity24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowDensity24(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28a9.0114,9.0114,0,0,1-9-9,9.9843,9.9843,0,0,1,1.4941-4.9554L15.1528,3.4367a1.04,1.04,0,0,1,1.6944,0l6.6289,10.5564A10.0633,10.0633,0,0,1,25,19,9.0114,9.0114,0,0,1,16,28ZM16,5.8483l-5.7817,9.2079A7.9771,7.9771,0,0,0,9,19a7,7,0,0,0,14,0,8.0615,8.0615,0,0,0-1.248-3.9953Z"
  })), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.6 16.8L19.4 15.2 17 17 17 14 15 14 15 17 12.6 15.2 11.4 16.8 14.333 19 11.4 21.2 12.6 22.8 15 21 15 24 17 24 17 21 19.4 22.8 20.6 21.2 17.667 19 20.6 16.8z"
  })), children);
});
var SnowDensity20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowDensity20(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28a9.0114,9.0114,0,0,1-9-9,9.9843,9.9843,0,0,1,1.4941-4.9554L15.1528,3.4367a1.04,1.04,0,0,1,1.6944,0l6.6289,10.5564A10.0633,10.0633,0,0,1,25,19,9.0114,9.0114,0,0,1,16,28ZM16,5.8483l-5.7817,9.2079A7.9771,7.9771,0,0,0,9,19a7,7,0,0,0,14,0,8.0615,8.0615,0,0,0-1.248-3.9953Z"
  })), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.6 16.8L19.4 15.2 17 17 17 14 15 14 15 17 12.6 15.2 11.4 16.8 14.333 19 11.4 21.2 12.6 22.8 15 21 15 24 17 24 17 21 19.4 22.8 20.6 21.2 17.667 19 20.6 16.8z"
  })), children);
});
var SnowDensity16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SnowDensity16(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28a9.0114,9.0114,0,0,1-9-9,9.9843,9.9843,0,0,1,1.4941-4.9554L15.1528,3.4367a1.04,1.04,0,0,1,1.6944,0l6.6289,10.5564A10.0633,10.0633,0,0,1,25,19,9.0114,9.0114,0,0,1,16,28ZM16,5.8483l-5.7817,9.2079A7.9771,7.9771,0,0,0,9,19a7,7,0,0,0,14,0,8.0615,8.0615,0,0,0-1.248-3.9953Z"
  })), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.6 16.8L19.4 15.2 17 17 17 14 15 14 15 17 12.6 15.2 11.4 16.8 14.333 19 11.4 21.2 12.6 22.8 15 21 15 24 17 24 17 21 19.4 22.8 20.6 21.2 17.667 19 20.6 16.8z"
  })), children);
});
var Snowflake32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Snowflake32(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4148,12H28V10H23.4148l4.5857-4.5854L26.5864,4,22,8.5869V4H20v6.5869L18.5867,12H17V8H15v4H13.4133L12,10.5869V4H10V8.5869L5.4136,4,4,5.4146,8.5852,10H4v2h6.5852L12,13.415V15H8v2h4v1.5869L10.5867,20H4v2H8.5867L4,26.5864l1.4141,1.4141L10,23.415V28h2V21.415L13.4148,20H15v4h2V20h1.5852L20,21.415V28h2V23.415l4.5854,4.5855L28,26.5864,23.4133,22H28V20H21.4133L20,18.5869V17h4V15H20V13.415ZM18,18H14V14h4Z"
  })), children);
});
var Snowflake24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Snowflake24(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4148,12H28V10H23.4148l4.5857-4.5854L26.5864,4,22,8.5869V4H20v6.5869L18.5867,12H17V8H15v4H13.4133L12,10.5869V4H10V8.5869L5.4136,4,4,5.4146,8.5852,10H4v2h6.5852L12,13.415V15H8v2h4v1.5869L10.5867,20H4v2H8.5867L4,26.5864l1.4141,1.4141L10,23.415V28h2V21.415L13.4148,20H15v4h2V20h1.5852L20,21.415V28h2V23.415l4.5854,4.5855L28,26.5864,23.4133,22H28V20H21.4133L20,18.5869V17h4V15H20V13.415ZM18,18H14V14h4Z"
  })), children);
});
var Snowflake20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Snowflake20(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4148,12H28V10H23.4148l4.5857-4.5854L26.5864,4,22,8.5869V4H20v6.5869L18.5867,12H17V8H15v4H13.4133L12,10.5869V4H10V8.5869L5.4136,4,4,5.4146,8.5852,10H4v2h6.5852L12,13.415V15H8v2h4v1.5869L10.5867,20H4v2H8.5867L4,26.5864l1.4141,1.4141L10,23.415V28h2V21.415L13.4148,20H15v4h2V20h1.5852L20,21.415V28h2V23.415l4.5854,4.5855L28,26.5864,23.4133,22H28V20H21.4133L20,18.5869V17h4V15H20V13.415ZM18,18H14V14h4Z"
  })), children);
});
var Snowflake16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Snowflake16(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4148,12H28V10H23.4148l4.5857-4.5854L26.5864,4,22,8.5869V4H20v6.5869L18.5867,12H17V8H15v4H13.4133L12,10.5869V4H10V8.5869L5.4136,4,4,5.4146,8.5852,10H4v2h6.5852L12,13.415V15H8v2h4v1.5869L10.5867,20H4v2H8.5867L4,26.5864l1.4141,1.4141L10,23.415V28h2V21.415L13.4148,20H15v4h2V20h1.5852L20,21.415V28h2V23.415l4.5854,4.5855L28,26.5864,23.4133,22H28V20H21.4133L20,18.5869V17h4V15H20V13.415ZM18,18H14V14h4Z"
  })), children);
});
var Soccer32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Soccer32(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17",
    cy: "28",
    r: "2"
  })), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.55 17.5H15.45V19.5H7.55z",
    transform: "rotate(-45 11.5 18.5)"
  })), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 16.584L19.4143 8H6v2H18.5857l3 3L6 28.5859 7.4141 30 23 14.415 26.584 18 23 21.5859 24.4141 23 28 19.416A2.0044 2.0044 0 0028 16.584zM24.5 9A3.5 3.5 0 1128 5.5 3.504 3.504 0 0124.5 9zm0-5A1.5 1.5 0 1026 5.5 1.5017 1.5017 0 0024.5 4z"
  })), children);
});
var Soccer24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Soccer24(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17",
    cy: "28",
    r: "2"
  })), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.55 17.5H15.45V19.5H7.55z",
    transform: "rotate(-45 11.5 18.5)"
  })), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 16.584L19.4143 8H6v2H18.5857l3 3L6 28.5859 7.4141 30 23 14.415 26.584 18 23 21.5859 24.4141 23 28 19.416A2.0044 2.0044 0 0028 16.584zM24.5 9A3.5 3.5 0 1128 5.5 3.504 3.504 0 0124.5 9zm0-5A1.5 1.5 0 1026 5.5 1.5017 1.5017 0 0024.5 4z"
  })), children);
});
var Soccer20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Soccer20(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17",
    cy: "28",
    r: "2"
  })), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.55 17.5H15.45V19.5H7.55z",
    transform: "rotate(-45 11.5 18.5)"
  })), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 16.584L19.4143 8H6v2H18.5857l3 3L6 28.5859 7.4141 30 23 14.415 26.584 18 23 21.5859 24.4141 23 28 19.416A2.0044 2.0044 0 0028 16.584zM24.5 9A3.5 3.5 0 1128 5.5 3.504 3.504 0 0124.5 9zm0-5A1.5 1.5 0 1026 5.5 1.5017 1.5017 0 0024.5 4z"
  })), children);
});
var Soccer16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Soccer16(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17",
    cy: "28",
    r: "2"
  })), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.55 17.5H15.45V19.5H7.55z",
    transform: "rotate(-45 11.5 18.5)"
  })), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 16.584L19.4143 8H6v2H18.5857l3 3L6 28.5859 7.4141 30 23 14.415 26.584 18 23 21.5859 24.4141 23 28 19.416A2.0044 2.0044 0 0028 16.584zM24.5 9A3.5 3.5 0 1128 5.5 3.504 3.504 0 0124.5 9zm0-5A1.5 1.5 0 1026 5.5 1.5017 1.5017 0 0024.5 4z"
  })), children);
});
var SoftwareResource32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoftwareResource32(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2c-0.533,0-1.067,0.203-1.473,0.609L2.609,14.527\tC2.203,14.933,2,15.466,2,16s0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30c0.533,0,1.067-0.203,1.473-0.609\tl11.917-11.917C29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M16,28.036L3.965,16L16,3.964L28.036,16L16,28.036z"
  })), children);
});
var SoftwareResource24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoftwareResource24(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2c-0.533,0-1.067,0.203-1.473,0.609L2.609,14.527\tC2.203,14.933,2,15.466,2,16s0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30c0.533,0,1.067-0.203,1.473-0.609\tl11.917-11.917C29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M16,28.036L3.965,16L16,3.964L28.036,16L16,28.036z"
  })), children);
});
var SoftwareResource20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoftwareResource20(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2c-0.533,0-1.067,0.203-1.473,0.609L2.609,14.527\tC2.203,14.933,2,15.466,2,16s0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30c0.533,0,1.067-0.203,1.473-0.609\tl11.917-11.917C29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M16,28.036L3.965,16L16,3.964L28.036,16L16,28.036z"
  })), children);
});
var SoftwareResource16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoftwareResource16(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2c-0.533,0-1.067,0.203-1.473,0.609L2.609,14.527\tC2.203,14.933,2,15.466,2,16s0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30c0.533,0,1.067-0.203,1.473-0.609\tl11.917-11.917C29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M16,28.036L3.965,16L16,3.964L28.036,16L16,28.036z"
  })), children);
});
var SoftwareResourceCluster32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoftwareResourceCluster32(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21c-.5 0-1-.2-1.4-.6l-3-3C19.2 17 19 16.5 19 16s.2-1 .6-1.4l3-3C23 11.2 23.5 11 24 11c.5 0 1 .2 1.4.6l3 3C28.8 15 29 15.5 29 16c0 .5-.2 1-.6 1.4l-3 3C25 20.8 24.5 21 24 21zM24 13l-3 3 3 3 3-3L24 13zM16 13c-.5 0-1-.2-1.4-.6l-3-3C11.2 9 11 8.5 11 8s.2-1 .6-1.4l3-3C15 3.2 15.5 3 16 3c.5 0 1 .2 1.4.6l3 3C20.8 7 21 7.5 21 8c0 .5-.2 1-.6 1.4l-3 3C17 12.8 16.5 13 16 13zM16 5l-3 3 3 3 3-3L16 5zM16 29c-.5 0-1-.2-1.4-.6l-3-3C11.2 25 11 24.5 11 24s.2-1 .6-1.4l3-3C15 19.2 15.5 19 16 19c.5 0 1 .2 1.4.6l3 3C20.8 23 21 23.5 21 24c0 .5-.2 1-.6 1.4l-3 3C17 28.8 16.5 29 16 29zM16 21l-3 3 3 3 3-3L16 21zM8 21c-.5 0-1-.2-1.4-.6l-3-3C3.2 17 3 16.5 3 16s.2-1 .6-1.4l3-3C7 11.2 7.5 11 8 11c.5 0 1 .2 1.4.6l3 3C12.8 15 13 15.5 13 16c0 .5-.2 1-.6 1.4l-3 3C9 20.8 8.5 21 8 21zM8 13l-3 3 3 3 3-3L8 13z"
  })), children);
});
var SoftwareResourceCluster24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoftwareResourceCluster24(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21c-.5 0-1-.2-1.4-.6l-3-3C19.2 17 19 16.5 19 16s.2-1 .6-1.4l3-3C23 11.2 23.5 11 24 11c.5 0 1 .2 1.4.6l3 3C28.8 15 29 15.5 29 16c0 .5-.2 1-.6 1.4l-3 3C25 20.8 24.5 21 24 21zM24 13l-3 3 3 3 3-3L24 13zM16 13c-.5 0-1-.2-1.4-.6l-3-3C11.2 9 11 8.5 11 8s.2-1 .6-1.4l3-3C15 3.2 15.5 3 16 3c.5 0 1 .2 1.4.6l3 3C20.8 7 21 7.5 21 8c0 .5-.2 1-.6 1.4l-3 3C17 12.8 16.5 13 16 13zM16 5l-3 3 3 3 3-3L16 5zM16 29c-.5 0-1-.2-1.4-.6l-3-3C11.2 25 11 24.5 11 24s.2-1 .6-1.4l3-3C15 19.2 15.5 19 16 19c.5 0 1 .2 1.4.6l3 3C20.8 23 21 23.5 21 24c0 .5-.2 1-.6 1.4l-3 3C17 28.8 16.5 29 16 29zM16 21l-3 3 3 3 3-3L16 21zM8 21c-.5 0-1-.2-1.4-.6l-3-3C3.2 17 3 16.5 3 16s.2-1 .6-1.4l3-3C7 11.2 7.5 11 8 11c.5 0 1 .2 1.4.6l3 3C12.8 15 13 15.5 13 16c0 .5-.2 1-.6 1.4l-3 3C9 20.8 8.5 21 8 21zM8 13l-3 3 3 3 3-3L8 13z"
  })), children);
});
var SoftwareResourceCluster20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoftwareResourceCluster20(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21c-.5 0-1-.2-1.4-.6l-3-3C19.2 17 19 16.5 19 16s.2-1 .6-1.4l3-3C23 11.2 23.5 11 24 11c.5 0 1 .2 1.4.6l3 3C28.8 15 29 15.5 29 16c0 .5-.2 1-.6 1.4l-3 3C25 20.8 24.5 21 24 21zM24 13l-3 3 3 3 3-3L24 13zM16 13c-.5 0-1-.2-1.4-.6l-3-3C11.2 9 11 8.5 11 8s.2-1 .6-1.4l3-3C15 3.2 15.5 3 16 3c.5 0 1 .2 1.4.6l3 3C20.8 7 21 7.5 21 8c0 .5-.2 1-.6 1.4l-3 3C17 12.8 16.5 13 16 13zM16 5l-3 3 3 3 3-3L16 5zM16 29c-.5 0-1-.2-1.4-.6l-3-3C11.2 25 11 24.5 11 24s.2-1 .6-1.4l3-3C15 19.2 15.5 19 16 19c.5 0 1 .2 1.4.6l3 3C20.8 23 21 23.5 21 24c0 .5-.2 1-.6 1.4l-3 3C17 28.8 16.5 29 16 29zM16 21l-3 3 3 3 3-3L16 21zM8 21c-.5 0-1-.2-1.4-.6l-3-3C3.2 17 3 16.5 3 16s.2-1 .6-1.4l3-3C7 11.2 7.5 11 8 11c.5 0 1 .2 1.4.6l3 3C12.8 15 13 15.5 13 16c0 .5-.2 1-.6 1.4l-3 3C9 20.8 8.5 21 8 21zM8 13l-3 3 3 3 3-3L8 13z"
  })), children);
});
var SoftwareResourceCluster16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoftwareResourceCluster16(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21c-.5 0-1-.2-1.4-.6l-3-3C19.2 17 19 16.5 19 16s.2-1 .6-1.4l3-3C23 11.2 23.5 11 24 11c.5 0 1 .2 1.4.6l3 3C28.8 15 29 15.5 29 16c0 .5-.2 1-.6 1.4l-3 3C25 20.8 24.5 21 24 21zM24 13l-3 3 3 3 3-3L24 13zM16 13c-.5 0-1-.2-1.4-.6l-3-3C11.2 9 11 8.5 11 8s.2-1 .6-1.4l3-3C15 3.2 15.5 3 16 3c.5 0 1 .2 1.4.6l3 3C20.8 7 21 7.5 21 8c0 .5-.2 1-.6 1.4l-3 3C17 12.8 16.5 13 16 13zM16 5l-3 3 3 3 3-3L16 5zM16 29c-.5 0-1-.2-1.4-.6l-3-3C11.2 25 11 24.5 11 24s.2-1 .6-1.4l3-3C15 19.2 15.5 19 16 19c.5 0 1 .2 1.4.6l3 3C20.8 23 21 23.5 21 24c0 .5-.2 1-.6 1.4l-3 3C17 28.8 16.5 29 16 29zM16 21l-3 3 3 3 3-3L16 21zM8 21c-.5 0-1-.2-1.4-.6l-3-3C3.2 17 3 16.5 3 16s.2-1 .6-1.4l3-3C7 11.2 7.5 11 8 11c.5 0 1 .2 1.4.6l3 3C12.8 15 13 15.5 13 16c0 .5-.2 1-.6 1.4l-3 3C9 20.8 8.5 21 8 21zM8 13l-3 3 3 3 3-3L8 13z"
  })), children);
});
var SoftwareResourceResource32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoftwareResourceResource32(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.9 8.3H11.7V10.3H6.9z",
    transform: "rotate(-45.001 9.293 9.293)"
  })), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9,19.7l-2.3-2.3C2.2,17,2,16.5,2,16s0.2-1,0.6-1.4l2.3-2.3l1.4,1.4L4,16l2.3,2.3L4.9,19.7z"
  })), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.3 20.3H10.3V25.1H8.3z",
    transform: "rotate(-45.001 9.293 22.707)"
  })), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30c-0.5,0-1-0.2-1.4-0.6l-2.3-2.3l1.4-1.4L16,28l2.3-2.3l1.4,1.4l-2.3,2.3C17,29.8,16.5,30,16,30z"
  })), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.3 21.7H25.1V23.7H20.3z",
    transform: "rotate(-45.001 22.707 22.707)"
  })), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.1,19.7l-1.4-1.4L28,16l-2.3-2.3l1.4-1.4l2.3,2.3C29.8,15,30,15.5,30,16s-0.2,1-0.6,1.4L27.1,19.7z"
  })), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.7 6.9H23.7V11.7H21.7z",
    transform: "rotate(-45.001 22.707 9.293)"
  })), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2c-0.5,0-1,0.2-1.4,0.6l-2.3,2.3l1.4,1.4L16,4l2.3,2.3l1.4-1.4l-2.3-2.3C17,2.2,16.5,2,16,2z"
  })), children);
});
var SoftwareResourceResource24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoftwareResourceResource24(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.9 8.3H11.7V10.3H6.9z",
    transform: "rotate(-45.001 9.293 9.293)"
  })), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9,19.7l-2.3-2.3C2.2,17,2,16.5,2,16s0.2-1,0.6-1.4l2.3-2.3l1.4,1.4L4,16l2.3,2.3L4.9,19.7z"
  })), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.3 20.3H10.3V25.1H8.3z",
    transform: "rotate(-45.001 9.293 22.707)"
  })), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30c-0.5,0-1-0.2-1.4-0.6l-2.3-2.3l1.4-1.4L16,28l2.3-2.3l1.4,1.4l-2.3,2.3C17,29.8,16.5,30,16,30z"
  })), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.3 21.7H25.1V23.7H20.3z",
    transform: "rotate(-45.001 22.707 22.707)"
  })), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.1,19.7l-1.4-1.4L28,16l-2.3-2.3l1.4-1.4l2.3,2.3C29.8,15,30,15.5,30,16s-0.2,1-0.6,1.4L27.1,19.7z"
  })), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.7 6.9H23.7V11.7H21.7z",
    transform: "rotate(-45.001 22.707 9.293)"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2c-0.5,0-1,0.2-1.4,0.6l-2.3,2.3l1.4,1.4L16,4l2.3,2.3l1.4-1.4l-2.3-2.3C17,2.2,16.5,2,16,2z"
  })), children);
});
var SoftwareResourceResource20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoftwareResourceResource20(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.9 8.3H11.7V10.3H6.9z",
    transform: "rotate(-45.001 9.293 9.293)"
  })), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9,19.7l-2.3-2.3C2.2,17,2,16.5,2,16s0.2-1,0.6-1.4l2.3-2.3l1.4,1.4L4,16l2.3,2.3L4.9,19.7z"
  })), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.3 20.3H10.3V25.1H8.3z",
    transform: "rotate(-45.001 9.293 22.707)"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30c-0.5,0-1-0.2-1.4-0.6l-2.3-2.3l1.4-1.4L16,28l2.3-2.3l1.4,1.4l-2.3,2.3C17,29.8,16.5,30,16,30z"
  })), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.3 21.7H25.1V23.7H20.3z",
    transform: "rotate(-45.001 22.707 22.707)"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.1,19.7l-1.4-1.4L28,16l-2.3-2.3l1.4-1.4l2.3,2.3C29.8,15,30,15.5,30,16s-0.2,1-0.6,1.4L27.1,19.7z"
  })), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.7 6.9H23.7V11.7H21.7z",
    transform: "rotate(-45.001 22.707 9.293)"
  })), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2c-0.5,0-1,0.2-1.4,0.6l-2.3,2.3l1.4,1.4L16,4l2.3,2.3l1.4-1.4l-2.3-2.3C17,2.2,16.5,2,16,2z"
  })), children);
});
var SoftwareResourceResource16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoftwareResourceResource16(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.9 8.3H11.7V10.3H6.9z",
    transform: "rotate(-45.001 9.293 9.293)"
  })), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.9,19.7l-2.3-2.3C2.2,17,2,16.5,2,16s0.2-1,0.6-1.4l2.3-2.3l1.4,1.4L4,16l2.3,2.3L4.9,19.7z"
  })), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.3 20.3H10.3V25.1H8.3z",
    transform: "rotate(-45.001 9.293 22.707)"
  })), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30c-0.5,0-1-0.2-1.4-0.6l-2.3-2.3l1.4-1.4L16,28l2.3-2.3l1.4,1.4l-2.3,2.3C17,29.8,16.5,30,16,30z"
  })), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.3 21.7H25.1V23.7H20.3z",
    transform: "rotate(-45.001 22.707 22.707)"
  })), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.1,19.7l-1.4-1.4L28,16l-2.3-2.3l1.4-1.4l2.3,2.3C29.8,15,30,15.5,30,16s-0.2,1-0.6,1.4L27.1,19.7z"
  })), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.7 6.9H23.7V11.7H21.7z",
    transform: "rotate(-45.001 22.707 9.293)"
  })), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2c-0.5,0-1,0.2-1.4,0.6l-2.3,2.3l1.4,1.4L16,4l2.3,2.3l1.4-1.4l-2.3-2.3C17,2.2,16.5,2,16,2z"
  })), children);
});
var SoilMoisture32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilMoisture32(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5,28A5.385,5.385,0,0,1,19,22.751a5.3837,5.3837,0,0,1,.874-2.8308L23.49,14.5383a1.217,1.217,0,0,1,2.02,0L29.06,19.8154A5.4923,5.4923,0,0,1,30,22.751,5.385,5.385,0,0,1,24.5,28Zm0-11.38-2.9356,4.3672A3.3586,3.3586,0,0,0,21,22.751a3.51,3.51,0,0,0,7,0,3.4356,3.4356,0,0,0-.63-1.867Z"
  })), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "5",
    cy: "13",
    r: "1"
  })), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "19",
    r: "1"
  })), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "25",
    r: "1"
  })), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17",
    cy: "15",
    r: "1"
  })), _circle21 || (_circle21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13",
    cy: "11",
    r: "1"
  })), _circle22 || (_circle22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "27",
    cy: "11",
    r: "1"
  })), _circle23 || (_circle23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _circle24 || (_circle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "21",
    r: "1"
  })), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 6H30V8H2z"
  })), children);
});
var SoilMoisture24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilMoisture24(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5,28A5.385,5.385,0,0,1,19,22.751a5.3837,5.3837,0,0,1,.874-2.8308L23.49,14.5383a1.217,1.217,0,0,1,2.02,0L29.06,19.8154A5.4923,5.4923,0,0,1,30,22.751,5.385,5.385,0,0,1,24.5,28Zm0-11.38-2.9356,4.3672A3.3586,3.3586,0,0,0,21,22.751a3.51,3.51,0,0,0,7,0,3.4356,3.4356,0,0,0-.63-1.867Z"
  })), _circle25 || (_circle25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "5",
    cy: "13",
    r: "1"
  })), _circle26 || (_circle26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "19",
    r: "1"
  })), _circle27 || (_circle27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "25",
    r: "1"
  })), _circle28 || (_circle28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17",
    cy: "15",
    r: "1"
  })), _circle29 || (_circle29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13",
    cy: "11",
    r: "1"
  })), _circle30 || (_circle30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "27",
    cy: "11",
    r: "1"
  })), _circle31 || (_circle31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _circle32 || (_circle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "21",
    r: "1"
  })), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 6H30V8H2z"
  })), children);
});
var SoilMoisture20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilMoisture20(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5,28A5.385,5.385,0,0,1,19,22.751a5.3837,5.3837,0,0,1,.874-2.8308L23.49,14.5383a1.217,1.217,0,0,1,2.02,0L29.06,19.8154A5.4923,5.4923,0,0,1,30,22.751,5.385,5.385,0,0,1,24.5,28Zm0-11.38-2.9356,4.3672A3.3586,3.3586,0,0,0,21,22.751a3.51,3.51,0,0,0,7,0,3.4356,3.4356,0,0,0-.63-1.867Z"
  })), _circle33 || (_circle33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "5",
    cy: "13",
    r: "1"
  })), _circle34 || (_circle34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "19",
    r: "1"
  })), _circle35 || (_circle35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "25",
    r: "1"
  })), _circle36 || (_circle36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17",
    cy: "15",
    r: "1"
  })), _circle37 || (_circle37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13",
    cy: "11",
    r: "1"
  })), _circle38 || (_circle38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "27",
    cy: "11",
    r: "1"
  })), _circle39 || (_circle39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _circle40 || (_circle40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "21",
    r: "1"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 6H30V8H2z"
  })), children);
});
var SoilMoisture16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilMoisture16(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5,28A5.385,5.385,0,0,1,19,22.751a5.3837,5.3837,0,0,1,.874-2.8308L23.49,14.5383a1.217,1.217,0,0,1,2.02,0L29.06,19.8154A5.4923,5.4923,0,0,1,30,22.751,5.385,5.385,0,0,1,24.5,28Zm0-11.38-2.9356,4.3672A3.3586,3.3586,0,0,0,21,22.751a3.51,3.51,0,0,0,7,0,3.4356,3.4356,0,0,0-.63-1.867Z"
  })), _circle41 || (_circle41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "5",
    cy: "13",
    r: "1"
  })), _circle42 || (_circle42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "19",
    r: "1"
  })), _circle43 || (_circle43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "25",
    r: "1"
  })), _circle44 || (_circle44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17",
    cy: "15",
    r: "1"
  })), _circle45 || (_circle45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13",
    cy: "11",
    r: "1"
  })), _circle46 || (_circle46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "27",
    cy: "11",
    r: "1"
  })), _circle47 || (_circle47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _circle48 || (_circle48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "21",
    r: "1"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 6H30V8H2z"
  })), children);
});
var SoilMoistureField32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilMoistureField32(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 30a5.202 5.202 0 01-4.626-8.08L23.49 16.5382a1.217 1.217 0 012.02 0L29.06 21.8154A5.4921 5.4921 0 0130 24.751 5.385 5.385 0 0124.5 30zm0-11.38l-2.9356 4.3672A3.2079 3.2079 0 0024.5 28 3.3855 3.3855 0 0028 24.751a3.4354 3.4354 0 00-.63-1.867zM11 16V11h1a4.0045 4.0045 0 004-4V4H13a3.9779 3.9779 0 00-2.7468 1.1067A6.0034 6.0034 0 005 2H2V5a6.0066 6.0066 0 006 6H9v5H2v2H16V16zM13 6h1V7a2.002 2.002 0 01-2 2H11V8A2.002 2.002 0 0113 6zM8 9A4.0045 4.0045 0 014 5V4H5A4.0045 4.0045 0 019 8V9zM2 21H16V23H2zM2 26H16V28H2z"
  })), children);
});
var SoilMoistureField24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilMoistureField24(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 30a5.202 5.202 0 01-4.626-8.08L23.49 16.5382a1.217 1.217 0 012.02 0L29.06 21.8154A5.4921 5.4921 0 0130 24.751 5.385 5.385 0 0124.5 30zm0-11.38l-2.9356 4.3672A3.2079 3.2079 0 0024.5 28 3.3855 3.3855 0 0028 24.751a3.4354 3.4354 0 00-.63-1.867zM11 16V11h1a4.0045 4.0045 0 004-4V4H13a3.9779 3.9779 0 00-2.7468 1.1067A6.0034 6.0034 0 005 2H2V5a6.0066 6.0066 0 006 6H9v5H2v2H16V16zM13 6h1V7a2.002 2.002 0 01-2 2H11V8A2.002 2.002 0 0113 6zM8 9A4.0045 4.0045 0 014 5V4H5A4.0045 4.0045 0 019 8V9zM2 21H16V23H2zM2 26H16V28H2z"
  })), children);
});
var SoilMoistureField20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilMoistureField20(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 30a5.202 5.202 0 01-4.626-8.08L23.49 16.5382a1.217 1.217 0 012.02 0L29.06 21.8154A5.4921 5.4921 0 0130 24.751 5.385 5.385 0 0124.5 30zm0-11.38l-2.9356 4.3672A3.2079 3.2079 0 0024.5 28 3.3855 3.3855 0 0028 24.751a3.4354 3.4354 0 00-.63-1.867zM11 16V11h1a4.0045 4.0045 0 004-4V4H13a3.9779 3.9779 0 00-2.7468 1.1067A6.0034 6.0034 0 005 2H2V5a6.0066 6.0066 0 006 6H9v5H2v2H16V16zM13 6h1V7a2.002 2.002 0 01-2 2H11V8A2.002 2.002 0 0113 6zM8 9A4.0045 4.0045 0 014 5V4H5A4.0045 4.0045 0 019 8V9zM2 21H16V23H2zM2 26H16V28H2z"
  })), children);
});
var SoilMoistureField16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilMoistureField16(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.5 30a5.202 5.202 0 01-4.626-8.08L23.49 16.5382a1.217 1.217 0 012.02 0L29.06 21.8154A5.4921 5.4921 0 0130 24.751 5.385 5.385 0 0124.5 30zm0-11.38l-2.9356 4.3672A3.2079 3.2079 0 0024.5 28 3.3855 3.3855 0 0028 24.751a3.4354 3.4354 0 00-.63-1.867zM11 16V11h1a4.0045 4.0045 0 004-4V4H13a3.9779 3.9779 0 00-2.7468 1.1067A6.0034 6.0034 0 005 2H2V5a6.0066 6.0066 0 006 6H9v5H2v2H16V16zM13 6h1V7a2.002 2.002 0 01-2 2H11V8A2.002 2.002 0 0113 6zM8 9A4.0045 4.0045 0 014 5V4H5A4.0045 4.0045 0 019 8V9zM2 21H16V23H2zM2 26H16V28H2z"
  })), children);
});
var SoilMoistureGlobal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilMoistureGlobal32(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 30a4.7347 4.7347 0 01-4.2075-7.35l3.3687-5.1942a1 1 0 011.6779 0l3.3152 5.11A4.9753 4.9753 0 0130 25.2231 4.8979 4.8979 0 0125 30zm0-10.1629l-2.5078 3.8662A2.9264 2.9264 0 1028 25.2231a2.96 2.96 0 00-.5444-1.6028zM11 24H9A17.0192 17.0192 0 0126 7h4V9H26A15.017 15.017 0 0011 24z"
  })), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24H14A12.0137,12.0137,0,0,1,26,12h4v2H26A10.0113,10.0113,0,0,0,16,24Z"
  })), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2A21.8625,21.8625,0,0,0,13.9993,5.5757,21.856,21.856,0,0,0,2,2V4A19.8735,19.8735,0,0,1,12.2622,6.835,22.1514,22.1514,0,0,0,9.9475,8.979,17.001,17.001,0,0,0,2,7V9a15.0142,15.0142,0,0,1,6.6191,1.5366,22.0768,22.0768,0,0,0-1.7016,2.5371A12.0319,12.0319,0,0,0,2,12v2a9.8838,9.8838,0,0,1,4.0007.8506A21.861,21.861,0,0,0,4,24H6A20.0226,20.0226,0,0,1,26,4h4V2Z"
  })), children);
});
var SoilMoistureGlobal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilMoistureGlobal24(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 30a4.7347 4.7347 0 01-4.2075-7.35l3.3687-5.1942a1 1 0 011.6779 0l3.3152 5.11A4.9753 4.9753 0 0130 25.2231 4.8979 4.8979 0 0125 30zm0-10.1629l-2.5078 3.8662A2.9264 2.9264 0 1028 25.2231a2.96 2.96 0 00-.5444-1.6028zM11 24H9A17.0192 17.0192 0 0126 7h4V9H26A15.017 15.017 0 0011 24z"
  })), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24H14A12.0137,12.0137,0,0,1,26,12h4v2H26A10.0113,10.0113,0,0,0,16,24Z"
  })), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2A21.8625,21.8625,0,0,0,13.9993,5.5757,21.856,21.856,0,0,0,2,2V4A19.8735,19.8735,0,0,1,12.2622,6.835,22.1514,22.1514,0,0,0,9.9475,8.979,17.001,17.001,0,0,0,2,7V9a15.0142,15.0142,0,0,1,6.6191,1.5366,22.0768,22.0768,0,0,0-1.7016,2.5371A12.0319,12.0319,0,0,0,2,12v2a9.8838,9.8838,0,0,1,4.0007.8506A21.861,21.861,0,0,0,4,24H6A20.0226,20.0226,0,0,1,26,4h4V2Z"
  })), children);
});
var SoilMoistureGlobal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilMoistureGlobal20(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 30a4.7347 4.7347 0 01-4.2075-7.35l3.3687-5.1942a1 1 0 011.6779 0l3.3152 5.11A4.9753 4.9753 0 0130 25.2231 4.8979 4.8979 0 0125 30zm0-10.1629l-2.5078 3.8662A2.9264 2.9264 0 1028 25.2231a2.96 2.96 0 00-.5444-1.6028zM11 24H9A17.0192 17.0192 0 0126 7h4V9H26A15.017 15.017 0 0011 24z"
  })), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24H14A12.0137,12.0137,0,0,1,26,12h4v2H26A10.0113,10.0113,0,0,0,16,24Z"
  })), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2A21.8625,21.8625,0,0,0,13.9993,5.5757,21.856,21.856,0,0,0,2,2V4A19.8735,19.8735,0,0,1,12.2622,6.835,22.1514,22.1514,0,0,0,9.9475,8.979,17.001,17.001,0,0,0,2,7V9a15.0142,15.0142,0,0,1,6.6191,1.5366,22.0768,22.0768,0,0,0-1.7016,2.5371A12.0319,12.0319,0,0,0,2,12v2a9.8838,9.8838,0,0,1,4.0007.8506A21.861,21.861,0,0,0,4,24H6A20.0226,20.0226,0,0,1,26,4h4V2Z"
  })), children);
});
var SoilMoistureGlobal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilMoistureGlobal16(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 30a4.7347 4.7347 0 01-4.2075-7.35l3.3687-5.1942a1 1 0 011.6779 0l3.3152 5.11A4.9753 4.9753 0 0130 25.2231 4.8979 4.8979 0 0125 30zm0-10.1629l-2.5078 3.8662A2.9264 2.9264 0 1028 25.2231a2.96 2.96 0 00-.5444-1.6028zM11 24H9A17.0192 17.0192 0 0126 7h4V9H26A15.017 15.017 0 0011 24z"
  })), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,24H14A12.0137,12.0137,0,0,1,26,12h4v2H26A10.0113,10.0113,0,0,0,16,24Z"
  })), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2A21.8625,21.8625,0,0,0,13.9993,5.5757,21.856,21.856,0,0,0,2,2V4A19.8735,19.8735,0,0,1,12.2622,6.835,22.1514,22.1514,0,0,0,9.9475,8.979,17.001,17.001,0,0,0,2,7V9a15.0142,15.0142,0,0,1,6.6191,1.5366,22.0768,22.0768,0,0,0-1.7016,2.5371A12.0319,12.0319,0,0,0,2,12v2a9.8838,9.8838,0,0,1,4.0007.8506A21.861,21.861,0,0,0,4,24H6A20.0226,20.0226,0,0,1,26,4h4V2Z"
  })), children);
});
var SoilTemperature32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilTemperature32(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle49 || (_circle49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "5",
    cy: "13",
    r: "1"
  })), _circle50 || (_circle50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "19",
    r: "1"
  })), _circle51 || (_circle51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "25",
    r: "1"
  })), _circle52 || (_circle52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17",
    cy: "15",
    r: "1"
  })), _circle53 || (_circle53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13",
    cy: "11",
    r: "1"
  })), _circle54 || (_circle54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _circle55 || (_circle55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "21",
    r: "1"
  })), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 30a4.9863 4.9863 0 01-3-8.98V15a3 3 0 016 0v6.02A4.9863 4.9863 0 0125 30zm0-16a1.0011 1.0011 0 00-1 1v7.13l-.4971.2893A2.9676 2.9676 0 0022 25a3 3 0 006 0 2.9676 2.9676 0 00-1.5029-2.5811L26 22.13V15A1.0011 1.0011 0 0025 14zM2 6H30V8H2z"
  })), children);
});
var SoilTemperature24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilTemperature24(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle56 || (_circle56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "5",
    cy: "13",
    r: "1"
  })), _circle57 || (_circle57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "19",
    r: "1"
  })), _circle58 || (_circle58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "25",
    r: "1"
  })), _circle59 || (_circle59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17",
    cy: "15",
    r: "1"
  })), _circle60 || (_circle60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13",
    cy: "11",
    r: "1"
  })), _circle61 || (_circle61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _circle62 || (_circle62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "21",
    r: "1"
  })), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 30a4.9863 4.9863 0 01-3-8.98V15a3 3 0 016 0v6.02A4.9863 4.9863 0 0125 30zm0-16a1.0011 1.0011 0 00-1 1v7.13l-.4971.2893A2.9676 2.9676 0 0022 25a3 3 0 006 0 2.9676 2.9676 0 00-1.5029-2.5811L26 22.13V15A1.0011 1.0011 0 0025 14zM2 6H30V8H2z"
  })), children);
});
var SoilTemperature20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilTemperature20(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle63 || (_circle63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "5",
    cy: "13",
    r: "1"
  })), _circle64 || (_circle64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "19",
    r: "1"
  })), _circle65 || (_circle65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "25",
    r: "1"
  })), _circle66 || (_circle66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17",
    cy: "15",
    r: "1"
  })), _circle67 || (_circle67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13",
    cy: "11",
    r: "1"
  })), _circle68 || (_circle68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _circle69 || (_circle69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "21",
    r: "1"
  })), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 30a4.9863 4.9863 0 01-3-8.98V15a3 3 0 016 0v6.02A4.9863 4.9863 0 0125 30zm0-16a1.0011 1.0011 0 00-1 1v7.13l-.4971.2893A2.9676 2.9676 0 0022 25a3 3 0 006 0 2.9676 2.9676 0 00-1.5029-2.5811L26 22.13V15A1.0011 1.0011 0 0025 14zM2 6H30V8H2z"
  })), children);
});
var SoilTemperature16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilTemperature16(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle70 || (_circle70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "5",
    cy: "13",
    r: "1"
  })), _circle71 || (_circle71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "19",
    r: "1"
  })), _circle72 || (_circle72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "25",
    r: "1"
  })), _circle73 || (_circle73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "17",
    cy: "15",
    r: "1"
  })), _circle74 || (_circle74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13",
    cy: "11",
    r: "1"
  })), _circle75 || (_circle75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "27",
    r: "1"
  })), _circle76 || (_circle76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "21",
    r: "1"
  })), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 30a4.9863 4.9863 0 01-3-8.98V15a3 3 0 016 0v6.02A4.9863 4.9863 0 0125 30zm0-16a1.0011 1.0011 0 00-1 1v7.13l-.4971.2893A2.9676 2.9676 0 0022 25a3 3 0 006 0 2.9676 2.9676 0 00-1.5029-2.5811L26 22.13V15A1.0011 1.0011 0 0025 14zM2 6H30V8H2z"
  })), children);
});
var SoilTemperatureField32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilTemperatureField32(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 16V11h1a4.0045 4.0045 0 004-4V4H13a3.9779 3.9779 0 00-2.7468 1.1067A6.0034 6.0034 0 005 2H2V5a6.0066 6.0066 0 006 6H9v5H2v2H16V16zM13 6h1V7a2.002 2.002 0 01-2 2H11V8A2.002 2.002 0 0113 6zM8 9A4.0045 4.0045 0 014 5V4H5A4.0045 4.0045 0 019 8V9zM2 21H16V23H2zM2 26H16V28H2zM25 30a4.9863 4.9863 0 01-3-8.98V15a3 3 0 016 0v6.02A4.9863 4.9863 0 0125 30zm0-16a1.0011 1.0011 0 00-1 1v7.13l-.4971.2893A2.9676 2.9676 0 0022 25a3 3 0 006 0 2.9676 2.9676 0 00-1.5029-2.5811L26 22.13V15A1.0011 1.0011 0 0025 14z"
  })), children);
});
var SoilTemperatureField24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilTemperatureField24(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 16V11h1a4.0045 4.0045 0 004-4V4H13a3.9779 3.9779 0 00-2.7468 1.1067A6.0034 6.0034 0 005 2H2V5a6.0066 6.0066 0 006 6H9v5H2v2H16V16zM13 6h1V7a2.002 2.002 0 01-2 2H11V8A2.002 2.002 0 0113 6zM8 9A4.0045 4.0045 0 014 5V4H5A4.0045 4.0045 0 019 8V9zM2 21H16V23H2zM2 26H16V28H2zM25 30a4.9863 4.9863 0 01-3-8.98V15a3 3 0 016 0v6.02A4.9863 4.9863 0 0125 30zm0-16a1.0011 1.0011 0 00-1 1v7.13l-.4971.2893A2.9676 2.9676 0 0022 25a3 3 0 006 0 2.9676 2.9676 0 00-1.5029-2.5811L26 22.13V15A1.0011 1.0011 0 0025 14z"
  })), children);
});
var SoilTemperatureField20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilTemperatureField20(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 16V11h1a4.0045 4.0045 0 004-4V4H13a3.9779 3.9779 0 00-2.7468 1.1067A6.0034 6.0034 0 005 2H2V5a6.0066 6.0066 0 006 6H9v5H2v2H16V16zM13 6h1V7a2.002 2.002 0 01-2 2H11V8A2.002 2.002 0 0113 6zM8 9A4.0045 4.0045 0 014 5V4H5A4.0045 4.0045 0 019 8V9zM2 21H16V23H2zM2 26H16V28H2zM25 30a4.9863 4.9863 0 01-3-8.98V15a3 3 0 016 0v6.02A4.9863 4.9863 0 0125 30zm0-16a1.0011 1.0011 0 00-1 1v7.13l-.4971.2893A2.9676 2.9676 0 0022 25a3 3 0 006 0 2.9676 2.9676 0 00-1.5029-2.5811L26 22.13V15A1.0011 1.0011 0 0025 14z"
  })), children);
});
var SoilTemperatureField16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilTemperatureField16(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 16V11h1a4.0045 4.0045 0 004-4V4H13a3.9779 3.9779 0 00-2.7468 1.1067A6.0034 6.0034 0 005 2H2V5a6.0066 6.0066 0 006 6H9v5H2v2H16V16zM13 6h1V7a2.002 2.002 0 01-2 2H11V8A2.002 2.002 0 0113 6zM8 9A4.0045 4.0045 0 014 5V4H5A4.0045 4.0045 0 019 8V9zM2 21H16V23H2zM2 26H16V28H2zM25 30a4.9863 4.9863 0 01-3-8.98V15a3 3 0 016 0v6.02A4.9863 4.9863 0 0125 30zm0-16a1.0011 1.0011 0 00-1 1v7.13l-.4971.2893A2.9676 2.9676 0 0022 25a3 3 0 006 0 2.9676 2.9676 0 00-1.5029-2.5811L26 22.13V15A1.0011 1.0011 0 0025 14z"
  })), children);
});
var SoilTemperatureGlobal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilTemperatureGlobal32(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 30a4.9863 4.9863 0 01-3-8.98V15a3 3 0 016 0v6.02A4.9863 4.9863 0 0125 30zm0-16a1.0011 1.0011 0 00-1 1v7.13l-.4971.2893A2.9676 2.9676 0 0022 25a3 3 0 006 0 2.9676 2.9676 0 00-1.5029-2.5811L26 22.13V15A1.0011 1.0011 0 0025 14zM16 24H14a11.89 11.89 0 013.7642-8.7271l1.373 1.4542A9.909 9.909 0 0016 24z"
  })), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,24H9A17.0192,17.0192,0,0,1,26,7h4V9H26A15.017,15.017,0,0,0,11,24Z"
  })), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2A21.8625,21.8625,0,0,0,13.9993,5.5757,21.856,21.856,0,0,0,2,2V4A19.8735,19.8735,0,0,1,12.2622,6.835,22.1514,22.1514,0,0,0,9.9475,8.979,17.001,17.001,0,0,0,2,7V9a15.0142,15.0142,0,0,1,6.6191,1.5366,22.0768,22.0768,0,0,0-1.7016,2.5371A12.0319,12.0319,0,0,0,2,12v2a9.8838,9.8838,0,0,1,4.0007.8506A21.861,21.861,0,0,0,4,24H6A20.0226,20.0226,0,0,1,26,4h4V2Z"
  })), children);
});
var SoilTemperatureGlobal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilTemperatureGlobal24(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 30a4.9863 4.9863 0 01-3-8.98V15a3 3 0 016 0v6.02A4.9863 4.9863 0 0125 30zm0-16a1.0011 1.0011 0 00-1 1v7.13l-.4971.2893A2.9676 2.9676 0 0022 25a3 3 0 006 0 2.9676 2.9676 0 00-1.5029-2.5811L26 22.13V15A1.0011 1.0011 0 0025 14zM16 24H14a11.89 11.89 0 013.7642-8.7271l1.373 1.4542A9.909 9.909 0 0016 24z"
  })), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,24H9A17.0192,17.0192,0,0,1,26,7h4V9H26A15.017,15.017,0,0,0,11,24Z"
  })), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2A21.8625,21.8625,0,0,0,13.9993,5.5757,21.856,21.856,0,0,0,2,2V4A19.8735,19.8735,0,0,1,12.2622,6.835,22.1514,22.1514,0,0,0,9.9475,8.979,17.001,17.001,0,0,0,2,7V9a15.0142,15.0142,0,0,1,6.6191,1.5366,22.0768,22.0768,0,0,0-1.7016,2.5371A12.0319,12.0319,0,0,0,2,12v2a9.8838,9.8838,0,0,1,4.0007.8506A21.861,21.861,0,0,0,4,24H6A20.0226,20.0226,0,0,1,26,4h4V2Z"
  })), children);
});
var SoilTemperatureGlobal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilTemperatureGlobal20(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 30a4.9863 4.9863 0 01-3-8.98V15a3 3 0 016 0v6.02A4.9863 4.9863 0 0125 30zm0-16a1.0011 1.0011 0 00-1 1v7.13l-.4971.2893A2.9676 2.9676 0 0022 25a3 3 0 006 0 2.9676 2.9676 0 00-1.5029-2.5811L26 22.13V15A1.0011 1.0011 0 0025 14zM16 24H14a11.89 11.89 0 013.7642-8.7271l1.373 1.4542A9.909 9.909 0 0016 24z"
  })), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,24H9A17.0192,17.0192,0,0,1,26,7h4V9H26A15.017,15.017,0,0,0,11,24Z"
  })), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2A21.8625,21.8625,0,0,0,13.9993,5.5757,21.856,21.856,0,0,0,2,2V4A19.8735,19.8735,0,0,1,12.2622,6.835,22.1514,22.1514,0,0,0,9.9475,8.979,17.001,17.001,0,0,0,2,7V9a15.0142,15.0142,0,0,1,6.6191,1.5366,22.0768,22.0768,0,0,0-1.7016,2.5371A12.0319,12.0319,0,0,0,2,12v2a9.8838,9.8838,0,0,1,4.0007.8506A21.861,21.861,0,0,0,4,24H6A20.0226,20.0226,0,0,1,26,4h4V2Z"
  })), children);
});
var SoilTemperatureGlobal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SoilTemperatureGlobal16(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 30a4.9863 4.9863 0 01-3-8.98V15a3 3 0 016 0v6.02A4.9863 4.9863 0 0125 30zm0-16a1.0011 1.0011 0 00-1 1v7.13l-.4971.2893A2.9676 2.9676 0 0022 25a3 3 0 006 0 2.9676 2.9676 0 00-1.5029-2.5811L26 22.13V15A1.0011 1.0011 0 0025 14zM16 24H14a11.89 11.89 0 013.7642-8.7271l1.373 1.4542A9.909 9.909 0 0016 24z"
  })), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,24H9A17.0192,17.0192,0,0,1,26,7h4V9H26A15.017,15.017,0,0,0,11,24Z"
  })), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2A21.8625,21.8625,0,0,0,13.9993,5.5757,21.856,21.856,0,0,0,2,2V4A19.8735,19.8735,0,0,1,12.2622,6.835,22.1514,22.1514,0,0,0,9.9475,8.979,17.001,17.001,0,0,0,2,7V9a15.0142,15.0142,0,0,1,6.6191,1.5366,22.0768,22.0768,0,0,0-1.7016,2.5371A12.0319,12.0319,0,0,0,2,12v2a9.8838,9.8838,0,0,1,4.0007.8506A21.861,21.861,0,0,0,4,24H6A20.0226,20.0226,0,0,1,26,4h4V2Z"
  })), children);
});
var SolarPanel32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SolarPanel32(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 26V14H13V26h5v2H2v2H30V28H25V26zm-5-2V21h3v3zm-2-3v3H20V21zm-3-2V16h3v3zm8 0H25V16h3zM18 16v3H15V16zm-3 8V21h3v3zm8 4H20V26h3zM9.3328 14.981A4 4 0 1116 12H14a2 2 0 10-3.3333 1.4907zM11 2H13V6H11zM2 11H6V13H2z"
  })), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.343 4.343H7.343V8.343H5.343z",
    transform: "rotate(-45 6.343 6.343)"
  })), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.657 4.343H18.657V8.343H16.657z",
    transform: "rotate(-135 17.657 6.343)"
  })), children);
});
var SolarPanel24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SolarPanel24(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 26V14H13V26h5v2H2v2H30V28H25V26zm-5-2V21h3v3zm-2-3v3H20V21zm-3-2V16h3v3zm8 0H25V16h3zM18 16v3H15V16zm-3 8V21h3v3zm8 4H20V26h3zM9.3328 14.981A4 4 0 1116 12H14a2 2 0 10-3.3333 1.4907zM11 2H13V6H11zM2 11H6V13H2z"
  })), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.343 4.343H7.343V8.343H5.343z",
    transform: "rotate(-45 6.343 6.343)"
  })), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.657 4.343H18.657V8.343H16.657z",
    transform: "rotate(-135 17.657 6.343)"
  })), children);
});
var SolarPanel20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SolarPanel20(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 26V14H13V26h5v2H2v2H30V28H25V26zm-5-2V21h3v3zm-2-3v3H20V21zm-3-2V16h3v3zm8 0H25V16h3zM18 16v3H15V16zm-3 8V21h3v3zm8 4H20V26h3zM9.3328 14.981A4 4 0 1116 12H14a2 2 0 10-3.3333 1.4907zM11 2H13V6H11zM2 11H6V13H2z"
  })), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.343 4.343H7.343V8.343H5.343z",
    transform: "rotate(-45 6.343 6.343)"
  })), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.657 4.343H18.657V8.343H16.657z",
    transform: "rotate(-135 17.657 6.343)"
  })), children);
});
var SolarPanel16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SolarPanel16(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 26V14H13V26h5v2H2v2H30V28H25V26zm-5-2V21h3v3zm-2-3v3H20V21zm-3-2V16h3v3zm8 0H25V16h3zM18 16v3H15V16zm-3 8V21h3v3zm8 4H20V26h3zM9.3328 14.981A4 4 0 1116 12H14a2 2 0 10-3.3333 1.4907zM11 2H13V6H11zM2 11H6V13H2z"
  })), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.343 4.343H7.343V8.343H5.343z",
    transform: "rotate(-45 6.343 6.343)"
  })), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.657 4.343H18.657V8.343H16.657z",
    transform: "rotate(-135 17.657 6.343)"
  })), children);
});
var SortAscending32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SortAscending32(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 22L19.414 20.586 23 24.172 23 4 25 4 25 24.172 28.586 20.586 30 22 24 28 18 22zM2 18H16V20H2zM6 12H16V14H6zM10 6H16V8H10z"
  })), children);
});
var SortAscending24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SortAscending24(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 22L19.414 20.586 23 24.172 23 4 25 4 25 24.172 28.586 20.586 30 22 24 28 18 22zM2 18H16V20H2zM6 12H16V14H6zM10 6H16V8H10z"
  })), children);
});
var SortAscending20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SortAscending20(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 22L19.414 20.586 23 24.172 23 4 25 4 25 24.172 28.586 20.586 30 22 24 28 18 22zM2 18H16V20H2zM6 12H16V14H6zM10 6H16V8H10z"
  })), children);
});
var SortAscending16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SortAscending16(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 22L19.414 20.586 23 24.172 23 4 25 4 25 24.172 28.586 20.586 30 22 24 28 18 22zM2 18H16V20H2zM6 12H16V14H6zM10 6H16V8H10z"
  })), children);
});
var SortDescending32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SortDescending32(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 22L19.414 20.586 23 24.172 23 4 25 4 25 24.172 28.586 20.586 30 22 24 28 18 22zM2 6H16V8H2zM6 12H16V14H6zM10 18H16V20H10z"
  })), children);
});
var SortDescending24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SortDescending24(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 22L19.414 20.586 23 24.172 23 4 25 4 25 24.172 28.586 20.586 30 22 24 28 18 22zM2 6H16V8H2zM6 12H16V14H6zM10 18H16V20H10z"
  })), children);
});
var SortDescending20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SortDescending20(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 22L19.414 20.586 23 24.172 23 4 25 4 25 24.172 28.586 20.586 30 22 24 28 18 22zM2 6H16V8H2zM6 12H16V14H6zM10 18H16V20H10z"
  })), children);
});
var SortDescending16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SortDescending16(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 22L19.414 20.586 23 24.172 23 4 25 4 25 24.172 28.586 20.586 30 22 24 28 18 22zM2 6H16V8H2zM6 12H16V14H6zM10 18H16V20H10z"
  })), children);
});
var SortRemove32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SortRemove32(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 19.415L28.586 18 25 21.587 21.414 18 20 19.415 23.586 23 20 26.586 21.414 28 25 24.414 28.586 28 30 26.586 26.414 23 30 19.415zM10 18H16V20H10zM2 6H16V8H2zM6 12H16V14H6z"
  })), children);
});
var SortRemove24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SortRemove24(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path390 || (_path390 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 19.415L28.586 18 25 21.587 21.414 18 20 19.415 23.586 23 20 26.586 21.414 28 25 24.414 28.586 28 30 26.586 26.414 23 30 19.415zM10 18H16V20H10zM2 6H16V8H2zM6 12H16V14H6z"
  })), children);
});
var SortRemove20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SortRemove20(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path391 || (_path391 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 19.415L28.586 18 25 21.587 21.414 18 20 19.415 23.586 23 20 26.586 21.414 28 25 24.414 28.586 28 30 26.586 26.414 23 30 19.415zM10 18H16V20H10zM2 6H16V8H2zM6 12H16V14H6z"
  })), children);
});
var SortRemove16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SortRemove16(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path392 || (_path392 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 19.415L28.586 18 25 21.587 21.414 18 20 19.415 23.586 23 20 26.586 21.414 28 25 24.414 28.586 28 30 26.586 26.414 23 30 19.415zM10 18H16V20H10zM2 6H16V8H2zM6 12H16V14H6z"
  })), children);
});
var SpellCheck32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SpellCheck32(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path393 || (_path393 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,22h2L17,10H15L10,22h2l1.24-3h5.53Zm-5.93-5,1.82-4.42h.25L18,17Z"
  })), _path394 || (_path394 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 28H6a2 2 0 01-2-2V6A2 2 0 016 4H26a2 2 0 012 2V17H26V6H6V26h6zM23 27.18L20.41 24.59 19 26 23 30 30 23 28.59 21.59 23 27.18z"
  })), children);
});
var SpellCheck24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SpellCheck24(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path395 || (_path395 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,22h2L17,10H15L10,22h2l1.24-3h5.53Zm-5.93-5,1.82-4.42h.25L18,17Z"
  })), _path396 || (_path396 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 28H6a2 2 0 01-2-2V6A2 2 0 016 4H26a2 2 0 012 2V17H26V6H6V26h6zM23 27.18L20.41 24.59 19 26 23 30 30 23 28.59 21.59 23 27.18z"
  })), children);
});
var SpellCheck20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SpellCheck20(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path397 || (_path397 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,22h2L17,10H15L10,22h2l1.24-3h5.53Zm-5.93-5,1.82-4.42h.25L18,17Z"
  })), _path398 || (_path398 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 28H6a2 2 0 01-2-2V6A2 2 0 016 4H26a2 2 0 012 2V17H26V6H6V26h6zM23 27.18L20.41 24.59 19 26 23 30 30 23 28.59 21.59 23 27.18z"
  })), children);
});
var SpellCheck16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SpellCheck16(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path399 || (_path399 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,22h2L17,10H15L10,22h2l1.24-3h5.53Zm-5.93-5,1.82-4.42h.25L18,17Z"
  })), _path400 || (_path400 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 28H6a2 2 0 01-2-2V6A2 2 0 016 4H26a2 2 0 012 2V17H26V6H6V26h6zM23 27.18L20.41 24.59 19 26 23 30 30 23 28.59 21.59 23 27.18z"
  })), children);
});
var WatsonHealthSpineLabel32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSpineLabel32(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path401 || (_path401 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3 11L3 13 8.59 13 2.29 19.29 3.71 20.71 10 14.41 10 20 12 20 12 11 3 11zM26 13H23V12H21v1H18a2 2 0 00-2 2v2a2 2 0 002 2h3v1h2V19h3a2 2 0 002-2V15A2 2 0 0026 13zm-8 4V15h8v2zM26 23H23V22H21v1H18a2 2 0 00-2 2v2a2 2 0 002 2h3v1h2V29h3a2 2 0 002-2V25A2 2 0 0026 23zm-8 4V25h8v2zM26 3H23V2H21V3H18a2 2 0 00-2 2V7a2 2 0 002 2h3v1h2V9h3a2 2 0 002-2V5A2 2 0 0026 3zM18 7V5h8V7z"
  })), children);
});
var WatsonHealthSpineLabel24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSpineLabel24(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path402 || (_path402 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3 11L3 13 8.59 13 2.29 19.29 3.71 20.71 10 14.41 10 20 12 20 12 11 3 11zM26 13H23V12H21v1H18a2 2 0 00-2 2v2a2 2 0 002 2h3v1h2V19h3a2 2 0 002-2V15A2 2 0 0026 13zm-8 4V15h8v2zM26 23H23V22H21v1H18a2 2 0 00-2 2v2a2 2 0 002 2h3v1h2V29h3a2 2 0 002-2V25A2 2 0 0026 23zm-8 4V25h8v2zM26 3H23V2H21V3H18a2 2 0 00-2 2V7a2 2 0 002 2h3v1h2V9h3a2 2 0 002-2V5A2 2 0 0026 3zM18 7V5h8V7z"
  })), children);
});
var WatsonHealthSpineLabel20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSpineLabel20(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path403 || (_path403 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3 11L3 13 8.59 13 2.29 19.29 3.71 20.71 10 14.41 10 20 12 20 12 11 3 11zM26 13H23V12H21v1H18a2 2 0 00-2 2v2a2 2 0 002 2h3v1h2V19h3a2 2 0 002-2V15A2 2 0 0026 13zm-8 4V15h8v2zM26 23H23V22H21v1H18a2 2 0 00-2 2v2a2 2 0 002 2h3v1h2V29h3a2 2 0 002-2V25A2 2 0 0026 23zm-8 4V25h8v2zM26 3H23V2H21V3H18a2 2 0 00-2 2V7a2 2 0 002 2h3v1h2V9h3a2 2 0 002-2V5A2 2 0 0026 3zM18 7V5h8V7z"
  })), children);
});
var WatsonHealthSpineLabel16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSpineLabel16(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path404 || (_path404 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3 11L3 13 8.59 13 2.29 19.29 3.71 20.71 10 14.41 10 20 12 20 12 11 3 11zM26 13H23V12H21v1H18a2 2 0 00-2 2v2a2 2 0 002 2h3v1h2V19h3a2 2 0 002-2V15A2 2 0 0026 13zm-8 4V15h8v2zM26 23H23V22H21v1H18a2 2 0 00-2 2v2a2 2 0 002 2h3v1h2V29h3a2 2 0 002-2V25A2 2 0 0026 23zm-8 4V25h8v2zM26 3H23V2H21V3H18a2 2 0 00-2 2V7a2 2 0 002 2h3v1h2V9h3a2 2 0 002-2V5A2 2 0 0026 3zM18 7V5h8V7z"
  })), children);
});
var Split32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Split32(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path405 || (_path405 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 20H17V24H15zM15 14H17V18H15zM15 8H17V12H15z"
  })), _path406 || (_path406 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16A12.01,12.01,0,0,0,17,4.0508V2H15V4.0508a11.99,11.99,0,0,0,0,23.8984V30h2V27.9492A12.01,12.01,0,0,0,28,16ZM16,26A10,10,0,1,1,26,16,10.0114,10.0114,0,0,1,16,26Z"
  })), children);
});
var Split24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Split24(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path407 || (_path407 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 20H17V24H15zM15 14H17V18H15zM15 8H17V12H15z"
  })), _path408 || (_path408 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16A12.01,12.01,0,0,0,17,4.0508V2H15V4.0508a11.99,11.99,0,0,0,0,23.8984V30h2V27.9492A12.01,12.01,0,0,0,28,16ZM16,26A10,10,0,1,1,26,16,10.0114,10.0114,0,0,1,16,26Z"
  })), children);
});
var Split20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Split20(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path409 || (_path409 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 20H17V24H15zM15 14H17V18H15zM15 8H17V12H15z"
  })), _path410 || (_path410 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16A12.01,12.01,0,0,0,17,4.0508V2H15V4.0508a11.99,11.99,0,0,0,0,23.8984V30h2V27.9492A12.01,12.01,0,0,0,28,16ZM16,26A10,10,0,1,1,26,16,10.0114,10.0114,0,0,1,16,26Z"
  })), children);
});
var Split16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Split16(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path411 || (_path411 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 20H17V24H15zM15 14H17V18H15zM15 8H17V12H15z"
  })), _path412 || (_path412 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16A12.01,12.01,0,0,0,17,4.0508V2H15V4.0508a11.99,11.99,0,0,0,0,23.8984V30h2V27.9492A12.01,12.01,0,0,0,28,16ZM16,26A10,10,0,1,1,26,16,10.0114,10.0114,0,0,1,16,26Z"
  })), children);
});
var WatsonHealthSplitDiscard32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSplitDiscard32(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path413 || (_path413 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16A12.01,12.01,0,0,0,17,4.0508V2H15V4.0508a11.99,11.99,0,0,0,0,23.8984V30h2V27.9492A12.01,12.01,0,0,0,28,16ZM16,26V6a10,10,0,0,1,0,20Z"
  })), children);
});
var WatsonHealthSplitDiscard24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSplitDiscard24(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path414 || (_path414 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16A12.01,12.01,0,0,0,17,4.0508V2H15V4.0508a11.99,11.99,0,0,0,0,23.8984V30h2V27.9492A12.01,12.01,0,0,0,28,16ZM16,26V6a10,10,0,0,1,0,20Z"
  })), children);
});
var WatsonHealthSplitDiscard20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSplitDiscard20(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path415 || (_path415 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16A12.01,12.01,0,0,0,17,4.0508V2H15V4.0508a11.99,11.99,0,0,0,0,23.8984V30h2V27.9492A12.01,12.01,0,0,0,28,16ZM16,26V6a10,10,0,0,1,0,20Z"
  })), children);
});
var WatsonHealthSplitDiscard16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSplitDiscard16(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path416 || (_path416 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16A12.01,12.01,0,0,0,17,4.0508V2H15V4.0508a11.99,11.99,0,0,0,0,23.8984V30h2V27.9492A12.01,12.01,0,0,0,28,16ZM16,26V6a10,10,0,0,1,0,20Z"
  })), children);
});
var SplitScreen32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SplitScreen32(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path417 || (_path417 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 4H17V28H15zM10 7V25H4V7h6m0-2H4A2 2 0 002 7V25a2 2 0 002 2h6a2 2 0 002-2V7a2 2 0 00-2-2zM28 7V25H22V7h6m0-2H22a2 2 0 00-2 2V25a2 2 0 002 2h6a2 2 0 002-2V7a2 2 0 00-2-2z"
  })), children);
});
var SplitScreen24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SplitScreen24(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path418 || (_path418 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 4H17V28H15zM10 7V25H4V7h6m0-2H4A2 2 0 002 7V25a2 2 0 002 2h6a2 2 0 002-2V7a2 2 0 00-2-2zM28 7V25H22V7h6m0-2H22a2 2 0 00-2 2V25a2 2 0 002 2h6a2 2 0 002-2V7a2 2 0 00-2-2z"
  })), children);
});
var SplitScreen20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SplitScreen20(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path419 || (_path419 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 4H17V28H15zM10 7V25H4V7h6m0-2H4A2 2 0 002 7V25a2 2 0 002 2h6a2 2 0 002-2V7a2 2 0 00-2-2zM28 7V25H22V7h6m0-2H22a2 2 0 00-2 2V25a2 2 0 002 2h6a2 2 0 002-2V7a2 2 0 00-2-2z"
  })), children);
});
var SplitScreen16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SplitScreen16(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path420 || (_path420 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 4H17V28H15zM10 7V25H4V7h6m0-2H4A2 2 0 002 7V25a2 2 0 002 2h6a2 2 0 002-2V7a2 2 0 00-2-2zM28 7V25H22V7h6m0-2H22a2 2 0 00-2 2V25a2 2 0 002 2h6a2 2 0 002-2V7a2 2 0 00-2-2z"
  })), children);
});
var SprayPaint32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SprayPaint32(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path421 || (_path421 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.5,23A4.5,4.5,0,1,1,27,18.5,4.505,4.505,0,0,1,22.5,23Zm0-7A2.5,2.5,0,1,0,25,18.5,2.5026,2.5026,0,0,0,22.5,16Z"
  })), _path422 || (_path422 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 8H26V3H19V8H17a2.002 2.002 0 00-2 2V28a2.0023 2.0023 0 002 2H28a2.0027 2.0027 0 002-2V10A2.0023 2.0023 0 0028 8zM21 5h3V8H21zM17 28V10H28l.002 18zM2 14H5V17H2zM7 9H10V12H7zM2 9H5V12H2zM12 4H15V7H12zM7 4H10V7H7zM2 4H5V7H2z"
  })), children);
});
var SprayPaint24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SprayPaint24(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path423 || (_path423 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.5,23A4.5,4.5,0,1,1,27,18.5,4.505,4.505,0,0,1,22.5,23Zm0-7A2.5,2.5,0,1,0,25,18.5,2.5026,2.5026,0,0,0,22.5,16Z"
  })), _path424 || (_path424 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 8H26V3H19V8H17a2.002 2.002 0 00-2 2V28a2.0023 2.0023 0 002 2H28a2.0027 2.0027 0 002-2V10A2.0023 2.0023 0 0028 8zM21 5h3V8H21zM17 28V10H28l.002 18zM2 14H5V17H2zM7 9H10V12H7zM2 9H5V12H2zM12 4H15V7H12zM7 4H10V7H7zM2 4H5V7H2z"
  })), children);
});
var SprayPaint20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SprayPaint20(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path425 || (_path425 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.5,23A4.5,4.5,0,1,1,27,18.5,4.505,4.505,0,0,1,22.5,23Zm0-7A2.5,2.5,0,1,0,25,18.5,2.5026,2.5026,0,0,0,22.5,16Z"
  })), _path426 || (_path426 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 8H26V3H19V8H17a2.002 2.002 0 00-2 2V28a2.0023 2.0023 0 002 2H28a2.0027 2.0027 0 002-2V10A2.0023 2.0023 0 0028 8zM21 5h3V8H21zM17 28V10H28l.002 18zM2 14H5V17H2zM7 9H10V12H7zM2 9H5V12H2zM12 4H15V7H12zM7 4H10V7H7zM2 4H5V7H2z"
  })), children);
});
var SprayPaint16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SprayPaint16(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path427 || (_path427 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.5,23A4.5,4.5,0,1,1,27,18.5,4.505,4.505,0,0,1,22.5,23Zm0-7A2.5,2.5,0,1,0,25,18.5,2.5026,2.5026,0,0,0,22.5,16Z"
  })), _path428 || (_path428 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 8H26V3H19V8H17a2.002 2.002 0 00-2 2V28a2.0023 2.0023 0 002 2H28a2.0027 2.0027 0 002-2V10A2.0023 2.0023 0 0028 8zM21 5h3V8H21zM17 28V10H28l.002 18zM2 14H5V17H2zM7 9H10V12H7zM2 9H5V12H2zM12 4H15V7H12zM7 4H10V7H7zM2 4H5V7H2z"
  })), children);
});
var Sprout32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sprout32(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path429 || (_path429 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,2A11.01,11.01,0,0,0,14.7549,9.0244,6.9939,6.9939,0,0,0,9,6H6V9a7.0078,7.0078,0,0,0,7,7h1v9.0493a9.9229,9.9229,0,0,0-6.071,2.8794l1.414,1.4141a8,8,0,0,1,12.3086,1.2134l1.6616-1.1128A9.98,9.98,0,0,0,16,25.062V16h1A11.0125,11.0125,0,0,0,28,5V2ZM13,14A5.0057,5.0057,0,0,1,8,9V8H9a5.0054,5.0054,0,0,1,5,5v1ZM26,5a9.01,9.01,0,0,1-9,9H16V13a9.01,9.01,0,0,1,9-9h1Z"
  })), children);
});
var Sprout24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sprout24(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path430 || (_path430 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,2A11.01,11.01,0,0,0,14.7549,9.0244,6.9939,6.9939,0,0,0,9,6H6V9a7.0078,7.0078,0,0,0,7,7h1v9.0493a9.9229,9.9229,0,0,0-6.071,2.8794l1.414,1.4141a8,8,0,0,1,12.3086,1.2134l1.6616-1.1128A9.98,9.98,0,0,0,16,25.062V16h1A11.0125,11.0125,0,0,0,28,5V2ZM13,14A5.0057,5.0057,0,0,1,8,9V8H9a5.0054,5.0054,0,0,1,5,5v1ZM26,5a9.01,9.01,0,0,1-9,9H16V13a9.01,9.01,0,0,1,9-9h1Z"
  })), children);
});
var Sprout20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sprout20(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path431 || (_path431 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,2A11.01,11.01,0,0,0,14.7549,9.0244,6.9939,6.9939,0,0,0,9,6H6V9a7.0078,7.0078,0,0,0,7,7h1v9.0493a9.9229,9.9229,0,0,0-6.071,2.8794l1.414,1.4141a8,8,0,0,1,12.3086,1.2134l1.6616-1.1128A9.98,9.98,0,0,0,16,25.062V16h1A11.0125,11.0125,0,0,0,28,5V2ZM13,14A5.0057,5.0057,0,0,1,8,9V8H9a5.0054,5.0054,0,0,1,5,5v1ZM26,5a9.01,9.01,0,0,1-9,9H16V13a9.01,9.01,0,0,1,9-9h1Z"
  })), children);
});
var Sprout16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sprout16(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path432 || (_path432 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,2A11.01,11.01,0,0,0,14.7549,9.0244,6.9939,6.9939,0,0,0,9,6H6V9a7.0078,7.0078,0,0,0,7,7h1v9.0493a9.9229,9.9229,0,0,0-6.071,2.8794l1.414,1.4141a8,8,0,0,1,12.3086,1.2134l1.6616-1.1128A9.98,9.98,0,0,0,16,25.062V16h1A11.0125,11.0125,0,0,0,28,5V2ZM13,14A5.0057,5.0057,0,0,1,8,9V8H9a5.0054,5.0054,0,0,1,5,5v1ZM26,5a9.01,9.01,0,0,1-9,9H16V13a9.01,9.01,0,0,1,9-9h1Z"
  })), children);
});
var Sql32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sql32(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path433 || (_path433 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21L24 9 22 9 22 23 30 23 30 21 24 21zM18 9H14a2 2 0 00-2 2V21a2 2 0 002 2h1v2a2 2 0 002 2h2V25H17V23h1a2 2 0 002-2V11A2 2 0 0018 9zM14 21V11h4V21zM8 23H2V21H8V17H4a2 2 0 01-2-2V11A2 2 0 014 9h6v2H4v4H8a2 2 0 012 2v4A2 2 0 018 23z"
  })), children);
});
var Sql24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sql24(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path434 || (_path434 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21L24 9 22 9 22 23 30 23 30 21 24 21zM18 9H14a2 2 0 00-2 2V21a2 2 0 002 2h1v2a2 2 0 002 2h2V25H17V23h1a2 2 0 002-2V11A2 2 0 0018 9zM14 21V11h4V21zM8 23H2V21H8V17H4a2 2 0 01-2-2V11A2 2 0 014 9h6v2H4v4H8a2 2 0 012 2v4A2 2 0 018 23z"
  })), children);
});
var Sql20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sql20(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path435 || (_path435 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21L24 9 22 9 22 23 30 23 30 21 24 21zM18 9H14a2 2 0 00-2 2V21a2 2 0 002 2h1v2a2 2 0 002 2h2V25H17V23h1a2 2 0 002-2V11A2 2 0 0018 9zM14 21V11h4V21zM8 23H2V21H8V17H4a2 2 0 01-2-2V11A2 2 0 014 9h6v2H4v4H8a2 2 0 012 2v4A2 2 0 018 23z"
  })), children);
});
var Sql16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sql16(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path436 || (_path436 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21L24 9 22 9 22 23 30 23 30 21 24 21zM18 9H14a2 2 0 00-2 2V21a2 2 0 002 2h1v2a2 2 0 002 2h2V25H17V23h1a2 2 0 002-2V11A2 2 0 0018 9zM14 21V11h4V21zM8 23H2V21H8V17H4a2 2 0 01-2-2V11A2 2 0 014 9h6v2H4v4H8a2 2 0 012 2v4A2 2 0 018 23z"
  })), children);
});
var SquareFillGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SquareFillGlyph(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path437 || (_path437 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3 3H13V13H3z"
  })), children);
});
var StackLimitation32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StackLimitation32(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path438 || (_path438 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 22H16V30H8zM24 12H20v2h4v2H21v2h3v2H20v2h4a2.0027 2.0027 0 002-2V14A2.0023 2.0023 0 0024 12zM16 20H8V12h8zm-6-2h4V14H10zM16 3.41L14.59 2 12 4.59 9.41 2 8 3.41 10.59 6 8 8.59 9.41 10 12 7.41 14.59 10 16 8.59 13.41 6 16 3.41z"
  })), children);
});
var StackLimitation24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StackLimitation24(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path439 || (_path439 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 22H16V30H8zM24 12H20v2h4v2H21v2h3v2H20v2h4a2.0027 2.0027 0 002-2V14A2.0023 2.0023 0 0024 12zM16 20H8V12h8zm-6-2h4V14H10zM16 3.41L14.59 2 12 4.59 9.41 2 8 3.41 10.59 6 8 8.59 9.41 10 12 7.41 14.59 10 16 8.59 13.41 6 16 3.41z"
  })), children);
});
var StackLimitation20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StackLimitation20(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path440 || (_path440 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 22H16V30H8zM24 12H20v2h4v2H21v2h3v2H20v2h4a2.0027 2.0027 0 002-2V14A2.0023 2.0023 0 0024 12zM16 20H8V12h8zm-6-2h4V14H10zM16 3.41L14.59 2 12 4.59 9.41 2 8 3.41 10.59 6 8 8.59 9.41 10 12 7.41 14.59 10 16 8.59 13.41 6 16 3.41z"
  })), children);
});
var StackLimitation16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StackLimitation16(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path441 || (_path441 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 22H16V30H8zM24 12H20v2h4v2H21v2h3v2H20v2h4a2.0027 2.0027 0 002-2V14A2.0023 2.0023 0 0024 12zM16 20H8V12h8zm-6-2h4V14H10zM16 3.41L14.59 2 12 4.59 9.41 2 8 3.41 10.59 6 8 8.59 9.41 10 12 7.41 14.59 10 16 8.59 13.41 6 16 3.41z"
  })), children);
});
var WatsonHealthStackedMove32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStackedMove32(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path442 || (_path442 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,28H4a2,2,0,0,1-2-2V11A2,2,0,0,1,4,9H15a2,2,0,0,1,2,2V26A2,2,0,0,1,15,28ZM4,11V26H15V11Z"
  })), _path443 || (_path443 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6,24.59,7.41,27,10H22V6a2,2,0,0,0-2-2H10V6H20V20h2V12h5l-2.41,2.59L26,16l5-5Z"
  })), children);
});
var WatsonHealthStackedMove24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStackedMove24(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path444 || (_path444 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,28H4a2,2,0,0,1-2-2V11A2,2,0,0,1,4,9H15a2,2,0,0,1,2,2V26A2,2,0,0,1,15,28ZM4,11V26H15V11Z"
  })), _path445 || (_path445 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6,24.59,7.41,27,10H22V6a2,2,0,0,0-2-2H10V6H20V20h2V12h5l-2.41,2.59L26,16l5-5Z"
  })), children);
});
var WatsonHealthStackedMove20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStackedMove20(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path446 || (_path446 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,28H4a2,2,0,0,1-2-2V11A2,2,0,0,1,4,9H15a2,2,0,0,1,2,2V26A2,2,0,0,1,15,28ZM4,11V26H15V11Z"
  })), _path447 || (_path447 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6,24.59,7.41,27,10H22V6a2,2,0,0,0-2-2H10V6H20V20h2V12h5l-2.41,2.59L26,16l5-5Z"
  })), children);
});
var WatsonHealthStackedMove16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStackedMove16(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path448 || (_path448 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,28H4a2,2,0,0,1-2-2V11A2,2,0,0,1,4,9H15a2,2,0,0,1,2,2V26A2,2,0,0,1,15,28ZM4,11V26H15V11Z"
  })), _path449 || (_path449 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6,24.59,7.41,27,10H22V6a2,2,0,0,0-2-2H10V6H20V20h2V12h5l-2.41,2.59L26,16l5-5Z"
  })), children);
});
var WatsonHealthStackedScrolling_132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStackedScrolling_132(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path450 || (_path450 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,30H4a2,2,0,0,1-2-2V14a2,2,0,0,1,2-2H18a2,2,0,0,1,2,2V28A2,2,0,0,1,18,30ZM4,14V28H18V14Z"
  })), _path451 || (_path451 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,23H23V9H9V7H23a2,2,0,0,1,2,2Z"
  })), _path452 || (_path452 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16H28V4H16V2H28a2,2,0,0,1,2,2Z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-25.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-25.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "QT16": () => (/* binding */ QT16),
/* harmony export */   "QT20": () => (/* binding */ QT20),
/* harmony export */   "QT24": () => (/* binding */ QT24),
/* harmony export */   "QT32": () => (/* binding */ QT32),
/* harmony export */   "QTAlt16": () => (/* binding */ QTAlt16),
/* harmony export */   "QTAlt20": () => (/* binding */ QTAlt20),
/* harmony export */   "QTAlt24": () => (/* binding */ QTAlt24),
/* harmony export */   "QTAlt32": () => (/* binding */ QTAlt32),
/* harmony export */   "Stamp16": () => (/* binding */ Stamp16),
/* harmony export */   "Stamp20": () => (/* binding */ Stamp20),
/* harmony export */   "Stamp24": () => (/* binding */ Stamp24),
/* harmony export */   "Stamp32": () => (/* binding */ Stamp32),
/* harmony export */   "Star16": () => (/* binding */ Star16),
/* harmony export */   "Star20": () => (/* binding */ Star20),
/* harmony export */   "Star24": () => (/* binding */ Star24),
/* harmony export */   "Star32": () => (/* binding */ Star32),
/* harmony export */   "StarFilled16": () => (/* binding */ StarFilled16),
/* harmony export */   "StarFilled20": () => (/* binding */ StarFilled20),
/* harmony export */   "StarFilled24": () => (/* binding */ StarFilled24),
/* harmony export */   "StarFilled32": () => (/* binding */ StarFilled32),
/* harmony export */   "StarHalf16": () => (/* binding */ StarHalf16),
/* harmony export */   "StarHalf20": () => (/* binding */ StarHalf20),
/* harmony export */   "StarHalf24": () => (/* binding */ StarHalf24),
/* harmony export */   "StarHalf32": () => (/* binding */ StarHalf32),
/* harmony export */   "StarReview16": () => (/* binding */ StarReview16),
/* harmony export */   "StarReview20": () => (/* binding */ StarReview20),
/* harmony export */   "StarReview24": () => (/* binding */ StarReview24),
/* harmony export */   "StarReview32": () => (/* binding */ StarReview32),
/* harmony export */   "StayInside16": () => (/* binding */ StayInside16),
/* harmony export */   "StayInside20": () => (/* binding */ StayInside20),
/* harmony export */   "StayInside24": () => (/* binding */ StayInside24),
/* harmony export */   "StayInside32": () => (/* binding */ StayInside32),
/* harmony export */   "StemLeafPlot16": () => (/* binding */ StemLeafPlot16),
/* harmony export */   "StemLeafPlot20": () => (/* binding */ StemLeafPlot20),
/* harmony export */   "StemLeafPlot24": () => (/* binding */ StemLeafPlot24),
/* harmony export */   "StemLeafPlot32": () => (/* binding */ StemLeafPlot32),
/* harmony export */   "Stethoscope16": () => (/* binding */ Stethoscope16),
/* harmony export */   "Stethoscope20": () => (/* binding */ Stethoscope20),
/* harmony export */   "Stethoscope24": () => (/* binding */ Stethoscope24),
/* harmony export */   "Stethoscope32": () => (/* binding */ Stethoscope32),
/* harmony export */   "Stop16": () => (/* binding */ Stop16),
/* harmony export */   "Stop20": () => (/* binding */ Stop20),
/* harmony export */   "Stop24": () => (/* binding */ Stop24),
/* harmony export */   "Stop32": () => (/* binding */ Stop32),
/* harmony export */   "StopFilled16": () => (/* binding */ StopFilled16),
/* harmony export */   "StopFilled20": () => (/* binding */ StopFilled20),
/* harmony export */   "StopFilled24": () => (/* binding */ StopFilled24),
/* harmony export */   "StopFilled32": () => (/* binding */ StopFilled32),
/* harmony export */   "StopFilledAlt16": () => (/* binding */ StopFilledAlt16),
/* harmony export */   "StopFilledAlt20": () => (/* binding */ StopFilledAlt20),
/* harmony export */   "StopFilledAlt24": () => (/* binding */ StopFilledAlt24),
/* harmony export */   "StopFilledAlt32": () => (/* binding */ StopFilledAlt32),
/* harmony export */   "StopOutline16": () => (/* binding */ StopOutline16),
/* harmony export */   "StopOutline20": () => (/* binding */ StopOutline20),
/* harmony export */   "StopOutline24": () => (/* binding */ StopOutline24),
/* harmony export */   "StopOutline32": () => (/* binding */ StopOutline32),
/* harmony export */   "StopOutlineFilled16": () => (/* binding */ StopOutlineFilled16),
/* harmony export */   "StopOutlineFilled20": () => (/* binding */ StopOutlineFilled20),
/* harmony export */   "StopOutlineFilled24": () => (/* binding */ StopOutlineFilled24),
/* harmony export */   "StopOutlineFilled32": () => (/* binding */ StopOutlineFilled32),
/* harmony export */   "StopSign16": () => (/* binding */ StopSign16),
/* harmony export */   "StopSign20": () => (/* binding */ StopSign20),
/* harmony export */   "StopSign24": () => (/* binding */ StopSign24),
/* harmony export */   "StopSign32": () => (/* binding */ StopSign32),
/* harmony export */   "StopSignFilled16": () => (/* binding */ StopSignFilled16),
/* harmony export */   "StopSignFilled20": () => (/* binding */ StopSignFilled20),
/* harmony export */   "StopSignFilled24": () => (/* binding */ StopSignFilled24),
/* harmony export */   "StopSignFilled32": () => (/* binding */ StopSignFilled32),
/* harmony export */   "StoragePool16": () => (/* binding */ StoragePool16),
/* harmony export */   "StoragePool20": () => (/* binding */ StoragePool20),
/* harmony export */   "StoragePool24": () => (/* binding */ StoragePool24),
/* harmony export */   "StoragePool32": () => (/* binding */ StoragePool32),
/* harmony export */   "StorageRequest16": () => (/* binding */ StorageRequest16),
/* harmony export */   "StorageRequest20": () => (/* binding */ StorageRequest20),
/* harmony export */   "StorageRequest24": () => (/* binding */ StorageRequest24),
/* harmony export */   "StorageRequest32": () => (/* binding */ StorageRequest32),
/* harmony export */   "Store16": () => (/* binding */ Store16),
/* harmony export */   "Store20": () => (/* binding */ Store20),
/* harmony export */   "Store24": () => (/* binding */ Store24),
/* harmony export */   "Store32": () => (/* binding */ Store32),
/* harmony export */   "StormTracker16": () => (/* binding */ StormTracker16),
/* harmony export */   "StormTracker20": () => (/* binding */ StormTracker20),
/* harmony export */   "StormTracker24": () => (/* binding */ StormTracker24),
/* harmony export */   "StormTracker32": () => (/* binding */ StormTracker32),
/* harmony export */   "Strawberry16": () => (/* binding */ Strawberry16),
/* harmony export */   "Strawberry20": () => (/* binding */ Strawberry20),
/* harmony export */   "Strawberry24": () => (/* binding */ Strawberry24),
/* harmony export */   "Strawberry32": () => (/* binding */ Strawberry32),
/* harmony export */   "StringInteger16": () => (/* binding */ StringInteger16),
/* harmony export */   "StringInteger20": () => (/* binding */ StringInteger20),
/* harmony export */   "StringInteger24": () => (/* binding */ StringInteger24),
/* harmony export */   "StringInteger32": () => (/* binding */ StringInteger32),
/* harmony export */   "StringText16": () => (/* binding */ StringText16),
/* harmony export */   "StringText20": () => (/* binding */ StringText20),
/* harmony export */   "StringText24": () => (/* binding */ StringText24),
/* harmony export */   "StringText32": () => (/* binding */ StringText32),
/* harmony export */   "Subflow16": () => (/* binding */ Subflow16),
/* harmony export */   "Subflow20": () => (/* binding */ Subflow20),
/* harmony export */   "Subflow24": () => (/* binding */ Subflow24),
/* harmony export */   "Subflow32": () => (/* binding */ Subflow32),
/* harmony export */   "SubflowLocal16": () => (/* binding */ SubflowLocal16),
/* harmony export */   "SubflowLocal20": () => (/* binding */ SubflowLocal20),
/* harmony export */   "SubflowLocal24": () => (/* binding */ SubflowLocal24),
/* harmony export */   "SubflowLocal32": () => (/* binding */ SubflowLocal32),
/* harmony export */   "SubnetAclRules16": () => (/* binding */ SubnetAclRules16),
/* harmony export */   "SubnetAclRules20": () => (/* binding */ SubnetAclRules20),
/* harmony export */   "SubnetAclRules24": () => (/* binding */ SubnetAclRules24),
/* harmony export */   "SubnetAclRules32": () => (/* binding */ SubnetAclRules32),
/* harmony export */   "Subtract16": () => (/* binding */ Subtract16),
/* harmony export */   "Subtract20": () => (/* binding */ Subtract20),
/* harmony export */   "Subtract24": () => (/* binding */ Subtract24),
/* harmony export */   "Subtract32": () => (/* binding */ Subtract32),
/* harmony export */   "SubtractAlt16": () => (/* binding */ SubtractAlt16),
/* harmony export */   "SubtractAlt20": () => (/* binding */ SubtractAlt20),
/* harmony export */   "SubtractAlt24": () => (/* binding */ SubtractAlt24),
/* harmony export */   "SubtractAlt32": () => (/* binding */ SubtractAlt32),
/* harmony export */   "SummaryKpi16": () => (/* binding */ SummaryKpi16),
/* harmony export */   "SummaryKpi20": () => (/* binding */ SummaryKpi20),
/* harmony export */   "SummaryKpi24": () => (/* binding */ SummaryKpi24),
/* harmony export */   "SummaryKpi32": () => (/* binding */ SummaryKpi32),
/* harmony export */   "Sun16": () => (/* binding */ Sun16),
/* harmony export */   "Sun20": () => (/* binding */ Sun20),
/* harmony export */   "Sun24": () => (/* binding */ Sun24),
/* harmony export */   "Sun32": () => (/* binding */ Sun32),
/* harmony export */   "Sunny16": () => (/* binding */ Sunny16),
/* harmony export */   "Sunny20": () => (/* binding */ Sunny20),
/* harmony export */   "Sunny24": () => (/* binding */ Sunny24),
/* harmony export */   "Sunny32": () => (/* binding */ Sunny32),
/* harmony export */   "Sunrise16": () => (/* binding */ Sunrise16),
/* harmony export */   "Sunrise20": () => (/* binding */ Sunrise20),
/* harmony export */   "Sunrise24": () => (/* binding */ Sunrise24),
/* harmony export */   "Sunrise32": () => (/* binding */ Sunrise32),
/* harmony export */   "Sunset16": () => (/* binding */ Sunset16),
/* harmony export */   "Sunset20": () => (/* binding */ Sunset20),
/* harmony export */   "Sunset24": () => (/* binding */ Sunset24),
/* harmony export */   "Sunset32": () => (/* binding */ Sunset32),
/* harmony export */   "Svg16": () => (/* binding */ Svg16),
/* harmony export */   "Svg20": () => (/* binding */ Svg20),
/* harmony export */   "Svg24": () => (/* binding */ Svg24),
/* harmony export */   "Svg32": () => (/* binding */ Svg32),
/* harmony export */   "Swim16": () => (/* binding */ Swim16),
/* harmony export */   "Swim20": () => (/* binding */ Swim20),
/* harmony export */   "Swim24": () => (/* binding */ Swim24),
/* harmony export */   "Swim32": () => (/* binding */ Swim32),
/* harmony export */   "SwitchLayer_216": () => (/* binding */ SwitchLayer_216),
/* harmony export */   "SwitchLayer_220": () => (/* binding */ SwitchLayer_220),
/* harmony export */   "SwitchLayer_224": () => (/* binding */ SwitchLayer_224),
/* harmony export */   "SwitchLayer_232": () => (/* binding */ SwitchLayer_232),
/* harmony export */   "SwitchLayer_316": () => (/* binding */ SwitchLayer_316),
/* harmony export */   "SwitchLayer_320": () => (/* binding */ SwitchLayer_320),
/* harmony export */   "SwitchLayer_324": () => (/* binding */ SwitchLayer_324),
/* harmony export */   "SwitchLayer_332": () => (/* binding */ SwitchLayer_332),
/* harmony export */   "Switcher16": () => (/* binding */ Switcher16),
/* harmony export */   "Switcher20": () => (/* binding */ Switcher20),
/* harmony export */   "Switcher24": () => (/* binding */ Switcher24),
/* harmony export */   "Switcher32": () => (/* binding */ Switcher32),
/* harmony export */   "SysProvision16": () => (/* binding */ SysProvision16),
/* harmony export */   "SysProvision20": () => (/* binding */ SysProvision20),
/* harmony export */   "SysProvision24": () => (/* binding */ SysProvision24),
/* harmony export */   "SysProvision32": () => (/* binding */ SysProvision32),
/* harmony export */   "Table16": () => (/* binding */ Table16),
/* harmony export */   "Table20": () => (/* binding */ Table20),
/* harmony export */   "Table24": () => (/* binding */ Table24),
/* harmony export */   "Table32": () => (/* binding */ Table32),
/* harmony export */   "TableAlias16": () => (/* binding */ TableAlias16),
/* harmony export */   "TableAlias20": () => (/* binding */ TableAlias20),
/* harmony export */   "TableAlias24": () => (/* binding */ TableAlias24),
/* harmony export */   "TableAlias32": () => (/* binding */ TableAlias32),
/* harmony export */   "TableBuilt16": () => (/* binding */ TableBuilt16),
/* harmony export */   "TableBuilt20": () => (/* binding */ TableBuilt20),
/* harmony export */   "TableBuilt24": () => (/* binding */ TableBuilt24),
/* harmony export */   "TableBuilt32": () => (/* binding */ TableBuilt32),
/* harmony export */   "TableOfContents16": () => (/* binding */ TableOfContents16),
/* harmony export */   "TableOfContents20": () => (/* binding */ TableOfContents20),
/* harmony export */   "TableOfContents24": () => (/* binding */ TableOfContents24),
/* harmony export */   "TableOfContents32": () => (/* binding */ TableOfContents32),
/* harmony export */   "TableShortcut16": () => (/* binding */ TableShortcut16),
/* harmony export */   "TableShortcut20": () => (/* binding */ TableShortcut20),
/* harmony export */   "TableShortcut24": () => (/* binding */ TableShortcut24),
/* harmony export */   "TableShortcut32": () => (/* binding */ TableShortcut32),
/* harmony export */   "TableSplit16": () => (/* binding */ TableSplit16),
/* harmony export */   "TableSplit20": () => (/* binding */ TableSplit20),
/* harmony export */   "TableSplit24": () => (/* binding */ TableSplit24),
/* harmony export */   "TableSplit32": () => (/* binding */ TableSplit32),
/* harmony export */   "Tablet16": () => (/* binding */ Tablet16),
/* harmony export */   "Tablet20": () => (/* binding */ Tablet20),
/* harmony export */   "Tablet24": () => (/* binding */ Tablet24),
/* harmony export */   "Tablet32": () => (/* binding */ Tablet32),
/* harmony export */   "TabletLandscape20": () => (/* binding */ TabletLandscape20),
/* harmony export */   "TabletLandscape24": () => (/* binding */ TabletLandscape24),
/* harmony export */   "TabletLandscape32": () => (/* binding */ TabletLandscape32),
/* harmony export */   "WatsonHealthStackedScrolling_116": () => (/* binding */ WatsonHealthStackedScrolling_116),
/* harmony export */   "WatsonHealthStackedScrolling_120": () => (/* binding */ WatsonHealthStackedScrolling_120),
/* harmony export */   "WatsonHealthStackedScrolling_124": () => (/* binding */ WatsonHealthStackedScrolling_124),
/* harmony export */   "WatsonHealthStackedScrolling_216": () => (/* binding */ WatsonHealthStackedScrolling_216),
/* harmony export */   "WatsonHealthStackedScrolling_220": () => (/* binding */ WatsonHealthStackedScrolling_220),
/* harmony export */   "WatsonHealthStackedScrolling_224": () => (/* binding */ WatsonHealthStackedScrolling_224),
/* harmony export */   "WatsonHealthStackedScrolling_232": () => (/* binding */ WatsonHealthStackedScrolling_232),
/* harmony export */   "WatsonHealthStatusAcknowledge16": () => (/* binding */ WatsonHealthStatusAcknowledge16),
/* harmony export */   "WatsonHealthStatusAcknowledge20": () => (/* binding */ WatsonHealthStatusAcknowledge20),
/* harmony export */   "WatsonHealthStatusAcknowledge24": () => (/* binding */ WatsonHealthStatusAcknowledge24),
/* harmony export */   "WatsonHealthStatusAcknowledge32": () => (/* binding */ WatsonHealthStatusAcknowledge32),
/* harmony export */   "WatsonHealthStatusChange16": () => (/* binding */ WatsonHealthStatusChange16),
/* harmony export */   "WatsonHealthStatusChange20": () => (/* binding */ WatsonHealthStatusChange20),
/* harmony export */   "WatsonHealthStatusChange24": () => (/* binding */ WatsonHealthStatusChange24),
/* harmony export */   "WatsonHealthStatusChange32": () => (/* binding */ WatsonHealthStatusChange32),
/* harmony export */   "WatsonHealthStatusPartialFail16": () => (/* binding */ WatsonHealthStatusPartialFail16),
/* harmony export */   "WatsonHealthStatusPartialFail20": () => (/* binding */ WatsonHealthStatusPartialFail20),
/* harmony export */   "WatsonHealthStatusPartialFail24": () => (/* binding */ WatsonHealthStatusPartialFail24),
/* harmony export */   "WatsonHealthStatusPartialFail32": () => (/* binding */ WatsonHealthStatusPartialFail32),
/* harmony export */   "WatsonHealthStatusResolved16": () => (/* binding */ WatsonHealthStatusResolved16),
/* harmony export */   "WatsonHealthStatusResolved20": () => (/* binding */ WatsonHealthStatusResolved20),
/* harmony export */   "WatsonHealthStatusResolved24": () => (/* binding */ WatsonHealthStatusResolved24),
/* harmony export */   "WatsonHealthStatusResolved32": () => (/* binding */ WatsonHealthStatusResolved32),
/* harmony export */   "WatsonHealthStressBreathEditor16": () => (/* binding */ WatsonHealthStressBreathEditor16),
/* harmony export */   "WatsonHealthStressBreathEditor20": () => (/* binding */ WatsonHealthStressBreathEditor20),
/* harmony export */   "WatsonHealthStressBreathEditor24": () => (/* binding */ WatsonHealthStressBreathEditor24),
/* harmony export */   "WatsonHealthStressBreathEditor32": () => (/* binding */ WatsonHealthStressBreathEditor32),
/* harmony export */   "WatsonHealthStudyNext16": () => (/* binding */ WatsonHealthStudyNext16),
/* harmony export */   "WatsonHealthStudyNext20": () => (/* binding */ WatsonHealthStudyNext20),
/* harmony export */   "WatsonHealthStudyNext24": () => (/* binding */ WatsonHealthStudyNext24),
/* harmony export */   "WatsonHealthStudyNext32": () => (/* binding */ WatsonHealthStudyNext32),
/* harmony export */   "WatsonHealthStudyPrevious16": () => (/* binding */ WatsonHealthStudyPrevious16),
/* harmony export */   "WatsonHealthStudyPrevious20": () => (/* binding */ WatsonHealthStudyPrevious20),
/* harmony export */   "WatsonHealthStudyPrevious24": () => (/* binding */ WatsonHealthStudyPrevious24),
/* harmony export */   "WatsonHealthStudyPrevious32": () => (/* binding */ WatsonHealthStudyPrevious32),
/* harmony export */   "WatsonHealthStudyRead16": () => (/* binding */ WatsonHealthStudyRead16),
/* harmony export */   "WatsonHealthStudyRead20": () => (/* binding */ WatsonHealthStudyRead20),
/* harmony export */   "WatsonHealthStudyRead24": () => (/* binding */ WatsonHealthStudyRead24),
/* harmony export */   "WatsonHealthStudyRead32": () => (/* binding */ WatsonHealthStudyRead32),
/* harmony export */   "WatsonHealthStudySkip16": () => (/* binding */ WatsonHealthStudySkip16),
/* harmony export */   "WatsonHealthStudySkip20": () => (/* binding */ WatsonHealthStudySkip20),
/* harmony export */   "WatsonHealthStudySkip24": () => (/* binding */ WatsonHealthStudySkip24),
/* harmony export */   "WatsonHealthStudySkip32": () => (/* binding */ WatsonHealthStudySkip32),
/* harmony export */   "WatsonHealthStudyTransfer16": () => (/* binding */ WatsonHealthStudyTransfer16),
/* harmony export */   "WatsonHealthStudyTransfer20": () => (/* binding */ WatsonHealthStudyTransfer20),
/* harmony export */   "WatsonHealthStudyTransfer24": () => (/* binding */ WatsonHealthStudyTransfer24),
/* harmony export */   "WatsonHealthStudyTransfer32": () => (/* binding */ WatsonHealthStudyTransfer32),
/* harmony export */   "WatsonHealthStudyUnread16": () => (/* binding */ WatsonHealthStudyUnread16),
/* harmony export */   "WatsonHealthStudyUnread20": () => (/* binding */ WatsonHealthStudyUnread20),
/* harmony export */   "WatsonHealthStudyUnread24": () => (/* binding */ WatsonHealthStudyUnread24),
/* harmony export */   "WatsonHealthStudyUnread32": () => (/* binding */ WatsonHealthStudyUnread32),
/* harmony export */   "WatsonHealthStudyView16": () => (/* binding */ WatsonHealthStudyView16),
/* harmony export */   "WatsonHealthStudyView20": () => (/* binding */ WatsonHealthStudyView20),
/* harmony export */   "WatsonHealthStudyView24": () => (/* binding */ WatsonHealthStudyView24),
/* harmony export */   "WatsonHealthStudyView32": () => (/* binding */ WatsonHealthStudyView32),
/* harmony export */   "WatsonHealthSubVolume16": () => (/* binding */ WatsonHealthSubVolume16),
/* harmony export */   "WatsonHealthSubVolume20": () => (/* binding */ WatsonHealthSubVolume20),
/* harmony export */   "WatsonHealthSubVolume24": () => (/* binding */ WatsonHealthSubVolume24),
/* harmony export */   "WatsonHealthSubVolume32": () => (/* binding */ WatsonHealthSubVolume32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _path65, _path66, _path67, _path68, _path69, _path70, _path71, _path72, _path73, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _circle, _circle2, _path135, _circle3, _circle4, _path136, _circle5, _circle6, _path137, _circle7, _circle8, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _path224, _path225, _path226, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388, _path389, _path390, _path391, _path392, _path393, _path394, _path395, _path396, _path397, _path398, _path399, _path400, _path401, _path402, _circle9, _path403, _path404, _path405, _circle10, _path406, _path407, _path408, _circle11, _path409, _path410, _path411, _circle12, _path412, _path413, _path414, _path415, _path416, _path417, _path418, _path419, _path420, _path421, _path422, _path423, _path424, _path425, _path426, _path427, _path428, _path429, _path430, _path431, _path432, _path433, _path434, _path435, _path436, _path437, _path438, _path439, _path440, _path441, _path442, _path443, _path444, _path445, _path446, _path447, _path448, _path449, _path450, _path451, _path452, _path453, _path454, _path455, _path456, _path457, _path458, _path459, _path460, _path461, _path462, _path463, _path464, _path465, _path466, _path467;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var didWarnAboutDeprecation = {};
var WatsonHealthStackedScrolling_124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStackedScrolling_124(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,30H4a2,2,0,0,1-2-2V14a2,2,0,0,1,2-2H18a2,2,0,0,1,2,2V28A2,2,0,0,1,18,30ZM4,14V28H18V14Z"
  })), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,23H23V9H9V7H23a2,2,0,0,1,2,2Z"
  })), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16H28V4H16V2H28a2,2,0,0,1,2,2Z"
  })), children);
});
var WatsonHealthStackedScrolling_120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStackedScrolling_120(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,30H4a2,2,0,0,1-2-2V14a2,2,0,0,1,2-2H18a2,2,0,0,1,2,2V28A2,2,0,0,1,18,30ZM4,14V28H18V14Z"
  })), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,23H23V9H9V7H23a2,2,0,0,1,2,2Z"
  })), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16H28V4H16V2H28a2,2,0,0,1,2,2Z"
  })), children);
});
var WatsonHealthStackedScrolling_116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStackedScrolling_116(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,30H4a2,2,0,0,1-2-2V14a2,2,0,0,1,2-2H18a2,2,0,0,1,2,2V28A2,2,0,0,1,18,30ZM4,14V28H18V14Z"
  })), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,23H23V9H9V7H23a2,2,0,0,1,2,2Z"
  })), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16H28V4H16V2H28a2,2,0,0,1,2,2Z"
  })), children);
});
var WatsonHealthStackedScrolling_232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStackedScrolling_232(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30H2a2 2 0 01-2-2V14a2 2 0 012-2H8a2 2 0 012 2V28A2 2 0 018 30zM2 14V28H8V14zM20 30H14a2 2 0 01-2-2V14a2 2 0 012-2h6a2 2 0 012 2V28A2 2 0 0120 30zM14 14V28h6V14z"
  })), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,21H25V9H17V7h8a2,2,0,0,1,2,2Z"
  })), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32,16H30V4H22V2h8a2,2,0,0,1,2,2Z"
  })), children);
});
var WatsonHealthStackedScrolling_224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStackedScrolling_224(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30H2a2 2 0 01-2-2V14a2 2 0 012-2H8a2 2 0 012 2V28A2 2 0 018 30zM2 14V28H8V14zM20 30H14a2 2 0 01-2-2V14a2 2 0 012-2h6a2 2 0 012 2V28A2 2 0 0120 30zM14 14V28h6V14z"
  })), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,21H25V9H17V7h8a2,2,0,0,1,2,2Z"
  })), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32,16H30V4H22V2h8a2,2,0,0,1,2,2Z"
  })), children);
});
var WatsonHealthStackedScrolling_220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStackedScrolling_220(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30H2a2 2 0 01-2-2V14a2 2 0 012-2H8a2 2 0 012 2V28A2 2 0 018 30zM2 14V28H8V14zM20 30H14a2 2 0 01-2-2V14a2 2 0 012-2h6a2 2 0 012 2V28A2 2 0 0120 30zM14 14V28h6V14z"
  })), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,21H25V9H17V7h8a2,2,0,0,1,2,2Z"
  })), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32,16H30V4H22V2h8a2,2,0,0,1,2,2Z"
  })), children);
});
var WatsonHealthStackedScrolling_216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStackedScrolling_216(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30H2a2 2 0 01-2-2V14a2 2 0 012-2H8a2 2 0 012 2V28A2 2 0 018 30zM2 14V28H8V14zM20 30H14a2 2 0 01-2-2V14a2 2 0 012-2h6a2 2 0 012 2V28A2 2 0 0120 30zM14 14V28h6V14z"
  })), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,21H25V9H17V7h8a2,2,0,0,1,2,2Z"
  })), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32,16H30V4H22V2h8a2,2,0,0,1,2,2Z"
  })), children);
});
var Stamp32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Stamp32(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,18H20V14.8982a7.4938,7.4938,0,0,1,1.1587-3.8542,5.9751,5.9751,0,0,0-1.3735-7.7006,5.9968,5.9968,0,0,0-9.6829,3.54,5.91,5.91,0,0,0,.7478,4.175A7.2573,7.2573,0,0,1,12,14.7942V18H6a2.002,2.002,0,0,0-2,2v4a2.0025,2.0025,0,0,0,2,2v2a2.0025,2.0025,0,0,0,2,2H24a2.0025,2.0025,0,0,0,2-2V26a2.0025,2.0025,0,0,0,2-2V20A2.002,2.002,0,0,0,26,18ZM12.07,7.244a3.9994,3.9994,0,1,1,7.3728,2.7731A9.76,9.76,0,0,0,18.0664,14H13.94a9.5433,9.5433,0,0,0-1.376-3.9736A3.9366,3.9366,0,0,1,12.07,7.244ZM18,16v2H14V16Zm6,12H8V26H24ZM6,24V20H26v4Z"
  })), children);
});
var Stamp24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Stamp24(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,18H20V14.8982a7.4938,7.4938,0,0,1,1.1587-3.8542,5.9751,5.9751,0,0,0-1.3735-7.7006,5.9968,5.9968,0,0,0-9.6829,3.54,5.91,5.91,0,0,0,.7478,4.175A7.2573,7.2573,0,0,1,12,14.7942V18H6a2.002,2.002,0,0,0-2,2v4a2.0025,2.0025,0,0,0,2,2v2a2.0025,2.0025,0,0,0,2,2H24a2.0025,2.0025,0,0,0,2-2V26a2.0025,2.0025,0,0,0,2-2V20A2.002,2.002,0,0,0,26,18ZM12.07,7.244a3.9994,3.9994,0,1,1,7.3728,2.7731A9.76,9.76,0,0,0,18.0664,14H13.94a9.5433,9.5433,0,0,0-1.376-3.9736A3.9366,3.9366,0,0,1,12.07,7.244ZM18,16v2H14V16Zm6,12H8V26H24ZM6,24V20H26v4Z"
  })), children);
});
var Stamp20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Stamp20(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,18H20V14.8982a7.4938,7.4938,0,0,1,1.1587-3.8542,5.9751,5.9751,0,0,0-1.3735-7.7006,5.9968,5.9968,0,0,0-9.6829,3.54,5.91,5.91,0,0,0,.7478,4.175A7.2573,7.2573,0,0,1,12,14.7942V18H6a2.002,2.002,0,0,0-2,2v4a2.0025,2.0025,0,0,0,2,2v2a2.0025,2.0025,0,0,0,2,2H24a2.0025,2.0025,0,0,0,2-2V26a2.0025,2.0025,0,0,0,2-2V20A2.002,2.002,0,0,0,26,18ZM12.07,7.244a3.9994,3.9994,0,1,1,7.3728,2.7731A9.76,9.76,0,0,0,18.0664,14H13.94a9.5433,9.5433,0,0,0-1.376-3.9736A3.9366,3.9366,0,0,1,12.07,7.244ZM18,16v2H14V16Zm6,12H8V26H24ZM6,24V20H26v4Z"
  })), children);
});
var Stamp16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Stamp16(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,18H20V14.8982a7.4938,7.4938,0,0,1,1.1587-3.8542,5.9751,5.9751,0,0,0-1.3735-7.7006,5.9968,5.9968,0,0,0-9.6829,3.54,5.91,5.91,0,0,0,.7478,4.175A7.2573,7.2573,0,0,1,12,14.7942V18H6a2.002,2.002,0,0,0-2,2v4a2.0025,2.0025,0,0,0,2,2v2a2.0025,2.0025,0,0,0,2,2H24a2.0025,2.0025,0,0,0,2-2V26a2.0025,2.0025,0,0,0,2-2V20A2.002,2.002,0,0,0,26,18ZM12.07,7.244a3.9994,3.9994,0,1,1,7.3728,2.7731A9.76,9.76,0,0,0,18.0664,14H13.94a9.5433,9.5433,0,0,0-1.376-3.9736A3.9366,3.9366,0,0,1,12.07,7.244ZM18,16v2H14V16Zm6,12H8V26H24ZM6,24V20H26v4Z"
  })), children);
});
var Star32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Star32(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6.52l2.76,5.58.46,1,1,.15,6.16.89L22,18.44l-.75.73.18,1,1.05,6.13-5.51-2.89L16,23l-.93.49L9.56,26.34l1-6.13.18-1L10,18.44,5.58,14.09l6.16-.89,1-.15.46-1L16,6.52M16,2l-4.55,9.22L1.28,12.69l7.36,7.18L6.9,30,16,25.22,25.1,30,23.36,19.87l7.36-7.17L20.55,11.22Z"
  })), children);
});
var Star24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Star24(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6.52l2.76,5.58.46,1,1,.15,6.16.89L22,18.44l-.75.73.18,1,1.05,6.13-5.51-2.89L16,23l-.93.49L9.56,26.34l1-6.13.18-1L10,18.44,5.58,14.09l6.16-.89,1-.15.46-1L16,6.52M16,2l-4.55,9.22L1.28,12.69l7.36,7.18L6.9,30,16,25.22,25.1,30,23.36,19.87l7.36-7.17L20.55,11.22Z"
  })), children);
});
var Star20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Star20(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6.52l2.76,5.58.46,1,1,.15,6.16.89L22,18.44l-.75.73.18,1,1.05,6.13-5.51-2.89L16,23l-.93.49L9.56,26.34l1-6.13.18-1L10,18.44,5.58,14.09l6.16-.89,1-.15.46-1L16,6.52M16,2l-4.55,9.22L1.28,12.69l7.36,7.18L6.9,30,16,25.22,25.1,30,23.36,19.87l7.36-7.17L20.55,11.22Z"
  })), children);
});
var Star16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Star16(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,3.3l1.4,2.8l0.2,0.5l0.5,0.1l3.1,0.4L11,9.2l-0.4,0.4l0.1,0.5l0.5,3.1l-2.8-1.4L8,11.5l-0.5,0.2l-2.8,1.4l0.5-3.1\tl0.1-0.5L5,9.2L2.8,7l3.1-0.4l0.5-0.1L6.6,6L8,3.3 M8,1L5.7,5.6L0.6,6.3l3.7,3.6L3.5,15L8,12.6l4.6,2.4l-0.9-5.1l3.7-3.6l-5.1-0.7\tL8,1z"
  })), children);
});
var StarFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StarFilled32(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2l-4.55,9.22L1.28,12.69l7.36,7.18L6.9,30,16,25.22,25.1,30,23.36,19.87l7.36-7.17L20.55,11.22Z"
  })), children);
});
var StarFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StarFilled24(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2l-4.55,9.22L1.28,12.69l7.36,7.18L6.9,30,16,25.22,25.1,30,23.36,19.87l7.36-7.17L20.55,11.22Z"
  })), children);
});
var StarFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StarFilled20(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2l-4.55,9.22L1.28,12.69l7.36,7.18L6.9,30,16,25.22,25.1,30,23.36,19.87l7.36-7.17L20.55,11.22Z"
  })), children);
});
var StarFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StarFilled16(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,1L5.7,5.6L0.6,6.3l3.7,3.6L3.5,15L8,12.6l4.6,2.4l-0.9-5.1l3.7-3.6l-5.1-0.7L8,1z"
  })), children);
});
var StarHalf32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StarHalf32(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.45 11.22L1.28 12.7 8.64 19.87 6.9 30 16 25.22 16 2 11.45 11.22z"
  })), children);
});
var StarHalf24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StarHalf24(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.45 11.22L1.28 12.7 8.64 19.87 6.9 30 16 25.22 16 2 11.45 11.22z"
  })), children);
});
var StarHalf20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StarHalf20(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.45 11.22L1.28 12.7 8.64 19.87 6.9 30 16 25.22 16 2 11.45 11.22z"
  })), children);
});
var StarHalf16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StarHalf16(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.7 5.6L0.6 6.3 4.3 9.9 3.5 15 8 12.6 8 1z"
  })), children);
});
var StarReview32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StarReview32(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 26H26V28H18zM18 22H30V24H18zM18 18H30V20H18z"
  })), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.549 11.217L16 2 11.451 11.217 1.28 12.695 8.64 19.87 6.902 30 14 26.269 14 24.009 9.559 26.344 10.611 20.208 10.789 19.171 10.036 18.438 5.578 14.091 11.739 13.196 12.779 13.045 13.245 12.102 16 6.519 18.755 12.102 19.221 13.045 20.261 13.196 27.715 14.281 28 12.3 20.549 11.217z"
  })), children);
});
var StarReview24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StarReview24(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 26H26V28H18zM18 22H30V24H18zM18 18H30V20H18z"
  })), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.549 11.217L16 2 11.451 11.217 1.28 12.695 8.64 19.87 6.902 30 14 26.269 14 24.009 9.559 26.344 10.611 20.208 10.789 19.171 10.036 18.438 5.578 14.091 11.739 13.196 12.779 13.045 13.245 12.102 16 6.519 18.755 12.102 19.221 13.045 20.261 13.196 27.715 14.281 28 12.3 20.549 11.217z"
  })), children);
});
var StarReview20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StarReview20(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 26H26V28H18zM18 22H30V24H18zM18 18H30V20H18z"
  })), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.549 11.217L16 2 11.451 11.217 1.28 12.695 8.64 19.87 6.902 30 14 26.269 14 24.009 9.559 26.344 10.611 20.208 10.789 19.171 10.036 18.438 5.578 14.091 11.739 13.196 12.779 13.045 13.245 12.102 16 6.519 18.755 12.102 19.221 13.045 20.261 13.196 27.715 14.281 28 12.3 20.549 11.217z"
  })), children);
});
var StarReview16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StarReview16(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 26H26V28H18zM18 22H30V24H18zM18 18H30V20H18z"
  })), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.549 11.217L16 2 11.451 11.217 1.28 12.695 8.64 19.87 6.902 30 14 26.269 14 24.009 9.559 26.344 10.611 20.208 10.789 19.171 10.036 18.438 5.578 14.091 11.739 13.196 12.779 13.045 13.245 12.102 16 6.519 18.755 12.102 19.221 13.045 20.261 13.196 27.715 14.281 28 12.3 20.549 11.217z"
  })), children);
});
var WatsonHealthStatusAcknowledge32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStatusAcknowledge32(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30a6 6 0 116-6A6.0067 6.0067 0 0124 30zm0-10a4 4 0 104 4A4.0045 4.0045 0 0024 20zM12 15.59L9.41 13 8 14.41 12 18.41 19 11.41 17.59 10 12 15.59z"
  })), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,24A10,10,0,1,1,24,14h2A12,12,0,1,0,14,26Z"
  })), children);
});
var WatsonHealthStatusAcknowledge24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStatusAcknowledge24(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30a6 6 0 116-6A6.0067 6.0067 0 0124 30zm0-10a4 4 0 104 4A4.0045 4.0045 0 0024 20zM12 15.59L9.41 13 8 14.41 12 18.41 19 11.41 17.59 10 12 15.59z"
  })), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,24A10,10,0,1,1,24,14h2A12,12,0,1,0,14,26Z"
  })), children);
});
var WatsonHealthStatusAcknowledge20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStatusAcknowledge20(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30a6 6 0 116-6A6.0067 6.0067 0 0124 30zm0-10a4 4 0 104 4A4.0045 4.0045 0 0024 20zM12 15.59L9.41 13 8 14.41 12 18.41 19 11.41 17.59 10 12 15.59z"
  })), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,24A10,10,0,1,1,24,14h2A12,12,0,1,0,14,26Z"
  })), children);
});
var WatsonHealthStatusAcknowledge16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStatusAcknowledge16(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30a6 6 0 116-6A6.0067 6.0067 0 0124 30zm0-10a4 4 0 104 4A4.0045 4.0045 0 0024 20zM12 15.59L9.41 13 8 14.41 12 18.41 19 11.41 17.59 10 12 15.59z"
  })), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,24A10,10,0,1,1,24,14h2A12,12,0,1,0,14,26Z"
  })), children);
});
var WatsonHealthStatusChange32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStatusChange32(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 30a5 5 0 115-5A5.0057 5.0057 0 017 30zm0-8a3 3 0 103 3A3.0033 3.0033 0 007 22zM23 30a5 5 0 115-5A5.0057 5.0057 0 0123 30zm0-8a3 3 0 103 3A3.0033 3.0033 0 0023 22zM24 7v7l3.5859-3.4141L29 12l-6 6-6-6 1.4141-1.4141L22 14V7a1.0009 1.0009 0 00-1-1H9A1.0006 1.0006 0 008 7V18H6V7A3.0033 3.0033 0 019 4H21A3.0033 3.0033 0 0124 7z"
  })), children);
});
var WatsonHealthStatusChange24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStatusChange24(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 30a5 5 0 115-5A5.0057 5.0057 0 017 30zm0-8a3 3 0 103 3A3.0033 3.0033 0 007 22zM23 30a5 5 0 115-5A5.0057 5.0057 0 0123 30zm0-8a3 3 0 103 3A3.0033 3.0033 0 0023 22zM24 7v7l3.5859-3.4141L29 12l-6 6-6-6 1.4141-1.4141L22 14V7a1.0009 1.0009 0 00-1-1H9A1.0006 1.0006 0 008 7V18H6V7A3.0033 3.0033 0 019 4H21A3.0033 3.0033 0 0124 7z"
  })), children);
});
var WatsonHealthStatusChange20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStatusChange20(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 30a5 5 0 115-5A5.0057 5.0057 0 017 30zm0-8a3 3 0 103 3A3.0033 3.0033 0 007 22zM23 30a5 5 0 115-5A5.0057 5.0057 0 0123 30zm0-8a3 3 0 103 3A3.0033 3.0033 0 0023 22zM24 7v7l3.5859-3.4141L29 12l-6 6-6-6 1.4141-1.4141L22 14V7a1.0009 1.0009 0 00-1-1H9A1.0006 1.0006 0 008 7V18H6V7A3.0033 3.0033 0 019 4H21A3.0033 3.0033 0 0124 7z"
  })), children);
});
var WatsonHealthStatusChange16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStatusChange16(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 30a5 5 0 115-5A5.0057 5.0057 0 017 30zm0-8a3 3 0 103 3A3.0033 3.0033 0 007 22zM23 30a5 5 0 115-5A5.0057 5.0057 0 0123 30zm0-8a3 3 0 103 3A3.0033 3.0033 0 0023 22zM24 7v7l3.5859-3.4141L29 12l-6 6-6-6 1.4141-1.4141L22 14V7a1.0009 1.0009 0 00-1-1H9A1.0006 1.0006 0 008 7V18H6V7A3.0033 3.0033 0 019 4H21A3.0033 3.0033 0 0124 7z"
  })), children);
});
var WatsonHealthStatusPartialFail32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStatusPartialFail32(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.1407 23.7642l1.5315 1.2851a13.976 13.976 0 002.4408-4.1821l-1.8776-.6836A11.9729 11.9729 0 0125.1407 23.7642zM18 27.81l.4128 1.9677A13.8888 13.8888 0 0022.9543 28.14L22 26.4087A12.52 12.52 0 0118 27.81zM10 26.4087L9 28.14a14.14 14.14 0 004.5872 1.6382l.3469-1.9677A12.1519 12.1519 0 0110 26.4087zM4.7646 20.1836l-1.8776.6836a13.976 13.976 0 002.4408 4.1821l1.5315-1.2851A11.9729 11.9729 0 014.7646 20.1836zM16 22a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 22zM15 8H17V19H15z"
  })), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16H28A12,12,0,0,0,4,16H2a14,14,0,0,1,28,0Z"
  })), children);
});
var WatsonHealthStatusPartialFail24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStatusPartialFail24(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.1407 23.7642l1.5315 1.2851a13.976 13.976 0 002.4408-4.1821l-1.8776-.6836A11.9729 11.9729 0 0125.1407 23.7642zM18 27.81l.4128 1.9677A13.8888 13.8888 0 0022.9543 28.14L22 26.4087A12.52 12.52 0 0118 27.81zM10 26.4087L9 28.14a14.14 14.14 0 004.5872 1.6382l.3469-1.9677A12.1519 12.1519 0 0110 26.4087zM4.7646 20.1836l-1.8776.6836a13.976 13.976 0 002.4408 4.1821l1.5315-1.2851A11.9729 11.9729 0 014.7646 20.1836zM16 22a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 22zM15 8H17V19H15z"
  })), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16H28A12,12,0,0,0,4,16H2a14,14,0,0,1,28,0Z"
  })), children);
});
var WatsonHealthStatusPartialFail20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStatusPartialFail20(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.1407 23.7642l1.5315 1.2851a13.976 13.976 0 002.4408-4.1821l-1.8776-.6836A11.9729 11.9729 0 0125.1407 23.7642zM18 27.81l.4128 1.9677A13.8888 13.8888 0 0022.9543 28.14L22 26.4087A12.52 12.52 0 0118 27.81zM10 26.4087L9 28.14a14.14 14.14 0 004.5872 1.6382l.3469-1.9677A12.1519 12.1519 0 0110 26.4087zM4.7646 20.1836l-1.8776.6836a13.976 13.976 0 002.4408 4.1821l1.5315-1.2851A11.9729 11.9729 0 014.7646 20.1836zM16 22a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 22zM15 8H17V19H15z"
  })), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16H28A12,12,0,0,0,4,16H2a14,14,0,0,1,28,0Z"
  })), children);
});
var WatsonHealthStatusPartialFail16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStatusPartialFail16(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.1407 23.7642l1.5315 1.2851a13.976 13.976 0 002.4408-4.1821l-1.8776-.6836A11.9729 11.9729 0 0125.1407 23.7642zM18 27.81l.4128 1.9677A13.8888 13.8888 0 0022.9543 28.14L22 26.4087A12.52 12.52 0 0118 27.81zM10 26.4087L9 28.14a14.14 14.14 0 004.5872 1.6382l.3469-1.9677A12.1519 12.1519 0 0110 26.4087zM4.7646 20.1836l-1.8776.6836a13.976 13.976 0 002.4408 4.1821l1.5315-1.2851A11.9729 11.9729 0 014.7646 20.1836zM16 22a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 22zM15 8H17V19H15z"
  })), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16H28A12,12,0,0,0,4,16H2a14,14,0,0,1,28,0Z"
  })), children);
});
var WatsonHealthStatusResolved32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStatusResolved32(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 28.414L16 23.413 17.413 22 21 25.586 28.585 18 30 19.415 21 28.414zM12 15.59L9.41 13 8 14.41 12 18.41 19 11.41 17.59 10 12 15.59z"
  })), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.8193,25.8022a11.992,11.992,0,1,1,13.9829-9.6215l-1.9668-.3614A10.001,10.001,0,1,0,12.1807,23.835Z"
  })), children);
});
var WatsonHealthStatusResolved24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStatusResolved24(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 28.414L16 23.413 17.413 22 21 25.586 28.585 18 30 19.415 21 28.414zM12 15.59L9.41 13 8 14.41 12 18.41 19 11.41 17.59 10 12 15.59z"
  })), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.8193,25.8022a11.992,11.992,0,1,1,13.9829-9.6215l-1.9668-.3614A10.001,10.001,0,1,0,12.1807,23.835Z"
  })), children);
});
var WatsonHealthStatusResolved20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStatusResolved20(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 28.414L16 23.413 17.413 22 21 25.586 28.585 18 30 19.415 21 28.414zM12 15.59L9.41 13 8 14.41 12 18.41 19 11.41 17.59 10 12 15.59z"
  })), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.8193,25.8022a11.992,11.992,0,1,1,13.9829-9.6215l-1.9668-.3614A10.001,10.001,0,1,0,12.1807,23.835Z"
  })), children);
});
var WatsonHealthStatusResolved16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStatusResolved16(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 28.414L16 23.413 17.413 22 21 25.586 28.585 18 30 19.415 21 28.414zM12 15.59L9.41 13 8 14.41 12 18.41 19 11.41 17.59 10 12 15.59z"
  })), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.8193,25.8022a11.992,11.992,0,1,1,13.9829-9.6215l-1.9668-.3614A10.001,10.001,0,1,0,12.1807,23.835Z"
  })), children);
});
var StayInside32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StayInside32(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 30H21V28a3.0033 3.0033 0 00-3-3H14a3.0033 3.0033 0 00-3 3v2H9V28a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM16 13a3 3 0 11-3 3 3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0016 11z"
  })), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H28V14.4639L16,4.31,4,14.4639V30H2V14a1,1,0,0,1,.354-.7634l13-11a1,1,0,0,1,1.292,0l13,11A1,1,0,0,1,30,14Z"
  })), children);
});
var StayInside24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StayInside24(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 30H21V28a3.0033 3.0033 0 00-3-3H14a3.0033 3.0033 0 00-3 3v2H9V28a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM16 13a3 3 0 11-3 3 3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0016 11z"
  })), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H28V14.4639L16,4.31,4,14.4639V30H2V14a1,1,0,0,1,.354-.7634l13-11a1,1,0,0,1,1.292,0l13,11A1,1,0,0,1,30,14Z"
  })), children);
});
var StayInside20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StayInside20(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 30H21V28a3.0033 3.0033 0 00-3-3H14a3.0033 3.0033 0 00-3 3v2H9V28a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM16 13a3 3 0 11-3 3 3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0016 11z"
  })), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H28V14.4639L16,4.31,4,14.4639V30H2V14a1,1,0,0,1,.354-.7634l13-11a1,1,0,0,1,1.292,0l13,11A1,1,0,0,1,30,14Z"
  })), children);
});
var StayInside16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StayInside16(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 30H21V28a3.0033 3.0033 0 00-3-3H14a3.0033 3.0033 0 00-3 3v2H9V28a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM16 13a3 3 0 11-3 3 3 3 0 013-3m0-2a5 5 0 105 5A5 5 0 0016 11z"
  })), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H28V14.4639L16,4.31,4,14.4639V30H2V14a1,1,0,0,1,.354-.7634l13-11a1,1,0,0,1,1.292,0l13,11A1,1,0,0,1,30,14Z"
  })), children);
});
var StemLeafPlot32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StemLeafPlot32(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 10a3 3 0 113-3A3.0033 3.0033 0 0119 10zm0-4a1 1 0 101 1A1.0011 1.0011 0 0019 6zM19 19a3 3 0 113-3A3.0033 3.0033 0 0119 19zm0-4a1 1 0 101 1A1.0011 1.0011 0 0019 15zM27 19a3 3 0 113-3A3.0033 3.0033 0 0127 19zm0-4a1 1 0 101 1A1.0011 1.0011 0 0027 15zM19 28a3 3 0 113-3A3.0033 3.0033 0 0119 28zm0-4a1 1 0 101 1A1.0011 1.0011 0 0019 24zM12 2H14V30H12zM7 28a3 3 0 113-3A3.0033 3.0033 0 017 28zm0-4a1 1 0 101 1A1.0011 1.0011 0 007 24zM7 19a3 3 0 113-3A3.0033 3.0033 0 017 19zm0-4a1 1 0 101 1A1.0011 1.0011 0 007 15zM7 10a3 3 0 113-3A3.0033 3.0033 0 017 10zM7 6A1 1 0 108 7 1.0011 1.0011 0 007 6z"
  })), children);
});
var StemLeafPlot24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StemLeafPlot24(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 10a3 3 0 113-3A3.0033 3.0033 0 0119 10zm0-4a1 1 0 101 1A1.0011 1.0011 0 0019 6zM19 19a3 3 0 113-3A3.0033 3.0033 0 0119 19zm0-4a1 1 0 101 1A1.0011 1.0011 0 0019 15zM27 19a3 3 0 113-3A3.0033 3.0033 0 0127 19zm0-4a1 1 0 101 1A1.0011 1.0011 0 0027 15zM19 28a3 3 0 113-3A3.0033 3.0033 0 0119 28zm0-4a1 1 0 101 1A1.0011 1.0011 0 0019 24zM12 2H14V30H12zM7 28a3 3 0 113-3A3.0033 3.0033 0 017 28zm0-4a1 1 0 101 1A1.0011 1.0011 0 007 24zM7 19a3 3 0 113-3A3.0033 3.0033 0 017 19zm0-4a1 1 0 101 1A1.0011 1.0011 0 007 15zM7 10a3 3 0 113-3A3.0033 3.0033 0 017 10zM7 6A1 1 0 108 7 1.0011 1.0011 0 007 6z"
  })), children);
});
var StemLeafPlot20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StemLeafPlot20(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 10a3 3 0 113-3A3.0033 3.0033 0 0119 10zm0-4a1 1 0 101 1A1.0011 1.0011 0 0019 6zM19 19a3 3 0 113-3A3.0033 3.0033 0 0119 19zm0-4a1 1 0 101 1A1.0011 1.0011 0 0019 15zM27 19a3 3 0 113-3A3.0033 3.0033 0 0127 19zm0-4a1 1 0 101 1A1.0011 1.0011 0 0027 15zM19 28a3 3 0 113-3A3.0033 3.0033 0 0119 28zm0-4a1 1 0 101 1A1.0011 1.0011 0 0019 24zM12 2H14V30H12zM7 28a3 3 0 113-3A3.0033 3.0033 0 017 28zm0-4a1 1 0 101 1A1.0011 1.0011 0 007 24zM7 19a3 3 0 113-3A3.0033 3.0033 0 017 19zm0-4a1 1 0 101 1A1.0011 1.0011 0 007 15zM7 10a3 3 0 113-3A3.0033 3.0033 0 017 10zM7 6A1 1 0 108 7 1.0011 1.0011 0 007 6z"
  })), children);
});
var StemLeafPlot16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StemLeafPlot16(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 10a3 3 0 113-3A3.0033 3.0033 0 0119 10zm0-4a1 1 0 101 1A1.0011 1.0011 0 0019 6zM19 19a3 3 0 113-3A3.0033 3.0033 0 0119 19zm0-4a1 1 0 101 1A1.0011 1.0011 0 0019 15zM27 19a3 3 0 113-3A3.0033 3.0033 0 0127 19zm0-4a1 1 0 101 1A1.0011 1.0011 0 0027 15zM19 28a3 3 0 113-3A3.0033 3.0033 0 0119 28zm0-4a1 1 0 101 1A1.0011 1.0011 0 0019 24zM12 2H14V30H12zM7 28a3 3 0 113-3A3.0033 3.0033 0 017 28zm0-4a1 1 0 101 1A1.0011 1.0011 0 007 24zM7 19a3 3 0 113-3A3.0033 3.0033 0 017 19zm0-4a1 1 0 101 1A1.0011 1.0011 0 007 15zM7 10a3 3 0 113-3A3.0033 3.0033 0 017 10zM7 6A1 1 0 108 7 1.0011 1.0011 0 007 6z"
  })), children);
});
var Stethoscope32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Stethoscope32(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,2V4h2v6a4,4,0,0,1-8,0V4h2V2H16v8a6.0051,6.0051,0,0,0,5,5.91V22A6,6,0,0,1,9,22V15.8579a4,4,0,1,0-2,0V22a8,8,0,0,0,16,0V15.91A6.0051,6.0051,0,0,0,28,10V2ZM6,12a2,2,0,1,1,2,2A2.0023,2.0023,0,0,1,6,12Z"
  })), children);
});
var Stethoscope24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Stethoscope24(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,2V4h2v6a4,4,0,0,1-8,0V4h2V2H16v8a6.0051,6.0051,0,0,0,5,5.91V22A6,6,0,0,1,9,22V15.8579a4,4,0,1,0-2,0V22a8,8,0,0,0,16,0V15.91A6.0051,6.0051,0,0,0,28,10V2ZM6,12a2,2,0,1,1,2,2A2.0023,2.0023,0,0,1,6,12Z"
  })), children);
});
var Stethoscope20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Stethoscope20(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,2V4h2v6a4,4,0,0,1-8,0V4h2V2H16v8a6.0051,6.0051,0,0,0,5,5.91V22A6,6,0,0,1,9,22V15.8579a4,4,0,1,0-2,0V22a8,8,0,0,0,16,0V15.91A6.0051,6.0051,0,0,0,28,10V2ZM6,12a2,2,0,1,1,2,2A2.0023,2.0023,0,0,1,6,12Z"
  })), children);
});
var Stethoscope16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Stethoscope16(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,2V4h2v6a4,4,0,0,1-8,0V4h2V2H16v8a6.0051,6.0051,0,0,0,5,5.91V22A6,6,0,0,1,9,22V15.8579a4,4,0,1,0-2,0V22a8,8,0,0,0,16,0V15.91A6.0051,6.0051,0,0,0,28,10V2ZM6,12a2,2,0,1,1,2,2A2.0023,2.0023,0,0,1,6,12Z"
  })), children);
});
var Stop32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Stop32(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,8V24H8V8H24m0-2H8A2,2,0,0,0,6,8V24a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V8a2,2,0,0,0-2-2Z"
  })), children);
});
var Stop24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Stop24(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,8V24H8V8H24m0-2H8A2,2,0,0,0,6,8V24a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V8a2,2,0,0,0-2-2Z"
  })), children);
});
var Stop20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Stop20(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,8V24H8V8H24m0-2H8A2,2,0,0,0,6,8V24a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V8a2,2,0,0,0-2-2Z"
  })), children);
});
var Stop16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Stop16(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,4v8H4V4H12 M12,3H4C3.4,3,3,3.4,3,4v8c0,0.6,0.4,1,1,1h8c0.6,0,1-0.4,1-1V4C13,3.4,12.6,3,12,3z"
  })), children);
});
var StopFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopFilled32(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm6,18a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V12a2,2,0,0,1,2-2h8a2,2,0,0,1,2,2Z"
  })), children);
});
var StopFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopFilled24(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm6,18a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V12a2,2,0,0,1,2-2h8a2,2,0,0,1,2,2Z"
  })), children);
});
var StopFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopFilled20(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm6,18a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V12a2,2,0,0,1,2-2h8a2,2,0,0,1,2,2Z"
  })), children);
});
var StopFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopFilled16(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,1C4.1,1,1,4.1,1,8s3.1,7,7,7s7-3.1,7-7S11.9,1,8,1z M11,10c0,0.6-0.4,1-1,1H6c-0.6,0-1-0.4-1-1V6c0-0.6,0.4-1,1-1h4\tc0.6,0,1,0.4,1,1V10z"
  })), children);
});
var StopFilledAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopFilledAlt32(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,6H8A2,2,0,0,0,6,8V24a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V8a2,2,0,0,0-2-2Z"
  })), children);
});
var StopFilledAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopFilledAlt24(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,6H8A2,2,0,0,0,6,8V24a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V8a2,2,0,0,0-2-2Z"
  })), children);
});
var StopFilledAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopFilledAlt20(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,6H8A2,2,0,0,0,6,8V24a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V8a2,2,0,0,0-2-2Z"
  })), children);
});
var StopFilledAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopFilledAlt16(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,6H8A2,2,0,0,0,6,8V24a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V8a2,2,0,0,0-2-2Z"
  })), children);
});
var StopOutline32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopOutline32(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12,12,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,12v8H12V12h8m0-2H12a2,2,0,0,0-2,2v8a2,2,0,0,0,2,2h8a2,2,0,0,0,2-2V12a2,2,0,0,0-2-2Z"
  })), children);
});
var StopOutline24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopOutline24(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12,12,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,12v8H12V12h8m0-2H12a2,2,0,0,0-2,2v8a2,2,0,0,0,2,2h8a2,2,0,0,0,2-2V12a2,2,0,0,0-2-2Z"
  })), children);
});
var StopOutline20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopOutline20(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12,12,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,12v8H12V12h8m0-2H12a2,2,0,0,0-2,2v8a2,2,0,0,0,2,2h8a2,2,0,0,0,2-2V12a2,2,0,0,0-2-2Z"
  })), children);
});
var StopOutline16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopOutline16(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,2c3.3,0,6,2.7,6,6s-2.7,6-6,6s-6-2.7-6-6S4.7,2,8,2 M8,1C4.1,1,1,4.1,1,8s3.1,7,7,7s7-3.1,7-7S11.9,1,8,1z"
  })), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,6v4H6V6H10 M10,5H6C5.4,5,5,5.4,5,6v4c0,0.6,0.4,1,1,1h4c0.6,0,1-0.4,1-1V6C11,5.4,10.6,5,10,5z"
  })), children);
});
var StopOutlineFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopOutlineFilled32(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm6,18a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V12a2,2,0,0,1,2-2h8a2,2,0,0,1,2,2Z"
  })), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 12H20V20H12z"
  })), children);
});
var StopOutlineFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopOutlineFilled24(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm6,18a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V12a2,2,0,0,1,2-2h8a2,2,0,0,1,2,2Z"
  })), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 12H20V20H12z"
  })), children);
});
var StopOutlineFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopOutlineFilled20(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm6,18a2,2,0,0,1-2,2H12a2,2,0,0,1-2-2V12a2,2,0,0,1,2-2h8a2,2,0,0,1,2,2Z"
  })), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 12H20V20H12z"
  })), children);
});
var StopOutlineFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopOutlineFilled16(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,1C4.1,1,1,4.1,1,8s3.1,7,7,7s7-3.1,7-7S11.9,1,8,1z M11,10c0,0.6-0.4,1-1,1H6c-0.6,0-1-0.4-1-1V6c0-0.6,0.4-1,1-1h4\tc0.6,0,1,0.4,1,1V10z"
  })), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 6H10V10H6z"
  })), children);
});
var StopSign32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopSign32(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.5857,29H11.4143A1.9865,1.9865,0,0,1,10,28.4141L3.5859,22A1.9865,1.9865,0,0,1,3,20.5857V11.4143A1.9865,1.9865,0,0,1,3.5859,10L10,3.5859A1.9865,1.9865,0,0,1,11.4143,3h9.1714A1.9865,1.9865,0,0,1,22,3.5859L28.4141,10A1.9865,1.9865,0,0,1,29,11.4143v9.1714A1.9865,1.9865,0,0,1,28.4141,22L22,28.4141A1.9865,1.9865,0,0,1,20.5857,29ZM11.4141,5,5,11.4141v9.1716L11.4141,27h9.1716L27,20.5859V11.4143L20.5859,5H11.4141Z"
  })), children);
});
var StopSign24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopSign24(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.5857,29H11.4143A1.9865,1.9865,0,0,1,10,28.4141L3.5859,22A1.9865,1.9865,0,0,1,3,20.5857V11.4143A1.9865,1.9865,0,0,1,3.5859,10L10,3.5859A1.9865,1.9865,0,0,1,11.4143,3h9.1714A1.9865,1.9865,0,0,1,22,3.5859L28.4141,10A1.9865,1.9865,0,0,1,29,11.4143v9.1714A1.9865,1.9865,0,0,1,28.4141,22L22,28.4141A1.9865,1.9865,0,0,1,20.5857,29ZM11.4141,5,5,11.4141v9.1716L11.4141,27h9.1716L27,20.5859V11.4143L20.5859,5H11.4141Z"
  })), children);
});
var StopSign20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopSign20(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.5857,29H11.4143A1.9865,1.9865,0,0,1,10,28.4141L3.5859,22A1.9865,1.9865,0,0,1,3,20.5857V11.4143A1.9865,1.9865,0,0,1,3.5859,10L10,3.5859A1.9865,1.9865,0,0,1,11.4143,3h9.1714A1.9865,1.9865,0,0,1,22,3.5859L28.4141,10A1.9865,1.9865,0,0,1,29,11.4143v9.1714A1.9865,1.9865,0,0,1,28.4141,22L22,28.4141A1.9865,1.9865,0,0,1,20.5857,29ZM11.4141,5,5,11.4141v9.1716L11.4141,27h9.1716L27,20.5859V11.4143L20.5859,5H11.4141Z"
  })), children);
});
var StopSign16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopSign16(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.5857,29H11.4143A1.9865,1.9865,0,0,1,10,28.4141L3.5859,22A1.9865,1.9865,0,0,1,3,20.5857V11.4143A1.9865,1.9865,0,0,1,3.5859,10L10,3.5859A1.9865,1.9865,0,0,1,11.4143,3h9.1714A1.9865,1.9865,0,0,1,22,3.5859L28.4141,10A1.9865,1.9865,0,0,1,29,11.4143v9.1714A1.9865,1.9865,0,0,1,28.4141,22L22,28.4141A1.9865,1.9865,0,0,1,20.5857,29ZM11.4141,5,5,11.4141v9.1716L11.4141,27h9.1716L27,20.5859V11.4143L20.5859,5H11.4141Z"
  })), children);
});
var StopSignFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopSignFilled32(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.5857,29H11.4143A1.9865,1.9865,0,0,1,10,28.4141L3.5859,22A1.9865,1.9865,0,0,1,3,20.5857V11.4143A1.9865,1.9865,0,0,1,3.5859,10L10,3.5859A1.9865,1.9865,0,0,1,11.4143,3h9.1714A1.9865,1.9865,0,0,1,22,3.5859L28.4141,10A1.9865,1.9865,0,0,1,29,11.4143v9.1714A1.9865,1.9865,0,0,1,28.4141,22L22,28.4141A1.9865,1.9865,0,0,1,20.5857,29Z"
  })), children);
});
var StopSignFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopSignFilled24(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.5857,29H11.4143A1.9865,1.9865,0,0,1,10,28.4141L3.5859,22A1.9865,1.9865,0,0,1,3,20.5857V11.4143A1.9865,1.9865,0,0,1,3.5859,10L10,3.5859A1.9865,1.9865,0,0,1,11.4143,3h9.1714A1.9865,1.9865,0,0,1,22,3.5859L28.4141,10A1.9865,1.9865,0,0,1,29,11.4143v9.1714A1.9865,1.9865,0,0,1,28.4141,22L22,28.4141A1.9865,1.9865,0,0,1,20.5857,29Z"
  })), children);
});
var StopSignFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopSignFilled20(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.5857,29H11.4143A1.9865,1.9865,0,0,1,10,28.4141L3.5859,22A1.9865,1.9865,0,0,1,3,20.5857V11.4143A1.9865,1.9865,0,0,1,3.5859,10L10,3.5859A1.9865,1.9865,0,0,1,11.4143,3h9.1714A1.9865,1.9865,0,0,1,22,3.5859L28.4141,10A1.9865,1.9865,0,0,1,29,11.4143v9.1714A1.9865,1.9865,0,0,1,28.4141,22L22,28.4141A1.9865,1.9865,0,0,1,20.5857,29Z"
  })), children);
});
var StopSignFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StopSignFilled16(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.5857,29H11.4143A1.9865,1.9865,0,0,1,10,28.4141L3.5859,22A1.9865,1.9865,0,0,1,3,20.5857V11.4143A1.9865,1.9865,0,0,1,3.5859,10L10,3.5859A1.9865,1.9865,0,0,1,11.4143,3h9.1714A1.9865,1.9865,0,0,1,22,3.5859L28.4141,10A1.9865,1.9865,0,0,1,29,11.4143v9.1714A1.9865,1.9865,0,0,1,28.4141,22L22,28.4141A1.9865,1.9865,0,0,1,20.5857,29Z"
  })), children);
});
var StoragePool32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StoragePool32(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.5 13A3.5 3.5 0 1121 9.5 3.5041 3.5041 0 0117.5 13zm0-5A1.5 1.5 0 1019 9.5 1.5017 1.5017 0 0017.5 8zM14.5 26A3.5 3.5 0 1118 22.5 3.5041 3.5041 0 0114.5 26zm0-5A1.5 1.5 0 1016 22.5 1.5017 1.5017 0 0014.5 21zM9.5 18A3.5 3.5 0 1113 14.5 3.5041 3.5041 0 019.5 18zm0-5A1.5 1.5 0 1011 14.5 1.5017 1.5017 0 009.5 13zM22.5 21A3.5 3.5 0 1126 17.5 3.5041 3.5041 0 0122.5 21zm0-5A1.5 1.5 0 1024 17.5 1.5017 1.5017 0 0022.5 16z"
  })), children);
});
var StoragePool24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StoragePool24(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.5 13A3.5 3.5 0 1121 9.5 3.5041 3.5041 0 0117.5 13zm0-5A1.5 1.5 0 1019 9.5 1.5017 1.5017 0 0017.5 8zM14.5 26A3.5 3.5 0 1118 22.5 3.5041 3.5041 0 0114.5 26zm0-5A1.5 1.5 0 1016 22.5 1.5017 1.5017 0 0014.5 21zM9.5 18A3.5 3.5 0 1113 14.5 3.5041 3.5041 0 019.5 18zm0-5A1.5 1.5 0 1011 14.5 1.5017 1.5017 0 009.5 13zM22.5 21A3.5 3.5 0 1126 17.5 3.5041 3.5041 0 0122.5 21zm0-5A1.5 1.5 0 1024 17.5 1.5017 1.5017 0 0022.5 16z"
  })), children);
});
var StoragePool20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StoragePool20(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.5 13A3.5 3.5 0 1121 9.5 3.5041 3.5041 0 0117.5 13zm0-5A1.5 1.5 0 1019 9.5 1.5017 1.5017 0 0017.5 8zM14.5 26A3.5 3.5 0 1118 22.5 3.5041 3.5041 0 0114.5 26zm0-5A1.5 1.5 0 1016 22.5 1.5017 1.5017 0 0014.5 21zM9.5 18A3.5 3.5 0 1113 14.5 3.5041 3.5041 0 019.5 18zm0-5A1.5 1.5 0 1011 14.5 1.5017 1.5017 0 009.5 13zM22.5 21A3.5 3.5 0 1126 17.5 3.5041 3.5041 0 0122.5 21zm0-5A1.5 1.5 0 1024 17.5 1.5017 1.5017 0 0022.5 16z"
  })), children);
});
var StoragePool16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StoragePool16(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.5 13A3.5 3.5 0 1121 9.5 3.5041 3.5041 0 0117.5 13zm0-5A1.5 1.5 0 1019 9.5 1.5017 1.5017 0 0017.5 8zM14.5 26A3.5 3.5 0 1118 22.5 3.5041 3.5041 0 0114.5 26zm0-5A1.5 1.5 0 1016 22.5 1.5017 1.5017 0 0014.5 21zM9.5 18A3.5 3.5 0 1113 14.5 3.5041 3.5041 0 019.5 18zm0-5A1.5 1.5 0 1011 14.5 1.5017 1.5017 0 009.5 13zM22.5 21A3.5 3.5 0 1126 17.5 3.5041 3.5041 0 0122.5 21zm0-5A1.5 1.5 0 1024 17.5 1.5017 1.5017 0 0022.5 16z"
  })), children);
});
var StorageRequest32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StorageRequest32(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 21H2v3a2.0059 2.0059 0 002 2H7V24H4zM4 8H7V6H4A2.0059 2.0059 0 002 8v3H4zM17 6H23V8H17zM9 6H15V8H9zM17 24H23V26H17zM28 15L4 15 4 13 2 13 2 19 4 19 4 17 28 17 28 19 30 19 30 13 28 13 28 15zM28 24H25v2h3a2.0059 2.0059 0 002-2V21H28zM28 6H25V8h3v3h2V8A2.0059 2.0059 0 0028 6zM9 24H15V26H9z"
  })), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "12",
    r: "1"
  })), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "20",
    r: "1"
  })), children);
});
var StorageRequest24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StorageRequest24(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 21H2v3a2.0059 2.0059 0 002 2H7V24H4zM4 8H7V6H4A2.0059 2.0059 0 002 8v3H4zM17 6H23V8H17zM9 6H15V8H9zM17 24H23V26H17zM28 15L4 15 4 13 2 13 2 19 4 19 4 17 28 17 28 19 30 19 30 13 28 13 28 15zM28 24H25v2h3a2.0059 2.0059 0 002-2V21H28zM28 6H25V8h3v3h2V8A2.0059 2.0059 0 0028 6zM9 24H15V26H9z"
  })), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "12",
    r: "1"
  })), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "20",
    r: "1"
  })), children);
});
var StorageRequest20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StorageRequest20(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 21H2v3a2.0059 2.0059 0 002 2H7V24H4zM4 8H7V6H4A2.0059 2.0059 0 002 8v3H4zM17 6H23V8H17zM9 6H15V8H9zM17 24H23V26H17zM28 15L4 15 4 13 2 13 2 19 4 19 4 17 28 17 28 19 30 19 30 13 28 13 28 15zM28 24H25v2h3a2.0059 2.0059 0 002-2V21H28zM28 6H25V8h3v3h2V8A2.0059 2.0059 0 0028 6zM9 24H15V26H9z"
  })), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "12",
    r: "1"
  })), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "20",
    r: "1"
  })), children);
});
var StorageRequest16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StorageRequest16(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 21H2v3a2.0059 2.0059 0 002 2H7V24H4zM4 8H7V6H4A2.0059 2.0059 0 002 8v3H4zM17 6H23V8H17zM9 6H15V8H9zM17 24H23V26H17zM28 15L4 15 4 13 2 13 2 19 4 19 4 17 28 17 28 19 30 19 30 13 28 13 28 15zM28 24H25v2h3a2.0059 2.0059 0 002-2V21H28zM28 6H25V8h3v3h2V8A2.0059 2.0059 0 0028 6zM9 24H15V26H9z"
  })), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "12",
    r: "1"
  })), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "20",
    r: "1"
  })), children);
});
var Store32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Store32(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10.68l-2-6A1,1,0,0,0,27,4H5a1,1,0,0,0-1,.68l-2,6A1.19,1.19,0,0,0,2,11v6a1,1,0,0,0,1,1H4V28H6V18h6V28H28V18h1a1,1,0,0,0,1-1V11A1.19,1.19,0,0,0,30,10.68ZM26,26H14V18H26Zm2-10H24V12H22v4H17V12H15v4H10V12H8v4H4V11.16L5.72,6H26.28L28,11.16Z"
  })), children);
});
var Store24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Store24(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10.68l-2-6A1,1,0,0,0,27,4H5a1,1,0,0,0-1,.68l-2,6A1.19,1.19,0,0,0,2,11v6a1,1,0,0,0,1,1H4V28H6V18h6V28H28V18h1a1,1,0,0,0,1-1V11A1.19,1.19,0,0,0,30,10.68ZM26,26H14V18H26Zm2-10H24V12H22v4H17V12H15v4H10V12H8v4H4V11.16L5.72,6H26.28L28,11.16Z"
  })), children);
});
var Store20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Store20(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10.68l-2-6A1,1,0,0,0,27,4H5a1,1,0,0,0-1,.68l-2,6A1.19,1.19,0,0,0,2,11v6a1,1,0,0,0,1,1H4V28H6V18h6V28H28V18h1a1,1,0,0,0,1-1V11A1.19,1.19,0,0,0,30,10.68ZM26,26H14V18H26Zm2-10H24V12H22v4H17V12H15v4H10V12H8v4H4V11.16L5.72,6H26.28L28,11.16Z"
  })), children);
});
var Store16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Store16(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10.68l-2-6A1,1,0,0,0,27,4H5a1,1,0,0,0-1,.68l-2,6A1.19,1.19,0,0,0,2,11v6a1,1,0,0,0,1,1H4V28H6V18h6V28H28V18h1a1,1,0,0,0,1-1V11A1.19,1.19,0,0,0,30,10.68ZM26,26H14V18H26Zm2-10H24V12H22v4H17V12H15v4H10V12H8v4H4V11.16L5.72,6H26.28L28,11.16Z"
  })), children);
});
var StormTracker32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StormTracker32(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2a1,1,0,0,0-.9736.771l-1.7229,7.3223a10.0653,10.0653,0,1,0,8.6032,8.603l7.3223-1.7227A1,1,0,0,0,30,16,14.0158,14.0158,0,0,0,16,2ZM11.293,20.707A1,1,0,0,0,12,21a1.013,1.013,0,0,0,.229-.0264l3.7622-.8852a3.996,3.996,0,1,1-4.08-4.08l-.8852,3.7622A1,1,0,0,0,11.293,20.707Zm2.05-2.0508,2.271-9.65a7.5018,7.5018,0,0,1,7.38,7.38ZM20,20a8,8,0,1,1-8-8,8.1017,8.1017,0,0,1,.8438.0469L12.38,14.019C12.2532,14.0107,12.127,14,12,14a6,6,0,1,0,6,6c0-.127-.011-.2534-.019-.38l1.9721-.4643A8.1048,8.1048,0,0,1,20,20Zm4.9707-4.0791a9.4981,9.4981,0,0,0-8.8914-8.8916l.7068-3.0039A12.0193,12.0193,0,0,1,27.9746,15.2139Z"
  })), children);
});
var StormTracker24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StormTracker24(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2a1,1,0,0,0-.9736.771l-1.7229,7.3223a10.0653,10.0653,0,1,0,8.6032,8.603l7.3223-1.7227A1,1,0,0,0,30,16,14.0158,14.0158,0,0,0,16,2ZM11.293,20.707A1,1,0,0,0,12,21a1.013,1.013,0,0,0,.229-.0264l3.7622-.8852a3.996,3.996,0,1,1-4.08-4.08l-.8852,3.7622A1,1,0,0,0,11.293,20.707Zm2.05-2.0508,2.271-9.65a7.5018,7.5018,0,0,1,7.38,7.38ZM20,20a8,8,0,1,1-8-8,8.1017,8.1017,0,0,1,.8438.0469L12.38,14.019C12.2532,14.0107,12.127,14,12,14a6,6,0,1,0,6,6c0-.127-.011-.2534-.019-.38l1.9721-.4643A8.1048,8.1048,0,0,1,20,20Zm4.9707-4.0791a9.4981,9.4981,0,0,0-8.8914-8.8916l.7068-3.0039A12.0193,12.0193,0,0,1,27.9746,15.2139Z"
  })), children);
});
var StormTracker20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StormTracker20(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2a1,1,0,0,0-.9736.771l-1.7229,7.3223a10.0653,10.0653,0,1,0,8.6032,8.603l7.3223-1.7227A1,1,0,0,0,30,16,14.0158,14.0158,0,0,0,16,2ZM11.293,20.707A1,1,0,0,0,12,21a1.013,1.013,0,0,0,.229-.0264l3.7622-.8852a3.996,3.996,0,1,1-4.08-4.08l-.8852,3.7622A1,1,0,0,0,11.293,20.707Zm2.05-2.0508,2.271-9.65a7.5018,7.5018,0,0,1,7.38,7.38ZM20,20a8,8,0,1,1-8-8,8.1017,8.1017,0,0,1,.8438.0469L12.38,14.019C12.2532,14.0107,12.127,14,12,14a6,6,0,1,0,6,6c0-.127-.011-.2534-.019-.38l1.9721-.4643A8.1048,8.1048,0,0,1,20,20Zm4.9707-4.0791a9.4981,9.4981,0,0,0-8.8914-8.8916l.7068-3.0039A12.0193,12.0193,0,0,1,27.9746,15.2139Z"
  })), children);
});
var StormTracker16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StormTracker16(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2a1,1,0,0,0-.9736.771l-1.7229,7.3223a10.0653,10.0653,0,1,0,8.6032,8.603l7.3223-1.7227A1,1,0,0,0,30,16,14.0158,14.0158,0,0,0,16,2ZM11.293,20.707A1,1,0,0,0,12,21a1.013,1.013,0,0,0,.229-.0264l3.7622-.8852a3.996,3.996,0,1,1-4.08-4.08l-.8852,3.7622A1,1,0,0,0,11.293,20.707Zm2.05-2.0508,2.271-9.65a7.5018,7.5018,0,0,1,7.38,7.38ZM20,20a8,8,0,1,1-8-8,8.1017,8.1017,0,0,1,.8438.0469L12.38,14.019C12.2532,14.0107,12.127,14,12,14a6,6,0,1,0,6,6c0-.127-.011-.2534-.019-.38l1.9721-.4643A8.1048,8.1048,0,0,1,20,20Zm4.9707-4.0791a9.4981,9.4981,0,0,0-8.8914-8.8916l.7068-3.0039A12.0193,12.0193,0,0,1,27.9746,15.2139Z"
  })), children);
});
var Strawberry32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Strawberry32(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 10H11V12H9zM9 14H11V16H9zM13 12H15V14H13z"
  })), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 28a5.169 5.169 0 01-.7441-.054A5.0935 5.0935 0 014 22.8669V11.1985a7.1615 7.1615 0 016.31-7.1653 6.9607 6.9607 0 014.4643 1.0706l7.9688 4.9807a6.98 6.98 0 01-.6885 12.19l-10.88 5.2285A4.9765 4.9765 0 019 28zM11.002 6q-.2484 0-.5005.0241A5.1463 5.1463 0 006 11.1985V22.8669a3.0839 3.0839 0 002.5435 3.1 3.0266 3.0266 0 001.7622-.2649l10.8828-5.23a4.9807 4.9807 0 00.4887-8.6958L13.7046 6.7935A4.9687 4.9687 0 0011.002 6zM26 7H22a4.0045 4.0045 0 01-4-4V2h2V3a2.0021 2.0021 0 002 2h4z"
  })), children);
});
var Strawberry24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Strawberry24(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 10H11V12H9zM9 14H11V16H9zM13 12H15V14H13z"
  })), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 28a5.169 5.169 0 01-.7441-.054A5.0935 5.0935 0 014 22.8669V11.1985a7.1615 7.1615 0 016.31-7.1653 6.9607 6.9607 0 014.4643 1.0706l7.9688 4.9807a6.98 6.98 0 01-.6885 12.19l-10.88 5.2285A4.9765 4.9765 0 019 28zM11.002 6q-.2484 0-.5005.0241A5.1463 5.1463 0 006 11.1985V22.8669a3.0839 3.0839 0 002.5435 3.1 3.0266 3.0266 0 001.7622-.2649l10.8828-5.23a4.9807 4.9807 0 00.4887-8.6958L13.7046 6.7935A4.9687 4.9687 0 0011.002 6zM26 7H22a4.0045 4.0045 0 01-4-4V2h2V3a2.0021 2.0021 0 002 2h4z"
  })), children);
});
var Strawberry20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Strawberry20(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 10H11V12H9zM9 14H11V16H9zM13 12H15V14H13z"
  })), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 28a5.169 5.169 0 01-.7441-.054A5.0935 5.0935 0 014 22.8669V11.1985a7.1615 7.1615 0 016.31-7.1653 6.9607 6.9607 0 014.4643 1.0706l7.9688 4.9807a6.98 6.98 0 01-.6885 12.19l-10.88 5.2285A4.9765 4.9765 0 019 28zM11.002 6q-.2484 0-.5005.0241A5.1463 5.1463 0 006 11.1985V22.8669a3.0839 3.0839 0 002.5435 3.1 3.0266 3.0266 0 001.7622-.2649l10.8828-5.23a4.9807 4.9807 0 00.4887-8.6958L13.7046 6.7935A4.9687 4.9687 0 0011.002 6zM26 7H22a4.0045 4.0045 0 01-4-4V2h2V3a2.0021 2.0021 0 002 2h4z"
  })), children);
});
var Strawberry16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Strawberry16(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 10H11V12H9zM9 14H11V16H9zM13 12H15V14H13z"
  })), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 28a5.169 5.169 0 01-.7441-.054A5.0935 5.0935 0 014 22.8669V11.1985a7.1615 7.1615 0 016.31-7.1653 6.9607 6.9607 0 014.4643 1.0706l7.9688 4.9807a6.98 6.98 0 01-.6885 12.19l-10.88 5.2285A4.9765 4.9765 0 019 28zM11.002 6q-.2484 0-.5005.0241A5.1463 5.1463 0 006 11.1985V22.8669a3.0839 3.0839 0 002.5435 3.1 3.0266 3.0266 0 001.7622-.2649l10.8828-5.23a4.9807 4.9807 0 00.4887-8.6958L13.7046 6.7935A4.9687 4.9687 0 0011.002 6zM26 7H22a4.0045 4.0045 0 01-4-4V2h2V3a2.0021 2.0021 0 002 2h4z"
  })), children);
});
var WatsonHealthStressBreathEditor32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStressBreathEditor32(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 4a5 5 0 11-5 5 5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0020 2zM30 30H28V25a5 5 0 00-5-5H17a5 5 0 00-5 5v5H10V25a7 7 0 017-7h6a7 7 0 017 7zM11 8H5A3 3 0 012 5V3H4V5A1 1 0 005 6h6zM4 15H2V13a3 3 0 013-3h6v2H5a1 1 0 00-1 1z"
  })), children);
});
var WatsonHealthStressBreathEditor24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStressBreathEditor24(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 4a5 5 0 11-5 5 5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0020 2zM30 30H28V25a5 5 0 00-5-5H17a5 5 0 00-5 5v5H10V25a7 7 0 017-7h6a7 7 0 017 7zM11 8H5A3 3 0 012 5V3H4V5A1 1 0 005 6h6zM4 15H2V13a3 3 0 013-3h6v2H5a1 1 0 00-1 1z"
  })), children);
});
var WatsonHealthStressBreathEditor20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStressBreathEditor20(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 4a5 5 0 11-5 5 5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0020 2zM30 30H28V25a5 5 0 00-5-5H17a5 5 0 00-5 5v5H10V25a7 7 0 017-7h6a7 7 0 017 7zM11 8H5A3 3 0 012 5V3H4V5A1 1 0 005 6h6zM4 15H2V13a3 3 0 013-3h6v2H5a1 1 0 00-1 1z"
  })), children);
});
var WatsonHealthStressBreathEditor16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStressBreathEditor16(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 4a5 5 0 11-5 5 5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0020 2zM30 30H28V25a5 5 0 00-5-5H17a5 5 0 00-5 5v5H10V25a7 7 0 017-7h6a7 7 0 017 7zM11 8H5A3 3 0 012 5V3H4V5A1 1 0 005 6h6zM4 15H2V13a3 3 0 013-3h6v2H5a1 1 0 00-1 1z"
  })), children);
});
var StringInteger32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StringInteger32(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 12H22v2h4v2H23v2h3v2H22v2h4a2.0027 2.0027 0 002-2V14A2.0023 2.0023 0 0026 12zM19 22H13V18a2.002 2.002 0 012-2h2V14H13V12h4a2.0023 2.0023 0 012 2v2a2.0023 2.0023 0 01-2 2H15v2h4zM8 20L8 12 6 12 6 13 4 13 4 15 6 15 6 20 4 20 4 22 10 22 10 20 8 20z"
  })), children);
});
var StringInteger24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StringInteger24(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 12H22v2h4v2H23v2h3v2H22v2h4a2.0027 2.0027 0 002-2V14A2.0023 2.0023 0 0026 12zM19 22H13V18a2.002 2.002 0 012-2h2V14H13V12h4a2.0023 2.0023 0 012 2v2a2.0023 2.0023 0 01-2 2H15v2h4zM8 20L8 12 6 12 6 13 4 13 4 15 6 15 6 20 4 20 4 22 10 22 10 20 8 20z"
  })), children);
});
var StringInteger20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StringInteger20(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 12H22v2h4v2H23v2h3v2H22v2h4a2.0027 2.0027 0 002-2V14A2.0023 2.0023 0 0026 12zM19 22H13V18a2.002 2.002 0 012-2h2V14H13V12h4a2.0023 2.0023 0 012 2v2a2.0023 2.0023 0 01-2 2H15v2h4zM8 20L8 12 6 12 6 13 4 13 4 15 6 15 6 20 4 20 4 22 10 22 10 20 8 20z"
  })), children);
});
var StringInteger16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StringInteger16(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 12H22v2h4v2H23v2h3v2H22v2h4a2.0027 2.0027 0 002-2V14A2.0023 2.0023 0 0026 12zM19 22H13V18a2.002 2.002 0 012-2h2V14H13V12h4a2.0023 2.0023 0 012 2v2a2.0023 2.0023 0 01-2 2H15v2h4zM8 20L8 12 6 12 6 13 4 13 4 15 6 15 6 20 4 20 4 22 10 22 10 20 8 20z"
  })), children);
});
var StringText32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StringText32(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 22H24a2.0027 2.0027 0 01-2-2V14a2.0023 2.0023 0 012-2h5v2H24v6h5zM18 12H14V8H12V22h6a2.0027 2.0027 0 002-2V14A2.0023 2.0023 0 0018 12zm-4 8V14h4v6zM8 12H3v2H8v2H4a2 2 0 00-2 2v2a2 2 0 002 2h6V14A2.0023 2.0023 0 008 12zm0 8H4V18H8z"
  })), children);
});
var StringText24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StringText24(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 22H24a2.0027 2.0027 0 01-2-2V14a2.0023 2.0023 0 012-2h5v2H24v6h5zM18 12H14V8H12V22h6a2.0027 2.0027 0 002-2V14A2.0023 2.0023 0 0018 12zm-4 8V14h4v6zM8 12H3v2H8v2H4a2 2 0 00-2 2v2a2 2 0 002 2h6V14A2.0023 2.0023 0 008 12zm0 8H4V18H8z"
  })), children);
});
var StringText20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StringText20(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 22H24a2.0027 2.0027 0 01-2-2V14a2.0023 2.0023 0 012-2h5v2H24v6h5zM18 12H14V8H12V22h6a2.0027 2.0027 0 002-2V14A2.0023 2.0023 0 0018 12zm-4 8V14h4v6zM8 12H3v2H8v2H4a2 2 0 00-2 2v2a2 2 0 002 2h6V14A2.0023 2.0023 0 008 12zm0 8H4V18H8z"
  })), children);
});
var StringText16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function StringText16(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 22H24a2.0027 2.0027 0 01-2-2V14a2.0023 2.0023 0 012-2h5v2H24v6h5zM18 12H14V8H12V22h6a2.0027 2.0027 0 002-2V14A2.0023 2.0023 0 0018 12zm-4 8V14h4v6zM8 12H3v2H8v2H4a2 2 0 00-2 2v2a2 2 0 002 2h6V14A2.0023 2.0023 0 008 12zm0 8H4V18H8z"
  })), children);
});
var WatsonHealthStudyNext32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyNext32(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.93 21L30 15 23.93 9 22.5 10.41 27.14 15 22.5 19.59 23.93 21zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7z"
  })), children);
});
var WatsonHealthStudyNext24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyNext24(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.93 21L30 15 23.93 9 22.5 10.41 27.14 15 22.5 19.59 23.93 21zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7z"
  })), children);
});
var WatsonHealthStudyNext20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyNext20(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.93 21L30 15 23.93 9 22.5 10.41 27.14 15 22.5 19.59 23.93 21zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7z"
  })), children);
});
var WatsonHealthStudyNext16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyNext16(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.93 21L30 15 23.93 9 22.5 10.41 27.14 15 22.5 19.59 23.93 21zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7z"
  })), children);
});
var WatsonHealthStudyPrevious32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyPrevious32(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.07 21L2 15 8.07 9 9.5 10.41 4.86 15 9.5 19.59 8.07 21zM20 4a5 5 0 11-5 5 5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0020 2zM30 30H28V25a5 5 0 00-5-5H17a5 5 0 00-5 5v5H10V25a7 7 0 017-7h6a7 7 0 017 7z"
  })), children);
});
var WatsonHealthStudyPrevious24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyPrevious24(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.07 21L2 15 8.07 9 9.5 10.41 4.86 15 9.5 19.59 8.07 21zM20 4a5 5 0 11-5 5 5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0020 2zM30 30H28V25a5 5 0 00-5-5H17a5 5 0 00-5 5v5H10V25a7 7 0 017-7h6a7 7 0 017 7z"
  })), children);
});
var WatsonHealthStudyPrevious20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyPrevious20(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.07 21L2 15 8.07 9 9.5 10.41 4.86 15 9.5 19.59 8.07 21zM20 4a5 5 0 11-5 5 5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0020 2zM30 30H28V25a5 5 0 00-5-5H17a5 5 0 00-5 5v5H10V25a7 7 0 017-7h6a7 7 0 017 7z"
  })), children);
});
var WatsonHealthStudyPrevious16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyPrevious16(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.07 21L2 15 8.07 9 9.5 10.41 4.86 15 9.5 19.59 8.07 21zM20 4a5 5 0 11-5 5 5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0020 2zM30 30H28V25a5 5 0 00-5-5H17a5 5 0 00-5 5v5H10V25a7 7 0 017-7h6a7 7 0 017 7z"
  })), children);
});
var WatsonHealthStudyRead32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyRead32(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 29.414L16 24.413 17.413 23 21 26.586 28.585 19 30 20.415 21 29.414zM20 14L20 12 15 12 15 10 18 10 18 8 15 8 15 6 13 6 13 8 10 8 10 10 13 10 13 12 8 12 8 14 13 14 13 16 8 16 8 18 13 18 13 20 10 20 10 22 15 22 15 18 18 18 18 16 15 16 15 14 20 14z"
  })), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,24H4V4H24V16h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V24a2,2,0,0,0,2,2h9Z"
  })), children);
});
var WatsonHealthStudyRead24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyRead24(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 29.414L16 24.413 17.413 23 21 26.586 28.585 19 30 20.415 21 29.414zM20 14L20 12 15 12 15 10 18 10 18 8 15 8 15 6 13 6 13 8 10 8 10 10 13 10 13 12 8 12 8 14 13 14 13 16 8 16 8 18 13 18 13 20 10 20 10 22 15 22 15 18 18 18 18 16 15 16 15 14 20 14z"
  })), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,24H4V4H24V16h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V24a2,2,0,0,0,2,2h9Z"
  })), children);
});
var WatsonHealthStudyRead20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyRead20(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 29.414L16 24.413 17.413 23 21 26.586 28.585 19 30 20.415 21 29.414zM20 14L20 12 15 12 15 10 18 10 18 8 15 8 15 6 13 6 13 8 10 8 10 10 13 10 13 12 8 12 8 14 13 14 13 16 8 16 8 18 13 18 13 20 10 20 10 22 15 22 15 18 18 18 18 16 15 16 15 14 20 14z"
  })), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,24H4V4H24V16h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V24a2,2,0,0,0,2,2h9Z"
  })), children);
});
var WatsonHealthStudyRead16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyRead16(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 29.414L16 24.413 17.413 23 21 26.586 28.585 19 30 20.415 21 29.414zM20 14L20 12 15 12 15 10 18 10 18 8 15 8 15 6 13 6 13 8 10 8 10 10 13 10 13 12 8 12 8 14 13 14 13 16 8 16 8 18 13 18 13 20 10 20 10 22 15 22 15 18 18 18 18 16 15 16 15 14 20 14z"
  })), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,24H4V4H24V16h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V24a2,2,0,0,0,2,2h9Z"
  })), children);
});
var WatsonHealthStudySkip32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudySkip32(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,9h5.2A11,11,0,0,0,7,15H5A13,13,0,0,1,28,6.7V3h2v8H22Z"
  })), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 12a3 3 0 11-3 3 2.95 2.95 0 013-3m0-2a5 5 0 105 5A5 5 0 0016 10zM23 30H21V27a3 3 0 00-3-3H14a3 3 0 00-3 3v3H9V27a5 5 0 015-5h4a5 5 0 015 5z"
  })), children);
});
var WatsonHealthStudySkip24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudySkip24(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,9h5.2A11,11,0,0,0,7,15H5A13,13,0,0,1,28,6.7V3h2v8H22Z"
  })), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 12a3 3 0 11-3 3 2.95 2.95 0 013-3m0-2a5 5 0 105 5A5 5 0 0016 10zM23 30H21V27a3 3 0 00-3-3H14a3 3 0 00-3 3v3H9V27a5 5 0 015-5h4a5 5 0 015 5z"
  })), children);
});
var WatsonHealthStudySkip20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudySkip20(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,9h5.2A11,11,0,0,0,7,15H5A13,13,0,0,1,28,6.7V3h2v8H22Z"
  })), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 12a3 3 0 11-3 3 2.95 2.95 0 013-3m0-2a5 5 0 105 5A5 5 0 0016 10zM23 30H21V27a3 3 0 00-3-3H14a3 3 0 00-3 3v3H9V27a5 5 0 015-5h4a5 5 0 015 5z"
  })), children);
});
var WatsonHealthStudySkip16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudySkip16(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,9h5.2A11,11,0,0,0,7,15H5A13,13,0,0,1,28,6.7V3h2v8H22Z"
  })), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 12a3 3 0 11-3 3 2.95 2.95 0 013-3m0-2a5 5 0 105 5A5 5 0 0016 10zM23 30H21V27a3 3 0 00-3-3H14a3 3 0 00-3 3v3H9V27a5 5 0 015-5h4a5 5 0 015 5z"
  })), children);
});
var WatsonHealthStudyTransfer32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyTransfer32(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.586 19.414L13.165 24 8.586 28.586 10 30 16 24 10 18 8.586 19.414z"
  })), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.586 19.414L7.165 24 2.586 28.586 4 30 10 24 4 18 2.586 19.414zM12 14L12 12 17 12 17 10 14 10 14 8 17 8 17 6 19 6 19 8 22 8 22 10 19 10 19 12 24 12 24 14 19 14 19 16 24 16 24 18 19 18 19 20 22 20 22 22 17 22 17 18 14 18 14 16 17 16 17 14 12 14z"
  })), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,24h9V4H8V16H6V4A2,2,0,0,1,8,2H28a2,2,0,0,1,2,2V24a2,2,0,0,1-2,2H19Z"
  })), children);
});
var WatsonHealthStudyTransfer24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyTransfer24(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.586 19.414L13.165 24 8.586 28.586 10 30 16 24 10 18 8.586 19.414z"
  })), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.586 19.414L7.165 24 2.586 28.586 4 30 10 24 4 18 2.586 19.414zM12 14L12 12 17 12 17 10 14 10 14 8 17 8 17 6 19 6 19 8 22 8 22 10 19 10 19 12 24 12 24 14 19 14 19 16 24 16 24 18 19 18 19 20 22 20 22 22 17 22 17 18 14 18 14 16 17 16 17 14 12 14z"
  })), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,24h9V4H8V16H6V4A2,2,0,0,1,8,2H28a2,2,0,0,1,2,2V24a2,2,0,0,1-2,2H19Z"
  })), children);
});
var WatsonHealthStudyTransfer20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyTransfer20(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.586 19.414L13.165 24 8.586 28.586 10 30 16 24 10 18 8.586 19.414z"
  })), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.586 19.414L7.165 24 2.586 28.586 4 30 10 24 4 18 2.586 19.414zM12 14L12 12 17 12 17 10 14 10 14 8 17 8 17 6 19 6 19 8 22 8 22 10 19 10 19 12 24 12 24 14 19 14 19 16 24 16 24 18 19 18 19 20 22 20 22 22 17 22 17 18 14 18 14 16 17 16 17 14 12 14z"
  })), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,24h9V4H8V16H6V4A2,2,0,0,1,8,2H28a2,2,0,0,1,2,2V24a2,2,0,0,1-2,2H19Z"
  })), children);
});
var WatsonHealthStudyTransfer16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyTransfer16(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.586 19.414L13.165 24 8.586 28.586 10 30 16 24 10 18 8.586 19.414z"
  })), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.586 19.414L7.165 24 2.586 28.586 4 30 10 24 4 18 2.586 19.414zM12 14L12 12 17 12 17 10 14 10 14 8 17 8 17 6 19 6 19 8 22 8 22 10 19 10 19 12 24 12 24 14 19 14 19 16 24 16 24 18 19 18 19 20 22 20 22 22 17 22 17 18 14 18 14 16 17 16 17 14 12 14z"
  })), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,24h9V4H8V16H6V4A2,2,0,0,1,8,2H28a2,2,0,0,1,2,2V24a2,2,0,0,1-2,2H19Z"
  })), children);
});
var WatsonHealthStudyUnread32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyUnread32(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30a6 6 0 116-6A6.0067 6.0067 0 0124 30zm0-10a4 4 0 104 4A4.0045 4.0045 0 0024 20zM20 14L20 12 15 12 15 10 18 10 18 8 15 8 15 6 13 6 13 8 10 8 10 10 13 10 13 12 8 12 8 14 13 14 13 16 8 16 8 18 13 18 13 20 10 20 10 22 17 22 17 20 15 20 15 18 18 18 18 16 15 16 15 14 20 14z"
  })), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,24H4V4H24V15h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V24a2,2,0,0,0,2,2H15Z"
  })), children);
});
var WatsonHealthStudyUnread24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyUnread24(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30a6 6 0 116-6A6.0067 6.0067 0 0124 30zm0-10a4 4 0 104 4A4.0045 4.0045 0 0024 20zM20 14L20 12 15 12 15 10 18 10 18 8 15 8 15 6 13 6 13 8 10 8 10 10 13 10 13 12 8 12 8 14 13 14 13 16 8 16 8 18 13 18 13 20 10 20 10 22 17 22 17 20 15 20 15 18 18 18 18 16 15 16 15 14 20 14z"
  })), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,24H4V4H24V15h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V24a2,2,0,0,0,2,2H15Z"
  })), children);
});
var WatsonHealthStudyUnread20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyUnread20(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30a6 6 0 116-6A6.0067 6.0067 0 0124 30zm0-10a4 4 0 104 4A4.0045 4.0045 0 0024 20zM20 14L20 12 15 12 15 10 18 10 18 8 15 8 15 6 13 6 13 8 10 8 10 10 13 10 13 12 8 12 8 14 13 14 13 16 8 16 8 18 13 18 13 20 10 20 10 22 17 22 17 20 15 20 15 18 18 18 18 16 15 16 15 14 20 14z"
  })), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,24H4V4H24V15h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V24a2,2,0,0,0,2,2H15Z"
  })), children);
});
var WatsonHealthStudyUnread16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyUnread16(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30a6 6 0 116-6A6.0067 6.0067 0 0124 30zm0-10a4 4 0 104 4A4.0045 4.0045 0 0024 20zM20 14L20 12 15 12 15 10 18 10 18 8 15 8 15 6 13 6 13 8 10 8 10 10 13 10 13 12 8 12 8 14 13 14 13 16 8 16 8 18 13 18 13 20 10 20 10 22 17 22 17 20 15 20 15 18 18 18 18 16 15 16 15 14 20 14z"
  })), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,24H4V4H24V15h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V24a2,2,0,0,0,2,2H15Z"
  })), children);
});
var WatsonHealthStudyView32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyView32(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 20H25V18h3V4H14V7H12V4a2.002 2.002 0 012-2H28a2.0023 2.0023 0 012 2V18A2.0027 2.0027 0 0128 20zM17 22L17 20 13 20 13 18 16 18 16 16 13 16 13 14 11 14 11 16 8 16 8 18 11 18 11 20 7 20 7 22 11 22 11 24 8 24 8 26 16 26 16 24 13 24 13 22 17 22z"
  })), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,30H4a2.0021,2.0021,0,0,1-2-2V12a2.0021,2.0021,0,0,1,2-2H20a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,20,30ZM4,12V28H20V12Z"
  })), children);
});
var WatsonHealthStudyView24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyView24(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 20H25V18h3V4H14V7H12V4a2.002 2.002 0 012-2H28a2.0023 2.0023 0 012 2V18A2.0027 2.0027 0 0128 20zM17 22L17 20 13 20 13 18 16 18 16 16 13 16 13 14 11 14 11 16 8 16 8 18 11 18 11 20 7 20 7 22 11 22 11 24 8 24 8 26 16 26 16 24 13 24 13 22 17 22z"
  })), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,30H4a2.0021,2.0021,0,0,1-2-2V12a2.0021,2.0021,0,0,1,2-2H20a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,20,30ZM4,12V28H20V12Z"
  })), children);
});
var WatsonHealthStudyView20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyView20(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 20H25V18h3V4H14V7H12V4a2.002 2.002 0 012-2H28a2.0023 2.0023 0 012 2V18A2.0027 2.0027 0 0128 20zM17 22L17 20 13 20 13 18 16 18 16 16 13 16 13 14 11 14 11 16 8 16 8 18 11 18 11 20 7 20 7 22 11 22 11 24 8 24 8 26 16 26 16 24 13 24 13 22 17 22z"
  })), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,30H4a2.0021,2.0021,0,0,1-2-2V12a2.0021,2.0021,0,0,1,2-2H20a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,20,30ZM4,12V28H20V12Z"
  })), children);
});
var WatsonHealthStudyView16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthStudyView16(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 20H25V18h3V4H14V7H12V4a2.002 2.002 0 012-2H28a2.0023 2.0023 0 012 2V18A2.0027 2.0027 0 0128 20zM17 22L17 20 13 20 13 18 16 18 16 16 13 16 13 14 11 14 11 16 8 16 8 18 11 18 11 20 7 20 7 22 11 22 11 24 8 24 8 26 16 26 16 24 13 24 13 22 17 22z"
  })), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,30H4a2.0021,2.0021,0,0,1-2-2V12a2.0021,2.0021,0,0,1,2-2H20a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,20,30ZM4,12V28H20V12Z"
  })), children);
});
var WatsonHealthSubVolume32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSubVolume32(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4741,19.12,23.6807,16l5.7934-3.12a1,1,0,0,0,0-1.7607l-13-7a.9982.9982,0,0,0-.9482,0l-13,7a1,1,0,0,0,0,1.7607L8.3193,16,2.5259,19.12a1,1,0,0,0,0,1.7607l13,7a.9995.9995,0,0,0,.9482,0l13-7a1,1,0,0,0,0-1.7607ZM16,6.1359,26.8906,12,16,17.8643,5.1094,12Zm0,19.7284L5.1094,20l5.3193-2.8642L15.5259,19.88a.9995.9995,0,0,0,.9482,0l5.0972-2.7446L26.8906,20Z"
  })), children);
});
var WatsonHealthSubVolume24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSubVolume24(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4741,19.12,23.6807,16l5.7934-3.12a1,1,0,0,0,0-1.7607l-13-7a.9982.9982,0,0,0-.9482,0l-13,7a1,1,0,0,0,0,1.7607L8.3193,16,2.5259,19.12a1,1,0,0,0,0,1.7607l13,7a.9995.9995,0,0,0,.9482,0l13-7a1,1,0,0,0,0-1.7607ZM16,6.1359,26.8906,12,16,17.8643,5.1094,12Zm0,19.7284L5.1094,20l5.3193-2.8642L15.5259,19.88a.9995.9995,0,0,0,.9482,0l5.0972-2.7446L26.8906,20Z"
  })), children);
});
var WatsonHealthSubVolume20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSubVolume20(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4741,19.12,23.6807,16l5.7934-3.12a1,1,0,0,0,0-1.7607l-13-7a.9982.9982,0,0,0-.9482,0l-13,7a1,1,0,0,0,0,1.7607L8.3193,16,2.5259,19.12a1,1,0,0,0,0,1.7607l13,7a.9995.9995,0,0,0,.9482,0l13-7a1,1,0,0,0,0-1.7607ZM16,6.1359,26.8906,12,16,17.8643,5.1094,12Zm0,19.7284L5.1094,20l5.3193-2.8642L15.5259,19.88a.9995.9995,0,0,0,.9482,0l5.0972-2.7446L26.8906,20Z"
  })), children);
});
var WatsonHealthSubVolume16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthSubVolume16(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4741,19.12,23.6807,16l5.7934-3.12a1,1,0,0,0,0-1.7607l-13-7a.9982.9982,0,0,0-.9482,0l-13,7a1,1,0,0,0,0,1.7607L8.3193,16,2.5259,19.12a1,1,0,0,0,0,1.7607l13,7a.9995.9995,0,0,0,.9482,0l13-7a1,1,0,0,0,0-1.7607ZM16,6.1359,26.8906,12,16,17.8643,5.1094,12Zm0,19.7284L5.1094,20l5.3193-2.8642L15.5259,19.88a.9995.9995,0,0,0,.9482,0l5.0972-2.7446L26.8906,20Z"
  })), children);
});
var Subflow32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Subflow32(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14.0158,14.0158,0,0,1,2,16H4A12.0025,12.0025,0,0,0,22.4609,26.1143l1.0782,1.684A13.9511,13.9511,0,0,1,16,30Z"
  })), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,17l-1.4141,1.4141L26.1719,20H15.8157a2.9874,2.9874,0,0,0-.2742-.5762l4.481-5.601A2.9676,2.9676,0,0,0,21,14a3,3,0,1,0-2.8157-4H13.8157a2.982,2.982,0,0,0-5.6314,0H2v2H8.1843a2.982,2.982,0,0,0,5.6314,0h4.3686a2.9874,2.9874,0,0,0,.2742.5762l-4.481,5.601A2.9676,2.9676,0,0,0,13,18a3,3,0,1,0,2.8157,4H26.1719l-1.586,1.5859L26,25l4-4Zm-5-7a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,21,10ZM11,12a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,11,12Zm2,10a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,13,22Z"
  })), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16H28A12.0025,12.0025,0,0,0,9.5391,5.8857L8.4609,4.2017A14.0019,14.0019,0,0,1,30,16Z"
  })), children);
});
var Subflow24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Subflow24(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14.0158,14.0158,0,0,1,2,16H4A12.0025,12.0025,0,0,0,22.4609,26.1143l1.0782,1.684A13.9511,13.9511,0,0,1,16,30Z"
  })), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,17l-1.4141,1.4141L26.1719,20H15.8157a2.9874,2.9874,0,0,0-.2742-.5762l4.481-5.601A2.9676,2.9676,0,0,0,21,14a3,3,0,1,0-2.8157-4H13.8157a2.982,2.982,0,0,0-5.6314,0H2v2H8.1843a2.982,2.982,0,0,0,5.6314,0h4.3686a2.9874,2.9874,0,0,0,.2742.5762l-4.481,5.601A2.9676,2.9676,0,0,0,13,18a3,3,0,1,0,2.8157,4H26.1719l-1.586,1.5859L26,25l4-4Zm-5-7a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,21,10ZM11,12a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,11,12Zm2,10a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,13,22Z"
  })), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16H28A12.0025,12.0025,0,0,0,9.5391,5.8857L8.4609,4.2017A14.0019,14.0019,0,0,1,30,16Z"
  })), children);
});
var Subflow20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Subflow20(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14.0158,14.0158,0,0,1,2,16H4A12.0025,12.0025,0,0,0,22.4609,26.1143l1.0782,1.684A13.9511,13.9511,0,0,1,16,30Z"
  })), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,17l-1.4141,1.4141L26.1719,20H15.8157a2.9874,2.9874,0,0,0-.2742-.5762l4.481-5.601A2.9676,2.9676,0,0,0,21,14a3,3,0,1,0-2.8157-4H13.8157a2.982,2.982,0,0,0-5.6314,0H2v2H8.1843a2.982,2.982,0,0,0,5.6314,0h4.3686a2.9874,2.9874,0,0,0,.2742.5762l-4.481,5.601A2.9676,2.9676,0,0,0,13,18a3,3,0,1,0,2.8157,4H26.1719l-1.586,1.5859L26,25l4-4Zm-5-7a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,21,10ZM11,12a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,11,12Zm2,10a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,13,22Z"
  })), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16H28A12.0025,12.0025,0,0,0,9.5391,5.8857L8.4609,4.2017A14.0019,14.0019,0,0,1,30,16Z"
  })), children);
});
var Subflow16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Subflow16(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14.0158,14.0158,0,0,1,2,16H4A12.0025,12.0025,0,0,0,22.4609,26.1143l1.0782,1.684A13.9511,13.9511,0,0,1,16,30Z"
  })), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,17l-1.4141,1.4141L26.1719,20H15.8157a2.9874,2.9874,0,0,0-.2742-.5762l4.481-5.601A2.9676,2.9676,0,0,0,21,14a3,3,0,1,0-2.8157-4H13.8157a2.982,2.982,0,0,0-5.6314,0H2v2H8.1843a2.982,2.982,0,0,0,5.6314,0h4.3686a2.9874,2.9874,0,0,0,.2742.5762l-4.481,5.601A2.9676,2.9676,0,0,0,13,18a3,3,0,1,0,2.8157,4H26.1719l-1.586,1.5859L26,25l4-4Zm-5-7a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,21,10ZM11,12a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,11,12Zm2,10a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,13,22Z"
  })), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16H28A12.0025,12.0025,0,0,0,9.5391,5.8857L8.4609,4.2017A14.0019,14.0019,0,0,1,30,16Z"
  })), children);
});
var SubflowLocal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SubflowLocal32(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.3472 29.9851a13.9282 13.9282 0 01-4.2051-.8516l.6943-1.8754a11.929 11.929 0 003.6026.729zm4.2651-.4558l-.5146-1.9326a11.915 11.915 0 003.3632-1.4827l1.0782 1.6846A13.915 13.915 0 0119.6123 29.5293zM7.395 27.0439a14.0632 14.0632 0 01-2.94-3.1218l1.6484-1.1333a12.0521 12.0521 0 002.522 2.6785zM2.5967 20.0544A14.0512 14.0512 0 012.0005 16H4a12.0412 12.0412 0 00.5117 3.4763zM26 17l-1.4141 1.4141L26.1719 20H15.8157a2.9874 2.9874 0 00-.2742-.5762l4.481-5.601A2.9676 2.9676 0 0021 14a3 3 0 10-2.8157-4H13.8157a2.982 2.982 0 00-5.6314 0H2v2H8.1843a2.982 2.982 0 005.6314 0h4.3686a2.9874 2.9874 0 00.2742.5762l-4.481 5.601A2.9676 2.9676 0 0013 18a3 3 0 102.8157 4H26.1719l-1.586 1.5859L26 25l4-4zm-5-7a1 1 0 11-1 1A1.0009 1.0009 0 0121 10zM11 12a1 1 0 111-1A1.0009 1.0009 0 0111 12zm2 10a1 1 0 111-1A1.0009 1.0009 0 0113 22zM28 16a12.0412 12.0412 0 00-.5117-3.4763l1.915-.5781A14.0551 14.0551 0 0130 16zM25.8965 9.2112a12.0521 12.0521 0 00-2.522-2.6785l1.23-1.5766a14.0632 14.0632 0 012.94 3.1218zM9.5391 5.886L8.4609 4.2014a13.915 13.915 0 013.9268-1.7307l.5146 1.9326A11.915 11.915 0 009.5391 5.886zM20.1636 4.7419a11.929 11.929 0 00-3.6026-.729l.0918-1.998a13.9282 13.9282 0 014.2051.8516z"
  })), children);
});
var SubflowLocal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SubflowLocal24(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.3472 29.9851a13.9282 13.9282 0 01-4.2051-.8516l.6943-1.8754a11.929 11.929 0 003.6026.729zm4.2651-.4558l-.5146-1.9326a11.915 11.915 0 003.3632-1.4827l1.0782 1.6846A13.915 13.915 0 0119.6123 29.5293zM7.395 27.0439a14.0632 14.0632 0 01-2.94-3.1218l1.6484-1.1333a12.0521 12.0521 0 002.522 2.6785zM2.5967 20.0544A14.0512 14.0512 0 012.0005 16H4a12.0412 12.0412 0 00.5117 3.4763zM26 17l-1.4141 1.4141L26.1719 20H15.8157a2.9874 2.9874 0 00-.2742-.5762l4.481-5.601A2.9676 2.9676 0 0021 14a3 3 0 10-2.8157-4H13.8157a2.982 2.982 0 00-5.6314 0H2v2H8.1843a2.982 2.982 0 005.6314 0h4.3686a2.9874 2.9874 0 00.2742.5762l-4.481 5.601A2.9676 2.9676 0 0013 18a3 3 0 102.8157 4H26.1719l-1.586 1.5859L26 25l4-4zm-5-7a1 1 0 11-1 1A1.0009 1.0009 0 0121 10zM11 12a1 1 0 111-1A1.0009 1.0009 0 0111 12zm2 10a1 1 0 111-1A1.0009 1.0009 0 0113 22zM28 16a12.0412 12.0412 0 00-.5117-3.4763l1.915-.5781A14.0551 14.0551 0 0130 16zM25.8965 9.2112a12.0521 12.0521 0 00-2.522-2.6785l1.23-1.5766a14.0632 14.0632 0 012.94 3.1218zM9.5391 5.886L8.4609 4.2014a13.915 13.915 0 013.9268-1.7307l.5146 1.9326A11.915 11.915 0 009.5391 5.886zM20.1636 4.7419a11.929 11.929 0 00-3.6026-.729l.0918-1.998a13.9282 13.9282 0 014.2051.8516z"
  })), children);
});
var SubflowLocal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SubflowLocal20(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.3472 29.9851a13.9282 13.9282 0 01-4.2051-.8516l.6943-1.8754a11.929 11.929 0 003.6026.729zm4.2651-.4558l-.5146-1.9326a11.915 11.915 0 003.3632-1.4827l1.0782 1.6846A13.915 13.915 0 0119.6123 29.5293zM7.395 27.0439a14.0632 14.0632 0 01-2.94-3.1218l1.6484-1.1333a12.0521 12.0521 0 002.522 2.6785zM2.5967 20.0544A14.0512 14.0512 0 012.0005 16H4a12.0412 12.0412 0 00.5117 3.4763zM26 17l-1.4141 1.4141L26.1719 20H15.8157a2.9874 2.9874 0 00-.2742-.5762l4.481-5.601A2.9676 2.9676 0 0021 14a3 3 0 10-2.8157-4H13.8157a2.982 2.982 0 00-5.6314 0H2v2H8.1843a2.982 2.982 0 005.6314 0h4.3686a2.9874 2.9874 0 00.2742.5762l-4.481 5.601A2.9676 2.9676 0 0013 18a3 3 0 102.8157 4H26.1719l-1.586 1.5859L26 25l4-4zm-5-7a1 1 0 11-1 1A1.0009 1.0009 0 0121 10zM11 12a1 1 0 111-1A1.0009 1.0009 0 0111 12zm2 10a1 1 0 111-1A1.0009 1.0009 0 0113 22zM28 16a12.0412 12.0412 0 00-.5117-3.4763l1.915-.5781A14.0551 14.0551 0 0130 16zM25.8965 9.2112a12.0521 12.0521 0 00-2.522-2.6785l1.23-1.5766a14.0632 14.0632 0 012.94 3.1218zM9.5391 5.886L8.4609 4.2014a13.915 13.915 0 013.9268-1.7307l.5146 1.9326A11.915 11.915 0 009.5391 5.886zM20.1636 4.7419a11.929 11.929 0 00-3.6026-.729l.0918-1.998a13.9282 13.9282 0 014.2051.8516z"
  })), children);
});
var SubflowLocal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SubflowLocal16(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.3472 29.9851a13.9282 13.9282 0 01-4.2051-.8516l.6943-1.8754a11.929 11.929 0 003.6026.729zm4.2651-.4558l-.5146-1.9326a11.915 11.915 0 003.3632-1.4827l1.0782 1.6846A13.915 13.915 0 0119.6123 29.5293zM7.395 27.0439a14.0632 14.0632 0 01-2.94-3.1218l1.6484-1.1333a12.0521 12.0521 0 002.522 2.6785zM2.5967 20.0544A14.0512 14.0512 0 012.0005 16H4a12.0412 12.0412 0 00.5117 3.4763zM26 17l-1.4141 1.4141L26.1719 20H15.8157a2.9874 2.9874 0 00-.2742-.5762l4.481-5.601A2.9676 2.9676 0 0021 14a3 3 0 10-2.8157-4H13.8157a2.982 2.982 0 00-5.6314 0H2v2H8.1843a2.982 2.982 0 005.6314 0h4.3686a2.9874 2.9874 0 00.2742.5762l-4.481 5.601A2.9676 2.9676 0 0013 18a3 3 0 102.8157 4H26.1719l-1.586 1.5859L26 25l4-4zm-5-7a1 1 0 11-1 1A1.0009 1.0009 0 0121 10zM11 12a1 1 0 111-1A1.0009 1.0009 0 0111 12zm2 10a1 1 0 111-1A1.0009 1.0009 0 0113 22zM28 16a12.0412 12.0412 0 00-.5117-3.4763l1.915-.5781A14.0551 14.0551 0 0130 16zM25.8965 9.2112a12.0521 12.0521 0 00-2.522-2.6785l1.23-1.5766a14.0632 14.0632 0 012.94 3.1218zM9.5391 5.886L8.4609 4.2014a13.915 13.915 0 013.9268-1.7307l.5146 1.9326A11.915 11.915 0 009.5391 5.886zM20.1636 4.7419a11.929 11.929 0 00-3.6026-.729l.0918-1.998a13.9282 13.9282 0 014.2051.8516z"
  })), children);
});
var SubnetAclRules32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SubnetAclRules32(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 14H30V16H18zM18 19H26V21H18zM18 9H30V11H18z"
  })), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,24v4H6V16h8V14H10V8a4.0008,4.0008,0,0,1,7.6675-1.6L19.5005,5.6A6.001,6.001,0,0,0,8,8v6H6a2.0023,2.0023,0,0,0-2,2V28a2.0023,2.0023,0,0,0,2,2H22a2.0023,2.0023,0,0,0,2-2V24Z"
  })), children);
});
var SubnetAclRules24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SubnetAclRules24(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 14H30V16H18zM18 19H26V21H18zM18 9H30V11H18z"
  })), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,24v4H6V16h8V14H10V8a4.0008,4.0008,0,0,1,7.6675-1.6L19.5005,5.6A6.001,6.001,0,0,0,8,8v6H6a2.0023,2.0023,0,0,0-2,2V28a2.0023,2.0023,0,0,0,2,2H22a2.0023,2.0023,0,0,0,2-2V24Z"
  })), children);
});
var SubnetAclRules20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SubnetAclRules20(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 14H30V16H18zM18 19H26V21H18zM18 9H30V11H18z"
  })), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,24v4H6V16h8V14H10V8a4.0008,4.0008,0,0,1,7.6675-1.6L19.5005,5.6A6.001,6.001,0,0,0,8,8v6H6a2.0023,2.0023,0,0,0-2,2V28a2.0023,2.0023,0,0,0,2,2H22a2.0023,2.0023,0,0,0,2-2V24Z"
  })), children);
});
var SubnetAclRules16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SubnetAclRules16(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 14H30V16H18zM18 19H26V21H18zM18 9H30V11H18z"
  })), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,24v4H6V16h8V14H10V8a4.0008,4.0008,0,0,1,7.6675-1.6L19.5005,5.6A6.001,6.001,0,0,0,8,8v6H6a2.0023,2.0023,0,0,0-2,2V28a2.0023,2.0023,0,0,0,2,2H22a2.0023,2.0023,0,0,0,2-2V24Z"
  })), children);
});
var Subtract32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Subtract32(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 15H24V17H8z"
  })), children);
});
var Subtract24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Subtract24(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 15H24V17H8z"
  })), children);
});
var Subtract20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Subtract20(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 15H24V17H8z"
  })), children);
});
var Subtract16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Subtract16(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 15H24V17H8z"
  })), children);
});
var SubtractAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SubtractAlt32(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4c6.6,0,12,5.4,12,12s-5.4,12-12,12S4,22.6,4,16S9.4,4,16,4 M16,2C8.3,2,2,8.3,2,16s6.3,14,14,14s14-6.3,14-14\tS23.7,2,16,2z"
  })), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 15H24V17H8z"
  })), children);
});
var SubtractAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SubtractAlt24(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4c6.6,0,12,5.4,12,12s-5.4,12-12,12S4,22.6,4,16S9.4,4,16,4 M16,2C8.3,2,2,8.3,2,16s6.3,14,14,14s14-6.3,14-14\tS23.7,2,16,2z"
  })), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 15H24V17H8z"
  })), children);
});
var SubtractAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SubtractAlt20(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4c6.6,0,12,5.4,12,12s-5.4,12-12,12S4,22.6,4,16S9.4,4,16,4 M16,2C8.3,2,2,8.3,2,16s6.3,14,14,14s14-6.3,14-14\tS23.7,2,16,2z"
  })), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 15H24V17H8z"
  })), children);
});
var SubtractAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SubtractAlt16(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4c6.6,0,12,5.4,12,12s-5.4,12-12,12S4,22.6,4,16S9.4,4,16,4 M16,2C8.3,2,2,8.3,2,16s6.3,14,14,14s14-6.3,14-14\tS23.7,2,16,2z"
  })), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 15H24V17H8z"
  })), children);
});
var SummaryKpi32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SummaryKpi32(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.6667 27.5027L2 22.4484l1.3311-1.4927 5.6411 5.0316 7.6906-7.4449a1.9282 1.9282 0 012.6736-.0084L22.96 21.9983l5.5791-5.9735L30 17.3905l-5.5812 5.9758a1.996 1.996 0 01-2.8379.08l-3.5765-3.4191-7.666 7.4206A1.9629 1.9629 0 017.6667 27.5027zM30 11L26 11 28 8 30 11zM22 4H18V6h4V8H19v2h3v2H18v2h4a2.0027 2.0027 0 002-2V6A2.0023 2.0023 0 0022 4zM16 14H10V10a2.002 2.002 0 012-2h2V6H10V4h4a2.0023 2.0023 0 012 2V8a2.0023 2.0023 0 01-2 2H12v2h4zM6 12L6 4 4 4 4 5 2 5 2 7 4 7 4 12 2 12 2 14 8 14 8 12 6 12z"
  })), children);
});
var SummaryKpi24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SummaryKpi24(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.6667 27.5027L2 22.4484l1.3311-1.4927 5.6411 5.0316 7.6906-7.4449a1.9282 1.9282 0 012.6736-.0084L22.96 21.9983l5.5791-5.9735L30 17.3905l-5.5812 5.9758a1.996 1.996 0 01-2.8379.08l-3.5765-3.4191-7.666 7.4206A1.9629 1.9629 0 017.6667 27.5027zM30 11L26 11 28 8 30 11zM22 4H18V6h4V8H19v2h3v2H18v2h4a2.0027 2.0027 0 002-2V6A2.0023 2.0023 0 0022 4zM16 14H10V10a2.002 2.002 0 012-2h2V6H10V4h4a2.0023 2.0023 0 012 2V8a2.0023 2.0023 0 01-2 2H12v2h4zM6 12L6 4 4 4 4 5 2 5 2 7 4 7 4 12 2 12 2 14 8 14 8 12 6 12z"
  })), children);
});
var SummaryKpi20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SummaryKpi20(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.6667 27.5027L2 22.4484l1.3311-1.4927 5.6411 5.0316 7.6906-7.4449a1.9282 1.9282 0 012.6736-.0084L22.96 21.9983l5.5791-5.9735L30 17.3905l-5.5812 5.9758a1.996 1.996 0 01-2.8379.08l-3.5765-3.4191-7.666 7.4206A1.9629 1.9629 0 017.6667 27.5027zM30 11L26 11 28 8 30 11zM22 4H18V6h4V8H19v2h3v2H18v2h4a2.0027 2.0027 0 002-2V6A2.0023 2.0023 0 0022 4zM16 14H10V10a2.002 2.002 0 012-2h2V6H10V4h4a2.0023 2.0023 0 012 2V8a2.0023 2.0023 0 01-2 2H12v2h4zM6 12L6 4 4 4 4 5 2 5 2 7 4 7 4 12 2 12 2 14 8 14 8 12 6 12z"
  })), children);
});
var SummaryKpi16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SummaryKpi16(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.6667 27.5027L2 22.4484l1.3311-1.4927 5.6411 5.0316 7.6906-7.4449a1.9282 1.9282 0 012.6736-.0084L22.96 21.9983l5.5791-5.9735L30 17.3905l-5.5812 5.9758a1.996 1.996 0 01-2.8379.08l-3.5765-3.4191-7.666 7.4206A1.9629 1.9629 0 017.6667 27.5027zM30 11L26 11 28 8 30 11zM22 4H18V6h4V8H19v2h3v2H18v2h4a2.0027 2.0027 0 002-2V6A2.0023 2.0023 0 0022 4zM16 14H10V10a2.002 2.002 0 012-2h2V6H10V4h4a2.0023 2.0023 0 012 2V8a2.0023 2.0023 0 01-2 2H12v2h4zM6 12L6 4 4 4 4 5 2 5 2 7 4 7 4 12 2 12 2 14 8 14 8 12 6 12z"
  })), children);
});
var Sun32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sun32(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4.0045,4.0045,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z",
    transform: "translate(0 .005)"
  })), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.86 7.856)"
  })), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15.005H7V17.005000000000003H2z"
  })), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.375 23.147H10.333V25.147H5.375z",
    transform: "rotate(-45 7.86 24.149)"
  })), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25.005H17V30.005H15z"
  })), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.147 21.668H25.147V26.625999999999998H23.147z",
    transform: "rotate(-45 24.152 24.149)"
  })), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15.005H30V17.005000000000003H25z"
  })), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.152 7.856)"
  })), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2.005H17V7.005H15z"
  })), children);
});
var Sun24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sun24(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4.0045,4.0045,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z",
    transform: "translate(0 .005)"
  })), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.86 7.856)"
  })), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15.005H7V17.005000000000003H2z"
  })), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.375 23.147H10.333V25.147H5.375z",
    transform: "rotate(-45 7.86 24.149)"
  })), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25.005H17V30.005H15z"
  })), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.147 21.668H25.147V26.625999999999998H23.147z",
    transform: "rotate(-45 24.152 24.149)"
  })), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15.005H30V17.005000000000003H25z"
  })), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.152 7.856)"
  })), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2.005H17V7.005H15z"
  })), children);
});
var Sun20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sun20(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4.0045,4.0045,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z",
    transform: "translate(0 .005)"
  })), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.86 7.856)"
  })), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15.005H7V17.005000000000003H2z"
  })), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.375 23.147H10.333V25.147H5.375z",
    transform: "rotate(-45 7.86 24.149)"
  })), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25.005H17V30.005H15z"
  })), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.147 21.668H25.147V26.625999999999998H23.147z",
    transform: "rotate(-45 24.152 24.149)"
  })), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15.005H30V17.005000000000003H25z"
  })), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.152 7.856)"
  })), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2.005H17V7.005H15z"
  })), children);
});
var Sun16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sun16(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4.0045,4.0045,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z",
    transform: "translate(0 .005)"
  })), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.86 7.856)"
  })), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15.005H7V17.005000000000003H2z"
  })), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.375 23.147H10.333V25.147H5.375z",
    transform: "rotate(-45 7.86 24.149)"
  })), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25.005H17V30.005H15z"
  })), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.147 21.668H25.147V26.625999999999998H23.147z",
    transform: "rotate(-45 24.152 24.149)"
  })), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15.005H30V17.005000000000003H25z"
  })), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.152 7.856)"
  })), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2.005H17V7.005H15z"
  })), children);
});
var Sunny32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sunny32(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  if (true) {
    if (!didWarnAboutDeprecation['Sunny32']) {
      didWarnAboutDeprecation['Sunny32'] = true;
      console.warn("The Sunny32 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4.0045,4.0045,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z",
    transform: "translate(0 .005)"
  })), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.86 7.856)"
  })), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15.005H7V17.005000000000003H2z"
  })), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.375 23.147H10.333V25.147H5.375z",
    transform: "rotate(-45 7.86 24.149)"
  })), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25.005H17V30.005H15z"
  })), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.147 21.668H25.147V26.625999999999998H23.147z",
    transform: "rotate(-45 24.152 24.149)"
  })), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15.005H30V17.005000000000003H25z"
  })), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.152 7.856)"
  })), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2.005H17V7.005H15z"
  })), children);
});
var Sunny24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sunny24(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  if (true) {
    if (!didWarnAboutDeprecation['Sunny24']) {
      didWarnAboutDeprecation['Sunny24'] = true;
      console.warn("The Sunny24 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4.0045,4.0045,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z",
    transform: "translate(0 .005)"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.86 7.856)"
  })), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15.005H7V17.005000000000003H2z"
  })), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.375 23.147H10.333V25.147H5.375z",
    transform: "rotate(-45 7.86 24.149)"
  })), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25.005H17V30.005H15z"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.147 21.668H25.147V26.625999999999998H23.147z",
    transform: "rotate(-45 24.152 24.149)"
  })), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15.005H30V17.005000000000003H25z"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.152 7.856)"
  })), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2.005H17V7.005H15z"
  })), children);
});
var Sunny20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sunny20(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  if (true) {
    if (!didWarnAboutDeprecation['Sunny20']) {
      didWarnAboutDeprecation['Sunny20'] = true;
      console.warn("The Sunny20 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4.0045,4.0045,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z",
    transform: "translate(0 .005)"
  })), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.86 7.856)"
  })), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15.005H7V17.005000000000003H2z"
  })), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.375 23.147H10.333V25.147H5.375z",
    transform: "rotate(-45 7.86 24.149)"
  })), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25.005H17V30.005H15z"
  })), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.147 21.668H25.147V26.625999999999998H23.147z",
    transform: "rotate(-45 24.152 24.149)"
  })), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15.005H30V17.005000000000003H25z"
  })), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.152 7.856)"
  })), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2.005H17V7.005H15z"
  })), children);
});
var Sunny16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sunny16(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  if (true) {
    if (!didWarnAboutDeprecation['Sunny16']) {
      didWarnAboutDeprecation['Sunny16'] = true;
      console.warn("The Sunny16 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a4,4,0,1,1-4,4,4.0045,4.0045,0,0,1,4-4m0-2a6,6,0,1,0,6,6,6,6,0,0,0-6-6Z",
    transform: "translate(0 .005)"
  })), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.86 7.856)"
  })), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 15.005H7V17.005000000000003H2z"
  })), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.375 23.147H10.333V25.147H5.375z",
    transform: "rotate(-45 7.86 24.149)"
  })), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 25.005H17V30.005H15z"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.147 21.668H25.147V26.625999999999998H23.147z",
    transform: "rotate(-45 24.152 24.149)"
  })), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15.005H30V17.005000000000003H25z"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.152 7.856)"
  })), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2.005H17V7.005H15z"
  })), children);
});
var Sunrise32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sunrise32(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 27H29.998V29H2zM16 20a4.0045 4.0045 0 014 4h2a6 6 0 00-12 0h2A4.0045 4.0045 0 0116 20zM25 22H30V24H25z"
  })), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 14.854H26.625999999999998V16.854H21.668z",
    transform: "rotate(-45 24.146 15.854)"
  })), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 4L11 9 12.41 10.41 15 7.83 15 8 15 15 17 15 17 8 17 7.83 19.59 10.41 21 9 16 4z"
  })), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 13.374H8.854V18.332H6.854z",
    transform: "rotate(-45 7.854 15.854)"
  })), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 22H7V24H2z"
  })), children);
});
var Sunrise24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sunrise24(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 27H29.998V29H2zM16 20a4.0045 4.0045 0 014 4h2a6 6 0 00-12 0h2A4.0045 4.0045 0 0116 20zM25 22H30V24H25z"
  })), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 14.854H26.625999999999998V16.854H21.668z",
    transform: "rotate(-45 24.146 15.854)"
  })), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 4L11 9 12.41 10.41 15 7.83 15 8 15 15 17 15 17 8 17 7.83 19.59 10.41 21 9 16 4z"
  })), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 13.374H8.854V18.332H6.854z",
    transform: "rotate(-45 7.854 15.854)"
  })), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 22H7V24H2z"
  })), children);
});
var Sunrise20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sunrise20(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 27H29.998V29H2zM16 20a4.0045 4.0045 0 014 4h2a6 6 0 00-12 0h2A4.0045 4.0045 0 0116 20zM25 22H30V24H25z"
  })), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 14.854H26.625999999999998V16.854H21.668z",
    transform: "rotate(-45 24.146 15.854)"
  })), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 4L11 9 12.41 10.41 15 7.83 15 8 15 15 17 15 17 8 17 7.83 19.59 10.41 21 9 16 4z"
  })), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 13.374H8.854V18.332H6.854z",
    transform: "rotate(-45 7.854 15.854)"
  })), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 22H7V24H2z"
  })), children);
});
var Sunrise16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sunrise16(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 27H29.998V29H2zM16 20a4.0045 4.0045 0 014 4h2a6 6 0 00-12 0h2A4.0045 4.0045 0 0116 20zM25 22H30V24H25z"
  })), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 14.854H26.625999999999998V16.854H21.668z",
    transform: "rotate(-45 24.146 15.854)"
  })), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 4L11 9 12.41 10.41 15 7.83 15 8 15 15 17 15 17 8 17 7.83 19.59 10.41 21 9 16 4z"
  })), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 13.374H8.854V18.332H6.854z",
    transform: "rotate(-45 7.854 15.854)"
  })), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 22H7V24H2z"
  })), children);
});
var Sunset32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sunset32(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 27.005H29.998V29.005H2z"
  })), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,20a4.0045,4.0045,0,0,1,4,4h2a6,6,0,0,0-12,0h2A4.0045,4.0045,0,0,1,16,20Z",
    transform: "translate(0 .005)"
  })), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 22.005H30V24.005H25z"
  })), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 14.854H26.625999999999998V16.854H21.668z",
    transform: "rotate(-45 24.152 15.856)"
  })), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.59 9.595L17 12.175 17 4.005 15 4.005 15 12.175 12.41 9.595 11 11.005 16 16.005 21 11.005 19.59 9.595z"
  })), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 13.374H8.854V18.332H6.854z",
    transform: "rotate(-45 7.86 15.856)"
  })), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 22.005H7V24.005H2z"
  })), children);
});
var Sunset24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sunset24(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 27.005H29.998V29.005H2z"
  })), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,20a4.0045,4.0045,0,0,1,4,4h2a6,6,0,0,0-12,0h2A4.0045,4.0045,0,0,1,16,20Z",
    transform: "translate(0 .005)"
  })), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 22.005H30V24.005H25z"
  })), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 14.854H26.625999999999998V16.854H21.668z",
    transform: "rotate(-45 24.152 15.856)"
  })), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.59 9.595L17 12.175 17 4.005 15 4.005 15 12.175 12.41 9.595 11 11.005 16 16.005 21 11.005 19.59 9.595z"
  })), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 13.374H8.854V18.332H6.854z",
    transform: "rotate(-45 7.86 15.856)"
  })), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 22.005H7V24.005H2z"
  })), children);
});
var Sunset20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sunset20(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 27.005H29.998V29.005H2z"
  })), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,20a4.0045,4.0045,0,0,1,4,4h2a6,6,0,0,0-12,0h2A4.0045,4.0045,0,0,1,16,20Z",
    transform: "translate(0 .005)"
  })), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 22.005H30V24.005H25z"
  })), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 14.854H26.625999999999998V16.854H21.668z",
    transform: "rotate(-45 24.152 15.856)"
  })), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.59 9.595L17 12.175 17 4.005 15 4.005 15 12.175 12.41 9.595 11 11.005 16 16.005 21 11.005 19.59 9.595z"
  })), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 13.374H8.854V18.332H6.854z",
    transform: "rotate(-45 7.86 15.856)"
  })), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 22.005H7V24.005H2z"
  })), children);
});
var Sunset16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Sunset16(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 27.005H29.998V29.005H2z"
  })), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,20a4.0045,4.0045,0,0,1,4,4h2a6,6,0,0,0-12,0h2A4.0045,4.0045,0,0,1,16,20Z",
    transform: "translate(0 .005)"
  })), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 22.005H30V24.005H25z"
  })), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 14.854H26.625999999999998V16.854H21.668z",
    transform: "rotate(-45 24.152 15.856)"
  })), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.59 9.595L17 12.175 17 4.005 15 4.005 15 12.175 12.41 9.595 11 11.005 16 16.005 21 11.005 19.59 9.595z"
  })), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 13.374H8.854V18.332H6.854z",
    transform: "rotate(-45 7.86 15.856)"
  })), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 22.005H7V24.005H2z"
  })), children);
});
var Svg32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Svg32(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2 2 0 01-2-2V11a2 2 0 012-2h6v2H24V21h4V17H26V15h4zM18 9L16 22 14 9 12 9 14.52 23 17.48 23 20 9 18 9zM8 23H2V21H8V17H4a2 2 0 01-2-2V11A2 2 0 014 9h6v2H4v4H8a2 2 0 012 2v4A2 2 0 018 23z"
  })), children);
});
var Svg24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Svg24(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2 2 0 01-2-2V11a2 2 0 012-2h6v2H24V21h4V17H26V15h4zM18 9L16 22 14 9 12 9 14.52 23 17.48 23 20 9 18 9zM8 23H2V21H8V17H4a2 2 0 01-2-2V11A2 2 0 014 9h6v2H4v4H8a2 2 0 012 2v4A2 2 0 018 23z"
  })), children);
});
var Svg20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Svg20(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2 2 0 01-2-2V11a2 2 0 012-2h6v2H24V21h4V17H26V15h4zM18 9L16 22 14 9 12 9 14.52 23 17.48 23 20 9 18 9zM8 23H2V21H8V17H4a2 2 0 01-2-2V11A2 2 0 014 9h6v2H4v4H8a2 2 0 012 2v4A2 2 0 018 23z"
  })), children);
});
var Svg16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Svg16(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2 2 0 01-2-2V11a2 2 0 012-2h6v2H24V21h4V17H26V15h4zM18 9L16 22 14 9 12 9 14.52 23 17.48 23 20 9 18 9zM8 23H2V21H8V17H4a2 2 0 01-2-2V11A2 2 0 014 9h6v2H4v4H8a2 2 0 012 2v4A2 2 0 018 23z"
  })), children);
});
var Swim32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Swim32(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 26H28a4.9316 4.9316 0 01-4-1.9873 5.0192 5.0192 0 01-8 0 5.0192 5.0192 0 01-8 0A4.9316 4.9316 0 014 26H2V24H4a3.44 3.44 0 003.0532-2.3215A.9712.9712 0 018 21a1.0069 1.0069 0 01.9487.6838A3.4381 3.4381 0 0012 24a3.44 3.44 0 003.0532-2.3215A.99.99 0 0116 21a1.0069 1.0069 0 01.9487.6838A3.4381 3.4381 0 0020 24a3.44 3.44 0 003.0532-2.3215 1 1 0 011.8955.0053A3.4381 3.4381 0 0028 24h2zM23 17.5859l-8.707-8.707A2.9791 2.9791 0 0012.1714 8H4v2h8.1714a.9933.9933 0 01.7075.293L15.5859 13 10 18.5859 11.4141 20 17 14.4141 21.5859 19zM20 10a4 4 0 114 4A4.0042 4.0042 0 0120 10zm2 0a2 2 0 102-2A2.0023 2.0023 0 0022 10z"
  })), children);
});
var Swim24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Swim24(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 26H28a4.9316 4.9316 0 01-4-1.9873 5.0192 5.0192 0 01-8 0 5.0192 5.0192 0 01-8 0A4.9316 4.9316 0 014 26H2V24H4a3.44 3.44 0 003.0532-2.3215A.9712.9712 0 018 21a1.0069 1.0069 0 01.9487.6838A3.4381 3.4381 0 0012 24a3.44 3.44 0 003.0532-2.3215A.99.99 0 0116 21a1.0069 1.0069 0 01.9487.6838A3.4381 3.4381 0 0020 24a3.44 3.44 0 003.0532-2.3215 1 1 0 011.8955.0053A3.4381 3.4381 0 0028 24h2zM23 17.5859l-8.707-8.707A2.9791 2.9791 0 0012.1714 8H4v2h8.1714a.9933.9933 0 01.7075.293L15.5859 13 10 18.5859 11.4141 20 17 14.4141 21.5859 19zM20 10a4 4 0 114 4A4.0042 4.0042 0 0120 10zm2 0a2 2 0 102-2A2.0023 2.0023 0 0022 10z"
  })), children);
});
var Swim20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Swim20(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 26H28a4.9316 4.9316 0 01-4-1.9873 5.0192 5.0192 0 01-8 0 5.0192 5.0192 0 01-8 0A4.9316 4.9316 0 014 26H2V24H4a3.44 3.44 0 003.0532-2.3215A.9712.9712 0 018 21a1.0069 1.0069 0 01.9487.6838A3.4381 3.4381 0 0012 24a3.44 3.44 0 003.0532-2.3215A.99.99 0 0116 21a1.0069 1.0069 0 01.9487.6838A3.4381 3.4381 0 0020 24a3.44 3.44 0 003.0532-2.3215 1 1 0 011.8955.0053A3.4381 3.4381 0 0028 24h2zM23 17.5859l-8.707-8.707A2.9791 2.9791 0 0012.1714 8H4v2h8.1714a.9933.9933 0 01.7075.293L15.5859 13 10 18.5859 11.4141 20 17 14.4141 21.5859 19zM20 10a4 4 0 114 4A4.0042 4.0042 0 0120 10zm2 0a2 2 0 102-2A2.0023 2.0023 0 0022 10z"
  })), children);
});
var Swim16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Swim16(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 26H28a4.9316 4.9316 0 01-4-1.9873 5.0192 5.0192 0 01-8 0 5.0192 5.0192 0 01-8 0A4.9316 4.9316 0 014 26H2V24H4a3.44 3.44 0 003.0532-2.3215A.9712.9712 0 018 21a1.0069 1.0069 0 01.9487.6838A3.4381 3.4381 0 0012 24a3.44 3.44 0 003.0532-2.3215A.99.99 0 0116 21a1.0069 1.0069 0 01.9487.6838A3.4381 3.4381 0 0020 24a3.44 3.44 0 003.0532-2.3215 1 1 0 011.8955.0053A3.4381 3.4381 0 0028 24h2zM23 17.5859l-8.707-8.707A2.9791 2.9791 0 0012.1714 8H4v2h8.1714a.9933.9933 0 01.7075.293L15.5859 13 10 18.5859 11.4141 20 17 14.4141 21.5859 19zM20 10a4 4 0 114 4A4.0042 4.0042 0 0120 10zm2 0a2 2 0 102-2A2.0023 2.0023 0 0022 10z"
  })), children);
});
var SwitchLayer_232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SwitchLayer_232(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path390 || (_path390 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 26L16 24 5.83 24 8.41 21.41 7 20 2 25 7 30 8.41 28.59 5.83 26 16 26zM16 14L16 12 5.83 12 8.41 9.41 7 8 2 13 7 18 8.41 16.59 5.83 14 16 14zM16 6L16 8 26.17 8 23.59 10.59 25 12 30 7 25 2 23.59 3.41 26.17 6 16 6zM16 18L16 20 26.17 20 23.59 22.59 25 24 30 19 25 14 23.59 15.41 26.17 18 16 18z"
  })), children);
});
var SwitchLayer_224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SwitchLayer_224(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path391 || (_path391 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 26L16 24 5.83 24 8.41 21.41 7 20 2 25 7 30 8.41 28.59 5.83 26 16 26zM16 14L16 12 5.83 12 8.41 9.41 7 8 2 13 7 18 8.41 16.59 5.83 14 16 14zM16 6L16 8 26.17 8 23.59 10.59 25 12 30 7 25 2 23.59 3.41 26.17 6 16 6zM16 18L16 20 26.17 20 23.59 22.59 25 24 30 19 25 14 23.59 15.41 26.17 18 16 18z"
  })), children);
});
var SwitchLayer_220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SwitchLayer_220(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path392 || (_path392 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 26L16 24 5.83 24 8.41 21.41 7 20 2 25 7 30 8.41 28.59 5.83 26 16 26zM16 14L16 12 5.83 12 8.41 9.41 7 8 2 13 7 18 8.41 16.59 5.83 14 16 14zM16 6L16 8 26.17 8 23.59 10.59 25 12 30 7 25 2 23.59 3.41 26.17 6 16 6zM16 18L16 20 26.17 20 23.59 22.59 25 24 30 19 25 14 23.59 15.41 26.17 18 16 18z"
  })), children);
});
var SwitchLayer_216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SwitchLayer_216(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path393 || (_path393 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 26L16 24 5.83 24 8.41 21.41 7 20 2 25 7 30 8.41 28.59 5.83 26 16 26zM16 14L16 12 5.83 12 8.41 9.41 7 8 2 13 7 18 8.41 16.59 5.83 14 16 14zM16 6L16 8 26.17 8 23.59 10.59 25 12 30 7 25 2 23.59 3.41 26.17 6 16 6zM16 18L16 20 26.17 20 23.59 22.59 25 24 30 19 25 14 23.59 15.41 26.17 18 16 18z"
  })), children);
});
var SwitchLayer_332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SwitchLayer_332(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path394 || (_path394 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 4L22 6 24.586 6 19.586 11 21 12.414 26 7.414 26 10 28 10 28 4 22 4zM10 4L10 6 7.414 6 12.414 11 11 12.414 6 7.414 6 10 4 10 4 4 10 4zM20 5L16 1 12 5 13.414 6.414 15 4.829 15 11 17 11 17 4.829 18.586 6.414 20 5zM22 28L22 26 24.586 26 19.586 21 21 19.586 26 24.586 26 22 28 22 28 28 22 28zM10 28L10 26 7.414 26 12.414 21 11 19.586 6 24.586 6 22 4 22 4 28 10 28zM20 27L16 31 12 27 13.414 25.586 15 27.171 15 21 17 21 17 27.171 18.586 25.586 20 27zM5 12L1 16 5 20 6.414 18.586 4.829 17 11 17 11 15 4.829 15 6.414 13.414 5 12zM27 12L31 16 27 20 25.586 18.586 27.171 17 21 17 21 15 27.171 15 25.586 13.414 27 12z"
  })), children);
});
var SwitchLayer_324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SwitchLayer_324(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path395 || (_path395 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 4L22 6 24.586 6 19.586 11 21 12.414 26 7.414 26 10 28 10 28 4 22 4zM10 4L10 6 7.414 6 12.414 11 11 12.414 6 7.414 6 10 4 10 4 4 10 4zM20 5L16 1 12 5 13.414 6.414 15 4.829 15 11 17 11 17 4.829 18.586 6.414 20 5zM22 28L22 26 24.586 26 19.586 21 21 19.586 26 24.586 26 22 28 22 28 28 22 28zM10 28L10 26 7.414 26 12.414 21 11 19.586 6 24.586 6 22 4 22 4 28 10 28zM20 27L16 31 12 27 13.414 25.586 15 27.171 15 21 17 21 17 27.171 18.586 25.586 20 27zM5 12L1 16 5 20 6.414 18.586 4.829 17 11 17 11 15 4.829 15 6.414 13.414 5 12zM27 12L31 16 27 20 25.586 18.586 27.171 17 21 17 21 15 27.171 15 25.586 13.414 27 12z"
  })), children);
});
var SwitchLayer_320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SwitchLayer_320(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path396 || (_path396 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 4L22 6 24.586 6 19.586 11 21 12.414 26 7.414 26 10 28 10 28 4 22 4zM10 4L10 6 7.414 6 12.414 11 11 12.414 6 7.414 6 10 4 10 4 4 10 4zM20 5L16 1 12 5 13.414 6.414 15 4.829 15 11 17 11 17 4.829 18.586 6.414 20 5zM22 28L22 26 24.586 26 19.586 21 21 19.586 26 24.586 26 22 28 22 28 28 22 28zM10 28L10 26 7.414 26 12.414 21 11 19.586 6 24.586 6 22 4 22 4 28 10 28zM20 27L16 31 12 27 13.414 25.586 15 27.171 15 21 17 21 17 27.171 18.586 25.586 20 27zM5 12L1 16 5 20 6.414 18.586 4.829 17 11 17 11 15 4.829 15 6.414 13.414 5 12zM27 12L31 16 27 20 25.586 18.586 27.171 17 21 17 21 15 27.171 15 25.586 13.414 27 12z"
  })), children);
});
var SwitchLayer_316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SwitchLayer_316(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path397 || (_path397 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 4L22 6 24.586 6 19.586 11 21 12.414 26 7.414 26 10 28 10 28 4 22 4zM10 4L10 6 7.414 6 12.414 11 11 12.414 6 7.414 6 10 4 10 4 4 10 4zM20 5L16 1 12 5 13.414 6.414 15 4.829 15 11 17 11 17 4.829 18.586 6.414 20 5zM22 28L22 26 24.586 26 19.586 21 21 19.586 26 24.586 26 22 28 22 28 28 22 28zM10 28L10 26 7.414 26 12.414 21 11 19.586 6 24.586 6 22 4 22 4 28 10 28zM20 27L16 31 12 27 13.414 25.586 15 27.171 15 21 17 21 17 27.171 18.586 25.586 20 27zM5 12L1 16 5 20 6.414 18.586 4.829 17 11 17 11 15 4.829 15 6.414 13.414 5 12zM27 12L31 16 27 20 25.586 18.586 27.171 17 21 17 21 15 27.171 15 25.586 13.414 27 12z"
  })), children);
});
var Switcher32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Switcher32(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path398 || (_path398 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 4H18V8H14zM4 4H8V8H4zM24 4H28V8H24zM14 14H18V18H14zM4 14H8V18H4zM24 14H28V18H24zM14 24H18V28H14zM4 24H8V28H4zM24 24H28V28H24z"
  })), children);
});
var Switcher24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Switcher24(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path399 || (_path399 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 4H18V8H14zM4 4H8V8H4zM24 4H28V8H24zM14 14H18V18H14zM4 14H8V18H4zM24 14H28V18H24zM14 24H18V28H14zM4 24H8V28H4zM24 24H28V28H24z"
  })), children);
});
var Switcher20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Switcher20(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path400 || (_path400 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 4H18V8H14zM4 4H8V8H4zM24 4H28V8H24zM14 14H18V18H14zM4 14H8V18H4zM24 14H28V18H24zM14 24H18V28H14zM4 24H8V28H4zM24 24H28V28H24z"
  })), children);
});
var Switcher16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Switcher16(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path401 || (_path401 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 4H18V8H14zM4 4H8V8H4zM24 4H28V8H24zM14 14H18V18H14zM4 14H8V18H4zM24 14H28V18H24zM14 24H18V28H14zM4 24H8V28H4zM24 24H28V28H24z"
  })), children);
});
var SysProvision32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SysProvision32(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path402 || (_path402 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 20L21 30 30 25 21 20z"
  })), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "14",
    r: "2"
  })), _path403 || (_path403 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,14,20Zm0-10a4,4,0,1,0,4,4A4.0045,4.0045,0,0,0,14,10Z"
  })), _path404 || (_path404 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.9512,12.91l-.0064,0A12.05,12.05,0,1,0,17,25.605V23.5386a9.9813,9.9813,0,1,1,6.6235-6.81l1.9248.544A12.0341,12.0341,0,0,0,26,14Q26,13.4492,25.9512,12.91Z"
  })), children);
});
var SysProvision24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SysProvision24(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path405 || (_path405 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 20L21 30 30 25 21 20z"
  })), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "14",
    r: "2"
  })), _path406 || (_path406 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,14,20Zm0-10a4,4,0,1,0,4,4A4.0045,4.0045,0,0,0,14,10Z"
  })), _path407 || (_path407 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.9512,12.91l-.0064,0A12.05,12.05,0,1,0,17,25.605V23.5386a9.9813,9.9813,0,1,1,6.6235-6.81l1.9248.544A12.0341,12.0341,0,0,0,26,14Q26,13.4492,25.9512,12.91Z"
  })), children);
});
var SysProvision20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SysProvision20(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path408 || (_path408 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 20L21 30 30 25 21 20z"
  })), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "14",
    r: "2"
  })), _path409 || (_path409 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,14,20Zm0-10a4,4,0,1,0,4,4A4.0045,4.0045,0,0,0,14,10Z"
  })), _path410 || (_path410 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.9512,12.91l-.0064,0A12.05,12.05,0,1,0,17,25.605V23.5386a9.9813,9.9813,0,1,1,6.6235-6.81l1.9248.544A12.0341,12.0341,0,0,0,26,14Q26,13.4492,25.9512,12.91Z"
  })), children);
});
var SysProvision16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function SysProvision16(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path411 || (_path411 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 20L21 30 30 25 21 20z"
  })), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "14",
    r: "2"
  })), _path412 || (_path412 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,14,20Zm0-10a4,4,0,1,0,4,4A4.0045,4.0045,0,0,0,14,10Z"
  })), _path413 || (_path413 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.9512,12.91l-.0064,0A12.05,12.05,0,1,0,17,25.605V23.5386a9.9813,9.9813,0,1,1,6.6235-6.81l1.9248.544A12.0341,12.0341,0,0,0,26,14Q26,13.4492,25.9512,12.91Z"
  })), children);
});
var QT32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QT32(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path414 || (_path414 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 11L15 11 15 23 17 23 17 11 20 11 20 9 12 9 12 11z"
  })), children);
});
var QT24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QT24(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path415 || (_path415 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 11L15 11 15 23 17 23 17 11 20 11 20 9 12 9 12 11z"
  })), children);
});
var QT20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QT20(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path416 || (_path416 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 11L15 11 15 23 17 23 17 11 20 11 20 9 12 9 12 11z"
  })), children);
});
var QT16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QT16(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path417 || (_path417 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 11L15 11 15 23 17 23 17 11 20 11 20 9 12 9 12 11z"
  })), children);
});
var QTAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QTAlt32(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path418 || (_path418 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 11L11 11 11 23 13 23 13 11 16 11 16 9 8 9 8 11zM24 9L22 9 22 7 20 7 20 9 18 9 18 11 20 11 20 17 21 18 22 17 22 11 24 11 24 9z"
  })), children);
});
var QTAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QTAlt24(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path419 || (_path419 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 11L11 11 11 23 13 23 13 11 16 11 16 9 8 9 8 11zM24 9L22 9 22 7 20 7 20 9 18 9 18 11 20 11 20 17 21 18 22 17 22 11 24 11 24 9z"
  })), children);
});
var QTAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QTAlt20(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path420 || (_path420 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 11L11 11 11 23 13 23 13 11 16 11 16 9 8 9 8 11zM24 9L22 9 22 7 20 7 20 9 18 9 18 11 20 11 20 17 21 18 22 17 22 11 24 11 24 9z"
  })), children);
});
var QTAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QTAlt16(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path421 || (_path421 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 11L11 11 11 23 13 23 13 11 16 11 16 9 8 9 8 11zM24 9L22 9 22 7 20 7 20 9 18 9 18 11 20 11 20 17 21 18 22 17 22 11 24 11 24 9z"
  })), children);
});
var Table32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Table32(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path422 || (_path422 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,5a2,2,0,0,0-2-2H5A2,2,0,0,0,3,5V27a2,2,0,0,0,2,2H27a2,2,0,0,0,2-2ZM27,5V9H5V5Zm0,22H5V23H27Zm0-6H5V17H27Zm0-6H5V11H27Z"
  })), children);
});
var Table24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Table24(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path423 || (_path423 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,5a2,2,0,0,0-2-2H5A2,2,0,0,0,3,5V27a2,2,0,0,0,2,2H27a2,2,0,0,0,2-2ZM27,5V9H5V5Zm0,22H5V23H27Zm0-6H5V17H27Zm0-6H5V11H27Z"
  })), children);
});
var Table20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Table20(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path424 || (_path424 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,5a2,2,0,0,0-2-2H5A2,2,0,0,0,3,5V27a2,2,0,0,0,2,2H27a2,2,0,0,0,2-2ZM27,5V9H5V5Zm0,22H5V23H27Zm0-6H5V17H27Zm0-6H5V11H27Z"
  })), children);
});
var Table16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Table16(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path425 || (_path425 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,5a2,2,0,0,0-2-2H5A2,2,0,0,0,3,5V27a2,2,0,0,0,2,2H27a2,2,0,0,0,2-2ZM27,5V9H5V5Zm0,22H5V23H27Zm0-6H5V17H27Zm0-6H5V11H27Z"
  })), children);
});
var TableAlias32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableAlias32(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path426 || (_path426 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,29H5a2.0021,2.0021,0,0,1-2-2V20a2.0021,2.0021,0,0,1,2-2h7a2.0021,2.0021,0,0,1,2,2v7A2.0021,2.0021,0,0,1,12,29ZM5,20v7h7V20Z"
  })), _path427 || (_path427 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2,2,0,0,0,3,5V15H5V11H15v4h2V11H27v7H17v2H27v7H17v2H27a2,2,0,0,0,2-2V5A2,2,0,0,0,27,3Zm0,6H5V5H27Z"
  })), children);
});
var TableAlias24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableAlias24(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path428 || (_path428 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,29H5a2.0021,2.0021,0,0,1-2-2V20a2.0021,2.0021,0,0,1,2-2h7a2.0021,2.0021,0,0,1,2,2v7A2.0021,2.0021,0,0,1,12,29ZM5,20v7h7V20Z"
  })), _path429 || (_path429 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2,2,0,0,0,3,5V15H5V11H15v4h2V11H27v7H17v2H27v7H17v2H27a2,2,0,0,0,2-2V5A2,2,0,0,0,27,3Zm0,6H5V5H27Z"
  })), children);
});
var TableAlias20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableAlias20(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path430 || (_path430 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,29H5a2.0021,2.0021,0,0,1-2-2V20a2.0021,2.0021,0,0,1,2-2h7a2.0021,2.0021,0,0,1,2,2v7A2.0021,2.0021,0,0,1,12,29ZM5,20v7h7V20Z"
  })), _path431 || (_path431 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2,2,0,0,0,3,5V15H5V11H15v4h2V11H27v7H17v2H27v7H17v2H27a2,2,0,0,0,2-2V5A2,2,0,0,0,27,3Zm0,6H5V5H27Z"
  })), children);
});
var TableAlias16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableAlias16(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path432 || (_path432 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,29H5a2.0021,2.0021,0,0,1-2-2V20a2.0021,2.0021,0,0,1,2-2h7a2.0021,2.0021,0,0,1,2,2v7A2.0021,2.0021,0,0,1,12,29ZM5,20v7h7V20Z"
  })), _path433 || (_path433 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2,2,0,0,0,3,5V15H5V11H15v4h2V11H27v7H17v2H27v7H17v2H27a2,2,0,0,0,2-2V5A2,2,0,0,0,27,3Zm0,6H5V5H27Z"
  })), children);
});
var TableBuilt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableBuilt32(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path434 || (_path434 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H24V4a2.0025,2.0025,0,0,0-2-2H4A2.0025,2.0025,0,0,0,2,4V22a2.0025,2.0025,0,0,0,2,2H8v4a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V10A2.0025,2.0025,0,0,0,28,8ZM22,22H14V17h8Zm0-7H14V10h8ZM12,15H4V10h8ZM22,4V8H4V4ZM4,22V17h8v5Zm24,6H10V24H22a2.0025,2.0025,0,0,0,2-2V10h4Z"
  })), children);
});
var TableBuilt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableBuilt24(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path435 || (_path435 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H24V4a2.0025,2.0025,0,0,0-2-2H4A2.0025,2.0025,0,0,0,2,4V22a2.0025,2.0025,0,0,0,2,2H8v4a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V10A2.0025,2.0025,0,0,0,28,8ZM22,22H14V17h8Zm0-7H14V10h8ZM12,15H4V10h8ZM22,4V8H4V4ZM4,22V17h8v5Zm24,6H10V24H22a2.0025,2.0025,0,0,0,2-2V10h4Z"
  })), children);
});
var TableBuilt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableBuilt20(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path436 || (_path436 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H24V4a2.0025,2.0025,0,0,0-2-2H4A2.0025,2.0025,0,0,0,2,4V22a2.0025,2.0025,0,0,0,2,2H8v4a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V10A2.0025,2.0025,0,0,0,28,8ZM22,22H14V17h8Zm0-7H14V10h8ZM12,15H4V10h8ZM22,4V8H4V4ZM4,22V17h8v5Zm24,6H10V24H22a2.0025,2.0025,0,0,0,2-2V10h4Z"
  })), children);
});
var TableBuilt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableBuilt16(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path437 || (_path437 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H24V4a2.0025,2.0025,0,0,0-2-2H4A2.0025,2.0025,0,0,0,2,4V22a2.0025,2.0025,0,0,0,2,2H8v4a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V10A2.0025,2.0025,0,0,0,28,8ZM22,22H14V17h8Zm0-7H14V10h8ZM12,15H4V10h8ZM22,4V8H4V4ZM4,22V17h8v5Zm24,6H10V24H22a2.0025,2.0025,0,0,0,2-2V10h4Z"
  })), children);
});
var TableShortcut32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableShortcut32(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path438 || (_path438 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 18L5 20 10.586 20 3 27.586 4.414 29 12 21.414 12 27 14 27 14 18 5 18z"
  })), _path439 || (_path439 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2,2,0,0,0,3,5V15H5V11H15v4h2V11H27v7H17v2H27v7H17v2H27a2,2,0,0,0,2-2V5A2,2,0,0,0,27,3Zm0,6H5V5H27Z"
  })), children);
});
var TableShortcut24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableShortcut24(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path440 || (_path440 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 18L5 20 10.586 20 3 27.586 4.414 29 12 21.414 12 27 14 27 14 18 5 18z"
  })), _path441 || (_path441 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2,2,0,0,0,3,5V15H5V11H15v4h2V11H27v7H17v2H27v7H17v2H27a2,2,0,0,0,2-2V5A2,2,0,0,0,27,3Zm0,6H5V5H27Z"
  })), children);
});
var TableShortcut20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableShortcut20(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path442 || (_path442 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 18L5 20 10.586 20 3 27.586 4.414 29 12 21.414 12 27 14 27 14 18 5 18z"
  })), _path443 || (_path443 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2,2,0,0,0,3,5V15H5V11H15v4h2V11H27v7H17v2H27v7H17v2H27a2,2,0,0,0,2-2V5A2,2,0,0,0,27,3Zm0,6H5V5H27Z"
  })), children);
});
var TableShortcut16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableShortcut16(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path444 || (_path444 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 18L5 20 10.586 20 3 27.586 4.414 29 12 21.414 12 27 14 27 14 18 5 18z"
  })), _path445 || (_path445 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2,2,0,0,0,3,5V15H5V11H15v4h2V11H27v7H17v2H27v7H17v2H27a2,2,0,0,0,2-2V5A2,2,0,0,0,27,3Zm0,6H5V5H27Z"
  })), children);
});
var TableSplit32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableSplit32(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path446 || (_path446 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2,2,0,0,0,3,5V27a2,2,0,0,0,2,2H27a2,2,0,0,0,2-2V5A2,2,0,0,0,27,3Zm0,2V9H5V5ZM17,11H27v7H17Zm-2,7H5V11H15ZM5,20H15v7H5Zm12,7V20H27v7Z"
  })), children);
});
var TableSplit24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableSplit24(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path447 || (_path447 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2,2,0,0,0,3,5V27a2,2,0,0,0,2,2H27a2,2,0,0,0,2-2V5A2,2,0,0,0,27,3Zm0,2V9H5V5ZM17,11H27v7H17Zm-2,7H5V11H15ZM5,20H15v7H5Zm12,7V20H27v7Z"
  })), children);
});
var TableSplit20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableSplit20(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path448 || (_path448 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2,2,0,0,0,3,5V27a2,2,0,0,0,2,2H27a2,2,0,0,0,2-2V5A2,2,0,0,0,27,3Zm0,2V9H5V5ZM17,11H27v7H17Zm-2,7H5V11H15ZM5,20H15v7H5Zm12,7V20H27v7Z"
  })), children);
});
var TableSplit16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableSplit16(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path449 || (_path449 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2,2,0,0,0,3,5V27a2,2,0,0,0,2,2H27a2,2,0,0,0,2-2V5A2,2,0,0,0,27,3Zm0,2V9H5V5ZM17,11H27v7H17Zm-2,7H5V11H15ZM5,20H15v7H5Zm12,7V20H27v7Z"
  })), children);
});
var TableOfContents32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableOfContents32(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path450 || (_path450 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 6H22V8H4zM4 12H22V14H4zM4 18H22V20H4zM4 24H22V26H4zM26 6H28V8H26zM26 12H28V14H26zM26 18H28V20H26zM26 24H28V26H26z"
  })), children);
});
var TableOfContents24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableOfContents24(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path451 || (_path451 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 6H22V8H4zM4 12H22V14H4zM4 18H22V20H4zM4 24H22V26H4zM26 6H28V8H26zM26 12H28V14H26zM26 18H28V20H26zM26 24H28V26H26z"
  })), children);
});
var TableOfContents20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableOfContents20(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path452 || (_path452 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 6H22V8H4zM4 12H22V14H4zM4 18H22V20H4zM4 24H22V26H4zM26 6H28V8H26zM26 12H28V14H26zM26 18H28V20H26zM26 24H28V26H26z"
  })), children);
});
var TableOfContents16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TableOfContents16(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path453 || (_path453 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 6H22V8H4zM4 12H22V14H4zM4 18H22V20H4zM4 24H22V26H4zM26 6H28V8H26zM26 12H28V14H26zM26 18H28V20H26zM26 24H28V26H26z"
  })), children);
});
var Tablet32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tablet32(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path454 || (_path454 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 22H17V28H15z",
    transform: "rotate(90 16 25)"
  })), _path455 || (_path455 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,30H7a2.0023,2.0023,0,0,1-2-2V4A2.002,2.002,0,0,1,7,2H25a2.0023,2.0023,0,0,1,2,2V28A2.0027,2.0027,0,0,1,25,30ZM7,4V28H25V4Z"
  })), children);
});
var Tablet24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tablet24(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path456 || (_path456 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 22H17V28H15z",
    transform: "rotate(90 16 25)"
  })), _path457 || (_path457 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,30H7a2.0023,2.0023,0,0,1-2-2V4A2.002,2.002,0,0,1,7,2H25a2.0023,2.0023,0,0,1,2,2V28A2.0027,2.0027,0,0,1,25,30ZM7,4V28H25V4Z"
  })), children);
});
var Tablet20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tablet20(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path458 || (_path458 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 22H17V28H15z",
    transform: "rotate(90 16 25)"
  })), _path459 || (_path459 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,30H7a2.0023,2.0023,0,0,1-2-2V4A2.002,2.002,0,0,1,7,2H25a2.0023,2.0023,0,0,1,2,2V28A2.0027,2.0027,0,0,1,25,30ZM7,4V28H25V4Z"
  })), children);
});
var Tablet16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tablet16(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path460 || (_path460 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 22H17V28H15z",
    transform: "rotate(90 16 25)"
  })), _path461 || (_path461 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,30H7a2.0023,2.0023,0,0,1-2-2V4A2.002,2.002,0,0,1,7,2H25a2.0023,2.0023,0,0,1,2,2V28A2.0027,2.0027,0,0,1,25,30ZM7,4V28H25V4Z"
  })), children);
});
var TabletLandscape32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TabletLandscape32(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path462 || (_path462 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 13H26V19H24z"
  })), _path463 || (_path463 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,7V25a2.0023,2.0023,0,0,1-2,2H4a2.002,2.002,0,0,1-2-2V7A2.0023,2.0023,0,0,1,4,5H28A2.0027,2.0027,0,0,1,30,7ZM4,25H28V7H4Z"
  })), children);
});
var TabletLandscape24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TabletLandscape24(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path464 || (_path464 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 13H26V19H24z"
  })), _path465 || (_path465 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,7V25a2.0023,2.0023,0,0,1-2,2H4a2.002,2.002,0,0,1-2-2V7A2.0023,2.0023,0,0,1,4,5H28A2.0027,2.0027,0,0,1,30,7ZM4,25H28V7H4Z"
  })), children);
});
var TabletLandscape20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TabletLandscape20(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path466 || (_path466 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 13H26V19H24z"
  })), _path467 || (_path467 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,7V25a2.0023,2.0023,0,0,1-2,2H4a2.002,2.002,0,0,1-2-2V7A2.0023,2.0023,0,0,1,4,5H28A2.0027,2.0027,0,0,1,30,7ZM4,25H28V7H4Z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-27.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-27.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "TextLink16": () => (/* binding */ TextLink16),
/* harmony export */   "TextLink20": () => (/* binding */ TextLink20),
/* harmony export */   "TextLink24": () => (/* binding */ TextLink24),
/* harmony export */   "TextLink32": () => (/* binding */ TextLink32),
/* harmony export */   "TextLinkAnalysis16": () => (/* binding */ TextLinkAnalysis16),
/* harmony export */   "TextLinkAnalysis20": () => (/* binding */ TextLinkAnalysis20),
/* harmony export */   "TextLinkAnalysis24": () => (/* binding */ TextLinkAnalysis24),
/* harmony export */   "TextLinkAnalysis32": () => (/* binding */ TextLinkAnalysis32),
/* harmony export */   "TextMining16": () => (/* binding */ TextMining16),
/* harmony export */   "TextMining20": () => (/* binding */ TextMining20),
/* harmony export */   "TextMining24": () => (/* binding */ TextMining24),
/* harmony export */   "TextMining32": () => (/* binding */ TextMining32),
/* harmony export */   "TextMiningApplier16": () => (/* binding */ TextMiningApplier16),
/* harmony export */   "TextMiningApplier20": () => (/* binding */ TextMiningApplier20),
/* harmony export */   "TextMiningApplier24": () => (/* binding */ TextMiningApplier24),
/* harmony export */   "TextMiningApplier32": () => (/* binding */ TextMiningApplier32),
/* harmony export */   "TextSmallCaps16": () => (/* binding */ TextSmallCaps16),
/* harmony export */   "TextSmallCaps20": () => (/* binding */ TextSmallCaps20),
/* harmony export */   "TextSmallCaps24": () => (/* binding */ TextSmallCaps24),
/* harmony export */   "TextStrikethrough16": () => (/* binding */ TextStrikethrough16),
/* harmony export */   "TextStrikethrough20": () => (/* binding */ TextStrikethrough20),
/* harmony export */   "TextStrikethrough24": () => (/* binding */ TextStrikethrough24),
/* harmony export */   "TextStrikethrough32": () => (/* binding */ TextStrikethrough32),
/* harmony export */   "TextSubscript16": () => (/* binding */ TextSubscript16),
/* harmony export */   "TextSubscript20": () => (/* binding */ TextSubscript20),
/* harmony export */   "TextSubscript24": () => (/* binding */ TextSubscript24),
/* harmony export */   "TextSubscript32": () => (/* binding */ TextSubscript32),
/* harmony export */   "TextSuperscript16": () => (/* binding */ TextSuperscript16),
/* harmony export */   "TextSuperscript20": () => (/* binding */ TextSuperscript20),
/* harmony export */   "TextSuperscript24": () => (/* binding */ TextSuperscript24),
/* harmony export */   "TextSuperscript32": () => (/* binding */ TextSuperscript32),
/* harmony export */   "TextTracking16": () => (/* binding */ TextTracking16),
/* harmony export */   "TextTracking20": () => (/* binding */ TextTracking20),
/* harmony export */   "TextTracking24": () => (/* binding */ TextTracking24),
/* harmony export */   "TextTracking32": () => (/* binding */ TextTracking32),
/* harmony export */   "TextUnderline16": () => (/* binding */ TextUnderline16),
/* harmony export */   "TextUnderline20": () => (/* binding */ TextUnderline20),
/* harmony export */   "TextUnderline24": () => (/* binding */ TextUnderline24),
/* harmony export */   "TextUnderline32": () => (/* binding */ TextUnderline32),
/* harmony export */   "TextVerticalAlignment16": () => (/* binding */ TextVerticalAlignment16),
/* harmony export */   "TextVerticalAlignment20": () => (/* binding */ TextVerticalAlignment20),
/* harmony export */   "TextVerticalAlignment24": () => (/* binding */ TextVerticalAlignment24),
/* harmony export */   "TextVerticalAlignment32": () => (/* binding */ TextVerticalAlignment32),
/* harmony export */   "TextWrap16": () => (/* binding */ TextWrap16),
/* harmony export */   "TextWrap20": () => (/* binding */ TextWrap20),
/* harmony export */   "TextWrap24": () => (/* binding */ TextWrap24),
/* harmony export */   "TextWrap32": () => (/* binding */ TextWrap32),
/* harmony export */   "Theater16": () => (/* binding */ Theater16),
/* harmony export */   "Theater20": () => (/* binding */ Theater20),
/* harmony export */   "Theater24": () => (/* binding */ Theater24),
/* harmony export */   "Theater32": () => (/* binding */ Theater32),
/* harmony export */   "ThisSideUp16": () => (/* binding */ ThisSideUp16),
/* harmony export */   "ThisSideUp20": () => (/* binding */ ThisSideUp20),
/* harmony export */   "ThisSideUp24": () => (/* binding */ ThisSideUp24),
/* harmony export */   "ThisSideUp32": () => (/* binding */ ThisSideUp32),
/* harmony export */   "Thumbnail_116": () => (/* binding */ Thumbnail_116),
/* harmony export */   "Thumbnail_120": () => (/* binding */ Thumbnail_120),
/* harmony export */   "Thumbnail_124": () => (/* binding */ Thumbnail_124),
/* harmony export */   "Thumbnail_132": () => (/* binding */ Thumbnail_132),
/* harmony export */   "Thumbnail_216": () => (/* binding */ Thumbnail_216),
/* harmony export */   "Thumbnail_220": () => (/* binding */ Thumbnail_220),
/* harmony export */   "Thumbnail_224": () => (/* binding */ Thumbnail_224),
/* harmony export */   "Thumbnail_232": () => (/* binding */ Thumbnail_232),
/* harmony export */   "ThumbsDown16": () => (/* binding */ ThumbsDown16),
/* harmony export */   "ThumbsDown20": () => (/* binding */ ThumbsDown20),
/* harmony export */   "ThumbsDown24": () => (/* binding */ ThumbsDown24),
/* harmony export */   "ThumbsDown32": () => (/* binding */ ThumbsDown32),
/* harmony export */   "ThumbsDownFilled16": () => (/* binding */ ThumbsDownFilled16),
/* harmony export */   "ThumbsDownFilled20": () => (/* binding */ ThumbsDownFilled20),
/* harmony export */   "ThumbsDownFilled24": () => (/* binding */ ThumbsDownFilled24),
/* harmony export */   "ThumbsDownFilled32": () => (/* binding */ ThumbsDownFilled32),
/* harmony export */   "ThumbsUp16": () => (/* binding */ ThumbsUp16),
/* harmony export */   "ThumbsUp20": () => (/* binding */ ThumbsUp20),
/* harmony export */   "ThumbsUp24": () => (/* binding */ ThumbsUp24),
/* harmony export */   "ThumbsUp32": () => (/* binding */ ThumbsUp32),
/* harmony export */   "ThumbsUpFilled16": () => (/* binding */ ThumbsUpFilled16),
/* harmony export */   "ThumbsUpFilled20": () => (/* binding */ ThumbsUpFilled20),
/* harmony export */   "ThumbsUpFilled24": () => (/* binding */ ThumbsUpFilled24),
/* harmony export */   "ThumbsUpFilled32": () => (/* binding */ ThumbsUpFilled32),
/* harmony export */   "Thunderstorm16": () => (/* binding */ Thunderstorm16),
/* harmony export */   "Thunderstorm20": () => (/* binding */ Thunderstorm20),
/* harmony export */   "Thunderstorm24": () => (/* binding */ Thunderstorm24),
/* harmony export */   "Thunderstorm32": () => (/* binding */ Thunderstorm32),
/* harmony export */   "ThunderstormScattered16": () => (/* binding */ ThunderstormScattered16),
/* harmony export */   "ThunderstormScattered20": () => (/* binding */ ThunderstormScattered20),
/* harmony export */   "ThunderstormScattered24": () => (/* binding */ ThunderstormScattered24),
/* harmony export */   "ThunderstormScattered32": () => (/* binding */ ThunderstormScattered32),
/* harmony export */   "ThunderstormScatteredNight16": () => (/* binding */ ThunderstormScatteredNight16),
/* harmony export */   "ThunderstormScatteredNight20": () => (/* binding */ ThunderstormScatteredNight20),
/* harmony export */   "ThunderstormScatteredNight24": () => (/* binding */ ThunderstormScatteredNight24),
/* harmony export */   "ThunderstormScatteredNight32": () => (/* binding */ ThunderstormScatteredNight32),
/* harmony export */   "ThunderstormSevere16": () => (/* binding */ ThunderstormSevere16),
/* harmony export */   "ThunderstormSevere20": () => (/* binding */ ThunderstormSevere20),
/* harmony export */   "ThunderstormSevere24": () => (/* binding */ ThunderstormSevere24),
/* harmony export */   "ThunderstormSevere32": () => (/* binding */ ThunderstormSevere32),
/* harmony export */   "ThunderstormStrong16": () => (/* binding */ ThunderstormStrong16),
/* harmony export */   "ThunderstormStrong20": () => (/* binding */ ThunderstormStrong20),
/* harmony export */   "ThunderstormStrong24": () => (/* binding */ ThunderstormStrong24),
/* harmony export */   "ThunderstormStrong32": () => (/* binding */ ThunderstormStrong32),
/* harmony export */   "Ticket16": () => (/* binding */ Ticket16),
/* harmony export */   "Ticket20": () => (/* binding */ Ticket20),
/* harmony export */   "Ticket24": () => (/* binding */ Ticket24),
/* harmony export */   "Ticket32": () => (/* binding */ Ticket32),
/* harmony export */   "Tides16": () => (/* binding */ Tides16),
/* harmony export */   "Tides20": () => (/* binding */ Tides20),
/* harmony export */   "Tides24": () => (/* binding */ Tides24),
/* harmony export */   "Tides32": () => (/* binding */ Tides32),
/* harmony export */   "Tif16": () => (/* binding */ Tif16),
/* harmony export */   "Tif20": () => (/* binding */ Tif20),
/* harmony export */   "Tif24": () => (/* binding */ Tif24),
/* harmony export */   "Tif32": () => (/* binding */ Tif32),
/* harmony export */   "Time16": () => (/* binding */ Time16),
/* harmony export */   "Time20": () => (/* binding */ Time20),
/* harmony export */   "Time24": () => (/* binding */ Time24),
/* harmony export */   "Time32": () => (/* binding */ Time32),
/* harmony export */   "TimePlot16": () => (/* binding */ TimePlot16),
/* harmony export */   "TimePlot20": () => (/* binding */ TimePlot20),
/* harmony export */   "TimePlot24": () => (/* binding */ TimePlot24),
/* harmony export */   "TimePlot32": () => (/* binding */ TimePlot32),
/* harmony export */   "Timer16": () => (/* binding */ Timer16),
/* harmony export */   "Timer20": () => (/* binding */ Timer20),
/* harmony export */   "Timer24": () => (/* binding */ Timer24),
/* harmony export */   "Timer32": () => (/* binding */ Timer32),
/* harmony export */   "ToolBox16": () => (/* binding */ ToolBox16),
/* harmony export */   "ToolBox20": () => (/* binding */ ToolBox20),
/* harmony export */   "ToolBox24": () => (/* binding */ ToolBox24),
/* harmony export */   "ToolBox32": () => (/* binding */ ToolBox32),
/* harmony export */   "ToolKit16": () => (/* binding */ ToolKit16),
/* harmony export */   "ToolKit20": () => (/* binding */ ToolKit20),
/* harmony export */   "ToolKit24": () => (/* binding */ ToolKit24),
/* harmony export */   "ToolKit32": () => (/* binding */ ToolKit32),
/* harmony export */   "Tools16": () => (/* binding */ Tools16),
/* harmony export */   "Tools20": () => (/* binding */ Tools20),
/* harmony export */   "Tools24": () => (/* binding */ Tools24),
/* harmony export */   "Tools32": () => (/* binding */ Tools32),
/* harmony export */   "ToolsAlt16": () => (/* binding */ ToolsAlt16),
/* harmony export */   "ToolsAlt20": () => (/* binding */ ToolsAlt20),
/* harmony export */   "ToolsAlt24": () => (/* binding */ ToolsAlt24),
/* harmony export */   "ToolsAlt32": () => (/* binding */ ToolsAlt32),
/* harmony export */   "Tornado16": () => (/* binding */ Tornado16),
/* harmony export */   "Tornado20": () => (/* binding */ Tornado20),
/* harmony export */   "Tornado24": () => (/* binding */ Tornado24),
/* harmony export */   "Tornado32": () => (/* binding */ Tornado32),
/* harmony export */   "TornadoWarning16": () => (/* binding */ TornadoWarning16),
/* harmony export */   "TornadoWarning20": () => (/* binding */ TornadoWarning20),
/* harmony export */   "TornadoWarning24": () => (/* binding */ TornadoWarning24),
/* harmony export */   "TornadoWarning32": () => (/* binding */ TornadoWarning32),
/* harmony export */   "TouchInteraction16": () => (/* binding */ TouchInteraction16),
/* harmony export */   "TouchInteraction20": () => (/* binding */ TouchInteraction20),
/* harmony export */   "TouchInteraction24": () => (/* binding */ TouchInteraction24),
/* harmony export */   "TouchInteraction32": () => (/* binding */ TouchInteraction32),
/* harmony export */   "Touch_116": () => (/* binding */ Touch_116),
/* harmony export */   "Touch_120": () => (/* binding */ Touch_120),
/* harmony export */   "Touch_124": () => (/* binding */ Touch_124),
/* harmony export */   "Touch_132": () => (/* binding */ Touch_132),
/* harmony export */   "Touch_1Down16": () => (/* binding */ Touch_1Down16),
/* harmony export */   "Touch_1Down20": () => (/* binding */ Touch_1Down20),
/* harmony export */   "Touch_1Down24": () => (/* binding */ Touch_1Down24),
/* harmony export */   "Touch_1Down32": () => (/* binding */ Touch_1Down32),
/* harmony export */   "Touch_1DownFilled16": () => (/* binding */ Touch_1DownFilled16),
/* harmony export */   "Touch_1DownFilled20": () => (/* binding */ Touch_1DownFilled20),
/* harmony export */   "Touch_1DownFilled24": () => (/* binding */ Touch_1DownFilled24),
/* harmony export */   "Touch_1DownFilled32": () => (/* binding */ Touch_1DownFilled32),
/* harmony export */   "Touch_1Filled16": () => (/* binding */ Touch_1Filled16),
/* harmony export */   "Touch_1Filled20": () => (/* binding */ Touch_1Filled20),
/* harmony export */   "Touch_1Filled24": () => (/* binding */ Touch_1Filled24),
/* harmony export */   "Touch_1Filled32": () => (/* binding */ Touch_1Filled32),
/* harmony export */   "Touch_216": () => (/* binding */ Touch_216),
/* harmony export */   "Touch_220": () => (/* binding */ Touch_220),
/* harmony export */   "Touch_224": () => (/* binding */ Touch_224),
/* harmony export */   "Touch_232": () => (/* binding */ Touch_232),
/* harmony export */   "Touch_2Filled16": () => (/* binding */ Touch_2Filled16),
/* harmony export */   "Touch_2Filled20": () => (/* binding */ Touch_2Filled20),
/* harmony export */   "Touch_2Filled24": () => (/* binding */ Touch_2Filled24),
/* harmony export */   "Touch_2Filled32": () => (/* binding */ Touch_2Filled32),
/* harmony export */   "TrafficCone16": () => (/* binding */ TrafficCone16),
/* harmony export */   "TrafficCone20": () => (/* binding */ TrafficCone20),
/* harmony export */   "TrafficCone24": () => (/* binding */ TrafficCone24),
/* harmony export */   "TrafficCone32": () => (/* binding */ TrafficCone32),
/* harmony export */   "TrafficEvent16": () => (/* binding */ TrafficEvent16),
/* harmony export */   "TrafficEvent20": () => (/* binding */ TrafficEvent20),
/* harmony export */   "TrafficEvent24": () => (/* binding */ TrafficEvent24),
/* harmony export */   "TrafficEvent32": () => (/* binding */ TrafficEvent32),
/* harmony export */   "TrafficFlow16": () => (/* binding */ TrafficFlow16),
/* harmony export */   "TrafficFlow20": () => (/* binding */ TrafficFlow20),
/* harmony export */   "TrafficFlow24": () => (/* binding */ TrafficFlow24),
/* harmony export */   "TrafficFlow32": () => (/* binding */ TrafficFlow32),
/* harmony export */   "TrafficFlowIncident16": () => (/* binding */ TrafficFlowIncident16),
/* harmony export */   "TrafficFlowIncident20": () => (/* binding */ TrafficFlowIncident20),
/* harmony export */   "TrafficFlowIncident24": () => (/* binding */ TrafficFlowIncident24),
/* harmony export */   "TrafficFlowIncident32": () => (/* binding */ TrafficFlowIncident32),
/* harmony export */   "TrafficIncident16": () => (/* binding */ TrafficIncident16),
/* harmony export */   "TrafficIncident20": () => (/* binding */ TrafficIncident20),
/* harmony export */   "TrafficIncident24": () => (/* binding */ TrafficIncident24),
/* harmony export */   "TrafficIncident32": () => (/* binding */ TrafficIncident32),
/* harmony export */   "TrafficWeatherIncident16": () => (/* binding */ TrafficWeatherIncident16),
/* harmony export */   "TrafficWeatherIncident20": () => (/* binding */ TrafficWeatherIncident20),
/* harmony export */   "TrafficWeatherIncident24": () => (/* binding */ TrafficWeatherIncident24),
/* harmony export */   "TrafficWeatherIncident32": () => (/* binding */ TrafficWeatherIncident32),
/* harmony export */   "Train16": () => (/* binding */ Train16),
/* harmony export */   "Train20": () => (/* binding */ Train20),
/* harmony export */   "Train24": () => (/* binding */ Train24),
/* harmony export */   "Train32": () => (/* binding */ Train32),
/* harmony export */   "TrainHeart16": () => (/* binding */ TrainHeart16),
/* harmony export */   "TrainHeart20": () => (/* binding */ TrainHeart20),
/* harmony export */   "TrainHeart24": () => (/* binding */ TrainHeart24),
/* harmony export */   "TrainHeart32": () => (/* binding */ TrainHeart32),
/* harmony export */   "TrainProfile16": () => (/* binding */ TrainProfile16),
/* harmony export */   "TrainProfile20": () => (/* binding */ TrainProfile20),
/* harmony export */   "TrainProfile24": () => (/* binding */ TrainProfile24),
/* harmony export */   "TrainProfile32": () => (/* binding */ TrainProfile32),
/* harmony export */   "TrainSpeed16": () => (/* binding */ TrainSpeed16),
/* harmony export */   "TrainSpeed20": () => (/* binding */ TrainSpeed20),
/* harmony export */   "TrainSpeed24": () => (/* binding */ TrainSpeed24),
/* harmony export */   "TrainSpeed32": () => (/* binding */ TrainSpeed32),
/* harmony export */   "TrainTicket16": () => (/* binding */ TrainTicket16),
/* harmony export */   "TrainTicket20": () => (/* binding */ TrainTicket20),
/* harmony export */   "TrainTicket24": () => (/* binding */ TrainTicket24),
/* harmony export */   "TrainTicket32": () => (/* binding */ TrainTicket32),
/* harmony export */   "TrainTime16": () => (/* binding */ TrainTime16),
/* harmony export */   "TrainTime20": () => (/* binding */ TrainTime20),
/* harmony export */   "TrainTime24": () => (/* binding */ TrainTime24),
/* harmony export */   "TrainTime32": () => (/* binding */ TrainTime32),
/* harmony export */   "Tram16": () => (/* binding */ Tram16),
/* harmony export */   "Tram20": () => (/* binding */ Tram20),
/* harmony export */   "Tram24": () => (/* binding */ Tram24),
/* harmony export */   "Tram32": () => (/* binding */ Tram32),
/* harmony export */   "Transgender16": () => (/* binding */ Transgender16),
/* harmony export */   "Transgender20": () => (/* binding */ Transgender20),
/* harmony export */   "Transgender24": () => (/* binding */ Transgender24),
/* harmony export */   "Transgender32": () => (/* binding */ Transgender32),
/* harmony export */   "Translate16": () => (/* binding */ Translate16),
/* harmony export */   "Translate20": () => (/* binding */ Translate20),
/* harmony export */   "Translate24": () => (/* binding */ Translate24),
/* harmony export */   "Translate32": () => (/* binding */ Translate32),
/* harmony export */   "TransmissionLte20": () => (/* binding */ TransmissionLte20),
/* harmony export */   "TransmissionLte24": () => (/* binding */ TransmissionLte24),
/* harmony export */   "TransmissionLte32": () => (/* binding */ TransmissionLte32),
/* harmony export */   "WatsonHealthTextAnnotationToggle16": () => (/* binding */ WatsonHealthTextAnnotationToggle16),
/* harmony export */   "WatsonHealthTextAnnotationToggle20": () => (/* binding */ WatsonHealthTextAnnotationToggle20),
/* harmony export */   "WatsonHealthTextAnnotationToggle24": () => (/* binding */ WatsonHealthTextAnnotationToggle24),
/* harmony export */   "WatsonHealthTextAnnotationToggle32": () => (/* binding */ WatsonHealthTextAnnotationToggle32),
/* harmony export */   "WatsonHealthThreshold16": () => (/* binding */ WatsonHealthThreshold16),
/* harmony export */   "WatsonHealthThreshold20": () => (/* binding */ WatsonHealthThreshold20),
/* harmony export */   "WatsonHealthThreshold24": () => (/* binding */ WatsonHealthThreshold24),
/* harmony export */   "WatsonHealthThreshold32": () => (/* binding */ WatsonHealthThreshold32),
/* harmony export */   "WatsonHealthThumbnailPreview16": () => (/* binding */ WatsonHealthThumbnailPreview16),
/* harmony export */   "WatsonHealthThumbnailPreview20": () => (/* binding */ WatsonHealthThumbnailPreview20),
/* harmony export */   "WatsonHealthThumbnailPreview24": () => (/* binding */ WatsonHealthThumbnailPreview24),
/* harmony export */   "WatsonHealthThumbnailPreview32": () => (/* binding */ WatsonHealthThumbnailPreview32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _path65, _path66, _path67, _path68, _path69, _path70, _path71, _path72, _path73, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _path224, _path225, _path226, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388, _path389, _path390, _path391, _path392, _path393, _path394, _path395, _path396, _path397, _path398, _path399, _path400, _path401, _path402, _path403, _path404, _path405, _path406, _path407, _path408, _path409, _path410, _path411, _path412, _path413, _path414, _path415, _path416, _path417, _path418, _path419, _path420, _path421, _path422, _path423, _path424, _path425, _path426, _path427, _path428, _path429, _path430, _path431, _path432;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var TextSmallCaps24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextSmallCaps24(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 27L23 15 18 15 18 13 30 13 30 15 25 15 25 27 23 27z"
  })), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 27L11 8 2 8 2 6 22 6 22 8 13 8 13 27 11 27z"
  })), children);
});
var TextSmallCaps20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextSmallCaps20(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 27L23 15 18 15 18 13 30 13 30 15 25 15 25 27 23 27z"
  })), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 27L11 8 2 8 2 6 22 6 22 8 13 8 13 27 11 27z"
  })), children);
});
var TextSmallCaps16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextSmallCaps16(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 27L23 15 18 15 18 13 30 13 30 15 25 15 25 27 23 27z"
  })), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 27L11 8 2 8 2 6 22 6 22 8 13 8 13 27 11 27z"
  })), children);
});
var TextStrikethrough32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextStrikethrough32(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,15H17.9563c-.4522-.1237-.9037-.2324-1.3381-.3352-2.8077-.6641-4.396-1.1506-4.396-3.4231a2.8684,2.8684,0,0,1,.7866-2.145,4.7888,4.7888,0,0,1,3.0137-1.09c2.8291-.07,4.1347.8894,5.2011,2.35l1.6153-1.1792a7.4727,7.4727,0,0,0-6.83-3.1706,6.7726,6.7726,0,0,0-4.4,1.6611,4.8274,4.8274,0,0,0-1.3862,3.5735A4.3723,4.3723,0,0,0,11.9573,15H4v2H17.6519c1.9668.57,3.1432,1.3123,3.1733,3.3579a3.119,3.119,0,0,1-.8623,2.3931A5.8241,5.8241,0,0,1,16.2432,24a6.6344,6.6344,0,0,1-5.1451-2.6912L9.5649,22.593A8.5262,8.5262,0,0,0,16.2119,26c.0088-.0012.042,0,.1,0A7.67,7.67,0,0,0,21.36,24.1812a5.0779,5.0779,0,0,0,1.4648-3.8531A4.952,4.952,0,0,0,21.6753,17H28Z"
  })), children);
});
var TextStrikethrough24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextStrikethrough24(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,15H17.9563c-.4522-.1237-.9037-.2324-1.3381-.3352-2.8077-.6641-4.396-1.1506-4.396-3.4231a2.8684,2.8684,0,0,1,.7866-2.145,4.7888,4.7888,0,0,1,3.0137-1.09c2.8291-.07,4.1347.8894,5.2011,2.35l1.6153-1.1792a7.4727,7.4727,0,0,0-6.83-3.1706,6.7726,6.7726,0,0,0-4.4,1.6611,4.8274,4.8274,0,0,0-1.3862,3.5735A4.3723,4.3723,0,0,0,11.9573,15H4v2H17.6519c1.9668.57,3.1432,1.3123,3.1733,3.3579a3.119,3.119,0,0,1-.8623,2.3931A5.8241,5.8241,0,0,1,16.2432,24a6.6344,6.6344,0,0,1-5.1451-2.6912L9.5649,22.593A8.5262,8.5262,0,0,0,16.2119,26c.0088-.0012.042,0,.1,0A7.67,7.67,0,0,0,21.36,24.1812a5.0779,5.0779,0,0,0,1.4648-3.8531A4.952,4.952,0,0,0,21.6753,17H28Z"
  })), children);
});
var TextStrikethrough20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextStrikethrough20(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,15H17.9563c-.4522-.1237-.9037-.2324-1.3381-.3352-2.8077-.6641-4.396-1.1506-4.396-3.4231a2.8684,2.8684,0,0,1,.7866-2.145,4.7888,4.7888,0,0,1,3.0137-1.09c2.8291-.07,4.1347.8894,5.2011,2.35l1.6153-1.1792a7.4727,7.4727,0,0,0-6.83-3.1706,6.7726,6.7726,0,0,0-4.4,1.6611,4.8274,4.8274,0,0,0-1.3862,3.5735A4.3723,4.3723,0,0,0,11.9573,15H4v2H17.6519c1.9668.57,3.1432,1.3123,3.1733,3.3579a3.119,3.119,0,0,1-.8623,2.3931A5.8241,5.8241,0,0,1,16.2432,24a6.6344,6.6344,0,0,1-5.1451-2.6912L9.5649,22.593A8.5262,8.5262,0,0,0,16.2119,26c.0088-.0012.042,0,.1,0A7.67,7.67,0,0,0,21.36,24.1812a5.0779,5.0779,0,0,0,1.4648-3.8531A4.952,4.952,0,0,0,21.6753,17H28Z"
  })), children);
});
var TextStrikethrough16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextStrikethrough16(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,15H17.9563c-.4522-.1237-.9037-.2324-1.3381-.3352-2.8077-.6641-4.396-1.1506-4.396-3.4231a2.8684,2.8684,0,0,1,.7866-2.145,4.7888,4.7888,0,0,1,3.0137-1.09c2.8291-.07,4.1347.8894,5.2011,2.35l1.6153-1.1792a7.4727,7.4727,0,0,0-6.83-3.1706,6.7726,6.7726,0,0,0-4.4,1.6611,4.8274,4.8274,0,0,0-1.3862,3.5735A4.3723,4.3723,0,0,0,11.9573,15H4v2H17.6519c1.9668.57,3.1432,1.3123,3.1733,3.3579a3.119,3.119,0,0,1-.8623,2.3931A5.8241,5.8241,0,0,1,16.2432,24a6.6344,6.6344,0,0,1-5.1451-2.6912L9.5649,22.593A8.5262,8.5262,0,0,0,16.2119,26c.0088-.0012.042,0,.1,0A7.67,7.67,0,0,0,21.36,24.1812a5.0779,5.0779,0,0,0,1.4648-3.8531A4.952,4.952,0,0,0,21.6753,17H28Z"
  })), children);
});
var TextSubscript32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextSubscript32(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 25L20 25 20 19 24 19 24 17 20 17 20 15 26 15 26 21 22 21 22 23 26 23 26 25zM5 7L5 9 12 9 12 25 14 25 14 9 21 9 21 7 5 7z"
  })), children);
});
var TextSubscript24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextSubscript24(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 25L20 25 20 19 24 19 24 17 20 17 20 15 26 15 26 21 22 21 22 23 26 23 26 25zM5 7L5 9 12 9 12 25 14 25 14 9 21 9 21 7 5 7z"
  })), children);
});
var TextSubscript20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextSubscript20(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 25L20 25 20 19 24 19 24 17 20 17 20 15 26 15 26 21 22 21 22 23 26 23 26 25zM5 7L5 9 12 9 12 25 14 25 14 9 21 9 21 7 5 7z"
  })), children);
});
var TextSubscript16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextSubscript16(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 25L20 25 20 19 24 19 24 17 20 17 20 15 26 15 26 21 22 21 22 23 26 23 26 25zM5 7L5 9 12 9 12 25 14 25 14 9 21 9 21 7 5 7z"
  })), children);
});
var TextSuperscript32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextSuperscript32(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 17L23 17 23 11 27 11 27 9 23 9 23 7 29 7 29 13 25 13 25 15 29 15 29 17zM4 7L4 9 11 9 11 25 13 25 13 9 20 9 20 7 4 7z"
  })), children);
});
var TextSuperscript24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextSuperscript24(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 17L23 17 23 11 27 11 27 9 23 9 23 7 29 7 29 13 25 13 25 15 29 15 29 17zM4 7L4 9 11 9 11 25 13 25 13 9 20 9 20 7 4 7z"
  })), children);
});
var TextSuperscript20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextSuperscript20(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 17L23 17 23 11 27 11 27 9 23 9 23 7 29 7 29 13 25 13 25 15 29 15 29 17zM4 7L4 9 11 9 11 25 13 25 13 9 20 9 20 7 4 7z"
  })), children);
});
var TextSuperscript16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextSuperscript16(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 17L23 17 23 11 27 11 27 9 23 9 23 7 29 7 29 13 25 13 25 15 29 15 29 17zM4 7L4 9 11 9 11 25 13 25 13 9 20 9 20 7 4 7z"
  })), children);
});
var TextTracking32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextTracking32(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.29 19.29L23.88 20.71 26.17 23 5.83 23 8.12 20.71 6.71 19.29 2 24 6.71 28.71 8.12 27.29 5.83 25 26.17 25 23.88 27.29 25.29 28.71 30 24 25.29 19.29zM26 17h2L23 3H21L16 17h2l1-3h6zm-6.33-5L22 5l2.33 7zM14 3L10 15 6 3 4 3 9 17 11 17 16 3 14 3z"
  })), children);
});
var TextTracking24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextTracking24(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.29 19.29L23.88 20.71 26.17 23 5.83 23 8.12 20.71 6.71 19.29 2 24 6.71 28.71 8.12 27.29 5.83 25 26.17 25 23.88 27.29 25.29 28.71 30 24 25.29 19.29zM26 17h2L23 3H21L16 17h2l1-3h6zm-6.33-5L22 5l2.33 7zM14 3L10 15 6 3 4 3 9 17 11 17 16 3 14 3z"
  })), children);
});
var TextTracking20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextTracking20(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.29 19.29L23.88 20.71 26.17 23 5.83 23 8.12 20.71 6.71 19.29 2 24 6.71 28.71 8.12 27.29 5.83 25 26.17 25 23.88 27.29 25.29 28.71 30 24 25.29 19.29zM26 17h2L23 3H21L16 17h2l1-3h6zm-6.33-5L22 5l2.33 7zM14 3L10 15 6 3 4 3 9 17 11 17 16 3 14 3z"
  })), children);
});
var TextTracking16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextTracking16(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.29 19.29L23.88 20.71 26.17 23 5.83 23 8.12 20.71 6.71 19.29 2 24 6.71 28.71 8.12 27.29 5.83 25 26.17 25 23.88 27.29 25.29 28.71 30 24 25.29 19.29zM26 17h2L23 3H21L16 17h2l1-3h6zm-6.33-5L22 5l2.33 7zM14 3L10 15 6 3 4 3 9 17 11 17 16 3 14 3z"
  })), children);
});
var TextUnderline32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextUnderline32(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H28V28H4zM16 23a7 7 0 01-7-7V5h2V16a5 5 0 0010 0V5h2V16A7 7 0 0116 23z"
  })), children);
});
var TextUnderline24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextUnderline24(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H28V28H4zM16 23a7 7 0 01-7-7V5h2V16a5 5 0 0010 0V5h2V16A7 7 0 0116 23z"
  })), children);
});
var TextUnderline20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextUnderline20(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H28V28H4zM16 23a7 7 0 01-7-7V5h2V16a5 5 0 0010 0V5h2V16A7 7 0 0116 23z"
  })), children);
});
var TextUnderline16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextUnderline16(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H28V28H4zM16 23a7 7 0 01-7-7V5h2V16a5 5 0 0010 0V5h2V16A7 7 0 0116 23z"
  })), children);
});
var TextVerticalAlignment32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextVerticalAlignment32(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 28H30V30H16zM16 23H30V25H16zM10.8458 30H13L8.64 20H6.36L2 30H4.1542l.8-2h5.0916zM5.7541 26L7.5 21.6347 9.2459 26zM2 15H30V17H2zM16 7H30V9H16zM16 2H30V4H16zM10.8458 12H13L8.64 2H6.36L2 12H4.1542l.8-2h5.0916zM5.7541 8L7.5 3.6347 9.2459 8z"
  })), children);
});
var TextVerticalAlignment24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextVerticalAlignment24(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 28H30V30H16zM16 23H30V25H16zM10.8458 30H13L8.64 20H6.36L2 30H4.1542l.8-2h5.0916zM5.7541 26L7.5 21.6347 9.2459 26zM2 15H30V17H2zM16 7H30V9H16zM16 2H30V4H16zM10.8458 12H13L8.64 2H6.36L2 12H4.1542l.8-2h5.0916zM5.7541 8L7.5 3.6347 9.2459 8z"
  })), children);
});
var TextVerticalAlignment20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextVerticalAlignment20(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 28H30V30H16zM16 23H30V25H16zM10.8458 30H13L8.64 20H6.36L2 30H4.1542l.8-2h5.0916zM5.7541 26L7.5 21.6347 9.2459 26zM2 15H30V17H2zM16 7H30V9H16zM16 2H30V4H16zM10.8458 12H13L8.64 2H6.36L2 12H4.1542l.8-2h5.0916zM5.7541 8L7.5 3.6347 9.2459 8z"
  })), children);
});
var TextVerticalAlignment16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextVerticalAlignment16(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 28H30V30H16zM16 23H30V25H16zM10.8458 30H13L8.64 20H6.36L2 30H4.1542l.8-2h5.0916zM5.7541 26L7.5 21.6347 9.2459 26zM2 15H30V17H2zM16 7H30V9H16zM16 2H30V4H16zM10.8458 12H13L8.64 2H6.36L2 12H4.1542l.8-2h5.0916zM5.7541 8L7.5 3.6347 9.2459 8z"
  })), children);
});
var TextWrap32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextWrap32(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 23H12V25H4zM24.5232 14H4v2H24.5a3.5 3.5 0 010 7H18.8281l2.586-2.5859L20 19l-5 5 5 5 1.4141-1.4141L18.8281 25H24.533a5.5 5.5 0 00-.01-11zM4 5H28V7H4z"
  })), children);
});
var TextWrap24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextWrap24(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 23H12V25H4zM24.5232 14H4v2H24.5a3.5 3.5 0 010 7H18.8281l2.586-2.5859L20 19l-5 5 5 5 1.4141-1.4141L18.8281 25H24.533a5.5 5.5 0 00-.01-11zM4 5H28V7H4z"
  })), children);
});
var TextWrap20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextWrap20(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 23H12V25H4zM24.5232 14H4v2H24.5a3.5 3.5 0 010 7H18.8281l2.586-2.5859L20 19l-5 5 5 5 1.4141-1.4141L18.8281 25H24.533a5.5 5.5 0 00-.01-11zM4 5H28V7H4z"
  })), children);
});
var TextWrap16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextWrap16(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 23H12V25H4zM24.5232 14H4v2H24.5a3.5 3.5 0 010 7H18.8281l2.586-2.5859L20 19l-5 5 5 5 1.4141-1.4141L18.8281 25H24.533a5.5 5.5 0 00-.01-11zM4 5H28V7H4z"
  })), children);
});
var WatsonHealthTextAnnotationToggle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthTextAnnotationToggle32(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.537 13.76L26.24 10.463a1.5862 1.5862 0 00-2.24 0L10 24.4674V30h5.5326L29.537 16a1.5862 1.5862 0 000-2.24zM14.7042 28H12V25.2958l9.4409-9.4409 2.7042 2.7042zM25.5591 17.145L22.855 14.4409l2.2672-2.2672 2.7042 2.7042zM11 17L13 17 13 10 16 10 16 8 8 8 8 10 11 10 11 17z"
  })), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,20H4V4H20V8h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V20a2,2,0,0,0,2,2H8Z"
  })), children);
});
var WatsonHealthTextAnnotationToggle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthTextAnnotationToggle24(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.537 13.76L26.24 10.463a1.5862 1.5862 0 00-2.24 0L10 24.4674V30h5.5326L29.537 16a1.5862 1.5862 0 000-2.24zM14.7042 28H12V25.2958l9.4409-9.4409 2.7042 2.7042zM25.5591 17.145L22.855 14.4409l2.2672-2.2672 2.7042 2.7042zM11 17L13 17 13 10 16 10 16 8 8 8 8 10 11 10 11 17z"
  })), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,20H4V4H20V8h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V20a2,2,0,0,0,2,2H8Z"
  })), children);
});
var WatsonHealthTextAnnotationToggle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthTextAnnotationToggle20(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.537 13.76L26.24 10.463a1.5862 1.5862 0 00-2.24 0L10 24.4674V30h5.5326L29.537 16a1.5862 1.5862 0 000-2.24zM14.7042 28H12V25.2958l9.4409-9.4409 2.7042 2.7042zM25.5591 17.145L22.855 14.4409l2.2672-2.2672 2.7042 2.7042zM11 17L13 17 13 10 16 10 16 8 8 8 8 10 11 10 11 17z"
  })), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,20H4V4H20V8h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V20a2,2,0,0,0,2,2H8Z"
  })), children);
});
var WatsonHealthTextAnnotationToggle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthTextAnnotationToggle16(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.537 13.76L26.24 10.463a1.5862 1.5862 0 00-2.24 0L10 24.4674V30h5.5326L29.537 16a1.5862 1.5862 0 000-2.24zM14.7042 28H12V25.2958l9.4409-9.4409 2.7042 2.7042zM25.5591 17.145L22.855 14.4409l2.2672-2.2672 2.7042 2.7042zM11 17L13 17 13 10 16 10 16 8 8 8 8 10 11 10 11 17z"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,20H4V4H20V8h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V20a2,2,0,0,0,2,2H8Z"
  })), children);
});
var TextLink32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextLink32(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.7061,27.585a5.2615,5.2615,0,0,1-3.7227-8.9834l1.415,1.414a3.2638,3.2638,0,1,0,4.6153,4.6162l6.03-6.03a3.264,3.264,0,0,0-4.6162-4.6158l-1.414-1.414a5.2637,5.2637,0,0,1,7.4443,7.4438l-6.03,6.03A5.2461,5.2461,0,0,1,18.7061,27.585Z"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.2642 29.9971A5.2619 5.2619 0 016.542 21.0137l6.03-6.03a5.2636 5.2636 0 117.4438 7.4438l-1.414-1.414a3.2639 3.2639 0 10-4.6158-4.6158l-6.03 6.03a3.264 3.264 0 004.6157 4.6162l1.414 1.4141A5.2452 5.2452 0 0110.2642 29.9971zM2 10H10V12H2zM2 6H14V8H2zM2 2H14V4H2z"
  })), children);
});
var TextLink24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextLink24(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.7061,27.585a5.2615,5.2615,0,0,1-3.7227-8.9834l1.415,1.414a3.2638,3.2638,0,1,0,4.6153,4.6162l6.03-6.03a3.264,3.264,0,0,0-4.6162-4.6158l-1.414-1.414a5.2637,5.2637,0,0,1,7.4443,7.4438l-6.03,6.03A5.2461,5.2461,0,0,1,18.7061,27.585Z"
  })), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.2642 29.9971A5.2619 5.2619 0 016.542 21.0137l6.03-6.03a5.2636 5.2636 0 117.4438 7.4438l-1.414-1.414a3.2639 3.2639 0 10-4.6158-4.6158l-6.03 6.03a3.264 3.264 0 004.6157 4.6162l1.414 1.4141A5.2452 5.2452 0 0110.2642 29.9971zM2 10H10V12H2zM2 6H14V8H2zM2 2H14V4H2z"
  })), children);
});
var TextLink20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextLink20(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.7061,27.585a5.2615,5.2615,0,0,1-3.7227-8.9834l1.415,1.414a3.2638,3.2638,0,1,0,4.6153,4.6162l6.03-6.03a3.264,3.264,0,0,0-4.6162-4.6158l-1.414-1.414a5.2637,5.2637,0,0,1,7.4443,7.4438l-6.03,6.03A5.2461,5.2461,0,0,1,18.7061,27.585Z"
  })), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.2642 29.9971A5.2619 5.2619 0 016.542 21.0137l6.03-6.03a5.2636 5.2636 0 117.4438 7.4438l-1.414-1.414a3.2639 3.2639 0 10-4.6158-4.6158l-6.03 6.03a3.264 3.264 0 004.6157 4.6162l1.414 1.4141A5.2452 5.2452 0 0110.2642 29.9971zM2 10H10V12H2zM2 6H14V8H2zM2 2H14V4H2z"
  })), children);
});
var TextLink16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextLink16(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.7061,27.585a5.2615,5.2615,0,0,1-3.7227-8.9834l1.415,1.414a3.2638,3.2638,0,1,0,4.6153,4.6162l6.03-6.03a3.264,3.264,0,0,0-4.6162-4.6158l-1.414-1.414a5.2637,5.2637,0,0,1,7.4443,7.4438l-6.03,6.03A5.2461,5.2461,0,0,1,18.7061,27.585Z"
  })), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.2642 29.9971A5.2619 5.2619 0 016.542 21.0137l6.03-6.03a5.2636 5.2636 0 117.4438 7.4438l-1.414-1.414a3.2639 3.2639 0 10-4.6158-4.6158l-6.03 6.03a3.264 3.264 0 004.6157 4.6162l1.414 1.4141A5.2452 5.2452 0 0110.2642 29.9971zM2 10H10V12H2zM2 6H14V8H2zM2 2H14V4H2z"
  })), children);
});
var TextLinkAnalysis32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextLinkAnalysis32(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 10H16V12H8zM8 6H20V8H8zM8 2H20V4H8z"
  })), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.7111,28l5.6312-9.9961,7.4341,6.49A2,2,0,0,0,20.86,23.96l6.9707-10.4034-1.6622-1.1132-7,10.4472-.07.1035-7.4345-6.4907a2.0032,2.0032,0,0,0-3.0806.5308L4,25.1826V2H2V28a2.0023,2.0023,0,0,0,2,2H30V28Z"
  })), children);
});
var TextLinkAnalysis24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextLinkAnalysis24(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 10H16V12H8zM8 6H20V8H8zM8 2H20V4H8z"
  })), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.7111,28l5.6312-9.9961,7.4341,6.49A2,2,0,0,0,20.86,23.96l6.9707-10.4034-1.6622-1.1132-7,10.4472-.07.1035-7.4345-6.4907a2.0032,2.0032,0,0,0-3.0806.5308L4,25.1826V2H2V28a2.0023,2.0023,0,0,0,2,2H30V28Z"
  })), children);
});
var TextLinkAnalysis20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextLinkAnalysis20(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 10H16V12H8zM8 6H20V8H8zM8 2H20V4H8z"
  })), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.7111,28l5.6312-9.9961,7.4341,6.49A2,2,0,0,0,20.86,23.96l6.9707-10.4034-1.6622-1.1132-7,10.4472-.07.1035-7.4345-6.4907a2.0032,2.0032,0,0,0-3.0806.5308L4,25.1826V2H2V28a2.0023,2.0023,0,0,0,2,2H30V28Z"
  })), children);
});
var TextLinkAnalysis16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextLinkAnalysis16(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 10H16V12H8zM8 6H20V8H8zM8 2H20V4H8z"
  })), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.7111,28l5.6312-9.9961,7.4341,6.49A2,2,0,0,0,20.86,23.96l6.9707-10.4034-1.6622-1.1132-7,10.4472-.07.1035-7.4345-6.4907a2.0032,2.0032,0,0,0-3.0806.5308L4,25.1826V2H2V28a2.0023,2.0023,0,0,0,2,2H30V28Z"
  })), children);
});
var TextMining32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextMining32(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 28H26V30H18zM18 24H30V26H18zM18 20H30V22H18z"
  })), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.001 26.473L16 26.473 4.284 12.955 9.5 6 22.5 6 27.716 12.955 24.476 16.692 25.989 18.002 30.284 13.045 23.5 4 8.5 4 1.716 13.045 14.488 27.782 16.001 26.473z"
  })), children);
});
var TextMining24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextMining24(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 28H26V30H18zM18 24H30V26H18zM18 20H30V22H18z"
  })), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.001 26.473L16 26.473 4.284 12.955 9.5 6 22.5 6 27.716 12.955 24.476 16.692 25.989 18.002 30.284 13.045 23.5 4 8.5 4 1.716 13.045 14.488 27.782 16.001 26.473z"
  })), children);
});
var TextMining20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextMining20(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 28H26V30H18zM18 24H30V26H18zM18 20H30V22H18z"
  })), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.001 26.473L16 26.473 4.284 12.955 9.5 6 22.5 6 27.716 12.955 24.476 16.692 25.989 18.002 30.284 13.045 23.5 4 8.5 4 1.716 13.045 14.488 27.782 16.001 26.473z"
  })), children);
});
var TextMining16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextMining16(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 28H26V30H18zM18 24H30V26H18zM18 20H30V22H18z"
  })), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.001 26.473L16 26.473 4.284 12.955 9.5 6 22.5 6 27.716 12.955 24.476 16.692 25.989 18.002 30.284 13.045 23.5 4 8.5 4 1.716 13.045 14.488 27.782 16.001 26.473z"
  })), children);
});
var TextMiningApplier32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextMiningApplier32(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.001 26.473L16 26.473 4.284 12.955 9.5 6 22.5 6 27.716 12.955 24.476 16.692 25.989 18.002 30.284 13.045 23.5 4 8.5 4 1.716 13.045 14.488 27.782 16.001 26.473z"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 19L27 24 20 29 20 19z"
  })), children);
});
var TextMiningApplier24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextMiningApplier24(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.001 26.473L16 26.473 4.284 12.955 9.5 6 22.5 6 27.716 12.955 24.476 16.692 25.989 18.002 30.284 13.045 23.5 4 8.5 4 1.716 13.045 14.488 27.782 16.001 26.473z"
  })), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 19L27 24 20 29 20 19z"
  })), children);
});
var TextMiningApplier20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextMiningApplier20(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.001 26.473L16 26.473 4.284 12.955 9.5 6 22.5 6 27.716 12.955 24.476 16.692 25.989 18.002 30.284 13.045 23.5 4 8.5 4 1.716 13.045 14.488 27.782 16.001 26.473z"
  })), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 19L27 24 20 29 20 19z"
  })), children);
});
var TextMiningApplier16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TextMiningApplier16(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.001 26.473L16 26.473 4.284 12.955 9.5 6 22.5 6 27.716 12.955 24.476 16.692 25.989 18.002 30.284 13.045 23.5 4 8.5 4 1.716 13.045 14.488 27.782 16.001 26.473z"
  })), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 19L27 24 20 29 20 19z"
  })), children);
});
var Theater32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Theater32(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 25a6.9908 6.9908 0 01-5.833-3.1287l1.666-1.1074a5.0007 5.0007 0 008.334 0l1.666 1.1074A6.9908 6.9908 0 0120 25zM24 14a2 2 0 102 2A1.9806 1.9806 0 0024 14zM16 14a2 2 0 102 2A1.9806 1.9806 0 0016 14z"
  })), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H22V4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V14a10.01,10.01,0,0,0,8.8027,9.9214A9.9989,9.9989,0,0,0,30,20V10A2.0023,2.0023,0,0,0,28,8ZM4,14V4H20V8H12a2.0023,2.0023,0,0,0-2,2V20a9.9628,9.9628,0,0,0,.168,1.78A8.0081,8.0081,0,0,1,4,14Zm24,6a8,8,0,0,1-16,0V10H28Z"
  })), children);
});
var Theater24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Theater24(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 25a6.9908 6.9908 0 01-5.833-3.1287l1.666-1.1074a5.0007 5.0007 0 008.334 0l1.666 1.1074A6.9908 6.9908 0 0120 25zM24 14a2 2 0 102 2A1.9806 1.9806 0 0024 14zM16 14a2 2 0 102 2A1.9806 1.9806 0 0016 14z"
  })), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H22V4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V14a10.01,10.01,0,0,0,8.8027,9.9214A9.9989,9.9989,0,0,0,30,20V10A2.0023,2.0023,0,0,0,28,8ZM4,14V4H20V8H12a2.0023,2.0023,0,0,0-2,2V20a9.9628,9.9628,0,0,0,.168,1.78A8.0081,8.0081,0,0,1,4,14Zm24,6a8,8,0,0,1-16,0V10H28Z"
  })), children);
});
var Theater20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Theater20(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 25a6.9908 6.9908 0 01-5.833-3.1287l1.666-1.1074a5.0007 5.0007 0 008.334 0l1.666 1.1074A6.9908 6.9908 0 0120 25zM24 14a2 2 0 102 2A1.9806 1.9806 0 0024 14zM16 14a2 2 0 102 2A1.9806 1.9806 0 0016 14z"
  })), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H22V4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V14a10.01,10.01,0,0,0,8.8027,9.9214A9.9989,9.9989,0,0,0,30,20V10A2.0023,2.0023,0,0,0,28,8ZM4,14V4H20V8H12a2.0023,2.0023,0,0,0-2,2V20a9.9628,9.9628,0,0,0,.168,1.78A8.0081,8.0081,0,0,1,4,14Zm24,6a8,8,0,0,1-16,0V10H28Z"
  })), children);
});
var Theater16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Theater16(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 25a6.9908 6.9908 0 01-5.833-3.1287l1.666-1.1074a5.0007 5.0007 0 008.334 0l1.666 1.1074A6.9908 6.9908 0 0120 25zM24 14a2 2 0 102 2A1.9806 1.9806 0 0024 14zM16 14a2 2 0 102 2A1.9806 1.9806 0 0016 14z"
  })), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H22V4a2.0023,2.0023,0,0,0-2-2H4A2.0023,2.0023,0,0,0,2,4V14a10.01,10.01,0,0,0,8.8027,9.9214A9.9989,9.9989,0,0,0,30,20V10A2.0023,2.0023,0,0,0,28,8ZM4,14V4H20V8H12a2.0023,2.0023,0,0,0-2,2V20a9.9628,9.9628,0,0,0,.168,1.78A8.0081,8.0081,0,0,1,4,14Zm24,6a8,8,0,0,1-16,0V10H28Z"
  })), children);
});
var ThisSideUp32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThisSideUp32(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM7 5.828L7 24 9 24 9 5.828 12.586 9.414 14 8 8 2 2 8 3.414 9.414 7 5.828zM23 5.828L23 24 25 24 25 5.828 28.586 9.414 30 8 24 2 18 8 19.414 9.414 23 5.828z"
  })), children);
});
var ThisSideUp24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThisSideUp24(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM7 5.828L7 24 9 24 9 5.828 12.586 9.414 14 8 8 2 2 8 3.414 9.414 7 5.828zM23 5.828L23 24 25 24 25 5.828 28.586 9.414 30 8 24 2 18 8 19.414 9.414 23 5.828z"
  })), children);
});
var ThisSideUp20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThisSideUp20(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM7 5.828L7 24 9 24 9 5.828 12.586 9.414 14 8 8 2 2 8 3.414 9.414 7 5.828zM23 5.828L23 24 25 24 25 5.828 28.586 9.414 30 8 24 2 18 8 19.414 9.414 23 5.828z"
  })), children);
});
var ThisSideUp16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThisSideUp16(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM7 5.828L7 24 9 24 9 5.828 12.586 9.414 14 8 8 2 2 8 3.414 9.414 7 5.828zM23 5.828L23 24 25 24 25 5.828 28.586 9.414 30 8 24 2 18 8 19.414 9.414 23 5.828z"
  })), children);
});
var WatsonHealthThreshold32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthThreshold32(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0025,2.0025,0,0,0,4,6V26a2.0025,2.0025,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6A2.0023,2.0023,0,0,0,26,4ZM6,6H26V16H24v2h2v2H24v2h2v2H24v2H22V24H20v2H18V24H16v2H14V24H12v2H10V24H8v2H6Z"
  })), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 20H10V22H8zM12 20H14V22H12zM16 20H18V22H16zM20 20H22V22H20zM8 16H10V18H8zM16 16H18V18H16zM20 16H22V18H20zM20 12H22V14H20zM20 8H22V10H20z"
  })), children);
});
var WatsonHealthThreshold24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthThreshold24(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0025,2.0025,0,0,0,4,6V26a2.0025,2.0025,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6A2.0023,2.0023,0,0,0,26,4ZM6,6H26V16H24v2h2v2H24v2h2v2H24v2H22V24H20v2H18V24H16v2H14V24H12v2H10V24H8v2H6Z"
  })), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 20H10V22H8zM12 20H14V22H12zM16 20H18V22H16zM20 20H22V22H20zM8 16H10V18H8zM16 16H18V18H16zM20 16H22V18H20zM20 12H22V14H20zM20 8H22V10H20z"
  })), children);
});
var WatsonHealthThreshold20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthThreshold20(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0025,2.0025,0,0,0,4,6V26a2.0025,2.0025,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6A2.0023,2.0023,0,0,0,26,4ZM6,6H26V16H24v2h2v2H24v2h2v2H24v2H22V24H20v2H18V24H16v2H14V24H12v2H10V24H8v2H6Z"
  })), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 20H10V22H8zM12 20H14V22H12zM16 20H18V22H16zM20 20H22V22H20zM8 16H10V18H8zM16 16H18V18H16zM20 16H22V18H20zM20 12H22V14H20zM20 8H22V10H20z"
  })), children);
});
var WatsonHealthThreshold16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthThreshold16(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0025,2.0025,0,0,0,4,6V26a2.0025,2.0025,0,0,0,2,2H26a2.0023,2.0023,0,0,0,2-2V6A2.0023,2.0023,0,0,0,26,4ZM6,6H26V16H24v2h2v2H24v2h2v2H24v2H22V24H20v2H18V24H16v2H14V24H12v2H10V24H8v2H6Z"
  })), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 20H10V22H8zM12 20H14V22H12zM16 20H18V22H16zM20 20H22V22H20zM8 16H10V18H8zM16 16H18V18H16zM20 16H22V18H20zM20 12H22V14H20zM20 8H22V10H20z"
  })), children);
});
var Thumbnail_132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Thumbnail_132(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30H4a2 2 0 01-2-2V24a2 2 0 012-2H8a2 2 0 012 2v4A2 2 0 018 30zM4 24v4H8V24zM18 30H14a2 2 0 01-2-2V24a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0118 30zm-4-6v4h4V24zM28 30H24a2 2 0 01-2-2V24a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0128 30zm-4-6v4h4V24zM28 20H4a2 2 0 01-2-2V4A2 2 0 014 2H28a2 2 0 012 2V18A2 2 0 0128 20zM4 4V18H28V4z"
  })), children);
});
var Thumbnail_124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Thumbnail_124(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30H4a2 2 0 01-2-2V24a2 2 0 012-2H8a2 2 0 012 2v4A2 2 0 018 30zM4 24v4H8V24zM18 30H14a2 2 0 01-2-2V24a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0118 30zm-4-6v4h4V24zM28 30H24a2 2 0 01-2-2V24a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0128 30zm-4-6v4h4V24zM28 20H4a2 2 0 01-2-2V4A2 2 0 014 2H28a2 2 0 012 2V18A2 2 0 0128 20zM4 4V18H28V4z"
  })), children);
});
var Thumbnail_120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Thumbnail_120(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30H4a2 2 0 01-2-2V24a2 2 0 012-2H8a2 2 0 012 2v4A2 2 0 018 30zM4 24v4H8V24zM18 30H14a2 2 0 01-2-2V24a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0118 30zm-4-6v4h4V24zM28 30H24a2 2 0 01-2-2V24a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0128 30zm-4-6v4h4V24zM28 20H4a2 2 0 01-2-2V4A2 2 0 014 2H28a2 2 0 012 2V18A2 2 0 0128 20zM4 4V18H28V4z"
  })), children);
});
var Thumbnail_116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Thumbnail_116(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30H4a2 2 0 01-2-2V24a2 2 0 012-2H8a2 2 0 012 2v4A2 2 0 018 30zM4 24v4H8V24zM18 30H14a2 2 0 01-2-2V24a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0118 30zm-4-6v4h4V24zM28 30H24a2 2 0 01-2-2V24a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0128 30zm-4-6v4h4V24zM28 20H4a2 2 0 01-2-2V4A2 2 0 014 2H28a2 2 0 012 2V18A2 2 0 0128 20zM4 4V18H28V4z"
  })), children);
});
var Thumbnail_232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Thumbnail_232(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30H4a2 2 0 01-2-2V24a2 2 0 012-2H8a2 2 0 012 2v4A2 2 0 018 30zM4 24v4H8V24zM18 30H14a2 2 0 01-2-2V24a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0118 30zm-4-6v4h4V24zM28 30H24a2 2 0 01-2-2V24a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0128 30zm-4-6v4h4V24zM8 20H4a2 2 0 01-2-2V14a2 2 0 012-2H8a2 2 0 012 2v4A2 2 0 018 20zM4 14v4H8V14zM18 20H14a2 2 0 01-2-2V14a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0118 20zm-4-6v4h4V14zM28 20H24a2 2 0 01-2-2V14a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0128 20zm-4-6v4h4V14zM8 10H4A2 2 0 012 8V4A2 2 0 014 2H8a2 2 0 012 2V8A2 2 0 018 10zM4 4V8H8V4zM18 10H14a2 2 0 01-2-2V4a2 2 0 012-2h4a2 2 0 012 2V8A2 2 0 0118 10zM14 4V8h4V4zM28 10H24a2 2 0 01-2-2V4a2 2 0 012-2h4a2 2 0 012 2V8A2 2 0 0128 10zM24 4V8h4V4z"
  })), children);
});
var Thumbnail_224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Thumbnail_224(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30H4a2 2 0 01-2-2V24a2 2 0 012-2H8a2 2 0 012 2v4A2 2 0 018 30zM4 24v4H8V24zM18 30H14a2 2 0 01-2-2V24a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0118 30zm-4-6v4h4V24zM28 30H24a2 2 0 01-2-2V24a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0128 30zm-4-6v4h4V24zM8 20H4a2 2 0 01-2-2V14a2 2 0 012-2H8a2 2 0 012 2v4A2 2 0 018 20zM4 14v4H8V14zM18 20H14a2 2 0 01-2-2V14a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0118 20zm-4-6v4h4V14zM28 20H24a2 2 0 01-2-2V14a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0128 20zm-4-6v4h4V14zM8 10H4A2 2 0 012 8V4A2 2 0 014 2H8a2 2 0 012 2V8A2 2 0 018 10zM4 4V8H8V4zM18 10H14a2 2 0 01-2-2V4a2 2 0 012-2h4a2 2 0 012 2V8A2 2 0 0118 10zM14 4V8h4V4zM28 10H24a2 2 0 01-2-2V4a2 2 0 012-2h4a2 2 0 012 2V8A2 2 0 0128 10zM24 4V8h4V4z"
  })), children);
});
var Thumbnail_220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Thumbnail_220(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30H4a2 2 0 01-2-2V24a2 2 0 012-2H8a2 2 0 012 2v4A2 2 0 018 30zM4 24v4H8V24zM18 30H14a2 2 0 01-2-2V24a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0118 30zm-4-6v4h4V24zM28 30H24a2 2 0 01-2-2V24a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0128 30zm-4-6v4h4V24zM8 20H4a2 2 0 01-2-2V14a2 2 0 012-2H8a2 2 0 012 2v4A2 2 0 018 20zM4 14v4H8V14zM18 20H14a2 2 0 01-2-2V14a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0118 20zm-4-6v4h4V14zM28 20H24a2 2 0 01-2-2V14a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0128 20zm-4-6v4h4V14zM8 10H4A2 2 0 012 8V4A2 2 0 014 2H8a2 2 0 012 2V8A2 2 0 018 10zM4 4V8H8V4zM18 10H14a2 2 0 01-2-2V4a2 2 0 012-2h4a2 2 0 012 2V8A2 2 0 0118 10zM14 4V8h4V4zM28 10H24a2 2 0 01-2-2V4a2 2 0 012-2h4a2 2 0 012 2V8A2 2 0 0128 10zM24 4V8h4V4z"
  })), children);
});
var Thumbnail_216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Thumbnail_216(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30H4a2 2 0 01-2-2V24a2 2 0 012-2H8a2 2 0 012 2v4A2 2 0 018 30zM4 24v4H8V24zM18 30H14a2 2 0 01-2-2V24a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0118 30zm-4-6v4h4V24zM28 30H24a2 2 0 01-2-2V24a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0128 30zm-4-6v4h4V24zM8 20H4a2 2 0 01-2-2V14a2 2 0 012-2H8a2 2 0 012 2v4A2 2 0 018 20zM4 14v4H8V14zM18 20H14a2 2 0 01-2-2V14a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0118 20zm-4-6v4h4V14zM28 20H24a2 2 0 01-2-2V14a2 2 0 012-2h4a2 2 0 012 2v4A2 2 0 0128 20zm-4-6v4h4V14zM8 10H4A2 2 0 012 8V4A2 2 0 014 2H8a2 2 0 012 2V8A2 2 0 018 10zM4 4V8H8V4zM18 10H14a2 2 0 01-2-2V4a2 2 0 012-2h4a2 2 0 012 2V8A2 2 0 0118 10zM14 4V8h4V4zM28 10H24a2 2 0 01-2-2V4a2 2 0 012-2h4a2 2 0 012 2V8A2 2 0 0128 10zM24 4V8h4V4z"
  })), children);
});
var WatsonHealthThumbnailPreview32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthThumbnailPreview32(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12H4a2.0023,2.0023,0,0,0-2,2V28a2.002,2.002,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V14A2.0027,2.0027,0,0,0,28,12ZM20,28H12V27a1.0009,1.0009,0,0,1,1-1h6a1.0009,1.0009,0,0,1,1,1Zm8,0H22V27a3.0033,3.0033,0,0,0-3-3H13a3.0033,3.0033,0,0,0-3,3v1H4V14H28.002Z"
  })), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 23a4 4 0 114-4A4.0042 4.0042 0 0116 23zm0-6a2 2 0 102 2A2.0023 2.0023 0 0016 17zM30 4V8a2.0027 2.0027 0 01-2 2H24a2.0027 2.0027 0 01-2-2V4a2.0027 2.0027 0 012-2h4A2.0027 2.0027 0 0130 4zM28 8l.002-4H24V8zM20 4V8a2.0027 2.0027 0 01-2 2H14a2.0023 2.0023 0 01-2-2V4a2.0023 2.0023 0 012-2h4A2.0027 2.0027 0 0120 4zM18 8l.002-4H14V8zM10 4V8a2.0023 2.0023 0 01-2 2H4A2.0023 2.0023 0 012 8V4A2.0023 2.0023 0 014 2H8A2.0023 2.0023 0 0110 4zM8 8l.0015-4H4V8z"
  })), children);
});
var WatsonHealthThumbnailPreview24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthThumbnailPreview24(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12H4a2.0023,2.0023,0,0,0-2,2V28a2.002,2.002,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V14A2.0027,2.0027,0,0,0,28,12ZM20,28H12V27a1.0009,1.0009,0,0,1,1-1h6a1.0009,1.0009,0,0,1,1,1Zm8,0H22V27a3.0033,3.0033,0,0,0-3-3H13a3.0033,3.0033,0,0,0-3,3v1H4V14H28.002Z"
  })), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 23a4 4 0 114-4A4.0042 4.0042 0 0116 23zm0-6a2 2 0 102 2A2.0023 2.0023 0 0016 17zM30 4V8a2.0027 2.0027 0 01-2 2H24a2.0027 2.0027 0 01-2-2V4a2.0027 2.0027 0 012-2h4A2.0027 2.0027 0 0130 4zM28 8l.002-4H24V8zM20 4V8a2.0027 2.0027 0 01-2 2H14a2.0023 2.0023 0 01-2-2V4a2.0023 2.0023 0 012-2h4A2.0027 2.0027 0 0120 4zM18 8l.002-4H14V8zM10 4V8a2.0023 2.0023 0 01-2 2H4A2.0023 2.0023 0 012 8V4A2.0023 2.0023 0 014 2H8A2.0023 2.0023 0 0110 4zM8 8l.0015-4H4V8z"
  })), children);
});
var WatsonHealthThumbnailPreview20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthThumbnailPreview20(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12H4a2.0023,2.0023,0,0,0-2,2V28a2.002,2.002,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V14A2.0027,2.0027,0,0,0,28,12ZM20,28H12V27a1.0009,1.0009,0,0,1,1-1h6a1.0009,1.0009,0,0,1,1,1Zm8,0H22V27a3.0033,3.0033,0,0,0-3-3H13a3.0033,3.0033,0,0,0-3,3v1H4V14H28.002Z"
  })), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 23a4 4 0 114-4A4.0042 4.0042 0 0116 23zm0-6a2 2 0 102 2A2.0023 2.0023 0 0016 17zM30 4V8a2.0027 2.0027 0 01-2 2H24a2.0027 2.0027 0 01-2-2V4a2.0027 2.0027 0 012-2h4A2.0027 2.0027 0 0130 4zM28 8l.002-4H24V8zM20 4V8a2.0027 2.0027 0 01-2 2H14a2.0023 2.0023 0 01-2-2V4a2.0023 2.0023 0 012-2h4A2.0027 2.0027 0 0120 4zM18 8l.002-4H14V8zM10 4V8a2.0023 2.0023 0 01-2 2H4A2.0023 2.0023 0 012 8V4A2.0023 2.0023 0 014 2H8A2.0023 2.0023 0 0110 4zM8 8l.0015-4H4V8z"
  })), children);
});
var WatsonHealthThumbnailPreview16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthThumbnailPreview16(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12H4a2.0023,2.0023,0,0,0-2,2V28a2.002,2.002,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V14A2.0027,2.0027,0,0,0,28,12ZM20,28H12V27a1.0009,1.0009,0,0,1,1-1h6a1.0009,1.0009,0,0,1,1,1Zm8,0H22V27a3.0033,3.0033,0,0,0-3-3H13a3.0033,3.0033,0,0,0-3,3v1H4V14H28.002Z"
  })), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 23a4 4 0 114-4A4.0042 4.0042 0 0116 23zm0-6a2 2 0 102 2A2.0023 2.0023 0 0016 17zM30 4V8a2.0027 2.0027 0 01-2 2H24a2.0027 2.0027 0 01-2-2V4a2.0027 2.0027 0 012-2h4A2.0027 2.0027 0 0130 4zM28 8l.002-4H24V8zM20 4V8a2.0027 2.0027 0 01-2 2H14a2.0023 2.0023 0 01-2-2V4a2.0023 2.0023 0 012-2h4A2.0027 2.0027 0 0120 4zM18 8l.002-4H14V8zM10 4V8a2.0023 2.0023 0 01-2 2H4A2.0023 2.0023 0 012 8V4A2.0023 2.0023 0 014 2H8A2.0023 2.0023 0 0110 4zM8 8l.0015-4H4V8z"
  })), children);
});
var ThumbsDown32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThumbsDown32(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16V9a7.0078,7.0078,0,0,0-7-7H2V16H8.4648l3.5774,5.3662.8453,5.9165A2.0094,2.0094,0,0,0,14.8672,29H17a3.0033,3.0033,0,0,0,3-3V20h6A4.0045,4.0045,0,0,0,30,16ZM8,14H4V4H8Zm20,2a2.0025,2.0025,0,0,1-2,2H18v8a1.0008,1.0008,0,0,1-1,1H14.8672l-.9094-6.3662L10,14.6973V4H23a5.0057,5.0057,0,0,1,5,5Z"
  })), children);
});
var ThumbsDown24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThumbsDown24(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16V9a7.0078,7.0078,0,0,0-7-7H2V16H8.4648l3.5774,5.3662.8453,5.9165A2.0094,2.0094,0,0,0,14.8672,29H17a3.0033,3.0033,0,0,0,3-3V20h6A4.0045,4.0045,0,0,0,30,16ZM8,14H4V4H8Zm20,2a2.0025,2.0025,0,0,1-2,2H18v8a1.0008,1.0008,0,0,1-1,1H14.8672l-.9094-6.3662L10,14.6973V4H23a5.0057,5.0057,0,0,1,5,5Z"
  })), children);
});
var ThumbsDown20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThumbsDown20(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16V9a7.0078,7.0078,0,0,0-7-7H2V16H8.4648l3.5774,5.3662.8453,5.9165A2.0094,2.0094,0,0,0,14.8672,29H17a3.0033,3.0033,0,0,0,3-3V20h6A4.0045,4.0045,0,0,0,30,16ZM8,14H4V4H8Zm20,2a2.0025,2.0025,0,0,1-2,2H18v8a1.0008,1.0008,0,0,1-1,1H14.8672l-.9094-6.3662L10,14.6973V4H23a5.0057,5.0057,0,0,1,5,5Z"
  })), children);
});
var ThumbsDown16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThumbsDown16(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16V9a7.0078,7.0078,0,0,0-7-7H2V16H8.4648l3.5774,5.3662.8453,5.9165A2.0094,2.0094,0,0,0,14.8672,29H17a3.0033,3.0033,0,0,0,3-3V20h6A4.0045,4.0045,0,0,0,30,16ZM8,14H4V4H8Zm20,2a2.0025,2.0025,0,0,1-2,2H18v8a1.0008,1.0008,0,0,1-1,1H14.8672l-.9094-6.3662L10,14.6973V4H23a5.0057,5.0057,0,0,1,5,5Z"
  })), children);
});
var ThumbsDownFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThumbsDownFilled32(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 2H7V16H2zM23 2H9V16.8027l3.0422 4.5635.8453 5.9165A2.0094 2.0094 0 0014.8672 29H15a3.0033 3.0033 0 003-3V20h8a4.0045 4.0045 0 004-4V9A7.0078 7.0078 0 0023 2z"
  })), children);
});
var ThumbsDownFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThumbsDownFilled24(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 2H7V16H2zM23 2H9V16.8027l3.0422 4.5635.8453 5.9165A2.0094 2.0094 0 0014.8672 29H15a3.0033 3.0033 0 003-3V20h8a4.0045 4.0045 0 004-4V9A7.0078 7.0078 0 0023 2z"
  })), children);
});
var ThumbsDownFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThumbsDownFilled20(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 2H7V16H2zM23 2H9V16.8027l3.0422 4.5635.8453 5.9165A2.0094 2.0094 0 0014.8672 29H15a3.0033 3.0033 0 003-3V20h8a4.0045 4.0045 0 004-4V9A7.0078 7.0078 0 0023 2z"
  })), children);
});
var ThumbsDownFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThumbsDownFilled16(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 2H7V16H2zM23 2H9V16.8027l3.0422 4.5635.8453 5.9165A2.0094 2.0094 0 0014.8672 29H15a3.0033 3.0033 0 003-3V20h8a4.0045 4.0045 0 004-4V9A7.0078 7.0078 0 0023 2z"
  })), children);
});
var ThumbsUp32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThumbsUp32(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,12H20V6a3.0033,3.0033,0,0,0-3-3H14.8672a2.0094,2.0094,0,0,0-1.98,1.7173l-.8453,5.9165L8.4648,16H2V30H23a7.0078,7.0078,0,0,0,7-7V16A4.0045,4.0045,0,0,0,26,12ZM8,28H4V18H8Zm20-5a5.0057,5.0057,0,0,1-5,5H10V17.3027l3.9578-5.9365L14.8672,5H17a1.0008,1.0008,0,0,1,1,1v8h8a2.0025,2.0025,0,0,1,2,2Z"
  })), children);
});
var ThumbsUp24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThumbsUp24(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,12H20V6a3.0033,3.0033,0,0,0-3-3H14.8672a2.0094,2.0094,0,0,0-1.98,1.7173l-.8453,5.9165L8.4648,16H2V30H23a7.0078,7.0078,0,0,0,7-7V16A4.0045,4.0045,0,0,0,26,12ZM8,28H4V18H8Zm20-5a5.0057,5.0057,0,0,1-5,5H10V17.3027l3.9578-5.9365L14.8672,5H17a1.0008,1.0008,0,0,1,1,1v8h8a2.0025,2.0025,0,0,1,2,2Z"
  })), children);
});
var ThumbsUp20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThumbsUp20(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,12H20V6a3.0033,3.0033,0,0,0-3-3H14.8672a2.0094,2.0094,0,0,0-1.98,1.7173l-.8453,5.9165L8.4648,16H2V30H23a7.0078,7.0078,0,0,0,7-7V16A4.0045,4.0045,0,0,0,26,12ZM8,28H4V18H8Zm20-5a5.0057,5.0057,0,0,1-5,5H10V17.3027l3.9578-5.9365L14.8672,5H17a1.0008,1.0008,0,0,1,1,1v8h8a2.0025,2.0025,0,0,1,2,2Z"
  })), children);
});
var ThumbsUp16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThumbsUp16(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,12H20V6a3.0033,3.0033,0,0,0-3-3H14.8672a2.0094,2.0094,0,0,0-1.98,1.7173l-.8453,5.9165L8.4648,16H2V30H23a7.0078,7.0078,0,0,0,7-7V16A4.0045,4.0045,0,0,0,26,12ZM8,28H4V18H8Zm20-5a5.0057,5.0057,0,0,1-5,5H10V17.3027l3.9578-5.9365L14.8672,5H17a1.0008,1.0008,0,0,1,1,1v8h8a2.0025,2.0025,0,0,1,2,2Z"
  })), children);
});
var ThumbsUpFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThumbsUpFilled32(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 16H7V30H2zM23 30H9V15.1973l3.0422-4.5635.8453-5.9165A2.0094 2.0094 0 0114.8672 3H15a3.0033 3.0033 0 013 3v6h8a4.0045 4.0045 0 014 4v7A7.0078 7.0078 0 0123 30z"
  })), children);
});
var ThumbsUpFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThumbsUpFilled24(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 16H7V30H2zM23 30H9V15.1973l3.0422-4.5635.8453-5.9165A2.0094 2.0094 0 0114.8672 3H15a3.0033 3.0033 0 013 3v6h8a4.0045 4.0045 0 014 4v7A7.0078 7.0078 0 0123 30z"
  })), children);
});
var ThumbsUpFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThumbsUpFilled20(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 16H7V30H2zM23 30H9V15.1973l3.0422-4.5635.8453-5.9165A2.0094 2.0094 0 0114.8672 3H15a3.0033 3.0033 0 013 3v6h8a4.0045 4.0045 0 014 4v7A7.0078 7.0078 0 0123 30z"
  })), children);
});
var ThumbsUpFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThumbsUpFilled16(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 16H7V30H2zM23 30H9V15.1973l3.0422-4.5635.8453-5.9165A2.0094 2.0094 0 0114.8672 3H15a3.0033 3.0033 0 013 3v6h8a4.0045 4.0045 0 014 4v7A7.0078 7.0078 0 0123 30z"
  })), children);
});
var Thunderstorm32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Thunderstorm32(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,22H23V20h.5a4.5,4.5,0,0,0,.36-9L23,11l-.1-.82a7,7,0,0,0-13.88,0L9,11,8.14,11a4.5,4.5,0,0,0,.36,9H9v2H8.5A6.5,6.5,0,0,1,7.2,9.14a9,9,0,0,1,17.6,0A6.5,6.5,0,0,1,23.5,22Z"
  })), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.87 30.5L14.13 29.5 17.28 24 11.28 24 16.13 15.5 17.87 16.5 14.72 22 20.72 22 15.87 30.5z"
  })), children);
});
var Thunderstorm24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Thunderstorm24(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,22H23V20h.5a4.5,4.5,0,0,0,.36-9L23,11l-.1-.82a7,7,0,0,0-13.88,0L9,11,8.14,11a4.5,4.5,0,0,0,.36,9H9v2H8.5A6.5,6.5,0,0,1,7.2,9.14a9,9,0,0,1,17.6,0A6.5,6.5,0,0,1,23.5,22Z"
  })), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.87 30.5L14.13 29.5 17.28 24 11.28 24 16.13 15.5 17.87 16.5 14.72 22 20.72 22 15.87 30.5z"
  })), children);
});
var Thunderstorm20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Thunderstorm20(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,22H23V20h.5a4.5,4.5,0,0,0,.36-9L23,11l-.1-.82a7,7,0,0,0-13.88,0L9,11,8.14,11a4.5,4.5,0,0,0,.36,9H9v2H8.5A6.5,6.5,0,0,1,7.2,9.14a9,9,0,0,1,17.6,0A6.5,6.5,0,0,1,23.5,22Z"
  })), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.87 30.5L14.13 29.5 17.28 24 11.28 24 16.13 15.5 17.87 16.5 14.72 22 20.72 22 15.87 30.5z"
  })), children);
});
var Thunderstorm16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Thunderstorm16(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,22H23V20h.5a4.5,4.5,0,0,0,.36-9L23,11l-.1-.82a7,7,0,0,0-13.88,0L9,11,8.14,11a4.5,4.5,0,0,0,.36,9H9v2H8.5A6.5,6.5,0,0,1,7.2,9.14a9,9,0,0,1,17.6,0A6.5,6.5,0,0,1,23.5,22Z"
  })), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.87 30.5L14.13 29.5 17.28 24 11.28 24 16.13 15.5 17.87 16.5 14.72 22 20.72 22 15.87 30.5z"
  })), children);
});
var ThunderstormScattered32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThunderstormScattered32(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.338 30L11.602 29 13.889 25 10 25 13.993 18 15.73 19 13.446 23 17.337 23 13.338 30z"
  })), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,11A5.9955,5.9955,0,0,0,15.6335,8.3311,7.3494,7.3494,0,0,0,13.5,8a7.5509,7.5509,0,0,0-7.1492,5.2441A5.9926,5.9926,0,0,0,8,25V23a3.9925,3.9925,0,0,1-.6731-7.9292L7.99,14.958l.1458-.6562a5.496,5.496,0,0,1,10.7294,0l.1458.6562.6626.1128A3.9925,3.9925,0,0,1,19,23v2a5.9853,5.9853,0,0,0,5.2163-8.9463A5.9941,5.9941,0,0,0,27,11Zm-4.0732,3.4893a5.96,5.96,0,0,0-2.2776-1.2452,7.5157,7.5157,0,0,0-3.1853-4.0688,3.9869,3.9869,0,1,1,5.4629,5.314Z"
  })), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 16.233H29.732V18.233H26.732z",
    transform: "rotate(-135 28.232 17.233)"
  })), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 10H32V12H29z"
  })), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 3.768H29.732V5.768H26.732z",
    transform: "rotate(-45 28.232 4.768)"
  })), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 0H22V3H20z"
  })), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.268 3.768H15.268V5.768H12.268z",
    transform: "rotate(-135 13.768 4.768)"
  })), children);
});
var ThunderstormScattered24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThunderstormScattered24(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.338 30L11.602 29 13.889 25 10 25 13.993 18 15.73 19 13.446 23 17.337 23 13.338 30z"
  })), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,11A5.9955,5.9955,0,0,0,15.6335,8.3311,7.3494,7.3494,0,0,0,13.5,8a7.5509,7.5509,0,0,0-7.1492,5.2441A5.9926,5.9926,0,0,0,8,25V23a3.9925,3.9925,0,0,1-.6731-7.9292L7.99,14.958l.1458-.6562a5.496,5.496,0,0,1,10.7294,0l.1458.6562.6626.1128A3.9925,3.9925,0,0,1,19,23v2a5.9853,5.9853,0,0,0,5.2163-8.9463A5.9941,5.9941,0,0,0,27,11Zm-4.0732,3.4893a5.96,5.96,0,0,0-2.2776-1.2452,7.5157,7.5157,0,0,0-3.1853-4.0688,3.9869,3.9869,0,1,1,5.4629,5.314Z"
  })), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 16.233H29.732V18.233H26.732z",
    transform: "rotate(-135 28.232 17.233)"
  })), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 10H32V12H29z"
  })), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 3.768H29.732V5.768H26.732z",
    transform: "rotate(-45 28.232 4.768)"
  })), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 0H22V3H20z"
  })), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.268 3.768H15.268V5.768H12.268z",
    transform: "rotate(-135 13.768 4.768)"
  })), children);
});
var ThunderstormScattered20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThunderstormScattered20(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.338 30L11.602 29 13.889 25 10 25 13.993 18 15.73 19 13.446 23 17.337 23 13.338 30z"
  })), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,11A5.9955,5.9955,0,0,0,15.6335,8.3311,7.3494,7.3494,0,0,0,13.5,8a7.5509,7.5509,0,0,0-7.1492,5.2441A5.9926,5.9926,0,0,0,8,25V23a3.9925,3.9925,0,0,1-.6731-7.9292L7.99,14.958l.1458-.6562a5.496,5.496,0,0,1,10.7294,0l.1458.6562.6626.1128A3.9925,3.9925,0,0,1,19,23v2a5.9853,5.9853,0,0,0,5.2163-8.9463A5.9941,5.9941,0,0,0,27,11Zm-4.0732,3.4893a5.96,5.96,0,0,0-2.2776-1.2452,7.5157,7.5157,0,0,0-3.1853-4.0688,3.9869,3.9869,0,1,1,5.4629,5.314Z"
  })), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 16.233H29.732V18.233H26.732z",
    transform: "rotate(-135 28.232 17.233)"
  })), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 10H32V12H29z"
  })), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 3.768H29.732V5.768H26.732z",
    transform: "rotate(-45 28.232 4.768)"
  })), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 0H22V3H20z"
  })), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.268 3.768H15.268V5.768H12.268z",
    transform: "rotate(-135 13.768 4.768)"
  })), children);
});
var ThunderstormScattered16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThunderstormScattered16(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.338 30L11.602 29 13.889 25 10 25 13.993 18 15.73 19 13.446 23 17.337 23 13.338 30z"
  })), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,11A5.9955,5.9955,0,0,0,15.6335,8.3311,7.3494,7.3494,0,0,0,13.5,8a7.5509,7.5509,0,0,0-7.1492,5.2441A5.9926,5.9926,0,0,0,8,25V23a3.9925,3.9925,0,0,1-.6731-7.9292L7.99,14.958l.1458-.6562a5.496,5.496,0,0,1,10.7294,0l.1458.6562.6626.1128A3.9925,3.9925,0,0,1,19,23v2a5.9853,5.9853,0,0,0,5.2163-8.9463A5.9941,5.9941,0,0,0,27,11Zm-4.0732,3.4893a5.96,5.96,0,0,0-2.2776-1.2452,7.5157,7.5157,0,0,0-3.1853-4.0688,3.9869,3.9869,0,1,1,5.4629,5.314Z"
  })), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 16.233H29.732V18.233H26.732z",
    transform: "rotate(-135 28.232 17.233)"
  })), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 10H32V12H29z"
  })), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.732 3.768H29.732V5.768H26.732z",
    transform: "rotate(-45 28.232 4.768)"
  })), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 0H22V3H20z"
  })), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.268 3.768H15.268V5.768H12.268z",
    transform: "rotate(-135 13.768 4.768)"
  })), children);
});
var ThunderstormScatteredNight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThunderstormScatteredNight32(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.338 30L11.602 29 13.889 25 10 25 13.993 18 15.73 19 13.446 23 17.337 23 13.338 30z"
  })), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.844,13.0347a1.52,1.52,0,0,0-1.231-.8658,5.3562,5.3562,0,0,1-3.4094-1.7158A6.4652,6.4652,0,0,1,23.9187,4.06a1.6039,1.6039,0,0,0-.3-1.5459,1.4547,1.4547,0,0,0-1.3591-.4922l-.0191.0039a7.8544,7.8544,0,0,0-6.1054,6.48A7.3725,7.3725,0,0,0,13.5,8a7.5511,7.5511,0,0,0-7.1494,5.2441A5.9926,5.9926,0,0,0,8,25V23a3.9926,3.9926,0,0,1-.6733-7.9292l.663-.1128.1456-.6562a5.496,5.496,0,0,1,10.7294,0l.1456.6562.6626.1128A3.9925,3.9925,0,0,1,19,23v2a5.9549,5.9549,0,0,0,5.88-7.1455,7.502,7.502,0,0,0,4.8669-3.3A1.537,1.537,0,0,0,29.844,13.0347Zm-5.6926,2.9179a5.9658,5.9658,0,0,0-3.502-2.7085A7.5084,7.5084,0,0,0,18.0288,9.55a6.0085,6.0085,0,0,1,3.77-5.3335,8.4582,8.4582,0,0,0,1.9392,7.5967A7.4037,7.4037,0,0,0,27.64,14.041,5.4419,5.4419,0,0,1,24.1514,15.9526Z"
  })), children);
});
var ThunderstormScatteredNight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThunderstormScatteredNight24(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.338 30L11.602 29 13.889 25 10 25 13.993 18 15.73 19 13.446 23 17.337 23 13.338 30z"
  })), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.844,13.0347a1.52,1.52,0,0,0-1.231-.8658,5.3562,5.3562,0,0,1-3.4094-1.7158A6.4652,6.4652,0,0,1,23.9187,4.06a1.6039,1.6039,0,0,0-.3-1.5459,1.4547,1.4547,0,0,0-1.3591-.4922l-.0191.0039a7.8544,7.8544,0,0,0-6.1054,6.48A7.3725,7.3725,0,0,0,13.5,8a7.5511,7.5511,0,0,0-7.1494,5.2441A5.9926,5.9926,0,0,0,8,25V23a3.9926,3.9926,0,0,1-.6733-7.9292l.663-.1128.1456-.6562a5.496,5.496,0,0,1,10.7294,0l.1456.6562.6626.1128A3.9925,3.9925,0,0,1,19,23v2a5.9549,5.9549,0,0,0,5.88-7.1455,7.502,7.502,0,0,0,4.8669-3.3A1.537,1.537,0,0,0,29.844,13.0347Zm-5.6926,2.9179a5.9658,5.9658,0,0,0-3.502-2.7085A7.5084,7.5084,0,0,0,18.0288,9.55a6.0085,6.0085,0,0,1,3.77-5.3335,8.4582,8.4582,0,0,0,1.9392,7.5967A7.4037,7.4037,0,0,0,27.64,14.041,5.4419,5.4419,0,0,1,24.1514,15.9526Z"
  })), children);
});
var ThunderstormScatteredNight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThunderstormScatteredNight20(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.338 30L11.602 29 13.889 25 10 25 13.993 18 15.73 19 13.446 23 17.337 23 13.338 30z"
  })), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.844,13.0347a1.52,1.52,0,0,0-1.231-.8658,5.3562,5.3562,0,0,1-3.4094-1.7158A6.4652,6.4652,0,0,1,23.9187,4.06a1.6039,1.6039,0,0,0-.3-1.5459,1.4547,1.4547,0,0,0-1.3591-.4922l-.0191.0039a7.8544,7.8544,0,0,0-6.1054,6.48A7.3725,7.3725,0,0,0,13.5,8a7.5511,7.5511,0,0,0-7.1494,5.2441A5.9926,5.9926,0,0,0,8,25V23a3.9926,3.9926,0,0,1-.6733-7.9292l.663-.1128.1456-.6562a5.496,5.496,0,0,1,10.7294,0l.1456.6562.6626.1128A3.9925,3.9925,0,0,1,19,23v2a5.9549,5.9549,0,0,0,5.88-7.1455,7.502,7.502,0,0,0,4.8669-3.3A1.537,1.537,0,0,0,29.844,13.0347Zm-5.6926,2.9179a5.9658,5.9658,0,0,0-3.502-2.7085A7.5084,7.5084,0,0,0,18.0288,9.55a6.0085,6.0085,0,0,1,3.77-5.3335,8.4582,8.4582,0,0,0,1.9392,7.5967A7.4037,7.4037,0,0,0,27.64,14.041,5.4419,5.4419,0,0,1,24.1514,15.9526Z"
  })), children);
});
var ThunderstormScatteredNight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThunderstormScatteredNight16(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.338 30L11.602 29 13.889 25 10 25 13.993 18 15.73 19 13.446 23 17.337 23 13.338 30z"
  })), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.844,13.0347a1.52,1.52,0,0,0-1.231-.8658,5.3562,5.3562,0,0,1-3.4094-1.7158A6.4652,6.4652,0,0,1,23.9187,4.06a1.6039,1.6039,0,0,0-.3-1.5459,1.4547,1.4547,0,0,0-1.3591-.4922l-.0191.0039a7.8544,7.8544,0,0,0-6.1054,6.48A7.3725,7.3725,0,0,0,13.5,8a7.5511,7.5511,0,0,0-7.1494,5.2441A5.9926,5.9926,0,0,0,8,25V23a3.9926,3.9926,0,0,1-.6733-7.9292l.663-.1128.1456-.6562a5.496,5.496,0,0,1,10.7294,0l.1456.6562.6626.1128A3.9925,3.9925,0,0,1,19,23v2a5.9549,5.9549,0,0,0,5.88-7.1455,7.502,7.502,0,0,0,4.8669-3.3A1.537,1.537,0,0,0,29.844,13.0347Zm-5.6926,2.9179a5.9658,5.9658,0,0,0-3.502-2.7085A7.5084,7.5084,0,0,0,18.0288,9.55a6.0085,6.0085,0,0,1,3.77-5.3335,8.4582,8.4582,0,0,0,1.9392,7.5967A7.4037,7.4037,0,0,0,27.64,14.041,5.4419,5.4419,0,0,1,24.1514,15.9526Z"
  })), children);
});
var ThunderstormSevere32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThunderstormSevere32(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7887.8947l-2 4A.9981.9981 0 0121 30zM9 32a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7887.8947l-2 4A.9981.9981 0 019 32zM15.901 30.496L14.165 29.504 17.309 24 11.31 24 16.165 15.504 17.901 16.496 14.756 22 20.757 22 15.901 30.496zM27.9516 15A4.399 4.399 0 0128 15.5 4.5049 4.5049 0 0123.5 20H23v2h.5A6.5075 6.5075 0 0030 15.5c0-.17-.0312-.333-.0444-.5z"
  })), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M25.75,8h-1.5V4h1.5ZM25,9a1,1,0,1,0,1,1A1,1,0,0,0,25,9Z"
  })), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31.9115 11.9355L25.6283.3706a.7181.7181 0 00-1.2568 0L18.0883 11.9355A.72.72 0 0018.72 13H31.28A.72.72 0 0031.9115 11.9355zM24.25 4h1.5V8h-1.5zM25 11a1 1 0 111-1A1 1 0 0125 11zM8.144 11.019l.8154-.0639.0991-.812a6.9863 6.9863 0 019.97-5.45L20 2.9468A8.9777 8.9777 0 007.2 9.1362 6.4929 6.4929 0 007.43 21.9043L6.1059 24.5527a1 1 0 101.7885.8946l2-4a1 1 0 00-.4471-1.3418A.9786.9786 0 009 20.01V20H8.5a4.4975 4.4975 0 01-.3559-8.981z"
  })), children);
});
var ThunderstormSevere24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThunderstormSevere24(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7887.8947l-2 4A.9981.9981 0 0121 30zM9 32a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7887.8947l-2 4A.9981.9981 0 019 32zM15.901 30.496L14.165 29.504 17.309 24 11.31 24 16.165 15.504 17.901 16.496 14.756 22 20.757 22 15.901 30.496zM27.9516 15A4.399 4.399 0 0128 15.5 4.5049 4.5049 0 0123.5 20H23v2h.5A6.5075 6.5075 0 0030 15.5c0-.17-.0312-.333-.0444-.5z"
  })), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M25.75,8h-1.5V4h1.5ZM25,9a1,1,0,1,0,1,1A1,1,0,0,0,25,9Z"
  })), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31.9115 11.9355L25.6283.3706a.7181.7181 0 00-1.2568 0L18.0883 11.9355A.72.72 0 0018.72 13H31.28A.72.72 0 0031.9115 11.9355zM24.25 4h1.5V8h-1.5zM25 11a1 1 0 111-1A1 1 0 0125 11zM8.144 11.019l.8154-.0639.0991-.812a6.9863 6.9863 0 019.97-5.45L20 2.9468A8.9777 8.9777 0 007.2 9.1362 6.4929 6.4929 0 007.43 21.9043L6.1059 24.5527a1 1 0 101.7885.8946l2-4a1 1 0 00-.4471-1.3418A.9786.9786 0 009 20.01V20H8.5a4.4975 4.4975 0 01-.3559-8.981z"
  })), children);
});
var ThunderstormSevere20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThunderstormSevere20(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7887.8947l-2 4A.9981.9981 0 0121 30zM9 32a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7887.8947l-2 4A.9981.9981 0 019 32zM15.901 30.496L14.165 29.504 17.309 24 11.31 24 16.165 15.504 17.901 16.496 14.756 22 20.757 22 15.901 30.496zM27.9516 15A4.399 4.399 0 0128 15.5 4.5049 4.5049 0 0123.5 20H23v2h.5A6.5075 6.5075 0 0030 15.5c0-.17-.0312-.333-.0444-.5z"
  })), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M25.75,8h-1.5V4h1.5ZM25,9a1,1,0,1,0,1,1A1,1,0,0,0,25,9Z"
  })), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31.9115 11.9355L25.6283.3706a.7181.7181 0 00-1.2568 0L18.0883 11.9355A.72.72 0 0018.72 13H31.28A.72.72 0 0031.9115 11.9355zM24.25 4h1.5V8h-1.5zM25 11a1 1 0 111-1A1 1 0 0125 11zM8.144 11.019l.8154-.0639.0991-.812a6.9863 6.9863 0 019.97-5.45L20 2.9468A8.9777 8.9777 0 007.2 9.1362 6.4929 6.4929 0 007.43 21.9043L6.1059 24.5527a1 1 0 101.7885.8946l2-4a1 1 0 00-.4471-1.3418A.9786.9786 0 009 20.01V20H8.5a4.4975 4.4975 0 01-.3559-8.981z"
  })), children);
});
var ThunderstormSevere16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThunderstormSevere16(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7887.8947l-2 4A.9981.9981 0 0121 30zM9 32a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7887.8947l-2 4A.9981.9981 0 019 32zM15.901 30.496L14.165 29.504 17.309 24 11.31 24 16.165 15.504 17.901 16.496 14.756 22 20.757 22 15.901 30.496zM27.9516 15A4.399 4.399 0 0128 15.5 4.5049 4.5049 0 0123.5 20H23v2h.5A6.5075 6.5075 0 0030 15.5c0-.17-.0312-.333-.0444-.5z"
  })), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M25.75,8h-1.5V4h1.5ZM25,9a1,1,0,1,0,1,1A1,1,0,0,0,25,9Z"
  })), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31.9115 11.9355L25.6283.3706a.7181.7181 0 00-1.2568 0L18.0883 11.9355A.72.72 0 0018.72 13H31.28A.72.72 0 0031.9115 11.9355zM24.25 4h1.5V8h-1.5zM25 11a1 1 0 111-1A1 1 0 0125 11zM8.144 11.019l.8154-.0639.0991-.812a6.9863 6.9863 0 019.97-5.45L20 2.9468A8.9777 8.9777 0 007.2 9.1362 6.4929 6.4929 0 007.43 21.9043L6.1059 24.5527a1 1 0 101.7885.8946l2-4a1 1 0 00-.4471-1.3418A.9786.9786 0 009 20.01V20H8.5a4.4975 4.4975 0 01-.3559-8.981z"
  })), children);
});
var ThunderstormStrong32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThunderstormStrong32(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 0121 30zM9 32a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 019 32zM15.901 30.496L14.165 29.504 17.31 24 11.31 24 16.165 15.504 17.901 16.496 14.756 22 20.757 22 15.901 30.496z"
  })), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0,6.4929,6.4929,0,0,0,.23,12.7681L6.106,24.5527a1,1,0,1,0,1.7885.8946l2-4a1,1,0,0,0-.447-1.3418A.9786.9786,0,0,0,9,20.01V20H8.5a4.4975,4.4975,0,0,1-.356-8.981l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4975,4.4975,0,0,1,23.5,20H23v2h.5A6.4974,6.4974,0,0,0,24.8008,9.1362Z"
  })), children);
});
var ThunderstormStrong24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThunderstormStrong24(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 0121 30zM9 32a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 019 32zM15.901 30.496L14.165 29.504 17.31 24 11.31 24 16.165 15.504 17.901 16.496 14.756 22 20.757 22 15.901 30.496z"
  })), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0,6.4929,6.4929,0,0,0,.23,12.7681L6.106,24.5527a1,1,0,1,0,1.7885.8946l2-4a1,1,0,0,0-.447-1.3418A.9786.9786,0,0,0,9,20.01V20H8.5a4.4975,4.4975,0,0,1-.356-8.981l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4975,4.4975,0,0,1,23.5,20H23v2h.5A6.4974,6.4974,0,0,0,24.8008,9.1362Z"
  })), children);
});
var ThunderstormStrong20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThunderstormStrong20(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 0121 30zM9 32a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 019 32zM15.901 30.496L14.165 29.504 17.31 24 11.31 24 16.165 15.504 17.901 16.496 14.756 22 20.757 22 15.901 30.496z"
  })), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0,6.4929,6.4929,0,0,0,.23,12.7681L6.106,24.5527a1,1,0,1,0,1.7885.8946l2-4a1,1,0,0,0-.447-1.3418A.9786.9786,0,0,0,9,20.01V20H8.5a4.4975,4.4975,0,0,1-.356-8.981l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4975,4.4975,0,0,1,23.5,20H23v2h.5A6.4974,6.4974,0,0,0,24.8008,9.1362Z"
  })), children);
});
var ThunderstormStrong16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ThunderstormStrong16(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 0121 30zM9 32a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 019 32zM15.901 30.496L14.165 29.504 17.31 24 11.31 24 16.165 15.504 17.901 16.496 14.756 22 20.757 22 15.901 30.496z"
  })), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0,6.4929,6.4929,0,0,0,.23,12.7681L6.106,24.5527a1,1,0,1,0,1.7885.8946l2-4a1,1,0,0,0-.447-1.3418A.9786.9786,0,0,0,9,20.01V20H8.5a4.4975,4.4975,0,0,1-.356-8.981l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4975,4.4975,0,0,1,23.5,20H23v2h.5A6.4974,6.4974,0,0,0,24.8008,9.1362Z"
  })), children);
});
var Ticket32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Ticket32(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,14a1,1,0,0,0,1-1V8a2,2,0,0,0-2-2H4A2,2,0,0,0,2,8v5a1,1,0,0,0,1,1,2,2,0,0,1,0,4,1,1,0,0,0-1,1v5a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V19a1,1,0,0,0-1-1,2,2,0,0,1,0-4Zm-1,5.87V24H21V21H19v3H4V19.87a4,4,0,0,0,0-7.74V8H19v3h2V8h7v4.13a4,4,0,0,0,0,7.74Z"
  })), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13H21V19H19z"
  })), children);
});
var Ticket24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Ticket24(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,14a1,1,0,0,0,1-1V8a2,2,0,0,0-2-2H4A2,2,0,0,0,2,8v5a1,1,0,0,0,1,1,2,2,0,0,1,0,4,1,1,0,0,0-1,1v5a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V19a1,1,0,0,0-1-1,2,2,0,0,1,0-4Zm-1,5.87V24H21V21H19v3H4V19.87a4,4,0,0,0,0-7.74V8H19v3h2V8h7v4.13a4,4,0,0,0,0,7.74Z"
  })), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13H21V19H19z"
  })), children);
});
var Ticket20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Ticket20(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,14a1,1,0,0,0,1-1V8a2,2,0,0,0-2-2H4A2,2,0,0,0,2,8v5a1,1,0,0,0,1,1,2,2,0,0,1,0,4,1,1,0,0,0-1,1v5a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V19a1,1,0,0,0-1-1,2,2,0,0,1,0-4Zm-1,5.87V24H21V21H19v3H4V19.87a4,4,0,0,0,0-7.74V8H19v3h2V8h7v4.13a4,4,0,0,0,0,7.74Z"
  })), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13H21V19H19z"
  })), children);
});
var Ticket16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Ticket16(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,14a1,1,0,0,0,1-1V8a2,2,0,0,0-2-2H4A2,2,0,0,0,2,8v5a1,1,0,0,0,1,1,2,2,0,0,1,0,4,1,1,0,0,0-1,1v5a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V19a1,1,0,0,0-1-1,2,2,0,0,1,0-4Zm-1,5.87V24H21V21H19v3H4V19.87a4,4,0,0,0,0-7.74V8H19v3h2V8h7v4.13a4,4,0,0,0,0,7.74Z"
  })), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13H21V19H19z"
  })), children);
});
var Tides32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tides32(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 7L9 2 4 7 5.413 8.416 8 5.833 8 14 10 14 10 5.833 12.586 8.414 14 7zM26.586 7.586L24 10.167 24 2 22 2 22 10.167 19.413 7.584 18 9 23 14 28 9 26.586 7.586zM20 20a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 0016 17a.9894.9894 0 00-.9468.6787A3.44 3.44 0 0112 20a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 008 17a.971.971 0 00-.9468.6787A3.44 3.44 0 014 20H2v2H4a4.9316 4.9316 0 004-1.9873 5.0192 5.0192 0 008 0A4.9316 4.9316 0 0020 22H30V20zM28 28a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 0024 25a.9894.9894 0 00-.9468.6787A3.44 3.44 0 0120 28a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 0016 25a.971.971 0 00-.9468.6787A3.44 3.44 0 0112 28H2v2H12a4.9316 4.9316 0 004-1.9873 5.0192 5.0192 0 008 0A4.9316 4.9316 0 0028 30h2V28z"
  })), children);
});
var Tides24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tides24(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 7L9 2 4 7 5.413 8.416 8 5.833 8 14 10 14 10 5.833 12.586 8.414 14 7zM26.586 7.586L24 10.167 24 2 22 2 22 10.167 19.413 7.584 18 9 23 14 28 9 26.586 7.586zM20 20a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 0016 17a.9894.9894 0 00-.9468.6787A3.44 3.44 0 0112 20a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 008 17a.971.971 0 00-.9468.6787A3.44 3.44 0 014 20H2v2H4a4.9316 4.9316 0 004-1.9873 5.0192 5.0192 0 008 0A4.9316 4.9316 0 0020 22H30V20zM28 28a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 0024 25a.9894.9894 0 00-.9468.6787A3.44 3.44 0 0120 28a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 0016 25a.971.971 0 00-.9468.6787A3.44 3.44 0 0112 28H2v2H12a4.9316 4.9316 0 004-1.9873 5.0192 5.0192 0 008 0A4.9316 4.9316 0 0028 30h2V28z"
  })), children);
});
var Tides20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tides20(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 7L9 2 4 7 5.413 8.416 8 5.833 8 14 10 14 10 5.833 12.586 8.414 14 7zM26.586 7.586L24 10.167 24 2 22 2 22 10.167 19.413 7.584 18 9 23 14 28 9 26.586 7.586zM20 20a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 0016 17a.9894.9894 0 00-.9468.6787A3.44 3.44 0 0112 20a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 008 17a.971.971 0 00-.9468.6787A3.44 3.44 0 014 20H2v2H4a4.9316 4.9316 0 004-1.9873 5.0192 5.0192 0 008 0A4.9316 4.9316 0 0020 22H30V20zM28 28a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 0024 25a.9894.9894 0 00-.9468.6787A3.44 3.44 0 0120 28a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 0016 25a.971.971 0 00-.9468.6787A3.44 3.44 0 0112 28H2v2H12a4.9316 4.9316 0 004-1.9873 5.0192 5.0192 0 008 0A4.9316 4.9316 0 0028 30h2V28z"
  })), children);
});
var Tides16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tides16(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 7L9 2 4 7 5.413 8.416 8 5.833 8 14 10 14 10 5.833 12.586 8.414 14 7zM26.586 7.586L24 10.167 24 2 22 2 22 10.167 19.413 7.584 18 9 23 14 28 9 26.586 7.586zM20 20a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 0016 17a.9894.9894 0 00-.9468.6787A3.44 3.44 0 0112 20a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 008 17a.971.971 0 00-.9468.6787A3.44 3.44 0 014 20H2v2H4a4.9316 4.9316 0 004-1.9873 5.0192 5.0192 0 008 0A4.9316 4.9316 0 0020 22H30V20zM28 28a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 0024 25a.9894.9894 0 00-.9468.6787A3.44 3.44 0 0120 28a3.4376 3.4376 0 01-3.0513-2.3164A1.007 1.007 0 0016 25a.971.971 0 00-.9468.6787A3.44 3.44 0 0112 28H2v2H12a4.9316 4.9316 0 004-1.9873 5.0192 5.0192 0 008 0A4.9316 4.9316 0 0028 30h2V28z"
  })), children);
});
var Tif32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tif32(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 11L30 9 22 9 22 23 24 23 24 17 29 17 29 15 24 15 24 11 30 11zM12 11L15 11 15 21 12 21 12 23 20 23 20 21 17 21 17 11 20 11 20 9 12 9 12 11zM2 11L5 11 5 23 7 23 7 11 10 11 10 9 2 9 2 11z"
  })), children);
});
var Tif24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tif24(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 11L30 9 22 9 22 23 24 23 24 17 29 17 29 15 24 15 24 11 30 11zM12 11L15 11 15 21 12 21 12 23 20 23 20 21 17 21 17 11 20 11 20 9 12 9 12 11zM2 11L5 11 5 23 7 23 7 11 10 11 10 9 2 9 2 11z"
  })), children);
});
var Tif20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tif20(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 11L30 9 22 9 22 23 24 23 24 17 29 17 29 15 24 15 24 11 30 11zM12 11L15 11 15 21 12 21 12 23 20 23 20 21 17 21 17 11 20 11 20 9 12 9 12 11zM2 11L5 11 5 23 7 23 7 11 10 11 10 9 2 9 2 11z"
  })), children);
});
var Tif16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tif16(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 11L30 9 22 9 22 23 24 23 24 17 29 17 29 15 24 15 24 11 30 11zM12 11L15 11 15 21 12 21 12 23 20 23 20 21 17 21 17 11 20 11 20 9 12 9 12 11zM2 11L5 11 5 23 7 23 7 11 10 11 10 9 2 9 2 11z"
  })), children);
});
var Time32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Time32(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14,14,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12,12,0,0,0,16,4Z"
  })), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.59 22L15 16.41 15 7 17 7 17 15.58 22 20.59 20.59 22z"
  })), children);
});
var Time24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Time24(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14,14,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12,12,0,0,0,16,4Z"
  })), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.59 22L15 16.41 15 7 17 7 17 15.58 22 20.59 20.59 22z"
  })), children);
});
var Time20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Time20(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 20 20",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,19c-5,0-9-4-9-9s4-9,9-9s9,4,9,9S15,19,10,19z M10,2.3c-4.3,0-7.7,3.5-7.7,7.7s3.5,7.7,7.7,7.7s7.7-3.5,7.7-7.7\tS14.3,2.3,10,2.3z"
  })), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 13.9L9.4 10.3 9.4 4 10.6 4 10.6 9.7 13.9 13z"
  })), children);
});
var Time16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Time16(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14,14,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12,12,0,0,0,16,4Z"
  })), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.59 22L15 16.41 15 7 17 7 17 15.58 22 20.59 20.59 22z"
  })), children);
});
var TimePlot32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TimePlot32(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.586 13L21 10.414 21 6 23 6 23 9.586 25 11.586 23.586 13z"
  })), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,18a8,8,0,1,1,8-8A8.0092,8.0092,0,0,1,22,18ZM22,4a6,6,0,1,0,6,6A6.0066,6.0066,0,0,0,22,4Z"
  })), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.63,18l7,6H30V22H16.37l-7-6H4V2H2V28a2.0025,2.0025,0,0,0,2,2H30V28H4V18Z"
  })), children);
});
var TimePlot24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TimePlot24(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.586 13L21 10.414 21 6 23 6 23 9.586 25 11.586 23.586 13z"
  })), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,18a8,8,0,1,1,8-8A8.0092,8.0092,0,0,1,22,18ZM22,4a6,6,0,1,0,6,6A6.0066,6.0066,0,0,0,22,4Z"
  })), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.63,18l7,6H30V22H16.37l-7-6H4V2H2V28a2.0025,2.0025,0,0,0,2,2H30V28H4V18Z"
  })), children);
});
var TimePlot20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TimePlot20(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.586 13L21 10.414 21 6 23 6 23 9.586 25 11.586 23.586 13z"
  })), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,18a8,8,0,1,1,8-8A8.0092,8.0092,0,0,1,22,18ZM22,4a6,6,0,1,0,6,6A6.0066,6.0066,0,0,0,22,4Z"
  })), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.63,18l7,6H30V22H16.37l-7-6H4V2H2V28a2.0025,2.0025,0,0,0,2,2H30V28H4V18Z"
  })), children);
});
var TimePlot16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TimePlot16(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.586 13L21 10.414 21 6 23 6 23 9.586 25 11.586 23.586 13z"
  })), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,18a8,8,0,1,1,8-8A8.0092,8.0092,0,0,1,22,18ZM22,4a6,6,0,1,0,6,6A6.0066,6.0066,0,0,0,22,4Z"
  })), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.63,18l7,6H30V22H16.37l-7-6H4V2H2V28a2.0025,2.0025,0,0,0,2,2H30V28H4V18Z"
  })), children);
});
var Timer32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Timer32(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 11H17V20H15zM13 2H19V4H13z"
  })), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,9,26.58,7.59,24.33,9.84a10.94,10.94,0,1,0,1.18,1.65ZM16,26a9,9,0,1,1,9-9A9,9,0,0,1,16,26Z"
  })), children);
});
var Timer24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Timer24(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 11H17V20H15zM13 2H19V4H13z"
  })), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,9,26.58,7.59,24.33,9.84a10.94,10.94,0,1,0,1.18,1.65ZM16,26a9,9,0,1,1,9-9A9,9,0,0,1,16,26Z"
  })), children);
});
var Timer20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Timer20(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 11H17V20H15zM13 2H19V4H13z"
  })), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,9,26.58,7.59,24.33,9.84a10.94,10.94,0,1,0,1.18,1.65ZM16,26a9,9,0,1,1,9-9A9,9,0,0,1,16,26Z"
  })), children);
});
var Timer16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Timer16(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 11H17V20H15zM13 2H19V4H13z"
  })), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,9,26.58,7.59,24.33,9.84a10.94,10.94,0,1,0,1.18,1.65ZM16,26a9,9,0,1,1,9-9A9,9,0,0,1,16,26Z"
  })), children);
});
var ToolBox32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ToolBox32(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,9H24V6a2,2,0,0,0-2-2H10A2,2,0,0,0,8,6V9H5a3,3,0,0,0-3,3V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A3,3,0,0,0,27,9ZM10,6H22V9H10ZM28,26H4V17h8v5h8V17h8ZM14,17h4v3H14ZM4,15V12a1,1,0,0,1,1-1H27a1,1,0,0,1,1,1v3Z"
  })), children);
});
var ToolBox24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ToolBox24(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,9H24V6a2,2,0,0,0-2-2H10A2,2,0,0,0,8,6V9H5a3,3,0,0,0-3,3V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A3,3,0,0,0,27,9ZM10,6H22V9H10ZM28,26H4V17h8v5h8V17h8ZM14,17h4v3H14ZM4,15V12a1,1,0,0,1,1-1H27a1,1,0,0,1,1,1v3Z"
  })), children);
});
var ToolBox20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ToolBox20(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,9H24V6a2,2,0,0,0-2-2H10A2,2,0,0,0,8,6V9H5a3,3,0,0,0-3,3V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A3,3,0,0,0,27,9ZM10,6H22V9H10ZM28,26H4V17h8v5h8V17h8ZM14,17h4v3H14ZM4,15V12a1,1,0,0,1,1-1H27a1,1,0,0,1,1,1v3Z"
  })), children);
});
var ToolBox16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ToolBox16(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,9H24V6a2,2,0,0,0-2-2H10A2,2,0,0,0,8,6V9H5a3,3,0,0,0-3,3V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V12A3,3,0,0,0,27,9ZM10,6H22V9H10ZM28,26H4V17h8v5h8V17h8ZM14,17h4v3H14ZM4,15V12a1,1,0,0,1,1-1H27a1,1,0,0,1,1,1v3Z"
  })), children);
});
var ToolKit32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ToolKit32(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9141,24.5l4.257-4.2568-1.414-1.4141L7.5,23.0859l-.793-.7929a.9994.9994,0,0,0-1.414,0l-4,4a.9994.9994,0,0,0,0,1.414l3,3a.9995.9995,0,0,0,1.414,0l4-4a.9994.9994,0,0,0,0-1.414ZM5,28.5859,3.4141,27,6,24.4141,7.5859,26Z"
  })), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30a6.0067,6.0067,0,0,1-6-6,5.84,5.84,0,0,1,.2109-1.5469l-8.664-8.6638A5.8483,5.8483,0,0,1,8,14,5.9757,5.9757,0,0,1,2.4228,5.8164l.5577-1.4219L6.293,7.707a1.0233,1.0233,0,0,0,1.4135,0,.999.999,0,0,0,0-1.4141L4.3936,2.979l1.4233-.5571A5.9772,5.9772,0,0,1,14,8a5.84,5.84,0,0,1-.2109,1.5469l8.664,8.6635A5.8548,5.8548,0,0,1,24,18a5.9755,5.9755,0,0,1,5.5771,8.1836L29.02,27.6055,25.707,24.293a1.0233,1.0233,0,0,0-1.4135,0,.999.999,0,0,0-.0005,1.4141L27.6055,29.02l-1.4219.5579A5.96,5.96,0,0,1,24,30ZM10.0625,11.4763,20.5234,21.9375l-.2392.6094A3.9754,3.9754,0,0,0,23.75,27.9922l-.8711-.8711a2.9992,2.9992,0,0,1,0-4.2424,3.0721,3.0721,0,0,1,4.2427.0005l.8706.8708a3.9759,3.9759,0,0,0-5.4458-3.4658l-.6094.2385-10.46-10.46.2392-.6094A3.9755,3.9755,0,0,0,8.2505,4.0078l.8706.8711a2.9992,2.9992,0,0,1,0,4.2424,3.0721,3.0721,0,0,1-4.2427-.0005L4.0078,8.25a3.975,3.975,0,0,0,5.4453,3.4656Z"
  })), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.1226,2.85a3.0716,3.0716,0,0,0-4.2422,0L17.4,10.33l1.4141,1.414,7.48-7.48a1.0244,1.0244,0,0,1,1.4141,0,1.002,1.002,0,0,1,0,1.4145l-7.48,7.48,1.414,1.4141,7.48-7.4795A3.0031,3.0031,0,0,0,29.1226,2.85Z"
  })), children);
});
var ToolKit24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ToolKit24(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9141,24.5l4.257-4.2568-1.414-1.4141L7.5,23.0859l-.793-.7929a.9994.9994,0,0,0-1.414,0l-4,4a.9994.9994,0,0,0,0,1.414l3,3a.9995.9995,0,0,0,1.414,0l4-4a.9994.9994,0,0,0,0-1.414ZM5,28.5859,3.4141,27,6,24.4141,7.5859,26Z"
  })), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30a6.0067,6.0067,0,0,1-6-6,5.84,5.84,0,0,1,.2109-1.5469l-8.664-8.6638A5.8483,5.8483,0,0,1,8,14,5.9757,5.9757,0,0,1,2.4228,5.8164l.5577-1.4219L6.293,7.707a1.0233,1.0233,0,0,0,1.4135,0,.999.999,0,0,0,0-1.4141L4.3936,2.979l1.4233-.5571A5.9772,5.9772,0,0,1,14,8a5.84,5.84,0,0,1-.2109,1.5469l8.664,8.6635A5.8548,5.8548,0,0,1,24,18a5.9755,5.9755,0,0,1,5.5771,8.1836L29.02,27.6055,25.707,24.293a1.0233,1.0233,0,0,0-1.4135,0,.999.999,0,0,0-.0005,1.4141L27.6055,29.02l-1.4219.5579A5.96,5.96,0,0,1,24,30ZM10.0625,11.4763,20.5234,21.9375l-.2392.6094A3.9754,3.9754,0,0,0,23.75,27.9922l-.8711-.8711a2.9992,2.9992,0,0,1,0-4.2424,3.0721,3.0721,0,0,1,4.2427.0005l.8706.8708a3.9759,3.9759,0,0,0-5.4458-3.4658l-.6094.2385-10.46-10.46.2392-.6094A3.9755,3.9755,0,0,0,8.2505,4.0078l.8706.8711a2.9992,2.9992,0,0,1,0,4.2424,3.0721,3.0721,0,0,1-4.2427-.0005L4.0078,8.25a3.975,3.975,0,0,0,5.4453,3.4656Z"
  })), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.1226,2.85a3.0716,3.0716,0,0,0-4.2422,0L17.4,10.33l1.4141,1.414,7.48-7.48a1.0244,1.0244,0,0,1,1.4141,0,1.002,1.002,0,0,1,0,1.4145l-7.48,7.48,1.414,1.4141,7.48-7.4795A3.0031,3.0031,0,0,0,29.1226,2.85Z"
  })), children);
});
var ToolKit20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ToolKit20(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9141,24.5l4.257-4.2568-1.414-1.4141L7.5,23.0859l-.793-.7929a.9994.9994,0,0,0-1.414,0l-4,4a.9994.9994,0,0,0,0,1.414l3,3a.9995.9995,0,0,0,1.414,0l4-4a.9994.9994,0,0,0,0-1.414ZM5,28.5859,3.4141,27,6,24.4141,7.5859,26Z"
  })), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30a6.0067,6.0067,0,0,1-6-6,5.84,5.84,0,0,1,.2109-1.5469l-8.664-8.6638A5.8483,5.8483,0,0,1,8,14,5.9757,5.9757,0,0,1,2.4228,5.8164l.5577-1.4219L6.293,7.707a1.0233,1.0233,0,0,0,1.4135,0,.999.999,0,0,0,0-1.4141L4.3936,2.979l1.4233-.5571A5.9772,5.9772,0,0,1,14,8a5.84,5.84,0,0,1-.2109,1.5469l8.664,8.6635A5.8548,5.8548,0,0,1,24,18a5.9755,5.9755,0,0,1,5.5771,8.1836L29.02,27.6055,25.707,24.293a1.0233,1.0233,0,0,0-1.4135,0,.999.999,0,0,0-.0005,1.4141L27.6055,29.02l-1.4219.5579A5.96,5.96,0,0,1,24,30ZM10.0625,11.4763,20.5234,21.9375l-.2392.6094A3.9754,3.9754,0,0,0,23.75,27.9922l-.8711-.8711a2.9992,2.9992,0,0,1,0-4.2424,3.0721,3.0721,0,0,1,4.2427.0005l.8706.8708a3.9759,3.9759,0,0,0-5.4458-3.4658l-.6094.2385-10.46-10.46.2392-.6094A3.9755,3.9755,0,0,0,8.2505,4.0078l.8706.8711a2.9992,2.9992,0,0,1,0,4.2424,3.0721,3.0721,0,0,1-4.2427-.0005L4.0078,8.25a3.975,3.975,0,0,0,5.4453,3.4656Z"
  })), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.1226,2.85a3.0716,3.0716,0,0,0-4.2422,0L17.4,10.33l1.4141,1.414,7.48-7.48a1.0244,1.0244,0,0,1,1.4141,0,1.002,1.002,0,0,1,0,1.4145l-7.48,7.48,1.414,1.4141,7.48-7.4795A3.0031,3.0031,0,0,0,29.1226,2.85Z"
  })), children);
});
var ToolKit16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ToolKit16(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9141,24.5l4.257-4.2568-1.414-1.4141L7.5,23.0859l-.793-.7929a.9994.9994,0,0,0-1.414,0l-4,4a.9994.9994,0,0,0,0,1.414l3,3a.9995.9995,0,0,0,1.414,0l4-4a.9994.9994,0,0,0,0-1.414ZM5,28.5859,3.4141,27,6,24.4141,7.5859,26Z"
  })), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30a6.0067,6.0067,0,0,1-6-6,5.84,5.84,0,0,1,.2109-1.5469l-8.664-8.6638A5.8483,5.8483,0,0,1,8,14,5.9757,5.9757,0,0,1,2.4228,5.8164l.5577-1.4219L6.293,7.707a1.0233,1.0233,0,0,0,1.4135,0,.999.999,0,0,0,0-1.4141L4.3936,2.979l1.4233-.5571A5.9772,5.9772,0,0,1,14,8a5.84,5.84,0,0,1-.2109,1.5469l8.664,8.6635A5.8548,5.8548,0,0,1,24,18a5.9755,5.9755,0,0,1,5.5771,8.1836L29.02,27.6055,25.707,24.293a1.0233,1.0233,0,0,0-1.4135,0,.999.999,0,0,0-.0005,1.4141L27.6055,29.02l-1.4219.5579A5.96,5.96,0,0,1,24,30ZM10.0625,11.4763,20.5234,21.9375l-.2392.6094A3.9754,3.9754,0,0,0,23.75,27.9922l-.8711-.8711a2.9992,2.9992,0,0,1,0-4.2424,3.0721,3.0721,0,0,1,4.2427.0005l.8706.8708a3.9759,3.9759,0,0,0-5.4458-3.4658l-.6094.2385-10.46-10.46.2392-.6094A3.9755,3.9755,0,0,0,8.2505,4.0078l.8706.8711a2.9992,2.9992,0,0,1,0,4.2424,3.0721,3.0721,0,0,1-4.2427-.0005L4.0078,8.25a3.975,3.975,0,0,0,5.4453,3.4656Z"
  })), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.1226,2.85a3.0716,3.0716,0,0,0-4.2422,0L17.4,10.33l1.4141,1.414,7.48-7.48a1.0244,1.0244,0,0,1,1.4141,0,1.002,1.002,0,0,1,0,1.4145l-7.48,7.48,1.414,1.4141,7.48-7.4795A3.0031,3.0031,0,0,0,29.1226,2.85Z"
  })), children);
});
var Tools32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tools32(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.1,2A9.8,9.8,0,0,0,6.7,3.6L13.1,10a2.1,2.1,0,0,1,.2,3,2.1,2.1,0,0,1-3-.2L3.7,6.4A9.84,9.84,0,0,0,2,12.1,10.14,10.14,0,0,0,12.1,22.2a10.9,10.9,0,0,0,2.6-.3l6.7,6.7a5,5,0,0,0,7.1-7.1l-6.7-6.7a10.9,10.9,0,0,0,.3-2.6A10,10,0,0,0,12.1,2Zm8,10.1a7.61,7.61,0,0,1-.3,2.1l-.3,1.1.8.8L27,22.8a2.88,2.88,0,0,1,.9,2.1A2.72,2.72,0,0,1,27,27a2.9,2.9,0,0,1-4.2,0l-6.7-6.7-.8-.8-1.1.3a7.61,7.61,0,0,1-2.1.3,8.27,8.27,0,0,1-5.7-2.3A7.63,7.63,0,0,1,4,12.1a8.33,8.33,0,0,1,.3-2.2l4.4,4.4a4.14,4.14,0,0,0,5.9.2,4.14,4.14,0,0,0-.2-5.9L10,4.2a6.45,6.45,0,0,1,2-.3,8.27,8.27,0,0,1,5.7,2.3A8.49,8.49,0,0,1,20.1,12.1Z"
  })), children);
});
var Tools24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tools24(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.1,2A9.8,9.8,0,0,0,6.7,3.6L13.1,10a2.1,2.1,0,0,1,.2,3,2.1,2.1,0,0,1-3-.2L3.7,6.4A9.84,9.84,0,0,0,2,12.1,10.14,10.14,0,0,0,12.1,22.2a10.9,10.9,0,0,0,2.6-.3l6.7,6.7a5,5,0,0,0,7.1-7.1l-6.7-6.7a10.9,10.9,0,0,0,.3-2.6A10,10,0,0,0,12.1,2Zm8,10.1a7.61,7.61,0,0,1-.3,2.1l-.3,1.1.8.8L27,22.8a2.88,2.88,0,0,1,.9,2.1A2.72,2.72,0,0,1,27,27a2.9,2.9,0,0,1-4.2,0l-6.7-6.7-.8-.8-1.1.3a7.61,7.61,0,0,1-2.1.3,8.27,8.27,0,0,1-5.7-2.3A7.63,7.63,0,0,1,4,12.1a8.33,8.33,0,0,1,.3-2.2l4.4,4.4a4.14,4.14,0,0,0,5.9.2,4.14,4.14,0,0,0-.2-5.9L10,4.2a6.45,6.45,0,0,1,2-.3,8.27,8.27,0,0,1,5.7,2.3A8.49,8.49,0,0,1,20.1,12.1Z"
  })), children);
});
var Tools20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tools20(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.1,2A9.8,9.8,0,0,0,6.7,3.6L13.1,10a2.1,2.1,0,0,1,.2,3,2.1,2.1,0,0,1-3-.2L3.7,6.4A9.84,9.84,0,0,0,2,12.1,10.14,10.14,0,0,0,12.1,22.2a10.9,10.9,0,0,0,2.6-.3l6.7,6.7a5,5,0,0,0,7.1-7.1l-6.7-6.7a10.9,10.9,0,0,0,.3-2.6A10,10,0,0,0,12.1,2Zm8,10.1a7.61,7.61,0,0,1-.3,2.1l-.3,1.1.8.8L27,22.8a2.88,2.88,0,0,1,.9,2.1A2.72,2.72,0,0,1,27,27a2.9,2.9,0,0,1-4.2,0l-6.7-6.7-.8-.8-1.1.3a7.61,7.61,0,0,1-2.1.3,8.27,8.27,0,0,1-5.7-2.3A7.63,7.63,0,0,1,4,12.1a8.33,8.33,0,0,1,.3-2.2l4.4,4.4a4.14,4.14,0,0,0,5.9.2,4.14,4.14,0,0,0-.2-5.9L10,4.2a6.45,6.45,0,0,1,2-.3,8.27,8.27,0,0,1,5.7,2.3A8.49,8.49,0,0,1,20.1,12.1Z"
  })), children);
});
var Tools16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tools16(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.1,2A9.8,9.8,0,0,0,6.7,3.6L13.1,10a2.1,2.1,0,0,1,.2,3,2.1,2.1,0,0,1-3-.2L3.7,6.4A9.84,9.84,0,0,0,2,12.1,10.14,10.14,0,0,0,12.1,22.2a10.9,10.9,0,0,0,2.6-.3l6.7,6.7a5,5,0,0,0,7.1-7.1l-6.7-6.7a10.9,10.9,0,0,0,.3-2.6A10,10,0,0,0,12.1,2Zm8,10.1a7.61,7.61,0,0,1-.3,2.1l-.3,1.1.8.8L27,22.8a2.88,2.88,0,0,1,.9,2.1A2.72,2.72,0,0,1,27,27a2.9,2.9,0,0,1-4.2,0l-6.7-6.7-.8-.8-1.1.3a7.61,7.61,0,0,1-2.1.3,8.27,8.27,0,0,1-5.7-2.3A7.63,7.63,0,0,1,4,12.1a8.33,8.33,0,0,1,.3-2.2l4.4,4.4a4.14,4.14,0,0,0,5.9.2,4.14,4.14,0,0,0-.2-5.9L10,4.2a6.45,6.45,0,0,1,2-.3,8.27,8.27,0,0,1,5.7,2.3A8.49,8.49,0,0,1,20.1,12.1Z"
  })), children);
});
var ToolsAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ToolsAlt32(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4148,21.6664,23.08,15.3305l6.3337-6.334a2,2,0,0,0,.0017-2.8281l-.0017-.002-3.58-3.58a2,2,0,0,0-2.8284-.0015l-.0017.0015L16.67,8.9194,10.3352,2.5839a2.0037,2.0037,0,0,0-2.8281.0005L2.5854,7.5063a2.0011,2.0011,0,0,0,0,2.8286l6.3338,6.3345L2,23.5883V30H8.4106l6.919-6.9194,6.3354,6.3364a2.0076,2.0076,0,0,0,2.8291,0l4.9207-4.9223A2.0011,2.0011,0,0,0,29.4148,21.6664Zm-5.0015-17.67,3.59,3.59L21.67,13.92l-3.59-3.59ZM8,28H4V24.4086L10.3291,18.08l3.677,3.6778Zm15.08.0035L4,8.9213,8.9219,4,12.71,7.7875,10.458,10.04l1.4153,1.4141,2.2507-2.252,4.1294,4.1294L16,15.5834l1.416,1.4141,2.2517-2.252,4.13,4.13-2.2517,2.251,1.4141,1.415L25.2117,20.29l2.7907,2.791Z"
  })), children);
});
var ToolsAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ToolsAlt24(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4148,21.6664,23.08,15.3305l6.3337-6.334a2,2,0,0,0,.0017-2.8281l-.0017-.002-3.58-3.58a2,2,0,0,0-2.8284-.0015l-.0017.0015L16.67,8.9194,10.3352,2.5839a2.0037,2.0037,0,0,0-2.8281.0005L2.5854,7.5063a2.0011,2.0011,0,0,0,0,2.8286l6.3338,6.3345L2,23.5883V30H8.4106l6.919-6.9194,6.3354,6.3364a2.0076,2.0076,0,0,0,2.8291,0l4.9207-4.9223A2.0011,2.0011,0,0,0,29.4148,21.6664Zm-5.0015-17.67,3.59,3.59L21.67,13.92l-3.59-3.59ZM8,28H4V24.4086L10.3291,18.08l3.677,3.6778Zm15.08.0035L4,8.9213,8.9219,4,12.71,7.7875,10.458,10.04l1.4153,1.4141,2.2507-2.252,4.1294,4.1294L16,15.5834l1.416,1.4141,2.2517-2.252,4.13,4.13-2.2517,2.251,1.4141,1.415L25.2117,20.29l2.7907,2.791Z"
  })), children);
});
var ToolsAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ToolsAlt20(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4148,21.6664,23.08,15.3305l6.3337-6.334a2,2,0,0,0,.0017-2.8281l-.0017-.002-3.58-3.58a2,2,0,0,0-2.8284-.0015l-.0017.0015L16.67,8.9194,10.3352,2.5839a2.0037,2.0037,0,0,0-2.8281.0005L2.5854,7.5063a2.0011,2.0011,0,0,0,0,2.8286l6.3338,6.3345L2,23.5883V30H8.4106l6.919-6.9194,6.3354,6.3364a2.0076,2.0076,0,0,0,2.8291,0l4.9207-4.9223A2.0011,2.0011,0,0,0,29.4148,21.6664Zm-5.0015-17.67,3.59,3.59L21.67,13.92l-3.59-3.59ZM8,28H4V24.4086L10.3291,18.08l3.677,3.6778Zm15.08.0035L4,8.9213,8.9219,4,12.71,7.7875,10.458,10.04l1.4153,1.4141,2.2507-2.252,4.1294,4.1294L16,15.5834l1.416,1.4141,2.2517-2.252,4.13,4.13-2.2517,2.251,1.4141,1.415L25.2117,20.29l2.7907,2.791Z"
  })), children);
});
var ToolsAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ToolsAlt16(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4148,21.6664,23.08,15.3305l6.3337-6.334a2,2,0,0,0,.0017-2.8281l-.0017-.002-3.58-3.58a2,2,0,0,0-2.8284-.0015l-.0017.0015L16.67,8.9194,10.3352,2.5839a2.0037,2.0037,0,0,0-2.8281.0005L2.5854,7.5063a2.0011,2.0011,0,0,0,0,2.8286l6.3338,6.3345L2,23.5883V30H8.4106l6.919-6.9194,6.3354,6.3364a2.0076,2.0076,0,0,0,2.8291,0l4.9207-4.9223A2.0011,2.0011,0,0,0,29.4148,21.6664Zm-5.0015-17.67,3.59,3.59L21.67,13.92l-3.59-3.59ZM8,28H4V24.4086L10.3291,18.08l3.677,3.6778Zm15.08.0035L4,8.9213,8.9219,4,12.71,7.7875,10.458,10.04l1.4153,1.4141,2.2507-2.252,4.1294,4.1294L16,15.5834l1.416,1.4141,2.2517-2.252,4.13,4.13-2.2517,2.251,1.4141,1.415L25.2117,20.29l2.7907,2.791Z"
  })), children);
});
var Tornado32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tornado32(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 26H20V28H16zM12 22H18V24H12zM8 18H18V20H8zM8 14H20V16H8zM10 10H24V12H10zM8 6H26V8H8z"
  })), children);
});
var Tornado24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tornado24(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 26H20V28H16zM12 22H18V24H12zM8 18H18V20H8zM8 14H20V16H8zM10 10H24V12H10zM8 6H26V8H8z"
  })), children);
});
var Tornado20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tornado20(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 26H20V28H16zM12 22H18V24H12zM8 18H18V20H8zM8 14H20V16H8zM10 10H24V12H10zM8 6H26V8H8z"
  })), children);
});
var Tornado16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tornado16(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 26H20V28H16zM12 22H18V24H12zM8 18H18V20H8zM8 14H20V16H8zM10 10H24V12H10zM8 6H26V8H8z"
  })), children);
});
var TornadoWarning32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TornadoWarning32(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 4H18V6H2zM4 8H16V10H4zM2 12H14V14H2zM2 16H12V18H2zM4 20H12V22H4zM8 24H14V26H8zM12 28H16V30H12z"
  })), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,10h-1.5V6h1.5ZM23,11a1,1,0,1,0,1,1A1,1,0,0,0,23,11Z"
  })), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115,13.9355,23.6284,2.3706a.7181.7181,0,0,0-1.2568,0L16.0885,13.9355A.72.72,0,0,0,16.72,15H29.28A.72.72,0,0,0,29.9115,13.9355ZM22.25,6h1.5v4h-1.5ZM23,13a1,1,0,1,1,1-1A1,1,0,0,1,23,13Z"
  })), children);
});
var TornadoWarning24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TornadoWarning24(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 4H18V6H2zM4 8H16V10H4zM2 12H14V14H2zM2 16H12V18H2zM4 20H12V22H4zM8 24H14V26H8zM12 28H16V30H12z"
  })), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,10h-1.5V6h1.5ZM23,11a1,1,0,1,0,1,1A1,1,0,0,0,23,11Z"
  })), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115,13.9355,23.6284,2.3706a.7181.7181,0,0,0-1.2568,0L16.0885,13.9355A.72.72,0,0,0,16.72,15H29.28A.72.72,0,0,0,29.9115,13.9355ZM22.25,6h1.5v4h-1.5ZM23,13a1,1,0,1,1,1-1A1,1,0,0,1,23,13Z"
  })), children);
});
var TornadoWarning20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TornadoWarning20(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 4H18V6H2zM4 8H16V10H4zM2 12H14V14H2zM2 16H12V18H2zM4 20H12V22H4zM8 24H14V26H8zM12 28H16V30H12z"
  })), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,10h-1.5V6h1.5ZM23,11a1,1,0,1,0,1,1A1,1,0,0,0,23,11Z"
  })), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115,13.9355,23.6284,2.3706a.7181.7181,0,0,0-1.2568,0L16.0885,13.9355A.72.72,0,0,0,16.72,15H29.28A.72.72,0,0,0,29.9115,13.9355ZM22.25,6h1.5v4h-1.5ZM23,13a1,1,0,1,1,1-1A1,1,0,0,1,23,13Z"
  })), children);
});
var TornadoWarning16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TornadoWarning16(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 4H18V6H2zM4 8H16V10H4zM2 12H14V14H2zM2 16H12V18H2zM4 20H12V22H4zM8 24H14V26H8zM12 28H16V30H12z"
  })), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,10h-1.5V6h1.5ZM23,11a1,1,0,1,0,1,1A1,1,0,0,0,23,11Z"
  })), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115,13.9355,23.6284,2.3706a.7181.7181,0,0,0-1.2568,0L16.0885,13.9355A.72.72,0,0,0,16.72,15H29.28A.72.72,0,0,0,29.9115,13.9355ZM22.25,6h1.5v4h-1.5ZM23,13a1,1,0,1,1,1-1A1,1,0,0,1,23,13Z"
  })), children);
});
var Touch_132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_132(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,8H18A5,5,0,0,0,8,8H6A7,7,0,0,1,20,8Z"
  })), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,15a2.94,2.94,0,0,0-1.47.4A3,3,0,0,0,21,14a2.94,2.94,0,0,0-1.47.4A3,3,0,0,0,16,13.18V8h0a3,3,0,0,0-6,0V19.1L7.77,17.58h0A2.93,2.93,0,0,0,6,17a3,3,0,0,0-2.12,5.13l8,7.3A6.16,6.16,0,0,0,16,31h5a7,7,0,0,0,7-7V18A3,3,0,0,0,25,15Zm1,9a5,5,0,0,1-5,5H16a4.17,4.17,0,0,1-2.76-1L5.29,20.7A1,1,0,0,1,5,20a1,1,0,0,1,1.6-.8L12,22.9V8a1,1,0,0,1,2,0h0V19h2V16a1,1,0,0,1,2,0v3h2V17a1,1,0,0,1,2,0v2h2V18a1,1,0,0,1,2,0Z"
  })), children);
});
var Touch_124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_124(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,8H18A5,5,0,0,0,8,8H6A7,7,0,0,1,20,8Z"
  })), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,15a2.94,2.94,0,0,0-1.47.4A3,3,0,0,0,21,14a2.94,2.94,0,0,0-1.47.4A3,3,0,0,0,16,13.18V8h0a3,3,0,0,0-6,0V19.1L7.77,17.58h0A2.93,2.93,0,0,0,6,17a3,3,0,0,0-2.12,5.13l8,7.3A6.16,6.16,0,0,0,16,31h5a7,7,0,0,0,7-7V18A3,3,0,0,0,25,15Zm1,9a5,5,0,0,1-5,5H16a4.17,4.17,0,0,1-2.76-1L5.29,20.7A1,1,0,0,1,5,20a1,1,0,0,1,1.6-.8L12,22.9V8a1,1,0,0,1,2,0h0V19h2V16a1,1,0,0,1,2,0v3h2V17a1,1,0,0,1,2,0v2h2V18a1,1,0,0,1,2,0Z"
  })), children);
});
var Touch_120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_120(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,8H18A5,5,0,0,0,8,8H6A7,7,0,0,1,20,8Z"
  })), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,15a2.94,2.94,0,0,0-1.47.4A3,3,0,0,0,21,14a2.94,2.94,0,0,0-1.47.4A3,3,0,0,0,16,13.18V8h0a3,3,0,0,0-6,0V19.1L7.77,17.58h0A2.93,2.93,0,0,0,6,17a3,3,0,0,0-2.12,5.13l8,7.3A6.16,6.16,0,0,0,16,31h5a7,7,0,0,0,7-7V18A3,3,0,0,0,25,15Zm1,9a5,5,0,0,1-5,5H16a4.17,4.17,0,0,1-2.76-1L5.29,20.7A1,1,0,0,1,5,20a1,1,0,0,1,1.6-.8L12,22.9V8a1,1,0,0,1,2,0h0V19h2V16a1,1,0,0,1,2,0v3h2V17a1,1,0,0,1,2,0v2h2V18a1,1,0,0,1,2,0Z"
  })), children);
});
var Touch_116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_116(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,8H18A5,5,0,0,0,8,8H6A7,7,0,0,1,20,8Z"
  })), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,15a2.94,2.94,0,0,0-1.47.4A3,3,0,0,0,21,14a2.94,2.94,0,0,0-1.47.4A3,3,0,0,0,16,13.18V8h0a3,3,0,0,0-6,0V19.1L7.77,17.58h0A2.93,2.93,0,0,0,6,17a3,3,0,0,0-2.12,5.13l8,7.3A6.16,6.16,0,0,0,16,31h5a7,7,0,0,0,7-7V18A3,3,0,0,0,25,15Zm1,9a5,5,0,0,1-5,5H16a4.17,4.17,0,0,1-2.76-1L5.29,20.7A1,1,0,0,1,5,20a1,1,0,0,1,1.6-.8L12,22.9V8a1,1,0,0,1,2,0h0V19h2V16a1,1,0,0,1,2,0v3h2V17a1,1,0,0,1,2,0v2h2V18a1,1,0,0,1,2,0Z"
  })), children);
});
var Touch_1Filled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_1Filled32(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,2A6.0067,6.0067,0,0,0,7,8H9a4,4,0,0,1,8,0h2A6.0067,6.0067,0,0,0,13,2Z"
  })), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,30H16.5606a4,4,0,0,1-2.7088-1.0566L4.6513,20.4771A2.0018,2.0018,0,0,1,4.77,17.4219a2.0743,2.0743,0,0,1,2.6578.1728L11,20.8569V8a2,2,0,0,1,4,0v7a2,2,0,0,1,4,0v1a2,2,0,0,1,4,0v1a2,2,0,0,1,4,0v7A6,6,0,0,1,21,30Z"
  })), children);
});
var Touch_1Filled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_1Filled24(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,2A6.0067,6.0067,0,0,0,7,8H9a4,4,0,0,1,8,0h2A6.0067,6.0067,0,0,0,13,2Z"
  })), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,30H16.5606a4,4,0,0,1-2.7088-1.0566L4.6513,20.4771A2.0018,2.0018,0,0,1,4.77,17.4219a2.0743,2.0743,0,0,1,2.6578.1728L11,20.8569V8a2,2,0,0,1,4,0v7a2,2,0,0,1,4,0v1a2,2,0,0,1,4,0v1a2,2,0,0,1,4,0v7A6,6,0,0,1,21,30Z"
  })), children);
});
var Touch_1Filled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_1Filled20(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,2A6.0067,6.0067,0,0,0,7,8H9a4,4,0,0,1,8,0h2A6.0067,6.0067,0,0,0,13,2Z"
  })), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,30H16.5606a4,4,0,0,1-2.7088-1.0566L4.6513,20.4771A2.0018,2.0018,0,0,1,4.77,17.4219a2.0743,2.0743,0,0,1,2.6578.1728L11,20.8569V8a2,2,0,0,1,4,0v7a2,2,0,0,1,4,0v1a2,2,0,0,1,4,0v1a2,2,0,0,1,4,0v7A6,6,0,0,1,21,30Z"
  })), children);
});
var Touch_1Filled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_1Filled16(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,2A6.0067,6.0067,0,0,0,7,8H9a4,4,0,0,1,8,0h2A6.0067,6.0067,0,0,0,13,2Z"
  })), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,30H16.5606a4,4,0,0,1-2.7088-1.0566L4.6513,20.4771A2.0018,2.0018,0,0,1,4.77,17.4219a2.0743,2.0743,0,0,1,2.6578.1728L11,20.8569V8a2,2,0,0,1,4,0v7a2,2,0,0,1,4,0v1a2,2,0,0,1,4,0v1a2,2,0,0,1,4,0v7A6,6,0,0,1,21,30Z"
  })), children);
});
var Touch_1Down32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_1Down32(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,24H18A5,5,0,0,1,8,24H6a7,7,0,0,0,14,0Z"
  })), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,14V8a7.0085,7.0085,0,0,0-7-7H16a6.1457,6.1457,0,0,0-4.1055,1.5664L3.8833,9.874a2.9986,2.9986,0,0,0,3.881,4.55l.0008.0012L10,12.8955V24a3,3,0,0,0,6,0h0l0-5.1843a2.939,2.939,0,0,0,3.5294-1.2171A2.963,2.963,0,0,0,21,18a2.9936,2.9936,0,0,0,2.5292-1.4014A2.963,2.963,0,0,0,25,17,3.0033,3.0033,0,0,0,28,14Zm-2,0a1,1,0,0,1-2,0V13H22v2a1,1,0,0,1-2,0V13H18v3a1,1,0,0,1-2,0V13H14V24h.0005A1,1,0,0,1,12,24V9.1045L6.6,12.8008a.9993.9993,0,0,1-1.3081-1.5044l7.9507-7.2515A4.1483,4.1483,0,0,1,16,3h5a5.0059,5.0059,0,0,1,5,5Z"
  })), children);
});
var Touch_1Down24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_1Down24(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,24H18A5,5,0,0,1,8,24H6a7,7,0,0,0,14,0Z"
  })), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,14V8a7.0085,7.0085,0,0,0-7-7H16a6.1457,6.1457,0,0,0-4.1055,1.5664L3.8833,9.874a2.9986,2.9986,0,0,0,3.881,4.55l.0008.0012L10,12.8955V24a3,3,0,0,0,6,0h0l0-5.1843a2.939,2.939,0,0,0,3.5294-1.2171A2.963,2.963,0,0,0,21,18a2.9936,2.9936,0,0,0,2.5292-1.4014A2.963,2.963,0,0,0,25,17,3.0033,3.0033,0,0,0,28,14Zm-2,0a1,1,0,0,1-2,0V13H22v2a1,1,0,0,1-2,0V13H18v3a1,1,0,0,1-2,0V13H14V24h.0005A1,1,0,0,1,12,24V9.1045L6.6,12.8008a.9993.9993,0,0,1-1.3081-1.5044l7.9507-7.2515A4.1483,4.1483,0,0,1,16,3h5a5.0059,5.0059,0,0,1,5,5Z"
  })), children);
});
var Touch_1Down20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_1Down20(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,24H18A5,5,0,0,1,8,24H6a7,7,0,0,0,14,0Z"
  })), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,14V8a7.0085,7.0085,0,0,0-7-7H16a6.1457,6.1457,0,0,0-4.1055,1.5664L3.8833,9.874a2.9986,2.9986,0,0,0,3.881,4.55l.0008.0012L10,12.8955V24a3,3,0,0,0,6,0h0l0-5.1843a2.939,2.939,0,0,0,3.5294-1.2171A2.963,2.963,0,0,0,21,18a2.9936,2.9936,0,0,0,2.5292-1.4014A2.963,2.963,0,0,0,25,17,3.0033,3.0033,0,0,0,28,14Zm-2,0a1,1,0,0,1-2,0V13H22v2a1,1,0,0,1-2,0V13H18v3a1,1,0,0,1-2,0V13H14V24h.0005A1,1,0,0,1,12,24V9.1045L6.6,12.8008a.9993.9993,0,0,1-1.3081-1.5044l7.9507-7.2515A4.1483,4.1483,0,0,1,16,3h5a5.0059,5.0059,0,0,1,5,5Z"
  })), children);
});
var Touch_1Down16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_1Down16(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,24H18A5,5,0,0,1,8,24H6a7,7,0,0,0,14,0Z"
  })), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,14V8a7.0085,7.0085,0,0,0-7-7H16a6.1457,6.1457,0,0,0-4.1055,1.5664L3.8833,9.874a2.9986,2.9986,0,0,0,3.881,4.55l.0008.0012L10,12.8955V24a3,3,0,0,0,6,0h0l0-5.1843a2.939,2.939,0,0,0,3.5294-1.2171A2.963,2.963,0,0,0,21,18a2.9936,2.9936,0,0,0,2.5292-1.4014A2.963,2.963,0,0,0,25,17,3.0033,3.0033,0,0,0,28,14Zm-2,0a1,1,0,0,1-2,0V13H22v2a1,1,0,0,1-2,0V13H18v3a1,1,0,0,1-2,0V13H14V24h.0005A1,1,0,0,1,12,24V9.1045L6.6,12.8008a.9993.9993,0,0,1-1.3081-1.5044l7.9507-7.2515A4.1483,4.1483,0,0,1,16,3h5a5.0059,5.0059,0,0,1,5,5Z"
  })), children);
});
var Touch_1DownFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_1DownFilled32(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,30a6.0067,6.0067,0,0,1-6-6H9a4,4,0,0,0,8,0h2A6.0067,6.0067,0,0,1,13,30Z"
  })), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,2H16.5606a4,4,0,0,0-2.7088,1.0566L4.6513,11.5229A2.0018,2.0018,0,0,0,4.77,14.5781a2.0743,2.0743,0,0,0,2.6578-.1728L11,11.1431V24a2,2,0,0,0,4,0V17a2,2,0,0,0,4,0V16a2,2,0,0,0,4,0V15a2,2,0,0,0,4,0V8A6,6,0,0,0,21,2Z"
  })), children);
});
var Touch_1DownFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_1DownFilled24(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,30a6.0067,6.0067,0,0,1-6-6H9a4,4,0,0,0,8,0h2A6.0067,6.0067,0,0,1,13,30Z"
  })), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,2H16.5606a4,4,0,0,0-2.7088,1.0566L4.6513,11.5229A2.0018,2.0018,0,0,0,4.77,14.5781a2.0743,2.0743,0,0,0,2.6578-.1728L11,11.1431V24a2,2,0,0,0,4,0V17a2,2,0,0,0,4,0V16a2,2,0,0,0,4,0V15a2,2,0,0,0,4,0V8A6,6,0,0,0,21,2Z"
  })), children);
});
var Touch_1DownFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_1DownFilled20(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,30a6.0067,6.0067,0,0,1-6-6H9a4,4,0,0,0,8,0h2A6.0067,6.0067,0,0,1,13,30Z"
  })), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,2H16.5606a4,4,0,0,0-2.7088,1.0566L4.6513,11.5229A2.0018,2.0018,0,0,0,4.77,14.5781a2.0743,2.0743,0,0,0,2.6578-.1728L11,11.1431V24a2,2,0,0,0,4,0V17a2,2,0,0,0,4,0V16a2,2,0,0,0,4,0V15a2,2,0,0,0,4,0V8A6,6,0,0,0,21,2Z"
  })), children);
});
var Touch_1DownFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_1DownFilled16(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,30a6.0067,6.0067,0,0,1-6-6H9a4,4,0,0,0,8,0h2A6.0067,6.0067,0,0,1,13,30Z"
  })), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,2H16.5606a4,4,0,0,0-2.7088,1.0566L4.6513,11.5229A2.0018,2.0018,0,0,0,4.77,14.5781a2.0743,2.0743,0,0,0,2.6578-.1728L11,11.1431V24a2,2,0,0,0,4,0V17a2,2,0,0,0,4,0V16a2,2,0,0,0,4,0V15a2,2,0,0,0,4,0V8A6,6,0,0,0,21,2Z"
  })), children);
});
var Touch_232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_232(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,15H27A11,11,0,0,0,5,15H3a13,13,0,0,1,26,0Z"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,28H23V15A7,7,0,1,0,9,15V28H7V15a9,9,0,0,1,18,0Z"
  })), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,20H11V15a5,5,0,0,1,10,0Zm-8-2h6V15a3,3,0,0,0-6,0Z"
  })), children);
});
var Touch_224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_224(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,15H27A11,11,0,0,0,5,15H3a13,13,0,0,1,26,0Z"
  })), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,28H23V15A7,7,0,1,0,9,15V28H7V15a9,9,0,0,1,18,0Z"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,20H11V15a5,5,0,0,1,10,0Zm-8-2h6V15a3,3,0,0,0-6,0Z"
  })), children);
});
var Touch_220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_220(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,15H27A11,11,0,0,0,5,15H3a13,13,0,0,1,26,0Z"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,28H23V15A7,7,0,1,0,9,15V28H7V15a9,9,0,0,1,18,0Z"
  })), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,20H11V15a5,5,0,0,1,10,0Zm-8-2h6V15a3,3,0,0,0-6,0Z"
  })), children);
});
var Touch_216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_216(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,15H27A11,11,0,0,0,5,15H3a13,13,0,0,1,26,0Z"
  })), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,28H23V15A7,7,0,1,0,9,15V28H7V15a9,9,0,0,1,18,0Z"
  })), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,20H11V15a5,5,0,0,1,10,0Zm-8-2h6V15a3,3,0,0,0-6,0Z"
  })), children);
});
var Touch_2Filled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_2Filled32(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a3.0033,3.0033,0,0,0-3,3v3h6V15A3.0033,3.0033,0,0,0,16,12Z"
  })), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6a9.0092,9.0092,0,0,0-9,9V28H25V15A9.01,9.01,0,0,0,16,6Zm5,14H11V15a5,5,0,0,1,10,0Z"
  })), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,15H27A11,11,0,0,0,5,15H3a13,13,0,0,1,26,0Z"
  })), children);
});
var Touch_2Filled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_2Filled24(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a3.0033,3.0033,0,0,0-3,3v3h6V15A3.0033,3.0033,0,0,0,16,12Z"
  })), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6a9.0092,9.0092,0,0,0-9,9V28H25V15A9.01,9.01,0,0,0,16,6Zm5,14H11V15a5,5,0,0,1,10,0Z"
  })), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,15H27A11,11,0,0,0,5,15H3a13,13,0,0,1,26,0Z"
  })), children);
});
var Touch_2Filled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_2Filled20(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a3.0033,3.0033,0,0,0-3,3v3h6V15A3.0033,3.0033,0,0,0,16,12Z"
  })), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6a9.0092,9.0092,0,0,0-9,9V28H25V15A9.01,9.01,0,0,0,16,6Zm5,14H11V15a5,5,0,0,1,10,0Z"
  })), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,15H27A11,11,0,0,0,5,15H3a13,13,0,0,1,26,0Z"
  })), children);
});
var Touch_2Filled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Touch_2Filled16(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,12a3.0033,3.0033,0,0,0-3,3v3h6V15A3.0033,3.0033,0,0,0,16,12Z"
  })), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6a9.0092,9.0092,0,0,0-9,9V28H25V15A9.01,9.01,0,0,0,16,6Zm5,14H11V15a5,5,0,0,1,10,0Z"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,15H27A11,11,0,0,0,5,15H3a13,13,0,0,1,26,0Z"
  })), children);
});
var TouchInteraction32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TouchInteraction32(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,21V20a1,1,0,0,1,2,0V30h2V20a3.0033,3.0033,0,0,0-3-3,2.964,2.964,0,0,0-1.4708.4014,2.9541,2.9541,0,0,0-4-1A2.9934,2.9934,0,0,0,19,15a2.96,2.96,0,0,0-1,.1846L18,10h0a3,3,0,0,0-6,0V21.1045L9.7651,19.5752l-.0008.001a2.999,2.999,0,0,0-3.881,4.55L12.3223,30l1.3479-1.478L7.2915,22.7036A.9908.9908,0,0,1,7,22a1.0005,1.0005,0,0,1,1.6-.8008L14,24.8955V10a1,1,0,0,1,2,0h0V21h2V18a1,1,0,0,1,2,0v3h2V19a1,1,0,0,1,2,0v2Z"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12H22V10h6V4H4v6H8v2H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2v6A2.0021,2.0021,0,0,1,28,12Z"
  })), children);
});
var TouchInteraction24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TouchInteraction24(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,21V20a1,1,0,0,1,2,0V30h2V20a3.0033,3.0033,0,0,0-3-3,2.964,2.964,0,0,0-1.4708.4014,2.9541,2.9541,0,0,0-4-1A2.9934,2.9934,0,0,0,19,15a2.96,2.96,0,0,0-1,.1846L18,10h0a3,3,0,0,0-6,0V21.1045L9.7651,19.5752l-.0008.001a2.999,2.999,0,0,0-3.881,4.55L12.3223,30l1.3479-1.478L7.2915,22.7036A.9908.9908,0,0,1,7,22a1.0005,1.0005,0,0,1,1.6-.8008L14,24.8955V10a1,1,0,0,1,2,0h0V21h2V18a1,1,0,0,1,2,0v3h2V19a1,1,0,0,1,2,0v2Z"
  })), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12H22V10h6V4H4v6H8v2H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2v6A2.0021,2.0021,0,0,1,28,12Z"
  })), children);
});
var TouchInteraction20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TouchInteraction20(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,21V20a1,1,0,0,1,2,0V30h2V20a3.0033,3.0033,0,0,0-3-3,2.964,2.964,0,0,0-1.4708.4014,2.9541,2.9541,0,0,0-4-1A2.9934,2.9934,0,0,0,19,15a2.96,2.96,0,0,0-1,.1846L18,10h0a3,3,0,0,0-6,0V21.1045L9.7651,19.5752l-.0008.001a2.999,2.999,0,0,0-3.881,4.55L12.3223,30l1.3479-1.478L7.2915,22.7036A.9908.9908,0,0,1,7,22a1.0005,1.0005,0,0,1,1.6-.8008L14,24.8955V10a1,1,0,0,1,2,0h0V21h2V18a1,1,0,0,1,2,0v3h2V19a1,1,0,0,1,2,0v2Z"
  })), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12H22V10h6V4H4v6H8v2H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2v6A2.0021,2.0021,0,0,1,28,12Z"
  })), children);
});
var TouchInteraction16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TouchInteraction16(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,21V20a1,1,0,0,1,2,0V30h2V20a3.0033,3.0033,0,0,0-3-3,2.964,2.964,0,0,0-1.4708.4014,2.9541,2.9541,0,0,0-4-1A2.9934,2.9934,0,0,0,19,15a2.96,2.96,0,0,0-1,.1846L18,10h0a3,3,0,0,0-6,0V21.1045L9.7651,19.5752l-.0008.001a2.999,2.999,0,0,0-3.881,4.55L12.3223,30l1.3479-1.478L7.2915,22.7036A.9908.9908,0,0,1,7,22a1.0005,1.0005,0,0,1,1.6-.8008L14,24.8955V10a1,1,0,0,1,2,0h0V21h2V18a1,1,0,0,1,2,0v3h2V19a1,1,0,0,1,2,0v2Z"
  })), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12H22V10h6V4H4v6H8v2H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2v6A2.0021,2.0021,0,0,1,28,12Z"
  })), children);
});
var TrafficEvent32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficEvent32(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 21H17V23H11z"
  })), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.2456,8,25.96,14H30V12H27.4688l-1.3-4.5488A2.0077,2.0077,0,0,0,24.2456,6H22.8972l-.7287-2.5488A2.0077,2.0077,0,0,0,20.2456,2H7.7544A2.0078,2.0078,0,0,0,5.8315,3.4507L4.5312,8H2v2H6.04L7.7544,4H20.2456l.5715,2H11.7544A2.008,2.008,0,0,0,9.8315,7.45L8.8171,11H7.7144a1.9981,1.9981,0,0,0-1.8916,1.3516L4.5715,16H2v2H4v7a2.0025,2.0025,0,0,0,2,2v3H8V27H20v3h2V27a2.0025,2.0025,0,0,0,2-2V18h2V16H23.4287l-1.251-3.6475A1.9988,1.9988,0,0,0,20.2856,11H10.897l.8574-3ZM22,19v2H20v2h2v2H6V23H8V21H6V19Zm-.3429-2H6.3428l1.3716-4H20.2856Z"
  })), children);
});
var TrafficEvent24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficEvent24(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 21H17V23H11z"
  })), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.2456,8,25.96,14H30V12H27.4688l-1.3-4.5488A2.0077,2.0077,0,0,0,24.2456,6H22.8972l-.7287-2.5488A2.0077,2.0077,0,0,0,20.2456,2H7.7544A2.0078,2.0078,0,0,0,5.8315,3.4507L4.5312,8H2v2H6.04L7.7544,4H20.2456l.5715,2H11.7544A2.008,2.008,0,0,0,9.8315,7.45L8.8171,11H7.7144a1.9981,1.9981,0,0,0-1.8916,1.3516L4.5715,16H2v2H4v7a2.0025,2.0025,0,0,0,2,2v3H8V27H20v3h2V27a2.0025,2.0025,0,0,0,2-2V18h2V16H23.4287l-1.251-3.6475A1.9988,1.9988,0,0,0,20.2856,11H10.897l.8574-3ZM22,19v2H20v2h2v2H6V23H8V21H6V19Zm-.3429-2H6.3428l1.3716-4H20.2856Z"
  })), children);
});
var TrafficEvent20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficEvent20(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 21H17V23H11z"
  })), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.2456,8,25.96,14H30V12H27.4688l-1.3-4.5488A2.0077,2.0077,0,0,0,24.2456,6H22.8972l-.7287-2.5488A2.0077,2.0077,0,0,0,20.2456,2H7.7544A2.0078,2.0078,0,0,0,5.8315,3.4507L4.5312,8H2v2H6.04L7.7544,4H20.2456l.5715,2H11.7544A2.008,2.008,0,0,0,9.8315,7.45L8.8171,11H7.7144a1.9981,1.9981,0,0,0-1.8916,1.3516L4.5715,16H2v2H4v7a2.0025,2.0025,0,0,0,2,2v3H8V27H20v3h2V27a2.0025,2.0025,0,0,0,2-2V18h2V16H23.4287l-1.251-3.6475A1.9988,1.9988,0,0,0,20.2856,11H10.897l.8574-3ZM22,19v2H20v2h2v2H6V23H8V21H6V19Zm-.3429-2H6.3428l1.3716-4H20.2856Z"
  })), children);
});
var TrafficEvent16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficEvent16(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 21H17V23H11z"
  })), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.2456,8,25.96,14H30V12H27.4688l-1.3-4.5488A2.0077,2.0077,0,0,0,24.2456,6H22.8972l-.7287-2.5488A2.0077,2.0077,0,0,0,20.2456,2H7.7544A2.0078,2.0078,0,0,0,5.8315,3.4507L4.5312,8H2v2H6.04L7.7544,4H20.2456l.5715,2H11.7544A2.008,2.008,0,0,0,9.8315,7.45L8.8171,11H7.7144a1.9981,1.9981,0,0,0-1.8916,1.3516L4.5715,16H2v2H4v7a2.0025,2.0025,0,0,0,2,2v3H8V27H20v3h2V27a2.0025,2.0025,0,0,0,2-2V18h2V16H23.4287l-1.251-3.6475A1.9988,1.9988,0,0,0,20.2856,11H10.897l.8574-3ZM22,19v2H20v2h2v2H6V23H8V21H6V19Zm-.3429-2H6.3428l1.3716-4H20.2856Z"
  })), children);
});
var TrafficFlow32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficFlow32(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 8L22 4 18 8 19.41 9.42 21 7.83 21 18 23 18 23 7.83 24.58 9.41 26 8zM12.59 22.58L11 24.17 11 14 9 14 9 24.17 7.42 22.59 6 24 10 28 14 24 12.59 22.58zM2 2H4V30H2zM28 2H30V30H28zM15 2H17V6H15zM15 10H17V14H15zM15 18H17V22H15zM15 26H17V30H15z"
  })), children);
});
var TrafficFlow24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficFlow24(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 8L22 4 18 8 19.41 9.42 21 7.83 21 18 23 18 23 7.83 24.58 9.41 26 8zM12.59 22.58L11 24.17 11 14 9 14 9 24.17 7.42 22.59 6 24 10 28 14 24 12.59 22.58zM2 2H4V30H2zM28 2H30V30H28zM15 2H17V6H15zM15 10H17V14H15zM15 18H17V22H15zM15 26H17V30H15z"
  })), children);
});
var TrafficFlow20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficFlow20(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 8L22 4 18 8 19.41 9.42 21 7.83 21 18 23 18 23 7.83 24.58 9.41 26 8zM12.59 22.58L11 24.17 11 14 9 14 9 24.17 7.42 22.59 6 24 10 28 14 24 12.59 22.58zM2 2H4V30H2zM28 2H30V30H28zM15 2H17V6H15zM15 10H17V14H15zM15 18H17V22H15zM15 26H17V30H15z"
  })), children);
});
var TrafficFlow16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficFlow16(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 8L22 4 18 8 19.41 9.42 21 7.83 21 18 23 18 23 7.83 24.58 9.41 26 8zM12.59 22.58L11 24.17 11 14 9 14 9 24.17 7.42 22.59 6 24 10 28 14 24 12.59 22.58zM2 2H4V30H2zM28 2H30V30H28zM15 2H17V6H15zM15 10H17V14H15zM15 18H17V22H15zM15 26H17V30H15z"
  })), children);
});
var TrafficFlowIncident32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficFlowIncident32(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 9.42L24.59 8 22.005 10.585 22 10.58 21.995 10.585 19.42 8.01 18 9.42 20.58 12 18 14.58 19.41 16 21.995 13.415 22 13.42 22.005 13.415 24.58 15.99 26 14.58 23.42 12 26 9.42zM14 17.42L12.59 16 10.005 18.585 10 18.58 9.995 18.585 7.42 16.01 6 17.42 8.58 20 6 22.58 7.41 24 9.995 21.415 10 21.42 10.005 21.415 12.58 23.99 14 22.58 11.42 20 14 17.42zM2 2H4V30H2zM28 2H30V30H28zM15 2H17V6H15zM15 10H17V14H15zM15 18H17V22H15zM15 26H17V30H15z"
  })), children);
});
var TrafficFlowIncident24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficFlowIncident24(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 9.42L24.59 8 22.005 10.585 22 10.58 21.995 10.585 19.42 8.01 18 9.42 20.58 12 18 14.58 19.41 16 21.995 13.415 22 13.42 22.005 13.415 24.58 15.99 26 14.58 23.42 12 26 9.42zM14 17.42L12.59 16 10.005 18.585 10 18.58 9.995 18.585 7.42 16.01 6 17.42 8.58 20 6 22.58 7.41 24 9.995 21.415 10 21.42 10.005 21.415 12.58 23.99 14 22.58 11.42 20 14 17.42zM2 2H4V30H2zM28 2H30V30H28zM15 2H17V6H15zM15 10H17V14H15zM15 18H17V22H15zM15 26H17V30H15z"
  })), children);
});
var TrafficFlowIncident20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficFlowIncident20(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 9.42L24.59 8 22.005 10.585 22 10.58 21.995 10.585 19.42 8.01 18 9.42 20.58 12 18 14.58 19.41 16 21.995 13.415 22 13.42 22.005 13.415 24.58 15.99 26 14.58 23.42 12 26 9.42zM14 17.42L12.59 16 10.005 18.585 10 18.58 9.995 18.585 7.42 16.01 6 17.42 8.58 20 6 22.58 7.41 24 9.995 21.415 10 21.42 10.005 21.415 12.58 23.99 14 22.58 11.42 20 14 17.42zM2 2H4V30H2zM28 2H30V30H28zM15 2H17V6H15zM15 10H17V14H15zM15 18H17V22H15zM15 26H17V30H15z"
  })), children);
});
var TrafficFlowIncident16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficFlowIncident16(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 9.42L24.59 8 22.005 10.585 22 10.58 21.995 10.585 19.42 8.01 18 9.42 20.58 12 18 14.58 19.41 16 21.995 13.415 22 13.42 22.005 13.415 24.58 15.99 26 14.58 23.42 12 26 9.42zM14 17.42L12.59 16 10.005 18.585 10 18.58 9.995 18.585 7.42 16.01 6 17.42 8.58 20 6 22.58 7.41 24 9.995 21.415 10 21.42 10.005 21.415 12.58 23.99 14 22.58 11.42 20 14 17.42zM2 2H4V30H2zM28 2H30V30H28zM15 2H17V6H15zM15 10H17V14H15zM15 18H17V22H15zM15 26H17V30H15z"
  })), children);
});
var TrafficIncident32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficIncident32(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2z"
  })), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.314 11.514H17.314V13.514H11.314z",
    transform: "rotate(-45 14.314 12.514)"
  })), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.0815,23.4329l4.1168,2.3176a2.009,2.009,0,0,0,2.3853-.3344l8.8326-8.8326a2.0088,2.0088,0,0,0,.334-2.3856l-2.2977-4.136,1.79-1.79L25.8283,6.8577,24.4141,8.2719l-4.95-4.95a2.0026,2.0026,0,0,0-2.8285,0L14.5146,1.2008,13.1,2.615l2.1213,2.1214L6.7364,13.2216,4.6151,11.1,3.2009,12.5145l2.1213,2.1213a2.0025,2.0025,0,0,0,0,2.8285l4.95,4.95L8.8577,23.8282l1.4143,1.4142Zm13.92-8.2636-8.8328,8.8328-4.5456-2.5255L23.4767,10.6235ZM9.5649,18.8785l1.4142-1.4142L9.5649,16.05,8.1506,17.4643,6.7364,16.05,18.05,4.7364l1.4143,1.4142L18.05,7.5648,19.4644,8.979l1.4142-1.4142L22.2928,8.979,10.9791,20.2927Z"
  })), children);
});
var TrafficIncident24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficIncident24(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2z"
  })), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.314 11.514H17.314V13.514H11.314z",
    transform: "rotate(-45 14.314 12.514)"
  })), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.0815,23.4329l4.1168,2.3176a2.009,2.009,0,0,0,2.3853-.3344l8.8326-8.8326a2.0088,2.0088,0,0,0,.334-2.3856l-2.2977-4.136,1.79-1.79L25.8283,6.8577,24.4141,8.2719l-4.95-4.95a2.0026,2.0026,0,0,0-2.8285,0L14.5146,1.2008,13.1,2.615l2.1213,2.1214L6.7364,13.2216,4.6151,11.1,3.2009,12.5145l2.1213,2.1213a2.0025,2.0025,0,0,0,0,2.8285l4.95,4.95L8.8577,23.8282l1.4143,1.4142Zm13.92-8.2636-8.8328,8.8328-4.5456-2.5255L23.4767,10.6235ZM9.5649,18.8785l1.4142-1.4142L9.5649,16.05,8.1506,17.4643,6.7364,16.05,18.05,4.7364l1.4143,1.4142L18.05,7.5648,19.4644,8.979l1.4142-1.4142L22.2928,8.979,10.9791,20.2927Z"
  })), children);
});
var TrafficIncident20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficIncident20(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2z"
  })), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.314 11.514H17.314V13.514H11.314z",
    transform: "rotate(-45 14.314 12.514)"
  })), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.0815,23.4329l4.1168,2.3176a2.009,2.009,0,0,0,2.3853-.3344l8.8326-8.8326a2.0088,2.0088,0,0,0,.334-2.3856l-2.2977-4.136,1.79-1.79L25.8283,6.8577,24.4141,8.2719l-4.95-4.95a2.0026,2.0026,0,0,0-2.8285,0L14.5146,1.2008,13.1,2.615l2.1213,2.1214L6.7364,13.2216,4.6151,11.1,3.2009,12.5145l2.1213,2.1213a2.0025,2.0025,0,0,0,0,2.8285l4.95,4.95L8.8577,23.8282l1.4143,1.4142Zm13.92-8.2636-8.8328,8.8328-4.5456-2.5255L23.4767,10.6235ZM9.5649,18.8785l1.4142-1.4142L9.5649,16.05,8.1506,17.4643,6.7364,16.05,18.05,4.7364l1.4143,1.4142L18.05,7.5648,19.4644,8.979l1.4142-1.4142L22.2928,8.979,10.9791,20.2927Z"
  })), children);
});
var TrafficIncident16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficIncident16(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2z"
  })), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.314 11.514H17.314V13.514H11.314z",
    transform: "rotate(-45 14.314 12.514)"
  })), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.0815,23.4329l4.1168,2.3176a2.009,2.009,0,0,0,2.3853-.3344l8.8326-8.8326a2.0088,2.0088,0,0,0,.334-2.3856l-2.2977-4.136,1.79-1.79L25.8283,6.8577,24.4141,8.2719l-4.95-4.95a2.0026,2.0026,0,0,0-2.8285,0L14.5146,1.2008,13.1,2.615l2.1213,2.1214L6.7364,13.2216,4.6151,11.1,3.2009,12.5145l2.1213,2.1213a2.0025,2.0025,0,0,0,0,2.8285l4.95,4.95L8.8577,23.8282l1.4143,1.4142Zm13.92-8.2636-8.8328,8.8328-4.5456-2.5255L23.4767,10.6235ZM9.5649,18.8785l1.4142-1.4142L9.5649,16.05,8.1506,17.4643,6.7364,16.05,18.05,4.7364l1.4143,1.4142L18.05,7.5648,19.4644,8.979l1.4142-1.4142L22.2928,8.979,10.9791,20.2927Z"
  })), children);
});
var TrafficWeatherIncident32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficWeatherIncident32(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 24H4V30H2zM28 2H30V30H28zM15 2H17V6H15zM15 10H17V14H15zM15 18H17V22H15zM15 26H17V30H15zM6 12A3.8978 3.8978 0 012 8.223a3.9017 3.9017 0 01.6533-2.0639L5.17 2.4141a1.0381 1.0381 0 011.6592 0L9.3154 6.11A3.9693 3.9693 0 0110 8.223 3.8978 3.8978 0 016 12zm0-7.2368L4.3438 7.2257A1.89 1.89 0 004 8.223a1.9007 1.9007 0 002 1.7775A1.9007 1.9007 0 008 8.223a1.98 1.98 0 00-.375-1.0466zM11 11.7627L9.3438 14.2253A1.89 1.89 0 009 15.2226 1.9007 1.9007 0 0011 17a1.9007 1.9007 0 002-1.7774 1.98 1.98 0 00-.375-1.0467zM6 15.7627L4.3438 18.2253A1.89 1.89 0 004 19.2226 1.9007 1.9007 0 006 21a1.9007 1.9007 0 002-1.7774 1.98 1.98 0 00-.375-1.0467z"
  })), children);
});
var TrafficWeatherIncident24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficWeatherIncident24(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 24H4V30H2zM28 2H30V30H28zM15 2H17V6H15zM15 10H17V14H15zM15 18H17V22H15zM15 26H17V30H15zM6 12A3.8978 3.8978 0 012 8.223a3.9017 3.9017 0 01.6533-2.0639L5.17 2.4141a1.0381 1.0381 0 011.6592 0L9.3154 6.11A3.9693 3.9693 0 0110 8.223 3.8978 3.8978 0 016 12zm0-7.2368L4.3438 7.2257A1.89 1.89 0 004 8.223a1.9007 1.9007 0 002 1.7775A1.9007 1.9007 0 008 8.223a1.98 1.98 0 00-.375-1.0466zM11 11.7627L9.3438 14.2253A1.89 1.89 0 009 15.2226 1.9007 1.9007 0 0011 17a1.9007 1.9007 0 002-1.7774 1.98 1.98 0 00-.375-1.0467zM6 15.7627L4.3438 18.2253A1.89 1.89 0 004 19.2226 1.9007 1.9007 0 006 21a1.9007 1.9007 0 002-1.7774 1.98 1.98 0 00-.375-1.0467z"
  })), children);
});
var TrafficWeatherIncident20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficWeatherIncident20(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 24H4V30H2zM28 2H30V30H28zM15 2H17V6H15zM15 10H17V14H15zM15 18H17V22H15zM15 26H17V30H15zM6 12A3.8978 3.8978 0 012 8.223a3.9017 3.9017 0 01.6533-2.0639L5.17 2.4141a1.0381 1.0381 0 011.6592 0L9.3154 6.11A3.9693 3.9693 0 0110 8.223 3.8978 3.8978 0 016 12zm0-7.2368L4.3438 7.2257A1.89 1.89 0 004 8.223a1.9007 1.9007 0 002 1.7775A1.9007 1.9007 0 008 8.223a1.98 1.98 0 00-.375-1.0466zM11 11.7627L9.3438 14.2253A1.89 1.89 0 009 15.2226 1.9007 1.9007 0 0011 17a1.9007 1.9007 0 002-1.7774 1.98 1.98 0 00-.375-1.0467zM6 15.7627L4.3438 18.2253A1.89 1.89 0 004 19.2226 1.9007 1.9007 0 006 21a1.9007 1.9007 0 002-1.7774 1.98 1.98 0 00-.375-1.0467z"
  })), children);
});
var TrafficWeatherIncident16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficWeatherIncident16(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 24H4V30H2zM28 2H30V30H28zM15 2H17V6H15zM15 10H17V14H15zM15 18H17V22H15zM15 26H17V30H15zM6 12A3.8978 3.8978 0 012 8.223a3.9017 3.9017 0 01.6533-2.0639L5.17 2.4141a1.0381 1.0381 0 011.6592 0L9.3154 6.11A3.9693 3.9693 0 0110 8.223 3.8978 3.8978 0 016 12zm0-7.2368L4.3438 7.2257A1.89 1.89 0 004 8.223a1.9007 1.9007 0 002 1.7775A1.9007 1.9007 0 008 8.223a1.98 1.98 0 00-.375-1.0466zM11 11.7627L9.3438 14.2253A1.89 1.89 0 009 15.2226 1.9007 1.9007 0 0011 17a1.9007 1.9007 0 002-1.7774 1.98 1.98 0 00-.375-1.0467zM6 15.7627L4.3438 18.2253A1.89 1.89 0 004 19.2226 1.9007 1.9007 0 006 21a1.9007 1.9007 0 002-1.7774 1.98 1.98 0 00-.375-1.0467z"
  })), children);
});
var TrafficCone32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficCone32(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.7957,28,18.9746,2.7754A1,1,0,0,0,18,2H14a1,1,0,0,0-.9746.7754L7.2043,28H4v2H28V28ZM19.9736,16H12.0264l.9229-4h6.1014Zm.4616,2,.923,4H10.6418l.923-4Zm-5.64-14h2.4092l1.3845,6H13.4109ZM10.18,24H21.82l.923,4H9.2573Z"
  })), children);
});
var TrafficCone24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficCone24(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.7957,28,18.9746,2.7754A1,1,0,0,0,18,2H14a1,1,0,0,0-.9746.7754L7.2043,28H4v2H28V28ZM19.9736,16H12.0264l.9229-4h6.1014Zm.4616,2,.923,4H10.6418l.923-4Zm-5.64-14h2.4092l1.3845,6H13.4109ZM10.18,24H21.82l.923,4H9.2573Z"
  })), children);
});
var TrafficCone20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficCone20(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.7957,28,18.9746,2.7754A1,1,0,0,0,18,2H14a1,1,0,0,0-.9746.7754L7.2043,28H4v2H28V28ZM19.9736,16H12.0264l.9229-4h6.1014Zm.4616,2,.923,4H10.6418l.923-4Zm-5.64-14h2.4092l1.3845,6H13.4109ZM10.18,24H21.82l.923,4H9.2573Z"
  })), children);
});
var TrafficCone16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrafficCone16(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.7957,28,18.9746,2.7754A1,1,0,0,0,18,2H14a1,1,0,0,0-.9746.7754L7.2043,28H4v2H28V28ZM19.9736,16H12.0264l.9229-4h6.1014Zm.4616,2,.923,4H10.6418l.923-4Zm-5.64-14h2.4092l1.3845,6H13.4109ZM10.18,24H21.82l.923,4H9.2573Z"
  })), children);
});
var Train32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Train32(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,3H11A5.0057,5.0057,0,0,0,6,8V20a4.99,4.99,0,0,0,3.582,4.77L7.7693,29H9.9451l1.7143-4h8.6812l1.7143,4h2.1758L22.418,24.77A4.99,4.99,0,0,0,26,20V8A5.0057,5.0057,0,0,0,21,3ZM11,5H21a2.9948,2.9948,0,0,1,2.8157,2H8.1843A2.9948,2.9948,0,0,1,11,5ZM24,19H21v2h2.8157A2.9948,2.9948,0,0,1,21,23H11a2.9948,2.9948,0,0,1-2.8157-2H11V19H8V17H24Zm0-4H8V9H24Z"
  })), children);
});
var Train24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Train24(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,3H11A5.0057,5.0057,0,0,0,6,8V20a4.99,4.99,0,0,0,3.582,4.77L7.7693,29H9.9451l1.7143-4h8.6812l1.7143,4h2.1758L22.418,24.77A4.99,4.99,0,0,0,26,20V8A5.0057,5.0057,0,0,0,21,3ZM11,5H21a2.9948,2.9948,0,0,1,2.8157,2H8.1843A2.9948,2.9948,0,0,1,11,5ZM24,19H21v2h2.8157A2.9948,2.9948,0,0,1,21,23H11a2.9948,2.9948,0,0,1-2.8157-2H11V19H8V17H24Zm0-4H8V9H24Z"
  })), children);
});
var Train20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Train20(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,3H11A5.0057,5.0057,0,0,0,6,8V20a4.99,4.99,0,0,0,3.582,4.77L7.7693,29H9.9451l1.7143-4h8.6812l1.7143,4h2.1758L22.418,24.77A4.99,4.99,0,0,0,26,20V8A5.0057,5.0057,0,0,0,21,3ZM11,5H21a2.9948,2.9948,0,0,1,2.8157,2H8.1843A2.9948,2.9948,0,0,1,11,5ZM24,19H21v2h2.8157A2.9948,2.9948,0,0,1,21,23H11a2.9948,2.9948,0,0,1-2.8157-2H11V19H8V17H24Zm0-4H8V9H24Z"
  })), children);
});
var Train16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Train16(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,3H11A5.0057,5.0057,0,0,0,6,8V20a4.99,4.99,0,0,0,3.582,4.77L7.7693,29H9.9451l1.7143-4h8.6812l1.7143,4h2.1758L22.418,24.77A4.99,4.99,0,0,0,26,20V8A5.0057,5.0057,0,0,0,21,3ZM11,5H21a2.9948,2.9948,0,0,1,2.8157,2H8.1843A2.9948,2.9948,0,0,1,11,5ZM24,19H21v2h2.8157A2.9948,2.9948,0,0,1,21,23H11a2.9948,2.9948,0,0,1-2.8157-2H11V19H8V17H24Zm0-4H8V9H24Z"
  })), children);
});
var TrainHeart32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainHeart32(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.303 2a2.6613 2.6613 0 00-1.9079.8059l-.3932.4053-.397-.4053a2.6612 2.6612 0 00-3.8157 0 2.7991 2.7991 0 000 3.8963L25.0019 11l4.2089-4.2978a2.7991 2.7991 0 000-3.8963A2.6613 2.6613 0 0027.303 2zM22 13v3H6V10h9V8H6.1843A2.9948 2.9948 0 019 6h6V4H9A5.0057 5.0057 0 004 9V21a4.99 4.99 0 003.582 4.77L5.7693 30H7.9451l1.7143-4h8.6812l1.7143 4h2.1758L20.418 25.77A4.99 4.99 0 0024 21V13zm0 7H19v2h2.8157A2.9948 2.9948 0 0119 24H9a2.9948 2.9948 0 01-2.8157-2H9V20H6V18H22z"
  })), children);
});
var TrainHeart24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainHeart24(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.303 2a2.6613 2.6613 0 00-1.9079.8059l-.3932.4053-.397-.4053a2.6612 2.6612 0 00-3.8157 0 2.7991 2.7991 0 000 3.8963L25.0019 11l4.2089-4.2978a2.7991 2.7991 0 000-3.8963A2.6613 2.6613 0 0027.303 2zM22 13v3H6V10h9V8H6.1843A2.9948 2.9948 0 019 6h6V4H9A5.0057 5.0057 0 004 9V21a4.99 4.99 0 003.582 4.77L5.7693 30H7.9451l1.7143-4h8.6812l1.7143 4h2.1758L20.418 25.77A4.99 4.99 0 0024 21V13zm0 7H19v2h2.8157A2.9948 2.9948 0 0119 24H9a2.9948 2.9948 0 01-2.8157-2H9V20H6V18H22z"
  })), children);
});
var TrainHeart20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainHeart20(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.303 2a2.6613 2.6613 0 00-1.9079.8059l-.3932.4053-.397-.4053a2.6612 2.6612 0 00-3.8157 0 2.7991 2.7991 0 000 3.8963L25.0019 11l4.2089-4.2978a2.7991 2.7991 0 000-3.8963A2.6613 2.6613 0 0027.303 2zM22 13v3H6V10h9V8H6.1843A2.9948 2.9948 0 019 6h6V4H9A5.0057 5.0057 0 004 9V21a4.99 4.99 0 003.582 4.77L5.7693 30H7.9451l1.7143-4h8.6812l1.7143 4h2.1758L20.418 25.77A4.99 4.99 0 0024 21V13zm0 7H19v2h2.8157A2.9948 2.9948 0 0119 24H9a2.9948 2.9948 0 01-2.8157-2H9V20H6V18H22z"
  })), children);
});
var TrainHeart16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainHeart16(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.303 2a2.6613 2.6613 0 00-1.9079.8059l-.3932.4053-.397-.4053a2.6612 2.6612 0 00-3.8157 0 2.7991 2.7991 0 000 3.8963L25.0019 11l4.2089-4.2978a2.7991 2.7991 0 000-3.8963A2.6613 2.6613 0 0027.303 2zM22 13v3H6V10h9V8H6.1843A2.9948 2.9948 0 019 6h6V4H9A5.0057 5.0057 0 004 9V21a4.99 4.99 0 003.582 4.77L5.7693 30H7.9451l1.7143-4h8.6812l1.7143 4h2.1758L20.418 25.77A4.99 4.99 0 0024 21V13zm0 7H19v2h2.8157A2.9948 2.9948 0 0119 24H9a2.9948 2.9948 0 01-2.8157-2H9V20H6V18H22z"
  })), children);
});
var TrainProfile32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainProfile32(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 25L2 25 2 27 4 27 4 29 6 29 6 27 11 27 11 29 13 29 13 27 18 27 18 29 20 29 20 27 25 27 25 29 27 29 27 27 30 27 30 25zM8 16H2V14H8V12H2V10H8a2.0021 2.0021 0 012 2v2A2.0021 2.0021 0 018 16z"
  })), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.55,14.2305,19.97,6.3657A8.9775,8.9775,0,0,0,13.8882,4H2V6H12v4a2.0023,2.0023,0,0,0,2,2h9.1565l4.0417,3.7051A2.4723,2.4723,0,0,1,25.5273,20H2v2H25.5273a4.4726,4.4726,0,0,0,3.0225-7.77ZM14,10V6.0054A6.9774,6.9774,0,0,1,18.6182,7.84L20.9746,10Z"
  })), children);
});
var TrainProfile24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainProfile24(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 25L2 25 2 27 4 27 4 29 6 29 6 27 11 27 11 29 13 29 13 27 18 27 18 29 20 29 20 27 25 27 25 29 27 29 27 27 30 27 30 25zM8 16H2V14H8V12H2V10H8a2.0021 2.0021 0 012 2v2A2.0021 2.0021 0 018 16z"
  })), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.55,14.2305,19.97,6.3657A8.9775,8.9775,0,0,0,13.8882,4H2V6H12v4a2.0023,2.0023,0,0,0,2,2h9.1565l4.0417,3.7051A2.4723,2.4723,0,0,1,25.5273,20H2v2H25.5273a4.4726,4.4726,0,0,0,3.0225-7.77ZM14,10V6.0054A6.9774,6.9774,0,0,1,18.6182,7.84L20.9746,10Z"
  })), children);
});
var TrainProfile20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainProfile20(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 25L2 25 2 27 4 27 4 29 6 29 6 27 11 27 11 29 13 29 13 27 18 27 18 29 20 29 20 27 25 27 25 29 27 29 27 27 30 27 30 25zM8 16H2V14H8V12H2V10H8a2.0021 2.0021 0 012 2v2A2.0021 2.0021 0 018 16z"
  })), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.55,14.2305,19.97,6.3657A8.9775,8.9775,0,0,0,13.8882,4H2V6H12v4a2.0023,2.0023,0,0,0,2,2h9.1565l4.0417,3.7051A2.4723,2.4723,0,0,1,25.5273,20H2v2H25.5273a4.4726,4.4726,0,0,0,3.0225-7.77ZM14,10V6.0054A6.9774,6.9774,0,0,1,18.6182,7.84L20.9746,10Z"
  })), children);
});
var TrainProfile16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainProfile16(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 25L2 25 2 27 4 27 4 29 6 29 6 27 11 27 11 29 13 29 13 27 18 27 18 29 20 29 20 27 25 27 25 29 27 29 27 27 30 27 30 25zM8 16H2V14H8V12H2V10H8a2.0021 2.0021 0 012 2v2A2.0021 2.0021 0 018 16z"
  })), _path390 || (_path390 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.55,14.2305,19.97,6.3657A8.9775,8.9775,0,0,0,13.8882,4H2V6H12v4a2.0023,2.0023,0,0,0,2,2h9.1565l4.0417,3.7051A2.4723,2.4723,0,0,1,25.5273,20H2v2H25.5273a4.4726,4.4726,0,0,0,3.0225-7.77ZM14,10V6.0054A6.9774,6.9774,0,0,1,18.6182,7.84L20.9746,10Z"
  })), children);
});
var TrainSpeed32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainSpeed32(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path391 || (_path391 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 25L2 25 2 27 4 27 4 29 6 29 6 27 11 27 11 29 13 29 13 27 18 27 18 29 20 29 20 27 25 27 25 29 27 29 27 27 30 27 30 25zM29.7144 16.59L18.1494 8.64A14.9327 14.9327 0 009.6519 6H2V8H9.6519a12.9459 12.9459 0 017.3647 2.2871L18.0532 11H9v2H20.9624l7.6187 5.2378A.966.966 0 0128.0342 20H2v2H28.0342a2.9661 2.9661 0 001.68-5.41z"
  })), children);
});
var TrainSpeed24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainSpeed24(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path392 || (_path392 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 25L2 25 2 27 4 27 4 29 6 29 6 27 11 27 11 29 13 29 13 27 18 27 18 29 20 29 20 27 25 27 25 29 27 29 27 27 30 27 30 25zM29.7144 16.59L18.1494 8.64A14.9327 14.9327 0 009.6519 6H2V8H9.6519a12.9459 12.9459 0 017.3647 2.2871L18.0532 11H9v2H20.9624l7.6187 5.2378A.966.966 0 0128.0342 20H2v2H28.0342a2.9661 2.9661 0 001.68-5.41z"
  })), children);
});
var TrainSpeed20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainSpeed20(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path393 || (_path393 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 25L2 25 2 27 4 27 4 29 6 29 6 27 11 27 11 29 13 29 13 27 18 27 18 29 20 29 20 27 25 27 25 29 27 29 27 27 30 27 30 25zM29.7144 16.59L18.1494 8.64A14.9327 14.9327 0 009.6519 6H2V8H9.6519a12.9459 12.9459 0 017.3647 2.2871L18.0532 11H9v2H20.9624l7.6187 5.2378A.966.966 0 0128.0342 20H2v2H28.0342a2.9661 2.9661 0 001.68-5.41z"
  })), children);
});
var TrainSpeed16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainSpeed16(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path394 || (_path394 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 25L2 25 2 27 4 27 4 29 6 29 6 27 11 27 11 29 13 29 13 27 18 27 18 29 20 29 20 27 25 27 25 29 27 29 27 27 30 27 30 25zM29.7144 16.59L18.1494 8.64A14.9327 14.9327 0 009.6519 6H2V8H9.6519a12.9459 12.9459 0 017.3647 2.2871L18.0532 11H9v2H20.9624l7.6187 5.2378A.966.966 0 0128.0342 20H2v2H28.0342a2.9661 2.9661 0 001.68-5.41z"
  })), children);
});
var TrainTicket32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainTicket32(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path395 || (_path395 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.1257,7.125a1.125,1.125,0,1,1,0-2.25h.875V2h-12V4.875h.875a1.125,1.125,0,0,1,0,2.25h-.875V10h12V7.125Z"
  })), _path396 || (_path396 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.0007,13v3h-16V10h9V8H6.185A2.9948,2.9948,0,0,1,9.0007,6h6V4h-6a5.0057,5.0057,0,0,0-5,5V21a4.99,4.99,0,0,0,3.582,4.77L5.77,30H7.9458L9.66,26h8.6812l1.7143,4h2.1758l-1.8127-4.23A4.99,4.99,0,0,0,24.0007,21V13Zm0,7h-3v2h2.8157a2.9948,2.9948,0,0,1-2.8157,2h-10A2.9948,2.9948,0,0,1,6.185,22H9.0007V20h-3V18h16Z"
  })), children);
});
var TrainTicket24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainTicket24(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path397 || (_path397 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.1257,7.125a1.125,1.125,0,1,1,0-2.25h.875V2h-12V4.875h.875a1.125,1.125,0,0,1,0,2.25h-.875V10h12V7.125Z"
  })), _path398 || (_path398 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.0007,13v3h-16V10h9V8H6.185A2.9948,2.9948,0,0,1,9.0007,6h6V4h-6a5.0057,5.0057,0,0,0-5,5V21a4.99,4.99,0,0,0,3.582,4.77L5.77,30H7.9458L9.66,26h8.6812l1.7143,4h2.1758l-1.8127-4.23A4.99,4.99,0,0,0,24.0007,21V13Zm0,7h-3v2h2.8157a2.9948,2.9948,0,0,1-2.8157,2h-10A2.9948,2.9948,0,0,1,6.185,22H9.0007V20h-3V18h16Z"
  })), children);
});
var TrainTicket20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainTicket20(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path399 || (_path399 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.1257,7.125a1.125,1.125,0,1,1,0-2.25h.875V2h-12V4.875h.875a1.125,1.125,0,0,1,0,2.25h-.875V10h12V7.125Z"
  })), _path400 || (_path400 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.0007,13v3h-16V10h9V8H6.185A2.9948,2.9948,0,0,1,9.0007,6h6V4h-6a5.0057,5.0057,0,0,0-5,5V21a4.99,4.99,0,0,0,3.582,4.77L5.77,30H7.9458L9.66,26h8.6812l1.7143,4h2.1758l-1.8127-4.23A4.99,4.99,0,0,0,24.0007,21V13Zm0,7h-3v2h2.8157a2.9948,2.9948,0,0,1-2.8157,2h-10A2.9948,2.9948,0,0,1,6.185,22H9.0007V20h-3V18h16Z"
  })), children);
});
var TrainTicket16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainTicket16(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path401 || (_path401 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.1257,7.125a1.125,1.125,0,1,1,0-2.25h.875V2h-12V4.875h.875a1.125,1.125,0,0,1,0,2.25h-.875V10h12V7.125Z"
  })), _path402 || (_path402 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.0007,13v3h-16V10h9V8H6.185A2.9948,2.9948,0,0,1,9.0007,6h6V4h-6a5.0057,5.0057,0,0,0-5,5V21a4.99,4.99,0,0,0,3.582,4.77L5.77,30H7.9458L9.66,26h8.6812l1.7143,4h2.1758l-1.8127-4.23A4.99,4.99,0,0,0,24.0007,21V13Zm0,7h-3v2h2.8157a2.9948,2.9948,0,0,1-2.8157,2h-10A2.9948,2.9948,0,0,1,6.185,22H9.0007V20h-3V18h16Z"
  })), children);
});
var TrainTime32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainTime32(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path403 || (_path403 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M25.496 10.088L22.874 7.466 22.874 3 25.124 3 25.124 6.534 27.088 8.498 25.496 10.088z"
  })), _path404 || (_path404 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,1a6,6,0,1,0,6,6A6.0066,6.0066,0,0,0,24,1Zm1.4971,9.0884L22.875,7.4658V3h2.25V6.5342l1.9639,1.9634Z"
  })), _path405 || (_path405 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,16V10h9V8H6.1843A2.9948,2.9948,0,0,1,9,6h6V4H9A5.0057,5.0057,0,0,0,4,9V21a4.99,4.99,0,0,0,3.582,4.77L5.7693,30H7.9451l1.7143-4h8.6812l1.7143,4h2.1758L20.418,25.77A4.99,4.99,0,0,0,24,21V16Zm16,4H19v2h2.8157A2.9948,2.9948,0,0,1,19,24H9a2.9948,2.9948,0,0,1-2.8157-2H9V20H6V18H22Z"
  })), children);
});
var TrainTime24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainTime24(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path406 || (_path406 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M25.496 10.088L22.874 7.466 22.874 3 25.124 3 25.124 6.534 27.088 8.498 25.496 10.088z"
  })), _path407 || (_path407 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,1a6,6,0,1,0,6,6A6.0066,6.0066,0,0,0,24,1Zm1.4971,9.0884L22.875,7.4658V3h2.25V6.5342l1.9639,1.9634Z"
  })), _path408 || (_path408 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,16V10h9V8H6.1843A2.9948,2.9948,0,0,1,9,6h6V4H9A5.0057,5.0057,0,0,0,4,9V21a4.99,4.99,0,0,0,3.582,4.77L5.7693,30H7.9451l1.7143-4h8.6812l1.7143,4h2.1758L20.418,25.77A4.99,4.99,0,0,0,24,21V16Zm16,4H19v2h2.8157A2.9948,2.9948,0,0,1,19,24H9a2.9948,2.9948,0,0,1-2.8157-2H9V20H6V18H22Z"
  })), children);
});
var TrainTime20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainTime20(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path409 || (_path409 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M25.496 10.088L22.874 7.466 22.874 3 25.124 3 25.124 6.534 27.088 8.498 25.496 10.088z"
  })), _path410 || (_path410 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,1a6,6,0,1,0,6,6A6.0066,6.0066,0,0,0,24,1Zm1.4971,9.0884L22.875,7.4658V3h2.25V6.5342l1.9639,1.9634Z"
  })), _path411 || (_path411 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,16V10h9V8H6.1843A2.9948,2.9948,0,0,1,9,6h6V4H9A5.0057,5.0057,0,0,0,4,9V21a4.99,4.99,0,0,0,3.582,4.77L5.7693,30H7.9451l1.7143-4h8.6812l1.7143,4h2.1758L20.418,25.77A4.99,4.99,0,0,0,24,21V16Zm16,4H19v2h2.8157A2.9948,2.9948,0,0,1,19,24H9a2.9948,2.9948,0,0,1-2.8157-2H9V20H6V18H22Z"
  })), children);
});
var TrainTime16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrainTime16(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path412 || (_path412 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M25.496 10.088L22.874 7.466 22.874 3 25.124 3 25.124 6.534 27.088 8.498 25.496 10.088z"
  })), _path413 || (_path413 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,1a6,6,0,1,0,6,6A6.0066,6.0066,0,0,0,24,1Zm1.4971,9.0884L22.875,7.4658V3h2.25V6.5342l1.9639,1.9634Z"
  })), _path414 || (_path414 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,16V10h9V8H6.1843A2.9948,2.9948,0,0,1,9,6h6V4H9A5.0057,5.0057,0,0,0,4,9V21a4.99,4.99,0,0,0,3.582,4.77L5.7693,30H7.9451l1.7143-4h8.6812l1.7143,4h2.1758L20.418,25.77A4.99,4.99,0,0,0,24,21V16Zm16,4H19v2h2.8157A2.9948,2.9948,0,0,1,19,24H9a2.9948,2.9948,0,0,1-2.8157-2H9V20H6V18H22Z"
  })), children);
});
var Tram32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tram32(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path415 || (_path415 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,6H17V4h6V2H9V4h6V6H11a5.0057,5.0057,0,0,0-5,5V22a4.99,4.99,0,0,0,3.582,4.77L8.1978,30h2.1757l1.2859-3h8.6812l1.2859,3h2.1757L22.418,26.77A4.99,4.99,0,0,0,26,22V11A5.0057,5.0057,0,0,0,21,6ZM11,8H21a2.9948,2.9948,0,0,1,2.8157,2H8.1843A2.9948,2.9948,0,0,1,11,8ZM24,21H21v2h2.8157A2.9948,2.9948,0,0,1,21,25H11a2.9948,2.9948,0,0,1-2.8157-2H11V21H8V19H24Zm0-4H8V12H24Z"
  })), children);
});
var Tram24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tram24(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path416 || (_path416 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,6H17V4h6V2H9V4h6V6H11a5.0057,5.0057,0,0,0-5,5V22a4.99,4.99,0,0,0,3.582,4.77L8.1978,30h2.1757l1.2859-3h8.6812l1.2859,3h2.1757L22.418,26.77A4.99,4.99,0,0,0,26,22V11A5.0057,5.0057,0,0,0,21,6ZM11,8H21a2.9948,2.9948,0,0,1,2.8157,2H8.1843A2.9948,2.9948,0,0,1,11,8ZM24,21H21v2h2.8157A2.9948,2.9948,0,0,1,21,25H11a2.9948,2.9948,0,0,1-2.8157-2H11V21H8V19H24Zm0-4H8V12H24Z"
  })), children);
});
var Tram20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tram20(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path417 || (_path417 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,6H17V4h6V2H9V4h6V6H11a5.0057,5.0057,0,0,0-5,5V22a4.99,4.99,0,0,0,3.582,4.77L8.1978,30h2.1757l1.2859-3h8.6812l1.2859,3h2.1757L22.418,26.77A4.99,4.99,0,0,0,26,22V11A5.0057,5.0057,0,0,0,21,6ZM11,8H21a2.9948,2.9948,0,0,1,2.8157,2H8.1843A2.9948,2.9948,0,0,1,11,8ZM24,21H21v2h2.8157A2.9948,2.9948,0,0,1,21,25H11a2.9948,2.9948,0,0,1-2.8157-2H11V21H8V19H24Zm0-4H8V12H24Z"
  })), children);
});
var Tram16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tram16(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path418 || (_path418 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,6H17V4h6V2H9V4h6V6H11a5.0057,5.0057,0,0,0-5,5V22a4.99,4.99,0,0,0,3.582,4.77L8.1978,30h2.1757l1.2859-3h8.6812l1.2859,3h2.1757L22.418,26.77A4.99,4.99,0,0,0,26,22V11A5.0057,5.0057,0,0,0,21,6ZM11,8H21a2.9948,2.9948,0,0,1,2.8157,2H8.1843A2.9948,2.9948,0,0,1,11,8ZM24,21H21v2h2.8157A2.9948,2.9948,0,0,1,21,25H11a2.9948,2.9948,0,0,1-2.8157-2H11V21H8V19H24Zm0-4H8V12H24Z"
  })), children);
});
var Transgender32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Transgender32(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path419 || (_path419 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,2V4h4.5859l-6.4016,6.4014a6.9474,6.9474,0,0,0-8.3686,0L10.4143,9,13,6.4141,11.5857,5,9,7.5859,5.4141,4H10V2H2v8H4V5.4141L7.5859,9,5,11.5854,6.4143,13,9,10.4141l1.4014,1.4013A6.9785,6.9785,0,0,0,15,22.92V25H11v2h4v3h2V27h4V25H17V22.92a6.9785,6.9785,0,0,0,4.5984-11.1045L28,5.4141V10h2V2ZM16,21a5,5,0,1,1,5-5A5.0059,5.0059,0,0,1,16,21Z"
  })), children);
});
var Transgender24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Transgender24(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path420 || (_path420 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,2V4h4.5859l-6.4016,6.4014a6.9474,6.9474,0,0,0-8.3686,0L10.4143,9,13,6.4141,11.5857,5,9,7.5859,5.4141,4H10V2H2v8H4V5.4141L7.5859,9,5,11.5854,6.4143,13,9,10.4141l1.4014,1.4013A6.9785,6.9785,0,0,0,15,22.92V25H11v2h4v3h2V27h4V25H17V22.92a6.9785,6.9785,0,0,0,4.5984-11.1045L28,5.4141V10h2V2ZM16,21a5,5,0,1,1,5-5A5.0059,5.0059,0,0,1,16,21Z"
  })), children);
});
var Transgender20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Transgender20(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path421 || (_path421 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,2V4h4.5859l-6.4016,6.4014a6.9474,6.9474,0,0,0-8.3686,0L10.4143,9,13,6.4141,11.5857,5,9,7.5859,5.4141,4H10V2H2v8H4V5.4141L7.5859,9,5,11.5854,6.4143,13,9,10.4141l1.4014,1.4013A6.9785,6.9785,0,0,0,15,22.92V25H11v2h4v3h2V27h4V25H17V22.92a6.9785,6.9785,0,0,0,4.5984-11.1045L28,5.4141V10h2V2ZM16,21a5,5,0,1,1,5-5A5.0059,5.0059,0,0,1,16,21Z"
  })), children);
});
var Transgender16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Transgender16(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path422 || (_path422 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,2V4h4.5859l-6.4016,6.4014a6.9474,6.9474,0,0,0-8.3686,0L10.4143,9,13,6.4141,11.5857,5,9,7.5859,5.4141,4H10V2H2v8H4V5.4141L7.5859,9,5,11.5854,6.4143,13,9,10.4141l1.4014,1.4013A6.9785,6.9785,0,0,0,15,22.92V25H11v2h4v3h2V27h4V25H17V22.92a6.9785,6.9785,0,0,0,4.5984-11.1045L28,5.4141V10h2V2ZM16,21a5,5,0,1,1,5-5A5.0059,5.0059,0,0,1,16,21Z"
  })), children);
});
var Translate32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Translate32(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path423 || (_path423 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.85 29H30L24 14H21.65l-6 15H17.8l1.6-4h6.85zM20.2 23l2.62-6.56L25.45 23zM18 7V5H11V2H9V5H2V7H12.74a14.71 14.71 0 01-3.19 6.18A13.5 13.5 0 017.26 9H5.16a16.47 16.47 0 003 5.58A16.84 16.84 0 013 18l.75 1.86A18.47 18.47 0 009.53 16a16.92 16.92 0 005.76 3.84L16 18a14.48 14.48 0 01-5.12-3.37A17.64 17.64 0 0014.8 7z"
  })), children);
});
var Translate24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Translate24(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path424 || (_path424 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.85 29H30L24 14H21.65l-6 15H17.8l1.6-4h6.85zM20.2 23l2.62-6.56L25.45 23zM18 7V5H11V2H9V5H2V7H12.74a14.71 14.71 0 01-3.19 6.18A13.5 13.5 0 017.26 9H5.16a16.47 16.47 0 003 5.58A16.84 16.84 0 013 18l.75 1.86A18.47 18.47 0 009.53 16a16.92 16.92 0 005.76 3.84L16 18a14.48 14.48 0 01-5.12-3.37A17.64 17.64 0 0014.8 7z"
  })), children);
});
var Translate20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Translate20(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path425 || (_path425 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.85 29H30L24 14H21.65l-6 15H17.8l1.6-4h6.85zM20.2 23l2.62-6.56L25.45 23zM18 7V5H11V2H9V5H2V7H12.74a14.71 14.71 0 01-3.19 6.18A13.5 13.5 0 017.26 9H5.16a16.47 16.47 0 003 5.58A16.84 16.84 0 013 18l.75 1.86A18.47 18.47 0 009.53 16a16.92 16.92 0 005.76 3.84L16 18a14.48 14.48 0 01-5.12-3.37A17.64 17.64 0 0014.8 7z"
  })), children);
});
var Translate16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Translate16(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path426 || (_path426 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.85 29H30L24 14H21.65l-6 15H17.8l1.6-4h6.85zM20.2 23l2.62-6.56L25.45 23zM18 7V5H11V2H9V5H2V7H12.74a14.71 14.71 0 01-3.19 6.18A13.5 13.5 0 017.26 9H5.16a16.47 16.47 0 003 5.58A16.84 16.84 0 013 18l.75 1.86A18.47 18.47 0 009.53 16a16.92 16.92 0 005.76 3.84L16 18a14.48 14.48 0 01-5.12-3.37A17.64 17.64 0 0014.8 7z"
  })), children);
});
var TransmissionLte32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TransmissionLte32(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path427 || (_path427 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.57 30l.9333-2h8.9928l.9333 2h2.2072L17 15.7778V11H15v4.7778L8.3631 30zM16 18.3647L17.6965 22h-3.393zM13.37 24h5.26l.9333 2H12.4369zM10.7832 9.3325a7.0007 7.0007 0 0110.4341 0l-1.49 1.334a5 5 0 00-7.4537 0z"
  })), _path428 || (_path428 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.1992,6.3994a11.0019,11.0019,0,0,1,17.6006,0L23.2,7.6a9.0009,9.0009,0,0,0-14.4014,0Z"
  })), children);
});
var TransmissionLte24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TransmissionLte24(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path429 || (_path429 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.57 30l.9333-2h8.9928l.9333 2h2.2072L17 15.7778V11H15v4.7778L8.3631 30zM16 18.3647L17.6965 22h-3.393zM13.37 24h5.26l.9333 2H12.4369zM10.7832 9.3325a7.0007 7.0007 0 0110.4341 0l-1.49 1.334a5 5 0 00-7.4537 0z"
  })), _path430 || (_path430 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.1992,6.3994a11.0019,11.0019,0,0,1,17.6006,0L23.2,7.6a9.0009,9.0009,0,0,0-14.4014,0Z"
  })), children);
});
var TransmissionLte20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TransmissionLte20(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path431 || (_path431 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.57 30l.9333-2h8.9928l.9333 2h2.2072L17 15.7778V11H15v4.7778L8.3631 30zM16 18.3647L17.6965 22h-3.393zM13.37 24h5.26l.9333 2H12.4369zM10.7832 9.3325a7.0007 7.0007 0 0110.4341 0l-1.49 1.334a5 5 0 00-7.4537 0z"
  })), _path432 || (_path432 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.1992,6.3994a11.0019,11.0019,0,0,1,17.6006,0L23.2,7.6a9.0009,9.0009,0,0,0-14.4014,0Z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-28.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-28.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "QU116": () => (/* binding */ QU116),
/* harmony export */   "QU120": () => (/* binding */ QU120),
/* harmony export */   "QU124": () => (/* binding */ QU124),
/* harmony export */   "QU132": () => (/* binding */ QU132),
/* harmony export */   "QU216": () => (/* binding */ QU216),
/* harmony export */   "QU220": () => (/* binding */ QU220),
/* harmony export */   "QU224": () => (/* binding */ QU224),
/* harmony export */   "QU232": () => (/* binding */ QU232),
/* harmony export */   "QU316": () => (/* binding */ QU316),
/* harmony export */   "QU320": () => (/* binding */ QU320),
/* harmony export */   "QU324": () => (/* binding */ QU324),
/* harmony export */   "QU332": () => (/* binding */ QU332),
/* harmony export */   "TransmissionLte16": () => (/* binding */ TransmissionLte16),
/* harmony export */   "Transpose16": () => (/* binding */ Transpose16),
/* harmony export */   "Transpose20": () => (/* binding */ Transpose20),
/* harmony export */   "Transpose24": () => (/* binding */ Transpose24),
/* harmony export */   "Transpose32": () => (/* binding */ Transpose32),
/* harmony export */   "TrashCan16": () => (/* binding */ TrashCan16),
/* harmony export */   "TrashCan20": () => (/* binding */ TrashCan20),
/* harmony export */   "TrashCan24": () => (/* binding */ TrashCan24),
/* harmony export */   "TrashCan32": () => (/* binding */ TrashCan32),
/* harmony export */   "Tree16": () => (/* binding */ Tree16),
/* harmony export */   "Tree20": () => (/* binding */ Tree20),
/* harmony export */   "Tree24": () => (/* binding */ Tree24),
/* harmony export */   "Tree32": () => (/* binding */ Tree32),
/* harmony export */   "TreeFallRisk16": () => (/* binding */ TreeFallRisk16),
/* harmony export */   "TreeFallRisk20": () => (/* binding */ TreeFallRisk20),
/* harmony export */   "TreeFallRisk24": () => (/* binding */ TreeFallRisk24),
/* harmony export */   "TreeFallRisk32": () => (/* binding */ TreeFallRisk32),
/* harmony export */   "TreeView16": () => (/* binding */ TreeView16),
/* harmony export */   "TreeView20": () => (/* binding */ TreeView20),
/* harmony export */   "TreeView24": () => (/* binding */ TreeView24),
/* harmony export */   "TreeView32": () => (/* binding */ TreeView32),
/* harmony export */   "TreeViewAlt16": () => (/* binding */ TreeViewAlt16),
/* harmony export */   "TreeViewAlt20": () => (/* binding */ TreeViewAlt20),
/* harmony export */   "TreeViewAlt24": () => (/* binding */ TreeViewAlt24),
/* harmony export */   "TreeViewAlt32": () => (/* binding */ TreeViewAlt32),
/* harmony export */   "Trophy16": () => (/* binding */ Trophy16),
/* harmony export */   "Trophy20": () => (/* binding */ Trophy20),
/* harmony export */   "Trophy24": () => (/* binding */ Trophy24),
/* harmony export */   "Trophy32": () => (/* binding */ Trophy32),
/* harmony export */   "TrophyFilled16": () => (/* binding */ TrophyFilled16),
/* harmony export */   "TrophyFilled20": () => (/* binding */ TrophyFilled20),
/* harmony export */   "TrophyFilled24": () => (/* binding */ TrophyFilled24),
/* harmony export */   "TrophyFilled32": () => (/* binding */ TrophyFilled32),
/* harmony export */   "TropicalStorm16": () => (/* binding */ TropicalStorm16),
/* harmony export */   "TropicalStorm20": () => (/* binding */ TropicalStorm20),
/* harmony export */   "TropicalStorm24": () => (/* binding */ TropicalStorm24),
/* harmony export */   "TropicalStorm32": () => (/* binding */ TropicalStorm32),
/* harmony export */   "TropicalStormModelTracks16": () => (/* binding */ TropicalStormModelTracks16),
/* harmony export */   "TropicalStormModelTracks20": () => (/* binding */ TropicalStormModelTracks20),
/* harmony export */   "TropicalStormModelTracks24": () => (/* binding */ TropicalStormModelTracks24),
/* harmony export */   "TropicalStormModelTracks32": () => (/* binding */ TropicalStormModelTracks32),
/* harmony export */   "TropicalStormTracks16": () => (/* binding */ TropicalStormTracks16),
/* harmony export */   "TropicalStormTracks20": () => (/* binding */ TropicalStormTracks20),
/* harmony export */   "TropicalStormTracks24": () => (/* binding */ TropicalStormTracks24),
/* harmony export */   "TropicalStormTracks32": () => (/* binding */ TropicalStormTracks32),
/* harmony export */   "TropicalWarning16": () => (/* binding */ TropicalWarning16),
/* harmony export */   "TropicalWarning20": () => (/* binding */ TropicalWarning20),
/* harmony export */   "TropicalWarning24": () => (/* binding */ TropicalWarning24),
/* harmony export */   "TropicalWarning32": () => (/* binding */ TropicalWarning32),
/* harmony export */   "Tsunami16": () => (/* binding */ Tsunami16),
/* harmony export */   "Tsunami20": () => (/* binding */ Tsunami20),
/* harmony export */   "Tsunami24": () => (/* binding */ Tsunami24),
/* harmony export */   "Tsunami32": () => (/* binding */ Tsunami32),
/* harmony export */   "Tsv16": () => (/* binding */ Tsv16),
/* harmony export */   "Tsv20": () => (/* binding */ Tsv20),
/* harmony export */   "Tsv24": () => (/* binding */ Tsv24),
/* harmony export */   "Tsv32": () => (/* binding */ Tsv32),
/* harmony export */   "TwoFactorAuthentication16": () => (/* binding */ TwoFactorAuthentication16),
/* harmony export */   "TwoFactorAuthentication20": () => (/* binding */ TwoFactorAuthentication20),
/* harmony export */   "TwoFactorAuthentication24": () => (/* binding */ TwoFactorAuthentication24),
/* harmony export */   "TwoFactorAuthentication32": () => (/* binding */ TwoFactorAuthentication32),
/* harmony export */   "TwoPersonLift16": () => (/* binding */ TwoPersonLift16),
/* harmony export */   "TwoPersonLift20": () => (/* binding */ TwoPersonLift20),
/* harmony export */   "TwoPersonLift24": () => (/* binding */ TwoPersonLift24),
/* harmony export */   "TwoPersonLift32": () => (/* binding */ TwoPersonLift32),
/* harmony export */   "Txt16": () => (/* binding */ Txt16),
/* harmony export */   "Txt20": () => (/* binding */ Txt20),
/* harmony export */   "Txt24": () => (/* binding */ Txt24),
/* harmony export */   "Txt32": () => (/* binding */ Txt32),
/* harmony export */   "TxtReference16": () => (/* binding */ TxtReference16),
/* harmony export */   "TxtReference20": () => (/* binding */ TxtReference20),
/* harmony export */   "TxtReference24": () => (/* binding */ TxtReference24),
/* harmony export */   "TxtReference32": () => (/* binding */ TxtReference32),
/* harmony export */   "TypePattern16": () => (/* binding */ TypePattern16),
/* harmony export */   "TypePattern20": () => (/* binding */ TypePattern20),
/* harmony export */   "TypePattern24": () => (/* binding */ TypePattern24),
/* harmony export */   "TypePattern32": () => (/* binding */ TypePattern32),
/* harmony export */   "Types16": () => (/* binding */ Types16),
/* harmony export */   "Types20": () => (/* binding */ Types20),
/* harmony export */   "Types24": () => (/* binding */ Types24),
/* harmony export */   "Types32": () => (/* binding */ Types32),
/* harmony export */   "Umbrella16": () => (/* binding */ Umbrella16),
/* harmony export */   "Umbrella20": () => (/* binding */ Umbrella20),
/* harmony export */   "Umbrella24": () => (/* binding */ Umbrella24),
/* harmony export */   "Umbrella32": () => (/* binding */ Umbrella32),
/* harmony export */   "Undefined16": () => (/* binding */ Undefined16),
/* harmony export */   "Undefined20": () => (/* binding */ Undefined20),
/* harmony export */   "Undefined24": () => (/* binding */ Undefined24),
/* harmony export */   "Undefined32": () => (/* binding */ Undefined32),
/* harmony export */   "UndefinedFilled16": () => (/* binding */ UndefinedFilled16),
/* harmony export */   "UndefinedFilled20": () => (/* binding */ UndefinedFilled20),
/* harmony export */   "UndefinedFilled24": () => (/* binding */ UndefinedFilled24),
/* harmony export */   "UndefinedFilled32": () => (/* binding */ UndefinedFilled32),
/* harmony export */   "UndefinedGlyph": () => (/* binding */ UndefinedGlyph),
/* harmony export */   "Undo16": () => (/* binding */ Undo16),
/* harmony export */   "Undo20": () => (/* binding */ Undo20),
/* harmony export */   "Undo24": () => (/* binding */ Undo24),
/* harmony export */   "Undo32": () => (/* binding */ Undo32),
/* harmony export */   "UngroupObjects16": () => (/* binding */ UngroupObjects16),
/* harmony export */   "UngroupObjects20": () => (/* binding */ UngroupObjects20),
/* harmony export */   "UngroupObjects24": () => (/* binding */ UngroupObjects24),
/* harmony export */   "UngroupObjects32": () => (/* binding */ UngroupObjects32),
/* harmony export */   "Unknown16": () => (/* binding */ Unknown16),
/* harmony export */   "Unknown20": () => (/* binding */ Unknown20),
/* harmony export */   "Unknown24": () => (/* binding */ Unknown24),
/* harmony export */   "Unknown32": () => (/* binding */ Unknown32),
/* harmony export */   "UnknownFilled16": () => (/* binding */ UnknownFilled16),
/* harmony export */   "UnknownFilled20": () => (/* binding */ UnknownFilled20),
/* harmony export */   "UnknownFilled24": () => (/* binding */ UnknownFilled24),
/* harmony export */   "UnknownFilled32": () => (/* binding */ UnknownFilled32),
/* harmony export */   "Unlink16": () => (/* binding */ Unlink16),
/* harmony export */   "Unlink20": () => (/* binding */ Unlink20),
/* harmony export */   "Unlink24": () => (/* binding */ Unlink24),
/* harmony export */   "Unlink32": () => (/* binding */ Unlink32),
/* harmony export */   "Unlocked16": () => (/* binding */ Unlocked16),
/* harmony export */   "Unlocked20": () => (/* binding */ Unlocked20),
/* harmony export */   "Unlocked24": () => (/* binding */ Unlocked24),
/* harmony export */   "Unlocked32": () => (/* binding */ Unlocked32),
/* harmony export */   "UpToTop16": () => (/* binding */ UpToTop16),
/* harmony export */   "UpToTop20": () => (/* binding */ UpToTop20),
/* harmony export */   "UpToTop24": () => (/* binding */ UpToTop24),
/* harmony export */   "UpToTop32": () => (/* binding */ UpToTop32),
/* harmony export */   "UpdateNow16": () => (/* binding */ UpdateNow16),
/* harmony export */   "UpdateNow20": () => (/* binding */ UpdateNow20),
/* harmony export */   "UpdateNow24": () => (/* binding */ UpdateNow24),
/* harmony export */   "UpdateNow32": () => (/* binding */ UpdateNow32),
/* harmony export */   "Upgrade16": () => (/* binding */ Upgrade16),
/* harmony export */   "Upgrade20": () => (/* binding */ Upgrade20),
/* harmony export */   "Upgrade24": () => (/* binding */ Upgrade24),
/* harmony export */   "Upgrade32": () => (/* binding */ Upgrade32),
/* harmony export */   "Upload16": () => (/* binding */ Upload16),
/* harmony export */   "Upload20": () => (/* binding */ Upload20),
/* harmony export */   "Upload24": () => (/* binding */ Upload24),
/* harmony export */   "Upload32": () => (/* binding */ Upload32),
/* harmony export */   "Usb16": () => (/* binding */ Usb16),
/* harmony export */   "Usb20": () => (/* binding */ Usb20),
/* harmony export */   "Usb24": () => (/* binding */ Usb24),
/* harmony export */   "Usb32": () => (/* binding */ Usb32),
/* harmony export */   "User16": () => (/* binding */ User16),
/* harmony export */   "User20": () => (/* binding */ User20),
/* harmony export */   "User24": () => (/* binding */ User24),
/* harmony export */   "User32": () => (/* binding */ User32),
/* harmony export */   "UserAccess16": () => (/* binding */ UserAccess16),
/* harmony export */   "UserAccess20": () => (/* binding */ UserAccess20),
/* harmony export */   "UserAccess24": () => (/* binding */ UserAccess24),
/* harmony export */   "UserAccess32": () => (/* binding */ UserAccess32),
/* harmony export */   "UserActivity16": () => (/* binding */ UserActivity16),
/* harmony export */   "UserActivity20": () => (/* binding */ UserActivity20),
/* harmony export */   "UserActivity24": () => (/* binding */ UserActivity24),
/* harmony export */   "UserActivity32": () => (/* binding */ UserActivity32),
/* harmony export */   "UserAdmin16": () => (/* binding */ UserAdmin16),
/* harmony export */   "UserAdmin20": () => (/* binding */ UserAdmin20),
/* harmony export */   "UserAdmin24": () => (/* binding */ UserAdmin24),
/* harmony export */   "UserAdmin32": () => (/* binding */ UserAdmin32),
/* harmony export */   "UserAvatar16": () => (/* binding */ UserAvatar16),
/* harmony export */   "UserAvatar20": () => (/* binding */ UserAvatar20),
/* harmony export */   "UserAvatar24": () => (/* binding */ UserAvatar24),
/* harmony export */   "UserAvatar32": () => (/* binding */ UserAvatar32),
/* harmony export */   "UserAvatarFilled16": () => (/* binding */ UserAvatarFilled16),
/* harmony export */   "UserAvatarFilled20": () => (/* binding */ UserAvatarFilled20),
/* harmony export */   "UserAvatarFilled24": () => (/* binding */ UserAvatarFilled24),
/* harmony export */   "UserAvatarFilled32": () => (/* binding */ UserAvatarFilled32),
/* harmony export */   "UserAvatarFilledAlt16": () => (/* binding */ UserAvatarFilledAlt16),
/* harmony export */   "UserAvatarFilledAlt20": () => (/* binding */ UserAvatarFilledAlt20),
/* harmony export */   "UserAvatarFilledAlt24": () => (/* binding */ UserAvatarFilledAlt24),
/* harmony export */   "UserAvatarFilledAlt32": () => (/* binding */ UserAvatarFilledAlt32),
/* harmony export */   "UserCertification16": () => (/* binding */ UserCertification16),
/* harmony export */   "UserCertification20": () => (/* binding */ UserCertification20),
/* harmony export */   "UserCertification24": () => (/* binding */ UserCertification24),
/* harmony export */   "UserCertification32": () => (/* binding */ UserCertification32),
/* harmony export */   "UserData16": () => (/* binding */ UserData16),
/* harmony export */   "UserData20": () => (/* binding */ UserData20),
/* harmony export */   "UserData24": () => (/* binding */ UserData24),
/* harmony export */   "UserData32": () => (/* binding */ UserData32),
/* harmony export */   "UserFavorite16": () => (/* binding */ UserFavorite16),
/* harmony export */   "UserFavorite20": () => (/* binding */ UserFavorite20),
/* harmony export */   "UserFavorite24": () => (/* binding */ UserFavorite24),
/* harmony export */   "UserFavorite32": () => (/* binding */ UserFavorite32),
/* harmony export */   "UserFavoriteAlt16": () => (/* binding */ UserFavoriteAlt16),
/* harmony export */   "UserFavoriteAlt20": () => (/* binding */ UserFavoriteAlt20),
/* harmony export */   "UserFavoriteAlt24": () => (/* binding */ UserFavoriteAlt24),
/* harmony export */   "UserFavoriteAlt32": () => (/* binding */ UserFavoriteAlt32),
/* harmony export */   "UserFavoriteAltFilled16": () => (/* binding */ UserFavoriteAltFilled16),
/* harmony export */   "UserFavoriteAltFilled20": () => (/* binding */ UserFavoriteAltFilled20),
/* harmony export */   "UserFavoriteAltFilled24": () => (/* binding */ UserFavoriteAltFilled24),
/* harmony export */   "UserFavoriteAltFilled32": () => (/* binding */ UserFavoriteAltFilled32),
/* harmony export */   "UserFilled16": () => (/* binding */ UserFilled16),
/* harmony export */   "UserFilled20": () => (/* binding */ UserFilled20),
/* harmony export */   "UserFilled24": () => (/* binding */ UserFilled24),
/* harmony export */   "UserFilled32": () => (/* binding */ UserFilled32),
/* harmony export */   "UserFollow16": () => (/* binding */ UserFollow16),
/* harmony export */   "UserFollow20": () => (/* binding */ UserFollow20),
/* harmony export */   "UserFollow24": () => (/* binding */ UserFollow24),
/* harmony export */   "UserFollow32": () => (/* binding */ UserFollow32),
/* harmony export */   "UserIdentification16": () => (/* binding */ UserIdentification16),
/* harmony export */   "UserIdentification20": () => (/* binding */ UserIdentification20),
/* harmony export */   "UserIdentification24": () => (/* binding */ UserIdentification24),
/* harmony export */   "UserIdentification32": () => (/* binding */ UserIdentification32),
/* harmony export */   "UserMilitary16": () => (/* binding */ UserMilitary16),
/* harmony export */   "UserMilitary20": () => (/* binding */ UserMilitary20),
/* harmony export */   "UserMilitary24": () => (/* binding */ UserMilitary24),
/* harmony export */   "UserMilitary32": () => (/* binding */ UserMilitary32),
/* harmony export */   "UserMultiple16": () => (/* binding */ UserMultiple16),
/* harmony export */   "UserMultiple20": () => (/* binding */ UserMultiple20),
/* harmony export */   "UserMultiple24": () => (/* binding */ UserMultiple24),
/* harmony export */   "UserMultiple32": () => (/* binding */ UserMultiple32),
/* harmony export */   "UserOnline16": () => (/* binding */ UserOnline16),
/* harmony export */   "UserOnline20": () => (/* binding */ UserOnline20),
/* harmony export */   "UserOnline24": () => (/* binding */ UserOnline24),
/* harmony export */   "UserOnline32": () => (/* binding */ UserOnline32),
/* harmony export */   "UserProfile16": () => (/* binding */ UserProfile16),
/* harmony export */   "UserProfile20": () => (/* binding */ UserProfile20),
/* harmony export */   "UserProfile24": () => (/* binding */ UserProfile24),
/* harmony export */   "UserProfile32": () => (/* binding */ UserProfile32),
/* harmony export */   "UserRole16": () => (/* binding */ UserRole16),
/* harmony export */   "UserRole20": () => (/* binding */ UserRole20),
/* harmony export */   "UserRole24": () => (/* binding */ UserRole24),
/* harmony export */   "UserRole32": () => (/* binding */ UserRole32),
/* harmony export */   "UserServiceDesk16": () => (/* binding */ UserServiceDesk16),
/* harmony export */   "UserServiceDesk20": () => (/* binding */ UserServiceDesk20),
/* harmony export */   "UserServiceDesk24": () => (/* binding */ UserServiceDesk24),
/* harmony export */   "UserServiceDesk32": () => (/* binding */ UserServiceDesk32),
/* harmony export */   "UserSettings16": () => (/* binding */ UserSettings16),
/* harmony export */   "UserSettings20": () => (/* binding */ UserSettings20),
/* harmony export */   "UserSettings24": () => (/* binding */ UserSettings24),
/* harmony export */   "UserSettings32": () => (/* binding */ UserSettings32),
/* harmony export */   "UserSimulation16": () => (/* binding */ UserSimulation16),
/* harmony export */   "UserSimulation20": () => (/* binding */ UserSimulation20),
/* harmony export */   "UserSimulation24": () => (/* binding */ UserSimulation24),
/* harmony export */   "UserSimulation32": () => (/* binding */ UserSimulation32),
/* harmony export */   "UserSpeaker16": () => (/* binding */ UserSpeaker16),
/* harmony export */   "UserSpeaker20": () => (/* binding */ UserSpeaker20),
/* harmony export */   "UserSpeaker24": () => (/* binding */ UserSpeaker24),
/* harmony export */   "UserSpeaker32": () => (/* binding */ UserSpeaker32),
/* harmony export */   "UserXRay16": () => (/* binding */ UserXRay16),
/* harmony export */   "UserXRay20": () => (/* binding */ UserXRay20),
/* harmony export */   "UserXRay24": () => (/* binding */ UserXRay24),
/* harmony export */   "UserXRay32": () => (/* binding */ UserXRay32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _path65, _path66, _path67, _path68, _path69, _path70, _path71, _path72, _path73, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _circle, _path185, _path186, _circle2, _path187, _path188, _circle3, _path189, _path190, _circle4, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _path224, _path225, _path226, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _circle5, _path314, _path315, _circle6, _path316, _path317, _circle7, _path318, _path319, _circle8, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _circle9, _path337, _circle10, _path338, _circle11, _path339, _circle12, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388, _path389, _path390, _path391, _path392, _path393, _path394, _path395, _path396, _path397, _path398, _path399, _path400;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var TransmissionLte16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TransmissionLte16(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.57 30l.9333-2h8.9928l.9333 2h2.2072L17 15.7778V11H15v4.7778L8.3631 30zM16 18.3647L17.6965 22h-3.393zM13.37 24h5.26l.9333 2H12.4369zM10.7832 9.3325a7.0007 7.0007 0 0110.4341 0l-1.49 1.334a5 5 0 00-7.4537 0z"
  })), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.1992,6.3994a11.0019,11.0019,0,0,1,17.6006,0L23.2,7.6a9.0009,9.0009,0,0,0-14.4014,0Z"
  })), children);
});
var Transpose32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Transpose32(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 26H14V24h5a5.0055 5.0055 0 005-5V14h2v5A7.0078 7.0078 0 0119 26zM8 30H4a2.0023 2.0023 0 01-2-2V14a2.0023 2.0023 0 012-2H8a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 018 30zM4 14V28H8V14zM28 10H14a2.0023 2.0023 0 01-2-2V4a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V8A2.0023 2.0023 0 0128 10zM14 4V8H28V4z"
  })), children);
});
var Transpose24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Transpose24(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 26H14V24h5a5.0055 5.0055 0 005-5V14h2v5A7.0078 7.0078 0 0119 26zM8 30H4a2.0023 2.0023 0 01-2-2V14a2.0023 2.0023 0 012-2H8a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 018 30zM4 14V28H8V14zM28 10H14a2.0023 2.0023 0 01-2-2V4a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V8A2.0023 2.0023 0 0128 10zM14 4V8H28V4z"
  })), children);
});
var Transpose20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Transpose20(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 26H14V24h5a5.0055 5.0055 0 005-5V14h2v5A7.0078 7.0078 0 0119 26zM8 30H4a2.0023 2.0023 0 01-2-2V14a2.0023 2.0023 0 012-2H8a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 018 30zM4 14V28H8V14zM28 10H14a2.0023 2.0023 0 01-2-2V4a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V8A2.0023 2.0023 0 0128 10zM14 4V8H28V4z"
  })), children);
});
var Transpose16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Transpose16(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 26H14V24h5a5.0055 5.0055 0 005-5V14h2v5A7.0078 7.0078 0 0119 26zM8 30H4a2.0023 2.0023 0 01-2-2V14a2.0023 2.0023 0 012-2H8a2.0023 2.0023 0 012 2V28A2.0023 2.0023 0 018 30zM4 14V28H8V14zM28 10H14a2.0023 2.0023 0 01-2-2V4a2.0023 2.0023 0 012-2H28a2.0023 2.0023 0 012 2V8A2.0023 2.0023 0 0128 10zM14 4V8H28V4z"
  })), children);
});
var TrashCan32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrashCan32(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 12H14V24H12zM18 12H20V24H18z"
  })), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 6V8H6V28a2 2 0 002 2H24a2 2 0 002-2V8h2V6zM8 28V8H24V28zM12 2H20V4H12z"
  })), children);
});
var TrashCan24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrashCan24(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 12H14V24H12zM18 12H20V24H18z"
  })), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 6V8H6V28a2 2 0 002 2H24a2 2 0 002-2V8h2V6zM8 28V8H24V28zM12 2H20V4H12z"
  })), children);
});
var TrashCan20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrashCan20(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 12H14V24H12zM18 12H20V24H18z"
  })), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 6V8H6V28a2 2 0 002 2H24a2 2 0 002-2V8h2V6zM8 28V8H24V28zM12 2H20V4H12z"
  })), children);
});
var TrashCan16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrashCan16(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 12H14V24H12zM18 12H20V24H18z"
  })), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 6V8H6V28a2 2 0 002 2H24a2 2 0 002-2V8h2V6zM8 28V8H24V28zM12 2H20V4H12z"
  })), children);
});
var Tree32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tree32(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H9V28h3V15.5664L8.4854,13.4575l1.0292-1.7148,3.5147,2.1084A2.0115,2.0115,0,0,1,14,15.5664V28A2.0023,2.0023,0,0,1,12,30Z"
  })), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,30H19a2.0024,2.0024,0,0,1-2-2V17h6a4.0008,4.0008,0,0,0,3.981-4.396A4.1489,4.1489,0,0,0,22.7853,9H21.2016L21.025,8.221C20.452,5.6961,18.0308,4,15,4A6.02,6.02,0,0,0,9.5585,7.4859L9.25,8.1531l-.863-.1143A2.771,2.771,0,0,0,8,8a4,4,0,1,0,0,8v2A6,6,0,1,1,8,6c.0264,0,.0525,0,.0786.001A8.0271,8.0271,0,0,1,15,2c3.6788,0,6.6923,1.9776,7.7516,5h.0337a6.1641,6.1641,0,0,1,6.1872,5.4141A6.0011,6.0011,0,0,1,23,19l-4,0v9h3Z"
  })), children);
});
var Tree24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tree24(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H9V28h3V15.5664L8.4854,13.4575l1.0292-1.7148,3.5147,2.1084A2.0115,2.0115,0,0,1,14,15.5664V28A2.0023,2.0023,0,0,1,12,30Z"
  })), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,30H19a2.0024,2.0024,0,0,1-2-2V17h6a4.0008,4.0008,0,0,0,3.981-4.396A4.1489,4.1489,0,0,0,22.7853,9H21.2016L21.025,8.221C20.452,5.6961,18.0308,4,15,4A6.02,6.02,0,0,0,9.5585,7.4859L9.25,8.1531l-.863-.1143A2.771,2.771,0,0,0,8,8a4,4,0,1,0,0,8v2A6,6,0,1,1,8,6c.0264,0,.0525,0,.0786.001A8.0271,8.0271,0,0,1,15,2c3.6788,0,6.6923,1.9776,7.7516,5h.0337a6.1641,6.1641,0,0,1,6.1872,5.4141A6.0011,6.0011,0,0,1,23,19l-4,0v9h3Z"
  })), children);
});
var Tree20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tree20(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H9V28h3V15.5664L8.4854,13.4575l1.0292-1.7148,3.5147,2.1084A2.0115,2.0115,0,0,1,14,15.5664V28A2.0023,2.0023,0,0,1,12,30Z"
  })), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,30H19a2.0024,2.0024,0,0,1-2-2V17h6a4.0008,4.0008,0,0,0,3.981-4.396A4.1489,4.1489,0,0,0,22.7853,9H21.2016L21.025,8.221C20.452,5.6961,18.0308,4,15,4A6.02,6.02,0,0,0,9.5585,7.4859L9.25,8.1531l-.863-.1143A2.771,2.771,0,0,0,8,8a4,4,0,1,0,0,8v2A6,6,0,1,1,8,6c.0264,0,.0525,0,.0786.001A8.0271,8.0271,0,0,1,15,2c3.6788,0,6.6923,1.9776,7.7516,5h.0337a6.1641,6.1641,0,0,1,6.1872,5.4141A6.0011,6.0011,0,0,1,23,19l-4,0v9h3Z"
  })), children);
});
var Tree16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tree16(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H9V28h3V15.5664L8.4854,13.4575l1.0292-1.7148,3.5147,2.1084A2.0115,2.0115,0,0,1,14,15.5664V28A2.0023,2.0023,0,0,1,12,30Z"
  })), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,30H19a2.0024,2.0024,0,0,1-2-2V17h6a4.0008,4.0008,0,0,0,3.981-4.396A4.1489,4.1489,0,0,0,22.7853,9H21.2016L21.025,8.221C20.452,5.6961,18.0308,4,15,4A6.02,6.02,0,0,0,9.5585,7.4859L9.25,8.1531l-.863-.1143A2.771,2.771,0,0,0,8,8a4,4,0,1,0,0,8v2A6,6,0,1,1,8,6c.0264,0,.0525,0,.0786.001A8.0271,8.0271,0,0,1,15,2c3.6788,0,6.6923,1.9776,7.7516,5h.0337a6.1641,6.1641,0,0,1,6.1872,5.4141A6.0011,6.0011,0,0,1,23,19l-4,0v9h3Z"
  })), children);
});
var TreeFallRisk32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TreeFallRisk32(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,10h-1.5V6h1.5ZM23,11a1,1,0,1,0,1,1A1,1,0,0,0,23,11Z",
    "data-icon-path": "inner-path"
  })), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115 13.9355L23.6284 2.3706a.7181.7181 0 00-1.2568 0L16.0885 13.9355A.72.72 0 0016.72 15H29.28A.72.72 0 0029.9115 13.9355zM22.25 6h1.5v4h-1.5zM23 13a1 1 0 111-1A1 1 0 0123 13zM26 19V17H17V28a2.0027 2.0027 0 002 2h3V28H19V19zM12 30H9V28h3V15.5664L8.4854 13.4575l1.0292-1.7148 3.5147 2.1084A2.0115 2.0115 0 0114 15.5664V28A2.0024 2.0024 0 0112 30z"
  })), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.6638,5.0059l.96-1.7671A8.9324,8.9324,0,0,0,15,2,8.0275,8.0275,0,0,0,8.0786,6.001C8.0525,6,8.0264,6,8,6A6,6,0,0,0,8,18V16A4,4,0,0,1,8,8a2.7009,2.7009,0,0,1,.387.0391l.863.1142.3086-.6675A6.0192,6.0192,0,0,1,15,4,6.8916,6.8916,0,0,1,18.6638,5.0059Z"
  })), children);
});
var TreeFallRisk24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TreeFallRisk24(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,10h-1.5V6h1.5ZM23,11a1,1,0,1,0,1,1A1,1,0,0,0,23,11Z",
    "data-icon-path": "inner-path"
  })), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115 13.9355L23.6284 2.3706a.7181.7181 0 00-1.2568 0L16.0885 13.9355A.72.72 0 0016.72 15H29.28A.72.72 0 0029.9115 13.9355zM22.25 6h1.5v4h-1.5zM23 13a1 1 0 111-1A1 1 0 0123 13zM26 19V17H17V28a2.0027 2.0027 0 002 2h3V28H19V19zM12 30H9V28h3V15.5664L8.4854 13.4575l1.0292-1.7148 3.5147 2.1084A2.0115 2.0115 0 0114 15.5664V28A2.0024 2.0024 0 0112 30z"
  })), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.6638,5.0059l.96-1.7671A8.9324,8.9324,0,0,0,15,2,8.0275,8.0275,0,0,0,8.0786,6.001C8.0525,6,8.0264,6,8,6A6,6,0,0,0,8,18V16A4,4,0,0,1,8,8a2.7009,2.7009,0,0,1,.387.0391l.863.1142.3086-.6675A6.0192,6.0192,0,0,1,15,4,6.8916,6.8916,0,0,1,18.6638,5.0059Z"
  })), children);
});
var TreeFallRisk20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TreeFallRisk20(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,10h-1.5V6h1.5ZM23,11a1,1,0,1,0,1,1A1,1,0,0,0,23,11Z",
    "data-icon-path": "inner-path"
  })), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115 13.9355L23.6284 2.3706a.7181.7181 0 00-1.2568 0L16.0885 13.9355A.72.72 0 0016.72 15H29.28A.72.72 0 0029.9115 13.9355zM22.25 6h1.5v4h-1.5zM23 13a1 1 0 111-1A1 1 0 0123 13zM26 19V17H17V28a2.0027 2.0027 0 002 2h3V28H19V19zM12 30H9V28h3V15.5664L8.4854 13.4575l1.0292-1.7148 3.5147 2.1084A2.0115 2.0115 0 0114 15.5664V28A2.0024 2.0024 0 0112 30z"
  })), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.6638,5.0059l.96-1.7671A8.9324,8.9324,0,0,0,15,2,8.0275,8.0275,0,0,0,8.0786,6.001C8.0525,6,8.0264,6,8,6A6,6,0,0,0,8,18V16A4,4,0,0,1,8,8a2.7009,2.7009,0,0,1,.387.0391l.863.1142.3086-.6675A6.0192,6.0192,0,0,1,15,4,6.8916,6.8916,0,0,1,18.6638,5.0059Z"
  })), children);
});
var TreeFallRisk16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TreeFallRisk16(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,10h-1.5V6h1.5ZM23,11a1,1,0,1,0,1,1A1,1,0,0,0,23,11Z",
    "data-icon-path": "inner-path"
  })), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115 13.9355L23.6284 2.3706a.7181.7181 0 00-1.2568 0L16.0885 13.9355A.72.72 0 0016.72 15H29.28A.72.72 0 0029.9115 13.9355zM22.25 6h1.5v4h-1.5zM23 13a1 1 0 111-1A1 1 0 0123 13zM26 19V17H17V28a2.0027 2.0027 0 002 2h3V28H19V19zM12 30H9V28h3V15.5664L8.4854 13.4575l1.0292-1.7148 3.5147 2.1084A2.0115 2.0115 0 0114 15.5664V28A2.0024 2.0024 0 0112 30z"
  })), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.6638,5.0059l.96-1.7671A8.9324,8.9324,0,0,0,15,2,8.0275,8.0275,0,0,0,8.0786,6.001C8.0525,6,8.0264,6,8,6A6,6,0,0,0,8,18V16A4,4,0,0,1,8,8a2.7009,2.7009,0,0,1,.387.0391l.863.1142.3086-.6675A6.0192,6.0192,0,0,1,15,4,6.8916,6.8916,0,0,1,18.6638,5.0059Z"
  })), children);
});
var TreeView32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TreeView32(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,20V12H22v3H17V7a2,2,0,0,0-2-2H10V2H2v8h8V7h5V25a2,2,0,0,0,2,2h5v3h8V22H22v3H17V17h5v3ZM8,8H4V4H8ZM24,24h4v4H24Zm0-10h4v4H24Z"
  })), children);
});
var TreeView24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TreeView24(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,20V12H22v3H17V7a2,2,0,0,0-2-2H10V2H2v8h8V7h5V25a2,2,0,0,0,2,2h5v3h8V22H22v3H17V17h5v3ZM8,8H4V4H8ZM24,24h4v4H24Zm0-10h4v4H24Z"
  })), children);
});
var TreeView20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TreeView20(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,20V12H22v3H17V7a2,2,0,0,0-2-2H10V2H2v8h8V7h5V25a2,2,0,0,0,2,2h5v3h8V22H22v3H17V17h5v3ZM8,8H4V4H8ZM24,24h4v4H24Zm0-10h4v4H24Z"
  })), children);
});
var TreeView16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TreeView16(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,20V12H22v3H17V7a2,2,0,0,0-2-2H10V2H2v8h8V7h5V25a2,2,0,0,0,2,2h5v3h8V22H22v3H17V17h5v3ZM8,8H4V4H8ZM24,24h4v4H24Zm0-10h4v4H24Z"
  })), children);
});
var TreeViewAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TreeViewAlt32(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,9h6a2,2,0,0,0,2-2V3a2,2,0,0,0-2-2H23a2,2,0,0,0-2,2V4H11V3A2,2,0,0,0,9,1H3A2,2,0,0,0,1,3V7A2,2,0,0,0,3,9H9a2,2,0,0,0,2-2V6h4V26a2.0023,2.0023,0,0,0,2,2h4v1a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V25a2,2,0,0,0-2-2H23a2,2,0,0,0-2,2v1H17V17h4v1a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V14a2,2,0,0,0-2-2H23a2,2,0,0,0-2,2v1H17V6h4V7A2,2,0,0,0,23,9Zm0-6h6V7H23ZM9,7H3V3H9ZM23,25h6v4H23Zm0-11h6v4H23Z",
    transform: "translate(0 .005)"
  })), children);
});
var TreeViewAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TreeViewAlt24(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,9h6a2,2,0,0,0,2-2V3a2,2,0,0,0-2-2H23a2,2,0,0,0-2,2V4H11V3A2,2,0,0,0,9,1H3A2,2,0,0,0,1,3V7A2,2,0,0,0,3,9H9a2,2,0,0,0,2-2V6h4V26a2.0023,2.0023,0,0,0,2,2h4v1a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V25a2,2,0,0,0-2-2H23a2,2,0,0,0-2,2v1H17V17h4v1a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V14a2,2,0,0,0-2-2H23a2,2,0,0,0-2,2v1H17V6h4V7A2,2,0,0,0,23,9Zm0-6h6V7H23ZM9,7H3V3H9ZM23,25h6v4H23Zm0-11h6v4H23Z",
    transform: "translate(0 .005)"
  })), children);
});
var TreeViewAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TreeViewAlt20(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,9h6a2,2,0,0,0,2-2V3a2,2,0,0,0-2-2H23a2,2,0,0,0-2,2V4H11V3A2,2,0,0,0,9,1H3A2,2,0,0,0,1,3V7A2,2,0,0,0,3,9H9a2,2,0,0,0,2-2V6h4V26a2.0023,2.0023,0,0,0,2,2h4v1a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V25a2,2,0,0,0-2-2H23a2,2,0,0,0-2,2v1H17V17h4v1a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V14a2,2,0,0,0-2-2H23a2,2,0,0,0-2,2v1H17V6h4V7A2,2,0,0,0,23,9Zm0-6h6V7H23ZM9,7H3V3H9ZM23,25h6v4H23Zm0-11h6v4H23Z",
    transform: "translate(0 .005)"
  })), children);
});
var TreeViewAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TreeViewAlt16(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,9h6a2,2,0,0,0,2-2V3a2,2,0,0,0-2-2H23a2,2,0,0,0-2,2V4H11V3A2,2,0,0,0,9,1H3A2,2,0,0,0,1,3V7A2,2,0,0,0,3,9H9a2,2,0,0,0,2-2V6h4V26a2.0023,2.0023,0,0,0,2,2h4v1a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V25a2,2,0,0,0-2-2H23a2,2,0,0,0-2,2v1H17V17h4v1a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V14a2,2,0,0,0-2-2H23a2,2,0,0,0-2,2v1H17V6h4V7A2,2,0,0,0,23,9Zm0-6h6V7H23ZM9,7H3V3H9ZM23,25h6v4H23Zm0-11h6v4H23Z",
    transform: "translate(0 .005)"
  })), children);
});
var Trophy32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Trophy32(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,7H24V6a2.0023,2.0023,0,0,0-2-2H10A2.0023,2.0023,0,0,0,8,6V7H6A2.0023,2.0023,0,0,0,4,9v3a4.0045,4.0045,0,0,0,4,4h.322A8.1689,8.1689,0,0,0,15,21.9341V26H10v2H22V26H17V21.9311A7.9661,7.9661,0,0,0,23.74,16H24a4.0045,4.0045,0,0,0,4-4V9A2.0023,2.0023,0,0,0,26,7ZM8,14a2.0023,2.0023,0,0,1-2-2V9H8Zm14,0a6,6,0,0,1-6.1855,5.9971A6.1991,6.1991,0,0,1,10,13.7065V6H22Zm4-2a2.0023,2.0023,0,0,1-2,2V9h2Z"
  })), children);
});
var Trophy24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Trophy24(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,7H24V6a2.0023,2.0023,0,0,0-2-2H10A2.0023,2.0023,0,0,0,8,6V7H6A2.0023,2.0023,0,0,0,4,9v3a4.0045,4.0045,0,0,0,4,4h.322A8.1689,8.1689,0,0,0,15,21.9341V26H10v2H22V26H17V21.9311A7.9661,7.9661,0,0,0,23.74,16H24a4.0045,4.0045,0,0,0,4-4V9A2.0023,2.0023,0,0,0,26,7ZM8,14a2.0023,2.0023,0,0,1-2-2V9H8Zm14,0a6,6,0,0,1-6.1855,5.9971A6.1991,6.1991,0,0,1,10,13.7065V6H22Zm4-2a2.0023,2.0023,0,0,1-2,2V9h2Z"
  })), children);
});
var Trophy20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Trophy20(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,7H24V6a2.0023,2.0023,0,0,0-2-2H10A2.0023,2.0023,0,0,0,8,6V7H6A2.0023,2.0023,0,0,0,4,9v3a4.0045,4.0045,0,0,0,4,4h.322A8.1689,8.1689,0,0,0,15,21.9341V26H10v2H22V26H17V21.9311A7.9661,7.9661,0,0,0,23.74,16H24a4.0045,4.0045,0,0,0,4-4V9A2.0023,2.0023,0,0,0,26,7ZM8,14a2.0023,2.0023,0,0,1-2-2V9H8Zm14,0a6,6,0,0,1-6.1855,5.9971A6.1991,6.1991,0,0,1,10,13.7065V6H22Zm4-2a2.0023,2.0023,0,0,1-2,2V9h2Z"
  })), children);
});
var Trophy16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Trophy16(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,7H24V6a2.0023,2.0023,0,0,0-2-2H10A2.0023,2.0023,0,0,0,8,6V7H6A2.0023,2.0023,0,0,0,4,9v3a4.0045,4.0045,0,0,0,4,4h.322A8.1689,8.1689,0,0,0,15,21.9341V26H10v2H22V26H17V21.9311A7.9661,7.9661,0,0,0,23.74,16H24a4.0045,4.0045,0,0,0,4-4V9A2.0023,2.0023,0,0,0,26,7ZM8,14a2.0023,2.0023,0,0,1-2-2V9H8Zm14,0a6,6,0,0,1-6.1855,5.9971A6.1991,6.1991,0,0,1,10,13.7065V6H22Zm4-2a2.0023,2.0023,0,0,1-2,2V9h2Z"
  })), children);
});
var TrophyFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrophyFilled32(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,7H24V6a2.0023,2.0023,0,0,0-2-2H10A2.0023,2.0023,0,0,0,8,6V7H6A2.0023,2.0023,0,0,0,4,9v3a4.0045,4.0045,0,0,0,4,4h.322A8.1689,8.1689,0,0,0,15,21.9341V26H10v2H22V26H17V21.9311A7.9661,7.9661,0,0,0,23.74,16H24a4.0045,4.0045,0,0,0,4-4V9A2.0023,2.0023,0,0,0,26,7ZM8,14a2.0023,2.0023,0,0,1-2-2V9H8Zm18-2a2.0023,2.0023,0,0,1-2,2V9h2Z"
  })), children);
});
var TrophyFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrophyFilled24(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,7H24V6a2.0023,2.0023,0,0,0-2-2H10A2.0023,2.0023,0,0,0,8,6V7H6A2.0023,2.0023,0,0,0,4,9v3a4.0045,4.0045,0,0,0,4,4h.322A8.1689,8.1689,0,0,0,15,21.9341V26H10v2H22V26H17V21.9311A7.9661,7.9661,0,0,0,23.74,16H24a4.0045,4.0045,0,0,0,4-4V9A2.0023,2.0023,0,0,0,26,7ZM8,14a2.0023,2.0023,0,0,1-2-2V9H8Zm18-2a2.0023,2.0023,0,0,1-2,2V9h2Z"
  })), children);
});
var TrophyFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrophyFilled20(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,7H24V6a2.0023,2.0023,0,0,0-2-2H10A2.0023,2.0023,0,0,0,8,6V7H6A2.0023,2.0023,0,0,0,4,9v3a4.0045,4.0045,0,0,0,4,4h.322A8.1689,8.1689,0,0,0,15,21.9341V26H10v2H22V26H17V21.9311A7.9661,7.9661,0,0,0,23.74,16H24a4.0045,4.0045,0,0,0,4-4V9A2.0023,2.0023,0,0,0,26,7ZM8,14a2.0023,2.0023,0,0,1-2-2V9H8Zm18-2a2.0023,2.0023,0,0,1-2,2V9h2Z"
  })), children);
});
var TrophyFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TrophyFilled16(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,7H24V6a2.0023,2.0023,0,0,0-2-2H10A2.0023,2.0023,0,0,0,8,6V7H6A2.0023,2.0023,0,0,0,4,9v3a4.0045,4.0045,0,0,0,4,4h.322A8.1689,8.1689,0,0,0,15,21.9341V26H10v2H22V26H17V21.9311A7.9661,7.9661,0,0,0,23.74,16H24a4.0045,4.0045,0,0,0,4-4V9A2.0023,2.0023,0,0,0,26,7ZM8,14a2.0023,2.0023,0,0,1-2-2V9H8Zm18-2a2.0023,2.0023,0,0,1-2,2V9h2Z"
  })), children);
});
var TropicalStorm32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TropicalStorm32(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,21a5,5,0,1,1,5-5A5.0057,5.0057,0,0,1,16,21Zm0-8a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,16,13Z"
  })), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.6521,4.1821l-2.177,2.5142L19.0713,8.3174,20.7864,9.605A7.9361,7.9361,0,0,1,23.9963,16l.0008.0576.0017.0415c.018.4317.2412,10.1113-14.6538,11.7222l2.18-2.5176,1.4039-1.6211L11.2139,22.395A7.9361,7.9361,0,0,1,8.0037,16l-.0008-.0576-.0017-.0415C7.9832,15.47,7.7605,5.8071,22.6521,4.1821M24.9978,2c-.0164,0-.0327,0-.0493.001C5.2532,2.9146,6.0037,16,6.0037,16a9.975,9.975,0,0,0,4.0095,7.9946L6.2368,28.3555A1.0044,1.0044,0,0,0,7.0022,30c.0164,0,.0327,0,.0493-.001C26.7468,29.0854,25.9963,16,25.9963,16a9.9756,9.9756,0,0,0-4.0092-7.9946l3.7761-4.3609A1.0044,1.0044,0,0,0,24.9978,2Z"
  })), children);
});
var TropicalStorm24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TropicalStorm24(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,21a5,5,0,1,1,5-5A5.0057,5.0057,0,0,1,16,21Zm0-8a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,16,13Z"
  })), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.6521,4.1821l-2.177,2.5142L19.0713,8.3174,20.7864,9.605A7.9361,7.9361,0,0,1,23.9963,16l.0008.0576.0017.0415c.018.4317.2412,10.1113-14.6538,11.7222l2.18-2.5176,1.4039-1.6211L11.2139,22.395A7.9361,7.9361,0,0,1,8.0037,16l-.0008-.0576-.0017-.0415C7.9832,15.47,7.7605,5.8071,22.6521,4.1821M24.9978,2c-.0164,0-.0327,0-.0493.001C5.2532,2.9146,6.0037,16,6.0037,16a9.975,9.975,0,0,0,4.0095,7.9946L6.2368,28.3555A1.0044,1.0044,0,0,0,7.0022,30c.0164,0,.0327,0,.0493-.001C26.7468,29.0854,25.9963,16,25.9963,16a9.9756,9.9756,0,0,0-4.0092-7.9946l3.7761-4.3609A1.0044,1.0044,0,0,0,24.9978,2Z"
  })), children);
});
var TropicalStorm20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TropicalStorm20(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,21a5,5,0,1,1,5-5A5.0057,5.0057,0,0,1,16,21Zm0-8a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,16,13Z"
  })), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.6521,4.1821l-2.177,2.5142L19.0713,8.3174,20.7864,9.605A7.9361,7.9361,0,0,1,23.9963,16l.0008.0576.0017.0415c.018.4317.2412,10.1113-14.6538,11.7222l2.18-2.5176,1.4039-1.6211L11.2139,22.395A7.9361,7.9361,0,0,1,8.0037,16l-.0008-.0576-.0017-.0415C7.9832,15.47,7.7605,5.8071,22.6521,4.1821M24.9978,2c-.0164,0-.0327,0-.0493.001C5.2532,2.9146,6.0037,16,6.0037,16a9.975,9.975,0,0,0,4.0095,7.9946L6.2368,28.3555A1.0044,1.0044,0,0,0,7.0022,30c.0164,0,.0327,0,.0493-.001C26.7468,29.0854,25.9963,16,25.9963,16a9.9756,9.9756,0,0,0-4.0092-7.9946l3.7761-4.3609A1.0044,1.0044,0,0,0,24.9978,2Z"
  })), children);
});
var TropicalStorm16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TropicalStorm16(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,21a5,5,0,1,1,5-5A5.0057,5.0057,0,0,1,16,21Zm0-8a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,16,13Z"
  })), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.6521,4.1821l-2.177,2.5142L19.0713,8.3174,20.7864,9.605A7.9361,7.9361,0,0,1,23.9963,16l.0008.0576.0017.0415c.018.4317.2412,10.1113-14.6538,11.7222l2.18-2.5176,1.4039-1.6211L11.2139,22.395A7.9361,7.9361,0,0,1,8.0037,16l-.0008-.0576-.0017-.0415C7.9832,15.47,7.7605,5.8071,22.6521,4.1821M24.9978,2c-.0164,0-.0327,0-.0493.001C5.2532,2.9146,6.0037,16,6.0037,16a9.975,9.975,0,0,0,4.0095,7.9946L6.2368,28.3555A1.0044,1.0044,0,0,0,7.0022,30c.0164,0,.0327,0,.0493-.001C26.7468,29.0854,25.9963,16,25.9963,16a9.9756,9.9756,0,0,0-4.0092-7.9946l3.7761-4.3609A1.0044,1.0044,0,0,0,24.9978,2Z"
  })), children);
});
var TropicalStormModelTracks32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TropicalStormModelTracks32(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,17a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,10,17Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,10,11Z"
  })), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.8188 6.65c.1163-.1211 1.8643-1.919 2.8882-2.9434A1 1 0 0017 2C11.812 2 2 4.2988 2 13a7.8938 7.8938 0 003.1812 6.35c-.1612.1675-1.9507 2.0054-2.8882 2.9429A1 1 0 003 24c5.188 0 15-2.2988 15-11A7.8927 7.8927 0 0014.8188 6.65zM9.7065 20.793a20.94 20.94 0 01-4.0932.9853c.1621-.166 2.7685-2.9053 2.7685-2.9053l-1.1743-.6074A5.9064 5.9064 0 014 13c0-3.667 2.1177-6.2886 6.2935-7.793a20.94 20.94 0 014.0932-.9853c-.227.2324-2.769 2.9057-2.769 2.9057l1.1748.607A5.9075 5.9075 0 0116 13C16 16.667 13.8823 19.2886 9.7065 20.793zM30 17l-5-5-5 5 1.4126 1.4155L24 15.8325V19a9.01 9.01 0 01-9 9H12v2h3A11.0125 11.0125 0 0026 19V15.8325l2.5859 2.5816z"
  })), children);
});
var TropicalStormModelTracks24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TropicalStormModelTracks24(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,17a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,10,17Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,10,11Z"
  })), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.8188 6.65c.1163-.1211 1.8643-1.919 2.8882-2.9434A1 1 0 0017 2C11.812 2 2 4.2988 2 13a7.8938 7.8938 0 003.1812 6.35c-.1612.1675-1.9507 2.0054-2.8882 2.9429A1 1 0 003 24c5.188 0 15-2.2988 15-11A7.8927 7.8927 0 0014.8188 6.65zM9.7065 20.793a20.94 20.94 0 01-4.0932.9853c.1621-.166 2.7685-2.9053 2.7685-2.9053l-1.1743-.6074A5.9064 5.9064 0 014 13c0-3.667 2.1177-6.2886 6.2935-7.793a20.94 20.94 0 014.0932-.9853c-.227.2324-2.769 2.9057-2.769 2.9057l1.1748.607A5.9075 5.9075 0 0116 13C16 16.667 13.8823 19.2886 9.7065 20.793zM30 17l-5-5-5 5 1.4126 1.4155L24 15.8325V19a9.01 9.01 0 01-9 9H12v2h3A11.0125 11.0125 0 0026 19V15.8325l2.5859 2.5816z"
  })), children);
});
var TropicalStormModelTracks20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TropicalStormModelTracks20(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,17a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,10,17Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,10,11Z"
  })), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.8188 6.65c.1163-.1211 1.8643-1.919 2.8882-2.9434A1 1 0 0017 2C11.812 2 2 4.2988 2 13a7.8938 7.8938 0 003.1812 6.35c-.1612.1675-1.9507 2.0054-2.8882 2.9429A1 1 0 003 24c5.188 0 15-2.2988 15-11A7.8927 7.8927 0 0014.8188 6.65zM9.7065 20.793a20.94 20.94 0 01-4.0932.9853c.1621-.166 2.7685-2.9053 2.7685-2.9053l-1.1743-.6074A5.9064 5.9064 0 014 13c0-3.667 2.1177-6.2886 6.2935-7.793a20.94 20.94 0 014.0932-.9853c-.227.2324-2.769 2.9057-2.769 2.9057l1.1748.607A5.9075 5.9075 0 0116 13C16 16.667 13.8823 19.2886 9.7065 20.793zM30 17l-5-5-5 5 1.4126 1.4155L24 15.8325V19a9.01 9.01 0 01-9 9H12v2h3A11.0125 11.0125 0 0026 19V15.8325l2.5859 2.5816z"
  })), children);
});
var TropicalStormModelTracks16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TropicalStormModelTracks16(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,17a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,10,17Zm0-6a2,2,0,1,0,2,2A2.0021,2.0021,0,0,0,10,11Z"
  })), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.8188 6.65c.1163-.1211 1.8643-1.919 2.8882-2.9434A1 1 0 0017 2C11.812 2 2 4.2988 2 13a7.8938 7.8938 0 003.1812 6.35c-.1612.1675-1.9507 2.0054-2.8882 2.9429A1 1 0 003 24c5.188 0 15-2.2988 15-11A7.8927 7.8927 0 0014.8188 6.65zM9.7065 20.793a20.94 20.94 0 01-4.0932.9853c.1621-.166 2.7685-2.9053 2.7685-2.9053l-1.1743-.6074A5.9064 5.9064 0 014 13c0-3.667 2.1177-6.2886 6.2935-7.793a20.94 20.94 0 014.0932-.9853c-.227.2324-2.769 2.9057-2.769 2.9057l1.1748.607A5.9075 5.9075 0 0116 13C16 16.667 13.8823 19.2886 9.7065 20.793zM30 17l-5-5-5 5 1.4126 1.4155L24 15.8325V19a9.01 9.01 0 01-9 9H12v2h3A11.0125 11.0125 0 0026 19V15.8325l2.5859 2.5816z"
  })), children);
});
var TropicalStormTracks32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TropicalStormTracks32(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,21a5,5,0,1,1,5-5A5.0057,5.0057,0,0,1,16,21Zm0-8a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,16,13Z"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.86,12.4805h0a12.9277,12.9277,0,0,0-4.8575-4.9991q.2044-.213.4424-.4589h0c.82-.8482,1.93-1.9825,3.2622-3.3155A1,1,0,0,0,25,2c-.354,0-8.7363.0488-14.269,4.3018h0A12.15,12.15,0,0,0,7.481,9.998c-.1416-.1367-.295-.2841-.4585-.4423C6.1743,8.7349,5.04,7.6255,3.707,6.293A1,1,0,0,0,2,7c0,.3594.05,8.874,4.4058,14.4023a12.1023,12.1023,0,0,0,3.5918,3.1163c-.21.2177-.4346.4516-.6563.68h0c-.7954.8208-1.8286,1.8745-3.0483,3.0943A1,1,0,0,0,7,30c.2856,0,7.061-.0352,12.459-3.1055a12.9618,12.9618,0,0,0,5.06-4.8925q.3062.2937.68.6567c.82.7954,1.8745,1.8286,3.0943,3.0483A1,1,0,0,0,30,25C30,24.7119,29.9644,17.8877,26.86,12.4805Zm-3.03,6.1074-.5469,1.3672A10.5415,10.5415,0,0,1,18.47,25.1562,24.3514,24.3514,0,0,1,9.584,27.8135c.4409-.4492,3.8281-3.9824,3.8281-3.9824l-1.3682-.5474a9.8021,9.8021,0,0,1-4.0668-3.1191c-2.5406-3.2242-3.4585-7.7623-3.79-10.58.5435.5337,3.9815,3.8266,3.9815,3.8266l.5468-1.3672A9.8569,9.8569,0,0,1,11.95,7.8877h0C15.1665,5.415,19.6309,4.5146,22.4155,4.187c-.5332.5435-3.8276,3.9819-3.8276,3.9819l1.3677.5469a10.52,10.52,0,0,1,5.17,4.7608v0a24.29,24.29,0,0,1,2.688,8.94C27.3643,21.9751,23.83,18.5879,23.83,18.5879Z"
  })), children);
});
var TropicalStormTracks24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TropicalStormTracks24(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,21a5,5,0,1,1,5-5A5.0057,5.0057,0,0,1,16,21Zm0-8a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,16,13Z"
  })), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.86,12.4805h0a12.9277,12.9277,0,0,0-4.8575-4.9991q.2044-.213.4424-.4589h0c.82-.8482,1.93-1.9825,3.2622-3.3155A1,1,0,0,0,25,2c-.354,0-8.7363.0488-14.269,4.3018h0A12.15,12.15,0,0,0,7.481,9.998c-.1416-.1367-.295-.2841-.4585-.4423C6.1743,8.7349,5.04,7.6255,3.707,6.293A1,1,0,0,0,2,7c0,.3594.05,8.874,4.4058,14.4023a12.1023,12.1023,0,0,0,3.5918,3.1163c-.21.2177-.4346.4516-.6563.68h0c-.7954.8208-1.8286,1.8745-3.0483,3.0943A1,1,0,0,0,7,30c.2856,0,7.061-.0352,12.459-3.1055a12.9618,12.9618,0,0,0,5.06-4.8925q.3062.2937.68.6567c.82.7954,1.8745,1.8286,3.0943,3.0483A1,1,0,0,0,30,25C30,24.7119,29.9644,17.8877,26.86,12.4805Zm-3.03,6.1074-.5469,1.3672A10.5415,10.5415,0,0,1,18.47,25.1562,24.3514,24.3514,0,0,1,9.584,27.8135c.4409-.4492,3.8281-3.9824,3.8281-3.9824l-1.3682-.5474a9.8021,9.8021,0,0,1-4.0668-3.1191c-2.5406-3.2242-3.4585-7.7623-3.79-10.58.5435.5337,3.9815,3.8266,3.9815,3.8266l.5468-1.3672A9.8569,9.8569,0,0,1,11.95,7.8877h0C15.1665,5.415,19.6309,4.5146,22.4155,4.187c-.5332.5435-3.8276,3.9819-3.8276,3.9819l1.3677.5469a10.52,10.52,0,0,1,5.17,4.7608v0a24.29,24.29,0,0,1,2.688,8.94C27.3643,21.9751,23.83,18.5879,23.83,18.5879Z"
  })), children);
});
var TropicalStormTracks20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TropicalStormTracks20(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,21a5,5,0,1,1,5-5A5.0057,5.0057,0,0,1,16,21Zm0-8a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,16,13Z"
  })), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.86,12.4805h0a12.9277,12.9277,0,0,0-4.8575-4.9991q.2044-.213.4424-.4589h0c.82-.8482,1.93-1.9825,3.2622-3.3155A1,1,0,0,0,25,2c-.354,0-8.7363.0488-14.269,4.3018h0A12.15,12.15,0,0,0,7.481,9.998c-.1416-.1367-.295-.2841-.4585-.4423C6.1743,8.7349,5.04,7.6255,3.707,6.293A1,1,0,0,0,2,7c0,.3594.05,8.874,4.4058,14.4023a12.1023,12.1023,0,0,0,3.5918,3.1163c-.21.2177-.4346.4516-.6563.68h0c-.7954.8208-1.8286,1.8745-3.0483,3.0943A1,1,0,0,0,7,30c.2856,0,7.061-.0352,12.459-3.1055a12.9618,12.9618,0,0,0,5.06-4.8925q.3062.2937.68.6567c.82.7954,1.8745,1.8286,3.0943,3.0483A1,1,0,0,0,30,25C30,24.7119,29.9644,17.8877,26.86,12.4805Zm-3.03,6.1074-.5469,1.3672A10.5415,10.5415,0,0,1,18.47,25.1562,24.3514,24.3514,0,0,1,9.584,27.8135c.4409-.4492,3.8281-3.9824,3.8281-3.9824l-1.3682-.5474a9.8021,9.8021,0,0,1-4.0668-3.1191c-2.5406-3.2242-3.4585-7.7623-3.79-10.58.5435.5337,3.9815,3.8266,3.9815,3.8266l.5468-1.3672A9.8569,9.8569,0,0,1,11.95,7.8877h0C15.1665,5.415,19.6309,4.5146,22.4155,4.187c-.5332.5435-3.8276,3.9819-3.8276,3.9819l1.3677.5469a10.52,10.52,0,0,1,5.17,4.7608v0a24.29,24.29,0,0,1,2.688,8.94C27.3643,21.9751,23.83,18.5879,23.83,18.5879Z"
  })), children);
});
var TropicalStormTracks16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TropicalStormTracks16(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,21a5,5,0,1,1,5-5A5.0057,5.0057,0,0,1,16,21Zm0-8a3,3,0,1,0,3,3A3.0033,3.0033,0,0,0,16,13Z"
  })), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.86,12.4805h0a12.9277,12.9277,0,0,0-4.8575-4.9991q.2044-.213.4424-.4589h0c.82-.8482,1.93-1.9825,3.2622-3.3155A1,1,0,0,0,25,2c-.354,0-8.7363.0488-14.269,4.3018h0A12.15,12.15,0,0,0,7.481,9.998c-.1416-.1367-.295-.2841-.4585-.4423C6.1743,8.7349,5.04,7.6255,3.707,6.293A1,1,0,0,0,2,7c0,.3594.05,8.874,4.4058,14.4023a12.1023,12.1023,0,0,0,3.5918,3.1163c-.21.2177-.4346.4516-.6563.68h0c-.7954.8208-1.8286,1.8745-3.0483,3.0943A1,1,0,0,0,7,30c.2856,0,7.061-.0352,12.459-3.1055a12.9618,12.9618,0,0,0,5.06-4.8925q.3062.2937.68.6567c.82.7954,1.8745,1.8286,3.0943,3.0483A1,1,0,0,0,30,25C30,24.7119,29.9644,17.8877,26.86,12.4805Zm-3.03,6.1074-.5469,1.3672A10.5415,10.5415,0,0,1,18.47,25.1562,24.3514,24.3514,0,0,1,9.584,27.8135c.4409-.4492,3.8281-3.9824,3.8281-3.9824l-1.3682-.5474a9.8021,9.8021,0,0,1-4.0668-3.1191c-2.5406-3.2242-3.4585-7.7623-3.79-10.58.5435.5337,3.9815,3.8266,3.9815,3.8266l.5468-1.3672A9.8569,9.8569,0,0,1,11.95,7.8877h0C15.1665,5.415,19.6309,4.5146,22.4155,4.187c-.5332.5435-3.8276,3.9819-3.8276,3.9819l1.3677.5469a10.52,10.52,0,0,1,5.17,4.7608v0a24.29,24.29,0,0,1,2.688,8.94C27.3643,21.9751,23.83,18.5879,23.83,18.5879Z"
  })), children);
});
var TropicalWarning32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TropicalWarning32(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.9487,25.6836a1,1,0,0,0-1.8955-.0049A3.44,3.44,0,0,1,23,28a3.44,3.44,0,0,1-3.0532-2.3213,1,1,0,0,0-1.8955.0049A3.4376,3.4376,0,0,1,15,28h-.4336C13.9241,26.7939,12,22.312,12,12v-.1313l1.1169.7446A6.46,6.46,0,0,1,14.4346,13.79l1.0007-1.8418a8.4469,8.4469,0,0,0-1.209-.9986L12.8025,10h1.5308a6.9861,6.9861,0,0,1,1.9934.3071l.9755-1.7954A9.0059,9.0059,0,0,0,14.3333,8H13.1169A7.0329,7.0329,0,0,1,18,6h.6669l1.0867-2H18a9.0361,9.0361,0,0,0-7,3.3638A9.0362,9.0362,0,0,0,4,4H2V6H4A7.0308,7.0308,0,0,1,8.8828,8H7.6665a9.06,9.06,0,0,0-5.4,1.8L.4,11.2l1.2,1.6L3.4668,11.4a7.04,7.04,0,0,1,4.2-1.4H9.1973l-1.4239.9492A8.457,8.457,0,0,0,4,18H6a6.46,6.46,0,0,1,2.8828-5.3867L10,11.8687V12c0,8.9365,1.3994,13.7539,2.355,16H2v2H15a4.9316,4.9316,0,0,0,4-1.9873,5.0192,5.0192,0,0,0,8,0,4.9955,4.9955,0,0,0,3,1.8833V27.8125A3.7616,3.7616,0,0,1,27.9487,25.6836Z"
  })), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,10h-1.5V6h1.5ZM23,11a1,1,0,1,0,1,1A1,1,0,0,0,23,11Z"
  })), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115,13.9355,23.6284,2.3706a.7181.7181,0,0,0-1.2568,0L16.0885,13.9355A.72.72,0,0,0,16.72,15H29.28A.72.72,0,0,0,29.9115,13.9355ZM22.25,6h1.5v4h-1.5ZM23,13a1,1,0,1,1,1-1A1,1,0,0,1,23,13Z"
  })), children);
});
var TropicalWarning24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TropicalWarning24(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.9487,25.6836a1,1,0,0,0-1.8955-.0049A3.44,3.44,0,0,1,23,28a3.44,3.44,0,0,1-3.0532-2.3213,1,1,0,0,0-1.8955.0049A3.4376,3.4376,0,0,1,15,28h-.4336C13.9241,26.7939,12,22.312,12,12v-.1313l1.1169.7446A6.46,6.46,0,0,1,14.4346,13.79l1.0007-1.8418a8.4469,8.4469,0,0,0-1.209-.9986L12.8025,10h1.5308a6.9861,6.9861,0,0,1,1.9934.3071l.9755-1.7954A9.0059,9.0059,0,0,0,14.3333,8H13.1169A7.0329,7.0329,0,0,1,18,6h.6669l1.0867-2H18a9.0361,9.0361,0,0,0-7,3.3638A9.0362,9.0362,0,0,0,4,4H2V6H4A7.0308,7.0308,0,0,1,8.8828,8H7.6665a9.06,9.06,0,0,0-5.4,1.8L.4,11.2l1.2,1.6L3.4668,11.4a7.04,7.04,0,0,1,4.2-1.4H9.1973l-1.4239.9492A8.457,8.457,0,0,0,4,18H6a6.46,6.46,0,0,1,2.8828-5.3867L10,11.8687V12c0,8.9365,1.3994,13.7539,2.355,16H2v2H15a4.9316,4.9316,0,0,0,4-1.9873,5.0192,5.0192,0,0,0,8,0,4.9955,4.9955,0,0,0,3,1.8833V27.8125A3.7616,3.7616,0,0,1,27.9487,25.6836Z"
  })), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,10h-1.5V6h1.5ZM23,11a1,1,0,1,0,1,1A1,1,0,0,0,23,11Z"
  })), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115,13.9355,23.6284,2.3706a.7181.7181,0,0,0-1.2568,0L16.0885,13.9355A.72.72,0,0,0,16.72,15H29.28A.72.72,0,0,0,29.9115,13.9355ZM22.25,6h1.5v4h-1.5ZM23,13a1,1,0,1,1,1-1A1,1,0,0,1,23,13Z"
  })), children);
});
var TropicalWarning20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TropicalWarning20(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.9487,25.6836a1,1,0,0,0-1.8955-.0049A3.44,3.44,0,0,1,23,28a3.44,3.44,0,0,1-3.0532-2.3213,1,1,0,0,0-1.8955.0049A3.4376,3.4376,0,0,1,15,28h-.4336C13.9241,26.7939,12,22.312,12,12v-.1313l1.1169.7446A6.46,6.46,0,0,1,14.4346,13.79l1.0007-1.8418a8.4469,8.4469,0,0,0-1.209-.9986L12.8025,10h1.5308a6.9861,6.9861,0,0,1,1.9934.3071l.9755-1.7954A9.0059,9.0059,0,0,0,14.3333,8H13.1169A7.0329,7.0329,0,0,1,18,6h.6669l1.0867-2H18a9.0361,9.0361,0,0,0-7,3.3638A9.0362,9.0362,0,0,0,4,4H2V6H4A7.0308,7.0308,0,0,1,8.8828,8H7.6665a9.06,9.06,0,0,0-5.4,1.8L.4,11.2l1.2,1.6L3.4668,11.4a7.04,7.04,0,0,1,4.2-1.4H9.1973l-1.4239.9492A8.457,8.457,0,0,0,4,18H6a6.46,6.46,0,0,1,2.8828-5.3867L10,11.8687V12c0,8.9365,1.3994,13.7539,2.355,16H2v2H15a4.9316,4.9316,0,0,0,4-1.9873,5.0192,5.0192,0,0,0,8,0,4.9955,4.9955,0,0,0,3,1.8833V27.8125A3.7616,3.7616,0,0,1,27.9487,25.6836Z"
  })), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,10h-1.5V6h1.5ZM23,11a1,1,0,1,0,1,1A1,1,0,0,0,23,11Z"
  })), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115,13.9355,23.6284,2.3706a.7181.7181,0,0,0-1.2568,0L16.0885,13.9355A.72.72,0,0,0,16.72,15H29.28A.72.72,0,0,0,29.9115,13.9355ZM22.25,6h1.5v4h-1.5ZM23,13a1,1,0,1,1,1-1A1,1,0,0,1,23,13Z"
  })), children);
});
var TropicalWarning16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TropicalWarning16(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.9487,25.6836a1,1,0,0,0-1.8955-.0049A3.44,3.44,0,0,1,23,28a3.44,3.44,0,0,1-3.0532-2.3213,1,1,0,0,0-1.8955.0049A3.4376,3.4376,0,0,1,15,28h-.4336C13.9241,26.7939,12,22.312,12,12v-.1313l1.1169.7446A6.46,6.46,0,0,1,14.4346,13.79l1.0007-1.8418a8.4469,8.4469,0,0,0-1.209-.9986L12.8025,10h1.5308a6.9861,6.9861,0,0,1,1.9934.3071l.9755-1.7954A9.0059,9.0059,0,0,0,14.3333,8H13.1169A7.0329,7.0329,0,0,1,18,6h.6669l1.0867-2H18a9.0361,9.0361,0,0,0-7,3.3638A9.0362,9.0362,0,0,0,4,4H2V6H4A7.0308,7.0308,0,0,1,8.8828,8H7.6665a9.06,9.06,0,0,0-5.4,1.8L.4,11.2l1.2,1.6L3.4668,11.4a7.04,7.04,0,0,1,4.2-1.4H9.1973l-1.4239.9492A8.457,8.457,0,0,0,4,18H6a6.46,6.46,0,0,1,2.8828-5.3867L10,11.8687V12c0,8.9365,1.3994,13.7539,2.355,16H2v2H15a4.9316,4.9316,0,0,0,4-1.9873,5.0192,5.0192,0,0,0,8,0,4.9955,4.9955,0,0,0,3,1.8833V27.8125A3.7616,3.7616,0,0,1,27.9487,25.6836Z"
  })), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,10h-1.5V6h1.5ZM23,11a1,1,0,1,0,1,1A1,1,0,0,0,23,11Z"
  })), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115,13.9355,23.6284,2.3706a.7181.7181,0,0,0-1.2568,0L16.0885,13.9355A.72.72,0,0,0,16.72,15H29.28A.72.72,0,0,0,29.9115,13.9355ZM22.25,6h1.5v4h-1.5ZM23,13a1,1,0,1,1,1-1A1,1,0,0,1,23,13Z"
  })), children);
});
var Tsunami32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tsunami32(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,26H24A10.0349,10.0349,0,0,1,17.0732,8.7378,11.9629,11.9629,0,0,0,12.9937,8a6.9027,6.9027,0,0,0-6.0308,3.42C4.9966,14.4348,4,19.34,4,26H2c0-7.0542,1.106-12.3274,3.2871-15.6726A8.906,8.906,0,0,1,12.9937,6h.0068a14.762,14.762,0,0,1,6.4619,1.592,1,1,0,0,1,.0869,1.7222A8.0249,8.0249,0,0,0,24,24h6Z"
  })), children);
});
var Tsunami24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tsunami24(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,26H24A10.0349,10.0349,0,0,1,17.0732,8.7378,11.9629,11.9629,0,0,0,12.9937,8a6.9027,6.9027,0,0,0-6.0308,3.42C4.9966,14.4348,4,19.34,4,26H2c0-7.0542,1.106-12.3274,3.2871-15.6726A8.906,8.906,0,0,1,12.9937,6h.0068a14.762,14.762,0,0,1,6.4619,1.592,1,1,0,0,1,.0869,1.7222A8.0249,8.0249,0,0,0,24,24h6Z"
  })), children);
});
var Tsunami20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tsunami20(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,26H24A10.0349,10.0349,0,0,1,17.0732,8.7378,11.9629,11.9629,0,0,0,12.9937,8a6.9027,6.9027,0,0,0-6.0308,3.42C4.9966,14.4348,4,19.34,4,26H2c0-7.0542,1.106-12.3274,3.2871-15.6726A8.906,8.906,0,0,1,12.9937,6h.0068a14.762,14.762,0,0,1,6.4619,1.592,1,1,0,0,1,.0869,1.7222A8.0249,8.0249,0,0,0,24,24h6Z"
  })), children);
});
var Tsunami16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tsunami16(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,26H24A10.0349,10.0349,0,0,1,17.0732,8.7378,11.9629,11.9629,0,0,0,12.9937,8a6.9027,6.9027,0,0,0-6.0308,3.42C4.9966,14.4348,4,19.34,4,26H2c0-7.0542,1.106-12.3274,3.2871-15.6726A8.906,8.906,0,0,1,12.9937,6h.0068a14.762,14.762,0,0,1,6.4619,1.592,1,1,0,0,1,.0869,1.7222A8.0249,8.0249,0,0,0,24,24h6Z"
  })), children);
});
var Tsv32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tsv32(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9L26 22 24 9 22 9 24.516 23 27.484 23 30 9 28 9zM18 23H12V21h6V17H14a2.002 2.002 0 01-2-2V11a2.002 2.002 0 012-2h6v2H14v4h4a2.002 2.002 0 012 2v4A2.002 2.002 0 0118 23zM2 11L5 11 5 23 7 23 7 11 10 11 10 9 2 9 2 11z"
  })), children);
});
var Tsv24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tsv24(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9L26 22 24 9 22 9 24.516 23 27.484 23 30 9 28 9zM18 23H12V21h6V17H14a2.002 2.002 0 01-2-2V11a2.002 2.002 0 012-2h6v2H14v4h4a2.002 2.002 0 012 2v4A2.002 2.002 0 0118 23zM2 11L5 11 5 23 7 23 7 11 10 11 10 9 2 9 2 11z"
  })), children);
});
var Tsv20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tsv20(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9L26 22 24 9 22 9 24.516 23 27.484 23 30 9 28 9zM18 23H12V21h6V17H14a2.002 2.002 0 01-2-2V11a2.002 2.002 0 012-2h6v2H14v4h4a2.002 2.002 0 012 2v4A2.002 2.002 0 0118 23zM2 11L5 11 5 23 7 23 7 11 10 11 10 9 2 9 2 11z"
  })), children);
});
var Tsv16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Tsv16(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9L26 22 24 9 22 9 24.516 23 27.484 23 30 9 28 9zM18 23H12V21h6V17H14a2.002 2.002 0 01-2-2V11a2.002 2.002 0 012-2h6v2H14v4h4a2.002 2.002 0 012 2v4A2.002 2.002 0 0118 23zM2 11L5 11 5 23 7 23 7 11 10 11 10 9 2 9 2 11z"
  })), children);
});
var TwoFactorAuthentication32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TwoFactorAuthentication32(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 23.18L9 21.179 7.589 22.589 11 26 17 20 15.59 18.59 11 23.18zM28 30H24V28h4V16H24V8a4.0045 4.0045 0 00-4-4V2a6.0067 6.0067 0 016 6v6h2a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0128 30z"
  })), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,14H18V8A6,6,0,0,0,6,8v6H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V16A2,2,0,0,0,20,14ZM8,8a4,4,0,0,1,8,0v6H8ZM20,28H4V16H20Z"
  })), children);
});
var TwoFactorAuthentication24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TwoFactorAuthentication24(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 23.18L9 21.179 7.589 22.589 11 26 17 20 15.59 18.59 11 23.18zM28 30H24V28h4V16H24V8a4.0045 4.0045 0 00-4-4V2a6.0067 6.0067 0 016 6v6h2a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0128 30z"
  })), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,14H18V8A6,6,0,0,0,6,8v6H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V16A2,2,0,0,0,20,14ZM8,8a4,4,0,0,1,8,0v6H8ZM20,28H4V16H20Z"
  })), children);
});
var TwoFactorAuthentication20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TwoFactorAuthentication20(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 23.18L9 21.179 7.589 22.589 11 26 17 20 15.59 18.59 11 23.18zM28 30H24V28h4V16H24V8a4.0045 4.0045 0 00-4-4V2a6.0067 6.0067 0 016 6v6h2a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0128 30z"
  })), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,14H18V8A6,6,0,0,0,6,8v6H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V16A2,2,0,0,0,20,14ZM8,8a4,4,0,0,1,8,0v6H8ZM20,28H4V16H20Z"
  })), children);
});
var TwoFactorAuthentication16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TwoFactorAuthentication16(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 23.18L9 21.179 7.589 22.589 11 26 17 20 15.59 18.59 11 23.18zM28 30H24V28h4V16H24V8a4.0045 4.0045 0 00-4-4V2a6.0067 6.0067 0 016 6v6h2a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0128 30z"
  })), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,14H18V8A6,6,0,0,0,6,8v6H4a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V16A2,2,0,0,0,20,14ZM8,8a4,4,0,0,1,8,0v6H8ZM20,28H4V16H20Z"
  })), children);
});
var TwoPersonLift32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TwoPersonLift32(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.96 30l-1.9215-6.7253a1.0008 1.0008 0 01.3369-1.0554L29.874 18.62 28.52 13.2014l-2.7382 3.4234A1.0026 1.0026 0 0125 17H20V15h4.52l3.6993-4.6248a1 1 0 011.7509.3824l2 8a.9989.9989 0 01-.3447 1.0232l-4.48 3.5845 1.7389 6.0854zM23 5.5A3.5 3.5 0 1126.5 9 3.5042 3.5042 0 0123 5.5zm2 0A1.5 1.5 0 1026.5 4 1.5017 1.5017 0 0025 5.5z"
  })), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.0039,19A2.0039,2.0039,0,0,1,18,16.9961V15.0039A2.0039,2.0039,0,0,1,20.0039,13H22V10H10v3h1.9961A2.0039,2.0039,0,0,1,14,15.0039v1.9922A2.0039,2.0039,0,0,1,11.9961,19H10v3H22V19Z"
  })), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.04 30l1.9215-6.7253a1.0013 1.0013 0 00-.3369-1.0555L2.126 18.62l1.3545-5.4185 2.7382 3.4234A1.0026 1.0026 0 007 17h5V15H7.4805L3.7812 10.3752a1 1 0 00-1.7509.3824l-2 8A.9989.9989 0 00.375 19.7808l4.4805 3.5844-1.739 6.0855zM5.5 9A3.5 3.5 0 119 5.5 3.5042 3.5042 0 015.5 9zm0-5A1.5 1.5 0 107 5.5 1.5017 1.5017 0 005.5 4z"
  })), children);
});
var TwoPersonLift24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TwoPersonLift24(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.96 30l-1.9215-6.7253a1.0008 1.0008 0 01.3369-1.0554L29.874 18.62 28.52 13.2014l-2.7382 3.4234A1.0026 1.0026 0 0125 17H20V15h4.52l3.6993-4.6248a1 1 0 011.7509.3824l2 8a.9989.9989 0 01-.3447 1.0232l-4.48 3.5845 1.7389 6.0854zM23 5.5A3.5 3.5 0 1126.5 9 3.5042 3.5042 0 0123 5.5zm2 0A1.5 1.5 0 1026.5 4 1.5017 1.5017 0 0025 5.5z"
  })), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.0039,19A2.0039,2.0039,0,0,1,18,16.9961V15.0039A2.0039,2.0039,0,0,1,20.0039,13H22V10H10v3h1.9961A2.0039,2.0039,0,0,1,14,15.0039v1.9922A2.0039,2.0039,0,0,1,11.9961,19H10v3H22V19Z"
  })), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.04 30l1.9215-6.7253a1.0013 1.0013 0 00-.3369-1.0555L2.126 18.62l1.3545-5.4185 2.7382 3.4234A1.0026 1.0026 0 007 17h5V15H7.4805L3.7812 10.3752a1 1 0 00-1.7509.3824l-2 8A.9989.9989 0 00.375 19.7808l4.4805 3.5844-1.739 6.0855zM5.5 9A3.5 3.5 0 119 5.5 3.5042 3.5042 0 015.5 9zm0-5A1.5 1.5 0 107 5.5 1.5017 1.5017 0 005.5 4z"
  })), children);
});
var TwoPersonLift20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TwoPersonLift20(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.96 30l-1.9215-6.7253a1.0008 1.0008 0 01.3369-1.0554L29.874 18.62 28.52 13.2014l-2.7382 3.4234A1.0026 1.0026 0 0125 17H20V15h4.52l3.6993-4.6248a1 1 0 011.7509.3824l2 8a.9989.9989 0 01-.3447 1.0232l-4.48 3.5845 1.7389 6.0854zM23 5.5A3.5 3.5 0 1126.5 9 3.5042 3.5042 0 0123 5.5zm2 0A1.5 1.5 0 1026.5 4 1.5017 1.5017 0 0025 5.5z"
  })), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.0039,19A2.0039,2.0039,0,0,1,18,16.9961V15.0039A2.0039,2.0039,0,0,1,20.0039,13H22V10H10v3h1.9961A2.0039,2.0039,0,0,1,14,15.0039v1.9922A2.0039,2.0039,0,0,1,11.9961,19H10v3H22V19Z"
  })), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.04 30l1.9215-6.7253a1.0013 1.0013 0 00-.3369-1.0555L2.126 18.62l1.3545-5.4185 2.7382 3.4234A1.0026 1.0026 0 007 17h5V15H7.4805L3.7812 10.3752a1 1 0 00-1.7509.3824l-2 8A.9989.9989 0 00.375 19.7808l4.4805 3.5844-1.739 6.0855zM5.5 9A3.5 3.5 0 119 5.5 3.5042 3.5042 0 015.5 9zm0-5A1.5 1.5 0 107 5.5 1.5017 1.5017 0 005.5 4z"
  })), children);
});
var TwoPersonLift16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TwoPersonLift16(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.96 30l-1.9215-6.7253a1.0008 1.0008 0 01.3369-1.0554L29.874 18.62 28.52 13.2014l-2.7382 3.4234A1.0026 1.0026 0 0125 17H20V15h4.52l3.6993-4.6248a1 1 0 011.7509.3824l2 8a.9989.9989 0 01-.3447 1.0232l-4.48 3.5845 1.7389 6.0854zM23 5.5A3.5 3.5 0 1126.5 9 3.5042 3.5042 0 0123 5.5zm2 0A1.5 1.5 0 1026.5 4 1.5017 1.5017 0 0025 5.5z"
  })), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.0039,19A2.0039,2.0039,0,0,1,18,16.9961V15.0039A2.0039,2.0039,0,0,1,20.0039,13H22V10H10v3h1.9961A2.0039,2.0039,0,0,1,14,15.0039v1.9922A2.0039,2.0039,0,0,1,11.9961,19H10v3H22V19Z"
  })), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.04 30l1.9215-6.7253a1.0013 1.0013 0 00-.3369-1.0555L2.126 18.62l1.3545-5.4185 2.7382 3.4234A1.0026 1.0026 0 007 17h5V15H7.4805L3.7812 10.3752a1 1 0 00-1.7509.3824l-2 8A.9989.9989 0 00.375 19.7808l4.4805 3.5844-1.739 6.0855zM5.5 9A3.5 3.5 0 119 5.5 3.5042 3.5042 0 015.5 9zm0-5A1.5 1.5 0 107 5.5 1.5017 1.5017 0 005.5 4z"
  })), children);
});
var Txt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Txt32(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 11L24 11 24 23 26 23 26 11 29 11 29 9 21 9 21 11zM20 9L18 9 16 15 14 9 12 9 14.75 16 12 23 14 23 16 17 18 23 20 23 17.25 16 20 9zM3 11L6 11 6 23 8 23 8 11 11 11 11 9 3 9 3 11z"
  })), children);
});
var Txt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Txt24(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 11L24 11 24 23 26 23 26 11 29 11 29 9 21 9 21 11zM20 9L18 9 16 15 14 9 12 9 14.75 16 12 23 14 23 16 17 18 23 20 23 17.25 16 20 9zM3 11L6 11 6 23 8 23 8 11 11 11 11 9 3 9 3 11z"
  })), children);
});
var Txt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Txt20(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 11L24 11 24 23 26 23 26 11 29 11 29 9 21 9 21 11zM20 9L18 9 16 15 14 9 12 9 14.75 16 12 23 14 23 16 17 18 23 20 23 17.25 16 20 9zM3 11L6 11 6 23 8 23 8 11 11 11 11 9 3 9 3 11z"
  })), children);
});
var Txt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Txt16(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 11L24 11 24 23 26 23 26 11 29 11 29 9 21 9 21 11zM20 9L18 9 16 15 14 9 12 9 14.75 16 12 23 14 23 16 17 18 23 20 23 17.25 16 20 9zM3 11L6 11 6 23 8 23 8 11 11 11 11 9 3 9 3 11z"
  })), children);
});
var TxtReference32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TxtReference32(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM21 4L24 4 24 16 26 16 26 4 29 4 29 2 21 2 21 4zM20 2L18 2 16 8 14 2 12 2 14.752 9 12 16 14 16 16 10 18 16 20 16 17.245 9 20 2zM3 4L6 4 6 16 8 16 8 4 11 4 11 2 3 2 3 4z"
  })), children);
});
var TxtReference24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TxtReference24(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM21 4L24 4 24 16 26 16 26 4 29 4 29 2 21 2 21 4zM20 2L18 2 16 8 14 2 12 2 14.752 9 12 16 14 16 16 10 18 16 20 16 17.245 9 20 2zM3 4L6 4 6 16 8 16 8 4 11 4 11 2 3 2 3 4z"
  })), children);
});
var TxtReference20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TxtReference20(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM21 4L24 4 24 16 26 16 26 4 29 4 29 2 21 2 21 4zM20 2L18 2 16 8 14 2 12 2 14.752 9 12 16 14 16 16 10 18 16 20 16 17.245 9 20 2zM3 4L6 4 6 16 8 16 8 4 11 4 11 2 3 2 3 4z"
  })), children);
});
var TxtReference16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TxtReference16(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM21 4L24 4 24 16 26 16 26 4 29 4 29 2 21 2 21 4zM20 2L18 2 16 8 14 2 12 2 14.752 9 12 16 14 16 16 10 18 16 20 16 17.245 9 20 2zM3 4L6 4 6 16 8 16 8 4 11 4 11 2 3 2 3 4z"
  })), children);
});
var TypePattern32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TypePattern32(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 15L17 15 17 2 15 2 15 15 2 15 2 17 15 17 15 30 17 30 17 17 30 17 30 15z"
  })), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.586 20L27 21.414 23.414 25 27 28.586 25.586 30 20.586 25 25.586 20zM11 30H3a1 1 0 01-.8945-1.4473l4-8a1.0412 1.0412 0 011.789 0l4 8A1 1 0 0111 30zM4.6182 28H9.3818L7 23.2363zM28 12H22a2.0023 2.0023 0 01-2-2V4a2.0023 2.0023 0 012-2h6a2.0023 2.0023 0 012 2v6A2.0023 2.0023 0 0128 12zM22 4v6h6.001L28 4zM7 12a5 5 0 115-5A5.0059 5.0059 0 017 12zM7 4a3 3 0 103 3A3.0033 3.0033 0 007 4z"
  })), children);
});
var TypePattern24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TypePattern24(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 15L17 15 17 2 15 2 15 15 2 15 2 17 15 17 15 30 17 30 17 17 30 17 30 15z"
  })), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.586 20L27 21.414 23.414 25 27 28.586 25.586 30 20.586 25 25.586 20zM11 30H3a1 1 0 01-.8945-1.4473l4-8a1.0412 1.0412 0 011.789 0l4 8A1 1 0 0111 30zM4.6182 28H9.3818L7 23.2363zM28 12H22a2.0023 2.0023 0 01-2-2V4a2.0023 2.0023 0 012-2h6a2.0023 2.0023 0 012 2v6A2.0023 2.0023 0 0128 12zM22 4v6h6.001L28 4zM7 12a5 5 0 115-5A5.0059 5.0059 0 017 12zM7 4a3 3 0 103 3A3.0033 3.0033 0 007 4z"
  })), children);
});
var TypePattern20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TypePattern20(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 15L17 15 17 2 15 2 15 15 2 15 2 17 15 17 15 30 17 30 17 17 30 17 30 15z"
  })), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.586 20L27 21.414 23.414 25 27 28.586 25.586 30 20.586 25 25.586 20zM11 30H3a1 1 0 01-.8945-1.4473l4-8a1.0412 1.0412 0 011.789 0l4 8A1 1 0 0111 30zM4.6182 28H9.3818L7 23.2363zM28 12H22a2.0023 2.0023 0 01-2-2V4a2.0023 2.0023 0 012-2h6a2.0023 2.0023 0 012 2v6A2.0023 2.0023 0 0128 12zM22 4v6h6.001L28 4zM7 12a5 5 0 115-5A5.0059 5.0059 0 017 12zM7 4a3 3 0 103 3A3.0033 3.0033 0 007 4z"
  })), children);
});
var TypePattern16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function TypePattern16(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 15L17 15 17 2 15 2 15 15 2 15 2 17 15 17 15 30 17 30 17 17 30 17 30 15z"
  })), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.586 20L27 21.414 23.414 25 27 28.586 25.586 30 20.586 25 25.586 20zM11 30H3a1 1 0 01-.8945-1.4473l4-8a1.0412 1.0412 0 011.789 0l4 8A1 1 0 0111 30zM4.6182 28H9.3818L7 23.2363zM28 12H22a2.0023 2.0023 0 01-2-2V4a2.0023 2.0023 0 012-2h6a2.0023 2.0023 0 012 2v6A2.0023 2.0023 0 0128 12zM22 4v6h6.001L28 4zM7 12a5 5 0 115-5A5.0059 5.0059 0 017 12zM7 4a3 3 0 103 3A3.0033 3.0033 0 007 4z"
  })), children);
});
var Types32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Types32(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 16L22 24 20.586 22.586 27.172 16 20.586 9.414 22 8 30 16z"
  })), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a.9967.9967,0,0,1-.707-.293l-5-5a.9994.9994,0,0,1,0-1.414l5-5a.9994.9994,0,0,1,1.414,0l5,5a.9994.9994,0,0,1,0,1.414l-5,5A.9967.9967,0,0,1,16,22Zm-3.5859-6L16,19.5859,19.5859,16,16,12.4141Z"
  })), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 16L10 8 11.414 9.414 4.828 16 11.414 22.586 10 24 2 16z"
  })), children);
});
var Types24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Types24(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 16L22 24 20.586 22.586 27.172 16 20.586 9.414 22 8 30 16z"
  })), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a.9967.9967,0,0,1-.707-.293l-5-5a.9994.9994,0,0,1,0-1.414l5-5a.9994.9994,0,0,1,1.414,0l5,5a.9994.9994,0,0,1,0,1.414l-5,5A.9967.9967,0,0,1,16,22Zm-3.5859-6L16,19.5859,19.5859,16,16,12.4141Z"
  })), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 16L10 8 11.414 9.414 4.828 16 11.414 22.586 10 24 2 16z"
  })), children);
});
var Types20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Types20(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 16L22 24 20.586 22.586 27.172 16 20.586 9.414 22 8 30 16z"
  })), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a.9967.9967,0,0,1-.707-.293l-5-5a.9994.9994,0,0,1,0-1.414l5-5a.9994.9994,0,0,1,1.414,0l5,5a.9994.9994,0,0,1,0,1.414l-5,5A.9967.9967,0,0,1,16,22Zm-3.5859-6L16,19.5859,19.5859,16,16,12.4141Z"
  })), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 16L10 8 11.414 9.414 4.828 16 11.414 22.586 10 24 2 16z"
  })), children);
});
var Types16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Types16(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 16L22 24 20.586 22.586 27.172 16 20.586 9.414 22 8 30 16z"
  })), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a.9967.9967,0,0,1-.707-.293l-5-5a.9994.9994,0,0,1,0-1.414l5-5a.9994.9994,0,0,1,1.414,0l5,5a.9994.9994,0,0,1,0,1.414l-5,5A.9967.9967,0,0,1,16,22Zm-3.5859-6L16,19.5859,19.5859,16,16,12.4141Z"
  })), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 16L10 8 11.414 9.414 4.828 16 11.414 22.586 10 24 2 16z"
  })), children);
});
var QU132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QU132(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 23H9a2 2 0 01-2-2V9H9V21h4V9h2V21A2 2 0 0113 23zM22 21L22 9 17 9 17 11 20 11 20 21 17 21 17 23 25 23 25 21 22 21z"
  })), children);
});
var QU124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QU124(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 23H9a2 2 0 01-2-2V9H9V21h4V9h2V21A2 2 0 0113 23zM22 21L22 9 17 9 17 11 20 11 20 21 17 21 17 23 25 23 25 21 22 21z"
  })), children);
});
var QU120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QU120(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 23H9a2 2 0 01-2-2V9H9V21h4V9h2V21A2 2 0 0113 23zM22 21L22 9 17 9 17 11 20 11 20 21 17 21 17 23 25 23 25 21 22 21z"
  })), children);
});
var QU116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QU116(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 23H9a2 2 0 01-2-2V9H9V21h4V9h2V21A2 2 0 0113 23zM22 21L22 9 17 9 17 11 20 11 20 21 17 21 17 23 25 23 25 21 22 21z"
  })), children);
});
var QU232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QU232(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 23H9a2 2 0 01-2-2V9H9V21h4V9h2V21A2 2 0 0113 23zM25 23H17V17a2 2 0 012-2h4V11H17V9h6a2 2 0 012 2v4a2 2 0 01-2 2H19v4h6z"
  })), children);
});
var QU224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QU224(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 23H9a2 2 0 01-2-2V9H9V21h4V9h2V21A2 2 0 0113 23zM25 23H17V17a2 2 0 012-2h4V11H17V9h6a2 2 0 012 2v4a2 2 0 01-2 2H19v4h6z"
  })), children);
});
var QU220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QU220(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 23H9a2 2 0 01-2-2V9H9V21h4V9h2V21A2 2 0 0113 23zM25 23H17V17a2 2 0 012-2h4V11H17V9h6a2 2 0 012 2v4a2 2 0 01-2 2H19v4h6z"
  })), children);
});
var QU216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QU216(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 23H9a2 2 0 01-2-2V9H9V21h4V9h2V21A2 2 0 0113 23zM25 23H17V17a2 2 0 012-2h4V11H17V9h6a2 2 0 012 2v4a2 2 0 01-2 2H19v4h6z"
  })), children);
});
var QU332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QU332(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 23H9a2 2 0 01-2-2V9H9V21h4V9h2V21A2 2 0 0113 23zM23 9H17v2h6v4H18v2h5v4H17v2h6a2 2 0 002-2V11A2 2 0 0023 9z"
  })), children);
});
var QU324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QU324(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 23H9a2 2 0 01-2-2V9H9V21h4V9h2V21A2 2 0 0113 23zM23 9H17v2h6v4H18v2h5v4H17v2h6a2 2 0 002-2V11A2 2 0 0023 9z"
  })), children);
});
var QU320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QU320(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 23H9a2 2 0 01-2-2V9H9V21h4V9h2V21A2 2 0 0113 23zM23 9H17v2h6v4H18v2h5v4H17v2h6a2 2 0 002-2V11A2 2 0 0023 9z"
  })), children);
});
var QU316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QU316(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 23H9a2 2 0 01-2-2V9H9V21h4V9h2V21A2 2 0 0113 23zM23 9H17v2h6v4H18v2h5v4H17v2h6a2 2 0 002-2V11A2 2 0 0023 9z"
  })), children);
});
var Umbrella32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Umbrella32(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9854,15.83A14.3808,14.3808,0,0,0,17,4.0464V2H15V4.0464A14.3808,14.3808,0,0,0,2.0146,15.83,1,1,0,0,0,3.51,16.86,4.8551,4.8551,0,0,1,6,16a4.8653,4.8653,0,0,1,4.1406,2.5107,1.0393,1.0393,0,0,0,1.7188,0A5.02,5.02,0,0,1,15,16.1255V25.5a2.5,2.5,0,0,1-5,0V25H8v.5a4.5,4.5,0,0,0,9,0V16.1255a5.02,5.02,0,0,1,3.1406,2.3852.9994.9994,0,0,0,1.7188,0A4.8653,4.8653,0,0,1,26,16a4.8551,4.8551,0,0,1,2.49.86,1,1,0,0,0,1.4957-1.03ZM6,14a5.4079,5.4079,0,0,0-1.5034.2134,12.4411,12.4411,0,0,1,8.488-7.8145A14.5157,14.5157,0,0,0,9.939,15.333,6.5439,6.5439,0,0,0,6,14Zm10,0a6.5528,6.5528,0,0,0-4.0564,1.4307c.0378-2.22.6089-6.49,4.0563-9.1763,3.4308,2.6768,4.0091,6.9487,4.0525,9.1728A6.553,6.553,0,0,0,16,14Zm10,0a6.5439,6.5439,0,0,0-3.939,1.333,14.5164,14.5164,0,0,0-3.0456-8.9341,12.4411,12.4411,0,0,1,8.488,7.8145A5.4079,5.4079,0,0,0,26,14Z"
  })), children);
});
var Umbrella24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Umbrella24(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9854,15.83A14.3808,14.3808,0,0,0,17,4.0464V2H15V4.0464A14.3808,14.3808,0,0,0,2.0146,15.83,1,1,0,0,0,3.51,16.86,4.8551,4.8551,0,0,1,6,16a4.8653,4.8653,0,0,1,4.1406,2.5107,1.0393,1.0393,0,0,0,1.7188,0A5.02,5.02,0,0,1,15,16.1255V25.5a2.5,2.5,0,0,1-5,0V25H8v.5a4.5,4.5,0,0,0,9,0V16.1255a5.02,5.02,0,0,1,3.1406,2.3852.9994.9994,0,0,0,1.7188,0A4.8653,4.8653,0,0,1,26,16a4.8551,4.8551,0,0,1,2.49.86,1,1,0,0,0,1.4957-1.03ZM6,14a5.4079,5.4079,0,0,0-1.5034.2134,12.4411,12.4411,0,0,1,8.488-7.8145A14.5157,14.5157,0,0,0,9.939,15.333,6.5439,6.5439,0,0,0,6,14Zm10,0a6.5528,6.5528,0,0,0-4.0564,1.4307c.0378-2.22.6089-6.49,4.0563-9.1763,3.4308,2.6768,4.0091,6.9487,4.0525,9.1728A6.553,6.553,0,0,0,16,14Zm10,0a6.5439,6.5439,0,0,0-3.939,1.333,14.5164,14.5164,0,0,0-3.0456-8.9341,12.4411,12.4411,0,0,1,8.488,7.8145A5.4079,5.4079,0,0,0,26,14Z"
  })), children);
});
var Umbrella20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Umbrella20(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9854,15.83A14.3808,14.3808,0,0,0,17,4.0464V2H15V4.0464A14.3808,14.3808,0,0,0,2.0146,15.83,1,1,0,0,0,3.51,16.86,4.8551,4.8551,0,0,1,6,16a4.8653,4.8653,0,0,1,4.1406,2.5107,1.0393,1.0393,0,0,0,1.7188,0A5.02,5.02,0,0,1,15,16.1255V25.5a2.5,2.5,0,0,1-5,0V25H8v.5a4.5,4.5,0,0,0,9,0V16.1255a5.02,5.02,0,0,1,3.1406,2.3852.9994.9994,0,0,0,1.7188,0A4.8653,4.8653,0,0,1,26,16a4.8551,4.8551,0,0,1,2.49.86,1,1,0,0,0,1.4957-1.03ZM6,14a5.4079,5.4079,0,0,0-1.5034.2134,12.4411,12.4411,0,0,1,8.488-7.8145A14.5157,14.5157,0,0,0,9.939,15.333,6.5439,6.5439,0,0,0,6,14Zm10,0a6.5528,6.5528,0,0,0-4.0564,1.4307c.0378-2.22.6089-6.49,4.0563-9.1763,3.4308,2.6768,4.0091,6.9487,4.0525,9.1728A6.553,6.553,0,0,0,16,14Zm10,0a6.5439,6.5439,0,0,0-3.939,1.333,14.5164,14.5164,0,0,0-3.0456-8.9341,12.4411,12.4411,0,0,1,8.488,7.8145A5.4079,5.4079,0,0,0,26,14Z"
  })), children);
});
var Umbrella16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Umbrella16(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9854,15.83A14.3808,14.3808,0,0,0,17,4.0464V2H15V4.0464A14.3808,14.3808,0,0,0,2.0146,15.83,1,1,0,0,0,3.51,16.86,4.8551,4.8551,0,0,1,6,16a4.8653,4.8653,0,0,1,4.1406,2.5107,1.0393,1.0393,0,0,0,1.7188,0A5.02,5.02,0,0,1,15,16.1255V25.5a2.5,2.5,0,0,1-5,0V25H8v.5a4.5,4.5,0,0,0,9,0V16.1255a5.02,5.02,0,0,1,3.1406,2.3852.9994.9994,0,0,0,1.7188,0A4.8653,4.8653,0,0,1,26,16a4.8551,4.8551,0,0,1,2.49.86,1,1,0,0,0,1.4957-1.03ZM6,14a5.4079,5.4079,0,0,0-1.5034.2134,12.4411,12.4411,0,0,1,8.488-7.8145A14.5157,14.5157,0,0,0,9.939,15.333,6.5439,6.5439,0,0,0,6,14Zm10,0a6.5528,6.5528,0,0,0-4.0564,1.4307c.0378-2.22.6089-6.49,4.0563-9.1763,3.4308,2.6768,4.0091,6.9487,4.0525,9.1728A6.553,6.553,0,0,0,16,14Zm10,0a6.5439,6.5439,0,0,0-3.939,1.333,14.5164,14.5164,0,0,0-3.0456-8.9341,12.4411,12.4411,0,0,1,8.488,7.8145A5.4079,5.4079,0,0,0,26,14Z"
  })), children);
});
var Undefined32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Undefined32(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 14H21V18H11z"
  })), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2c-0.533,0-1.067,0.203-1.473,0.609L2.609,14.527\tC2.203,14.933,2,15.466,2,16s0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30c0.533,0,1.067-0.203,1.473-0.609\tl11.917-11.917C29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M16,28.036L3.965,16L16,3.964L28.036,16L16,28.036z"
  })), children);
});
var Undefined24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Undefined24(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 14H21V18H11z"
  })), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2c-0.533,0-1.067,0.203-1.473,0.609L2.609,14.527\tC2.203,14.933,2,15.466,2,16s0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30c0.533,0,1.067-0.203,1.473-0.609\tl11.917-11.917C29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M16,28.036L3.965,16L16,3.964L28.036,16L16,28.036z"
  })), children);
});
var Undefined20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Undefined20(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 14H21V18H11z"
  })), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2c-0.533,0-1.067,0.203-1.473,0.609L2.609,14.527\tC2.203,14.933,2,15.466,2,16s0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30c0.533,0,1.067-0.203,1.473-0.609\tl11.917-11.917C29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M16,28.036L3.965,16L16,3.964L28.036,16L16,28.036z"
  })), children);
});
var Undefined16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Undefined16(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 14H21V18H11z"
  })), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2c-0.533,0-1.067,0.203-1.473,0.609L2.609,14.527\tC2.203,14.933,2,15.466,2,16s0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30c0.533,0,1.067-0.203,1.473-0.609\tl11.917-11.917C29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M16,28.036L3.965,16L16,3.964L28.036,16L16,28.036z"
  })), children);
});
var UndefinedGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UndefinedGlyph(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,2.4142,13.5858,8,8,13.5858,2.4142,8,8,2.4142M8,1,1,8l7,7,7-7L8,1Z"
  })), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,2.4142,13.5858,8,8,13.5858,2.4142,8,8,2.4142"
  })), children);
});
var UndefinedFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UndefinedFilled32(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2s-1.067,0.203-1.473,0.609L2.609,14.527C2.203,14.933,2,15.466,2,16\ts0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30s1.067-0.203,1.473-0.609l11.917-11.917\tC29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M21,18H11v-4h10V18z"
  })), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11 14H21V18H11z",
    "data-icon-path": "inner-path"
  })), children);
});
var UndefinedFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UndefinedFilled24(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2s-1.067,0.203-1.473,0.609L2.609,14.527C2.203,14.933,2,15.466,2,16\ts0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30s1.067-0.203,1.473-0.609l11.917-11.917\tC29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M21,18H11v-4h10V18z"
  })), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11 14H21V18H11z",
    "data-icon-path": "inner-path"
  })), children);
});
var UndefinedFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UndefinedFilled20(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2s-1.067,0.203-1.473,0.609L2.609,14.527C2.203,14.933,2,15.466,2,16\ts0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30s1.067-0.203,1.473-0.609l11.917-11.917\tC29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M21,18H11v-4h10V18z"
  })), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11 14H21V18H11z",
    "data-icon-path": "inner-path"
  })), children);
});
var UndefinedFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UndefinedFilled16(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2s-1.067,0.203-1.473,0.609L2.609,14.527C2.203,14.933,2,15.466,2,16\ts0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30s1.067-0.203,1.473-0.609l11.917-11.917\tC29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M21,18H11v-4h10V18z"
  })), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11 14H21V18H11z",
    "data-icon-path": "inner-path"
  })), children);
});
var Undo32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Undo32(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,10H7.8149l3.5874-3.5859L10,5,4,11,10,17l1.4023-1.4146L7.8179,12H20a6,6,0,0,1,0,12H12v2h8a8,8,0,0,0,0-16Z"
  })), children);
});
var Undo24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Undo24(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 24 24",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.2,11.2c1.8,0,3.2,1.7,3.2,3.3c0,1.5-1.5,3.2-3.2,3.2H14v1.5h3.2c2.2,0,4.8-2.3,4.8-4.8s-2-4.8-4.8-4.8\tH4.8l3-3L6.8,5.7L2,10.5l4.8,4.8l1.1-1.1l-3-3H17.2z"
  })), children);
});
var Undo20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Undo20(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 20 20",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,9.3c1.5,0,2.8,1.3,2.8,2.7c0,1.5-1.3,2.7-2.8,2.7h-4V16h4c2.3,0,4-1.7,4-4c0-2.2-1.8-4-4-4H3.4\tl2.5-2.5L5,4.6l-4,4l4,4l0.9-0.9L3.4,9.3H15z"
  })), children);
});
var Undo16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Undo16(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,8c1.2,0,2,0.8,2,2c0,1.2-0.8,2-2,2H9v1h3c1.7,0,3-1.2,3-3c0-1.7-1.3-3-3-3L2.9,7l2-2L4.2,4.3L1,7.5\tl3.2,3.2L4.9,10l-2-2L12,8z"
  })), children);
});
var UngroupObjects32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UngroupObjects32(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,14V10H26v2H20V6h2V2H18V4H6V2H2V6H4V18H2v4H6V20h6v6H10v4h4V28H26v2h4V26H28V14ZM6,6H18V18H6ZM26,26H14V20h4v2h4V18H20V14h6Z"
  })), children);
});
var UngroupObjects24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UngroupObjects24(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,14V10H26v2H20V6h2V2H18V4H6V2H2V6H4V18H2v4H6V20h6v6H10v4h4V28H26v2h4V26H28V14ZM6,6H18V18H6ZM26,26H14V20h4v2h4V18H20V14h6Z"
  })), children);
});
var UngroupObjects20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UngroupObjects20(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,14V10H26v2H20V6h2V2H18V4H6V2H2V6H4V18H2v4H6V20h6v6H10v4h4V28H26v2h4V26H28V14ZM6,6H18V18H6ZM26,26H14V20h4v2h4V18H20V14h6Z"
  })), children);
});
var UngroupObjects16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UngroupObjects16(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,14V10H26v2H20V6h2V2H18V4H6V2H2V6H4V18H2v4H6V20h6v6H10v4h4V28H26v2h4V26H28V14ZM6,6H18V18H6ZM26,26H14V20h4v2h4V18H20V14h6Z"
  })), children);
});
var Unknown32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Unknown32(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "22.5",
    r: "1.5"
  })), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,19h-2v-4h2c1.103,0,2-0.897,2-2s-0.897-2-2-2h-2c-1.103,0-2,0.897-2,2v0.5h-2V13c0-2.206,1.794-4,4-4h2\tc2.206,0,4,1.794,4,4s-1.794,4-4,4V19z"
  })), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2c-0.533,0-1.067,0.203-1.473,0.609L2.609,14.527\tC2.203,14.933,2,15.466,2,16s0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30c0.533,0,1.067-0.203,1.473-0.609\tl11.917-11.917C29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M16,28.036L3.965,16L16,3.964L28.036,16L16,28.036z"
  })), children);
});
var Unknown24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Unknown24(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "22.5",
    r: "1.5"
  })), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,19h-2v-4h2c1.103,0,2-0.897,2-2s-0.897-2-2-2h-2c-1.103,0-2,0.897-2,2v0.5h-2V13c0-2.206,1.794-4,4-4h2\tc2.206,0,4,1.794,4,4s-1.794,4-4,4V19z"
  })), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2c-0.533,0-1.067,0.203-1.473,0.609L2.609,14.527\tC2.203,14.933,2,15.466,2,16s0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30c0.533,0,1.067-0.203,1.473-0.609\tl11.917-11.917C29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M16,28.036L3.965,16L16,3.964L28.036,16L16,28.036z"
  })), children);
});
var Unknown20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Unknown20(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "22.5",
    r: "1.5"
  })), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,19h-2v-4h2c1.103,0,2-0.897,2-2s-0.897-2-2-2h-2c-1.103,0-2,0.897-2,2v0.5h-2V13c0-2.206,1.794-4,4-4h2\tc2.206,0,4,1.794,4,4s-1.794,4-4,4V19z"
  })), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2c-0.533,0-1.067,0.203-1.473,0.609L2.609,14.527\tC2.203,14.933,2,15.466,2,16s0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30c0.533,0,1.067-0.203,1.473-0.609\tl11.917-11.917C29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M16,28.036L3.965,16L16,3.964L28.036,16L16,28.036z"
  })), children);
});
var Unknown16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Unknown16(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "22.5",
    r: "1.5"
  })), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,19h-2v-4h2c1.103,0,2-0.897,2-2s-0.897-2-2-2h-2c-1.103,0-2,0.897-2,2v0.5h-2V13c0-2.206,1.794-4,4-4h2\tc2.206,0,4,1.794,4,4s-1.794,4-4,4V19z"
  })), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2c-0.533,0-1.067,0.203-1.473,0.609L2.609,14.527\tC2.203,14.933,2,15.466,2,16s0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30c0.533,0,1.067-0.203,1.473-0.609\tl11.917-11.917C29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M16,28.036L3.965,16L16,3.964L28.036,16L16,28.036z"
  })), children);
});
var UnknownFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UnknownFilled32(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2s-1.067,0.203-1.473,0.609L2.609,14.527C2.203,14.933,2,15.466,2,16\ts0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30s1.067-0.203,1.473-0.609l11.917-11.917\tC29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M16,24c-0.828,0-1.5-0.671-1.5-1.5S15.172,21,16,21s1.5,0.671,1.5,1.5\tS16.828,24,16,24z M17.125,17.248v1.877h-2.25V15H17c1.034,0,1.875-0.841,1.875-1.875S18.034,11.25,17,11.25h-2\tc-1.034,0-1.875,0.841-1.875,1.875v0.5h-2.25v-0.5C10.875,10.851,12.726,9,15,9h2c2.274,0,4.125,1.851,4.125,4.125\tC21.125,15.358,19.342,17.182,17.125,17.248z"
  })), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,21c0.828,0,1.5,0.672,1.5,1.5S16.828,24,16,24c-0.828,0-1.5-0.672-1.5-1.5S15.172,21,16,21\tz M17.125,17.248c2.217-0.066,4-1.89,4-4.123C21.125,10.851,19.274,9,17,9h-2c-2.274,0-4.125,1.851-4.125,4.125v0.5h2.25v-0.5\tc0-1.034,0.841-1.875,1.875-1.875h2c1.034,0,1.875,0.841,1.875,1.875S18.034,15,17,15h-2.125v4.125h2.25V17.248z",
    "data-icon-path": "inner-path"
  })), children);
});
var UnknownFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UnknownFilled24(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2s-1.067,0.203-1.473,0.609L2.609,14.527C2.203,14.933,2,15.466,2,16\ts0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30s1.067-0.203,1.473-0.609l11.917-11.917\tC29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M16,24c-0.828,0-1.5-0.671-1.5-1.5S15.172,21,16,21s1.5,0.671,1.5,1.5\tS16.828,24,16,24z M17.125,17.248v1.877h-2.25V15H17c1.034,0,1.875-0.841,1.875-1.875S18.034,11.25,17,11.25h-2\tc-1.034,0-1.875,0.841-1.875,1.875v0.5h-2.25v-0.5C10.875,10.851,12.726,9,15,9h2c2.274,0,4.125,1.851,4.125,4.125\tC21.125,15.358,19.342,17.182,17.125,17.248z"
  })), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,21c0.828,0,1.5,0.672,1.5,1.5S16.828,24,16,24c-0.828,0-1.5-0.672-1.5-1.5S15.172,21,16,21\tz M17.125,17.248c2.217-0.066,4-1.89,4-4.123C21.125,10.851,19.274,9,17,9h-2c-2.274,0-4.125,1.851-4.125,4.125v0.5h2.25v-0.5\tc0-1.034,0.841-1.875,1.875-1.875h2c1.034,0,1.875,0.841,1.875,1.875S18.034,15,17,15h-2.125v4.125h2.25V17.248z",
    "data-icon-path": "inner-path"
  })), children);
});
var UnknownFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UnknownFilled20(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2s-1.067,0.203-1.473,0.609L2.609,14.527C2.203,14.933,2,15.466,2,16\ts0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30s1.067-0.203,1.473-0.609l11.917-11.917\tC29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M16,24c-0.828,0-1.5-0.671-1.5-1.5S15.172,21,16,21s1.5,0.671,1.5,1.5\tS16.828,24,16,24z M17.125,17.248v1.877h-2.25V15H17c1.034,0,1.875-0.841,1.875-1.875S18.034,11.25,17,11.25h-2\tc-1.034,0-1.875,0.841-1.875,1.875v0.5h-2.25v-0.5C10.875,10.851,12.726,9,15,9h2c2.274,0,4.125,1.851,4.125,4.125\tC21.125,15.358,19.342,17.182,17.125,17.248z"
  })), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,21c0.828,0,1.5,0.672,1.5,1.5S16.828,24,16,24c-0.828,0-1.5-0.672-1.5-1.5S15.172,21,16,21\tz M17.125,17.248c2.217-0.066,4-1.89,4-4.123C21.125,10.851,19.274,9,17,9h-2c-2.274,0-4.125,1.851-4.125,4.125v0.5h2.25v-0.5\tc0-1.034,0.841-1.875,1.875-1.875h2c1.034,0,1.875,0.841,1.875,1.875S18.034,15,17,15h-2.125v4.125h2.25V17.248z",
    "data-icon-path": "inner-path"
  })), children);
});
var UnknownFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UnknownFilled16(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.391,14.527L17.473,2.609C17.067,2.203,16.533,2,16,2s-1.067,0.203-1.473,0.609L2.609,14.527C2.203,14.933,2,15.466,2,16\ts0.203,1.067,0.609,1.473l11.917,11.917C14.933,29.797,15.467,30,16,30s1.067-0.203,1.473-0.609l11.917-11.917\tC29.797,17.067,30,16.534,30,16S29.797,14.933,29.391,14.527z M16,24c-0.828,0-1.5-0.671-1.5-1.5S15.172,21,16,21s1.5,0.671,1.5,1.5\tS16.828,24,16,24z M17.125,17.248v1.877h-2.25V15H17c1.034,0,1.875-0.841,1.875-1.875S18.034,11.25,17,11.25h-2\tc-1.034,0-1.875,0.841-1.875,1.875v0.5h-2.25v-0.5C10.875,10.851,12.726,9,15,9h2c2.274,0,4.125,1.851,4.125,4.125\tC21.125,15.358,19.342,17.182,17.125,17.248z"
  })), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,21c0.828,0,1.5,0.672,1.5,1.5S16.828,24,16,24c-0.828,0-1.5-0.672-1.5-1.5S15.172,21,16,21\tz M17.125,17.248c2.217-0.066,4-1.89,4-4.123C21.125,10.851,19.274,9,17,9h-2c-2.274,0-4.125,1.851-4.125,4.125v0.5h2.25v-0.5\tc0-1.034,0.841-1.875,1.875-1.875h2c1.034,0,1.875,0.841,1.875,1.875S18.034,15,17,15h-2.125v4.125h2.25V17.248z",
    "data-icon-path": "inner-path"
  })), children);
});
var Unlink32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Unlink32(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 3.59H7V8.42H5z",
    transform: "rotate(-45.01 5.996 6.005)"
  })), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23.58H27V28.409999999999997H25z",
    transform: "rotate(-44.99 25.995 25.999)"
  })), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 2H13V6H11zM2 11H6V13H2zM26 19H30V21H26zM19 26H21V30H19zM16.58 21.07l-3.71 3.72a4 4 0 11-5.66-5.66l3.72-3.72L9.51 14 5.8 17.72a6 6 0 00-.06 8.54A6 6 0 0010 28a6.07 6.07 0 004.32-1.8L18 22.49zM15.41 10.93l3.72-3.72a4 4 0 115.66 5.66l-3.72 3.72L22.49 18l3.71-3.72a6 6 0 00.06-8.54A6 6 0 0022 4a6.07 6.07 0 00-4.32 1.8L14 9.51z"
  })), children);
});
var Unlink24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Unlink24(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 3.59H7V8.42H5z",
    transform: "rotate(-45.01 5.996 6.005)"
  })), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23.58H27V28.409999999999997H25z",
    transform: "rotate(-44.99 25.995 25.999)"
  })), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 2H13V6H11zM2 11H6V13H2zM26 19H30V21H26zM19 26H21V30H19zM16.58 21.07l-3.71 3.72a4 4 0 11-5.66-5.66l3.72-3.72L9.51 14 5.8 17.72a6 6 0 00-.06 8.54A6 6 0 0010 28a6.07 6.07 0 004.32-1.8L18 22.49zM15.41 10.93l3.72-3.72a4 4 0 115.66 5.66l-3.72 3.72L22.49 18l3.71-3.72a6 6 0 00.06-8.54A6 6 0 0022 4a6.07 6.07 0 00-4.32 1.8L14 9.51z"
  })), children);
});
var Unlink20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Unlink20(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 3.59H7V8.42H5z",
    transform: "rotate(-45.01 5.996 6.005)"
  })), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23.58H27V28.409999999999997H25z",
    transform: "rotate(-44.99 25.995 25.999)"
  })), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 2H13V6H11zM2 11H6V13H2zM26 19H30V21H26zM19 26H21V30H19zM16.58 21.07l-3.71 3.72a4 4 0 11-5.66-5.66l3.72-3.72L9.51 14 5.8 17.72a6 6 0 00-.06 8.54A6 6 0 0010 28a6.07 6.07 0 004.32-1.8L18 22.49zM15.41 10.93l3.72-3.72a4 4 0 115.66 5.66l-3.72 3.72L22.49 18l3.71-3.72a6 6 0 00.06-8.54A6 6 0 0022 4a6.07 6.07 0 00-4.32 1.8L14 9.51z"
  })), children);
});
var Unlink16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Unlink16(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 3.59H7V8.42H5z",
    transform: "rotate(-45.01 5.996 6.005)"
  })), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23.58H27V28.409999999999997H25z",
    transform: "rotate(-44.99 25.995 25.999)"
  })), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 2H13V6H11zM2 11H6V13H2zM26 19H30V21H26zM19 26H21V30H19zM16.58 21.07l-3.71 3.72a4 4 0 11-5.66-5.66l3.72-3.72L9.51 14 5.8 17.72a6 6 0 00-.06 8.54A6 6 0 0010 28a6.07 6.07 0 004.32-1.8L18 22.49zM15.41 10.93l3.72-3.72a4 4 0 115.66 5.66l-3.72 3.72L22.49 18l3.71-3.72a6 6 0 00.06-8.54A6 6 0 0022 4a6.07 6.07 0 00-4.32 1.8L14 9.51z"
  })), children);
});
var Unlocked32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Unlocked32(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,14H12V8a4,4,0,0,1,8,0h2A6,6,0,0,0,10,8v6H8a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V16A2,2,0,0,0,24,14Zm0,14H8V16H24Z"
  })), children);
});
var Unlocked24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Unlocked24(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,14H12V8a4,4,0,0,1,8,0h2A6,6,0,0,0,10,8v6H8a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V16A2,2,0,0,0,24,14Zm0,14H8V16H24Z"
  })), children);
});
var Unlocked20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Unlocked20(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,14H12V8a4,4,0,0,1,8,0h2A6,6,0,0,0,10,8v6H8a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V16A2,2,0,0,0,24,14Zm0,14H8V16H24Z"
  })), children);
});
var Unlocked16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Unlocked16(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,7H6V4c0-1.1,0.9-2,2-2s2,0.9,2,2h1c0-1.7-1.3-3-3-3S5,2.3,5,4v3H4C3.4,7,3,7.4,3,8v6c0,0.6,0.4,1,1,1h8c0.6,0,1-0.4,1-1\tV8C13,7.4,12.6,7,12,7z M12,14H4V8h8V14z"
  })), children);
});
var UpToTop32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UpToTop32(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 14L6 24 7.4 25.4 16 16.8 24.6 25.4 26 24zM4 8H28V10H4z"
  })), children);
});
var UpToTop24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UpToTop24(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 14L6 24 7.4 25.4 16 16.8 24.6 25.4 26 24zM4 8H28V10H4z"
  })), children);
});
var UpToTop20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UpToTop20(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 14L6 24 7.4 25.4 16 16.8 24.6 25.4 26 24zM4 8H28V10H4z"
  })), children);
});
var UpToTop16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UpToTop16(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 14L6 24 7.4 25.4 16 16.8 24.6 25.4 26 24zM4 8H28V10H4z"
  })), children);
});
var UpdateNow32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UpdateNow32(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 25.586L25 23.586 25 21 23 21 23 24.414 25.586 27 27 25.586z"
  })), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 31a7 7 0 117-7A7.0078 7.0078 0 0124 31zm0-12a5 5 0 105 5A5.0055 5.0055 0 0024 19zM16 28A12.0134 12.0134 0 014 16H2A14.0158 14.0158 0 0016 30zM12 8H7.0784A11.9843 11.9843 0 0128 16h2A13.9778 13.9778 0 006 6.2344V2H4v8h8z"
  })), children);
});
var UpdateNow24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UpdateNow24(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 25.586L25 23.586 25 21 23 21 23 24.414 25.586 27 27 25.586z"
  })), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 31a7 7 0 117-7A7.0078 7.0078 0 0124 31zm0-12a5 5 0 105 5A5.0055 5.0055 0 0024 19zM16 28A12.0134 12.0134 0 014 16H2A14.0158 14.0158 0 0016 30zM12 8H7.0784A11.9843 11.9843 0 0128 16h2A13.9778 13.9778 0 006 6.2344V2H4v8h8z"
  })), children);
});
var UpdateNow20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UpdateNow20(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 25.586L25 23.586 25 21 23 21 23 24.414 25.586 27 27 25.586z"
  })), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 31a7 7 0 117-7A7.0078 7.0078 0 0124 31zm0-12a5 5 0 105 5A5.0055 5.0055 0 0024 19zM16 28A12.0134 12.0134 0 014 16H2A14.0158 14.0158 0 0016 30zM12 8H7.0784A11.9843 11.9843 0 0128 16h2A13.9778 13.9778 0 006 6.2344V2H4v8h8z"
  })), children);
});
var UpdateNow16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UpdateNow16(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 25.586L25 23.586 25 21 23 21 23 24.414 25.586 27 27 25.586z"
  })), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 31a7 7 0 117-7A7.0078 7.0078 0 0124 31zm0-12a5 5 0 105 5A5.0055 5.0055 0 0024 19zM16 28A12.0134 12.0134 0 014 16H2A14.0158 14.0158 0 0016 30zM12 8H7.0784A11.9843 11.9843 0 0128 16h2A13.9778 13.9778 0 006 6.2344V2H4v8h8z"
  })), children);
});
var Upgrade32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Upgrade32(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 24H11a2 2 0 00-2 2v2a2 2 0 002 2H21a2 2 0 002-2V26A2 2 0 0021 24zm0 4H11V26H21zM28.707 14.293l-12-12a.9994.9994 0 00-1.414 0l-12 12A1 1 0 004 16H9v4a2.0023 2.0023 0 002 2H21a2.0027 2.0027 0 002-2V16h5a1 1 0 00.707-1.707zM21 14v6H11V14H6.4141L16 4.4141 25.5859 14z"
  })), children);
});
var Upgrade24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Upgrade24(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 24H11a2 2 0 00-2 2v2a2 2 0 002 2H21a2 2 0 002-2V26A2 2 0 0021 24zm0 4H11V26H21zM28.707 14.293l-12-12a.9994.9994 0 00-1.414 0l-12 12A1 1 0 004 16H9v4a2.0023 2.0023 0 002 2H21a2.0027 2.0027 0 002-2V16h5a1 1 0 00.707-1.707zM21 14v6H11V14H6.4141L16 4.4141 25.5859 14z"
  })), children);
});
var Upgrade20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Upgrade20(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 24H11a2 2 0 00-2 2v2a2 2 0 002 2H21a2 2 0 002-2V26A2 2 0 0021 24zm0 4H11V26H21zM28.707 14.293l-12-12a.9994.9994 0 00-1.414 0l-12 12A1 1 0 004 16H9v4a2.0023 2.0023 0 002 2H21a2.0027 2.0027 0 002-2V16h5a1 1 0 00.707-1.707zM21 14v6H11V14H6.4141L16 4.4141 25.5859 14z"
  })), children);
});
var Upgrade16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Upgrade16(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 24H11a2 2 0 00-2 2v2a2 2 0 002 2H21a2 2 0 002-2V26A2 2 0 0021 24zm0 4H11V26H21zM28.707 14.293l-12-12a.9994.9994 0 00-1.414 0l-12 12A1 1 0 004 16H9v4a2.0023 2.0023 0 002 2H21a2.0027 2.0027 0 002-2V16h5a1 1 0 00.707-1.707zM21 14v6H11V14H6.4141L16 4.4141 25.5859 14z"
  })), children);
});
var Upload32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Upload32(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 18L7.41 19.41 15 11.83 15 30 17 30 17 11.83 24.59 19.41 26 18 16 8 6 18zM6 8V4H26V8h2V4a2 2 0 00-2-2H6A2 2 0 004 4V8z"
  })), children);
});
var Upload24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Upload24(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 18L7.41 19.41 15 11.83 15 30 17 30 17 11.83 24.59 19.41 26 18 16 8 6 18zM6 8V4H26V8h2V4a2 2 0 00-2-2H6A2 2 0 004 4V8z"
  })), children);
});
var Upload20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Upload20(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 18L7.41 19.41 15 11.83 15 30 17 30 17 11.83 24.59 19.41 26 18 16 8 6 18zM6 8V4H26V8h2V4a2 2 0 00-2-2H6A2 2 0 004 4V8z"
  })), children);
});
var Upload16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Upload16(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M3 9L3.7 9.7 7.5 5.9 7.5 15 8.5 15 8.5 5.9 12.3 9.7 13 9 8 4zM3 4V2h10v2h1V2c0-.6-.4-1-1-1H3C2.4 1 2 1.4 2 2v2H3z"
  })), children);
});
var Usb32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Usb32(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,15V6a2,2,0,0,0-2-2H10A2,2,0,0,0,8,6v9a2,2,0,0,0-2,2V28H8V17H24V28h2V17A2,2,0,0,0,24,15ZM10,6H22v9H10Z"
  })), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 10H15V12H12zM17 10H20V12H17z"
  })), children);
});
var Usb24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Usb24(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,15V6a2,2,0,0,0-2-2H10A2,2,0,0,0,8,6v9a2,2,0,0,0-2,2V28H8V17H24V28h2V17A2,2,0,0,0,24,15ZM10,6H22v9H10Z"
  })), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 10H15V12H12zM17 10H20V12H17z"
  })), children);
});
var Usb20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Usb20(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,15V6a2,2,0,0,0-2-2H10A2,2,0,0,0,8,6v9a2,2,0,0,0-2,2V28H8V17H24V28h2V17A2,2,0,0,0,24,15ZM10,6H22v9H10Z"
  })), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 10H15V12H12zM17 10H20V12H17z"
  })), children);
});
var Usb16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Usb16(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,15V6a2,2,0,0,0-2-2H10A2,2,0,0,0,8,6v9a2,2,0,0,0-2,2V28H8V17H24V28h2V17A2,2,0,0,0,24,15ZM10,6H22v9H10Z"
  })), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 10H15V12H12zM17 10H20V12H17z"
  })), children);
});
var User32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function User32(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 4a5 5 0 11-5 5 5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0016 2zM26 30H24V25a5 5 0 00-5-5H13a5 5 0 00-5 5v5H6V25a7 7 0 017-7h6a7 7 0 017 7z"
  })), children);
});
var User24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function User24(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 4a5 5 0 11-5 5 5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0016 2zM26 30H24V25a5 5 0 00-5-5H13a5 5 0 00-5 5v5H6V25a7 7 0 017-7h6a7 7 0 017 7z"
  })), children);
});
var User20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function User20(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 4a5 5 0 11-5 5 5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0016 2zM26 30H24V25a5 5 0 00-5-5H13a5 5 0 00-5 5v5H6V25a7 7 0 017-7h6a7 7 0 017 7z"
  })), children);
});
var User16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function User16(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 2c1.4 0 2.5 1.1 2.5 2.5S9.4 7 8 7 5.5 5.9 5.5 4.5 6.6 2 8 2M8 1C6.1 1 4.5 2.6 4.5 4.5S6.1 8 8 8s3.5-1.6 3.5-3.5S9.9 1 8 1zM13 15h-1v-2.5c0-1.4-1.1-2.5-2.5-2.5h-3C5.1 10 4 11.1 4 12.5V15H3v-2.5C3 10.6 4.6 9 6.5 9h3c1.9 0 3.5 1.6 3.5 3.5V15z"
  })), children);
});
var UserAccess32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAccess32(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8zM30 12a1.9922 1.9922 0 00-.5117.0742L28.4331 11.019a3.8788 3.8788 0 000-4.038l1.0552-1.0552a2.0339 2.0339 0 10-1.4141-1.4141L27.019 5.5669a3.8788 3.8788 0 00-4.038 0L21.9258 4.5117a2.0339 2.0339 0 10-1.4141 1.4141L21.5669 6.981a3.8788 3.8788 0 000 4.038l-1.0552 1.0552a2.0339 2.0339 0 101.4141 1.4141l1.0552-1.0552a3.8788 3.8788 0 004.038 0l1.0552 1.0552A1.9957 1.9957 0 1030 12zM23 9a2 2 0 112 2A2.0025 2.0025 0 0123 9z"
  })), children);
});
var UserAccess24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAccess24(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8zM30 12a1.9922 1.9922 0 00-.5117.0742L28.4331 11.019a3.8788 3.8788 0 000-4.038l1.0552-1.0552a2.0339 2.0339 0 10-1.4141-1.4141L27.019 5.5669a3.8788 3.8788 0 00-4.038 0L21.9258 4.5117a2.0339 2.0339 0 10-1.4141 1.4141L21.5669 6.981a3.8788 3.8788 0 000 4.038l-1.0552 1.0552a2.0339 2.0339 0 101.4141 1.4141l1.0552-1.0552a3.8788 3.8788 0 004.038 0l1.0552 1.0552A1.9957 1.9957 0 1030 12zM23 9a2 2 0 112 2A2.0025 2.0025 0 0123 9z"
  })), children);
});
var UserAccess20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAccess20(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8zM30 12a1.9922 1.9922 0 00-.5117.0742L28.4331 11.019a3.8788 3.8788 0 000-4.038l1.0552-1.0552a2.0339 2.0339 0 10-1.4141-1.4141L27.019 5.5669a3.8788 3.8788 0 00-4.038 0L21.9258 4.5117a2.0339 2.0339 0 10-1.4141 1.4141L21.5669 6.981a3.8788 3.8788 0 000 4.038l-1.0552 1.0552a2.0339 2.0339 0 101.4141 1.4141l1.0552-1.0552a3.8788 3.8788 0 004.038 0l1.0552 1.0552A1.9957 1.9957 0 1030 12zM23 9a2 2 0 112 2A2.0025 2.0025 0 0123 9z"
  })), children);
});
var UserAccess16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAccess16(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8zM30 12a1.9922 1.9922 0 00-.5117.0742L28.4331 11.019a3.8788 3.8788 0 000-4.038l1.0552-1.0552a2.0339 2.0339 0 10-1.4141-1.4141L27.019 5.5669a3.8788 3.8788 0 00-4.038 0L21.9258 4.5117a2.0339 2.0339 0 10-1.4141 1.4141L21.5669 6.981a3.8788 3.8788 0 000 4.038l-1.0552 1.0552a2.0339 2.0339 0 101.4141 1.4141l1.0552-1.0552a3.8788 3.8788 0 004.038 0l1.0552 1.0552A1.9957 1.9957 0 1030 12zM23 9a2 2 0 112 2A2.0025 2.0025 0 0123 9z"
  })), children);
});
var UserActivity32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserActivity32(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23h-.0215a1.0016 1.0016 0 01-.94-.7256L20.8711 11.19l-1.9346 5.1607A1.0005 1.0005 0 0118 17H14V15h3.3066l2.7569-7.3511a1.0005 1.0005 0 011.8984.0762l3.1113 10.8921 1.9786-5.9336A.9988.9988 0 0128 12h4v2H28.7207l-2.7725 8.3164A.9984.9984 0 0125 23zM15 30H13V23a3.0033 3.0033 0 00-3-3H6a3.0033 3.0033 0 00-3 3v7H1V23a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM8 8a3 3 0 11-3 3A3 3 0 018 8M8 6a5 5 0 105 5A5 5 0 008 6z"
  })), children);
});
var UserActivity24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserActivity24(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23h-.0215a1.0016 1.0016 0 01-.94-.7256L20.8711 11.19l-1.9346 5.1607A1.0005 1.0005 0 0118 17H14V15h3.3066l2.7569-7.3511a1.0005 1.0005 0 011.8984.0762l3.1113 10.8921 1.9786-5.9336A.9988.9988 0 0128 12h4v2H28.7207l-2.7725 8.3164A.9984.9984 0 0125 23zM15 30H13V23a3.0033 3.0033 0 00-3-3H6a3.0033 3.0033 0 00-3 3v7H1V23a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM8 8a3 3 0 11-3 3A3 3 0 018 8M8 6a5 5 0 105 5A5 5 0 008 6z"
  })), children);
});
var UserActivity20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserActivity20(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23h-.0215a1.0016 1.0016 0 01-.94-.7256L20.8711 11.19l-1.9346 5.1607A1.0005 1.0005 0 0118 17H14V15h3.3066l2.7569-7.3511a1.0005 1.0005 0 011.8984.0762l3.1113 10.8921 1.9786-5.9336A.9988.9988 0 0128 12h4v2H28.7207l-2.7725 8.3164A.9984.9984 0 0125 23zM15 30H13V23a3.0033 3.0033 0 00-3-3H6a3.0033 3.0033 0 00-3 3v7H1V23a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM8 8a3 3 0 11-3 3A3 3 0 018 8M8 6a5 5 0 105 5A5 5 0 008 6z"
  })), children);
});
var UserActivity16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserActivity16(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 23h-.0215a1.0016 1.0016 0 01-.94-.7256L20.8711 11.19l-1.9346 5.1607A1.0005 1.0005 0 0118 17H14V15h3.3066l2.7569-7.3511a1.0005 1.0005 0 011.8984.0762l3.1113 10.8921 1.9786-5.9336A.9988.9988 0 0128 12h4v2H28.7207l-2.7725 8.3164A.9984.9984 0 0125 23zM15 30H13V23a3.0033 3.0033 0 00-3-3H6a3.0033 3.0033 0 00-3 3v7H1V23a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM8 8a3 3 0 11-3 3A3 3 0 018 8M8 6a5 5 0 105 5A5 5 0 008 6z"
  })), children);
});
var UserAdmin32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAdmin32(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7zM25 16.18L22.41 13.59 21 15 25 19 32 12 30.59 10.59 25 16.18z"
  })), children);
});
var UserAdmin24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAdmin24(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7zM25 16.18L22.41 13.59 21 15 25 19 32 12 30.59 10.59 25 16.18z"
  })), children);
});
var UserAdmin20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAdmin20(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7zM25 16.18L22.41 13.59 21 15 25 19 32 12 30.59 10.59 25 16.18z"
  })), children);
});
var UserAdmin16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAdmin16(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7zM25 16.18L22.41 13.59 21 15 25 19 32 12 30.59 10.59 25 16.18z"
  })), children);
});
var UserAvatar32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAvatar32(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,8a5,5,0,1,0,5,5A5,5,0,0,0,16,8Zm0,8a3,3,0,1,1,3-3A3.0034,3.0034,0,0,1,16,16Z"
  })), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM10,26.3765V25a3.0033,3.0033,0,0,1,3-3h6a3.0033,3.0033,0,0,1,3,3v1.3765a11.8989,11.8989,0,0,1-12,0Zm13.9925-1.4507A5.0016,5.0016,0,0,0,19,20H13a5.0016,5.0016,0,0,0-4.9925,4.9258,12,12,0,1,1,15.985,0Z"
  })), children);
});
var UserAvatar24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAvatar24(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,8a5,5,0,1,0,5,5A5,5,0,0,0,16,8Zm0,8a3,3,0,1,1,3-3A3.0034,3.0034,0,0,1,16,16Z"
  })), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM10,26.3765V25a3.0033,3.0033,0,0,1,3-3h6a3.0033,3.0033,0,0,1,3,3v1.3765a11.8989,11.8989,0,0,1-12,0Zm13.9925-1.4507A5.0016,5.0016,0,0,0,19,20H13a5.0016,5.0016,0,0,0-4.9925,4.9258,12,12,0,1,1,15.985,0Z"
  })), children);
});
var UserAvatar20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAvatar20(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,8a5,5,0,1,0,5,5A5,5,0,0,0,16,8Zm0,8a3,3,0,1,1,3-3A3.0034,3.0034,0,0,1,16,16Z"
  })), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM10,26.3765V25a3.0033,3.0033,0,0,1,3-3h6a3.0033,3.0033,0,0,1,3,3v1.3765a11.8989,11.8989,0,0,1-12,0Zm13.9925-1.4507A5.0016,5.0016,0,0,0,19,20H13a5.0016,5.0016,0,0,0-4.9925,4.9258,12,12,0,1,1,15.985,0Z"
  })), children);
});
var UserAvatar16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAvatar16(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,1C4.1,1,1,4.1,1,8s3.1,7,7,7s7-3.1,7-7S11.9,1,8,1z M5,13.2v-1.5c0-0.9,0.6-1.6,1.5-1.7h3c0.9,0.1,1.5,0.8,1.5,1.7v1.5\tC9.1,14.3,6.9,14.3,5,13.2L5,13.2z M12,12l0-0.8c0-0.9-1.1-2.1-2.5-2.2h-3C5.1,9.1,4,10.3,4,11.7l0,0.5v0.3c-2.5-2.2-2.7-6-0.5-8.5\ts6-2.7,8.5-0.5s2.7,6,0.5,8.5c-0.1,0.2-0.3,0.3-0.5,0.5V12z"
  })), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,3C6.6,3,5.5,4.1,5.5,5.5S6.6,8,8,8s2.5-1.1,2.5-2.5S9.4,3,8,3z M8,7C7.2,7,6.5,6.3,6.5,5.5S7.2,4,8,4s1.5,0.7,1.5,1.5\tS8.8,7,8,7z"
  })), children);
});
var UserAvatarFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAvatarFilled32(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M8.0071,24.93A4.9958,4.9958,0,0,1,13,20h6a4.9959,4.9959,0,0,1,4.9929,4.93,11.94,11.94,0,0,1-15.9858,0ZM20.5,12.5A4.5,4.5,0,1,1,16,8,4.5,4.5,0,0,1,20.5,12.5Z"
  })), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.7489,24.93A13.9893,13.9893,0,1,0,2,16a13.899,13.899,0,0,0,3.2511,8.93l-.02.0166c.07.0845.15.1567.2222.2392.09.1036.1864.2.28.3008.28.3033.5674.5952.87.87.0915.0831.1864.1612.28.2417.32.2759.6484.5372.99.7813.0441.0312.0832.0693.1276.1006v-.0127a13.9011,13.9011,0,0,0,16,0V27.48c.0444-.0313.0835-.0694.1276-.1006.3412-.2441.67-.5054.99-.7813.0936-.08.1885-.1586.28-.2417.3025-.2749.59-.5668.87-.87.0933-.1006.1894-.1972.28-.3008.0719-.0825.1522-.1547.2222-.2392ZM16,8a4.5,4.5,0,1,1-4.5,4.5A4.5,4.5,0,0,1,16,8ZM8.0071,24.93A4.9957,4.9957,0,0,1,13,20h6a4.9958,4.9958,0,0,1,4.9929,4.93,11.94,11.94,0,0,1-15.9858,0Z"
  })), children);
});
var UserAvatarFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAvatarFilled24(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M8.0071,24.93A4.9958,4.9958,0,0,1,13,20h6a4.9959,4.9959,0,0,1,4.9929,4.93,11.94,11.94,0,0,1-15.9858,0ZM20.5,12.5A4.5,4.5,0,1,1,16,8,4.5,4.5,0,0,1,20.5,12.5Z"
  })), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.7489,24.93A13.9893,13.9893,0,1,0,2,16a13.899,13.899,0,0,0,3.2511,8.93l-.02.0166c.07.0845.15.1567.2222.2392.09.1036.1864.2.28.3008.28.3033.5674.5952.87.87.0915.0831.1864.1612.28.2417.32.2759.6484.5372.99.7813.0441.0312.0832.0693.1276.1006v-.0127a13.9011,13.9011,0,0,0,16,0V27.48c.0444-.0313.0835-.0694.1276-.1006.3412-.2441.67-.5054.99-.7813.0936-.08.1885-.1586.28-.2417.3025-.2749.59-.5668.87-.87.0933-.1006.1894-.1972.28-.3008.0719-.0825.1522-.1547.2222-.2392ZM16,8a4.5,4.5,0,1,1-4.5,4.5A4.5,4.5,0,0,1,16,8ZM8.0071,24.93A4.9957,4.9957,0,0,1,13,20h6a4.9958,4.9958,0,0,1,4.9929,4.93,11.94,11.94,0,0,1-15.9858,0Z"
  })), children);
});
var UserAvatarFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAvatarFilled20(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M8.0071,24.93A4.9958,4.9958,0,0,1,13,20h6a4.9959,4.9959,0,0,1,4.9929,4.93,11.94,11.94,0,0,1-15.9858,0ZM20.5,12.5A4.5,4.5,0,1,1,16,8,4.5,4.5,0,0,1,20.5,12.5Z"
  })), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.7489,24.93A13.9893,13.9893,0,1,0,2,16a13.899,13.899,0,0,0,3.2511,8.93l-.02.0166c.07.0845.15.1567.2222.2392.09.1036.1864.2.28.3008.28.3033.5674.5952.87.87.0915.0831.1864.1612.28.2417.32.2759.6484.5372.99.7813.0441.0312.0832.0693.1276.1006v-.0127a13.9011,13.9011,0,0,0,16,0V27.48c.0444-.0313.0835-.0694.1276-.1006.3412-.2441.67-.5054.99-.7813.0936-.08.1885-.1586.28-.2417.3025-.2749.59-.5668.87-.87.0933-.1006.1894-.1972.28-.3008.0719-.0825.1522-.1547.2222-.2392ZM16,8a4.5,4.5,0,1,1-4.5,4.5A4.5,4.5,0,0,1,16,8ZM8.0071,24.93A4.9957,4.9957,0,0,1,13,20h6a4.9958,4.9958,0,0,1,4.9929,4.93,11.94,11.94,0,0,1-15.9858,0Z"
  })), children);
});
var UserAvatarFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAvatarFilled16(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M8.0071,24.93A4.9958,4.9958,0,0,1,13,20h6a4.9959,4.9959,0,0,1,4.9929,4.93,11.94,11.94,0,0,1-15.9858,0ZM20.5,12.5A4.5,4.5,0,1,1,16,8,4.5,4.5,0,0,1,20.5,12.5Z"
  })), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.7489,24.93A13.9893,13.9893,0,1,0,2,16a13.899,13.899,0,0,0,3.2511,8.93l-.02.0166c.07.0845.15.1567.2222.2392.09.1036.1864.2.28.3008.28.3033.5674.5952.87.87.0915.0831.1864.1612.28.2417.32.2759.6484.5372.99.7813.0441.0312.0832.0693.1276.1006v-.0127a13.9011,13.9011,0,0,0,16,0V27.48c.0444-.0313.0835-.0694.1276-.1006.3412-.2441.67-.5054.99-.7813.0936-.08.1885-.1586.28-.2417.3025-.2749.59-.5668.87-.87.0933-.1006.1894-.1972.28-.3008.0719-.0825.1522-.1547.2222-.2392ZM16,8a4.5,4.5,0,1,1-4.5,4.5A4.5,4.5,0,0,1,16,8ZM8.0071,24.93A4.9957,4.9957,0,0,1,13,20h6a4.9958,4.9958,0,0,1,4.9929,4.93,11.94,11.94,0,0,1-15.9858,0Z"
  })), children);
});
var UserAvatarFilledAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAvatarFilledAlt32(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,8a5,5,0,1,0,5,5A5,5,0,0,0,16,8Z"
  })), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2Zm7.9925,22.9258A5.0016,5.0016,0,0,0,19,20H13a5.0016,5.0016,0,0,0-4.9925,4.9258,12,12,0,1,1,15.985,0Z"
  })), children);
});
var UserAvatarFilledAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAvatarFilledAlt24(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,8a5,5,0,1,0,5,5A5,5,0,0,0,16,8Z"
  })), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2Zm7.9925,22.9258A5.0016,5.0016,0,0,0,19,20H13a5.0016,5.0016,0,0,0-4.9925,4.9258,12,12,0,1,1,15.985,0Z"
  })), children);
});
var UserAvatarFilledAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAvatarFilledAlt20(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,8a5,5,0,1,0,5,5A5,5,0,0,0,16,8Z"
  })), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2Zm7.9925,22.9258A5.0016,5.0016,0,0,0,19,20H13a5.0016,5.0016,0,0,0-4.9925,4.9258,12,12,0,1,1,15.985,0Z"
  })), children);
});
var UserAvatarFilledAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserAvatarFilledAlt16(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,8a5,5,0,1,0,5,5A5,5,0,0,0,16,8Z"
  })), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2Zm7.9925,22.9258A5.0016,5.0016,0,0,0,19,20H13a5.0016,5.0016,0,0,0-4.9925,4.9258,12,12,0,1,1,15.985,0Z"
  })), children);
});
var UserCertification32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserCertification32(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 10L26.593 13 30 13.414 27.5 15.667 28 19 25 17.125 22 19 22.5 15.667 20 13.414 23.5 13 25 10zM22 30H20V25a5.0059 5.0059 0 00-5-5H9a5.0059 5.0059 0 00-5 5v5H2V25a7.0082 7.0082 0 017-7h6a7.0082 7.0082 0 017 7zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserCertification24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserCertification24(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 10L26.593 13 30 13.414 27.5 15.667 28 19 25 17.125 22 19 22.5 15.667 20 13.414 23.5 13 25 10zM22 30H20V25a5.0059 5.0059 0 00-5-5H9a5.0059 5.0059 0 00-5 5v5H2V25a7.0082 7.0082 0 017-7h6a7.0082 7.0082 0 017 7zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserCertification20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserCertification20(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 10L26.593 13 30 13.414 27.5 15.667 28 19 25 17.125 22 19 22.5 15.667 20 13.414 23.5 13 25 10zM22 30H20V25a5.0059 5.0059 0 00-5-5H9a5.0059 5.0059 0 00-5 5v5H2V25a7.0082 7.0082 0 017-7h6a7.0082 7.0082 0 017 7zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserCertification16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserCertification16(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 10L26.593 13 30 13.414 27.5 15.667 28 19 25 17.125 22 19 22.5 15.667 20 13.414 23.5 13 25 10zM22 30H20V25a5.0059 5.0059 0 00-5-5H9a5.0059 5.0059 0 00-5 5v5H2V25a7.0082 7.0082 0 017-7h6a7.0082 7.0082 0 017 7zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserData32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserData32(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 8H30V16H28zM23 5H25V16H23zM18 10H20V16H18zM16 30H14V24a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v6H2V24a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 9a3 3 0 11-3 3A3 3 0 019 9M9 7a5 5 0 105 5A5 5 0 009 7z"
  })), children);
});
var UserData24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserData24(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 8H30V16H28zM23 5H25V16H23zM18 10H20V16H18zM16 30H14V24a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v6H2V24a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 9a3 3 0 11-3 3A3 3 0 019 9M9 7a5 5 0 105 5A5 5 0 009 7z"
  })), children);
});
var UserData20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserData20(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 8H30V16H28zM23 5H25V16H23zM18 10H20V16H18zM16 30H14V24a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v6H2V24a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 9a3 3 0 11-3 3A3 3 0 019 9M9 7a5 5 0 105 5A5 5 0 009 7z"
  })), children);
});
var UserData16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserData16(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 8H30V16H28zM23 5H25V16H23zM18 10H20V16H18zM16 30H14V24a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v6H2V24a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 9a3 3 0 11-3 3A3 3 0 019 9M9 7a5 5 0 105 5A5 5 0 009 7z"
  })), children);
});
var UserFavorite32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFavorite32(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.303 12a2.6616 2.6616 0 00-1.9079.8058l-.3932.4054-.397-.4054a2.6615 2.6615 0 00-3.8157 0 2.7992 2.7992 0 000 3.8964L25.0019 21l4.2089-4.2978a2.7992 2.7992 0 000-3.8964A2.6616 2.6616 0 0027.303 12zM2 30H4V25a5.0059 5.0059 0 015-5h6a5.0059 5.0059 0 015 5v5h2V25a7.0082 7.0082 0 00-7-7H9a7.0082 7.0082 0 00-7 7zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserFavorite24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFavorite24(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.303 12a2.6616 2.6616 0 00-1.9079.8058l-.3932.4054-.397-.4054a2.6615 2.6615 0 00-3.8157 0 2.7992 2.7992 0 000 3.8964L25.0019 21l4.2089-4.2978a2.7992 2.7992 0 000-3.8964A2.6616 2.6616 0 0027.303 12zM2 30H4V25a5.0059 5.0059 0 015-5h6a5.0059 5.0059 0 015 5v5h2V25a7.0082 7.0082 0 00-7-7H9a7.0082 7.0082 0 00-7 7zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserFavorite20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFavorite20(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.303 12a2.6616 2.6616 0 00-1.9079.8058l-.3932.4054-.397-.4054a2.6615 2.6615 0 00-3.8157 0 2.7992 2.7992 0 000 3.8964L25.0019 21l4.2089-4.2978a2.7992 2.7992 0 000-3.8964A2.6616 2.6616 0 0027.303 12zM2 30H4V25a5.0059 5.0059 0 015-5h6a5.0059 5.0059 0 015 5v5h2V25a7.0082 7.0082 0 00-7-7H9a7.0082 7.0082 0 00-7 7zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserFavorite16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFavorite16(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.303 12a2.6616 2.6616 0 00-1.9079.8058l-.3932.4054-.397-.4054a2.6615 2.6615 0 00-3.8157 0 2.7992 2.7992 0 000 3.8964L25.0019 21l4.2089-4.2978a2.7992 2.7992 0 000-3.8964A2.6616 2.6616 0 0027.303 12zM2 30H4V25a5.0059 5.0059 0 015-5h6a5.0059 5.0059 0 015 5v5h2V25a7.0082 7.0082 0 00-7-7H9a7.0082 7.0082 0 00-7 7zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserFavoriteAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFavoriteAlt32(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.7663 4.2558A4.2121 4.2121 0 0023 4.0321a4.2121 4.2121 0 00-5.7663.2237 4.319 4.319 0 000 6.0447L22.998 16.14 23 16.1376l.002.0019 5.7643-5.839A4.319 4.319 0 0028.7663 4.2558zM27.342 8.8948l-4.34 4.3973L23 13.29l-.002.002-4.34-4.3973a2.3085 2.3085 0 010-3.2338 2.2639 2.2639 0 013.1561 0l1.181 1.2074L23 6.8634l.0049.005 1.181-1.2074a2.2639 2.2639 0 013.1561 0A2.3085 2.3085 0 0127.342 8.8948zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserFavoriteAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFavoriteAlt24(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.7663 4.2558A4.2121 4.2121 0 0023 4.0321a4.2121 4.2121 0 00-5.7663.2237 4.319 4.319 0 000 6.0447L22.998 16.14 23 16.1376l.002.0019 5.7643-5.839A4.319 4.319 0 0028.7663 4.2558zM27.342 8.8948l-4.34 4.3973L23 13.29l-.002.002-4.34-4.3973a2.3085 2.3085 0 010-3.2338 2.2639 2.2639 0 013.1561 0l1.181 1.2074L23 6.8634l.0049.005 1.181-1.2074a2.2639 2.2639 0 013.1561 0A2.3085 2.3085 0 0127.342 8.8948zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserFavoriteAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFavoriteAlt20(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.7663 4.2558A4.2121 4.2121 0 0023 4.0321a4.2121 4.2121 0 00-5.7663.2237 4.319 4.319 0 000 6.0447L22.998 16.14 23 16.1376l.002.0019 5.7643-5.839A4.319 4.319 0 0028.7663 4.2558zM27.342 8.8948l-4.34 4.3973L23 13.29l-.002.002-4.34-4.3973a2.3085 2.3085 0 010-3.2338 2.2639 2.2639 0 013.1561 0l1.181 1.2074L23 6.8634l.0049.005 1.181-1.2074a2.2639 2.2639 0 013.1561 0A2.3085 2.3085 0 0127.342 8.8948zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserFavoriteAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFavoriteAlt16(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.7663 4.2558A4.2121 4.2121 0 0023 4.0321a4.2121 4.2121 0 00-5.7663.2237 4.319 4.319 0 000 6.0447L22.998 16.14 23 16.1376l.002.0019 5.7643-5.839A4.319 4.319 0 0028.7663 4.2558zM27.342 8.8948l-4.34 4.3973L23 13.29l-.002.002-4.34-4.3973a2.3085 2.3085 0 010-3.2338 2.2639 2.2639 0 013.1561 0l1.181 1.2074L23 6.8634l.0049.005 1.181-1.2074a2.2639 2.2639 0 013.1561 0A2.3085 2.3085 0 0127.342 8.8948zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserFavoriteAltFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFavoriteAltFilled32(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.4938 3a3.4735 3.4735 0 00-2.48 1.0393l-.5111.5228-.5161-.5228a3.4792 3.4792 0 00-4.96 0 3.59 3.59 0 000 5.0251l5.4766 5.5427 5.4716-5.5427a3.59 3.59 0 000-5.0251A3.4738 3.4738 0 0026.4938 3zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserFavoriteAltFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFavoriteAltFilled24(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.4938 3a3.4735 3.4735 0 00-2.48 1.0393l-.5111.5228-.5161-.5228a3.4792 3.4792 0 00-4.96 0 3.59 3.59 0 000 5.0251l5.4766 5.5427 5.4716-5.5427a3.59 3.59 0 000-5.0251A3.4738 3.4738 0 0026.4938 3zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserFavoriteAltFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFavoriteAltFilled20(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.4938 3a3.4735 3.4735 0 00-2.48 1.0393l-.5111.5228-.5161-.5228a3.4792 3.4792 0 00-4.96 0 3.59 3.59 0 000 5.0251l5.4766 5.5427 5.4716-5.5427a3.59 3.59 0 000-5.0251A3.4738 3.4738 0 0026.4938 3zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserFavoriteAltFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFavoriteAltFilled16(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.4938 3a3.4735 3.4735 0 00-2.48 1.0393l-.5111.5228-.5161-.5228a3.4792 3.4792 0 00-4.96 0 3.59 3.59 0 000 5.0251l5.4766 5.5427 5.4716-5.5427a3.59 3.59 0 000-5.0251A3.4738 3.4738 0 0026.4938 3zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFilled32(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 30H26V25a7.0082 7.0082 0 00-7-7H13a7.0082 7.0082 0 00-7 7zM9 9a7 7 0 107-7A7 7 0 009 9z"
  })), children);
});
var UserFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFilled24(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 30H26V25a7.0082 7.0082 0 00-7-7H13a7.0082 7.0082 0 00-7 7zM9 9a7 7 0 107-7A7 7 0 009 9z"
  })), children);
});
var UserFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFilled20(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 30H26V25a7.0082 7.0082 0 00-7-7H13a7.0082 7.0082 0 00-7 7zM9 9a7 7 0 107-7A7 7 0 009 9z"
  })), children);
});
var UserFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFilled16(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 30H26V25a7.0082 7.0082 0 00-7-7H13a7.0082 7.0082 0 00-7 7zM9 9a7 7 0 107-7A7 7 0 009 9z"
  })), children);
});
var UserFollow32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFollow32(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32 14L28 14 28 10 26 10 26 14 22 14 22 16 26 16 26 20 28 20 28 16 32 16 32 14zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7z"
  })), children);
});
var UserFollow24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFollow24(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32 14L28 14 28 10 26 10 26 14 22 14 22 16 26 16 26 20 28 20 28 16 32 16 32 14zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7z"
  })), children);
});
var UserFollow20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFollow20(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32 14L28 14 28 10 26 10 26 14 22 14 22 16 26 16 26 20 28 20 28 16 32 16 32 14zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7z"
  })), children);
});
var UserFollow16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserFollow16(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32 14L28 14 28 10 26 10 26 14 22 14 22 16 26 16 26 20 28 20 28 16 32 16 32 14zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7z"
  })), children);
});
var UserIdentification32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserIdentification32(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,11h4a1,1,0,0,1,1,1v2a0,0,0,0,1,0,0H21a0,0,0,0,1,0,0V12A1,1,0,0,1,22,11Z"
  })), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "8",
    r: "2"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 18H18a2.0023 2.0023 0 01-2-2V4a2.002 2.002 0 012-2H30a2.0023 2.0023 0 012 2V16A2.0027 2.0027 0 0130 18zM18 4V16H30.001L30 4zM15 30H13V26a2.9465 2.9465 0 00-3-3H6a2.9465 2.9465 0 00-3 3v4H1V26a4.9514 4.9514 0 015-5h4a4.9514 4.9514 0 015 5zM8 11a3 3 0 010 6 3 3 0 010-6M8 9A5 5 0 008 19 5 5 0 008 9z"
  })), children);
});
var UserIdentification24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserIdentification24(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,11h4a1,1,0,0,1,1,1v2a0,0,0,0,1,0,0H21a0,0,0,0,1,0,0V12A1,1,0,0,1,22,11Z"
  })), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "8",
    r: "2"
  })), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 18H18a2.0023 2.0023 0 01-2-2V4a2.002 2.002 0 012-2H30a2.0023 2.0023 0 012 2V16A2.0027 2.0027 0 0130 18zM18 4V16H30.001L30 4zM15 30H13V26a2.9465 2.9465 0 00-3-3H6a2.9465 2.9465 0 00-3 3v4H1V26a4.9514 4.9514 0 015-5h4a4.9514 4.9514 0 015 5zM8 11a3 3 0 010 6 3 3 0 010-6M8 9A5 5 0 008 19 5 5 0 008 9z"
  })), children);
});
var UserIdentification20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserIdentification20(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,11h4a1,1,0,0,1,1,1v2a0,0,0,0,1,0,0H21a0,0,0,0,1,0,0V12A1,1,0,0,1,22,11Z"
  })), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "8",
    r: "2"
  })), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 18H18a2.0023 2.0023 0 01-2-2V4a2.002 2.002 0 012-2H30a2.0023 2.0023 0 012 2V16A2.0027 2.0027 0 0130 18zM18 4V16H30.001L30 4zM15 30H13V26a2.9465 2.9465 0 00-3-3H6a2.9465 2.9465 0 00-3 3v4H1V26a4.9514 4.9514 0 015-5h4a4.9514 4.9514 0 015 5zM8 11a3 3 0 010 6 3 3 0 010-6M8 9A5 5 0 008 19 5 5 0 008 9z"
  })), children);
});
var UserIdentification16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserIdentification16(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,11h4a1,1,0,0,1,1,1v2a0,0,0,0,1,0,0H21a0,0,0,0,1,0,0V12A1,1,0,0,1,22,11Z"
  })), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "8",
    r: "2"
  })), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 18H18a2.0023 2.0023 0 01-2-2V4a2.002 2.002 0 012-2H30a2.0023 2.0023 0 012 2V16A2.0027 2.0027 0 0130 18zM18 4V16H30.001L30 4zM15 30H13V26a2.9465 2.9465 0 00-3-3H6a2.9465 2.9465 0 00-3 3v4H1V26a4.9514 4.9514 0 015-5h4a4.9514 4.9514 0 015 5zM8 11a3 3 0 010 6 3 3 0 010-6M8 9A5 5 0 008 19 5 5 0 008 9z"
  })), children);
});
var UserMilitary32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserMilitary32(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 13L23.407 16 20 16.414 22.5 18.667 22 22 25 20.125 28 22 27.5 18.667 30 16.414 26.5 16 25 13z"
  })), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.414 13.414L25 9.834 25 9.834 28.587 13.416 30 12 25 7 20 12 21.414 13.414z"
  })), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.414 8.414L25 4.834 25 4.834 28.587 8.416 30 7 25 2 20 7 21.414 8.414zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserMilitary24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserMilitary24(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 13L23.407 16 20 16.414 22.5 18.667 22 22 25 20.125 28 22 27.5 18.667 30 16.414 26.5 16 25 13z"
  })), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.414 13.414L25 9.834 25 9.834 28.587 13.416 30 12 25 7 20 12 21.414 13.414z"
  })), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.414 8.414L25 4.834 25 4.834 28.587 8.416 30 7 25 2 20 7 21.414 8.414zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserMilitary20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserMilitary20(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 13L23.407 16 20 16.414 22.5 18.667 22 22 25 20.125 28 22 27.5 18.667 30 16.414 26.5 16 25 13z"
  })), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.414 13.414L25 9.834 25 9.834 28.587 13.416 30 12 25 7 20 12 21.414 13.414z"
  })), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.414 8.414L25 4.834 25 4.834 28.587 8.416 30 7 25 2 20 7 21.414 8.414zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserMilitary16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserMilitary16(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 13L23.407 16 20 16.414 22.5 18.667 22 22 25 20.125 28 22 27.5 18.667 30 16.414 26.5 16 25 13z"
  })), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.414 13.414L25 9.834 25 9.834 28.587 13.416 30 12 25 7 20 12 21.414 13.414z"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.414 8.414L25 4.834 25 4.834 28.587 8.416 30 7 25 2 20 7 21.414 8.414zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserMultiple32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserMultiple32(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H28V25a5.0057 5.0057 0 00-5-5V18a7.0078 7.0078 0 017 7zM22 30H20V25a5.0059 5.0059 0 00-5-5H9a5.0059 5.0059 0 00-5 5v5H2V25a7.0082 7.0082 0 017-7h6a7.0082 7.0082 0 017 7zM20 2V4a5 5 0 010 10v2A7 7 0 0020 2zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserMultiple24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserMultiple24(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H28V25a5.0057 5.0057 0 00-5-5V18a7.0078 7.0078 0 017 7zM22 30H20V25a5.0059 5.0059 0 00-5-5H9a5.0059 5.0059 0 00-5 5v5H2V25a7.0082 7.0082 0 017-7h6a7.0082 7.0082 0 017 7zM20 2V4a5 5 0 010 10v2A7 7 0 0020 2zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserMultiple20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserMultiple20(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H28V25a5.0057 5.0057 0 00-5-5V18a7.0078 7.0078 0 017 7zM22 30H20V25a5.0059 5.0059 0 00-5-5H9a5.0059 5.0059 0 00-5 5v5H2V25a7.0082 7.0082 0 017-7h6a7.0082 7.0082 0 017 7zM20 2V4a5 5 0 010 10v2A7 7 0 0020 2zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserMultiple16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserMultiple16(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30H28V25a5.0057 5.0057 0 00-5-5V18a7.0078 7.0078 0 017 7zM22 30H20V25a5.0059 5.0059 0 00-5-5H9a5.0059 5.0059 0 00-5 5v5H2V25a7.0082 7.0082 0 017-7h6a7.0082 7.0082 0 017 7zM20 2V4a5 5 0 010 10v2A7 7 0 0020 2zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserOnline32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserOnline32(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "16",
    r: "4"
  })), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserOnline24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserOnline24(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "16",
    r: "4"
  })), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserOnline20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserOnline20(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "16",
    r: "4"
  })), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserOnline16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserOnline16(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "16",
    r: "4"
  })), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserProfile32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserProfile32(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7zM22 4H32V6H22zM22 9H32V11H22zM22 14H29V16H22z"
  })), children);
});
var UserProfile24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserProfile24(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7zM22 4H32V6H22zM22 9H32V11H22zM22 14H29V16H22z"
  })), children);
});
var UserProfile20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserProfile20(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7zM22 4H32V6H22zM22 9H32V11H22zM22 14H29V16H22z"
  })), children);
});
var UserProfile16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserProfile16(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7zM22 4H32V6H22zM22 9H32V11H22zM22 14H29V16H22z"
  })), children);
});
var UserRole32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserRole32(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.07 21L22 15 28.07 9 29.5 10.41 24.86 15 29.5 19.59 28.07 21zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserRole24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserRole24(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.07 21L22 15 28.07 9 29.5 10.41 24.86 15 29.5 19.59 28.07 21zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserRole20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserRole20(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.07 21L22 15 28.07 9 29.5 10.41 24.86 15 29.5 19.59 28.07 21zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserRole16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserRole16(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.07 21L22 15 28.07 9 29.5 10.41 24.86 15 29.5 19.59 28.07 21zM22 30H20V25a5 5 0 00-5-5H9a5 5 0 00-5 5v5H2V25a7 7 0 017-7h6a7 7 0 017 7zM12 4A5 5 0 117 9a5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0012 2z"
  })), children);
});
var UserServiceDesk32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserServiceDesk32(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.334 11.95l1.2055-1.206a1.178 1.178 0 011.2593-.2584l1.4693.5868A1.1736 1.1736 0 0130 12.1489v2.692A1.1681 1.1681 0 0128.8229 16l-.05-.0015C18.4775 15.3578 16.4 6.6357 16.0073 3.2976a1.1681 1.1681 0 011.0315-1.29A1.1492 1.1492 0 0117.1751 2h2.5994a1.1626 1.1626 0 011.0764.7322l.5866 1.47a1.1635 1.1635 0 01-.2529 1.26L19.9791 6.668S20.6733 11.3682 25.334 11.95zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserServiceDesk24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserServiceDesk24(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.334 11.95l1.2055-1.206a1.178 1.178 0 011.2593-.2584l1.4693.5868A1.1736 1.1736 0 0130 12.1489v2.692A1.1681 1.1681 0 0128.8229 16l-.05-.0015C18.4775 15.3578 16.4 6.6357 16.0073 3.2976a1.1681 1.1681 0 011.0315-1.29A1.1492 1.1492 0 0117.1751 2h2.5994a1.1626 1.1626 0 011.0764.7322l.5866 1.47a1.1635 1.1635 0 01-.2529 1.26L19.9791 6.668S20.6733 11.3682 25.334 11.95zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserServiceDesk20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserServiceDesk20(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.334 11.95l1.2055-1.206a1.178 1.178 0 011.2593-.2584l1.4693.5868A1.1736 1.1736 0 0130 12.1489v2.692A1.1681 1.1681 0 0128.8229 16l-.05-.0015C18.4775 15.3578 16.4 6.6357 16.0073 3.2976a1.1681 1.1681 0 011.0315-1.29A1.1492 1.1492 0 0117.1751 2h2.5994a1.1626 1.1626 0 011.0764.7322l.5866 1.47a1.1635 1.1635 0 01-.2529 1.26L19.9791 6.668S20.6733 11.3682 25.334 11.95zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserServiceDesk16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserServiceDesk16(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.334 11.95l1.2055-1.206a1.178 1.178 0 011.2593-.2584l1.4693.5868A1.1736 1.1736 0 0130 12.1489v2.692A1.1681 1.1681 0 0128.8229 16l-.05-.0015C18.4775 15.3578 16.4 6.6357 16.0073 3.2976a1.1681 1.1681 0 011.0315-1.29A1.1492 1.1492 0 0117.1751 2h2.5994a1.1626 1.1626 0 011.0764.7322l.5866 1.47a1.1635 1.1635 0 01-.2529 1.26L19.9791 6.668S20.6733 11.3682 25.334 11.95zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserSettings32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserSettings32(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 10V8H27.8989a4.9678 4.9678 0 00-.7319-1.7529l1.49-1.49-1.414-1.414-1.49 1.49A4.9678 4.9678 0 0024 4.1011V2H22V4.1011a4.9678 4.9678 0 00-1.7529.7319l-1.49-1.49-1.414 1.414 1.49 1.49A4.9678 4.9678 0 0018.1011 8H16v2h2.1011a4.9678 4.9678 0 00.7319 1.7529l-1.49 1.49 1.414 1.414 1.49-1.49A4.9678 4.9678 0 0022 13.8989V16h2V13.8989a4.9678 4.9678 0 001.7529-.7319l1.49 1.49 1.414-1.414-1.49-1.49A4.9678 4.9678 0 0027.8989 10zm-7 2a3 3 0 113-3A3.0033 3.0033 0 0123 12zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserSettings24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserSettings24(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 10V8H27.8989a4.9678 4.9678 0 00-.7319-1.7529l1.49-1.49-1.414-1.414-1.49 1.49A4.9678 4.9678 0 0024 4.1011V2H22V4.1011a4.9678 4.9678 0 00-1.7529.7319l-1.49-1.49-1.414 1.414 1.49 1.49A4.9678 4.9678 0 0018.1011 8H16v2h2.1011a4.9678 4.9678 0 00.7319 1.7529l-1.49 1.49 1.414 1.414 1.49-1.49A4.9678 4.9678 0 0022 13.8989V16h2V13.8989a4.9678 4.9678 0 001.7529-.7319l1.49 1.49 1.414-1.414-1.49-1.49A4.9678 4.9678 0 0027.8989 10zm-7 2a3 3 0 113-3A3.0033 3.0033 0 0123 12zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserSettings20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserSettings20(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 10V8H27.8989a4.9678 4.9678 0 00-.7319-1.7529l1.49-1.49-1.414-1.414-1.49 1.49A4.9678 4.9678 0 0024 4.1011V2H22V4.1011a4.9678 4.9678 0 00-1.7529.7319l-1.49-1.49-1.414 1.414 1.49 1.49A4.9678 4.9678 0 0018.1011 8H16v2h2.1011a4.9678 4.9678 0 00.7319 1.7529l-1.49 1.49 1.414 1.414 1.49-1.49A4.9678 4.9678 0 0022 13.8989V16h2V13.8989a4.9678 4.9678 0 001.7529-.7319l1.49 1.49 1.414-1.414-1.49-1.49A4.9678 4.9678 0 0027.8989 10zm-7 2a3 3 0 113-3A3.0033 3.0033 0 0123 12zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserSettings16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserSettings16(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 10V8H27.8989a4.9678 4.9678 0 00-.7319-1.7529l1.49-1.49-1.414-1.414-1.49 1.49A4.9678 4.9678 0 0024 4.1011V2H22V4.1011a4.9678 4.9678 0 00-1.7529.7319l-1.49-1.49-1.414 1.414 1.49 1.49A4.9678 4.9678 0 0018.1011 8H16v2h2.1011a4.9678 4.9678 0 00.7319 1.7529l-1.49 1.49 1.414 1.414 1.49-1.49A4.9678 4.9678 0 0022 13.8989V16h2V13.8989a4.9678 4.9678 0 001.7529-.7319l1.49 1.49 1.414-1.414-1.49-1.49A4.9678 4.9678 0 0027.8989 10zm-7 2a3 3 0 113-3A3.0033 3.0033 0 0123 12zM16 30H14V25a3.0033 3.0033 0 00-3-3H7a3.0033 3.0033 0 00-3 3v5H2V25a5.0059 5.0059 0 015-5h4a5.0059 5.0059 0 015 5zM9 10a3 3 0 11-3 3 3 3 0 013-3M9 8a5 5 0 105 5A5 5 0 009 8z"
  })), children);
});
var UserSimulation32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserSimulation32(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.232 12.866H29.232V14.866H25.232z",
    transform: "rotate(30 27.232 13.866)"
  })), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 8H30V10H26z"
  })), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.768 12.866H6.768V14.866H2.768z",
    transform: "rotate(150 4.768 13.866)"
  })), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 30H24V25a5.0059 5.0059 0 00-5-5H13a5.0059 5.0059 0 00-5 5v5H6V25a7.0082 7.0082 0 017-7h6a7.0082 7.0082 0 017 7zM16 4a5 5 0 11-5 5 5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0016 2z"
  })), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.232 3.134H29.232V5.134H25.232z",
    transform: "rotate(-30 27.232 4.134)"
  })), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 8H6V10H2z"
  })), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.768 3.134H6.768V5.134H2.768z",
    transform: "rotate(-150 4.768 4.134)"
  })), children);
});
var UserSimulation24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserSimulation24(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.232 12.866H29.232V14.866H25.232z",
    transform: "rotate(30 27.232 13.866)"
  })), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 8H30V10H26z"
  })), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.768 12.866H6.768V14.866H2.768z",
    transform: "rotate(150 4.768 13.866)"
  })), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 30H24V25a5.0059 5.0059 0 00-5-5H13a5.0059 5.0059 0 00-5 5v5H6V25a7.0082 7.0082 0 017-7h6a7.0082 7.0082 0 017 7zM16 4a5 5 0 11-5 5 5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0016 2z"
  })), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.232 3.134H29.232V5.134H25.232z",
    transform: "rotate(-30 27.232 4.134)"
  })), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 8H6V10H2z"
  })), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.768 3.134H6.768V5.134H2.768z",
    transform: "rotate(-150 4.768 4.134)"
  })), children);
});
var UserSimulation20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserSimulation20(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.232 12.866H29.232V14.866H25.232z",
    transform: "rotate(30 27.232 13.866)"
  })), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 8H30V10H26z"
  })), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.768 12.866H6.768V14.866H2.768z",
    transform: "rotate(150 4.768 13.866)"
  })), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 30H24V25a5.0059 5.0059 0 00-5-5H13a5.0059 5.0059 0 00-5 5v5H6V25a7.0082 7.0082 0 017-7h6a7.0082 7.0082 0 017 7zM16 4a5 5 0 11-5 5 5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0016 2z"
  })), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.232 3.134H29.232V5.134H25.232z",
    transform: "rotate(-30 27.232 4.134)"
  })), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 8H6V10H2z"
  })), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.768 3.134H6.768V5.134H2.768z",
    transform: "rotate(-150 4.768 4.134)"
  })), children);
});
var UserSimulation16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserSimulation16(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.232 12.866H29.232V14.866H25.232z",
    transform: "rotate(30 27.232 13.866)"
  })), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 8H30V10H26z"
  })), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.768 12.866H6.768V14.866H2.768z",
    transform: "rotate(150 4.768 13.866)"
  })), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 30H24V25a5.0059 5.0059 0 00-5-5H13a5.0059 5.0059 0 00-5 5v5H6V25a7.0082 7.0082 0 017-7h6a7.0082 7.0082 0 017 7zM16 4a5 5 0 11-5 5 5 5 0 015-5m0-2a7 7 0 107 7A7 7 0 0016 2z"
  })), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.232 3.134H29.232V5.134H25.232z",
    transform: "rotate(-30 27.232 4.134)"
  })), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 8H6V10H2z"
  })), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.768 3.134H6.768V5.134H2.768z",
    transform: "rotate(-150 4.768 4.134)"
  })), children);
});
var UserSpeaker32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserSpeaker32(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4146,19,27.7,17.2852A2.97,2.97,0,0,0,28,16a3,3,0,1,0-3,3,2.97,2.97,0,0,0,1.2864-.3L28,20.4141V28H22V25a7.0078,7.0078,0,0,0-7-7H9a7.008,7.008,0,0,0-7,7v5H30V20.4141A1.988,1.988,0,0,0,29.4146,19ZM4,25a5.006,5.006,0,0,1,5-5h6a5.0059,5.0059,0,0,1,5,5v3H4Z"
  })), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,4A5,5,0,1,1,7,9a5,5,0,0,1,5-5m0-2a7,7,0,1,0,7,7A7,7,0,0,0,12,2Z"
  })), children);
});
var UserSpeaker24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserSpeaker24(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4146,19,27.7,17.2852A2.97,2.97,0,0,0,28,16a3,3,0,1,0-3,3,2.97,2.97,0,0,0,1.2864-.3L28,20.4141V28H22V25a7.0078,7.0078,0,0,0-7-7H9a7.008,7.008,0,0,0-7,7v5H30V20.4141A1.988,1.988,0,0,0,29.4146,19ZM4,25a5.006,5.006,0,0,1,5-5h6a5.0059,5.0059,0,0,1,5,5v3H4Z"
  })), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,4A5,5,0,1,1,7,9a5,5,0,0,1,5-5m0-2a7,7,0,1,0,7,7A7,7,0,0,0,12,2Z"
  })), children);
});
var UserSpeaker20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserSpeaker20(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4146,19,27.7,17.2852A2.97,2.97,0,0,0,28,16a3,3,0,1,0-3,3,2.97,2.97,0,0,0,1.2864-.3L28,20.4141V28H22V25a7.0078,7.0078,0,0,0-7-7H9a7.008,7.008,0,0,0-7,7v5H30V20.4141A1.988,1.988,0,0,0,29.4146,19ZM4,25a5.006,5.006,0,0,1,5-5h6a5.0059,5.0059,0,0,1,5,5v3H4Z"
  })), _path390 || (_path390 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,4A5,5,0,1,1,7,9a5,5,0,0,1,5-5m0-2a7,7,0,1,0,7,7A7,7,0,0,0,12,2Z"
  })), children);
});
var UserSpeaker16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserSpeaker16(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path391 || (_path391 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.4146,19,27.7,17.2852A2.97,2.97,0,0,0,28,16a3,3,0,1,0-3,3,2.97,2.97,0,0,0,1.2864-.3L28,20.4141V28H22V25a7.0078,7.0078,0,0,0-7-7H9a7.008,7.008,0,0,0-7,7v5H30V20.4141A1.988,1.988,0,0,0,29.4146,19ZM4,25a5.006,5.006,0,0,1,5-5h6a5.0059,5.0059,0,0,1,5,5v3H4Z"
  })), _path392 || (_path392 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,4A5,5,0,1,1,7,9a5,5,0,0,1,5-5m0-2a7,7,0,1,0,7,7A7,7,0,0,0,12,2Z"
  })), children);
});
var UserXRay32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserXRay32(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path393 || (_path393 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M28 9L28 7 25 7 25 5 23 5 23 7 20 7 20 9 23 9 23 12 20 12 20 14 23 14 23 16 25 16 25 14 28 14 28 12 25 12 25 9 28 9z"
  })), _path394 || (_path394 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 3H17a1 1 0 00-1 1V17a1 1 0 001 1H31a1 1 0 001-1V4A1 1 0 0031 3zM28 9H25v3h3v2H25v2H23V14H20V12h3V9H20V7h3V5h2V7h3zM15 30H13V26a2.9465 2.9465 0 00-3-3H6a2.9465 2.9465 0 00-3 3v4H1V26a4.9514 4.9514 0 015-5h4a4.9514 4.9514 0 015 5zM8 11a3 3 0 010 6 3 3 0 010-6M8 9A5 5 0 008 19 5 5 0 008 9z"
  })), children);
});
var UserXRay24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserXRay24(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path395 || (_path395 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M28 9L28 7 25 7 25 5 23 5 23 7 20 7 20 9 23 9 23 12 20 12 20 14 23 14 23 16 25 16 25 14 28 14 28 12 25 12 25 9 28 9z"
  })), _path396 || (_path396 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 3H17a1 1 0 00-1 1V17a1 1 0 001 1H31a1 1 0 001-1V4A1 1 0 0031 3zM28 9H25v3h3v2H25v2H23V14H20V12h3V9H20V7h3V5h2V7h3zM15 30H13V26a2.9465 2.9465 0 00-3-3H6a2.9465 2.9465 0 00-3 3v4H1V26a4.9514 4.9514 0 015-5h4a4.9514 4.9514 0 015 5zM8 11a3 3 0 010 6 3 3 0 010-6M8 9A5 5 0 008 19 5 5 0 008 9z"
  })), children);
});
var UserXRay20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserXRay20(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path397 || (_path397 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M28 9L28 7 25 7 25 5 23 5 23 7 20 7 20 9 23 9 23 12 20 12 20 14 23 14 23 16 25 16 25 14 28 14 28 12 25 12 25 9 28 9z"
  })), _path398 || (_path398 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 3H17a1 1 0 00-1 1V17a1 1 0 001 1H31a1 1 0 001-1V4A1 1 0 0031 3zM28 9H25v3h3v2H25v2H23V14H20V12h3V9H20V7h3V5h2V7h3zM15 30H13V26a2.9465 2.9465 0 00-3-3H6a2.9465 2.9465 0 00-3 3v4H1V26a4.9514 4.9514 0 015-5h4a4.9514 4.9514 0 015 5zM8 11a3 3 0 010 6 3 3 0 010-6M8 9A5 5 0 008 19 5 5 0 008 9z"
  })), children);
});
var UserXRay16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserXRay16(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path399 || (_path399 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M28 9L28 7 25 7 25 5 23 5 23 7 20 7 20 9 23 9 23 12 20 12 20 14 23 14 23 16 25 16 25 14 28 14 28 12 25 12 25 9 28 9z"
  })), _path400 || (_path400 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 3H17a1 1 0 00-1 1V17a1 1 0 001 1H31a1 1 0 001-1V4A1 1 0 0031 3zM28 9H25v3h3v2H25v2H23V14H20V12h3V9H20V7h3V5h2V7h3zM15 30H13V26a2.9465 2.9465 0 00-3-3H6a2.9465 2.9465 0 00-3 3v4H1V26a4.9514 4.9514 0 015-5h4a4.9514 4.9514 0 015 5zM8 11a3 3 0 010 6 3 3 0 010-6M8 9A5 5 0 008 19 5 5 0 008 9z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-29.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-29.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "UserProfileAlt16": () => (/* binding */ UserProfileAlt16),
/* harmony export */   "UserProfileAlt20": () => (/* binding */ UserProfileAlt20),
/* harmony export */   "UserProfileAlt24": () => (/* binding */ UserProfileAlt24),
/* harmony export */   "UserProfileAlt32": () => (/* binding */ UserProfileAlt32),
/* harmony export */   "UvIndex16": () => (/* binding */ UvIndex16),
/* harmony export */   "UvIndex20": () => (/* binding */ UvIndex20),
/* harmony export */   "UvIndex24": () => (/* binding */ UvIndex24),
/* harmony export */   "UvIndex32": () => (/* binding */ UvIndex32),
/* harmony export */   "UvIndexAlt16": () => (/* binding */ UvIndexAlt16),
/* harmony export */   "UvIndexAlt20": () => (/* binding */ UvIndexAlt20),
/* harmony export */   "UvIndexAlt24": () => (/* binding */ UvIndexAlt24),
/* harmony export */   "UvIndexAlt32": () => (/* binding */ UvIndexAlt32),
/* harmony export */   "UvIndexFilled16": () => (/* binding */ UvIndexFilled16),
/* harmony export */   "UvIndexFilled20": () => (/* binding */ UvIndexFilled20),
/* harmony export */   "UvIndexFilled24": () => (/* binding */ UvIndexFilled24),
/* harmony export */   "UvIndexFilled32": () => (/* binding */ UvIndexFilled32),
/* harmony export */   "ValueVariable16": () => (/* binding */ ValueVariable16),
/* harmony export */   "ValueVariable20": () => (/* binding */ ValueVariable20),
/* harmony export */   "ValueVariable24": () => (/* binding */ ValueVariable24),
/* harmony export */   "ValueVariable32": () => (/* binding */ ValueVariable32),
/* harmony export */   "Van16": () => (/* binding */ Van16),
/* harmony export */   "Van20": () => (/* binding */ Van20),
/* harmony export */   "Van24": () => (/* binding */ Van24),
/* harmony export */   "Van32": () => (/* binding */ Van32),
/* harmony export */   "VegetationAsset16": () => (/* binding */ VegetationAsset16),
/* harmony export */   "VegetationAsset20": () => (/* binding */ VegetationAsset20),
/* harmony export */   "VegetationAsset24": () => (/* binding */ VegetationAsset24),
/* harmony export */   "VegetationAsset32": () => (/* binding */ VegetationAsset32),
/* harmony export */   "VehicleApi16": () => (/* binding */ VehicleApi16),
/* harmony export */   "VehicleApi20": () => (/* binding */ VehicleApi20),
/* harmony export */   "VehicleApi24": () => (/* binding */ VehicleApi24),
/* harmony export */   "VehicleApi32": () => (/* binding */ VehicleApi32),
/* harmony export */   "VehicleConnected16": () => (/* binding */ VehicleConnected16),
/* harmony export */   "VehicleConnected20": () => (/* binding */ VehicleConnected20),
/* harmony export */   "VehicleConnected24": () => (/* binding */ VehicleConnected24),
/* harmony export */   "VehicleConnected32": () => (/* binding */ VehicleConnected32),
/* harmony export */   "VehicleInsights16": () => (/* binding */ VehicleInsights16),
/* harmony export */   "VehicleInsights20": () => (/* binding */ VehicleInsights20),
/* harmony export */   "VehicleInsights24": () => (/* binding */ VehicleInsights24),
/* harmony export */   "VehicleInsights32": () => (/* binding */ VehicleInsights32),
/* harmony export */   "VehicleServices16": () => (/* binding */ VehicleServices16),
/* harmony export */   "VehicleServices20": () => (/* binding */ VehicleServices20),
/* harmony export */   "VehicleServices24": () => (/* binding */ VehicleServices24),
/* harmony export */   "VehicleServices32": () => (/* binding */ VehicleServices32),
/* harmony export */   "Version16": () => (/* binding */ Version16),
/* harmony export */   "Version20": () => (/* binding */ Version20),
/* harmony export */   "Version24": () => (/* binding */ Version24),
/* harmony export */   "Version32": () => (/* binding */ Version32),
/* harmony export */   "VerticalView16": () => (/* binding */ VerticalView16),
/* harmony export */   "VerticalView20": () => (/* binding */ VerticalView20),
/* harmony export */   "VerticalView24": () => (/* binding */ VerticalView24),
/* harmony export */   "VerticalView32": () => (/* binding */ VerticalView32),
/* harmony export */   "Video16": () => (/* binding */ Video16),
/* harmony export */   "Video20": () => (/* binding */ Video20),
/* harmony export */   "Video24": () => (/* binding */ Video24),
/* harmony export */   "Video32": () => (/* binding */ Video32),
/* harmony export */   "VideoAdd16": () => (/* binding */ VideoAdd16),
/* harmony export */   "VideoAdd20": () => (/* binding */ VideoAdd20),
/* harmony export */   "VideoAdd24": () => (/* binding */ VideoAdd24),
/* harmony export */   "VideoAdd32": () => (/* binding */ VideoAdd32),
/* harmony export */   "VideoChat16": () => (/* binding */ VideoChat16),
/* harmony export */   "VideoChat20": () => (/* binding */ VideoChat20),
/* harmony export */   "VideoChat24": () => (/* binding */ VideoChat24),
/* harmony export */   "VideoChat32": () => (/* binding */ VideoChat32),
/* harmony export */   "VideoFilled16": () => (/* binding */ VideoFilled16),
/* harmony export */   "VideoFilled20": () => (/* binding */ VideoFilled20),
/* harmony export */   "VideoFilled24": () => (/* binding */ VideoFilled24),
/* harmony export */   "VideoFilled32": () => (/* binding */ VideoFilled32),
/* harmony export */   "VideoOff16": () => (/* binding */ VideoOff16),
/* harmony export */   "VideoOff20": () => (/* binding */ VideoOff20),
/* harmony export */   "VideoOff24": () => (/* binding */ VideoOff24),
/* harmony export */   "VideoOff32": () => (/* binding */ VideoOff32),
/* harmony export */   "VideoOffFilled16": () => (/* binding */ VideoOffFilled16),
/* harmony export */   "VideoOffFilled20": () => (/* binding */ VideoOffFilled20),
/* harmony export */   "VideoOffFilled24": () => (/* binding */ VideoOffFilled24),
/* harmony export */   "VideoOffFilled32": () => (/* binding */ VideoOffFilled32),
/* harmony export */   "View16": () => (/* binding */ View16),
/* harmony export */   "View20": () => (/* binding */ View20),
/* harmony export */   "View24": () => (/* binding */ View24),
/* harmony export */   "View32": () => (/* binding */ View32),
/* harmony export */   "ViewFilled16": () => (/* binding */ ViewFilled16),
/* harmony export */   "ViewFilled20": () => (/* binding */ ViewFilled20),
/* harmony export */   "ViewFilled24": () => (/* binding */ ViewFilled24),
/* harmony export */   "ViewFilled32": () => (/* binding */ ViewFilled32),
/* harmony export */   "ViewMode_116": () => (/* binding */ ViewMode_116),
/* harmony export */   "ViewMode_120": () => (/* binding */ ViewMode_120),
/* harmony export */   "ViewMode_124": () => (/* binding */ ViewMode_124),
/* harmony export */   "ViewMode_132": () => (/* binding */ ViewMode_132),
/* harmony export */   "ViewMode_216": () => (/* binding */ ViewMode_216),
/* harmony export */   "ViewMode_220": () => (/* binding */ ViewMode_220),
/* harmony export */   "ViewMode_224": () => (/* binding */ ViewMode_224),
/* harmony export */   "ViewMode_232": () => (/* binding */ ViewMode_232),
/* harmony export */   "ViewNext16": () => (/* binding */ ViewNext16),
/* harmony export */   "ViewNext20": () => (/* binding */ ViewNext20),
/* harmony export */   "ViewNext24": () => (/* binding */ ViewNext24),
/* harmony export */   "ViewNext32": () => (/* binding */ ViewNext32),
/* harmony export */   "ViewOff16": () => (/* binding */ ViewOff16),
/* harmony export */   "ViewOff20": () => (/* binding */ ViewOff20),
/* harmony export */   "ViewOff24": () => (/* binding */ ViewOff24),
/* harmony export */   "ViewOff32": () => (/* binding */ ViewOff32),
/* harmony export */   "ViewOffFilled16": () => (/* binding */ ViewOffFilled16),
/* harmony export */   "ViewOffFilled20": () => (/* binding */ ViewOffFilled20),
/* harmony export */   "ViewOffFilled24": () => (/* binding */ ViewOffFilled24),
/* harmony export */   "ViewOffFilled32": () => (/* binding */ ViewOffFilled32),
/* harmony export */   "VirtualColumn16": () => (/* binding */ VirtualColumn16),
/* harmony export */   "VirtualColumn20": () => (/* binding */ VirtualColumn20),
/* harmony export */   "VirtualColumn24": () => (/* binding */ VirtualColumn24),
/* harmony export */   "VirtualColumn32": () => (/* binding */ VirtualColumn32),
/* harmony export */   "VirtualColumnKey16": () => (/* binding */ VirtualColumnKey16),
/* harmony export */   "VirtualColumnKey20": () => (/* binding */ VirtualColumnKey20),
/* harmony export */   "VirtualColumnKey24": () => (/* binding */ VirtualColumnKey24),
/* harmony export */   "VirtualColumnKey32": () => (/* binding */ VirtualColumnKey32),
/* harmony export */   "VirtualDesktop16": () => (/* binding */ VirtualDesktop16),
/* harmony export */   "VirtualDesktop20": () => (/* binding */ VirtualDesktop20),
/* harmony export */   "VirtualDesktop24": () => (/* binding */ VirtualDesktop24),
/* harmony export */   "VirtualDesktop32": () => (/* binding */ VirtualDesktop32),
/* harmony export */   "VirtualMachine16": () => (/* binding */ VirtualMachine16),
/* harmony export */   "VirtualMachine20": () => (/* binding */ VirtualMachine20),
/* harmony export */   "VirtualMachine24": () => (/* binding */ VirtualMachine24),
/* harmony export */   "VirtualMachine32": () => (/* binding */ VirtualMachine32),
/* harmony export */   "VirtualPrivateCloud16": () => (/* binding */ VirtualPrivateCloud16),
/* harmony export */   "VirtualPrivateCloud20": () => (/* binding */ VirtualPrivateCloud20),
/* harmony export */   "VirtualPrivateCloud24": () => (/* binding */ VirtualPrivateCloud24),
/* harmony export */   "VirtualPrivateCloud32": () => (/* binding */ VirtualPrivateCloud32),
/* harmony export */   "VirtualPrivateCloudAlt16": () => (/* binding */ VirtualPrivateCloudAlt16),
/* harmony export */   "VirtualPrivateCloudAlt20": () => (/* binding */ VirtualPrivateCloudAlt20),
/* harmony export */   "VirtualPrivateCloudAlt24": () => (/* binding */ VirtualPrivateCloudAlt24),
/* harmony export */   "VirtualPrivateCloudAlt32": () => (/* binding */ VirtualPrivateCloudAlt32),
/* harmony export */   "VisualRecognition16": () => (/* binding */ VisualRecognition16),
/* harmony export */   "VisualRecognition20": () => (/* binding */ VisualRecognition20),
/* harmony export */   "VisualRecognition24": () => (/* binding */ VisualRecognition24),
/* harmony export */   "VisualRecognition32": () => (/* binding */ VisualRecognition32),
/* harmony export */   "Vlan16": () => (/* binding */ Vlan16),
/* harmony export */   "Vlan20": () => (/* binding */ Vlan20),
/* harmony export */   "Vlan24": () => (/* binding */ Vlan24),
/* harmony export */   "Vlan32": () => (/* binding */ Vlan32),
/* harmony export */   "VlanIbm16": () => (/* binding */ VlanIbm16),
/* harmony export */   "VlanIbm20": () => (/* binding */ VlanIbm20),
/* harmony export */   "VlanIbm24": () => (/* binding */ VlanIbm24),
/* harmony export */   "VlanIbm32": () => (/* binding */ VlanIbm32),
/* harmony export */   "VmdkDisk16": () => (/* binding */ VmdkDisk16),
/* harmony export */   "VmdkDisk20": () => (/* binding */ VmdkDisk20),
/* harmony export */   "VmdkDisk24": () => (/* binding */ VmdkDisk24),
/* harmony export */   "VmdkDisk32": () => (/* binding */ VmdkDisk32),
/* harmony export */   "VoiceActivate16": () => (/* binding */ VoiceActivate16),
/* harmony export */   "VoiceActivate20": () => (/* binding */ VoiceActivate20),
/* harmony export */   "VoiceActivate24": () => (/* binding */ VoiceActivate24),
/* harmony export */   "VoiceActivate32": () => (/* binding */ VoiceActivate32),
/* harmony export */   "Voicemail16": () => (/* binding */ Voicemail16),
/* harmony export */   "Voicemail20": () => (/* binding */ Voicemail20),
/* harmony export */   "Voicemail24": () => (/* binding */ Voicemail24),
/* harmony export */   "Voicemail32": () => (/* binding */ Voicemail32),
/* harmony export */   "VolumeBlockStorage16": () => (/* binding */ VolumeBlockStorage16),
/* harmony export */   "VolumeBlockStorage20": () => (/* binding */ VolumeBlockStorage20),
/* harmony export */   "VolumeBlockStorage24": () => (/* binding */ VolumeBlockStorage24),
/* harmony export */   "VolumeBlockStorage32": () => (/* binding */ VolumeBlockStorage32),
/* harmony export */   "VolumeDown16": () => (/* binding */ VolumeDown16),
/* harmony export */   "VolumeDown20": () => (/* binding */ VolumeDown20),
/* harmony export */   "VolumeDown24": () => (/* binding */ VolumeDown24),
/* harmony export */   "VolumeDown32": () => (/* binding */ VolumeDown32),
/* harmony export */   "VolumeDownAlt16": () => (/* binding */ VolumeDownAlt16),
/* harmony export */   "VolumeDownAlt20": () => (/* binding */ VolumeDownAlt20),
/* harmony export */   "VolumeDownAlt24": () => (/* binding */ VolumeDownAlt24),
/* harmony export */   "VolumeDownAlt32": () => (/* binding */ VolumeDownAlt32),
/* harmony export */   "VolumeDownFilled16": () => (/* binding */ VolumeDownFilled16),
/* harmony export */   "VolumeDownFilled20": () => (/* binding */ VolumeDownFilled20),
/* harmony export */   "VolumeDownFilled24": () => (/* binding */ VolumeDownFilled24),
/* harmony export */   "VolumeDownFilled32": () => (/* binding */ VolumeDownFilled32),
/* harmony export */   "VolumeDownFilledAlt16": () => (/* binding */ VolumeDownFilledAlt16),
/* harmony export */   "VolumeDownFilledAlt20": () => (/* binding */ VolumeDownFilledAlt20),
/* harmony export */   "VolumeDownFilledAlt24": () => (/* binding */ VolumeDownFilledAlt24),
/* harmony export */   "VolumeDownFilledAlt32": () => (/* binding */ VolumeDownFilledAlt32),
/* harmony export */   "VolumeFileStorage16": () => (/* binding */ VolumeFileStorage16),
/* harmony export */   "VolumeFileStorage20": () => (/* binding */ VolumeFileStorage20),
/* harmony export */   "VolumeFileStorage24": () => (/* binding */ VolumeFileStorage24),
/* harmony export */   "VolumeFileStorage32": () => (/* binding */ VolumeFileStorage32),
/* harmony export */   "VolumeMute16": () => (/* binding */ VolumeMute16),
/* harmony export */   "VolumeMute20": () => (/* binding */ VolumeMute20),
/* harmony export */   "VolumeMute24": () => (/* binding */ VolumeMute24),
/* harmony export */   "VolumeMute32": () => (/* binding */ VolumeMute32),
/* harmony export */   "VolumeMuteFilled16": () => (/* binding */ VolumeMuteFilled16),
/* harmony export */   "VolumeMuteFilled20": () => (/* binding */ VolumeMuteFilled20),
/* harmony export */   "VolumeMuteFilled24": () => (/* binding */ VolumeMuteFilled24),
/* harmony export */   "VolumeMuteFilled32": () => (/* binding */ VolumeMuteFilled32),
/* harmony export */   "VolumeObjectStorage16": () => (/* binding */ VolumeObjectStorage16),
/* harmony export */   "VolumeObjectStorage20": () => (/* binding */ VolumeObjectStorage20),
/* harmony export */   "VolumeObjectStorage24": () => (/* binding */ VolumeObjectStorage24),
/* harmony export */   "VolumeObjectStorage32": () => (/* binding */ VolumeObjectStorage32),
/* harmony export */   "VolumeUp16": () => (/* binding */ VolumeUp16),
/* harmony export */   "VolumeUp20": () => (/* binding */ VolumeUp20),
/* harmony export */   "VolumeUp24": () => (/* binding */ VolumeUp24),
/* harmony export */   "VolumeUp32": () => (/* binding */ VolumeUp32),
/* harmony export */   "VolumeUpAlt16": () => (/* binding */ VolumeUpAlt16),
/* harmony export */   "VolumeUpAlt20": () => (/* binding */ VolumeUpAlt20),
/* harmony export */   "VolumeUpAlt24": () => (/* binding */ VolumeUpAlt24),
/* harmony export */   "VolumeUpAlt32": () => (/* binding */ VolumeUpAlt32),
/* harmony export */   "VolumeUpFilled16": () => (/* binding */ VolumeUpFilled16),
/* harmony export */   "VolumeUpFilled20": () => (/* binding */ VolumeUpFilled20),
/* harmony export */   "VolumeUpFilled24": () => (/* binding */ VolumeUpFilled24),
/* harmony export */   "VolumeUpFilled32": () => (/* binding */ VolumeUpFilled32),
/* harmony export */   "VolumeUpFilledAlt16": () => (/* binding */ VolumeUpFilledAlt16),
/* harmony export */   "VolumeUpFilledAlt20": () => (/* binding */ VolumeUpFilledAlt20),
/* harmony export */   "VolumeUpFilledAlt24": () => (/* binding */ VolumeUpFilledAlt24),
/* harmony export */   "VolumeUpFilledAlt32": () => (/* binding */ VolumeUpFilledAlt32),
/* harmony export */   "Vpn16": () => (/* binding */ Vpn16),
/* harmony export */   "Vpn20": () => (/* binding */ Vpn20),
/* harmony export */   "Vpn24": () => (/* binding */ Vpn24),
/* harmony export */   "Vpn32": () => (/* binding */ Vpn32),
/* harmony export */   "VpnConnection16": () => (/* binding */ VpnConnection16),
/* harmony export */   "VpnConnection20": () => (/* binding */ VpnConnection20),
/* harmony export */   "VpnConnection24": () => (/* binding */ VpnConnection24),
/* harmony export */   "VpnConnection32": () => (/* binding */ VpnConnection32),
/* harmony export */   "VpnPolicy16": () => (/* binding */ VpnPolicy16),
/* harmony export */   "VpnPolicy20": () => (/* binding */ VpnPolicy20),
/* harmony export */   "VpnPolicy24": () => (/* binding */ VpnPolicy24),
/* harmony export */   "VpnPolicy32": () => (/* binding */ VpnPolicy32),
/* harmony export */   "Wallet16": () => (/* binding */ Wallet16),
/* harmony export */   "Wallet20": () => (/* binding */ Wallet20),
/* harmony export */   "Wallet24": () => (/* binding */ Wallet24),
/* harmony export */   "Wallet32": () => (/* binding */ Wallet32),
/* harmony export */   "Warning16": () => (/* binding */ Warning16),
/* harmony export */   "Warning20": () => (/* binding */ Warning20),
/* harmony export */   "Warning24": () => (/* binding */ Warning24),
/* harmony export */   "Warning32": () => (/* binding */ Warning32),
/* harmony export */   "WarningAlt16": () => (/* binding */ WarningAlt16),
/* harmony export */   "WarningAlt20": () => (/* binding */ WarningAlt20),
/* harmony export */   "WarningAlt24": () => (/* binding */ WarningAlt24),
/* harmony export */   "WarningAlt32": () => (/* binding */ WarningAlt32),
/* harmony export */   "WarningAltFilled16": () => (/* binding */ WarningAltFilled16),
/* harmony export */   "WarningAltFilled20": () => (/* binding */ WarningAltFilled20),
/* harmony export */   "WarningAltFilled24": () => (/* binding */ WarningAltFilled24),
/* harmony export */   "WarningAltFilled32": () => (/* binding */ WarningAltFilled32),
/* harmony export */   "WarningAltInverted16": () => (/* binding */ WarningAltInverted16),
/* harmony export */   "WarningAltInverted20": () => (/* binding */ WarningAltInverted20),
/* harmony export */   "WarningAltInverted24": () => (/* binding */ WarningAltInverted24),
/* harmony export */   "WarningAltInverted32": () => (/* binding */ WarningAltInverted32),
/* harmony export */   "WarningAltInvertedFilled16": () => (/* binding */ WarningAltInvertedFilled16),
/* harmony export */   "WarningAltInvertedFilled20": () => (/* binding */ WarningAltInvertedFilled20),
/* harmony export */   "WarningAltInvertedFilled24": () => (/* binding */ WarningAltInvertedFilled24),
/* harmony export */   "WarningAltInvertedFilled32": () => (/* binding */ WarningAltInvertedFilled32),
/* harmony export */   "WarningFilled16": () => (/* binding */ WarningFilled16),
/* harmony export */   "WarningFilled20": () => (/* binding */ WarningFilled20),
/* harmony export */   "WarningFilled24": () => (/* binding */ WarningFilled24),
/* harmony export */   "WarningFilled32": () => (/* binding */ WarningFilled32),
/* harmony export */   "WarningHex16": () => (/* binding */ WarningHex16),
/* harmony export */   "WarningHex20": () => (/* binding */ WarningHex20),
/* harmony export */   "WarningHex24": () => (/* binding */ WarningHex24),
/* harmony export */   "WarningHex32": () => (/* binding */ WarningHex32),
/* harmony export */   "WarningHexFilled24": () => (/* binding */ WarningHexFilled24),
/* harmony export */   "WarningHexFilled32": () => (/* binding */ WarningHexFilled32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _circle, _path41, _path42, _circle2, _path43, _path44, _circle3, _path45, _path46, _circle4, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _path65, _path66, _path67, _path68, _path69, _path70, _path71, _path72, _path73, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _circle5, _path125, _circle6, _path126, _circle7, _path127, _circle8, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _circle9, _path169, _path170, _circle10, _path171, _path172, _circle11, _path173, _path174, _circle12, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _circle13, _path209, _circle14, _path210, _circle15, _path211, _circle16, _path212, _path213, _path214, _path215, _path216, _path217, _circle17, _path218, _circle18, _path219, _circle19, _path220, _circle20, _circle21, _path221, _circle22, _path222, _path223, _circle23, _path224, _circle24, _path225, _path226, _circle25, _path227, _circle26, _path228, _path229, _circle27, _path230, _circle28, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388, _path389, _path390, _path391, _path392, _path393, _path394, _path395, _path396, _path397, _path398, _path399, _path400, _path401, _path402, _path403, _path404, _path405, _path406, _path407, _path408, _path409, _path410, _path411, _path412;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var UserProfileAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserProfileAlt32(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13H26V15H19zM19 8H30V10H19zM19 3H30V5H19zM11 30H7a2.0059 2.0059 0 01-2-2V21a2.0059 2.0059 0 01-2-2V13a2.9465 2.9465 0 013-3h6a2.9465 2.9465 0 013 3v6a2.0059 2.0059 0 01-2 2v7A2.0059 2.0059 0 0111 30zM6 12a.9448.9448 0 00-1 1v6H7v9h4V19h2V13a.9448.9448 0 00-1-1zM9 9a4 4 0 114-4h0A4.0118 4.0118 0 019 9zM9 3a2 2 0 102 2h0A2.0059 2.0059 0 009 3z"
  })), children);
});
var UserProfileAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserProfileAlt24(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13H26V15H19zM19 8H30V10H19zM19 3H30V5H19zM11 30H7a2.0059 2.0059 0 01-2-2V21a2.0059 2.0059 0 01-2-2V13a2.9465 2.9465 0 013-3h6a2.9465 2.9465 0 013 3v6a2.0059 2.0059 0 01-2 2v7A2.0059 2.0059 0 0111 30zM6 12a.9448.9448 0 00-1 1v6H7v9h4V19h2V13a.9448.9448 0 00-1-1zM9 9a4 4 0 114-4h0A4.0118 4.0118 0 019 9zM9 3a2 2 0 102 2h0A2.0059 2.0059 0 009 3z"
  })), children);
});
var UserProfileAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserProfileAlt20(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13H26V15H19zM19 8H30V10H19zM19 3H30V5H19zM11 30H7a2.0059 2.0059 0 01-2-2V21a2.0059 2.0059 0 01-2-2V13a2.9465 2.9465 0 013-3h6a2.9465 2.9465 0 013 3v6a2.0059 2.0059 0 01-2 2v7A2.0059 2.0059 0 0111 30zM6 12a.9448.9448 0 00-1 1v6H7v9h4V19h2V13a.9448.9448 0 00-1-1zM9 9a4 4 0 114-4h0A4.0118 4.0118 0 019 9zM9 3a2 2 0 102 2h0A2.0059 2.0059 0 009 3z"
  })), children);
});
var UserProfileAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UserProfileAlt16(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13H26V15H19zM19 8H30V10H19zM19 3H30V5H19zM11 30H7a2.0059 2.0059 0 01-2-2V21a2.0059 2.0059 0 01-2-2V13a2.9465 2.9465 0 013-3h6a2.9465 2.9465 0 013 3v6a2.0059 2.0059 0 01-2 2v7A2.0059 2.0059 0 0111 30zM6 12a.9448.9448 0 00-1 1v6H7v9h4V19h2V13a.9448.9448 0 00-1-1zM9 9a4 4 0 114-4h0A4.0118 4.0118 0 019 9zM9 3a2 2 0 102 2h0A2.0059 2.0059 0 009 3z"
  })), children);
});
var UvIndex32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UvIndex32(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,5.9121l1.7444,2.9326.7822,1.315,1.4739-.4107,3.1206-.87L22.2512,12,21.84,13.4731l1.315.7823L26.0876,16l-2.9323,1.7441-1.315.7818L22.2512,20l.87,3.1211-3.1208-.87L18.5266,21.84l-.7822,1.315L16,26.0879l-1.7444-2.9326-.7822-1.315L12,22.251l-3.1208.87L9.7488,20l.4109-1.4741-1.315-.7818L5.9124,16l2.9323-1.7446,1.315-.7823L9.7488,12l-.87-3.1206L12,9.749l1.4739.4107.7822-1.315L16,5.9121M16,2,12.5366,7.8223,6,6l1.8223,6.5366L2,16l5.8223,3.4629L6,26l6.5366-1.8223L16,30l3.4634-5.8223L26,26l-1.8223-6.5371L30,16l-5.8223-3.4634L26,6,19.4634,7.8223,16,2Z"
  })), children);
});
var UvIndex24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UvIndex24(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,5.9121l1.7444,2.9326.7822,1.315,1.4739-.4107,3.1206-.87L22.2512,12,21.84,13.4731l1.315.7823L26.0876,16l-2.9323,1.7441-1.315.7818L22.2512,20l.87,3.1211-3.1208-.87L18.5266,21.84l-.7822,1.315L16,26.0879l-1.7444-2.9326-.7822-1.315L12,22.251l-3.1208.87L9.7488,20l.4109-1.4741-1.315-.7818L5.9124,16l2.9323-1.7446,1.315-.7823L9.7488,12l-.87-3.1206L12,9.749l1.4739.4107.7822-1.315L16,5.9121M16,2,12.5366,7.8223,6,6l1.8223,6.5366L2,16l5.8223,3.4629L6,26l6.5366-1.8223L16,30l3.4634-5.8223L26,26l-1.8223-6.5371L30,16l-5.8223-3.4634L26,6,19.4634,7.8223,16,2Z"
  })), children);
});
var UvIndex20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UvIndex20(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,5.9121l1.7444,2.9326.7822,1.315,1.4739-.4107,3.1206-.87L22.2512,12,21.84,13.4731l1.315.7823L26.0876,16l-2.9323,1.7441-1.315.7818L22.2512,20l.87,3.1211-3.1208-.87L18.5266,21.84l-.7822,1.315L16,26.0879l-1.7444-2.9326-.7822-1.315L12,22.251l-3.1208.87L9.7488,20l.4109-1.4741-1.315-.7818L5.9124,16l2.9323-1.7446,1.315-.7823L9.7488,12l-.87-3.1206L12,9.749l1.4739.4107.7822-1.315L16,5.9121M16,2,12.5366,7.8223,6,6l1.8223,6.5366L2,16l5.8223,3.4629L6,26l6.5366-1.8223L16,30l3.4634-5.8223L26,26l-1.8223-6.5371L30,16l-5.8223-3.4634L26,6,19.4634,7.8223,16,2Z"
  })), children);
});
var UvIndex16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UvIndex16(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,5.9121l1.7444,2.9326.7822,1.315,1.4739-.4107,3.1206-.87L22.2512,12,21.84,13.4731l1.315.7823L26.0876,16l-2.9323,1.7441-1.315.7818L22.2512,20l.87,3.1211-3.1208-.87L18.5266,21.84l-.7822,1.315L16,26.0879l-1.7444-2.9326-.7822-1.315L12,22.251l-3.1208.87L9.7488,20l.4109-1.4741-1.315-.7818L5.9124,16l2.9323-1.7446,1.315-.7823L9.7488,12l-.87-3.1206L12,9.749l1.4739.4107.7822-1.315L16,5.9121M16,2,12.5366,7.8223,6,6l1.8223,6.5366L2,16l5.8223,3.4629L6,26l6.5366-1.8223L16,30l3.4634-5.8223L26,26l-1.8223-6.5371L30,16l-5.8223-3.4634L26,6,19.4634,7.8223,16,2Z"
  })), children);
});
var UvIndexAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UvIndexAlt32(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 30H9a2.0027 2.0027 0 01-2-2V20H9v8h4V20h2v8A2.0027 2.0027 0 0113 30zM25 20L23.25 20 21 29.031 18.792 20 17 20 19.5 30 22.5 30 25 20zM15 2H17V7H15z"
  })), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.147 7.853)"
  })), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15H30V17H25zM2 15H7V17H2z"
  })), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.854 7.853)"
  })), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,17H20V16a4,4,0,0,0-8,0v1H10V16a6,6,0,0,1,12,0Z"
  })), children);
});
var UvIndexAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UvIndexAlt24(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 30H9a2.0027 2.0027 0 01-2-2V20H9v8h4V20h2v8A2.0027 2.0027 0 0113 30zM25 20L23.25 20 21 29.031 18.792 20 17 20 19.5 30 22.5 30 25 20zM15 2H17V7H15z"
  })), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.147 7.853)"
  })), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15H30V17H25zM2 15H7V17H2z"
  })), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.854 7.853)"
  })), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,17H20V16a4,4,0,0,0-8,0v1H10V16a6,6,0,0,1,12,0Z"
  })), children);
});
var UvIndexAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UvIndexAlt20(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 30H9a2.0027 2.0027 0 01-2-2V20H9v8h4V20h2v8A2.0027 2.0027 0 0113 30zM25 20L23.25 20 21 29.031 18.792 20 17 20 19.5 30 22.5 30 25 20zM15 2H17V7H15z"
  })), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.147 7.853)"
  })), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15H30V17H25zM2 15H7V17H2z"
  })), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.854 7.853)"
  })), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,17H20V16a4,4,0,0,0-8,0v1H10V16a6,6,0,0,1,12,0Z"
  })), children);
});
var UvIndexAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UvIndexAlt16(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 30H9a2.0027 2.0027 0 01-2-2V20H9v8h4V20h2v8A2.0027 2.0027 0 0113 30zM25 20L23.25 20 21 29.031 18.792 20 17 20 19.5 30 22.5 30 25 20zM15 2H17V7H15z"
  })), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.668 6.854H26.625999999999998V8.854H21.668z",
    transform: "rotate(-45 24.147 7.853)"
  })), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 15H30V17H25zM2 15H7V17H2z"
  })), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.854 5.375H8.854V10.333H6.854z",
    transform: "rotate(-45 7.854 7.853)"
  })), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,17H20V16a4,4,0,0,0-8,0v1H10V16a6,6,0,0,1,12,0Z"
  })), children);
});
var UvIndexFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UvIndexFilled32(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30l-3.4634-5.8223L6,26l1.8223-6.5369L2,16l5.8223-3.4631L6,6l6.5366,1.8223L16,2l3.4634,5.8223L26,6l-1.8223,6.5369L30,16l-5.8223,3.4631L26,26l-6.5366-1.8223Z"
  })), children);
});
var UvIndexFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UvIndexFilled24(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30l-3.4634-5.8223L6,26l1.8223-6.5369L2,16l5.8223-3.4631L6,6l6.5366,1.8223L16,2l3.4634,5.8223L26,6l-1.8223,6.5369L30,16l-5.8223,3.4631L26,26l-6.5366-1.8223Z"
  })), children);
});
var UvIndexFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UvIndexFilled20(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30l-3.4634-5.8223L6,26l1.8223-6.5369L2,16l5.8223-3.4631L6,6l6.5366,1.8223L16,2l3.4634,5.8223L26,6l-1.8223,6.5369L30,16l-5.8223,3.4631L26,26l-6.5366-1.8223Z"
  })), children);
});
var UvIndexFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function UvIndexFilled16(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30l-3.4634-5.8223L6,26l1.8223-6.5369L2,16l5.8223-3.4631L6,6l6.5366,1.8223L16,2l3.4634,5.8223L26,6l-1.8223,6.5369L30,16l-5.8223,3.4631L26,26l-6.5366-1.8223Z"
  })), children);
});
var ValueVariable32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ValueVariable32(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 28H22V26h4V6H22V4h4a2.0021 2.0021 0 012 2V26A2.0021 2.0021 0 0126 28zM20 11L18 11 16 14.897 14 11 12 11 14.905 16 12 21 14 21 16 17.201 18 21 20 21 17.098 16 20 11zM10 28H6a2.0021 2.0021 0 01-2-2V6A2.0021 2.0021 0 016 4h4V6H6V26h4z"
  })), children);
});
var ValueVariable24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ValueVariable24(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 28H22V26h4V6H22V4h4a2.0021 2.0021 0 012 2V26A2.0021 2.0021 0 0126 28zM20 11L18 11 16 14.897 14 11 12 11 14.905 16 12 21 14 21 16 17.201 18 21 20 21 17.098 16 20 11zM10 28H6a2.0021 2.0021 0 01-2-2V6A2.0021 2.0021 0 016 4h4V6H6V26h4z"
  })), children);
});
var ValueVariable20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ValueVariable20(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 28H22V26h4V6H22V4h4a2.0021 2.0021 0 012 2V26A2.0021 2.0021 0 0126 28zM20 11L18 11 16 14.897 14 11 12 11 14.905 16 12 21 14 21 16 17.201 18 21 20 21 17.098 16 20 11zM10 28H6a2.0021 2.0021 0 01-2-2V6A2.0021 2.0021 0 016 4h4V6H6V26h4z"
  })), children);
});
var ValueVariable16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ValueVariable16(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 28H22V26h4V6H22V4h4a2.0021 2.0021 0 012 2V26A2.0021 2.0021 0 0126 28zM20 11L18 11 16 14.897 14 11 12 11 14.905 16 12 21 14 21 16 17.201 18 21 20 21 17.098 16 20 11zM10 28H6a2.0021 2.0021 0 01-2-2V6A2.0021 2.0021 0 016 4h4V6H6V26h4z"
  })), children);
});
var Van32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Van32(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.81,16l-7-9.56A1,1,0,0,0,22,6H3A1,1,0,0,0,2,7V24a1,1,0,0,0,1,1H5.14a4,4,0,0,0,7.72,0h6.28a4,4,0,0,0,7.72,0H29a1,1,0,0,0,1-1V16.56A1,1,0,0,0,29.81,16ZM20,8h1.49l5.13,7H20ZM9,26a2,2,0,1,1,2-2A2,2,0,0,1,9,26Zm14,0a2,2,0,1,1,2-2A2,2,0,0,1,23,26Zm5-3H26.86a4,4,0,0,0-7.72,0H12.86a4,4,0,0,0-7.72,0H4V8H18v9H28Z"
  })), children);
});
var Van24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Van24(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.81,16l-7-9.56A1,1,0,0,0,22,6H3A1,1,0,0,0,2,7V24a1,1,0,0,0,1,1H5.14a4,4,0,0,0,7.72,0h6.28a4,4,0,0,0,7.72,0H29a1,1,0,0,0,1-1V16.56A1,1,0,0,0,29.81,16ZM20,8h1.49l5.13,7H20ZM9,26a2,2,0,1,1,2-2A2,2,0,0,1,9,26Zm14,0a2,2,0,1,1,2-2A2,2,0,0,1,23,26Zm5-3H26.86a4,4,0,0,0-7.72,0H12.86a4,4,0,0,0-7.72,0H4V8H18v9H28Z"
  })), children);
});
var Van20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Van20(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.81,16l-7-9.56A1,1,0,0,0,22,6H3A1,1,0,0,0,2,7V24a1,1,0,0,0,1,1H5.14a4,4,0,0,0,7.72,0h6.28a4,4,0,0,0,7.72,0H29a1,1,0,0,0,1-1V16.56A1,1,0,0,0,29.81,16ZM20,8h1.49l5.13,7H20ZM9,26a2,2,0,1,1,2-2A2,2,0,0,1,9,26Zm14,0a2,2,0,1,1,2-2A2,2,0,0,1,23,26Zm5-3H26.86a4,4,0,0,0-7.72,0H12.86a4,4,0,0,0-7.72,0H4V8H18v9H28Z"
  })), children);
});
var Van16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Van16(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.81,16l-7-9.56A1,1,0,0,0,22,6H3A1,1,0,0,0,2,7V24a1,1,0,0,0,1,1H5.14a4,4,0,0,0,7.72,0h6.28a4,4,0,0,0,7.72,0H29a1,1,0,0,0,1-1V16.56A1,1,0,0,0,29.81,16ZM20,8h1.49l5.13,7H20ZM9,26a2,2,0,1,1,2-2A2,2,0,0,1,9,26Zm14,0a2,2,0,1,1,2-2A2,2,0,0,1,23,26Zm5-3H26.86a4,4,0,0,0-7.72,0H12.86a4,4,0,0,0-7.72,0H4V8H18v9H28Z"
  })), children);
});
var VegetationAsset32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VegetationAsset32(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21.5",
    cy: "10.5",
    r: "1.5"
  })), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5 1a2.4518 2.4518 0 00-1.2061.3105L18.9834 5.6084l.0027.0054a5.497 5.497 0 107.3257 7.5444l.0031.0015 4.4-8.5A2.5 2.5 0 0028.5 1zm-7 13A3.5 3.5 0 1125 10.5 3.5042 3.5042 0 0121.5 14zM28.9414 3.7354L26.5571 8.3408A5.5279 5.5279 0 0023.658 5.4424l4.5949-2.377A.5165.5165 0 0129 3.5.4985.4985 0 0128.9414 3.7354zM19 20h7V18H17V28a2.0027 2.0027 0 002 2h3V28H19zM12 30H9V28h3V15.5664L8.4854 13.4575l1.0292-1.7148 3.5147 2.1084A2.0115 2.0115 0 0114 15.5664V28A2.0024 2.0024 0 0112 30z"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.3079,2.2852A9.4882,9.4882,0,0,0,15,2,8.0275,8.0275,0,0,0,8.0786,6.001C8.0525,6,8.0264,6,8,6A6,6,0,0,0,8,18V16A4,4,0,0,1,8,8a2.7009,2.7009,0,0,1,.387.0391l.863.1142.3086-.6675A6.0192,6.0192,0,0,1,15,4a7.499,7.499,0,0,1,1.731.2148Z"
  })), children);
});
var VegetationAsset24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VegetationAsset24(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21.5",
    cy: "10.5",
    r: "1.5"
  })), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5 1a2.4518 2.4518 0 00-1.2061.3105L18.9834 5.6084l.0027.0054a5.497 5.497 0 107.3257 7.5444l.0031.0015 4.4-8.5A2.5 2.5 0 0028.5 1zm-7 13A3.5 3.5 0 1125 10.5 3.5042 3.5042 0 0121.5 14zM28.9414 3.7354L26.5571 8.3408A5.5279 5.5279 0 0023.658 5.4424l4.5949-2.377A.5165.5165 0 0129 3.5.4985.4985 0 0128.9414 3.7354zM19 20h7V18H17V28a2.0027 2.0027 0 002 2h3V28H19zM12 30H9V28h3V15.5664L8.4854 13.4575l1.0292-1.7148 3.5147 2.1084A2.0115 2.0115 0 0114 15.5664V28A2.0024 2.0024 0 0112 30z"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.3079,2.2852A9.4882,9.4882,0,0,0,15,2,8.0275,8.0275,0,0,0,8.0786,6.001C8.0525,6,8.0264,6,8,6A6,6,0,0,0,8,18V16A4,4,0,0,1,8,8a2.7009,2.7009,0,0,1,.387.0391l.863.1142.3086-.6675A6.0192,6.0192,0,0,1,15,4a7.499,7.499,0,0,1,1.731.2148Z"
  })), children);
});
var VegetationAsset20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VegetationAsset20(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21.5",
    cy: "10.5",
    r: "1.5"
  })), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5 1a2.4518 2.4518 0 00-1.2061.3105L18.9834 5.6084l.0027.0054a5.497 5.497 0 107.3257 7.5444l.0031.0015 4.4-8.5A2.5 2.5 0 0028.5 1zm-7 13A3.5 3.5 0 1125 10.5 3.5042 3.5042 0 0121.5 14zM28.9414 3.7354L26.5571 8.3408A5.5279 5.5279 0 0023.658 5.4424l4.5949-2.377A.5165.5165 0 0129 3.5.4985.4985 0 0128.9414 3.7354zM19 20h7V18H17V28a2.0027 2.0027 0 002 2h3V28H19zM12 30H9V28h3V15.5664L8.4854 13.4575l1.0292-1.7148 3.5147 2.1084A2.0115 2.0115 0 0114 15.5664V28A2.0024 2.0024 0 0112 30z"
  })), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.3079,2.2852A9.4882,9.4882,0,0,0,15,2,8.0275,8.0275,0,0,0,8.0786,6.001C8.0525,6,8.0264,6,8,6A6,6,0,0,0,8,18V16A4,4,0,0,1,8,8a2.7009,2.7009,0,0,1,.387.0391l.863.1142.3086-.6675A6.0192,6.0192,0,0,1,15,4a7.499,7.499,0,0,1,1.731.2148Z"
  })), children);
});
var VegetationAsset16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VegetationAsset16(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21.5",
    cy: "10.5",
    r: "1.5"
  })), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5 1a2.4518 2.4518 0 00-1.2061.3105L18.9834 5.6084l.0027.0054a5.497 5.497 0 107.3257 7.5444l.0031.0015 4.4-8.5A2.5 2.5 0 0028.5 1zm-7 13A3.5 3.5 0 1125 10.5 3.5042 3.5042 0 0121.5 14zM28.9414 3.7354L26.5571 8.3408A5.5279 5.5279 0 0023.658 5.4424l4.5949-2.377A.5165.5165 0 0129 3.5.4985.4985 0 0128.9414 3.7354zM19 20h7V18H17V28a2.0027 2.0027 0 002 2h3V28H19zM12 30H9V28h3V15.5664L8.4854 13.4575l1.0292-1.7148 3.5147 2.1084A2.0115 2.0115 0 0114 15.5664V28A2.0024 2.0024 0 0112 30z"
  })), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.3079,2.2852A9.4882,9.4882,0,0,0,15,2,8.0275,8.0275,0,0,0,8.0786,6.001C8.0525,6,8.0264,6,8,6A6,6,0,0,0,8,18V16A4,4,0,0,1,8,8a2.7009,2.7009,0,0,1,.387.0391l.863.1142.3086-.6675A6.0192,6.0192,0,0,1,15,4a7.499,7.499,0,0,1,1.731.2148Z"
  })), children);
});
var VehicleApi32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VehicleApi32(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 11a1.9907 1.9907 0 00-.8247.1821L24.8337 9.51A3.45 3.45 0 0025 8.5a3.45 3.45 0 00-.1663-1.01l2.3416-1.6723A1.9975 1.9975 0 1026 4c0 .064.0129.124.0188.1865L23.7273 5.8232A3.4652 3.4652 0 0021.5 5a3.5 3.5 0 000 7 3.4652 3.4652 0 002.2273-.8232l2.2915 1.6367C26.0129 12.876 26 12.936 26 13a2 2 0 102-2zm-6.5-1A1.5 1.5 0 1123 8.5 1.5017 1.5017 0 0121.5 10zM29.3379 19.9336l-7.7324-2.7783L18.374 13.0967A2.99 2.99 0 0016.0537 12H8.0576a2.9982 2.9982 0 00-2.48 1.3115L2.8662 17.2949A4.9884 4.9884 0 002 20.1074V26a1 1 0 001 1H5.1421a3.9806 3.9806 0 007.7158 0h6.2842a3.9806 3.9806 0 007.7158 0H29a1 1 0 001-1V20.875A1 1 0 0029.3379 19.9336zM9 28a2 2 0 112-2A2.0027 2.0027 0 019 28zm14 0a2 2 0 112-2A2.0025 2.0025 0 0123 28zm5-3H26.8579a3.9806 3.9806 0 00-7.7158 0H12.8579a3.9806 3.9806 0 00-7.7158 0H4V20.1074A2.9977 2.9977 0 014.52 18.4189l2.711-3.9814A.9992.9992 0 018.0576 14h7.9961a.9928.9928 0 01.7647.3545l3.3994 4.2685a1.0007 1.0007 0 00.4443.3184L28 21.5781z"
  })), children);
});
var VehicleApi24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VehicleApi24(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 11a1.9907 1.9907 0 00-.8247.1821L24.8337 9.51A3.45 3.45 0 0025 8.5a3.45 3.45 0 00-.1663-1.01l2.3416-1.6723A1.9975 1.9975 0 1026 4c0 .064.0129.124.0188.1865L23.7273 5.8232A3.4652 3.4652 0 0021.5 5a3.5 3.5 0 000 7 3.4652 3.4652 0 002.2273-.8232l2.2915 1.6367C26.0129 12.876 26 12.936 26 13a2 2 0 102-2zm-6.5-1A1.5 1.5 0 1123 8.5 1.5017 1.5017 0 0121.5 10zM29.3379 19.9336l-7.7324-2.7783L18.374 13.0967A2.99 2.99 0 0016.0537 12H8.0576a2.9982 2.9982 0 00-2.48 1.3115L2.8662 17.2949A4.9884 4.9884 0 002 20.1074V26a1 1 0 001 1H5.1421a3.9806 3.9806 0 007.7158 0h6.2842a3.9806 3.9806 0 007.7158 0H29a1 1 0 001-1V20.875A1 1 0 0029.3379 19.9336zM9 28a2 2 0 112-2A2.0027 2.0027 0 019 28zm14 0a2 2 0 112-2A2.0025 2.0025 0 0123 28zm5-3H26.8579a3.9806 3.9806 0 00-7.7158 0H12.8579a3.9806 3.9806 0 00-7.7158 0H4V20.1074A2.9977 2.9977 0 014.52 18.4189l2.711-3.9814A.9992.9992 0 018.0576 14h7.9961a.9928.9928 0 01.7647.3545l3.3994 4.2685a1.0007 1.0007 0 00.4443.3184L28 21.5781z"
  })), children);
});
var VehicleApi20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VehicleApi20(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 11a1.9907 1.9907 0 00-.8247.1821L24.8337 9.51A3.45 3.45 0 0025 8.5a3.45 3.45 0 00-.1663-1.01l2.3416-1.6723A1.9975 1.9975 0 1026 4c0 .064.0129.124.0188.1865L23.7273 5.8232A3.4652 3.4652 0 0021.5 5a3.5 3.5 0 000 7 3.4652 3.4652 0 002.2273-.8232l2.2915 1.6367C26.0129 12.876 26 12.936 26 13a2 2 0 102-2zm-6.5-1A1.5 1.5 0 1123 8.5 1.5017 1.5017 0 0121.5 10zM29.3379 19.9336l-7.7324-2.7783L18.374 13.0967A2.99 2.99 0 0016.0537 12H8.0576a2.9982 2.9982 0 00-2.48 1.3115L2.8662 17.2949A4.9884 4.9884 0 002 20.1074V26a1 1 0 001 1H5.1421a3.9806 3.9806 0 007.7158 0h6.2842a3.9806 3.9806 0 007.7158 0H29a1 1 0 001-1V20.875A1 1 0 0029.3379 19.9336zM9 28a2 2 0 112-2A2.0027 2.0027 0 019 28zm14 0a2 2 0 112-2A2.0025 2.0025 0 0123 28zm5-3H26.8579a3.9806 3.9806 0 00-7.7158 0H12.8579a3.9806 3.9806 0 00-7.7158 0H4V20.1074A2.9977 2.9977 0 014.52 18.4189l2.711-3.9814A.9992.9992 0 018.0576 14h7.9961a.9928.9928 0 01.7647.3545l3.3994 4.2685a1.0007 1.0007 0 00.4443.3184L28 21.5781z"
  })), children);
});
var VehicleApi16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VehicleApi16(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 11a1.9907 1.9907 0 00-.8247.1821L24.8337 9.51A3.45 3.45 0 0025 8.5a3.45 3.45 0 00-.1663-1.01l2.3416-1.6723A1.9975 1.9975 0 1026 4c0 .064.0129.124.0188.1865L23.7273 5.8232A3.4652 3.4652 0 0021.5 5a3.5 3.5 0 000 7 3.4652 3.4652 0 002.2273-.8232l2.2915 1.6367C26.0129 12.876 26 12.936 26 13a2 2 0 102-2zm-6.5-1A1.5 1.5 0 1123 8.5 1.5017 1.5017 0 0121.5 10zM29.3379 19.9336l-7.7324-2.7783L18.374 13.0967A2.99 2.99 0 0016.0537 12H8.0576a2.9982 2.9982 0 00-2.48 1.3115L2.8662 17.2949A4.9884 4.9884 0 002 20.1074V26a1 1 0 001 1H5.1421a3.9806 3.9806 0 007.7158 0h6.2842a3.9806 3.9806 0 007.7158 0H29a1 1 0 001-1V20.875A1 1 0 0029.3379 19.9336zM9 28a2 2 0 112-2A2.0027 2.0027 0 019 28zm14 0a2 2 0 112-2A2.0025 2.0025 0 0123 28zm5-3H26.8579a3.9806 3.9806 0 00-7.7158 0H12.8579a3.9806 3.9806 0 00-7.7158 0H4V20.1074A2.9977 2.9977 0 014.52 18.4189l2.711-3.9814A.9992.9992 0 018.0576 14h7.9961a.9928.9928 0 01.7647.3545l3.3994 4.2685a1.0007 1.0007 0 00.4443.3184L28 21.5781z"
  })), children);
});
var VehicleConnected32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VehicleConnected32(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3379 17.9336l-7.7324-2.7783L18.374 11.0967A2.99 2.99 0 0016.0537 10H8.0576a2.9982 2.9982 0 00-2.48 1.3115L2.8662 15.2949A4.9884 4.9884 0 002 18.1074V26a1 1 0 001 1H5.1421a3.9806 3.9806 0 007.7158 0h6.2842a3.9806 3.9806 0 007.7158 0H29a1 1 0 001-1V18.875A1 1 0 0029.3379 17.9336zM9 28a2 2 0 112-2A2.0027 2.0027 0 019 28zm14 0a2 2 0 112-2A2.0025 2.0025 0 0123 28zm5-3H26.8579a3.9806 3.9806 0 00-7.7158 0H12.8579a3.9806 3.9806 0 00-7.7158 0H4V18.1074A2.9977 2.9977 0 014.52 16.4189l2.711-3.9814A.9992.9992 0 018.0576 12h7.9961a.9928.9928 0 01.7647.3545l3.3994 4.2685a1.0007 1.0007 0 00.4443.3184L28 19.5781zM25 11H23a2.0021 2.0021 0 00-2-2V7A4.0045 4.0045 0 0125 11z"
  })), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,11H27a6.0067,6.0067,0,0,0-6-6V3A8.0092,8.0092,0,0,1,29,11Z"
  })), children);
});
var VehicleConnected24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VehicleConnected24(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3379 17.9336l-7.7324-2.7783L18.374 11.0967A2.99 2.99 0 0016.0537 10H8.0576a2.9982 2.9982 0 00-2.48 1.3115L2.8662 15.2949A4.9884 4.9884 0 002 18.1074V26a1 1 0 001 1H5.1421a3.9806 3.9806 0 007.7158 0h6.2842a3.9806 3.9806 0 007.7158 0H29a1 1 0 001-1V18.875A1 1 0 0029.3379 17.9336zM9 28a2 2 0 112-2A2.0027 2.0027 0 019 28zm14 0a2 2 0 112-2A2.0025 2.0025 0 0123 28zm5-3H26.8579a3.9806 3.9806 0 00-7.7158 0H12.8579a3.9806 3.9806 0 00-7.7158 0H4V18.1074A2.9977 2.9977 0 014.52 16.4189l2.711-3.9814A.9992.9992 0 018.0576 12h7.9961a.9928.9928 0 01.7647.3545l3.3994 4.2685a1.0007 1.0007 0 00.4443.3184L28 19.5781zM25 11H23a2.0021 2.0021 0 00-2-2V7A4.0045 4.0045 0 0125 11z"
  })), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,11H27a6.0067,6.0067,0,0,0-6-6V3A8.0092,8.0092,0,0,1,29,11Z"
  })), children);
});
var VehicleConnected20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VehicleConnected20(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3379 17.9336l-7.7324-2.7783L18.374 11.0967A2.99 2.99 0 0016.0537 10H8.0576a2.9982 2.9982 0 00-2.48 1.3115L2.8662 15.2949A4.9884 4.9884 0 002 18.1074V26a1 1 0 001 1H5.1421a3.9806 3.9806 0 007.7158 0h6.2842a3.9806 3.9806 0 007.7158 0H29a1 1 0 001-1V18.875A1 1 0 0029.3379 17.9336zM9 28a2 2 0 112-2A2.0027 2.0027 0 019 28zm14 0a2 2 0 112-2A2.0025 2.0025 0 0123 28zm5-3H26.8579a3.9806 3.9806 0 00-7.7158 0H12.8579a3.9806 3.9806 0 00-7.7158 0H4V18.1074A2.9977 2.9977 0 014.52 16.4189l2.711-3.9814A.9992.9992 0 018.0576 12h7.9961a.9928.9928 0 01.7647.3545l3.3994 4.2685a1.0007 1.0007 0 00.4443.3184L28 19.5781zM25 11H23a2.0021 2.0021 0 00-2-2V7A4.0045 4.0045 0 0125 11z"
  })), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,11H27a6.0067,6.0067,0,0,0-6-6V3A8.0092,8.0092,0,0,1,29,11Z"
  })), children);
});
var VehicleConnected16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VehicleConnected16(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3379 17.9336l-7.7324-2.7783L18.374 11.0967A2.99 2.99 0 0016.0537 10H8.0576a2.9982 2.9982 0 00-2.48 1.3115L2.8662 15.2949A4.9884 4.9884 0 002 18.1074V26a1 1 0 001 1H5.1421a3.9806 3.9806 0 007.7158 0h6.2842a3.9806 3.9806 0 007.7158 0H29a1 1 0 001-1V18.875A1 1 0 0029.3379 17.9336zM9 28a2 2 0 112-2A2.0027 2.0027 0 019 28zm14 0a2 2 0 112-2A2.0025 2.0025 0 0123 28zm5-3H26.8579a3.9806 3.9806 0 00-7.7158 0H12.8579a3.9806 3.9806 0 00-7.7158 0H4V18.1074A2.9977 2.9977 0 014.52 16.4189l2.711-3.9814A.9992.9992 0 018.0576 12h7.9961a.9928.9928 0 01.7647.3545l3.3994 4.2685a1.0007 1.0007 0 00.4443.3184L28 19.5781zM25 11H23a2.0021 2.0021 0 00-2-2V7A4.0045 4.0045 0 0125 11z"
  })), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,11H27a6.0067,6.0067,0,0,0-6-6V3A8.0092,8.0092,0,0,1,29,11Z"
  })), children);
});
var VehicleInsights32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VehicleInsights32(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3379 17.9336l-7.7324-2.7783L18.374 11.0967A2.99 2.99 0 0016.0537 10H8.0576a2.9982 2.9982 0 00-2.48 1.3115L2.8662 15.2949A4.9884 4.9884 0 002 18.1074V26a1 1 0 001 1H5.1421a3.9806 3.9806 0 007.7158 0h6.2842a3.9806 3.9806 0 007.7158 0H29a1 1 0 001-1V18.875A1 1 0 0029.3379 17.9336zM9 28a2 2 0 112-2A2.0027 2.0027 0 019 28zm14 0a2 2 0 112-2A2.0025 2.0025 0 0123 28zm5-3H26.8579a3.9806 3.9806 0 00-7.7158 0H12.8579a3.9806 3.9806 0 00-7.7158 0H4V18.1074A2.9977 2.9977 0 014.52 16.4189l2.711-3.9814A.9992.9992 0 018.0576 12h7.9961a.9928.9928 0 01.7647.3545l3.3994 4.2685a1.0007 1.0007 0 00.4443.3184L28 19.5781zM28 2H30V9H28zM24 6H26V9H24zM20 4H22V9H20z"
  })), children);
});
var VehicleInsights24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VehicleInsights24(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3379 17.9336l-7.7324-2.7783L18.374 11.0967A2.99 2.99 0 0016.0537 10H8.0576a2.9982 2.9982 0 00-2.48 1.3115L2.8662 15.2949A4.9884 4.9884 0 002 18.1074V26a1 1 0 001 1H5.1421a3.9806 3.9806 0 007.7158 0h6.2842a3.9806 3.9806 0 007.7158 0H29a1 1 0 001-1V18.875A1 1 0 0029.3379 17.9336zM9 28a2 2 0 112-2A2.0027 2.0027 0 019 28zm14 0a2 2 0 112-2A2.0025 2.0025 0 0123 28zm5-3H26.8579a3.9806 3.9806 0 00-7.7158 0H12.8579a3.9806 3.9806 0 00-7.7158 0H4V18.1074A2.9977 2.9977 0 014.52 16.4189l2.711-3.9814A.9992.9992 0 018.0576 12h7.9961a.9928.9928 0 01.7647.3545l3.3994 4.2685a1.0007 1.0007 0 00.4443.3184L28 19.5781zM28 2H30V9H28zM24 6H26V9H24zM20 4H22V9H20z"
  })), children);
});
var VehicleInsights20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VehicleInsights20(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3379 17.9336l-7.7324-2.7783L18.374 11.0967A2.99 2.99 0 0016.0537 10H8.0576a2.9982 2.9982 0 00-2.48 1.3115L2.8662 15.2949A4.9884 4.9884 0 002 18.1074V26a1 1 0 001 1H5.1421a3.9806 3.9806 0 007.7158 0h6.2842a3.9806 3.9806 0 007.7158 0H29a1 1 0 001-1V18.875A1 1 0 0029.3379 17.9336zM9 28a2 2 0 112-2A2.0027 2.0027 0 019 28zm14 0a2 2 0 112-2A2.0025 2.0025 0 0123 28zm5-3H26.8579a3.9806 3.9806 0 00-7.7158 0H12.8579a3.9806 3.9806 0 00-7.7158 0H4V18.1074A2.9977 2.9977 0 014.52 16.4189l2.711-3.9814A.9992.9992 0 018.0576 12h7.9961a.9928.9928 0 01.7647.3545l3.3994 4.2685a1.0007 1.0007 0 00.4443.3184L28 19.5781zM28 2H30V9H28zM24 6H26V9H24zM20 4H22V9H20z"
  })), children);
});
var VehicleInsights16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VehicleInsights16(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3379 17.9336l-7.7324-2.7783L18.374 11.0967A2.99 2.99 0 0016.0537 10H8.0576a2.9982 2.9982 0 00-2.48 1.3115L2.8662 15.2949A4.9884 4.9884 0 002 18.1074V26a1 1 0 001 1H5.1421a3.9806 3.9806 0 007.7158 0h6.2842a3.9806 3.9806 0 007.7158 0H29a1 1 0 001-1V18.875A1 1 0 0029.3379 17.9336zM9 28a2 2 0 112-2A2.0027 2.0027 0 019 28zm14 0a2 2 0 112-2A2.0025 2.0025 0 0123 28zm5-3H26.8579a3.9806 3.9806 0 00-7.7158 0H12.8579a3.9806 3.9806 0 00-7.7158 0H4V18.1074A2.9977 2.9977 0 014.52 16.4189l2.711-3.9814A.9992.9992 0 018.0576 12h7.9961a.9928.9928 0 01.7647.3545l3.3994 4.2685a1.0007 1.0007 0 00.4443.3184L28 19.5781zM28 2H30V9H28zM24 6H26V9H24zM20 4H22V9H20z"
  })), children);
});
var VehicleServices32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VehicleServices32(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3379 17.9336l-7.7324-2.7783L18.374 11.0967A2.99 2.99 0 0016.0537 10H8.0576a2.9982 2.9982 0 00-2.48 1.3115L2.8662 15.2949A4.9884 4.9884 0 002 18.1074V26a1 1 0 001 1H5.1421a3.9806 3.9806 0 007.7158 0h6.2842a3.9806 3.9806 0 007.7158 0H29a1 1 0 001-1V18.875A1 1 0 0029.3379 17.9336zM9 28a2 2 0 112-2A2.0027 2.0027 0 019 28zm14 0a2 2 0 112-2A2.0025 2.0025 0 0123 28zm5-3H26.8579a3.9806 3.9806 0 00-7.7158 0H12.8579a3.9806 3.9806 0 00-7.7158 0H4V18.1074A2.9977 2.9977 0 014.52 16.4189l2.711-3.9814A.9992.9992 0 018.0576 12h7.9961a.9928.9928 0 01.7647.3545l3.3994 4.2685a1.0007 1.0007 0 00.4443.3184L28 19.5781zM24.5547 6a2 2 0 012-2H30a3.9756 3.9756 0 00-7.304 1H16V7h6.696A3.9756 3.9756 0 0030 8H26.5547A2 2 0 0124.5547 6z"
  })), children);
});
var VehicleServices24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VehicleServices24(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3379 17.9336l-7.7324-2.7783L18.374 11.0967A2.99 2.99 0 0016.0537 10H8.0576a2.9982 2.9982 0 00-2.48 1.3115L2.8662 15.2949A4.9884 4.9884 0 002 18.1074V26a1 1 0 001 1H5.1421a3.9806 3.9806 0 007.7158 0h6.2842a3.9806 3.9806 0 007.7158 0H29a1 1 0 001-1V18.875A1 1 0 0029.3379 17.9336zM9 28a2 2 0 112-2A2.0027 2.0027 0 019 28zm14 0a2 2 0 112-2A2.0025 2.0025 0 0123 28zm5-3H26.8579a3.9806 3.9806 0 00-7.7158 0H12.8579a3.9806 3.9806 0 00-7.7158 0H4V18.1074A2.9977 2.9977 0 014.52 16.4189l2.711-3.9814A.9992.9992 0 018.0576 12h7.9961a.9928.9928 0 01.7647.3545l3.3994 4.2685a1.0007 1.0007 0 00.4443.3184L28 19.5781zM24.5547 6a2 2 0 012-2H30a3.9756 3.9756 0 00-7.304 1H16V7h6.696A3.9756 3.9756 0 0030 8H26.5547A2 2 0 0124.5547 6z"
  })), children);
});
var VehicleServices20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VehicleServices20(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3379 17.9336l-7.7324-2.7783L18.374 11.0967A2.99 2.99 0 0016.0537 10H8.0576a2.9982 2.9982 0 00-2.48 1.3115L2.8662 15.2949A4.9884 4.9884 0 002 18.1074V26a1 1 0 001 1H5.1421a3.9806 3.9806 0 007.7158 0h6.2842a3.9806 3.9806 0 007.7158 0H29a1 1 0 001-1V18.875A1 1 0 0029.3379 17.9336zM9 28a2 2 0 112-2A2.0027 2.0027 0 019 28zm14 0a2 2 0 112-2A2.0025 2.0025 0 0123 28zm5-3H26.8579a3.9806 3.9806 0 00-7.7158 0H12.8579a3.9806 3.9806 0 00-7.7158 0H4V18.1074A2.9977 2.9977 0 014.52 16.4189l2.711-3.9814A.9992.9992 0 018.0576 12h7.9961a.9928.9928 0 01.7647.3545l3.3994 4.2685a1.0007 1.0007 0 00.4443.3184L28 19.5781zM24.5547 6a2 2 0 012-2H30a3.9756 3.9756 0 00-7.304 1H16V7h6.696A3.9756 3.9756 0 0030 8H26.5547A2 2 0 0124.5547 6z"
  })), children);
});
var VehicleServices16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VehicleServices16(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3379 17.9336l-7.7324-2.7783L18.374 11.0967A2.99 2.99 0 0016.0537 10H8.0576a2.9982 2.9982 0 00-2.48 1.3115L2.8662 15.2949A4.9884 4.9884 0 002 18.1074V26a1 1 0 001 1H5.1421a3.9806 3.9806 0 007.7158 0h6.2842a3.9806 3.9806 0 007.7158 0H29a1 1 0 001-1V18.875A1 1 0 0029.3379 17.9336zM9 28a2 2 0 112-2A2.0027 2.0027 0 019 28zm14 0a2 2 0 112-2A2.0025 2.0025 0 0123 28zm5-3H26.8579a3.9806 3.9806 0 00-7.7158 0H12.8579a3.9806 3.9806 0 00-7.7158 0H4V18.1074A2.9977 2.9977 0 014.52 16.4189l2.711-3.9814A.9992.9992 0 018.0576 12h7.9961a.9928.9928 0 01.7647.3545l3.3994 4.2685a1.0007 1.0007 0 00.4443.3184L28 19.5781zM24.5547 6a2 2 0 012-2H30a3.9756 3.9756 0 00-7.304 1H16V7h6.696A3.9756 3.9756 0 0030 8H26.5547A2 2 0 0124.5547 6z"
  })), children);
});
var Version32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Version32(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2V4H26V19h2V4a2.0023,2.0023,0,0,0-2-2Z"
  })), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,7V9H21V24h2V9a2.0023,2.0023,0,0,0-2-2Z"
  })), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,12H16a2.0023,2.0023,0,0,1,2,2V28a2.0023,2.0023,0,0,1-2,2H6a2.0023,2.0023,0,0,1-2-2V14A2.0023,2.0023,0,0,1,6,12Zm10,2L6,13.9988V28H16Z"
  })), children);
});
var Version24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Version24(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2V4H26V19h2V4a2.0023,2.0023,0,0,0-2-2Z"
  })), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,7V9H21V24h2V9a2.0023,2.0023,0,0,0-2-2Z"
  })), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,12H16a2.0023,2.0023,0,0,1,2,2V28a2.0023,2.0023,0,0,1-2,2H6a2.0023,2.0023,0,0,1-2-2V14A2.0023,2.0023,0,0,1,6,12Zm10,2L6,13.9988V28H16Z"
  })), children);
});
var Version20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Version20(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2V4H26V19h2V4a2.0023,2.0023,0,0,0-2-2Z"
  })), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,7V9H21V24h2V9a2.0023,2.0023,0,0,0-2-2Z"
  })), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,12H16a2.0023,2.0023,0,0,1,2,2V28a2.0023,2.0023,0,0,1-2,2H6a2.0023,2.0023,0,0,1-2-2V14A2.0023,2.0023,0,0,1,6,12Zm10,2L6,13.9988V28H16Z"
  })), children);
});
var Version16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Version16(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2V4H26V19h2V4a2.0023,2.0023,0,0,0-2-2Z"
  })), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,7V9H21V24h2V9a2.0023,2.0023,0,0,0-2-2Z"
  })), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,12H16a2.0023,2.0023,0,0,1,2,2V28a2.0023,2.0023,0,0,1-2,2H6a2.0023,2.0023,0,0,1-2-2V14A2.0023,2.0023,0,0,1,6,12Zm10,2L6,13.9988V28H16Z"
  })), children);
});
var VerticalView32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VerticalView32(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 30H4a2.0021 2.0021 0 01-2-2V4A2.0021 2.0021 0 014 2h8a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0112 30zM4 4V28h8V4zM28 30H20a2.0021 2.0021 0 01-2-2V4a2.0021 2.0021 0 012-2h8a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0128 30zM20 4V28h8V4z"
  })), children);
});
var VerticalView24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VerticalView24(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 30H4a2.0021 2.0021 0 01-2-2V4A2.0021 2.0021 0 014 2h8a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0112 30zM4 4V28h8V4zM28 30H20a2.0021 2.0021 0 01-2-2V4a2.0021 2.0021 0 012-2h8a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0128 30zM20 4V28h8V4z"
  })), children);
});
var VerticalView20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VerticalView20(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 30H4a2.0021 2.0021 0 01-2-2V4A2.0021 2.0021 0 014 2h8a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0112 30zM4 4V28h8V4zM28 30H20a2.0021 2.0021 0 01-2-2V4a2.0021 2.0021 0 012-2h8a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0128 30zM20 4V28h8V4z"
  })), children);
});
var VerticalView16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VerticalView16(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 30H4a2.0021 2.0021 0 01-2-2V4A2.0021 2.0021 0 014 2h8a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0112 30zM4 4V28h8V4zM28 30H20a2.0021 2.0021 0 01-2-2V4a2.0021 2.0021 0 012-2h8a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0128 30zM20 4V28h8V4z"
  })), children);
});
var Video32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Video32(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,26H4a2,2,0,0,1-2-2V8A2,2,0,0,1,4,6H21a2,2,0,0,1,2,2v4.06l5.42-3.87A1,1,0,0,1,30,9V23a1,1,0,0,1-1.58.81L23,19.94V24A2,2,0,0,1,21,26ZM4,8V24H21V18a1,1,0,0,1,1.58-.81L28,21.06V10.94l-5.42,3.87A1,1,0,0,1,21,14V8Z"
  })), children);
});
var Video24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Video24(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,26H4a2,2,0,0,1-2-2V8A2,2,0,0,1,4,6H21a2,2,0,0,1,2,2v4.06l5.42-3.87A1,1,0,0,1,30,9V23a1,1,0,0,1-1.58.81L23,19.94V24A2,2,0,0,1,21,26ZM4,8V24H21V18a1,1,0,0,1,1.58-.81L28,21.06V10.94l-5.42,3.87A1,1,0,0,1,21,14V8Z"
  })), children);
});
var Video20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Video20(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,26H4a2,2,0,0,1-2-2V8A2,2,0,0,1,4,6H21a2,2,0,0,1,2,2v4.06l5.42-3.87A1,1,0,0,1,30,9V23a1,1,0,0,1-1.58.81L23,19.94V24A2,2,0,0,1,21,26ZM4,8V24H21V18a1,1,0,0,1,1.58-.81L28,21.06V10.94l-5.42,3.87A1,1,0,0,1,21,14V8Z"
  })), children);
});
var Video16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Video16(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,26H4a2,2,0,0,1-2-2V8A2,2,0,0,1,4,6H21a2,2,0,0,1,2,2v4.06l5.42-3.87A1,1,0,0,1,30,9V23a1,1,0,0,1-1.58.81L23,19.94V24A2,2,0,0,1,21,26ZM4,8V24H21V18a1,1,0,0,1,1.58-.81L28,21.06V10.94l-5.42,3.87A1,1,0,0,1,21,14V8Z"
  })), children);
});
var VideoAdd32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoAdd32(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 15L14 15 14 11 12 11 12 15 8 15 8 17 12 17 12 21 14 21 14 17 18 17 18 15z"
  })), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,26H4a2.0023,2.0023,0,0,1-2-2V8A2.0023,2.0023,0,0,1,4,6H21a2.0023,2.0023,0,0,1,2,2v4.0566l5.4189-3.87A.9995.9995,0,0,1,30,9V23a.9995.9995,0,0,1-1.5811.8135L23,19.9434V24A2.0023,2.0023,0,0,1,21,26ZM4,8V24.001L21,24V18a.9995.9995,0,0,1,1.5811-.8135L28,21.0566V10.9434l-5.4189,3.87A.9995.9995,0,0,1,21,14V8Z"
  })), children);
});
var VideoAdd24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoAdd24(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 15L14 15 14 11 12 11 12 15 8 15 8 17 12 17 12 21 14 21 14 17 18 17 18 15z"
  })), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,26H4a2.0023,2.0023,0,0,1-2-2V8A2.0023,2.0023,0,0,1,4,6H21a2.0023,2.0023,0,0,1,2,2v4.0566l5.4189-3.87A.9995.9995,0,0,1,30,9V23a.9995.9995,0,0,1-1.5811.8135L23,19.9434V24A2.0023,2.0023,0,0,1,21,26ZM4,8V24.001L21,24V18a.9995.9995,0,0,1,1.5811-.8135L28,21.0566V10.9434l-5.4189,3.87A.9995.9995,0,0,1,21,14V8Z"
  })), children);
});
var VideoAdd20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoAdd20(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 15L14 15 14 11 12 11 12 15 8 15 8 17 12 17 12 21 14 21 14 17 18 17 18 15z"
  })), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,26H4a2.0023,2.0023,0,0,1-2-2V8A2.0023,2.0023,0,0,1,4,6H21a2.0023,2.0023,0,0,1,2,2v4.0566l5.4189-3.87A.9995.9995,0,0,1,30,9V23a.9995.9995,0,0,1-1.5811.8135L23,19.9434V24A2.0023,2.0023,0,0,1,21,26ZM4,8V24.001L21,24V18a.9995.9995,0,0,1,1.5811-.8135L28,21.0566V10.9434l-5.4189,3.87A.9995.9995,0,0,1,21,14V8Z"
  })), children);
});
var VideoAdd16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoAdd16(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 15L14 15 14 11 12 11 12 15 8 15 8 17 12 17 12 21 14 21 14 17 18 17 18 15z"
  })), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,26H4a2.0023,2.0023,0,0,1-2-2V8A2.0023,2.0023,0,0,1,4,6H21a2.0023,2.0023,0,0,1,2,2v4.0566l5.4189-3.87A.9995.9995,0,0,1,30,9V23a.9995.9995,0,0,1-1.5811.8135L23,19.9434V24A2.0023,2.0023,0,0,1,21,26ZM4,8V24.001L21,24V18a.9995.9995,0,0,1,1.5811-.8135L28,21.0566V10.9434l-5.4189,3.87A.9995.9995,0,0,1,21,14V8Z"
  })), children);
});
var VideoChat32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoChat32(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 12H17V14H8zM8 17H13V19H8z"
  })), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,26H4a2.0023,2.0023,0,0,1-2-2V8A2.0023,2.0023,0,0,1,4,6H21a2.0023,2.0023,0,0,1,2,2v4.0566l5.4189-3.87A.9995.9995,0,0,1,30,9V23a.9995.9995,0,0,1-1.5811.8135L23,19.9434V24A2.0023,2.0023,0,0,1,21,26ZM4,8V24.001L21,24V18a.9995.9995,0,0,1,1.5811-.8135L28,21.0566V10.9434l-5.4189,3.87A.9995.9995,0,0,1,21,14V8Z"
  })), children);
});
var VideoChat24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoChat24(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 12H17V14H8zM8 17H13V19H8z"
  })), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,26H4a2.0023,2.0023,0,0,1-2-2V8A2.0023,2.0023,0,0,1,4,6H21a2.0023,2.0023,0,0,1,2,2v4.0566l5.4189-3.87A.9995.9995,0,0,1,30,9V23a.9995.9995,0,0,1-1.5811.8135L23,19.9434V24A2.0023,2.0023,0,0,1,21,26ZM4,8V24.001L21,24V18a.9995.9995,0,0,1,1.5811-.8135L28,21.0566V10.9434l-5.4189,3.87A.9995.9995,0,0,1,21,14V8Z"
  })), children);
});
var VideoChat20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoChat20(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 12H17V14H8zM8 17H13V19H8z"
  })), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,26H4a2.0023,2.0023,0,0,1-2-2V8A2.0023,2.0023,0,0,1,4,6H21a2.0023,2.0023,0,0,1,2,2v4.0566l5.4189-3.87A.9995.9995,0,0,1,30,9V23a.9995.9995,0,0,1-1.5811.8135L23,19.9434V24A2.0023,2.0023,0,0,1,21,26ZM4,8V24.001L21,24V18a.9995.9995,0,0,1,1.5811-.8135L28,21.0566V10.9434l-5.4189,3.87A.9995.9995,0,0,1,21,14V8Z"
  })), children);
});
var VideoChat16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoChat16(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 12H17V14H8zM8 17H13V19H8z"
  })), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,26H4a2.0023,2.0023,0,0,1-2-2V8A2.0023,2.0023,0,0,1,4,6H21a2.0023,2.0023,0,0,1,2,2v4.0566l5.4189-3.87A.9995.9995,0,0,1,30,9V23a.9995.9995,0,0,1-1.5811.8135L23,19.9434V24A2.0023,2.0023,0,0,1,21,26ZM4,8V24.001L21,24V18a.9995.9995,0,0,1,1.5811-.8135L28,21.0566V10.9434l-5.4189,3.87A.9995.9995,0,0,1,21,14V8Z"
  })), children);
});
var VideoFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoFilled32(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,26H4a2,2,0,0,1-2-2V8A2,2,0,0,1,4,6H21a2,2,0,0,1,2,2v4.06l5.42-3.87A1,1,0,0,1,30,9V23a1,1,0,0,1-1.58.81L23,19.94V24A2,2,0,0,1,21,26Z"
  })), children);
});
var VideoFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoFilled24(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,26H4a2,2,0,0,1-2-2V8A2,2,0,0,1,4,6H21a2,2,0,0,1,2,2v4.06l5.42-3.87A1,1,0,0,1,30,9V23a1,1,0,0,1-1.58.81L23,19.94V24A2,2,0,0,1,21,26Z"
  })), children);
});
var VideoFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoFilled20(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,26H4a2,2,0,0,1-2-2V8A2,2,0,0,1,4,6H21a2,2,0,0,1,2,2v4.06l5.42-3.87A1,1,0,0,1,30,9V23a1,1,0,0,1-1.58.81L23,19.94V24A2,2,0,0,1,21,26Z"
  })), children);
});
var VideoFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoFilled16(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,26H4a2,2,0,0,1-2-2V8A2,2,0,0,1,4,6H21a2,2,0,0,1,2,2v4.06l5.42-3.87A1,1,0,0,1,30,9V23a1,1,0,0,1-1.58.81L23,19.94V24A2,2,0,0,1,21,26Z"
  })), children);
});
var VideoOff32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoOff32(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.46 8.11a1 1 0 00-1 .08L23 12.06V10.44l7-7L28.56 2 2 28.56 3.44 30l4-4H21a2 2 0 002-2V19.94l5.42 3.87A1 1 0 0030 23V9A1 1 0 0029.46 8.11zM28 21.06l-5.42-3.87A1 1 0 0021 18v6H9.44L21 12.44V14a1 1 0 001.58.81L28 10.94zM4 24V8H20V6H4A2 2 0 002 8V24z"
  })), children);
});
var VideoOff24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoOff24(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.46 8.11a1 1 0 00-1 .08L23 12.06V10.44l7-7L28.56 2 2 28.56 3.44 30l4-4H21a2 2 0 002-2V19.94l5.42 3.87A1 1 0 0030 23V9A1 1 0 0029.46 8.11zM28 21.06l-5.42-3.87A1 1 0 0021 18v6H9.44L21 12.44V14a1 1 0 001.58.81L28 10.94zM4 24V8H20V6H4A2 2 0 002 8V24z"
  })), children);
});
var VideoOff20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoOff20(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.46 8.11a1 1 0 00-1 .08L23 12.06V10.44l7-7L28.56 2 2 28.56 3.44 30l4-4H21a2 2 0 002-2V19.94l5.42 3.87A1 1 0 0030 23V9A1 1 0 0029.46 8.11zM28 21.06l-5.42-3.87A1 1 0 0021 18v6H9.44L21 12.44V14a1 1 0 001.58.81L28 10.94zM4 24V8H20V6H4A2 2 0 002 8V24z"
  })), children);
});
var VideoOff16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoOff16(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.46 8.11a1 1 0 00-1 .08L23 12.06V10.44l7-7L28.56 2 2 28.56 3.44 30l4-4H21a2 2 0 002-2V19.94l5.42 3.87A1 1 0 0030 23V9A1 1 0 0029.46 8.11zM28 21.06l-5.42-3.87A1 1 0 0021 18v6H9.44L21 12.44V14a1 1 0 001.58.81L28 10.94zM4 24V8H20V6H4A2 2 0 002 8V24z"
  })), children);
});
var VideoOffFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoOffFilled32(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.31 6H4A2 2 0 002 8V24a2.85 2.85 0 000 .29zM29.46 8.11a1 1 0 00-1 .08L23 12.06V10.44l7-7L28.56 2 2 28.56 3.44 30l4-4H21a2 2 0 002-2V19.94l5.42 3.87A1 1 0 0030 23V9A1 1 0 0029.46 8.11z"
  })), children);
});
var VideoOffFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoOffFilled24(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.31 6H4A2 2 0 002 8V24a2.85 2.85 0 000 .29zM29.46 8.11a1 1 0 00-1 .08L23 12.06V10.44l7-7L28.56 2 2 28.56 3.44 30l4-4H21a2 2 0 002-2V19.94l5.42 3.87A1 1 0 0030 23V9A1 1 0 0029.46 8.11z"
  })), children);
});
var VideoOffFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoOffFilled20(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.31 6H4A2 2 0 002 8V24a2.85 2.85 0 000 .29zM29.46 8.11a1 1 0 00-1 .08L23 12.06V10.44l7-7L28.56 2 2 28.56 3.44 30l4-4H21a2 2 0 002-2V19.94l5.42 3.87A1 1 0 0030 23V9A1 1 0 0029.46 8.11z"
  })), children);
});
var VideoOffFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VideoOffFilled16(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.31 6H4A2 2 0 002 8V24a2.85 2.85 0 000 .29zM29.46 8.11a1 1 0 00-1 .08L23 12.06V10.44l7-7L28.56 2 2 28.56 3.44 30l4-4H21a2 2 0 002-2V19.94l5.42 3.87A1 1 0 0030 23V9A1 1 0 0029.46 8.11z"
  })), children);
});
var View32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function View32(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.94,15.66A16.69,16.69,0,0,0,16,5,16.69,16.69,0,0,0,1.06,15.66a1,1,0,0,0,0,.68A16.69,16.69,0,0,0,16,27,16.69,16.69,0,0,0,30.94,16.34,1,1,0,0,0,30.94,15.66ZM16,25c-5.3,0-10.9-3.93-12.93-9C5.1,10.93,10.7,7,16,7s10.9,3.93,12.93,9C26.9,21.07,21.3,25,16,25Z"
  })), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a6,6,0,1,0,6,6A6,6,0,0,0,16,10Zm0,10a4,4,0,1,1,4-4A4,4,0,0,1,16,20Z"
  })), children);
});
var View24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function View24(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.94,15.66A16.69,16.69,0,0,0,16,5,16.69,16.69,0,0,0,1.06,15.66a1,1,0,0,0,0,.68A16.69,16.69,0,0,0,16,27,16.69,16.69,0,0,0,30.94,16.34,1,1,0,0,0,30.94,15.66ZM16,25c-5.3,0-10.9-3.93-12.93-9C5.1,10.93,10.7,7,16,7s10.9,3.93,12.93,9C26.9,21.07,21.3,25,16,25Z"
  })), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a6,6,0,1,0,6,6A6,6,0,0,0,16,10Zm0,10a4,4,0,1,1,4-4A4,4,0,0,1,16,20Z"
  })), children);
});
var View20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function View20(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.94,15.66A16.69,16.69,0,0,0,16,5,16.69,16.69,0,0,0,1.06,15.66a1,1,0,0,0,0,.68A16.69,16.69,0,0,0,16,27,16.69,16.69,0,0,0,30.94,16.34,1,1,0,0,0,30.94,15.66ZM16,25c-5.3,0-10.9-3.93-12.93-9C5.1,10.93,10.7,7,16,7s10.9,3.93,12.93,9C26.9,21.07,21.3,25,16,25Z"
  })), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,10a6,6,0,1,0,6,6A6,6,0,0,0,16,10Zm0,10a4,4,0,1,1,4-4A4,4,0,0,1,16,20Z"
  })), children);
});
var View16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function View16(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.5,7.8C14.3,4.7,11.3,2.6,8,2.5C4.7,2.6,1.7,4.7,0.5,7.8c0,0.1,0,0.2,0,0.3c1.2,3.1,4.1,5.2,7.5,5.3\tc3.3-0.1,6.3-2.2,7.5-5.3C15.5,8.1,15.5,7.9,15.5,7.8z M8,12.5c-2.7,0-5.4-2-6.5-4.5c1-2.5,3.8-4.5,6.5-4.5s5.4,2,6.5,4.5\tC13.4,10.5,10.6,12.5,8,12.5z"
  })), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,5C6.3,5,5,6.3,5,8s1.3,3,3,3s3-1.3,3-3S9.7,5,8,5z M8,10c-1.1,0-2-0.9-2-2s0.9-2,2-2s2,0.9,2,2S9.1,10,8,10z"
  })), children);
});
var ViewFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewFilled32(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "4"
  })), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.94,15.66A16.69,16.69,0,0,0,16,5,16.69,16.69,0,0,0,1.06,15.66a1,1,0,0,0,0,.68A16.69,16.69,0,0,0,16,27,16.69,16.69,0,0,0,30.94,16.34,1,1,0,0,0,30.94,15.66ZM16,22.5A6.5,6.5,0,1,1,22.5,16,6.51,6.51,0,0,1,16,22.5Z"
  })), children);
});
var ViewFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewFilled24(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "4"
  })), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.94,15.66A16.69,16.69,0,0,0,16,5,16.69,16.69,0,0,0,1.06,15.66a1,1,0,0,0,0,.68A16.69,16.69,0,0,0,16,27,16.69,16.69,0,0,0,30.94,16.34,1,1,0,0,0,30.94,15.66ZM16,22.5A6.5,6.5,0,1,1,22.5,16,6.51,6.51,0,0,1,16,22.5Z"
  })), children);
});
var ViewFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewFilled20(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "4"
  })), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.94,15.66A16.69,16.69,0,0,0,16,5,16.69,16.69,0,0,0,1.06,15.66a1,1,0,0,0,0,.68A16.69,16.69,0,0,0,16,27,16.69,16.69,0,0,0,30.94,16.34,1,1,0,0,0,30.94,15.66ZM16,22.5A6.5,6.5,0,1,1,22.5,16,6.51,6.51,0,0,1,16,22.5Z"
  })), children);
});
var ViewFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewFilled16(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "4"
  })), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.94,15.66A16.69,16.69,0,0,0,16,5,16.69,16.69,0,0,0,1.06,15.66a1,1,0,0,0,0,.68A16.69,16.69,0,0,0,16,27,16.69,16.69,0,0,0,30.94,16.34,1,1,0,0,0,30.94,15.66ZM16,22.5A6.5,6.5,0,1,1,22.5,16,6.51,6.51,0,0,1,16,22.5Z"
  })), children);
});
var ViewMode_132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewMode_132(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H28V28H4zM4 19H28V21H4zM26 6v6H6V6H26m0-2H6A2 2 0 004 6v6a2 2 0 002 2H26a2 2 0 002-2V6a2 2 0 00-2-2z"
  })), children);
});
var ViewMode_124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewMode_124(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H28V28H4zM4 19H28V21H4zM26 6v6H6V6H26m0-2H6A2 2 0 004 6v6a2 2 0 002 2H26a2 2 0 002-2V6a2 2 0 00-2-2z"
  })), children);
});
var ViewMode_120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewMode_120(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H28V28H4zM4 19H28V21H4zM26 6v6H6V6H26m0-2H6A2 2 0 004 6v6a2 2 0 002 2H26a2 2 0 002-2V6a2 2 0 00-2-2z"
  })), children);
});
var ViewMode_116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewMode_116(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H28V28H4zM4 19H28V21H4zM26 6v6H6V6H26m0-2H6A2 2 0 004 6v6a2 2 0 002 2H26a2 2 0 002-2V6a2 2 0 00-2-2z"
  })), children);
});
var ViewMode_232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewMode_232(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H28V28H4zM4 19H28V21H4zM12 6v6H6V6h6m0-2H6A2 2 0 004 6v6a2 2 0 002 2h6a2 2 0 002-2V6a2 2 0 00-2-2zM26 6v6H20V6h6m0-2H20a2 2 0 00-2 2v6a2 2 0 002 2h6a2 2 0 002-2V6a2 2 0 00-2-2z"
  })), children);
});
var ViewMode_224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewMode_224(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H28V28H4zM4 19H28V21H4zM12 6v6H6V6h6m0-2H6A2 2 0 004 6v6a2 2 0 002 2h6a2 2 0 002-2V6a2 2 0 00-2-2zM26 6v6H20V6h6m0-2H20a2 2 0 00-2 2v6a2 2 0 002 2h6a2 2 0 002-2V6a2 2 0 00-2-2z"
  })), children);
});
var ViewMode_220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewMode_220(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H28V28H4zM4 19H28V21H4zM12 6v6H6V6h6m0-2H6A2 2 0 004 6v6a2 2 0 002 2h6a2 2 0 002-2V6a2 2 0 00-2-2zM26 6v6H20V6h6m0-2H20a2 2 0 00-2 2v6a2 2 0 002 2h6a2 2 0 002-2V6a2 2 0 00-2-2z"
  })), children);
});
var ViewMode_216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewMode_216(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 26H28V28H4zM4 19H28V21H4zM12 6v6H6V6h6m0-2H6A2 2 0 004 6v6a2 2 0 002 2h6a2 2 0 002-2V6a2 2 0 00-2-2zM26 6v6H20V6h6m0-2H20a2 2 0 00-2 2v6a2 2 0 002 2h6a2 2 0 002-2V6a2 2 0 00-2-2z"
  })), children);
});
var ViewOff32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewOff32(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.24,22.51l1.43-1.42A14.06,14.06,0,0,1,3.07,16C5.1,10.93,10.7,7,16,7a12.38,12.38,0,0,1,4,.72l1.55-1.56A14.72,14.72,0,0,0,16,5,16.69,16.69,0,0,0,1.06,15.66a1,1,0,0,0,0,.68A16,16,0,0,0,5.24,22.51Z"
  })), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 15.73a4 4 0 013.7-3.7l1.81-1.82a6 6 0 00-7.33 7.33zM30.94 15.66A16.4 16.4 0 0025.2 8.22L30 3.41 28.59 2 2 28.59 3.41 30l5.1-5.1A15.29 15.29 0 0016 27 16.69 16.69 0 0030.94 16.34 1 1 0 0030.94 15.66zM20 16a4 4 0 01-6 3.44L19.44 14A4 4 0 0120 16zm-4 9a13.05 13.05 0 01-6-1.58l2.54-2.54a6 6 0 008.35-8.35l2.87-2.87A14.54 14.54 0 0128.93 16C26.9 21.07 21.3 25 16 25z"
  })), children);
});
var ViewOff24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewOff24(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.24,22.51l1.43-1.42A14.06,14.06,0,0,1,3.07,16C5.1,10.93,10.7,7,16,7a12.38,12.38,0,0,1,4,.72l1.55-1.56A14.72,14.72,0,0,0,16,5,16.69,16.69,0,0,0,1.06,15.66a1,1,0,0,0,0,.68A16,16,0,0,0,5.24,22.51Z"
  })), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 15.73a4 4 0 013.7-3.7l1.81-1.82a6 6 0 00-7.33 7.33zM30.94 15.66A16.4 16.4 0 0025.2 8.22L30 3.41 28.59 2 2 28.59 3.41 30l5.1-5.1A15.29 15.29 0 0016 27 16.69 16.69 0 0030.94 16.34 1 1 0 0030.94 15.66zM20 16a4 4 0 01-6 3.44L19.44 14A4 4 0 0120 16zm-4 9a13.05 13.05 0 01-6-1.58l2.54-2.54a6 6 0 008.35-8.35l2.87-2.87A14.54 14.54 0 0128.93 16C26.9 21.07 21.3 25 16 25z"
  })), children);
});
var ViewOff20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewOff20(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.24,22.51l1.43-1.42A14.06,14.06,0,0,1,3.07,16C5.1,10.93,10.7,7,16,7a12.38,12.38,0,0,1,4,.72l1.55-1.56A14.72,14.72,0,0,0,16,5,16.69,16.69,0,0,0,1.06,15.66a1,1,0,0,0,0,.68A16,16,0,0,0,5.24,22.51Z"
  })), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 15.73a4 4 0 013.7-3.7l1.81-1.82a6 6 0 00-7.33 7.33zM30.94 15.66A16.4 16.4 0 0025.2 8.22L30 3.41 28.59 2 2 28.59 3.41 30l5.1-5.1A15.29 15.29 0 0016 27 16.69 16.69 0 0030.94 16.34 1 1 0 0030.94 15.66zM20 16a4 4 0 01-6 3.44L19.44 14A4 4 0 0120 16zm-4 9a13.05 13.05 0 01-6-1.58l2.54-2.54a6 6 0 008.35-8.35l2.87-2.87A14.54 14.54 0 0128.93 16C26.9 21.07 21.3 25 16 25z"
  })), children);
});
var ViewOff16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewOff16(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2.6,11.3l0.7-0.7C2.6,9.8,1.9,9,1.5,8c1-2.5,3.8-4.5,6.5-4.5c0.7,0,1.4,0.1,2,0.4l0.8-0.8C9.9,2.7,9,2.5,8,2.5\tC4.7,2.6,1.7,4.7,0.5,7.8c0,0.1,0,0.2,0,0.3C1,9.3,1.7,10.4,2.6,11.3z"
  })), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 7.9c.1-1 .9-1.8 1.8-1.8l.9-.9C7.2 4.7 5.5 5.6 5.1 7.2 5 7.7 5 8.3 5.1 8.8L6 7.9zM15.5 7.8c-.6-1.5-1.6-2.8-2.9-3.7L15 1.7 14.3 1 1 14.3 1.7 15l2.6-2.6c1.1.7 2.4 1 3.7 1.1 3.3-.1 6.3-2.2 7.5-5.3C15.5 8.1 15.5 7.9 15.5 7.8zM10 8c0 1.1-.9 2-2 2-.3 0-.7-.1-1-.3L9.7 7C9.9 7.3 10 7.6 10 8zM8 12.5c-1 0-2.1-.3-3-.8l1.3-1.3c1.4.9 3.2.6 4.2-.8.7-1 .7-2.4 0-3.4l1.4-1.4c1.1.8 2 1.9 2.6 3.2C13.4 10.5 10.6 12.5 8 12.5z"
  })), children);
});
var ViewOffFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewOffFilled32(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.94 15.66a16.4 16.4 0 00-5.73-7.45L30 3.41 28.59 2 2 28.59 3.41 30l5.1-5.09A15.38 15.38 0 0016 27 16.69 16.69 0 0030.94 16.34 1 1 0 0030.94 15.66zM16 22.5a6.46 6.46 0 01-3.83-1.26L14 19.43A4 4 0 0019.43 14l1.81-1.81A6.49 6.49 0 0116 22.5zM4.53 21.81l5-5A6.84 6.84 0 019.5 16 6.51 6.51 0 0116 9.5a6.84 6.84 0 01.79.05l3.78-3.77A14.39 14.39 0 0016 5 16.69 16.69 0 001.06 15.66a1 1 0 000 .68A15.86 15.86 0 004.53 21.81z"
  })), children);
});
var ViewOffFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewOffFilled24(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.94 15.66a16.4 16.4 0 00-5.73-7.45L30 3.41 28.59 2 2 28.59 3.41 30l5.1-5.09A15.38 15.38 0 0016 27 16.69 16.69 0 0030.94 16.34 1 1 0 0030.94 15.66zM16 22.5a6.46 6.46 0 01-3.83-1.26L14 19.43A4 4 0 0019.43 14l1.81-1.81A6.49 6.49 0 0116 22.5zM4.53 21.81l5-5A6.84 6.84 0 019.5 16 6.51 6.51 0 0116 9.5a6.84 6.84 0 01.79.05l3.78-3.77A14.39 14.39 0 0016 5 16.69 16.69 0 001.06 15.66a1 1 0 000 .68A15.86 15.86 0 004.53 21.81z"
  })), children);
});
var ViewOffFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewOffFilled20(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.94 15.66a16.4 16.4 0 00-5.73-7.45L30 3.41 28.59 2 2 28.59 3.41 30l5.1-5.09A15.38 15.38 0 0016 27 16.69 16.69 0 0030.94 16.34 1 1 0 0030.94 15.66zM16 22.5a6.46 6.46 0 01-3.83-1.26L14 19.43A4 4 0 0019.43 14l1.81-1.81A6.49 6.49 0 0116 22.5zM4.53 21.81l5-5A6.84 6.84 0 019.5 16 6.51 6.51 0 0116 9.5a6.84 6.84 0 01.79.05l3.78-3.77A14.39 14.39 0 0016 5 16.69 16.69 0 001.06 15.66a1 1 0 000 .68A15.86 15.86 0 004.53 21.81z"
  })), children);
});
var ViewOffFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewOffFilled16(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.94 15.66a16.4 16.4 0 00-5.73-7.45L30 3.41 28.59 2 2 28.59 3.41 30l5.1-5.09A15.38 15.38 0 0016 27 16.69 16.69 0 0030.94 16.34 1 1 0 0030.94 15.66zM16 22.5a6.46 6.46 0 01-3.83-1.26L14 19.43A4 4 0 0019.43 14l1.81-1.81A6.49 6.49 0 0116 22.5zM4.53 21.81l5-5A6.84 6.84 0 019.5 16 6.51 6.51 0 0116 9.5a6.84 6.84 0 01.79.05l3.78-3.77A14.39 14.39 0 0016 5 16.69 16.69 0 001.06 15.66a1 1 0 000 .68A15.86 15.86 0 004.53 21.81z"
  })), children);
});
var ViewNext32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewNext32(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.587 22L15 16.41 15 7 16.998 7 16.998 15.582 22 20.587 20.587 22z"
  })), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9158,13.9158,0,0,1,26,6.2343V2h2v8H20V8h4.9217A11.9818,11.9818,0,1,0,28,16h2A14,14,0,1,1,16,2Z"
  })), children);
});
var ViewNext24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewNext24(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.587 22L15 16.41 15 7 16.998 7 16.998 15.582 22 20.587 20.587 22z"
  })), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9158,13.9158,0,0,1,26,6.2343V2h2v8H20V8h4.9217A11.9818,11.9818,0,1,0,28,16h2A14,14,0,1,1,16,2Z"
  })), children);
});
var ViewNext20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewNext20(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.587 22L15 16.41 15 7 16.998 7 16.998 15.582 22 20.587 20.587 22z"
  })), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9158,13.9158,0,0,1,26,6.2343V2h2v8H20V8h4.9217A11.9818,11.9818,0,1,0,28,16h2A14,14,0,1,1,16,2Z"
  })), children);
});
var ViewNext16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ViewNext16(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.587 22L15 16.41 15 7 16.998 7 16.998 15.582 22 20.587 20.587 22z"
  })), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.9158,13.9158,0,0,1,26,6.2343V2h2v8H20V8h4.9217A11.9818,11.9818,0,1,0,28,16h2A14,14,0,1,1,16,2Z"
  })), children);
});
var VirtualColumn32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualColumn32(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 11L26.414 12.414 23.828 15 30 15 30 17 23.828 17 26.414 19.586 25 21 20 16 25 11z"
  })), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 28H20a2.0023 2.0023 0 01-2-2V6a2.0023 2.0023 0 012-2H30V6H20V26H30zM12 28H2V26H12V6H2V4H12a2.0023 2.0023 0 012 2V26A2.0023 2.0023 0 0112 28z"
  })), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 11L5.586 12.414 8.172 15 2 15 2 17 8.172 17 5.586 19.586 7 21 12 16 7 11z"
  })), children);
});
var VirtualColumn24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualColumn24(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 11L26.414 12.414 23.828 15 30 15 30 17 23.828 17 26.414 19.586 25 21 20 16 25 11z"
  })), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 28H20a2.0023 2.0023 0 01-2-2V6a2.0023 2.0023 0 012-2H30V6H20V26H30zM12 28H2V26H12V6H2V4H12a2.0023 2.0023 0 012 2V26A2.0023 2.0023 0 0112 28z"
  })), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 11L5.586 12.414 8.172 15 2 15 2 17 8.172 17 5.586 19.586 7 21 12 16 7 11z"
  })), children);
});
var VirtualColumn20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualColumn20(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 11L26.414 12.414 23.828 15 30 15 30 17 23.828 17 26.414 19.586 25 21 20 16 25 11z"
  })), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 28H20a2.0023 2.0023 0 01-2-2V6a2.0023 2.0023 0 012-2H30V6H20V26H30zM12 28H2V26H12V6H2V4H12a2.0023 2.0023 0 012 2V26A2.0023 2.0023 0 0112 28z"
  })), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 11L5.586 12.414 8.172 15 2 15 2 17 8.172 17 5.586 19.586 7 21 12 16 7 11z"
  })), children);
});
var VirtualColumn16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualColumn16(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 11L26.414 12.414 23.828 15 30 15 30 17 23.828 17 26.414 19.586 25 21 20 16 25 11z"
  })), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 28H20a2.0023 2.0023 0 01-2-2V6a2.0023 2.0023 0 012-2H30V6H20V26H30zM12 28H2V26H12V6H2V4H12a2.0023 2.0023 0 012 2V26A2.0023 2.0023 0 0112 28z"
  })), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 11L5.586 12.414 8.172 15 2 15 2 17 8.172 17 5.586 19.586 7 21 12 16 7 11z"
  })), children);
});
var VirtualColumnKey32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualColumnKey32(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24.5",
    cy: "9.5",
    r: "1.5"
  })), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.4143,22H12V16.5857l6.03-6.03A5.3518,5.3518,0,0,1,18,10a6,6,0,1,1,6,6,5.3583,5.3583,0,0,1-.5559-.03ZM14,20h2.5857l6.1706-6.1709.5174.0957A3.935,3.935,0,0,0,24,14a4.0507,4.0507,0,1,0-3.925-3.2729l.0952.5166L14,17.4143Z"
  })), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,18v8H10V6h4V4H4A2.0025,2.0025,0,0,0,2,6V26a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V18ZM4,6H8V26H4Z"
  })), children);
});
var VirtualColumnKey24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualColumnKey24(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24.5",
    cy: "9.5",
    r: "1.5"
  })), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.4143,22H12V16.5857l6.03-6.03A5.3518,5.3518,0,0,1,18,10a6,6,0,1,1,6,6,5.3583,5.3583,0,0,1-.5559-.03ZM14,20h2.5857l6.1706-6.1709.5174.0957A3.935,3.935,0,0,0,24,14a4.0507,4.0507,0,1,0-3.925-3.2729l.0952.5166L14,17.4143Z"
  })), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,18v8H10V6h4V4H4A2.0025,2.0025,0,0,0,2,6V26a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V18ZM4,6H8V26H4Z"
  })), children);
});
var VirtualColumnKey20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualColumnKey20(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24.5",
    cy: "9.5",
    r: "1.5"
  })), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.4143,22H12V16.5857l6.03-6.03A5.3518,5.3518,0,0,1,18,10a6,6,0,1,1,6,6,5.3583,5.3583,0,0,1-.5559-.03ZM14,20h2.5857l6.1706-6.1709.5174.0957A3.935,3.935,0,0,0,24,14a4.0507,4.0507,0,1,0-3.925-3.2729l.0952.5166L14,17.4143Z"
  })), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,18v8H10V6h4V4H4A2.0025,2.0025,0,0,0,2,6V26a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V18ZM4,6H8V26H4Z"
  })), children);
});
var VirtualColumnKey16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualColumnKey16(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24.5",
    cy: "9.5",
    r: "1.5"
  })), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.4143,22H12V16.5857l6.03-6.03A5.3518,5.3518,0,0,1,18,10a6,6,0,1,1,6,6,5.3583,5.3583,0,0,1-.5559-.03ZM14,20h2.5857l6.1706-6.1709.5174.0957A3.935,3.935,0,0,0,24,14a4.0507,4.0507,0,1,0-3.925-3.2729l.0952.5166L14,17.4143Z"
  })), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,18v8H10V6h4V4H4A2.0025,2.0025,0,0,0,2,6V26a2.0025,2.0025,0,0,0,2,2H28a2.0025,2.0025,0,0,0,2-2V18ZM4,6H8V26H4Z"
  })), children);
});
var VirtualDesktop32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualDesktop32(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,16H11a2.0023,2.0023,0,0,0-2,2v6a2.0023,2.0023,0,0,0,2,2h4v2H12v2h8V28H17V26h4a2.0023,2.0023,0,0,0,2-2V18A2.0023,2.0023,0,0,0,21,16ZM11,24V18H21l.0015,6Z"
  })), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.8218,10.124a9.9992,9.9992,0,0,0-19.6436,0A7.4914,7.4914,0,0,0,7,24.9746v-2a5.4945,5.4945,0,0,1,.123-10.9541l.8365-.0566.09-.834a7.9979,7.9979,0,0,1,15.9014,0l.09.834.8365.0566A5.4945,5.4945,0,0,1,25,22.9746v2a7.4914,7.4914,0,0,0,.8218-14.8506Z"
  })), children);
});
var VirtualDesktop24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualDesktop24(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,16H11a2.0023,2.0023,0,0,0-2,2v6a2.0023,2.0023,0,0,0,2,2h4v2H12v2h8V28H17V26h4a2.0023,2.0023,0,0,0,2-2V18A2.0023,2.0023,0,0,0,21,16ZM11,24V18H21l.0015,6Z"
  })), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.8218,10.124a9.9992,9.9992,0,0,0-19.6436,0A7.4914,7.4914,0,0,0,7,24.9746v-2a5.4945,5.4945,0,0,1,.123-10.9541l.8365-.0566.09-.834a7.9979,7.9979,0,0,1,15.9014,0l.09.834.8365.0566A5.4945,5.4945,0,0,1,25,22.9746v2a7.4914,7.4914,0,0,0,.8218-14.8506Z"
  })), children);
});
var VirtualDesktop20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualDesktop20(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,16H11a2.0023,2.0023,0,0,0-2,2v6a2.0023,2.0023,0,0,0,2,2h4v2H12v2h8V28H17V26h4a2.0023,2.0023,0,0,0,2-2V18A2.0023,2.0023,0,0,0,21,16ZM11,24V18H21l.0015,6Z"
  })), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.8218,10.124a9.9992,9.9992,0,0,0-19.6436,0A7.4914,7.4914,0,0,0,7,24.9746v-2a5.4945,5.4945,0,0,1,.123-10.9541l.8365-.0566.09-.834a7.9979,7.9979,0,0,1,15.9014,0l.09.834.8365.0566A5.4945,5.4945,0,0,1,25,22.9746v2a7.4914,7.4914,0,0,0,.8218-14.8506Z"
  })), children);
});
var VirtualDesktop16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualDesktop16(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,16H11a2.0023,2.0023,0,0,0-2,2v6a2.0023,2.0023,0,0,0,2,2h4v2H12v2h8V28H17V26h4a2.0023,2.0023,0,0,0,2-2V18A2.0023,2.0023,0,0,0,21,16ZM11,24V18H21l.0015,6Z"
  })), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.8218,10.124a9.9992,9.9992,0,0,0-19.6436,0A7.4914,7.4914,0,0,0,7,24.9746v-2a5.4945,5.4945,0,0,1,.123-10.9541l.8365-.0566.09-.834a7.9979,7.9979,0,0,1,15.9014,0l.09.834.8365.0566A5.4945,5.4945,0,0,1,25,22.9746v2a7.4914,7.4914,0,0,0,.8218-14.8506Z"
  })), children);
});
var VirtualMachine32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualMachine32(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,13H12a2.0025,2.0025,0,0,0-2,2V28a2.0025,2.0025,0,0,0,2,2h8a2.0025,2.0025,0,0,0,2-2V15A2.0025,2.0025,0,0,0,20,13Zm0,2,0,3H12V15Zm0,5,0,3H12V20Zm-8,8V25h8v3Z"
  })), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.91,10.13a.121.121,0,0,1-.0967-.0952A10.0061,10.0061,0,0,0,17.89,2.1816,10.0025,10.0025,0,0,0,6.1858,10.0347a.1212.1212,0,0,1-.0964.0957A7.5019,7.5019,0,0,0,7.4912,25H8V23H7.4954a5.5108,5.5108,0,0,1-5.4387-6.3,5.6992,5.6992,0,0,1,4.7138-4.6606l1.0166-.1836a.1306.1306,0,0,0,.1045-.1035l.18-.9351a8.28,8.28,0,0,1,6.8469-6.7427,7.957,7.957,0,0,1,2.8471.1245,8.22,8.22,0,0,1,6.1475,6.545l.1941,1.0083a.13.13,0,0,0,.1045.1035l1.0576.1914a5.7819,5.7819,0,0,1,3.1011,1.539A5.5052,5.5052,0,0,1,24.5076,23H24v2h.5076A7.5019,7.5019,0,0,0,25.91,10.13Z"
  })), children);
});
var VirtualMachine24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualMachine24(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,13H12a2.0025,2.0025,0,0,0-2,2V28a2.0025,2.0025,0,0,0,2,2h8a2.0025,2.0025,0,0,0,2-2V15A2.0025,2.0025,0,0,0,20,13Zm0,2,0,3H12V15Zm0,5,0,3H12V20Zm-8,8V25h8v3Z"
  })), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.91,10.13a.121.121,0,0,1-.0967-.0952A10.0061,10.0061,0,0,0,17.89,2.1816,10.0025,10.0025,0,0,0,6.1858,10.0347a.1212.1212,0,0,1-.0964.0957A7.5019,7.5019,0,0,0,7.4912,25H8V23H7.4954a5.5108,5.5108,0,0,1-5.4387-6.3,5.6992,5.6992,0,0,1,4.7138-4.6606l1.0166-.1836a.1306.1306,0,0,0,.1045-.1035l.18-.9351a8.28,8.28,0,0,1,6.8469-6.7427,7.957,7.957,0,0,1,2.8471.1245,8.22,8.22,0,0,1,6.1475,6.545l.1941,1.0083a.13.13,0,0,0,.1045.1035l1.0576.1914a5.7819,5.7819,0,0,1,3.1011,1.539A5.5052,5.5052,0,0,1,24.5076,23H24v2h.5076A7.5019,7.5019,0,0,0,25.91,10.13Z"
  })), children);
});
var VirtualMachine20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualMachine20(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,13H12a2.0025,2.0025,0,0,0-2,2V28a2.0025,2.0025,0,0,0,2,2h8a2.0025,2.0025,0,0,0,2-2V15A2.0025,2.0025,0,0,0,20,13Zm0,2,0,3H12V15Zm0,5,0,3H12V20Zm-8,8V25h8v3Z"
  })), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.91,10.13a.121.121,0,0,1-.0967-.0952A10.0061,10.0061,0,0,0,17.89,2.1816,10.0025,10.0025,0,0,0,6.1858,10.0347a.1212.1212,0,0,1-.0964.0957A7.5019,7.5019,0,0,0,7.4912,25H8V23H7.4954a5.5108,5.5108,0,0,1-5.4387-6.3,5.6992,5.6992,0,0,1,4.7138-4.6606l1.0166-.1836a.1306.1306,0,0,0,.1045-.1035l.18-.9351a8.28,8.28,0,0,1,6.8469-6.7427,7.957,7.957,0,0,1,2.8471.1245,8.22,8.22,0,0,1,6.1475,6.545l.1941,1.0083a.13.13,0,0,0,.1045.1035l1.0576.1914a5.7819,5.7819,0,0,1,3.1011,1.539A5.5052,5.5052,0,0,1,24.5076,23H24v2h.5076A7.5019,7.5019,0,0,0,25.91,10.13Z"
  })), children);
});
var VirtualMachine16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualMachine16(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,13H12a2.0025,2.0025,0,0,0-2,2V28a2.0025,2.0025,0,0,0,2,2h8a2.0025,2.0025,0,0,0,2-2V15A2.0025,2.0025,0,0,0,20,13Zm0,2,0,3H12V15Zm0,5,0,3H12V20Zm-8,8V25h8v3Z"
  })), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.91,10.13a.121.121,0,0,1-.0967-.0952A10.0061,10.0061,0,0,0,17.89,2.1816,10.0025,10.0025,0,0,0,6.1858,10.0347a.1212.1212,0,0,1-.0964.0957A7.5019,7.5019,0,0,0,7.4912,25H8V23H7.4954a5.5108,5.5108,0,0,1-5.4387-6.3,5.6992,5.6992,0,0,1,4.7138-4.6606l1.0166-.1836a.1306.1306,0,0,0,.1045-.1035l.18-.9351a8.28,8.28,0,0,1,6.8469-6.7427,7.957,7.957,0,0,1,2.8471.1245,8.22,8.22,0,0,1,6.1475,6.545l.1941,1.0083a.13.13,0,0,0,.1045.1035l1.0576.1914a5.7819,5.7819,0,0,1,3.1011,1.539A5.5052,5.5052,0,0,1,24.5076,23H24v2h.5076A7.5019,7.5019,0,0,0,25.91,10.13Z"
  })), children);
});
var VirtualPrivateCloud32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualPrivateCloud32(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,20V17a4,4,0,0,0-8,0v3a2.0025,2.0025,0,0,0-2,2v6a2.0025,2.0025,0,0,0,2,2h8a2.0025,2.0025,0,0,0,2-2V22A2.0025,2.0025,0,0,0,20,20Zm-6-3a2,2,0,0,1,4,0v3H14ZM12,28V22h8l.0012,6Z"
  })), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.8288,10.1152A10.0067,10.0067,0,0,0,17.89,2.1816,10.0025,10.0025,0,0,0,6.17,10.1152,7.502,7.502,0,0,0,7.4912,25H8V23H7.4953a5.5019,5.5019,0,0,1-.9694-10.9165l1.3488-.2441.2591-1.3457a8.0109,8.0109,0,0,1,15.7312,0l.259,1.3457,1.3489.2441A5.5019,5.5019,0,0,1,24.5076,23H24v2h.5076a7.502,7.502,0,0,0,1.3212-14.8848Z"
  })), children);
});
var VirtualPrivateCloud24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualPrivateCloud24(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,20V17a4,4,0,0,0-8,0v3a2.0025,2.0025,0,0,0-2,2v6a2.0025,2.0025,0,0,0,2,2h8a2.0025,2.0025,0,0,0,2-2V22A2.0025,2.0025,0,0,0,20,20Zm-6-3a2,2,0,0,1,4,0v3H14ZM12,28V22h8l.0012,6Z"
  })), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.8288,10.1152A10.0067,10.0067,0,0,0,17.89,2.1816,10.0025,10.0025,0,0,0,6.17,10.1152,7.502,7.502,0,0,0,7.4912,25H8V23H7.4953a5.5019,5.5019,0,0,1-.9694-10.9165l1.3488-.2441.2591-1.3457a8.0109,8.0109,0,0,1,15.7312,0l.259,1.3457,1.3489.2441A5.5019,5.5019,0,0,1,24.5076,23H24v2h.5076a7.502,7.502,0,0,0,1.3212-14.8848Z"
  })), children);
});
var VirtualPrivateCloud20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualPrivateCloud20(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,20V17a4,4,0,0,0-8,0v3a2.0025,2.0025,0,0,0-2,2v6a2.0025,2.0025,0,0,0,2,2h8a2.0025,2.0025,0,0,0,2-2V22A2.0025,2.0025,0,0,0,20,20Zm-6-3a2,2,0,0,1,4,0v3H14ZM12,28V22h8l.0012,6Z"
  })), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.8288,10.1152A10.0067,10.0067,0,0,0,17.89,2.1816,10.0025,10.0025,0,0,0,6.17,10.1152,7.502,7.502,0,0,0,7.4912,25H8V23H7.4953a5.5019,5.5019,0,0,1-.9694-10.9165l1.3488-.2441.2591-1.3457a8.0109,8.0109,0,0,1,15.7312,0l.259,1.3457,1.3489.2441A5.5019,5.5019,0,0,1,24.5076,23H24v2h.5076a7.502,7.502,0,0,0,1.3212-14.8848Z"
  })), children);
});
var VirtualPrivateCloud16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualPrivateCloud16(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,20V17a4,4,0,0,0-8,0v3a2.0025,2.0025,0,0,0-2,2v6a2.0025,2.0025,0,0,0,2,2h8a2.0025,2.0025,0,0,0,2-2V22A2.0025,2.0025,0,0,0,20,20Zm-6-3a2,2,0,0,1,4,0v3H14ZM12,28V22h8l.0012,6Z"
  })), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.8288,10.1152A10.0067,10.0067,0,0,0,17.89,2.1816,10.0025,10.0025,0,0,0,6.17,10.1152,7.502,7.502,0,0,0,7.4912,25H8V23H7.4953a5.5019,5.5019,0,0,1-.9694-10.9165l1.3488-.2441.2591-1.3457a8.0109,8.0109,0,0,1,15.7312,0l.259,1.3457,1.3489.2441A5.5019,5.5019,0,0,1,24.5076,23H24v2h.5076a7.502,7.502,0,0,0,1.3212-14.8848Z"
  })), children);
});
var VirtualPrivateCloudAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualPrivateCloudAlt32(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.4141,22,10,8.5859V2H2v8H8.5859L22,23.4141V30h8V22ZM8,8H4V4H8ZM28,28H24V24h4Z"
  })), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 6a3.9915 3.9915 0 00-7.8579-1H13V7h9.1421A3.9945 3.9945 0 0025 9.8579V19h2V9.8579A3.9962 3.9962 0 0030 6zM26 8a2 2 0 112-2A2.0023 2.0023 0 0126 8zM19 25H9.8579A3.9945 3.9945 0 007 22.1421V13H5v9.1421A3.9915 3.9915 0 109.8579 27H19zM6 28a2 2 0 112-2A2.0023 2.0023 0 016 28z"
  })), children);
});
var VirtualPrivateCloudAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualPrivateCloudAlt24(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.4141,22,10,8.5859V2H2v8H8.5859L22,23.4141V30h8V22ZM8,8H4V4H8ZM28,28H24V24h4Z"
  })), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 6a3.9915 3.9915 0 00-7.8579-1H13V7h9.1421A3.9945 3.9945 0 0025 9.8579V19h2V9.8579A3.9962 3.9962 0 0030 6zM26 8a2 2 0 112-2A2.0023 2.0023 0 0126 8zM19 25H9.8579A3.9945 3.9945 0 007 22.1421V13H5v9.1421A3.9915 3.9915 0 109.8579 27H19zM6 28a2 2 0 112-2A2.0023 2.0023 0 016 28z"
  })), children);
});
var VirtualPrivateCloudAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualPrivateCloudAlt20(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.4141,22,10,8.5859V2H2v8H8.5859L22,23.4141V30h8V22ZM8,8H4V4H8ZM28,28H24V24h4Z"
  })), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 6a3.9915 3.9915 0 00-7.8579-1H13V7h9.1421A3.9945 3.9945 0 0025 9.8579V19h2V9.8579A3.9962 3.9962 0 0030 6zM26 8a2 2 0 112-2A2.0023 2.0023 0 0126 8zM19 25H9.8579A3.9945 3.9945 0 007 22.1421V13H5v9.1421A3.9915 3.9915 0 109.8579 27H19zM6 28a2 2 0 112-2A2.0023 2.0023 0 016 28z"
  })), children);
});
var VirtualPrivateCloudAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VirtualPrivateCloudAlt16(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.4141,22,10,8.5859V2H2v8H8.5859L22,23.4141V30h8V22ZM8,8H4V4H8ZM28,28H24V24h4Z"
  })), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 6a3.9915 3.9915 0 00-7.8579-1H13V7h9.1421A3.9945 3.9945 0 0025 9.8579V19h2V9.8579A3.9962 3.9962 0 0030 6zM26 8a2 2 0 112-2A2.0023 2.0023 0 0126 8zM19 25H9.8579A3.9945 3.9945 0 007 22.1421V13H5v9.1421A3.9915 3.9915 0 109.8579 27H19zM6 28a2 2 0 112-2A2.0023 2.0023 0 016 28z"
  })), children);
});
var VisualRecognition32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VisualRecognition32(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "12",
    r: "2"
  })), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,5H16.24A8,8,0,1,0,6,16.92V27a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V7A2,2,0,0,0,28,5ZM4,10A6,6,0,0,1,15.19,7H8V9h7.91A6.64,6.64,0,0,1,16,10a6.64,6.64,0,0,1-.09,1H10v2h5.19A6,6,0,0,1,4,10ZM28,27H8l5-5,1.59,1.59a2,2,0,0,0,2.82,0L23,18l5,5Zm0-6.83-3.59-3.59a2,2,0,0,0-2.82,0L16,22.17l-1.59-1.59a2,2,0,0,0-2.82,0L8,24.17V17.74A8.24,8.24,0,0,0,10,18a8,8,0,0,0,8-8,7.9,7.9,0,0,0-.59-3H28Z"
  })), children);
});
var VisualRecognition24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VisualRecognition24(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "12",
    r: "2"
  })), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,5H16.24A8,8,0,1,0,6,16.92V27a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V7A2,2,0,0,0,28,5ZM4,10A6,6,0,0,1,15.19,7H8V9h7.91A6.64,6.64,0,0,1,16,10a6.64,6.64,0,0,1-.09,1H10v2h5.19A6,6,0,0,1,4,10ZM28,27H8l5-5,1.59,1.59a2,2,0,0,0,2.82,0L23,18l5,5Zm0-6.83-3.59-3.59a2,2,0,0,0-2.82,0L16,22.17l-1.59-1.59a2,2,0,0,0-2.82,0L8,24.17V17.74A8.24,8.24,0,0,0,10,18a8,8,0,0,0,8-8,7.9,7.9,0,0,0-.59-3H28Z"
  })), children);
});
var VisualRecognition20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VisualRecognition20(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "12",
    r: "2"
  })), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,5H16.24A8,8,0,1,0,6,16.92V27a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V7A2,2,0,0,0,28,5ZM4,10A6,6,0,0,1,15.19,7H8V9h7.91A6.64,6.64,0,0,1,16,10a6.64,6.64,0,0,1-.09,1H10v2h5.19A6,6,0,0,1,4,10ZM28,27H8l5-5,1.59,1.59a2,2,0,0,0,2.82,0L23,18l5,5Zm0-6.83-3.59-3.59a2,2,0,0,0-2.82,0L16,22.17l-1.59-1.59a2,2,0,0,0-2.82,0L8,24.17V17.74A8.24,8.24,0,0,0,10,18a8,8,0,0,0,8-8,7.9,7.9,0,0,0-.59-3H28Z"
  })), children);
});
var VisualRecognition16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VisualRecognition16(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "12",
    r: "2"
  })), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,5H16.24A8,8,0,1,0,6,16.92V27a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V7A2,2,0,0,0,28,5ZM4,10A6,6,0,0,1,15.19,7H8V9h7.91A6.64,6.64,0,0,1,16,10a6.64,6.64,0,0,1-.09,1H10v2h5.19A6,6,0,0,1,4,10ZM28,27H8l5-5,1.59,1.59a2,2,0,0,0,2.82,0L23,18l5,5Zm0-6.83-3.59-3.59a2,2,0,0,0-2.82,0L16,22.17l-1.59-1.59a2,2,0,0,0-2.82,0L8,24.17V17.74A8.24,8.24,0,0,0,10,18a8,8,0,0,0,8-8,7.9,7.9,0,0,0-.59-3H28Z"
  })), children);
});
var Vlan32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Vlan32(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,17V15H17V11h2a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H13a2.0023,2.0023,0,0,0-2,2V9a2.0023,2.0023,0,0,0,2,2h2v4H2v2H8v4H6a2.0023,2.0023,0,0,0-2,2v5a2.0023,2.0023,0,0,0,2,2h6a2.0023,2.0023,0,0,0,2-2V23a2.0023,2.0023,0,0,0-2-2H10V17H22v4H20a2.0023,2.0023,0,0,0-2,2v5a2.0023,2.0023,0,0,0,2,2h6a2.0023,2.0023,0,0,0,2-2V23a2.0023,2.0023,0,0,0-2-2H24V17ZM13,4h6V9H13ZM12,28H6V23h6Zm14,0H20V23h6Z"
  })), children);
});
var Vlan24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Vlan24(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,17V15H17V11h2a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H13a2.0023,2.0023,0,0,0-2,2V9a2.0023,2.0023,0,0,0,2,2h2v4H2v2H8v4H6a2.0023,2.0023,0,0,0-2,2v5a2.0023,2.0023,0,0,0,2,2h6a2.0023,2.0023,0,0,0,2-2V23a2.0023,2.0023,0,0,0-2-2H10V17H22v4H20a2.0023,2.0023,0,0,0-2,2v5a2.0023,2.0023,0,0,0,2,2h6a2.0023,2.0023,0,0,0,2-2V23a2.0023,2.0023,0,0,0-2-2H24V17ZM13,4h6V9H13ZM12,28H6V23h6Zm14,0H20V23h6Z"
  })), children);
});
var Vlan20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Vlan20(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,17V15H17V11h2a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H13a2.0023,2.0023,0,0,0-2,2V9a2.0023,2.0023,0,0,0,2,2h2v4H2v2H8v4H6a2.0023,2.0023,0,0,0-2,2v5a2.0023,2.0023,0,0,0,2,2h6a2.0023,2.0023,0,0,0,2-2V23a2.0023,2.0023,0,0,0-2-2H10V17H22v4H20a2.0023,2.0023,0,0,0-2,2v5a2.0023,2.0023,0,0,0,2,2h6a2.0023,2.0023,0,0,0,2-2V23a2.0023,2.0023,0,0,0-2-2H24V17ZM13,4h6V9H13ZM12,28H6V23h6Zm14,0H20V23h6Z"
  })), children);
});
var Vlan16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Vlan16(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,17V15H17V11h2a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H13a2.0023,2.0023,0,0,0-2,2V9a2.0023,2.0023,0,0,0,2,2h2v4H2v2H8v4H6a2.0023,2.0023,0,0,0-2,2v5a2.0023,2.0023,0,0,0,2,2h6a2.0023,2.0023,0,0,0,2-2V23a2.0023,2.0023,0,0,0-2-2H10V17H22v4H20a2.0023,2.0023,0,0,0-2,2v5a2.0023,2.0023,0,0,0,2,2h6a2.0023,2.0023,0,0,0,2-2V23a2.0023,2.0023,0,0,0-2-2H24V17ZM13,4h6V9H13ZM12,28H6V23h6Zm14,0H20V23h6Z"
  })), children);
});
var VlanIbm32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VlanIbm32(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22a4 4 0 104 4A4.0045 4.0045 0 0016 22zm0 6a2 2 0 112-2A2.002 2.002 0 0116 28zM30 5a3 3 0 10-4 2.8154V15H17V9H15v6H6V7.8159a3.0007 3.0007 0 10-2 0V15a2.002 2.002 0 002 2h9v3h2V17h9a2.002 2.002 0 002-2V7.8159A2.9958 2.9958 0 0030 5zM5 4A1 1 0 114 5 1.0013 1.0013 0 015 4zM27 6a1 1 0 111-1A1.0013 1.0013 0 0127 6z"
  })), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "5",
    r: "2"
  })), children);
});
var VlanIbm24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VlanIbm24(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22a4 4 0 104 4A4.0045 4.0045 0 0016 22zm0 6a2 2 0 112-2A2.002 2.002 0 0116 28zM30 5a3 3 0 10-4 2.8154V15H17V9H15v6H6V7.8159a3.0007 3.0007 0 10-2 0V15a2.002 2.002 0 002 2h9v3h2V17h9a2.002 2.002 0 002-2V7.8159A2.9958 2.9958 0 0030 5zM5 4A1 1 0 114 5 1.0013 1.0013 0 015 4zM27 6a1 1 0 111-1A1.0013 1.0013 0 0127 6z"
  })), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "5",
    r: "2"
  })), children);
});
var VlanIbm20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VlanIbm20(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22a4 4 0 104 4A4.0045 4.0045 0 0016 22zm0 6a2 2 0 112-2A2.002 2.002 0 0116 28zM30 5a3 3 0 10-4 2.8154V15H17V9H15v6H6V7.8159a3.0007 3.0007 0 10-2 0V15a2.002 2.002 0 002 2h9v3h2V17h9a2.002 2.002 0 002-2V7.8159A2.9958 2.9958 0 0030 5zM5 4A1 1 0 114 5 1.0013 1.0013 0 015 4zM27 6a1 1 0 111-1A1.0013 1.0013 0 0127 6z"
  })), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "5",
    r: "2"
  })), children);
});
var VlanIbm16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VlanIbm16(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22a4 4 0 104 4A4.0045 4.0045 0 0016 22zm0 6a2 2 0 112-2A2.002 2.002 0 0116 28zM30 5a3 3 0 10-4 2.8154V15H17V9H15v6H6V7.8159a3.0007 3.0007 0 10-2 0V15a2.002 2.002 0 002 2h9v3h2V17h9a2.002 2.002 0 002-2V7.8159A2.9958 2.9958 0 0030 5zM5 4A1 1 0 114 5 1.0013 1.0013 0 015 4zM27 6a1 1 0 111-1A1.0013 1.0013 0 0127 6z"
  })), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "5",
    r: "2"
  })), children);
});
var VmdkDisk32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VmdkDisk32(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle21 || (_circle21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10.5",
    cy: "24.5",
    r: "1.5"
  })), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.5 14.964H21.5V20.035H19.5z",
    transform: "rotate(-45 20.5 17.5)"
  })), _circle22 || (_circle22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "13",
    r: "2"
  })), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6a7,7,0,0,0,0,14V18a5,5,0,1,1,5-5h2A7,7,0,0,0,16,6Z"
  })), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V4A2,2,0,0,0,26,2Zm0,26H6V4H26Z"
  })), children);
});
var VmdkDisk24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VmdkDisk24(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle23 || (_circle23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10.5",
    cy: "24.5",
    r: "1.5"
  })), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.5 14.964H21.5V20.035H19.5z",
    transform: "rotate(-45 20.5 17.5)"
  })), _circle24 || (_circle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "13",
    r: "2"
  })), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6a7,7,0,0,0,0,14V18a5,5,0,1,1,5-5h2A7,7,0,0,0,16,6Z"
  })), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V4A2,2,0,0,0,26,2Zm0,26H6V4H26Z"
  })), children);
});
var VmdkDisk20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VmdkDisk20(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle25 || (_circle25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10.5",
    cy: "24.5",
    r: "1.5"
  })), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.5 14.964H21.5V20.035H19.5z",
    transform: "rotate(-45 20.5 17.5)"
  })), _circle26 || (_circle26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "13",
    r: "2"
  })), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6a7,7,0,0,0,0,14V18a5,5,0,1,1,5-5h2A7,7,0,0,0,16,6Z"
  })), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V4A2,2,0,0,0,26,2Zm0,26H6V4H26Z"
  })), children);
});
var VmdkDisk16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VmdkDisk16(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle27 || (_circle27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10.5",
    cy: "24.5",
    r: "1.5"
  })), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.5 14.964H21.5V20.035H19.5z",
    transform: "rotate(-45 20.5 17.5)"
  })), _circle28 || (_circle28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "13",
    r: "2"
  })), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6a7,7,0,0,0,0,14V18a5,5,0,1,1,5-5h2A7,7,0,0,0,16,6Z"
  })), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V4A2,2,0,0,0,26,2Zm0,26H6V4H26Z"
  })), children);
});
var VoiceActivate32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VoiceActivate32(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H24V27H20a5.0055,5.0055,0,0,1-5-5V20.7207l-2.3162-.772a1,1,0,0,1-.5412-1.4631L15,13.7229V11a9.01,9.01,0,0,1,9-9h5V4H24a7.0078,7.0078,0,0,0-7,7v3a.9991.9991,0,0,1-.1426.5144l-2.3586,3.9312,1.8174.6057A1,1,0,0,1,17,20v2a3.0033,3.0033,0,0,0,3,3h5a1,1,0,0,1,1,1Z"
  })), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 12H23V14H19zM9.3325 25.2168a7.0007 7.0007 0 010-10.4341l1.334 1.49a5 5 0 000 7.4537z"
  })), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.3994,28.8008a11.0019,11.0019,0,0,1,0-17.6006L7.6,12.8a9.0009,9.0009,0,0,0,0,14.4014Z"
  })), children);
});
var VoiceActivate24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VoiceActivate24(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H24V27H20a5.0055,5.0055,0,0,1-5-5V20.7207l-2.3162-.772a1,1,0,0,1-.5412-1.4631L15,13.7229V11a9.01,9.01,0,0,1,9-9h5V4H24a7.0078,7.0078,0,0,0-7,7v3a.9991.9991,0,0,1-.1426.5144l-2.3586,3.9312,1.8174.6057A1,1,0,0,1,17,20v2a3.0033,3.0033,0,0,0,3,3h5a1,1,0,0,1,1,1Z"
  })), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 12H23V14H19zM9.3325 25.2168a7.0007 7.0007 0 010-10.4341l1.334 1.49a5 5 0 000 7.4537z"
  })), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.3994,28.8008a11.0019,11.0019,0,0,1,0-17.6006L7.6,12.8a9.0009,9.0009,0,0,0,0,14.4014Z"
  })), children);
});
var VoiceActivate20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VoiceActivate20(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H24V27H20a5.0055,5.0055,0,0,1-5-5V20.7207l-2.3162-.772a1,1,0,0,1-.5412-1.4631L15,13.7229V11a9.01,9.01,0,0,1,9-9h5V4H24a7.0078,7.0078,0,0,0-7,7v3a.9991.9991,0,0,1-.1426.5144l-2.3586,3.9312,1.8174.6057A1,1,0,0,1,17,20v2a3.0033,3.0033,0,0,0,3,3h5a1,1,0,0,1,1,1Z"
  })), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 12H23V14H19zM9.3325 25.2168a7.0007 7.0007 0 010-10.4341l1.334 1.49a5 5 0 000 7.4537z"
  })), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.3994,28.8008a11.0019,11.0019,0,0,1,0-17.6006L7.6,12.8a9.0009,9.0009,0,0,0,0,14.4014Z"
  })), children);
});
var VoiceActivate16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VoiceActivate16(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H24V27H20a5.0055,5.0055,0,0,1-5-5V20.7207l-2.3162-.772a1,1,0,0,1-.5412-1.4631L15,13.7229V11a9.01,9.01,0,0,1,9-9h5V4H24a7.0078,7.0078,0,0,0-7,7v3a.9991.9991,0,0,1-.1426.5144l-2.3586,3.9312,1.8174.6057A1,1,0,0,1,17,20v2a3.0033,3.0033,0,0,0,3,3h5a1,1,0,0,1,1,1Z"
  })), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 12H23V14H19zM9.3325 25.2168a7.0007 7.0007 0 010-10.4341l1.334 1.49a5 5 0 000 7.4537z"
  })), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.3994,28.8008a11.0019,11.0019,0,0,1,0-17.6006L7.6,12.8a9.0009,9.0009,0,0,0,0,14.4014Z"
  })), children);
});
var Voicemail32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Voicemail32(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,10a6,6,0,0,0-4.46,10H12.46A6,6,0,1,0,8,22H24a6,6,0,0,0,0-12ZM4,16a4,4,0,1,1,4,4A4,4,0,0,1,4,16Zm20,4a4,4,0,1,1,4-4A4,4,0,0,1,24,20Z"
  })), children);
});
var Voicemail24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Voicemail24(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,10a6,6,0,0,0-4.46,10H12.46A6,6,0,1,0,8,22H24a6,6,0,0,0,0-12ZM4,16a4,4,0,1,1,4,4A4,4,0,0,1,4,16Zm20,4a4,4,0,1,1,4-4A4,4,0,0,1,24,20Z"
  })), children);
});
var Voicemail20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Voicemail20(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,10a6,6,0,0,0-4.46,10H12.46A6,6,0,1,0,8,22H24a6,6,0,0,0,0-12ZM4,16a4,4,0,1,1,4,4A4,4,0,0,1,4,16Zm20,4a4,4,0,1,1,4-4A4,4,0,0,1,24,20Z"
  })), children);
});
var Voicemail16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Voicemail16(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,10a6,6,0,0,0-4.46,10H12.46A6,6,0,1,0,8,22H24a6,6,0,0,0,0-12ZM4,16a4,4,0,1,1,4,4A4,4,0,0,1,4,16Zm20,4a4,4,0,1,1,4-4A4,4,0,0,1,24,20Z"
  })), children);
});
var VolumeBlockStorage32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeBlockStorage32(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 21H10V14h7zm-5-2h3V16H12zM17 30H10V23h7zm-5-2h3V25H12zM26 21H19V14h7zm-5-2h3V16H21zM26 30H19V23h7zm-5-2h3V25H21z"
  })), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,28H4a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,4,4h7.5857A1.9865,1.9865,0,0,1,13,4.5859L16.4143,8H28a2.0023,2.0023,0,0,1,2,2v8H28V10H15.5857l-4-4H4V26H8Z"
  })), children);
});
var VolumeBlockStorage24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeBlockStorage24(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 21H10V14h7zm-5-2h3V16H12zM17 30H10V23h7zm-5-2h3V25H12zM26 21H19V14h7zm-5-2h3V16H21zM26 30H19V23h7zm-5-2h3V25H21z"
  })), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,28H4a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,4,4h7.5857A1.9865,1.9865,0,0,1,13,4.5859L16.4143,8H28a2.0023,2.0023,0,0,1,2,2v8H28V10H15.5857l-4-4H4V26H8Z"
  })), children);
});
var VolumeBlockStorage20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeBlockStorage20(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 21H10V14h7zm-5-2h3V16H12zM17 30H10V23h7zm-5-2h3V25H12zM26 21H19V14h7zm-5-2h3V16H21zM26 30H19V23h7zm-5-2h3V25H21z"
  })), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,28H4a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,4,4h7.5857A1.9865,1.9865,0,0,1,13,4.5859L16.4143,8H28a2.0023,2.0023,0,0,1,2,2v8H28V10H15.5857l-4-4H4V26H8Z"
  })), children);
});
var VolumeBlockStorage16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeBlockStorage16(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 21H10V14h7zm-5-2h3V16H12zM17 30H10V23h7zm-5-2h3V25H12zM26 21H19V14h7zm-5-2h3V16H21zM26 30H19V23h7zm-5-2h3V25H21z"
  })), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,28H4a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,4,4h7.5857A1.9865,1.9865,0,0,1,13,4.5859L16.4143,8H28a2.0023,2.0023,0,0,1,2,2v8H28V10H15.5857l-4-4H4V26H8Z"
  })), children);
});
var VolumeDown32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeDown32(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.1 10.66L23.58 12a6 6 0 01-.18 7.94l1.47 1.36a8 8 0 00.23-10.59zM20 30a1 1 0 01-.71-.3L11.67 22H5a1 1 0 01-1-1H4V11a1 1 0 011-1h6.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0121 3V29A1 1 0 0120 30zM6 20h6a1.17 1.17 0 01.79.3L19 26.57V5.43L12.79 11.7A1.17 1.17 0 0112 12H6z"
  })), children);
});
var VolumeDown24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeDown24(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.1 10.66L23.58 12a6 6 0 01-.18 7.94l1.47 1.36a8 8 0 00.23-10.59zM20 30a1 1 0 01-.71-.3L11.67 22H5a1 1 0 01-1-1H4V11a1 1 0 011-1h6.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0121 3V29A1 1 0 0120 30zM6 20h6a1.17 1.17 0 01.79.3L19 26.57V5.43L12.79 11.7A1.17 1.17 0 0112 12H6z"
  })), children);
});
var VolumeDown20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeDown20(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.1 10.66L23.58 12a6 6 0 01-.18 7.94l1.47 1.36a8 8 0 00.23-10.59zM20 30a1 1 0 01-.71-.3L11.67 22H5a1 1 0 01-1-1H4V11a1 1 0 011-1h6.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0121 3V29A1 1 0 0120 30zM6 20h6a1.17 1.17 0 01.79.3L19 26.57V5.43L12.79 11.7A1.17 1.17 0 0112 12H6z"
  })), children);
});
var VolumeDown16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeDown16(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.1 10.66L23.58 12a6 6 0 01-.18 7.94l1.47 1.36a8 8 0 00.23-10.59zM20 30a1 1 0 01-.71-.3L11.67 22H5a1 1 0 01-1-1H4V11a1 1 0 011-1h6.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0121 3V29A1 1 0 0120 30zM6 20h6a1.17 1.17 0 01.79.3L19 26.57V5.43L12.79 11.7A1.17 1.17 0 0112 12H6z"
  })), children);
});
var VolumeDownAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeDownAlt32(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 15H32V17H22zM18 30a.997.997 0 01-.7109-.2969L9.666 22H3a.9993.9993 0 01-1-.9988V11a.9993.9993 0 01.9988-1H9.666l7.623-7.7031A1 1 0 0119 3V29A1.0007 1.0007 0 0118 30zM4 20h6a1.2008 1.2008 0 01.7939.2969L17 26.5684V5.4316l-6.2061 6.2715A1.2013 1.2013 0 0110 12H4z"
  })), children);
});
var VolumeDownAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeDownAlt24(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 15H32V17H22zM18 30a.997.997 0 01-.7109-.2969L9.666 22H3a.9993.9993 0 01-1-.9988V11a.9993.9993 0 01.9988-1H9.666l7.623-7.7031A1 1 0 0119 3V29A1.0007 1.0007 0 0118 30zM4 20h6a1.2008 1.2008 0 01.7939.2969L17 26.5684V5.4316l-6.2061 6.2715A1.2013 1.2013 0 0110 12H4z"
  })), children);
});
var VolumeDownAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeDownAlt20(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 15H32V17H22zM18 30a.997.997 0 01-.7109-.2969L9.666 22H3a.9993.9993 0 01-1-.9988V11a.9993.9993 0 01.9988-1H9.666l7.623-7.7031A1 1 0 0119 3V29A1.0007 1.0007 0 0118 30zM4 20h6a1.2008 1.2008 0 01.7939.2969L17 26.5684V5.4316l-6.2061 6.2715A1.2013 1.2013 0 0110 12H4z"
  })), children);
});
var VolumeDownAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeDownAlt16(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 15H32V17H22zM18 30a.997.997 0 01-.7109-.2969L9.666 22H3a.9993.9993 0 01-1-.9988V11a.9993.9993 0 01.9988-1H9.666l7.623-7.7031A1 1 0 0119 3V29A1.0007 1.0007 0 0118 30zM4 20h6a1.2008 1.2008 0 01.7939.2969L17 26.5684V5.4316l-6.2061 6.2715A1.2013 1.2013 0 0110 12H4z"
  })), children);
});
var VolumeDownFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeDownFilled32(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.1 10.66L23.58 12a6 6 0 01-.18 7.94l1.47 1.36a8 8 0 00.23-10.59zM20 30a1 1 0 01-.71-.3L11.67 22H5a1 1 0 01-1-1H4V11a1 1 0 011-1h6.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0121 3V29A1 1 0 0120 30z"
  })), children);
});
var VolumeDownFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeDownFilled24(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.1 10.66L23.58 12a6 6 0 01-.18 7.94l1.47 1.36a8 8 0 00.23-10.59zM20 30a1 1 0 01-.71-.3L11.67 22H5a1 1 0 01-1-1H4V11a1 1 0 011-1h6.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0121 3V29A1 1 0 0120 30z"
  })), children);
});
var VolumeDownFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeDownFilled20(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.1 10.66L23.58 12a6 6 0 01-.18 7.94l1.47 1.36a8 8 0 00.23-10.59zM20 30a1 1 0 01-.71-.3L11.67 22H5a1 1 0 01-1-1H4V11a1 1 0 011-1h6.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0121 3V29A1 1 0 0120 30z"
  })), children);
});
var VolumeDownFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeDownFilled16(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.1 10.66L23.58 12a6 6 0 01-.18 7.94l1.47 1.36a8 8 0 00.23-10.59zM20 30a1 1 0 01-.71-.3L11.67 22H5a1 1 0 01-1-1H4V11a1 1 0 011-1h6.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0121 3V29A1 1 0 0120 30z"
  })), children);
});
var VolumeDownFilledAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeDownFilledAlt32(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 15H32V17H22zM18 30a.997.997 0 01-.7109-.2969L9.666 22H3a.9993.9993 0 01-1-.9988V11a.9993.9993 0 01.9988-1H9.666l7.623-7.7031A1 1 0 0119 3V29A1.0007 1.0007 0 0118 30z"
  })), children);
});
var VolumeDownFilledAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeDownFilledAlt24(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 15H32V17H22zM18 30a.997.997 0 01-.7109-.2969L9.666 22H3a.9993.9993 0 01-1-.9988V11a.9993.9993 0 01.9988-1H9.666l7.623-7.7031A1 1 0 0119 3V29A1.0007 1.0007 0 0118 30z"
  })), children);
});
var VolumeDownFilledAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeDownFilledAlt20(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 15H32V17H22zM18 30a.997.997 0 01-.7109-.2969L9.666 22H3a.9993.9993 0 01-1-.9988V11a.9993.9993 0 01.9988-1H9.666l7.623-7.7031A1 1 0 0119 3V29A1.0007 1.0007 0 0118 30z"
  })), children);
});
var VolumeDownFilledAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeDownFilledAlt16(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 15H32V17H22zM18 30a.997.997 0 01-.7109-.2969L9.666 22H3a.9993.9993 0 01-1-.9988V11a.9993.9993 0 01.9988-1H9.666l7.623-7.7031A1 1 0 0119 3V29A1.0007 1.0007 0 0118 30z"
  })), children);
});
var VolumeFileStorage32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeFileStorage32(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.707,17.293l-5-5A1,1,0,0,0,20,12H14a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V18A1,1,0,0,0,25.707,17.293ZM23.5857,18H20V14.4141ZM14,28V14h4v4a2,2,0,0,0,2,2h4v8Z"
  })), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,27H4a2.0023,2.0023,0,0,1-2-2V5A2.0023,2.0023,0,0,1,4,3h7.5857A1.9865,1.9865,0,0,1,13,3.5859L16.4143,7H28a2.0023,2.0023,0,0,1,2,2v8H28V9H15.5857l-4-4H4V25H8Z"
  })), children);
});
var VolumeFileStorage24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeFileStorage24(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.707,17.293l-5-5A1,1,0,0,0,20,12H14a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V18A1,1,0,0,0,25.707,17.293ZM23.5857,18H20V14.4141ZM14,28V14h4v4a2,2,0,0,0,2,2h4v8Z"
  })), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,27H4a2.0023,2.0023,0,0,1-2-2V5A2.0023,2.0023,0,0,1,4,3h7.5857A1.9865,1.9865,0,0,1,13,3.5859L16.4143,7H28a2.0023,2.0023,0,0,1,2,2v8H28V9H15.5857l-4-4H4V25H8Z"
  })), children);
});
var VolumeFileStorage20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeFileStorage20(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.707,17.293l-5-5A1,1,0,0,0,20,12H14a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V18A1,1,0,0,0,25.707,17.293ZM23.5857,18H20V14.4141ZM14,28V14h4v4a2,2,0,0,0,2,2h4v8Z"
  })), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,27H4a2.0023,2.0023,0,0,1-2-2V5A2.0023,2.0023,0,0,1,4,3h7.5857A1.9865,1.9865,0,0,1,13,3.5859L16.4143,7H28a2.0023,2.0023,0,0,1,2,2v8H28V9H15.5857l-4-4H4V25H8Z"
  })), children);
});
var VolumeFileStorage16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeFileStorage16(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.707,17.293l-5-5A1,1,0,0,0,20,12H14a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V18A1,1,0,0,0,25.707,17.293ZM23.5857,18H20V14.4141ZM14,28V14h4v4a2,2,0,0,0,2,2h4v8Z"
  })), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,27H4a2.0023,2.0023,0,0,1-2-2V5A2.0023,2.0023,0,0,1,4,3h7.5857A1.9865,1.9865,0,0,1,13,3.5859L16.4143,7H28a2.0023,2.0023,0,0,1,2,2v8H28V9H15.5857l-4-4H4V25H8Z"
  })), children);
});
var VolumeMute32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeMute32(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 12.41L29.59 11 26 14.59 22.41 11 21 12.41 24.59 16 21 19.59 22.41 21 26 17.41 29.59 21 31 19.59 27.41 16 31 12.41zM18 30a1 1 0 01-.71-.3L9.67 22H3a1 1 0 01-1-1H2V11a1 1 0 011-1H9.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0119 3V29A1 1 0 0118 30zM4 20h6a1.17 1.17 0 01.79.3L17 26.57V5.43L10.79 11.7A1.17 1.17 0 0110 12H4z"
  })), children);
});
var VolumeMute24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeMute24(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 12.41L29.59 11 26 14.59 22.41 11 21 12.41 24.59 16 21 19.59 22.41 21 26 17.41 29.59 21 31 19.59 27.41 16 31 12.41zM18 30a1 1 0 01-.71-.3L9.67 22H3a1 1 0 01-1-1H2V11a1 1 0 011-1H9.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0119 3V29A1 1 0 0118 30zM4 20h6a1.17 1.17 0 01.79.3L17 26.57V5.43L10.79 11.7A1.17 1.17 0 0110 12H4z"
  })), children);
});
var VolumeMute20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeMute20(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 12.41L29.59 11 26 14.59 22.41 11 21 12.41 24.59 16 21 19.59 22.41 21 26 17.41 29.59 21 31 19.59 27.41 16 31 12.41zM18 30a1 1 0 01-.71-.3L9.67 22H3a1 1 0 01-1-1H2V11a1 1 0 011-1H9.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0119 3V29A1 1 0 0118 30zM4 20h6a1.17 1.17 0 01.79.3L17 26.57V5.43L10.79 11.7A1.17 1.17 0 0110 12H4z"
  })), children);
});
var VolumeMute16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeMute16(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 12.41L29.59 11 26 14.59 22.41 11 21 12.41 24.59 16 21 19.59 22.41 21 26 17.41 29.59 21 31 19.59 27.41 16 31 12.41zM18 30a1 1 0 01-.71-.3L9.67 22H3a1 1 0 01-1-1H2V11a1 1 0 011-1H9.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0119 3V29A1 1 0 0118 30zM4 20h6a1.17 1.17 0 01.79.3L17 26.57V5.43L10.79 11.7A1.17 1.17 0 0110 12H4z"
  })), children);
});
var VolumeMuteFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeMuteFilled32(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 12.41L29.59 11 26 14.59 22.41 11 21 12.41 24.59 16 21 19.59 22.41 21 26 17.41 29.59 21 31 19.59 27.41 16 31 12.41zM18 30a1 1 0 01-.71-.3L9.67 22H3a1 1 0 01-1-1H2V11a1 1 0 011-1H9.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0119 3V29A1 1 0 0118 30z"
  })), children);
});
var VolumeMuteFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeMuteFilled24(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 12.41L29.59 11 26 14.59 22.41 11 21 12.41 24.59 16 21 19.59 22.41 21 26 17.41 29.59 21 31 19.59 27.41 16 31 12.41zM18 30a1 1 0 01-.71-.3L9.67 22H3a1 1 0 01-1-1H2V11a1 1 0 011-1H9.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0119 3V29A1 1 0 0118 30z"
  })), children);
});
var VolumeMuteFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeMuteFilled20(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 12.41L29.59 11 26 14.59 22.41 11 21 12.41 24.59 16 21 19.59 22.41 21 26 17.41 29.59 21 31 19.59 27.41 16 31 12.41zM18 30a1 1 0 01-.71-.3L9.67 22H3a1 1 0 01-1-1H2V11a1 1 0 011-1H9.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0119 3V29A1 1 0 0118 30z"
  })), children);
});
var VolumeMuteFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeMuteFilled16(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 12.41L29.59 11 26 14.59 22.41 11 21 12.41 24.59 16 21 19.59 22.41 21 26 17.41 29.59 21 31 19.59 27.41 16 31 12.41zM18 30a1 1 0 01-.71-.3L9.67 22H3a1 1 0 01-1-1H2V11a1 1 0 011-1H9.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0119 3V29A1 1 0 0118 30z"
  })), children);
});
var VolumeObjectStorage32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeObjectStorage32(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,24a2.98,2.98,0,0,0-2.0376.8115l-4.0037-2.4023a2.0478,2.0478,0,0,0,0-.8184l4.0037-2.4023a3.2463,3.2463,0,1,0-.9211-1.7793l-4.0037,2.4023a3,3,0,1,0,0,4.377l4.0037,2.4023A2.9729,2.9729,0,0,0,20,27a3,3,0,1,0,3-3Zm0-8a1,1,0,1,1-1,1A1.0008,1.0008,0,0,1,23,16Zm-9,7a1,1,0,1,1,1-1A1.0008,1.0008,0,0,1,14,23Zm9,5a1,1,0,1,1,1-1A1.0008,1.0008,0,0,1,23,28Z"
  })), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,28H4a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,4,4h7.5857A1.9865,1.9865,0,0,1,13,4.5859L16.4143,8H28a2.0023,2.0023,0,0,1,2,2v8H28V10H15.5857l-4-4H4V26H8Z"
  })), children);
});
var VolumeObjectStorage24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeObjectStorage24(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,24a2.98,2.98,0,0,0-2.0376.8115l-4.0037-2.4023a2.0478,2.0478,0,0,0,0-.8184l4.0037-2.4023a3.2463,3.2463,0,1,0-.9211-1.7793l-4.0037,2.4023a3,3,0,1,0,0,4.377l4.0037,2.4023A2.9729,2.9729,0,0,0,20,27a3,3,0,1,0,3-3Zm0-8a1,1,0,1,1-1,1A1.0008,1.0008,0,0,1,23,16Zm-9,7a1,1,0,1,1,1-1A1.0008,1.0008,0,0,1,14,23Zm9,5a1,1,0,1,1,1-1A1.0008,1.0008,0,0,1,23,28Z"
  })), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,28H4a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,4,4h7.5857A1.9865,1.9865,0,0,1,13,4.5859L16.4143,8H28a2.0023,2.0023,0,0,1,2,2v8H28V10H15.5857l-4-4H4V26H8Z"
  })), children);
});
var VolumeObjectStorage20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeObjectStorage20(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,24a2.98,2.98,0,0,0-2.0376.8115l-4.0037-2.4023a2.0478,2.0478,0,0,0,0-.8184l4.0037-2.4023a3.2463,3.2463,0,1,0-.9211-1.7793l-4.0037,2.4023a3,3,0,1,0,0,4.377l4.0037,2.4023A2.9729,2.9729,0,0,0,20,27a3,3,0,1,0,3-3Zm0-8a1,1,0,1,1-1,1A1.0008,1.0008,0,0,1,23,16Zm-9,7a1,1,0,1,1,1-1A1.0008,1.0008,0,0,1,14,23Zm9,5a1,1,0,1,1,1-1A1.0008,1.0008,0,0,1,23,28Z"
  })), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,28H4a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,4,4h7.5857A1.9865,1.9865,0,0,1,13,4.5859L16.4143,8H28a2.0023,2.0023,0,0,1,2,2v8H28V10H15.5857l-4-4H4V26H8Z"
  })), children);
});
var VolumeObjectStorage16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeObjectStorage16(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,24a2.98,2.98,0,0,0-2.0376.8115l-4.0037-2.4023a2.0478,2.0478,0,0,0,0-.8184l4.0037-2.4023a3.2463,3.2463,0,1,0-.9211-1.7793l-4.0037,2.4023a3,3,0,1,0,0,4.377l4.0037,2.4023A2.9729,2.9729,0,0,0,20,27a3,3,0,1,0,3-3Zm0-8a1,1,0,1,1-1,1A1.0008,1.0008,0,0,1,23,16Zm-9,7a1,1,0,1,1,1-1A1.0008,1.0008,0,0,1,14,23Zm9,5a1,1,0,1,1,1-1A1.0008,1.0008,0,0,1,23,28Z"
  })), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,28H4a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,4,4h7.5857A1.9865,1.9865,0,0,1,13,4.5859L16.4143,8H28a2.0023,2.0023,0,0,1,2,2v8H28V10H15.5857l-4-4H4V26H8Z"
  })), children);
});
var VolumeUp32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeUp32(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.16,8.08,25.63,9.37a10,10,0,0,1-.29,13.23L26.81,24a12,12,0,0,0,.35-15.88Z"
  })), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.58 12a6 6 0 01-.18 7.94l1.47 1.36a8 8 0 00.23-10.59zM18 30a1 1 0 01-.71-.3L9.67 22H3a1 1 0 01-1-1H2V11a1 1 0 011-1H9.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0119 3V29A1 1 0 0118 30zM4 20h6.08a1 1 0 01.71.3L17 26.57V5.43L10.79 11.7a1 1 0 01-.71.3H4z"
  })), children);
});
var VolumeUp24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeUp24(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.16,8.08,25.63,9.37a10,10,0,0,1-.29,13.23L26.81,24a12,12,0,0,0,.35-15.88Z"
  })), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.58 12a6 6 0 01-.18 7.94l1.47 1.36a8 8 0 00.23-10.59zM18 30a1 1 0 01-.71-.3L9.67 22H3a1 1 0 01-1-1H2V11a1 1 0 011-1H9.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0119 3V29A1 1 0 0118 30zM4 20h6.08a1 1 0 01.71.3L17 26.57V5.43L10.79 11.7a1 1 0 01-.71.3H4z"
  })), children);
});
var VolumeUp20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeUp20(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.16,8.08,25.63,9.37a10,10,0,0,1-.29,13.23L26.81,24a12,12,0,0,0,.35-15.88Z"
  })), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.58 12a6 6 0 01-.18 7.94l1.47 1.36a8 8 0 00.23-10.59zM18 30a1 1 0 01-.71-.3L9.67 22H3a1 1 0 01-1-1H2V11a1 1 0 011-1H9.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0119 3V29A1 1 0 0118 30zM4 20h6.08a1 1 0 01.71.3L17 26.57V5.43L10.79 11.7a1 1 0 01-.71.3H4z"
  })), children);
});
var VolumeUp16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeUp16(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.16,8.08,25.63,9.37a10,10,0,0,1-.29,13.23L26.81,24a12,12,0,0,0,.35-15.88Z"
  })), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.58 12a6 6 0 01-.18 7.94l1.47 1.36a8 8 0 00.23-10.59zM18 30a1 1 0 01-.71-.3L9.67 22H3a1 1 0 01-1-1H2V11a1 1 0 011-1H9.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0119 3V29A1 1 0 0118 30zM4 20h6.08a1 1 0 01.71.3L17 26.57V5.43L10.79 11.7a1 1 0 01-.71.3H4z"
  })), children);
});
var VolumeUpAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeUpAlt32(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32 15L28 15 28 11 26 11 26 15 22 15 22 17 26 17 26 21 28 21 28 17 32 17 32 15zM18 30a.997.997 0 01-.7109-.2969L9.666 22H3a.9993.9993 0 01-1-.9988V11a.9993.9993 0 01.9988-1H9.666l7.623-7.7031A1 1 0 0119 3V29A1.0007 1.0007 0 0118 30zM4 20h6a1.2008 1.2008 0 01.7939.2969L17 26.5684V5.4316l-6.2061 6.2715A1.2013 1.2013 0 0110 12H4z"
  })), children);
});
var VolumeUpAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeUpAlt24(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32 15L28 15 28 11 26 11 26 15 22 15 22 17 26 17 26 21 28 21 28 17 32 17 32 15zM18 30a.997.997 0 01-.7109-.2969L9.666 22H3a.9993.9993 0 01-1-.9988V11a.9993.9993 0 01.9988-1H9.666l7.623-7.7031A1 1 0 0119 3V29A1.0007 1.0007 0 0118 30zM4 20h6a1.2008 1.2008 0 01.7939.2969L17 26.5684V5.4316l-6.2061 6.2715A1.2013 1.2013 0 0110 12H4z"
  })), children);
});
var VolumeUpAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeUpAlt20(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32 15L28 15 28 11 26 11 26 15 22 15 22 17 26 17 26 21 28 21 28 17 32 17 32 15zM18 30a.997.997 0 01-.7109-.2969L9.666 22H3a.9993.9993 0 01-1-.9988V11a.9993.9993 0 01.9988-1H9.666l7.623-7.7031A1 1 0 0119 3V29A1.0007 1.0007 0 0118 30zM4 20h6a1.2008 1.2008 0 01.7939.2969L17 26.5684V5.4316l-6.2061 6.2715A1.2013 1.2013 0 0110 12H4z"
  })), children);
});
var VolumeUpAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeUpAlt16(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32 15L28 15 28 11 26 11 26 15 22 15 22 17 26 17 26 21 28 21 28 17 32 17 32 15zM18 30a.997.997 0 01-.7109-.2969L9.666 22H3a.9993.9993 0 01-1-.9988V11a.9993.9993 0 01.9988-1H9.666l7.623-7.7031A1 1 0 0119 3V29A1.0007 1.0007 0 0118 30zM4 20h6a1.2008 1.2008 0 01.7939.2969L17 26.5684V5.4316l-6.2061 6.2715A1.2013 1.2013 0 0110 12H4z"
  })), children);
});
var VolumeUpFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeUpFilled32(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.16,8.08,25.63,9.37a10,10,0,0,1-.29,13.23L26.81,24a12,12,0,0,0,.35-15.88Z"
  })), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.58 12a6 6 0 01-.18 7.94l1.47 1.36a8 8 0 00.23-10.59zM18 30a1 1 0 01-.71-.3L9.67 22H3a1 1 0 01-1-1H2V11a1 1 0 011-1H9.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0119 3V29A1 1 0 0118 30z"
  })), children);
});
var VolumeUpFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeUpFilled24(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.16,8.08,25.63,9.37a10,10,0,0,1-.29,13.23L26.81,24a12,12,0,0,0,.35-15.88Z"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.58 12a6 6 0 01-.18 7.94l1.47 1.36a8 8 0 00.23-10.59zM18 30a1 1 0 01-.71-.3L9.67 22H3a1 1 0 01-1-1H2V11a1 1 0 011-1H9.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0119 3V29A1 1 0 0118 30z"
  })), children);
});
var VolumeUpFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeUpFilled20(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.16,8.08,25.63,9.37a10,10,0,0,1-.29,13.23L26.81,24a12,12,0,0,0,.35-15.88Z"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.58 12a6 6 0 01-.18 7.94l1.47 1.36a8 8 0 00.23-10.59zM18 30a1 1 0 01-.71-.3L9.67 22H3a1 1 0 01-1-1H2V11a1 1 0 011-1H9.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0119 3V29A1 1 0 0118 30z"
  })), children);
});
var VolumeUpFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeUpFilled16(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.16,8.08,25.63,9.37a10,10,0,0,1-.29,13.23L26.81,24a12,12,0,0,0,.35-15.88Z"
  })), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.58 12a6 6 0 01-.18 7.94l1.47 1.36a8 8 0 00.23-10.59zM18 30a1 1 0 01-.71-.3L9.67 22H3a1 1 0 01-1-1H2V11a1 1 0 011-1H9.67l7.62-7.7a1 1 0 011.41 0A1 1 0 0119 3V29A1 1 0 0118 30z"
  })), children);
});
var VolumeUpFilledAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeUpFilledAlt32(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32 15L28 15 28 11 26 11 26 15 22 15 22 17 26 17 26 21 28 21 28 17 32 17 32 15zM18 30a.997.997 0 01-.7109-.2969L9.666 22H3a.9993.9993 0 01-1-.9988V11a.9993.9993 0 01.9988-1H9.666l7.623-7.7031A1 1 0 0119 3V29A1.0007 1.0007 0 0118 30z"
  })), children);
});
var VolumeUpFilledAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeUpFilledAlt24(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32 15L28 15 28 11 26 11 26 15 22 15 22 17 26 17 26 21 28 21 28 17 32 17 32 15zM18 30a.997.997 0 01-.7109-.2969L9.666 22H3a.9993.9993 0 01-1-.9988V11a.9993.9993 0 01.9988-1H9.666l7.623-7.7031A1 1 0 0119 3V29A1.0007 1.0007 0 0118 30z"
  })), children);
});
var VolumeUpFilledAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeUpFilledAlt20(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32 15L28 15 28 11 26 11 26 15 22 15 22 17 26 17 26 21 28 21 28 17 32 17 32 15zM18 30a.997.997 0 01-.7109-.2969L9.666 22H3a.9993.9993 0 01-1-.9988V11a.9993.9993 0 01.9988-1H9.666l7.623-7.7031A1 1 0 0119 3V29A1.0007 1.0007 0 0118 30z"
  })), children);
});
var VolumeUpFilledAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VolumeUpFilledAlt16(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32 15L28 15 28 11 26 11 26 15 22 15 22 17 26 17 26 21 28 21 28 17 32 17 32 15zM18 30a.997.997 0 01-.7109-.2969L9.666 22H3a.9993.9993 0 01-1-.9988V11a.9993.9993 0 01.9988-1H9.666l7.623-7.7031A1 1 0 0119 3V29A1.0007 1.0007 0 0118 30z"
  })), children);
});
var Vpn32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Vpn32(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 23H12V9h6a2 2 0 012 2v5a2 2 0 01-2 2H14zm0-7h4V11H14zM28 19L24.32 9 22 9 22 23 24 23 24 13 27.68 23 30 23 30 9 28 9 28 19zM8 9L6 22 4 9 2 9 4.52 23 7.48 23 10 9 8 9z"
  })), children);
});
var Vpn24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Vpn24(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 23H12V9h6a2 2 0 012 2v5a2 2 0 01-2 2H14zm0-7h4V11H14zM28 19L24.32 9 22 9 22 23 24 23 24 13 27.68 23 30 23 30 9 28 9 28 19zM8 9L6 22 4 9 2 9 4.52 23 7.48 23 10 9 8 9z"
  })), children);
});
var Vpn20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Vpn20(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 23H12V9h6a2 2 0 012 2v5a2 2 0 01-2 2H14zm0-7h4V11H14zM28 19L24.32 9 22 9 22 23 24 23 24 13 27.68 23 30 23 30 9 28 9 28 19zM8 9L6 22 4 9 2 9 4.52 23 7.48 23 10 9 8 9z"
  })), children);
});
var Vpn16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Vpn16(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 23H12V9h6a2 2 0 012 2v5a2 2 0 01-2 2H14zm0-7h4V11H14zM28 19L24.32 9 22 9 22 23 24 23 24 13 27.68 23 30 23 30 9 28 9 28 19zM8 9L6 22 4 9 2 9 4.52 23 7.48 23 10 9 8 9z"
  })), children);
});
var VpnConnection32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VpnConnection32(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,7a1.9919,1.9919,0,0,0-1.7227,1H22A6,6,0,0,0,10,8H5.7227a2,2,0,1,0,0,2H10v4H8a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V16a2,2,0,0,0-2-2H22V10h4.2773A1.9966,1.9966,0,1,0,28,7ZM12,8a4,4,0,0,1,8,0v6H12V10h5V8Zm12,8V28H8V16Z"
  })), children);
});
var VpnConnection24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VpnConnection24(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,7a1.9919,1.9919,0,0,0-1.7227,1H22A6,6,0,0,0,10,8H5.7227a2,2,0,1,0,0,2H10v4H8a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V16a2,2,0,0,0-2-2H22V10h4.2773A1.9966,1.9966,0,1,0,28,7ZM12,8a4,4,0,0,1,8,0v6H12V10h5V8Zm12,8V28H8V16Z"
  })), children);
});
var VpnConnection20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VpnConnection20(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,7a1.9919,1.9919,0,0,0-1.7227,1H22A6,6,0,0,0,10,8H5.7227a2,2,0,1,0,0,2H10v4H8a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V16a2,2,0,0,0-2-2H22V10h4.2773A1.9966,1.9966,0,1,0,28,7ZM12,8a4,4,0,0,1,8,0v6H12V10h5V8Zm12,8V28H8V16Z"
  })), children);
});
var VpnConnection16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VpnConnection16(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,7a1.9919,1.9919,0,0,0-1.7227,1H22A6,6,0,0,0,10,8H5.7227a2,2,0,1,0,0,2H10v4H8a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V16a2,2,0,0,0-2-2H22V10h4.2773A1.9966,1.9966,0,1,0,28,7ZM12,8a4,4,0,0,1,8,0v6H12V10h5V8Zm12,8V28H8V16Z"
  })), children);
});
var VpnPolicy32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VpnPolicy32(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15A6,6,0,1,0,20,19.46V29l4-1.8838L28,29V19.46A5.98,5.98,0,0,0,30,15ZM26,25.8477l-2-.9415-2,.9415V20.65a5.8877,5.8877,0,0,0,4,0ZM24,19a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,24,19Z"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2A6.0066,6.0066,0,0,0,8,8v6H6a2.0023,2.0023,0,0,0-2,2V28a2.0023,2.0023,0,0,0,2,2H17V28H6V16h9V14H10V8a4,4,0,0,1,7.92-.8008l1.96-.3984A6.0167,6.0167,0,0,0,14,2Z"
  })), children);
});
var VpnPolicy24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VpnPolicy24(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15A6,6,0,1,0,20,19.46V29l4-1.8838L28,29V19.46A5.98,5.98,0,0,0,30,15ZM26,25.8477l-2-.9415-2,.9415V20.65a5.8877,5.8877,0,0,0,4,0ZM24,19a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,24,19Z"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2A6.0066,6.0066,0,0,0,8,8v6H6a2.0023,2.0023,0,0,0-2,2V28a2.0023,2.0023,0,0,0,2,2H17V28H6V16h9V14H10V8a4,4,0,0,1,7.92-.8008l1.96-.3984A6.0167,6.0167,0,0,0,14,2Z"
  })), children);
});
var VpnPolicy20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VpnPolicy20(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15A6,6,0,1,0,20,19.46V29l4-1.8838L28,29V19.46A5.98,5.98,0,0,0,30,15ZM26,25.8477l-2-.9415-2,.9415V20.65a5.8877,5.8877,0,0,0,4,0ZM24,19a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,24,19Z"
  })), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2A6.0066,6.0066,0,0,0,8,8v6H6a2.0023,2.0023,0,0,0-2,2V28a2.0023,2.0023,0,0,0,2,2H17V28H6V16h9V14H10V8a4,4,0,0,1,7.92-.8008l1.96-.3984A6.0167,6.0167,0,0,0,14,2Z"
  })), children);
});
var VpnPolicy16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function VpnPolicy16(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15A6,6,0,1,0,20,19.46V29l4-1.8838L28,29V19.46A5.98,5.98,0,0,0,30,15ZM26,25.8477l-2-.9415-2,.9415V20.65a5.8877,5.8877,0,0,0,4,0ZM24,19a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,24,19Z"
  })), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2A6.0066,6.0066,0,0,0,8,8v6H6a2.0023,2.0023,0,0,0-2,2V28a2.0023,2.0023,0,0,0,2,2H17V28H6V16h9V14H10V8a4,4,0,0,1,7.92-.8008l1.96-.3984A6.0167,6.0167,0,0,0,14,2Z"
  })), children);
});
var Wallet32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wallet32(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 17H24V19H22z"
  })), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H4V5H26V3H4A2,2,0,0,0,2,5V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V10A2,2,0,0,0,28,8ZM4,26V10H28v3H20a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h8v3ZM28,15v6H20V15Z"
  })), children);
});
var Wallet24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wallet24(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 17H24V19H22z"
  })), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H4V5H26V3H4A2,2,0,0,0,2,5V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V10A2,2,0,0,0,28,8ZM4,26V10H28v3H20a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h8v3ZM28,15v6H20V15Z"
  })), children);
});
var Wallet20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wallet20(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 17H24V19H22z"
  })), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H4V5H26V3H4A2,2,0,0,0,2,5V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V10A2,2,0,0,0,28,8ZM4,26V10H28v3H20a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h8v3ZM28,15v6H20V15Z"
  })), children);
});
var Wallet16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wallet16(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 17H24V19H22z"
  })), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,8H4V5H26V3H4A2,2,0,0,0,2,5V26a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V10A2,2,0,0,0,28,8ZM4,26V10H28v3H20a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h8v3ZM28,15v6H20V15Z"
  })), children);
});
var Warning32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Warning32(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 8H17V19H15zM16 22a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 22z"
  })), children);
});
var Warning24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Warning24(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 8H17V19H15zM16 22a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 22z"
  })), children);
});
var Warning20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Warning20(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 8H17V19H15zM16 22a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 22z"
  })), children);
});
var Warning16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Warning16(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,1C4.1,1,1,4.1,1,8s3.1,7,7,7s7-3.1,7-7S11.9,1,8,1z M8,14c-3.3,0-6-2.7-6-6s2.7-6,6-6s6,2.7,6,6S11.3,14,8,14z"
  })), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.5 4H8.5V9H7.5zM8 10.2c-.4 0-.8.3-.8.8s.3.8.8.8c.4 0 .8-.3.8-.8S8.4 10.2 8 10.2z"
  })), children);
});
var WarningAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningAlt32(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 23a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 23zM15 12H17V21H15z"
  })), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,30H3a1,1,0,0,1-.8872-1.4614l13-25a1,1,0,0,1,1.7744,0l13,25A1,1,0,0,1,29,30ZM4.6507,28H27.3493l.002-.0033L16.002,6.1714h-.004L4.6487,27.9967Z"
  })), children);
});
var WarningAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningAlt24(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 23a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 23zM15 12H17V21H15z"
  })), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,30H3a1,1,0,0,1-.8872-1.4614l13-25a1,1,0,0,1,1.7744,0l13,25A1,1,0,0,1,29,30ZM4.6507,28H27.3493l.002-.0033L16.002,6.1714h-.004L4.6487,27.9967Z"
  })), children);
});
var WarningAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningAlt20(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 23a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 23zM15 12H17V21H15z"
  })), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,30H3a1,1,0,0,1-.8872-1.4614l13-25a1,1,0,0,1,1.7744,0l13,25A1,1,0,0,1,29,30ZM4.6507,28H27.3493l.002-.0033L16.002,6.1714h-.004L4.6487,27.9967Z"
  })), children);
});
var WarningAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningAlt16(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.5,14h-13c-0.2,0-0.3-0.1-0.4-0.2c-0.1-0.2-0.1-0.3,0-0.5l6.5-12C7.7,1,8,0.9,8.2,1.1c0.1,0,0.2,0.1,0.2,0.2l6.5,12\tc0.1,0.2,0.1,0.3,0,0.5C14.9,13.9,14.7,14,14.5,14z M2.3,13h11.3L8,2.5L2.3,13z"
  })), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.5 6H8.5V9.5H7.5zM8 10.8c-.4 0-.8.3-.8.8s.3.8.8.8c.4 0 .8-.3.8-.8S8.4 10.8 8 10.8z"
  })), children);
});
var WarningAltFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningAltFilled32(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,26a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,26Zm-1.125-5h2.25V12h-2.25Z",
    "data-icon-path": "inner-path"
  })), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.002,6.1714h-.004L4.6487,27.9966,4.6506,28H27.3494l.0019-.0034ZM14.875,12h2.25v9h-2.25ZM16,26a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,26Z"
  })), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,30H3a1,1,0,0,1-.8872-1.4614l13-25a1,1,0,0,1,1.7744,0l13,25A1,1,0,0,1,29,30ZM4.6507,28H27.3493l.002-.0033L16.002,6.1714h-.004L4.6487,27.9967Z"
  })), children);
});
var WarningAltFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningAltFilled24(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,26a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,26Zm-1.125-5h2.25V12h-2.25Z",
    "data-icon-path": "inner-path"
  })), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.002,6.1714h-.004L4.6487,27.9966,4.6506,28H27.3494l.0019-.0034ZM14.875,12h2.25v9h-2.25ZM16,26a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,26Z"
  })), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,30H3a1,1,0,0,1-.8872-1.4614l13-25a1,1,0,0,1,1.7744,0l13,25A1,1,0,0,1,29,30ZM4.6507,28H27.3493l.002-.0033L16.002,6.1714h-.004L4.6487,27.9967Z"
  })), children);
});
var WarningAltFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningAltFilled20(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,26a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,26Zm-1.125-5h2.25V12h-2.25Z",
    "data-icon-path": "inner-path"
  })), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.002,6.1714h-.004L4.6487,27.9966,4.6506,28H27.3494l.0019-.0034ZM14.875,12h2.25v9h-2.25ZM16,26a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,26Z"
  })), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,30H3a1,1,0,0,1-.8872-1.4614l13-25a1,1,0,0,1,1.7744,0l13,25A1,1,0,0,1,29,30ZM4.6507,28H27.3493l.002-.0033L16.002,6.1714h-.004L4.6487,27.9967Z"
  })), children);
});
var WarningAltFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningAltFilled16(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,26a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,26Zm-1.125-5h2.25V12h-2.25Z",
    "data-icon-path": "inner-path"
  })), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.002,6.1714h-.004L4.6487,27.9966,4.6506,28H27.3494l.0019-.0034ZM14.875,12h2.25v9h-2.25ZM16,26a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,26Z"
  })), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,30H3a1,1,0,0,1-.8872-1.4614l13-25a1,1,0,0,1,1.7744,0l13,25A1,1,0,0,1,29,30ZM4.6507,28H27.3493l.002-.0033L16.002,6.1714h-.004L4.6487,27.9967Z"
  })), children);
});
var WarningAltInverted32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningAltInverted32(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 17a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 17zM15 6H17V15H15z"
  })), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.855,2.481a1.001,1.001,0,0,1,.0322.98l-13,25a1,1,0,0,1-1.7744,0l-13-25A1,1,0,0,1,3,2H29A1.0007,1.0007,0,0,1,29.855,2.481ZM4.6487,4.0033,15.998,25.8286h.004L27.3513,4.0033,27.3493,4H4.6507Z"
  })), children);
});
var WarningAltInverted24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningAltInverted24(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 17a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 17zM15 6H17V15H15z"
  })), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.855,2.481a1.001,1.001,0,0,1,.0322.98l-13,25a1,1,0,0,1-1.7744,0l-13-25A1,1,0,0,1,3,2H29A1.0007,1.0007,0,0,1,29.855,2.481ZM4.6487,4.0033,15.998,25.8286h.004L27.3513,4.0033,27.3493,4H4.6507Z"
  })), children);
});
var WarningAltInverted20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningAltInverted20(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 17a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 17zM15 6H17V15H15z"
  })), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.855,2.481a1.001,1.001,0,0,1,.0322.98l-13,25a1,1,0,0,1-1.7744,0l-13-25A1,1,0,0,1,3,2H29A1.0007,1.0007,0,0,1,29.855,2.481ZM4.6487,4.0033,15.998,25.8286h.004L27.3513,4.0033,27.3493,4H4.6507Z"
  })), children);
});
var WarningAltInverted16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningAltInverted16(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 17a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 17zM15 6H17V15H15z"
  })), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.855,2.481a1.001,1.001,0,0,1,.0322.98l-13,25a1,1,0,0,1-1.7744,0l-13-25A1,1,0,0,1,3,2H29A1.0007,1.0007,0,0,1,29.855,2.481ZM4.6487,4.0033,15.998,25.8286h.004L27.3513,4.0033,27.3493,4H4.6507Z"
  })), children);
});
var WarningAltInvertedFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningAltInvertedFilled32(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,20a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,20Zm-1.125-5h2.25V6h-2.25Z",
    "data-icon-path": "inner-path"
  })), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.3494,4H4.6506l-.0019.0034L15.998,25.8286h.004L27.3513,4.0034ZM14.875,6h2.25v9h-2.25ZM16,20a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,20Z"
  })), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.855,2.481a1.001,1.001,0,0,1,.0322.98l-13,25a1,1,0,0,1-1.7744,0l-13-25A1,1,0,0,1,3,2H29A1.0007,1.0007,0,0,1,29.855,2.481ZM4.6487,4.0033,15.998,25.8286h.004L27.3513,4.0033,27.3493,4H4.6507Z"
  })), children);
});
var WarningAltInvertedFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningAltInvertedFilled24(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,20a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,20Zm-1.125-5h2.25V6h-2.25Z",
    "data-icon-path": "inner-path"
  })), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.3494,4H4.6506l-.0019.0034L15.998,25.8286h.004L27.3513,4.0034ZM14.875,6h2.25v9h-2.25ZM16,20a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,20Z"
  })), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.855,2.481a1.001,1.001,0,0,1,.0322.98l-13,25a1,1,0,0,1-1.7744,0l-13-25A1,1,0,0,1,3,2H29A1.0007,1.0007,0,0,1,29.855,2.481ZM4.6487,4.0033,15.998,25.8286h.004L27.3513,4.0033,27.3493,4H4.6507Z"
  })), children);
});
var WarningAltInvertedFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningAltInvertedFilled20(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,20a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,20Zm-1.125-5h2.25V6h-2.25Z",
    "data-icon-path": "inner-path"
  })), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.3494,4H4.6506l-.0019.0034L15.998,25.8286h.004L27.3513,4.0034ZM14.875,6h2.25v9h-2.25ZM16,20a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,20Z"
  })), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.855,2.481a1.001,1.001,0,0,1,.0322.98l-13,25a1,1,0,0,1-1.7744,0l-13-25A1,1,0,0,1,3,2H29A1.0007,1.0007,0,0,1,29.855,2.481ZM4.6487,4.0033,15.998,25.8286h.004L27.3513,4.0033,27.3493,4H4.6507Z"
  })), children);
});
var WarningAltInvertedFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningAltInvertedFilled16(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path390 || (_path390 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,20a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,20Zm-1.125-5h2.25V6h-2.25Z",
    "data-icon-path": "inner-path"
  })), _path391 || (_path391 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.3494,4H4.6506l-.0019.0034L15.998,25.8286h.004L27.3513,4.0034ZM14.875,6h2.25v9h-2.25ZM16,20a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,20Z"
  })), _path392 || (_path392 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.855,2.481a1.001,1.001,0,0,1,.0322.98l-13,25a1,1,0,0,1-1.7744,0l-13-25A1,1,0,0,1,3,2H29A1.0007,1.0007,0,0,1,29.855,2.481ZM4.6487,4.0033,15.998,25.8286h.004L27.3513,4.0033,27.3493,4H4.6507Z"
  })), children);
});
var WarningFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningFilled32(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path393 || (_path393 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2C8.3,2,2,8.3,2,16s6.3,14,14,14s14-6.3,14-14C30,8.3,23.7,2,16,2z M14.9,8h2.2v11h-2.2V8z M16,25\tc-0.8,0-1.5-0.7-1.5-1.5S15.2,22,16,22c0.8,0,1.5,0.7,1.5,1.5S16.8,25,16,25z"
  })), _path394 || (_path394 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M17.5,23.5c0,0.8-0.7,1.5-1.5,1.5c-0.8,0-1.5-0.7-1.5-1.5S15.2,22,16,22\tC16.8,22,17.5,22.7,17.5,23.5z M17.1,8h-2.2v11h2.2V8z",
    "data-icon-path": "inner-path",
    opacity: "0"
  })), children);
});
var WarningFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningFilled24(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 24 24",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path395 || (_path395 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,1C5.9,1,1,5.9,1,12s4.9,11,11,11s11-4.9,11-11C23,5.9,18.1,1,12,1z M11.1,6h1.8v8h-1.8V6z M12,19.2\tc-0.7,0-1.2-0.6-1.2-1.2s0.6-1.2,1.2-1.2s1.2,0.6,1.2,1.2S12.7,19.2,12,19.2z"
  })), _path396 || (_path396 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M13.2,18c0,0.7-0.6,1.2-1.2,1.2s-1.2-0.6-1.2-1.2s0.6-1.2,1.2-1.2S13.2,17.3,13.2,18z M12.9,6\th-1.8v8h1.8V6z",
    "data-icon-path": "inner-path",
    opacity: "0"
  })), children);
});
var WarningFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningFilled20(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 20 20",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path397 || (_path397 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,1c-5,0-9,4-9,9s4,9,9,9s9-4,9-9S15,1,10,1z M9.2,5h1.5v7H9.2V5z M10,16c-0.6,0-1-0.4-1-1s0.4-1,1-1\ts1,0.4,1,1S10.6,16,10,16z"
  })), _path398 || (_path398 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.2,5h1.5v7H9.2V5z M10,16c-0.6,0-1-0.4-1-1s0.4-1,1-1s1,0.4,1,1S10.6,16,10,16z",
    "data-icon-path": "inner-path",
    opacity: "0"
  })), children);
});
var WarningFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningFilled16(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path399 || (_path399 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,1C4.2,1,1,4.2,1,8s3.2,7,7,7s7-3.1,7-7S11.9,1,8,1z M7.5,4h1v5h-1C7.5,9,7.5,4,7.5,4z M8,12.2\tc-0.4,0-0.8-0.4-0.8-0.8s0.3-0.8,0.8-0.8c0.4,0,0.8,0.4,0.8,0.8S8.4,12.2,8,12.2z"
  })), _path400 || (_path400 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.5,4h1v5h-1C7.5,9,7.5,4,7.5,4z M8,12.2c-0.4,0-0.8-0.4-0.8-0.8s0.3-0.8,0.8-0.8\tc0.4,0,0.8,0.4,0.8,0.8S8.4,12.2,8,12.2z",
    "data-icon-path": "inner-path",
    opacity: "0"
  })), children);
});
var WarningHex32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningHex32(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path401 || (_path401 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 21a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 21zM15 8H17V18H15z"
  })), _path402 || (_path402 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,29H9a1,1,0,0,1-.8638-.4961l-7-12a1,1,0,0,1,0-1.0078l7-12A1,1,0,0,1,9,3H23a1,1,0,0,1,.8638.4961l7,12a1,1,0,0,1,0,1.0078l-7,12A1,1,0,0,1,23,29ZM9.5742,27H22.4258l6.4165-11L22.4258,5H9.5742L3.1577,16Z"
  })), children);
});
var WarningHex24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningHex24(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path403 || (_path403 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 21a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 21zM15 8H17V18H15z"
  })), _path404 || (_path404 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,29H9a1,1,0,0,1-.8638-.4961l-7-12a1,1,0,0,1,0-1.0078l7-12A1,1,0,0,1,9,3H23a1,1,0,0,1,.8638.4961l7,12a1,1,0,0,1,0,1.0078l-7,12A1,1,0,0,1,23,29ZM9.5742,27H22.4258l6.4165-11L22.4258,5H9.5742L3.1577,16Z"
  })), children);
});
var WarningHex20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningHex20(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path405 || (_path405 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 21a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 21zM15 8H17V18H15z"
  })), _path406 || (_path406 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,29H9a1,1,0,0,1-.8638-.4961l-7-12a1,1,0,0,1,0-1.0078l7-12A1,1,0,0,1,9,3H23a1,1,0,0,1,.8638.4961l7,12a1,1,0,0,1,0,1.0078l-7,12A1,1,0,0,1,23,29ZM9.5742,27H22.4258l6.4165-11L22.4258,5H9.5742L3.1577,16Z"
  })), children);
});
var WarningHex16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningHex16(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path407 || (_path407 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 21a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 21zM15 8H17V18H15z"
  })), _path408 || (_path408 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,29H9a1,1,0,0,1-.8638-.4961l-7-12a1,1,0,0,1,0-1.0078l7-12A1,1,0,0,1,9,3H23a1,1,0,0,1,.8638.4961l7,12a1,1,0,0,1,0,1.0078l-7,12A1,1,0,0,1,23,29ZM9.5742,27H22.4258l6.4165-11L22.4258,5H9.5742L3.1577,16Z"
  })), children);
});
var WarningHexFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningHexFilled32(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path409 || (_path409 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M14.875,8h2.25V19h-2.25ZM16,25a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,25Z",
    "data-icon-path": "inner-path"
  })), _path410 || (_path410 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.8508,15.4487,23.8867,3.5322A1.0687,1.0687,0,0,0,22.9643,3H9.0357a1.0687,1.0687,0,0,0-.9224.5322L1.1492,15.4487a1.0933,1.0933,0,0,0,0,1.1026L8.1133,28.4678A1.0687,1.0687,0,0,0,9.0357,29H22.9643a1.0687,1.0687,0,0,0,.9224-.5322l6.9641-11.9165A1.0933,1.0933,0,0,0,30.8508,15.4487ZM14.875,8h2.25V19h-2.25ZM16,25a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,25Z"
  })), children);
});
var WarningHexFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningHexFilled24(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path411 || (_path411 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M14.875,8h2.25V19h-2.25ZM16,25a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,25Z",
    "data-icon-path": "inner-path"
  })), _path412 || (_path412 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.8508,15.4487,23.8867,3.5322A1.0687,1.0687,0,0,0,22.9643,3H9.0357a1.0687,1.0687,0,0,0-.9224.5322L1.1492,15.4487a1.0933,1.0933,0,0,0,0,1.1026L8.1133,28.4678A1.0687,1.0687,0,0,0,9.0357,29H22.9643a1.0687,1.0687,0,0,0,.9224-.5322l6.9641-11.9165A1.0933,1.0933,0,0,0,30.8508,15.4487ZM14.875,8h2.25V19h-2.25ZM16,25a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,25Z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-3.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-3.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Cafe16": () => (/* binding */ Cafe16),
/* harmony export */   "Cafe20": () => (/* binding */ Cafe20),
/* harmony export */   "Calculation16": () => (/* binding */ Calculation16),
/* harmony export */   "Calculation20": () => (/* binding */ Calculation20),
/* harmony export */   "Calculation24": () => (/* binding */ Calculation24),
/* harmony export */   "Calculation32": () => (/* binding */ Calculation32),
/* harmony export */   "CalculationAlt16": () => (/* binding */ CalculationAlt16),
/* harmony export */   "CalculationAlt20": () => (/* binding */ CalculationAlt20),
/* harmony export */   "CalculationAlt24": () => (/* binding */ CalculationAlt24),
/* harmony export */   "CalculationAlt32": () => (/* binding */ CalculationAlt32),
/* harmony export */   "Calculator16": () => (/* binding */ Calculator16),
/* harmony export */   "Calculator20": () => (/* binding */ Calculator20),
/* harmony export */   "Calculator24": () => (/* binding */ Calculator24),
/* harmony export */   "Calculator32": () => (/* binding */ Calculator32),
/* harmony export */   "CalculatorCheck16": () => (/* binding */ CalculatorCheck16),
/* harmony export */   "CalculatorCheck20": () => (/* binding */ CalculatorCheck20),
/* harmony export */   "CalculatorCheck24": () => (/* binding */ CalculatorCheck24),
/* harmony export */   "CalculatorCheck32": () => (/* binding */ CalculatorCheck32),
/* harmony export */   "Calendar16": () => (/* binding */ Calendar16),
/* harmony export */   "Calendar20": () => (/* binding */ Calendar20),
/* harmony export */   "Calendar24": () => (/* binding */ Calendar24),
/* harmony export */   "Calendar32": () => (/* binding */ Calendar32),
/* harmony export */   "CalendarHeatMap16": () => (/* binding */ CalendarHeatMap16),
/* harmony export */   "CalendarHeatMap20": () => (/* binding */ CalendarHeatMap20),
/* harmony export */   "CalendarHeatMap24": () => (/* binding */ CalendarHeatMap24),
/* harmony export */   "CalendarHeatMap32": () => (/* binding */ CalendarHeatMap32),
/* harmony export */   "CalendarSettings16": () => (/* binding */ CalendarSettings16),
/* harmony export */   "CalendarSettings20": () => (/* binding */ CalendarSettings20),
/* harmony export */   "CalendarSettings24": () => (/* binding */ CalendarSettings24),
/* harmony export */   "CalendarSettings32": () => (/* binding */ CalendarSettings32),
/* harmony export */   "CalendarTools16": () => (/* binding */ CalendarTools16),
/* harmony export */   "CalendarTools20": () => (/* binding */ CalendarTools20),
/* harmony export */   "CalendarTools24": () => (/* binding */ CalendarTools24),
/* harmony export */   "CalendarTools32": () => (/* binding */ CalendarTools32),
/* harmony export */   "Calibrate16": () => (/* binding */ Calibrate16),
/* harmony export */   "Calibrate20": () => (/* binding */ Calibrate20),
/* harmony export */   "Calibrate24": () => (/* binding */ Calibrate24),
/* harmony export */   "Calibrate32": () => (/* binding */ Calibrate32),
/* harmony export */   "Camera16": () => (/* binding */ Camera16),
/* harmony export */   "Camera20": () => (/* binding */ Camera20),
/* harmony export */   "Camera24": () => (/* binding */ Camera24),
/* harmony export */   "Camera32": () => (/* binding */ Camera32),
/* harmony export */   "CameraAction16": () => (/* binding */ CameraAction16),
/* harmony export */   "CameraAction20": () => (/* binding */ CameraAction20),
/* harmony export */   "CameraAction24": () => (/* binding */ CameraAction24),
/* harmony export */   "CameraAction32": () => (/* binding */ CameraAction32),
/* harmony export */   "Campsite16": () => (/* binding */ Campsite16),
/* harmony export */   "Campsite20": () => (/* binding */ Campsite20),
/* harmony export */   "Campsite24": () => (/* binding */ Campsite24),
/* harmony export */   "Campsite32": () => (/* binding */ Campsite32),
/* harmony export */   "Car16": () => (/* binding */ Car16),
/* harmony export */   "Car20": () => (/* binding */ Car20),
/* harmony export */   "Car24": () => (/* binding */ Car24),
/* harmony export */   "Car32": () => (/* binding */ Car32),
/* harmony export */   "CarFront16": () => (/* binding */ CarFront16),
/* harmony export */   "CarFront20": () => (/* binding */ CarFront20),
/* harmony export */   "CarFront24": () => (/* binding */ CarFront24),
/* harmony export */   "CarFront32": () => (/* binding */ CarFront32),
/* harmony export */   "Carbon16": () => (/* binding */ Carbon16),
/* harmony export */   "Carbon20": () => (/* binding */ Carbon20),
/* harmony export */   "Carbon24": () => (/* binding */ Carbon24),
/* harmony export */   "Carbon32": () => (/* binding */ Carbon32),
/* harmony export */   "CarbonAccounting16": () => (/* binding */ CarbonAccounting16),
/* harmony export */   "CarbonAccounting20": () => (/* binding */ CarbonAccounting20),
/* harmony export */   "CarbonAccounting24": () => (/* binding */ CarbonAccounting24),
/* harmony export */   "CarbonAccounting32": () => (/* binding */ CarbonAccounting32),
/* harmony export */   "CarbonForIbmDotcom16": () => (/* binding */ CarbonForIbmDotcom16),
/* harmony export */   "CarbonForIbmDotcom20": () => (/* binding */ CarbonForIbmDotcom20),
/* harmony export */   "CarbonForIbmDotcom24": () => (/* binding */ CarbonForIbmDotcom24),
/* harmony export */   "CarbonForIbmDotcom32": () => (/* binding */ CarbonForIbmDotcom32),
/* harmony export */   "CarbonForIbmProduct16": () => (/* binding */ CarbonForIbmProduct16),
/* harmony export */   "CarbonForIbmProduct20": () => (/* binding */ CarbonForIbmProduct20),
/* harmony export */   "CarbonForIbmProduct24": () => (/* binding */ CarbonForIbmProduct24),
/* harmony export */   "CarbonForIbmProduct32": () => (/* binding */ CarbonForIbmProduct32),
/* harmony export */   "CaretDown16": () => (/* binding */ CaretDown16),
/* harmony export */   "CaretDown20": () => (/* binding */ CaretDown20),
/* harmony export */   "CaretDown24": () => (/* binding */ CaretDown24),
/* harmony export */   "CaretDown32": () => (/* binding */ CaretDown32),
/* harmony export */   "CaretDownGlyph": () => (/* binding */ CaretDownGlyph),
/* harmony export */   "CaretLeft16": () => (/* binding */ CaretLeft16),
/* harmony export */   "CaretLeft20": () => (/* binding */ CaretLeft20),
/* harmony export */   "CaretLeft24": () => (/* binding */ CaretLeft24),
/* harmony export */   "CaretLeft32": () => (/* binding */ CaretLeft32),
/* harmony export */   "CaretLeftGlyph": () => (/* binding */ CaretLeftGlyph),
/* harmony export */   "CaretRight16": () => (/* binding */ CaretRight16),
/* harmony export */   "CaretRight20": () => (/* binding */ CaretRight20),
/* harmony export */   "CaretRight24": () => (/* binding */ CaretRight24),
/* harmony export */   "CaretRight32": () => (/* binding */ CaretRight32),
/* harmony export */   "CaretRightGlyph": () => (/* binding */ CaretRightGlyph),
/* harmony export */   "CaretSort16": () => (/* binding */ CaretSort16),
/* harmony export */   "CaretSort20": () => (/* binding */ CaretSort20),
/* harmony export */   "CaretSort24": () => (/* binding */ CaretSort24),
/* harmony export */   "CaretSort32": () => (/* binding */ CaretSort32),
/* harmony export */   "CaretSortDown16": () => (/* binding */ CaretSortDown16),
/* harmony export */   "CaretSortDown20": () => (/* binding */ CaretSortDown20),
/* harmony export */   "CaretSortDown24": () => (/* binding */ CaretSortDown24),
/* harmony export */   "CaretSortDown32": () => (/* binding */ CaretSortDown32),
/* harmony export */   "CaretSortUp16": () => (/* binding */ CaretSortUp16),
/* harmony export */   "CaretSortUp20": () => (/* binding */ CaretSortUp20),
/* harmony export */   "CaretSortUp24": () => (/* binding */ CaretSortUp24),
/* harmony export */   "CaretSortUp32": () => (/* binding */ CaretSortUp32),
/* harmony export */   "CaretUp16": () => (/* binding */ CaretUp16),
/* harmony export */   "CaretUp20": () => (/* binding */ CaretUp20),
/* harmony export */   "CaretUp24": () => (/* binding */ CaretUp24),
/* harmony export */   "CaretUp32": () => (/* binding */ CaretUp32),
/* harmony export */   "CaretUpGlyph": () => (/* binding */ CaretUpGlyph),
/* harmony export */   "CarouselHorizontal16": () => (/* binding */ CarouselHorizontal16),
/* harmony export */   "CarouselHorizontal20": () => (/* binding */ CarouselHorizontal20),
/* harmony export */   "CarouselHorizontal24": () => (/* binding */ CarouselHorizontal24),
/* harmony export */   "CarouselHorizontal32": () => (/* binding */ CarouselHorizontal32),
/* harmony export */   "CarouselVertical16": () => (/* binding */ CarouselVertical16),
/* harmony export */   "CarouselVertical20": () => (/* binding */ CarouselVertical20),
/* harmony export */   "CarouselVertical24": () => (/* binding */ CarouselVertical24),
/* harmony export */   "CarouselVertical32": () => (/* binding */ CarouselVertical32),
/* harmony export */   "Catalog16": () => (/* binding */ Catalog16),
/* harmony export */   "Catalog20": () => (/* binding */ Catalog20),
/* harmony export */   "Catalog24": () => (/* binding */ Catalog24),
/* harmony export */   "Catalog32": () => (/* binding */ Catalog32),
/* harmony export */   "Categories16": () => (/* binding */ Categories16),
/* harmony export */   "Categories20": () => (/* binding */ Categories20),
/* harmony export */   "Categories24": () => (/* binding */ Categories24),
/* harmony export */   "Categories32": () => (/* binding */ Categories32),
/* harmony export */   "Category16": () => (/* binding */ Category16),
/* harmony export */   "Category20": () => (/* binding */ Category20),
/* harmony export */   "Category24": () => (/* binding */ Category24),
/* harmony export */   "Category32": () => (/* binding */ Category32),
/* harmony export */   "CategoryAdd16": () => (/* binding */ CategoryAdd16),
/* harmony export */   "CategoryAdd20": () => (/* binding */ CategoryAdd20),
/* harmony export */   "CategoryAdd24": () => (/* binding */ CategoryAdd24),
/* harmony export */   "CategoryAdd32": () => (/* binding */ CategoryAdd32),
/* harmony export */   "CategoryAnd16": () => (/* binding */ CategoryAnd16),
/* harmony export */   "CategoryAnd20": () => (/* binding */ CategoryAnd20),
/* harmony export */   "CategoryAnd24": () => (/* binding */ CategoryAnd24),
/* harmony export */   "CategoryAnd32": () => (/* binding */ CategoryAnd32),
/* harmony export */   "CategoryNew16": () => (/* binding */ CategoryNew16),
/* harmony export */   "CategoryNew20": () => (/* binding */ CategoryNew20),
/* harmony export */   "CategoryNew24": () => (/* binding */ CategoryNew24),
/* harmony export */   "CategoryNew32": () => (/* binding */ CategoryNew32),
/* harmony export */   "CategoryNewEach16": () => (/* binding */ CategoryNewEach16),
/* harmony export */   "CategoryNewEach20": () => (/* binding */ CategoryNewEach20),
/* harmony export */   "CategoryNewEach24": () => (/* binding */ CategoryNewEach24),
/* harmony export */   "CategoryNewEach32": () => (/* binding */ CategoryNewEach32),
/* harmony export */   "CautionGlyph": () => (/* binding */ CautionGlyph),
/* harmony export */   "CautionInvertedGlyph": () => (/* binding */ CautionInvertedGlyph),
/* harmony export */   "Cda16": () => (/* binding */ Cda16),
/* harmony export */   "Cda20": () => (/* binding */ Cda20),
/* harmony export */   "Cda24": () => (/* binding */ Cda24),
/* harmony export */   "Cda32": () => (/* binding */ Cda32),
/* harmony export */   "CellTower16": () => (/* binding */ CellTower16),
/* harmony export */   "CellTower20": () => (/* binding */ CellTower20),
/* harmony export */   "CellTower24": () => (/* binding */ CellTower24),
/* harmony export */   "CellTower32": () => (/* binding */ CellTower32),
/* harmony export */   "CenterCircle16": () => (/* binding */ CenterCircle16),
/* harmony export */   "CenterCircle20": () => (/* binding */ CenterCircle20),
/* harmony export */   "CenterCircle24": () => (/* binding */ CenterCircle24),
/* harmony export */   "CenterCircle32": () => (/* binding */ CenterCircle32),
/* harmony export */   "CenterSquare16": () => (/* binding */ CenterSquare16),
/* harmony export */   "CenterSquare20": () => (/* binding */ CenterSquare20),
/* harmony export */   "CenterSquare24": () => (/* binding */ CenterSquare24),
/* harmony export */   "CenterSquare32": () => (/* binding */ CenterSquare32),
/* harmony export */   "CenterToFit16": () => (/* binding */ CenterToFit16),
/* harmony export */   "CenterToFit20": () => (/* binding */ CenterToFit20),
/* harmony export */   "CenterToFit24": () => (/* binding */ CenterToFit24),
/* harmony export */   "CenterToFit32": () => (/* binding */ CenterToFit32),
/* harmony export */   "Certificate16": () => (/* binding */ Certificate16),
/* harmony export */   "Certificate20": () => (/* binding */ Certificate20),
/* harmony export */   "Certificate24": () => (/* binding */ Certificate24),
/* harmony export */   "Certificate32": () => (/* binding */ Certificate32),
/* harmony export */   "CertificateCheck16": () => (/* binding */ CertificateCheck16),
/* harmony export */   "CertificateCheck20": () => (/* binding */ CertificateCheck20),
/* harmony export */   "CertificateCheck24": () => (/* binding */ CertificateCheck24),
/* harmony export */   "CertificateCheck32": () => (/* binding */ CertificateCheck32),
/* harmony export */   "ChangeCatalog16": () => (/* binding */ ChangeCatalog16),
/* harmony export */   "ChangeCatalog20": () => (/* binding */ ChangeCatalog20),
/* harmony export */   "ChangeCatalog24": () => (/* binding */ ChangeCatalog24),
/* harmony export */   "ChangeCatalog32": () => (/* binding */ ChangeCatalog32),
/* harmony export */   "CharacterDecimal16": () => (/* binding */ CharacterDecimal16),
/* harmony export */   "CharacterDecimal20": () => (/* binding */ CharacterDecimal20),
/* harmony export */   "CharacterDecimal24": () => (/* binding */ CharacterDecimal24),
/* harmony export */   "CharacterDecimal32": () => (/* binding */ CharacterDecimal32),
/* harmony export */   "CharacterFraction16": () => (/* binding */ CharacterFraction16),
/* harmony export */   "CharacterFraction20": () => (/* binding */ CharacterFraction20),
/* harmony export */   "CharacterFraction24": () => (/* binding */ CharacterFraction24),
/* harmony export */   "CharacterFraction32": () => (/* binding */ CharacterFraction32),
/* harmony export */   "CharacterInteger16": () => (/* binding */ CharacterInteger16),
/* harmony export */   "CharacterInteger20": () => (/* binding */ CharacterInteger20),
/* harmony export */   "CharacterInteger24": () => (/* binding */ CharacterInteger24),
/* harmony export */   "CharacterInteger32": () => (/* binding */ CharacterInteger32),
/* harmony export */   "CharacterLowerCase16": () => (/* binding */ CharacterLowerCase16),
/* harmony export */   "CharacterLowerCase20": () => (/* binding */ CharacterLowerCase20),
/* harmony export */   "CharacterLowerCase24": () => (/* binding */ CharacterLowerCase24),
/* harmony export */   "CharacterLowerCase32": () => (/* binding */ CharacterLowerCase32),
/* harmony export */   "CharacterNegativeNumber16": () => (/* binding */ CharacterNegativeNumber16),
/* harmony export */   "CharacterNegativeNumber20": () => (/* binding */ CharacterNegativeNumber20),
/* harmony export */   "CharacterNegativeNumber24": () => (/* binding */ CharacterNegativeNumber24),
/* harmony export */   "CharacterNegativeNumber32": () => (/* binding */ CharacterNegativeNumber32),
/* harmony export */   "CharacterPatterns16": () => (/* binding */ CharacterPatterns16),
/* harmony export */   "CharacterPatterns20": () => (/* binding */ CharacterPatterns20),
/* harmony export */   "CharacterPatterns24": () => (/* binding */ CharacterPatterns24),
/* harmony export */   "CharacterPatterns32": () => (/* binding */ CharacterPatterns32),
/* harmony export */   "CharacterSentenceCase16": () => (/* binding */ CharacterSentenceCase16),
/* harmony export */   "CharacterSentenceCase20": () => (/* binding */ CharacterSentenceCase20),
/* harmony export */   "CharacterSentenceCase24": () => (/* binding */ CharacterSentenceCase24),
/* harmony export */   "CharacterSentenceCase32": () => (/* binding */ CharacterSentenceCase32),
/* harmony export */   "CharacterUpperCase16": () => (/* binding */ CharacterUpperCase16),
/* harmony export */   "CharacterUpperCase20": () => (/* binding */ CharacterUpperCase20),
/* harmony export */   "CharacterUpperCase24": () => (/* binding */ CharacterUpperCase24),
/* harmony export */   "CharacterUpperCase32": () => (/* binding */ CharacterUpperCase32),
/* harmony export */   "CharacterWholeNumber16": () => (/* binding */ CharacterWholeNumber16),
/* harmony export */   "CharacterWholeNumber20": () => (/* binding */ CharacterWholeNumber20),
/* harmony export */   "CharacterWholeNumber24": () => (/* binding */ CharacterWholeNumber24),
/* harmony export */   "CharacterWholeNumber32": () => (/* binding */ CharacterWholeNumber32),
/* harmony export */   "ChargingStation16": () => (/* binding */ ChargingStation16),
/* harmony export */   "ChargingStation20": () => (/* binding */ ChargingStation20),
/* harmony export */   "ChargingStation24": () => (/* binding */ ChargingStation24),
/* harmony export */   "ChargingStation32": () => (/* binding */ ChargingStation32),
/* harmony export */   "ChargingStationFilled16": () => (/* binding */ ChargingStationFilled16),
/* harmony export */   "ChargingStationFilled20": () => (/* binding */ ChargingStationFilled20),
/* harmony export */   "ChargingStationFilled24": () => (/* binding */ ChargingStationFilled24),
/* harmony export */   "ChargingStationFilled32": () => (/* binding */ ChargingStationFilled32),
/* harmony export */   "ChartArea16": () => (/* binding */ ChartArea16),
/* harmony export */   "ChartArea20": () => (/* binding */ ChartArea20),
/* harmony export */   "ChartArea24": () => (/* binding */ ChartArea24),
/* harmony export */   "ChartArea32": () => (/* binding */ ChartArea32),
/* harmony export */   "ChartAreaSmooth16": () => (/* binding */ ChartAreaSmooth16),
/* harmony export */   "ChartAreaSmooth20": () => (/* binding */ ChartAreaSmooth20),
/* harmony export */   "ChartAreaSmooth24": () => (/* binding */ ChartAreaSmooth24),
/* harmony export */   "ChartAreaSmooth32": () => (/* binding */ ChartAreaSmooth32),
/* harmony export */   "ChartAreaStepper24": () => (/* binding */ ChartAreaStepper24),
/* harmony export */   "ChartAreaStepper32": () => (/* binding */ ChartAreaStepper32),
/* harmony export */   "Chart_3D16": () => (/* binding */ Chart_3D16),
/* harmony export */   "Chart_3D20": () => (/* binding */ Chart_3D20),
/* harmony export */   "Chart_3D24": () => (/* binding */ Chart_3D24),
/* harmony export */   "Chart_3D32": () => (/* binding */ Chart_3D32),
/* harmony export */   "QCcX16": () => (/* binding */ QCcX16),
/* harmony export */   "QCcX20": () => (/* binding */ QCcX20),
/* harmony export */   "QCcX24": () => (/* binding */ QCcX24),
/* harmony export */   "QCcX32": () => (/* binding */ QCcX32),
/* harmony export */   "WatsonHealthCdArchive16": () => (/* binding */ WatsonHealthCdArchive16),
/* harmony export */   "WatsonHealthCdArchive20": () => (/* binding */ WatsonHealthCdArchive20),
/* harmony export */   "WatsonHealthCdArchive24": () => (/* binding */ WatsonHealthCdArchive24),
/* harmony export */   "WatsonHealthCdArchive32": () => (/* binding */ WatsonHealthCdArchive32),
/* harmony export */   "WatsonHealthCdCreateArchive16": () => (/* binding */ WatsonHealthCdCreateArchive16),
/* harmony export */   "WatsonHealthCdCreateArchive20": () => (/* binding */ WatsonHealthCdCreateArchive20),
/* harmony export */   "WatsonHealthCdCreateArchive24": () => (/* binding */ WatsonHealthCdCreateArchive24),
/* harmony export */   "WatsonHealthCdCreateArchive32": () => (/* binding */ WatsonHealthCdCreateArchive32),
/* harmony export */   "WatsonHealthCdCreateExchange16": () => (/* binding */ WatsonHealthCdCreateExchange16),
/* harmony export */   "WatsonHealthCdCreateExchange20": () => (/* binding */ WatsonHealthCdCreateExchange20),
/* harmony export */   "WatsonHealthCdCreateExchange24": () => (/* binding */ WatsonHealthCdCreateExchange24),
/* harmony export */   "WatsonHealthCdCreateExchange32": () => (/* binding */ WatsonHealthCdCreateExchange32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _path65, _path66, _path67, _path68, _path69, _circle, _path70, _path71, _path72, _circle2, _path73, _path74, _path75, _circle3, _path76, _path77, _path78, _circle4, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _circle5, _circle6, _path108, _path109, _circle7, _circle8, _path110, _path111, _circle9, _circle10, _path112, _path113, _circle11, _circle12, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _circle13, _path212, _path213, _circle14, _path214, _path215, _circle15, _path216, _path217, _circle16, _path218, _circle17, _path219, _path220, _path221, _circle18, _path222, _path223, _path224, _circle19, _path225, _path226, _path227, _circle20, _path228, _path229, _circle21, _path230, _path231, _circle22, _path232, _path233, _circle23, _path234, _path235, _circle24, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var Cafe20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cafe20(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM24.5 11H8a2.002 2.002 0 00-2 2v8a5.0059 5.0059 0 005 5h8a5.0059 5.0059 0 005-5V20h.5a4.5 4.5 0 000-9zM22 21a3.0033 3.0033 0 01-3 3H11a3.0033 3.0033 0 01-3-3V13H22zm2.5-3H24V13h.5a2.5 2.5 0 010 5zM19 9H17V8.854a1.9883 1.9883 0 00-1.1055-1.7886L13.2109 5.7236A3.9788 3.9788 0 0111 2.146V1h2V2.146a1.9892 1.9892 0 001.1055 1.7886l2.6836 1.3418A3.9792 3.9792 0 0119 8.854z"
  })), children);
});
var Cafe16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cafe16(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM24.5 11H8a2.002 2.002 0 00-2 2v8a5.0059 5.0059 0 005 5h8a5.0059 5.0059 0 005-5V20h.5a4.5 4.5 0 000-9zM22 21a3.0033 3.0033 0 01-3 3H11a3.0033 3.0033 0 01-3-3V13H22zm2.5-3H24V13h.5a2.5 2.5 0 010 5zM19 9H17V8.854a1.9883 1.9883 0 00-1.1055-1.7886L13.2109 5.7236A3.9788 3.9788 0 0111 2.146V1h2V2.146a1.9892 1.9892 0 001.1055 1.7886l2.6836 1.3418A3.9792 3.9792 0 0119 8.854z"
  })), children);
});
var Calculation32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Calculation32(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 8L10 8 10 4 8 4 8 8 4 8 4 10 8 10 8 14 10 14 10 10 14 10 14 8zM4 19H14V21H4zM4 24H14V26H4zM18 8H28V10H18zM24.41 22L28 18.41 26.59 17 23 20.59 19.41 17 18 18.41 21.59 22 18 25.59 19.41 27 23 23.41 26.59 27 28 25.59 24.41 22z"
  })), children);
});
var Calculation24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Calculation24(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 8L10 8 10 4 8 4 8 8 4 8 4 10 8 10 8 14 10 14 10 10 14 10 14 8zM4 19H14V21H4zM4 24H14V26H4zM18 8H28V10H18zM24.41 22L28 18.41 26.59 17 23 20.59 19.41 17 18 18.41 21.59 22 18 25.59 19.41 27 23 23.41 26.59 27 28 25.59 24.41 22z"
  })), children);
});
var Calculation20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Calculation20(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 8L10 8 10 4 8 4 8 8 4 8 4 10 8 10 8 14 10 14 10 10 14 10 14 8zM4 19H14V21H4zM4 24H14V26H4zM18 8H28V10H18zM24.41 22L28 18.41 26.59 17 23 20.59 19.41 17 18 18.41 21.59 22 18 25.59 19.41 27 23 23.41 26.59 27 28 25.59 24.41 22z"
  })), children);
});
var Calculation16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Calculation16(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 8L10 8 10 4 8 4 8 8 4 8 4 10 8 10 8 14 10 14 10 10 14 10 14 8zM4 19H14V21H4zM4 24H14V26H4zM18 8H28V10H18zM24.41 22L28 18.41 26.59 17 23 20.59 19.41 17 18 18.41 21.59 22 18 25.59 19.41 27 23 23.41 26.59 27 28 25.59 24.41 22z"
  })), children);
});
var CalculationAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalculationAlt32(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13H25V15H19zM13 21L11 21 11 19 9 19 9 21 7 21 7 23 9 23 9 25 11 25 11 23 13 23 13 21zM7 9H13V11H7zM19 17H25V19H19z"
  })), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2.0023,2.0023,0,0,0,3,5V27a2.0023,2.0023,0,0,0,2,2H27a2.0023,2.0023,0,0,0,2-2V5A2.0023,2.0023,0,0,0,27,3ZM15,5V15H5V5ZM5,17H15V27H5ZM17,27V5H27V27Z"
  })), children);
});
var CalculationAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalculationAlt24(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13H25V15H19zM13 21L11 21 11 19 9 19 9 21 7 21 7 23 9 23 9 25 11 25 11 23 13 23 13 21zM7 9H13V11H7zM19 17H25V19H19z"
  })), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2.0023,2.0023,0,0,0,3,5V27a2.0023,2.0023,0,0,0,2,2H27a2.0023,2.0023,0,0,0,2-2V5A2.0023,2.0023,0,0,0,27,3ZM15,5V15H5V5ZM5,17H15V27H5ZM17,27V5H27V27Z"
  })), children);
});
var CalculationAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalculationAlt20(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13H25V15H19zM13 21L11 21 11 19 9 19 9 21 7 21 7 23 9 23 9 25 11 25 11 23 13 23 13 21zM7 9H13V11H7zM19 17H25V19H19z"
  })), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2.0023,2.0023,0,0,0,3,5V27a2.0023,2.0023,0,0,0,2,2H27a2.0023,2.0023,0,0,0,2-2V5A2.0023,2.0023,0,0,0,27,3ZM15,5V15H5V5ZM5,17H15V27H5ZM17,27V5H27V27Z"
  })), children);
});
var CalculationAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalculationAlt16(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 13H25V15H19zM13 21L11 21 11 19 9 19 9 21 7 21 7 23 9 23 9 25 11 25 11 23 13 23 13 21zM7 9H13V11H7zM19 17H25V19H19z"
  })), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2.0023,2.0023,0,0,0,3,5V27a2.0023,2.0023,0,0,0,2,2H27a2.0023,2.0023,0,0,0,2-2V5A2.0023,2.0023,0,0,0,27,3ZM15,5V15H5V5ZM5,17H15V27H5ZM17,27V5H27V27Z"
  })), children);
});
var Calculator32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Calculator32(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4V28H6V4H26m0-2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V4A2,2,0,0,0,26,2Z"
  })), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 23H11V25H9zM21 23H23V25H21zM9 18H11V20H9zM21 18H23V20H21zM9 13H11V15H9zM15 23H17V25H15zM15 18H17V20H15zM15 13H17V15H15zM21 13H23V15H21zM9 7H23V10H9z"
  })), children);
});
var Calculator24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Calculator24(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4V28H6V4H26m0-2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V4A2,2,0,0,0,26,2Z"
  })), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 23H11V25H9zM21 23H23V25H21zM9 18H11V20H9zM21 18H23V20H21zM9 13H11V15H9zM15 23H17V25H15zM15 18H17V20H15zM15 13H17V15H15zM21 13H23V15H21zM9 7H23V10H9z"
  })), children);
});
var Calculator20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Calculator20(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4V28H6V4H26m0-2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V4A2,2,0,0,0,26,2Z"
  })), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 23H11V25H9zM21 23H23V25H21zM9 18H11V20H9zM21 18H23V20H21zM9 13H11V15H9zM15 23H17V25H15zM15 18H17V20H15zM15 13H17V15H15zM21 13H23V15H21zM9 7H23V10H9z"
  })), children);
});
var Calculator16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Calculator16(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4V28H6V4H26m0-2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V4A2,2,0,0,0,26,2Z"
  })), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 23H11V25H9zM21 23H23V25H21zM9 18H11V20H9zM21 18H23V20H21zM9 13H11V15H9zM15 23H17V25H15zM15 18H17V20H15zM15 13H17V15H15zM21 13H23V15H21zM9 7H23V10H9z"
  })), children);
});
var CalculatorCheck32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalculatorCheck32(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 26.59L21.41 24 20 25.41 24 29.41 31 22.41 29.59 21 24 26.59zM15 23H17V25H15zM9 23H11V25H9zM21 18H23V20H21zM15 18H17V20H15zM9 18H11V20H9zM21 13H23V15H21zM15 13H17V15H15zM9 13H11V15H9zM9 7H23V10H9z"
  })), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,30H6.0046A2.007,2.007,0,0,1,4,27.9951V3.9961A1.9984,1.9984,0,0,1,5.9961,2H26.0037A1.9985,1.9985,0,0,1,28,3.9961V18H26V4H6V28H17Z"
  })), children);
});
var CalculatorCheck24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalculatorCheck24(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 26.59L21.41 24 20 25.41 24 29.41 31 22.41 29.59 21 24 26.59zM15 23H17V25H15zM9 23H11V25H9zM21 18H23V20H21zM15 18H17V20H15zM9 18H11V20H9zM21 13H23V15H21zM15 13H17V15H15zM9 13H11V15H9zM9 7H23V10H9z"
  })), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,30H6.0046A2.007,2.007,0,0,1,4,27.9951V3.9961A1.9984,1.9984,0,0,1,5.9961,2H26.0037A1.9985,1.9985,0,0,1,28,3.9961V18H26V4H6V28H17Z"
  })), children);
});
var CalculatorCheck20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalculatorCheck20(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 26.59L21.41 24 20 25.41 24 29.41 31 22.41 29.59 21 24 26.59zM15 23H17V25H15zM9 23H11V25H9zM21 18H23V20H21zM15 18H17V20H15zM9 18H11V20H9zM21 13H23V15H21zM15 13H17V15H15zM9 13H11V15H9zM9 7H23V10H9z"
  })), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,30H6.0046A2.007,2.007,0,0,1,4,27.9951V3.9961A1.9984,1.9984,0,0,1,5.9961,2H26.0037A1.9985,1.9985,0,0,1,28,3.9961V18H26V4H6V28H17Z"
  })), children);
});
var CalculatorCheck16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalculatorCheck16(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 26.59L21.41 24 20 25.41 24 29.41 31 22.41 29.59 21 24 26.59zM15 23H17V25H15zM9 23H11V25H9zM21 18H23V20H21zM15 18H17V20H15zM9 18H11V20H9zM21 13H23V15H21zM15 13H17V15H15zM9 13H11V15H9zM9 7H23V10H9z"
  })), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,30H6.0046A2.007,2.007,0,0,1,4,27.9951V3.9961A1.9984,1.9984,0,0,1,5.9961,2H26.0037A1.9985,1.9985,0,0,1,28,3.9961V18H26V4H6V28H17Z"
  })), children);
});
var Calendar32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Calendar32(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4h-4V2h-2v2h-8V2h-2v2H6C4.9,4,4,4.9,4,6v20c0,1.1,0.9,2,2,2h20c1.1,0,2-0.9,2-2V6C28,4.9,27.1,4,26,4z M26,26H6V12h20\tV26z M26,10H6V6h4v2h2V6h8v2h2V6h4V10z"
  })), children);
});
var Calendar24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Calendar24(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4h-4V2h-2v2h-8V2h-2v2H6C4.9,4,4,4.9,4,6v20c0,1.1,0.9,2,2,2h20c1.1,0,2-0.9,2-2V6C28,4.9,27.1,4,26,4z M26,26H6V12h20\tV26z M26,10H6V6h4v2h2V6h8v2h2V6h4V10z"
  })), children);
});
var Calendar20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Calendar20(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4h-4V2h-2v2h-8V2h-2v2H6C4.9,4,4,4.9,4,6v20c0,1.1,0.9,2,2,2h20c1.1,0,2-0.9,2-2V6C28,4.9,27.1,4,26,4z M26,26H6V12h20\tV26z M26,10H6V6h4v2h2V6h8v2h2V6h4V10z"
  })), children);
});
var Calendar16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Calendar16(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4h-4V2h-2v2h-8V2h-2v2H6C4.9,4,4,4.9,4,6v20c0,1.1,0.9,2,2,2h20c1.1,0,2-0.9,2-2V6C28,4.9,27.1,4,26,4z M26,26H6V12h20\tV26z M26,10H6V6h4v2h2V6h8v2h2V6h4V10z"
  })), children);
});
var CalendarHeatMap32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalendarHeatMap32(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H22V2H20V4H12V2H10V4H6A2.0025,2.0025,0,0,0,4,6V26a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V6A2.0025,2.0025,0,0,0,26,4ZM6,6h4V8h2V6h8V8h2V6h4l0,4H6Zm0,6h5v6H6ZM19,26H13V20h6Zm0-8H13V12h6Zm2,8V20h5l.0012,6Z"
  })), children);
});
var CalendarHeatMap24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalendarHeatMap24(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H22V2H20V4H12V2H10V4H6A2.0025,2.0025,0,0,0,4,6V26a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V6A2.0025,2.0025,0,0,0,26,4ZM6,6h4V8h2V6h8V8h2V6h4l0,4H6Zm0,6h5v6H6ZM19,26H13V20h6Zm0-8H13V12h6Zm2,8V20h5l.0012,6Z"
  })), children);
});
var CalendarHeatMap20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalendarHeatMap20(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H22V2H20V4H12V2H10V4H6A2.0025,2.0025,0,0,0,4,6V26a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V6A2.0025,2.0025,0,0,0,26,4ZM6,6h4V8h2V6h8V8h2V6h4l0,4H6Zm0,6h5v6H6ZM19,26H13V20h6Zm0-8H13V12h6Zm2,8V20h5l.0012,6Z"
  })), children);
});
var CalendarHeatMap16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalendarHeatMap16(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H22V2H20V4H12V2H10V4H6A2.0025,2.0025,0,0,0,4,6V26a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V6A2.0025,2.0025,0,0,0,26,4ZM6,6h4V8h2V6h8V8h2V6h4l0,4H6Zm0,6h5v6H6ZM19,26H13V20h6Zm0-8H13V12h6Zm2,8V20h5l.0012,6Z"
  })), children);
});
var CalendarSettings32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalendarSettings32(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,23V21H27.91a5.9592,5.9592,0,0,0-1.0244-2.4707L28.364,17.05,26.95,15.6362l-1.4788,1.4785A5.9584,5.9584,0,0,0,23,16.09V14H21v2.09a5.9584,5.9584,0,0,0-2.4709,1.0244L17.05,15.6362,15.636,17.05l1.4787,1.479A5.9618,5.9618,0,0,0,16.09,21H14v2h2.09a5.9618,5.9618,0,0,0,1.0244,2.4707L15.636,26.95,17.05,28.3638l1.4788-1.4785A5.9584,5.9584,0,0,0,21,27.91V30h2V27.91a5.9584,5.9584,0,0,0,2.4709-1.0244L26.95,28.3638,28.364,26.95l-1.4787-1.479A5.9592,5.9592,0,0,0,27.91,23Zm-8,3a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,22,26Z"
  })), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6a2,2,0,0,0-2-2H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V6h4V8h2V6h8V8h2V6h4v6h2Z"
  })), children);
});
var CalendarSettings24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalendarSettings24(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,23V21H27.91a5.9592,5.9592,0,0,0-1.0244-2.4707L28.364,17.05,26.95,15.6362l-1.4788,1.4785A5.9584,5.9584,0,0,0,23,16.09V14H21v2.09a5.9584,5.9584,0,0,0-2.4709,1.0244L17.05,15.6362,15.636,17.05l1.4787,1.479A5.9618,5.9618,0,0,0,16.09,21H14v2h2.09a5.9618,5.9618,0,0,0,1.0244,2.4707L15.636,26.95,17.05,28.3638l1.4788-1.4785A5.9584,5.9584,0,0,0,21,27.91V30h2V27.91a5.9584,5.9584,0,0,0,2.4709-1.0244L26.95,28.3638,28.364,26.95l-1.4787-1.479A5.9592,5.9592,0,0,0,27.91,23Zm-8,3a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,22,26Z"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6a2,2,0,0,0-2-2H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V6h4V8h2V6h8V8h2V6h4v6h2Z"
  })), children);
});
var CalendarSettings20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalendarSettings20(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,23V21H27.91a5.9592,5.9592,0,0,0-1.0244-2.4707L28.364,17.05,26.95,15.6362l-1.4788,1.4785A5.9584,5.9584,0,0,0,23,16.09V14H21v2.09a5.9584,5.9584,0,0,0-2.4709,1.0244L17.05,15.6362,15.636,17.05l1.4787,1.479A5.9618,5.9618,0,0,0,16.09,21H14v2h2.09a5.9618,5.9618,0,0,0,1.0244,2.4707L15.636,26.95,17.05,28.3638l1.4788-1.4785A5.9584,5.9584,0,0,0,21,27.91V30h2V27.91a5.9584,5.9584,0,0,0,2.4709-1.0244L26.95,28.3638,28.364,26.95l-1.4787-1.479A5.9592,5.9592,0,0,0,27.91,23Zm-8,3a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,22,26Z"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6a2,2,0,0,0-2-2H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V6h4V8h2V6h8V8h2V6h4v6h2Z"
  })), children);
});
var CalendarSettings16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalendarSettings16(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,23V21H27.91a5.9592,5.9592,0,0,0-1.0244-2.4707L28.364,17.05,26.95,15.6362l-1.4788,1.4785A5.9584,5.9584,0,0,0,23,16.09V14H21v2.09a5.9584,5.9584,0,0,0-2.4709,1.0244L17.05,15.6362,15.636,17.05l1.4787,1.479A5.9618,5.9618,0,0,0,16.09,21H14v2h2.09a5.9618,5.9618,0,0,0,1.0244,2.4707L15.636,26.95,17.05,28.3638l1.4788-1.4785A5.9584,5.9584,0,0,0,21,27.91V30h2V27.91a5.9584,5.9584,0,0,0,2.4709-1.0244L26.95,28.3638,28.364,26.95l-1.4787-1.479A5.9592,5.9592,0,0,0,27.91,23Zm-8,3a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,22,26Z"
  })), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6a2,2,0,0,0-2-2H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h4V26H6V6h4V8h2V6h8V8h2V6h4v6h2Z"
  })), children);
});
var CalendarTools32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalendarTools32(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.981,24.4333A3.9549,3.9549,0,0,0,26,25a4.0045,4.0045,0,0,0,4-4,3.9427,3.9427,0,0,0-.1492-1.0228l-2.4367,2.4369-.0005-.0005a1.9991,1.9991,0,1,1-2.8272-2.8272l-.0005-.0005,2.4368-2.4368A3.95,3.95,0,0,0,26,17a4.0045,4.0045,0,0,0-4,4,3.9544,3.9544,0,0,0,.5669,2.0191L17,28.586,18.4141,30Z"
  })), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M26,4H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h8V26H6V6h4V8h2V6h8V8h2V6h4v8h2V6A2,2,0,0,0,26,4Z"
  })), children);
});
var CalendarTools24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalendarTools24(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.981,24.4333A3.9549,3.9549,0,0,0,26,25a4.0045,4.0045,0,0,0,4-4,3.9427,3.9427,0,0,0-.1492-1.0228l-2.4367,2.4369-.0005-.0005a1.9991,1.9991,0,1,1-2.8272-2.8272l-.0005-.0005,2.4368-2.4368A3.95,3.95,0,0,0,26,17a4.0045,4.0045,0,0,0-4,4,3.9544,3.9544,0,0,0,.5669,2.0191L17,28.586,18.4141,30Z"
  })), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M26,4H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h8V26H6V6h4V8h2V6h8V8h2V6h4v8h2V6A2,2,0,0,0,26,4Z"
  })), children);
});
var CalendarTools20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalendarTools20(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.981,24.4333A3.9549,3.9549,0,0,0,26,25a4.0045,4.0045,0,0,0,4-4,3.9427,3.9427,0,0,0-.1492-1.0228l-2.4367,2.4369-.0005-.0005a1.9991,1.9991,0,1,1-2.8272-2.8272l-.0005-.0005,2.4368-2.4368A3.95,3.95,0,0,0,26,17a4.0045,4.0045,0,0,0-4,4,3.9544,3.9544,0,0,0,.5669,2.0191L17,28.586,18.4141,30Z"
  })), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M26,4H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h8V26H6V6h4V8h2V6h8V8h2V6h4v8h2V6A2,2,0,0,0,26,4Z"
  })), children);
});
var CalendarTools16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CalendarTools16(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.981,24.4333A3.9549,3.9549,0,0,0,26,25a4.0045,4.0045,0,0,0,4-4,3.9427,3.9427,0,0,0-.1492-1.0228l-2.4367,2.4369-.0005-.0005a1.9991,1.9991,0,1,1-2.8272-2.8272l-.0005-.0005,2.4368-2.4368A3.95,3.95,0,0,0,26,17a4.0045,4.0045,0,0,0-4,4,3.9544,3.9544,0,0,0,.5669,2.0191L17,28.586,18.4141,30Z"
  })), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fillRule: "evenodd",
    d: "M26,4H22V2H20V4H12V2H10V4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2h8V26H6V6h4V8h2V6h8V8h2V6h4v8h2V6A2,2,0,0,0,26,4Z"
  })), children);
});
var Calibrate32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Calibrate32(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.83,21.17,25,17.37l.67-.67a1,1,0,0,0,0-1.41l-6-6a1,1,0,0,0-1.41,0h0l-.79.79L10.71,3.29a1,1,0,0,0-1.41,0h0l-4,4-.12.15-4,6a1,1,0,0,0,.12,1.26l3,3a1,1,0,0,0,1.42,0L10,13.41l2.09,2.09-4.8,4.79a1,1,0,0,0,0,1.41l2,2A1,1,0,0,0,10,24a1,1,0,0,0,.52-.15l4.33-2.6,2.44,2.45a1,1,0,0,0,1.41,0h0l.67-.7,3.79,3.83a4,4,0,0,0,5.66-5.66ZM10,10.58l-5,5L3.29,13.87,6.78,8.63,10,5.41l6.09,6.09L13.5,14.08Zm8,11-2.84-2.84-5,3L9.42,21,19,11.41,23.59,16Zm9.42,3.83a2,2,0,0,1-2.83,0h0l-3.8-3.79,2.83-2.83,3.8,3.79a2,2,0,0,1,0,2.83Z"
  })), children);
});
var Calibrate24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Calibrate24(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.83,21.17,25,17.37l.67-.67a1,1,0,0,0,0-1.41l-6-6a1,1,0,0,0-1.41,0h0l-.79.79L10.71,3.29a1,1,0,0,0-1.41,0h0l-4,4-.12.15-4,6a1,1,0,0,0,.12,1.26l3,3a1,1,0,0,0,1.42,0L10,13.41l2.09,2.09-4.8,4.79a1,1,0,0,0,0,1.41l2,2A1,1,0,0,0,10,24a1,1,0,0,0,.52-.15l4.33-2.6,2.44,2.45a1,1,0,0,0,1.41,0h0l.67-.7,3.79,3.83a4,4,0,0,0,5.66-5.66ZM10,10.58l-5,5L3.29,13.87,6.78,8.63,10,5.41l6.09,6.09L13.5,14.08Zm8,11-2.84-2.84-5,3L9.42,21,19,11.41,23.59,16Zm9.42,3.83a2,2,0,0,1-2.83,0h0l-3.8-3.79,2.83-2.83,3.8,3.79a2,2,0,0,1,0,2.83Z"
  })), children);
});
var Calibrate20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Calibrate20(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.83,21.17,25,17.37l.67-.67a1,1,0,0,0,0-1.41l-6-6a1,1,0,0,0-1.41,0h0l-.79.79L10.71,3.29a1,1,0,0,0-1.41,0h0l-4,4-.12.15-4,6a1,1,0,0,0,.12,1.26l3,3a1,1,0,0,0,1.42,0L10,13.41l2.09,2.09-4.8,4.79a1,1,0,0,0,0,1.41l2,2A1,1,0,0,0,10,24a1,1,0,0,0,.52-.15l4.33-2.6,2.44,2.45a1,1,0,0,0,1.41,0h0l.67-.7,3.79,3.83a4,4,0,0,0,5.66-5.66ZM10,10.58l-5,5L3.29,13.87,6.78,8.63,10,5.41l6.09,6.09L13.5,14.08Zm8,11-2.84-2.84-5,3L9.42,21,19,11.41,23.59,16Zm9.42,3.83a2,2,0,0,1-2.83,0h0l-3.8-3.79,2.83-2.83,3.8,3.79a2,2,0,0,1,0,2.83Z"
  })), children);
});
var Calibrate16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Calibrate16(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.83,21.17,25,17.37l.67-.67a1,1,0,0,0,0-1.41l-6-6a1,1,0,0,0-1.41,0h0l-.79.79L10.71,3.29a1,1,0,0,0-1.41,0h0l-4,4-.12.15-4,6a1,1,0,0,0,.12,1.26l3,3a1,1,0,0,0,1.42,0L10,13.41l2.09,2.09-4.8,4.79a1,1,0,0,0,0,1.41l2,2A1,1,0,0,0,10,24a1,1,0,0,0,.52-.15l4.33-2.6,2.44,2.45a1,1,0,0,0,1.41,0h0l.67-.7,3.79,3.83a4,4,0,0,0,5.66-5.66ZM10,10.58l-5,5L3.29,13.87,6.78,8.63,10,5.41l6.09,6.09L13.5,14.08Zm8,11-2.84-2.84-5,3L9.42,21,19,11.41,23.59,16Zm9.42,3.83a2,2,0,0,1-2.83,0h0l-3.8-3.79,2.83-2.83,3.8,3.79a2,2,0,0,1,0,2.83Z"
  })), children);
});
var Camera32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Camera32(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,26H3a1,1,0,0,1-1-1V8A1,1,0,0,1,3,7H9.46l1.71-2.55A1,1,0,0,1,12,4h8a1,1,0,0,1,.83.45L22.54,7H29a1,1,0,0,1,1,1V25A1,1,0,0,1,29,26ZM4,24H28V9H22a1,1,0,0,1-.83-.45L19.46,6H12.54L10.83,8.55A1,1,0,0,1,10,9H4Z"
  })), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A6,6,0,0,1,16,22Zm0-10a4,4,0,1,0,4,4A4,4,0,0,0,16,12Z"
  })), children);
});
var Camera24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Camera24(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,26H3a1,1,0,0,1-1-1V8A1,1,0,0,1,3,7H9.46l1.71-2.55A1,1,0,0,1,12,4h8a1,1,0,0,1,.83.45L22.54,7H29a1,1,0,0,1,1,1V25A1,1,0,0,1,29,26ZM4,24H28V9H22a1,1,0,0,1-.83-.45L19.46,6H12.54L10.83,8.55A1,1,0,0,1,10,9H4Z"
  })), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A6,6,0,0,1,16,22Zm0-10a4,4,0,1,0,4,4A4,4,0,0,0,16,12Z"
  })), children);
});
var Camera20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Camera20(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,26H3a1,1,0,0,1-1-1V8A1,1,0,0,1,3,7H9.46l1.71-2.55A1,1,0,0,1,12,4h8a1,1,0,0,1,.83.45L22.54,7H29a1,1,0,0,1,1,1V25A1,1,0,0,1,29,26ZM4,24H28V9H22a1,1,0,0,1-.83-.45L19.46,6H12.54L10.83,8.55A1,1,0,0,1,10,9H4Z"
  })), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A6,6,0,0,1,16,22Zm0-10a4,4,0,1,0,4,4A4,4,0,0,0,16,12Z"
  })), children);
});
var Camera16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Camera16(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,26H3a1,1,0,0,1-1-1V8A1,1,0,0,1,3,7H9.46l1.71-2.55A1,1,0,0,1,12,4h8a1,1,0,0,1,.83.45L22.54,7H29a1,1,0,0,1,1,1V25A1,1,0,0,1,29,26ZM4,24H28V9H22a1,1,0,0,1-.83-.45L19.46,6H12.54L10.83,8.55A1,1,0,0,1,10,9H4Z"
  })), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A6,6,0,0,1,16,22Zm0-10a4,4,0,1,0,4,4A4,4,0,0,0,16,12Z"
  })), children);
});
var CameraAction32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CameraAction32(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,23a6,6,0,1,1,6-6A6,6,0,0,1,12,23Zm0-10a4,4,0,1,0,4,4A4,4,0,0,0,12,13Z"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,27H3a1,1,0,0,1-1-1V6A1,1,0,0,1,3,5H29a1,1,0,0,1,1,1V26A1,1,0,0,1,29,27ZM4,25H28V7H4Z"
  })), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 9H26V11H19z"
  })), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "12",
    cy: "17",
    r: "1"
  })), children);
});
var CameraAction24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CameraAction24(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,23a6,6,0,1,1,6-6A6,6,0,0,1,12,23Zm0-10a4,4,0,1,0,4,4A4,4,0,0,0,12,13Z"
  })), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,27H3a1,1,0,0,1-1-1V6A1,1,0,0,1,3,5H29a1,1,0,0,1,1,1V26A1,1,0,0,1,29,27ZM4,25H28V7H4Z"
  })), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 9H26V11H19z"
  })), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "12",
    cy: "17",
    r: "1"
  })), children);
});
var CameraAction20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CameraAction20(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,23a6,6,0,1,1,6-6A6,6,0,0,1,12,23Zm0-10a4,4,0,1,0,4,4A4,4,0,0,0,12,13Z"
  })), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,27H3a1,1,0,0,1-1-1V6A1,1,0,0,1,3,5H29a1,1,0,0,1,1,1V26A1,1,0,0,1,29,27ZM4,25H28V7H4Z"
  })), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 9H26V11H19z"
  })), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "12",
    cy: "17",
    r: "1"
  })), children);
});
var CameraAction16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CameraAction16(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,23a6,6,0,1,1,6-6A6,6,0,0,1,12,23Zm0-10a4,4,0,1,0,4,4A4,4,0,0,0,12,13Z"
  })), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,27H3a1,1,0,0,1-1-1V6A1,1,0,0,1,3,5H29a1,1,0,0,1,1,1V26A1,1,0,0,1,29,27ZM4,25H28V7H4Z"
  })), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 9H26V11H19z"
  })), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "12",
    cy: "17",
    r: "1"
  })), children);
});
var Campsite32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Campsite32(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.5618,26,17.17,8.9277,19.5361,5.04,17.8281,4,16,7.0049,14.17,4l-1.708,1.04,2.3665,3.8877L4.438,26H2v2H30V26ZM16,10.8506,25.2207,26H17V18H15v8H6.7791Z"
  })), children);
});
var Campsite24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Campsite24(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.5618,26,17.17,8.9277,19.5361,5.04,17.8281,4,16,7.0049,14.17,4l-1.708,1.04,2.3665,3.8877L4.438,26H2v2H30V26ZM16,10.8506,25.2207,26H17V18H15v8H6.7791Z"
  })), children);
});
var Campsite20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Campsite20(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.5618,26,17.17,8.9277,19.5361,5.04,17.8281,4,16,7.0049,14.17,4l-1.708,1.04,2.3665,3.8877L4.438,26H2v2H30V26ZM16,10.8506,25.2207,26H17V18H15v8H6.7791Z"
  })), children);
});
var Campsite16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Campsite16(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.5618,26,17.17,8.9277,19.5361,5.04,17.8281,4,16,7.0049,14.17,4l-1.708,1.04,2.3665,3.8877L4.438,26H2v2H30V26ZM16,10.8506,25.2207,26H17V18H15v8H6.7791Z"
  })), children);
});
var Car32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Car32(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3379,15.9336l-7.7324-2.7783L18.374,9.0967A2.99,2.99,0,0,0,16.0537,8H8.0576a2.9982,2.9982,0,0,0-2.48,1.3115L2.8662,13.2949A4.9884,4.9884,0,0,0,2,16.1074V24a1,1,0,0,0,1,1H5.1421a3.9806,3.9806,0,0,0,7.7158,0h6.2842a3.9806,3.9806,0,0,0,7.7158,0H29a1,1,0,0,0,1-1V16.875A1,1,0,0,0,29.3379,15.9336ZM9,26a2,2,0,1,1,2-2A2.0027,2.0027,0,0,1,9,26Zm14,0a2,2,0,1,1,2-2A2.0025,2.0025,0,0,1,23,26Zm5-3H26.8579a3.9806,3.9806,0,0,0-7.7158,0H12.8579a3.9806,3.9806,0,0,0-7.7158,0H4V16.1074A2.9977,2.9977,0,0,1,4.52,14.4189l2.711-3.9814A.9992.9992,0,0,1,8.0576,10h7.9961a.9928.9928,0,0,1,.7647.3545l3.3994,4.2685a1.0007,1.0007,0,0,0,.4443.3184L28,17.5781Z"
  })), children);
});
var Car24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Car24(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3379,15.9336l-7.7324-2.7783L18.374,9.0967A2.99,2.99,0,0,0,16.0537,8H8.0576a2.9982,2.9982,0,0,0-2.48,1.3115L2.8662,13.2949A4.9884,4.9884,0,0,0,2,16.1074V24a1,1,0,0,0,1,1H5.1421a3.9806,3.9806,0,0,0,7.7158,0h6.2842a3.9806,3.9806,0,0,0,7.7158,0H29a1,1,0,0,0,1-1V16.875A1,1,0,0,0,29.3379,15.9336ZM9,26a2,2,0,1,1,2-2A2.0027,2.0027,0,0,1,9,26Zm14,0a2,2,0,1,1,2-2A2.0025,2.0025,0,0,1,23,26Zm5-3H26.8579a3.9806,3.9806,0,0,0-7.7158,0H12.8579a3.9806,3.9806,0,0,0-7.7158,0H4V16.1074A2.9977,2.9977,0,0,1,4.52,14.4189l2.711-3.9814A.9992.9992,0,0,1,8.0576,10h7.9961a.9928.9928,0,0,1,.7647.3545l3.3994,4.2685a1.0007,1.0007,0,0,0,.4443.3184L28,17.5781Z"
  })), children);
});
var Car20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Car20(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3379,15.9336l-7.7324-2.7783L18.374,9.0967A2.99,2.99,0,0,0,16.0537,8H8.0576a2.9982,2.9982,0,0,0-2.48,1.3115L2.8662,13.2949A4.9884,4.9884,0,0,0,2,16.1074V24a1,1,0,0,0,1,1H5.1421a3.9806,3.9806,0,0,0,7.7158,0h6.2842a3.9806,3.9806,0,0,0,7.7158,0H29a1,1,0,0,0,1-1V16.875A1,1,0,0,0,29.3379,15.9336ZM9,26a2,2,0,1,1,2-2A2.0027,2.0027,0,0,1,9,26Zm14,0a2,2,0,1,1,2-2A2.0025,2.0025,0,0,1,23,26Zm5-3H26.8579a3.9806,3.9806,0,0,0-7.7158,0H12.8579a3.9806,3.9806,0,0,0-7.7158,0H4V16.1074A2.9977,2.9977,0,0,1,4.52,14.4189l2.711-3.9814A.9992.9992,0,0,1,8.0576,10h7.9961a.9928.9928,0,0,1,.7647.3545l3.3994,4.2685a1.0007,1.0007,0,0,0,.4443.3184L28,17.5781Z"
  })), children);
});
var Car16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Car16(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3379,15.9336l-7.7324-2.7783L18.374,9.0967A2.99,2.99,0,0,0,16.0537,8H8.0576a2.9982,2.9982,0,0,0-2.48,1.3115L2.8662,13.2949A4.9884,4.9884,0,0,0,2,16.1074V24a1,1,0,0,0,1,1H5.1421a3.9806,3.9806,0,0,0,7.7158,0h6.2842a3.9806,3.9806,0,0,0,7.7158,0H29a1,1,0,0,0,1-1V16.875A1,1,0,0,0,29.3379,15.9336ZM9,26a2,2,0,1,1,2-2A2.0027,2.0027,0,0,1,9,26Zm14,0a2,2,0,1,1,2-2A2.0025,2.0025,0,0,1,23,26Zm5-3H26.8579a3.9806,3.9806,0,0,0-7.7158,0H12.8579a3.9806,3.9806,0,0,0-7.7158,0H4V16.1074A2.9977,2.9977,0,0,1,4.52,14.4189l2.711-3.9814A.9992.9992,0,0,1,8.0576,10h7.9961a.9928.9928,0,0,1,.7647.3545l3.3994,4.2685a1.0007,1.0007,0,0,0,.4443.3184L28,17.5781Z"
  })), children);
});
var CarFront32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarFront32(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 19H19V21H13z"
  })), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.4409,14,24.1687,9.45A2.009,2.009,0,0,0,22.2456,8H9.7544A2.0089,2.0089,0,0,0,7.8313,9.4507L6.5315,14H4v2H6v7a2.0025,2.0025,0,0,0,2,2v3h2V25H22v3h2V25a2.0025,2.0025,0,0,0,2-2V16h2V14ZM9.7544,10H22.2458l1.4285,5H8.3257ZM24,21v2H8V21h2V19H8V17H24v2H22v2Z"
  })), children);
});
var CarFront24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarFront24(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 19H19V21H13z"
  })), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.4409,14,24.1687,9.45A2.009,2.009,0,0,0,22.2456,8H9.7544A2.0089,2.0089,0,0,0,7.8313,9.4507L6.5315,14H4v2H6v7a2.0025,2.0025,0,0,0,2,2v3h2V25H22v3h2V25a2.0025,2.0025,0,0,0,2-2V16h2V14ZM9.7544,10H22.2458l1.4285,5H8.3257ZM24,21v2H8V21h2V19H8V17H24v2H22v2Z"
  })), children);
});
var CarFront20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarFront20(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 19H19V21H13z"
  })), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.4409,14,24.1687,9.45A2.009,2.009,0,0,0,22.2456,8H9.7544A2.0089,2.0089,0,0,0,7.8313,9.4507L6.5315,14H4v2H6v7a2.0025,2.0025,0,0,0,2,2v3h2V25H22v3h2V25a2.0025,2.0025,0,0,0,2-2V16h2V14ZM9.7544,10H22.2458l1.4285,5H8.3257ZM24,21v2H8V21h2V19H8V17H24v2H22v2Z"
  })), children);
});
var CarFront16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarFront16(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 19H19V21H13z"
  })), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.4409,14,24.1687,9.45A2.009,2.009,0,0,0,22.2456,8H9.7544A2.0089,2.0089,0,0,0,7.8313,9.4507L6.5315,14H4v2H6v7a2.0025,2.0025,0,0,0,2,2v3h2V25H22v3h2V25a2.0025,2.0025,0,0,0,2-2V16h2V14ZM9.7544,10H22.2458l1.4285,5H8.3257ZM24,21v2H8V21h2V19H8V17H24v2H22v2Z"
  })), children);
});
var Carbon32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Carbon32(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.5,30.8149a1.0011,1.0011,0,0,1-.4927-.13l-8.5-4.815A1,1,0,0,1,4,25V15a1,1,0,0,1,.5073-.87l8.5-4.815a1.0013,1.0013,0,0,1,.9854,0l8.5,4.815A1,1,0,0,1,23,15V25a1,1,0,0,1-.5073.87l-8.5,4.815A1.0011,1.0011,0,0,1,13.5,30.8149ZM6,24.417l7.5,4.2485L21,24.417V15.583l-7.5-4.2485L6,15.583Z"
  })), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,17H26V7.583L18.5,3.3345,10.4927,7.87,9.5073,6.13l8.5-4.815a1.0013,1.0013,0,0,1,.9854,0l8.5,4.815A1,1,0,0,1,28,7Z"
  })), children);
});
var Carbon24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Carbon24(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.5,30.8149a1.0011,1.0011,0,0,1-.4927-.13l-8.5-4.815A1,1,0,0,1,4,25V15a1,1,0,0,1,.5073-.87l8.5-4.815a1.0013,1.0013,0,0,1,.9854,0l8.5,4.815A1,1,0,0,1,23,15V25a1,1,0,0,1-.5073.87l-8.5,4.815A1.0011,1.0011,0,0,1,13.5,30.8149ZM6,24.417l7.5,4.2485L21,24.417V15.583l-7.5-4.2485L6,15.583Z"
  })), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,17H26V7.583L18.5,3.3345,10.4927,7.87,9.5073,6.13l8.5-4.815a1.0013,1.0013,0,0,1,.9854,0l8.5,4.815A1,1,0,0,1,28,7Z"
  })), children);
});
var Carbon20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Carbon20(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.5,30.8149a1.0011,1.0011,0,0,1-.4927-.13l-8.5-4.815A1,1,0,0,1,4,25V15a1,1,0,0,1,.5073-.87l8.5-4.815a1.0013,1.0013,0,0,1,.9854,0l8.5,4.815A1,1,0,0,1,23,15V25a1,1,0,0,1-.5073.87l-8.5,4.815A1.0011,1.0011,0,0,1,13.5,30.8149ZM6,24.417l7.5,4.2485L21,24.417V15.583l-7.5-4.2485L6,15.583Z"
  })), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,17H26V7.583L18.5,3.3345,10.4927,7.87,9.5073,6.13l8.5-4.815a1.0013,1.0013,0,0,1,.9854,0l8.5,4.815A1,1,0,0,1,28,7Z"
  })), children);
});
var Carbon16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Carbon16(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.5,30.8149a1.0011,1.0011,0,0,1-.4927-.13l-8.5-4.815A1,1,0,0,1,4,25V15a1,1,0,0,1,.5073-.87l8.5-4.815a1.0013,1.0013,0,0,1,.9854,0l8.5,4.815A1,1,0,0,1,23,15V25a1,1,0,0,1-.5073.87l-8.5,4.815A1.0011,1.0011,0,0,1,13.5,30.8149ZM6,24.417l7.5,4.2485L21,24.417V15.583l-7.5-4.2485L6,15.583Z"
  })), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,17H26V7.583L18.5,3.3345,10.4927,7.87,9.5073,6.13l8.5-4.815a1.0013,1.0013,0,0,1,.9854,0l8.5,4.815A1,1,0,0,1,28,7Z"
  })), children);
});
var CarbonAccounting32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarbonAccounting32(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 26H23V22a2.002 2.002 0 012-2h2V18H23V16h4a2.0023 2.0023 0 012 2v2a2.0023 2.0023 0 01-2 2H25v2h4zM19 22H15a2.0023 2.0023 0 01-2-2V10a2.002 2.002 0 012-2h4a2.002 2.002 0 012 2V20A2.0023 2.0023 0 0119 22zM15 10V20h4V10zM11 22H5a2.0023 2.0023 0 01-2-2V10A2.002 2.002 0 015 8h6v2H5V20h6z"
  })), children);
});
var CarbonAccounting24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarbonAccounting24(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 26H23V22a2.002 2.002 0 012-2h2V18H23V16h4a2.0023 2.0023 0 012 2v2a2.0023 2.0023 0 01-2 2H25v2h4zM19 22H15a2.0023 2.0023 0 01-2-2V10a2.002 2.002 0 012-2h4a2.002 2.002 0 012 2V20A2.0023 2.0023 0 0119 22zM15 10V20h4V10zM11 22H5a2.0023 2.0023 0 01-2-2V10A2.002 2.002 0 015 8h6v2H5V20h6z"
  })), children);
});
var CarbonAccounting20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarbonAccounting20(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 26H23V22a2.002 2.002 0 012-2h2V18H23V16h4a2.0023 2.0023 0 012 2v2a2.0023 2.0023 0 01-2 2H25v2h4zM19 22H15a2.0023 2.0023 0 01-2-2V10a2.002 2.002 0 012-2h4a2.002 2.002 0 012 2V20A2.0023 2.0023 0 0119 22zM15 10V20h4V10zM11 22H5a2.0023 2.0023 0 01-2-2V10A2.002 2.002 0 015 8h6v2H5V20h6z"
  })), children);
});
var CarbonAccounting16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarbonAccounting16(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 26H23V22a2.002 2.002 0 012-2h2V18H23V16h4a2.0023 2.0023 0 012 2v2a2.0023 2.0023 0 01-2 2H25v2h4zM19 22H15a2.0023 2.0023 0 01-2-2V10a2.002 2.002 0 012-2h4a2.002 2.002 0 012 2V20A2.0023 2.0023 0 0119 22zM15 10V20h4V10zM11 22H5a2.0023 2.0023 0 01-2-2V10A2.002 2.002 0 015 8h6v2H5V20h6z"
  })), children);
});
var CarbonForIbmDotcom32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarbonForIbmDotcom32(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.509,17.689l-6-3.55C23.352,14.046,23.176,14,23,14s-0.352,0.046-0.509,0.14l-6,3.55C16.187,17.869,16,18.196,16,18.55\tv6.9c0,0.354,0.187,0.681,0.491,0.86l6,3.55C22.648,29.954,22.824,30,23,30s0.352-0.046,0.509-0.14l6-3.55\tC29.813,26.131,30,25.804,30,25.45v-6.9C30,18.196,29.813,17.869,29.509,17.689z M28,24.88l-5,2.958l-5-2.958v-5.76l5-2.958l5,2.958\tV24.88z"
  })), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "6",
    r: "1"
  })), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "6",
    r: "1"
  })), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4C2.897,2,2,2.897,2,4v20c0,1.103,0.897,2,2,2h9v-2H4V10h24v4h2V4C30,2.897,29.103,2,28,2z M4,8V4h24v4H4z"
  })), children);
});
var CarbonForIbmDotcom24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarbonForIbmDotcom24(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.509,17.689l-6-3.55C23.352,14.046,23.176,14,23,14s-0.352,0.046-0.509,0.14l-6,3.55C16.187,17.869,16,18.196,16,18.55\tv6.9c0,0.354,0.187,0.681,0.491,0.86l6,3.55C22.648,29.954,22.824,30,23,30s0.352-0.046,0.509-0.14l6-3.55\tC29.813,26.131,30,25.804,30,25.45v-6.9C30,18.196,29.813,17.869,29.509,17.689z M28,24.88l-5,2.958l-5-2.958v-5.76l5-2.958l5,2.958\tV24.88z"
  })), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "6",
    r: "1"
  })), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "6",
    r: "1"
  })), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4C2.897,2,2,2.897,2,4v20c0,1.103,0.897,2,2,2h9v-2H4V10h24v4h2V4C30,2.897,29.103,2,28,2z M4,8V4h24v4H4z"
  })), children);
});
var CarbonForIbmDotcom20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarbonForIbmDotcom20(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.509,17.689l-6-3.55C23.352,14.046,23.176,14,23,14s-0.352,0.046-0.509,0.14l-6,3.55C16.187,17.869,16,18.196,16,18.55\tv6.9c0,0.354,0.187,0.681,0.491,0.86l6,3.55C22.648,29.954,22.824,30,23,30s0.352-0.046,0.509-0.14l6-3.55\tC29.813,26.131,30,25.804,30,25.45v-6.9C30,18.196,29.813,17.869,29.509,17.689z M28,24.88l-5,2.958l-5-2.958v-5.76l5-2.958l5,2.958\tV24.88z"
  })), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "6",
    r: "1"
  })), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "6",
    r: "1"
  })), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4C2.897,2,2,2.897,2,4v20c0,1.103,0.897,2,2,2h9v-2H4V10h24v4h2V4C30,2.897,29.103,2,28,2z M4,8V4h24v4H4z"
  })), children);
});
var CarbonForIbmDotcom16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarbonForIbmDotcom16(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.509,17.689l-6-3.55C23.352,14.046,23.176,14,23,14s-0.352,0.046-0.509,0.14l-6,3.55C16.187,17.869,16,18.196,16,18.55\tv6.9c0,0.354,0.187,0.681,0.491,0.86l6,3.55C22.648,29.954,22.824,30,23,30s0.352-0.046,0.509-0.14l6-3.55\tC29.813,26.131,30,25.804,30,25.45v-6.9C30,18.196,29.813,17.869,29.509,17.689z M28,24.88l-5,2.958l-5-2.958v-5.76l5-2.958l5,2.958\tV24.88z"
  })), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "6",
    r: "1"
  })), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "6",
    r: "1"
  })), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4C2.897,2,2,2.897,2,4v20c0,1.103,0.897,2,2,2h9v-2H4V10h24v4h2V4C30,2.897,29.103,2,28,2z M4,8V4h24v4H4z"
  })), children);
});
var CarbonForIbmProduct32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarbonForIbmProduct32(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.509,12.689l-6-3.55C16.352,9.046,16.176,9,16,9s-0.352,0.046-0.509,0.14l-6,3.55C9.187,12.869,9,13.196,9,13.55v6.9\tc0,0.354,0.187,0.681,0.491,0.86l6,3.55C15.648,24.954,15.824,25,16,25s0.352-0.046,0.509-0.14l6-3.55\tC22.813,21.131,23,20.804,23,20.45v-6.9C23,13.196,22.813,12.869,22.509,12.689z M21,19.88l-5,2.958l-5-2.958v-5.76l5-2.958l5,2.958\tV19.88z"
  })), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 20.184V11.07l6.2-3.664-1.017-1.722L4.491 9.639C4.187 9.819 4 10.146 4 10.5v9.684C2.839 20.598 2 21.698 2 23c0 1.654 1.346 3 3 3s3-1.346 3-3C8 21.698 7.161 20.598 6 20.184zM5 24c-.551 0-1-.448-1-1s.449-1 1-1 1 .448 1 1S5.551 24 5 24zM27 20c-1.654 0-3 1.346-3 3 0 .353.072.687.185 1.002L16 28.838l-6.404-3.784-1.017 1.722 6.912 4.084C15.648 30.954 15.824 31 16 31s.352-.046.509-.139l8.96-5.295C25.919 25.835 26.439 26 27 26c1.654 0 3-1.346 3-3S28.654 20 27 20zM27 24c-.551 0-1-.448-1-1s.449-1 1-1 1 .448 1 1S27.551 24 27 24zM16 7c.731 0 1.392-.273 1.913-.708L26 11.071V18h2v-7.5c0-.354-.187-.681-.491-.861l-8.567-5.062C18.978 4.39 19 4.198 19 4c0-1.654-1.346-3-3-3s-3 1.346-3 3S14.346 7 16 7zM16 3c.551 0 1 .448 1 1s-.449 1-1 1-1-.448-1-1S15.449 3 16 3z"
  })), children);
});
var CarbonForIbmProduct24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarbonForIbmProduct24(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.509,12.689l-6-3.55C16.352,9.046,16.176,9,16,9s-0.352,0.046-0.509,0.14l-6,3.55C9.187,12.869,9,13.196,9,13.55v6.9\tc0,0.354,0.187,0.681,0.491,0.86l6,3.55C15.648,24.954,15.824,25,16,25s0.352-0.046,0.509-0.14l6-3.55\tC22.813,21.131,23,20.804,23,20.45v-6.9C23,13.196,22.813,12.869,22.509,12.689z M21,19.88l-5,2.958l-5-2.958v-5.76l5-2.958l5,2.958\tV19.88z"
  })), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 20.184V11.07l6.2-3.664-1.017-1.722L4.491 9.639C4.187 9.819 4 10.146 4 10.5v9.684C2.839 20.598 2 21.698 2 23c0 1.654 1.346 3 3 3s3-1.346 3-3C8 21.698 7.161 20.598 6 20.184zM5 24c-.551 0-1-.448-1-1s.449-1 1-1 1 .448 1 1S5.551 24 5 24zM27 20c-1.654 0-3 1.346-3 3 0 .353.072.687.185 1.002L16 28.838l-6.404-3.784-1.017 1.722 6.912 4.084C15.648 30.954 15.824 31 16 31s.352-.046.509-.139l8.96-5.295C25.919 25.835 26.439 26 27 26c1.654 0 3-1.346 3-3S28.654 20 27 20zM27 24c-.551 0-1-.448-1-1s.449-1 1-1 1 .448 1 1S27.551 24 27 24zM16 7c.731 0 1.392-.273 1.913-.708L26 11.071V18h2v-7.5c0-.354-.187-.681-.491-.861l-8.567-5.062C18.978 4.39 19 4.198 19 4c0-1.654-1.346-3-3-3s-3 1.346-3 3S14.346 7 16 7zM16 3c.551 0 1 .448 1 1s-.449 1-1 1-1-.448-1-1S15.449 3 16 3z"
  })), children);
});
var CarbonForIbmProduct20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarbonForIbmProduct20(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.509,12.689l-6-3.55C16.352,9.046,16.176,9,16,9s-0.352,0.046-0.509,0.14l-6,3.55C9.187,12.869,9,13.196,9,13.55v6.9\tc0,0.354,0.187,0.681,0.491,0.86l6,3.55C15.648,24.954,15.824,25,16,25s0.352-0.046,0.509-0.14l6-3.55\tC22.813,21.131,23,20.804,23,20.45v-6.9C23,13.196,22.813,12.869,22.509,12.689z M21,19.88l-5,2.958l-5-2.958v-5.76l5-2.958l5,2.958\tV19.88z"
  })), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 20.184V11.07l6.2-3.664-1.017-1.722L4.491 9.639C4.187 9.819 4 10.146 4 10.5v9.684C2.839 20.598 2 21.698 2 23c0 1.654 1.346 3 3 3s3-1.346 3-3C8 21.698 7.161 20.598 6 20.184zM5 24c-.551 0-1-.448-1-1s.449-1 1-1 1 .448 1 1S5.551 24 5 24zM27 20c-1.654 0-3 1.346-3 3 0 .353.072.687.185 1.002L16 28.838l-6.404-3.784-1.017 1.722 6.912 4.084C15.648 30.954 15.824 31 16 31s.352-.046.509-.139l8.96-5.295C25.919 25.835 26.439 26 27 26c1.654 0 3-1.346 3-3S28.654 20 27 20zM27 24c-.551 0-1-.448-1-1s.449-1 1-1 1 .448 1 1S27.551 24 27 24zM16 7c.731 0 1.392-.273 1.913-.708L26 11.071V18h2v-7.5c0-.354-.187-.681-.491-.861l-8.567-5.062C18.978 4.39 19 4.198 19 4c0-1.654-1.346-3-3-3s-3 1.346-3 3S14.346 7 16 7zM16 3c.551 0 1 .448 1 1s-.449 1-1 1-1-.448-1-1S15.449 3 16 3z"
  })), children);
});
var CarbonForIbmProduct16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarbonForIbmProduct16(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.509,12.689l-6-3.55C16.352,9.046,16.176,9,16,9s-0.352,0.046-0.509,0.14l-6,3.55C9.187,12.869,9,13.196,9,13.55v6.9\tc0,0.354,0.187,0.681,0.491,0.86l6,3.55C15.648,24.954,15.824,25,16,25s0.352-0.046,0.509-0.14l6-3.55\tC22.813,21.131,23,20.804,23,20.45v-6.9C23,13.196,22.813,12.869,22.509,12.689z M21,19.88l-5,2.958l-5-2.958v-5.76l5-2.958l5,2.958\tV19.88z"
  })), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 20.184V11.07l6.2-3.664-1.017-1.722L4.491 9.639C4.187 9.819 4 10.146 4 10.5v9.684C2.839 20.598 2 21.698 2 23c0 1.654 1.346 3 3 3s3-1.346 3-3C8 21.698 7.161 20.598 6 20.184zM5 24c-.551 0-1-.448-1-1s.449-1 1-1 1 .448 1 1S5.551 24 5 24zM27 20c-1.654 0-3 1.346-3 3 0 .353.072.687.185 1.002L16 28.838l-6.404-3.784-1.017 1.722 6.912 4.084C15.648 30.954 15.824 31 16 31s.352-.046.509-.139l8.96-5.295C25.919 25.835 26.439 26 27 26c1.654 0 3-1.346 3-3S28.654 20 27 20zM27 24c-.551 0-1-.448-1-1s.449-1 1-1 1 .448 1 1S27.551 24 27 24zM16 7c.731 0 1.392-.273 1.913-.708L26 11.071V18h2v-7.5c0-.354-.187-.681-.491-.861l-8.567-5.062C18.978 4.39 19 4.198 19 4c0-1.654-1.346-3-3-3s-3 1.346-3 3S14.346 7 16 7zM16 3c.551 0 1 .448 1 1s-.449 1-1 1-1-.448-1-1S15.449 3 16 3z"
  })), children);
});
var CaretDown32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretDown32(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 12L16 22 8 12z"
  })), children);
});
var CaretDown24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretDown24(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 12L16 22 8 12z"
  })), children);
});
var CaretDown20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretDown20(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 12L16 22 8 12z"
  })), children);
});
var CaretDown16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretDown16(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 12L16 22 8 12z"
  })), children);
});
var CaretDownGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretDownGlyph(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 8,
    height: 4,
    viewBox: "0 0 8 4",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 0L4 4 0 0z"
  })), children);
});
var CaretLeft32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretLeft32(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 24L10 16 20 8z"
  })), children);
});
var CaretLeft24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretLeft24(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 24L10 16 20 8z"
  })), children);
});
var CaretLeft20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretLeft20(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 24L10 16 20 8z"
  })), children);
});
var CaretLeft16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretLeft16(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 24L10 16 20 8z"
  })), children);
});
var CaretLeftGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretLeftGlyph(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 5,
    height: 8,
    viewBox: "0 0 5 8",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 8L0 4 5 0z"
  })), children);
});
var CaretRight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretRight32(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 8L22 16 12 24z"
  })), children);
});
var CaretRight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretRight24(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 8L22 16 12 24z"
  })), children);
});
var CaretRight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretRight20(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 8L22 16 12 24z"
  })), children);
});
var CaretRight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretRight16(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 8L22 16 12 24z"
  })), children);
});
var CaretRightGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretRightGlyph(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 5,
    height: 8,
    viewBox: "0 0 5 8",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M0 0L5 4 0 8z"
  })), children);
});
var CaretSort32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretSort32(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 24L16 32 8 24zM8 8L16 0 24 8z"
  })), children);
});
var CaretSort24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretSort24(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 24L16 32 8 24zM8 8L16 0 24 8z"
  })), children);
});
var CaretSort20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretSort20(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 24L16 32 8 24zM8 8L16 0 24 8z"
  })), children);
});
var CaretSort16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretSort16(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 24L16 32 8 24zM8 8L16 0 24 8z"
  })), children);
});
var CaretSortDown32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretSortDown32(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 24L16 32 8 24z"
  })), children);
});
var CaretSortDown24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretSortDown24(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 24L16 32 8 24z"
  })), children);
});
var CaretSortDown20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretSortDown20(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 24L16 32 8 24z"
  })), children);
});
var CaretSortDown16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretSortDown16(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 24L16 32 8 24z"
  })), children);
});
var CaretSortUp32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretSortUp32(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8L16 0 24 8z"
  })), children);
});
var CaretSortUp24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretSortUp24(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8L16 0 24 8z"
  })), children);
});
var CaretSortUp20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretSortUp20(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8L16 0 24 8z"
  })), children);
});
var CaretSortUp16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretSortUp16(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8L16 0 24 8z"
  })), children);
});
var CaretUp32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretUp32(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 20L16 10 24 20z"
  })), children);
});
var CaretUp24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretUp24(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 20L16 10 24 20z"
  })), children);
});
var CaretUp20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretUp20(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 20L16 10 24 20z"
  })), children);
});
var CaretUp16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretUp16(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 20L16 10 24 20z"
  })), children);
});
var CaretUpGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CaretUpGlyph(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 8,
    height: 4,
    viewBox: "0 0 8 4",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M0 4L4 0 8 4z"
  })), children);
});
var CarouselHorizontal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarouselHorizontal32(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26H10a2 2 0 01-2-2V8a2 2 0 012-2H22a2 2 0 012 2V24A2 2 0 0122 26zM10 8V24H22V8zM4 24H0V22H4V10H0V8H4a2 2 0 012 2V22A2 2 0 014 24zM32 24H28a2 2 0 01-2-2V10a2 2 0 012-2h4v2H28V22h4z"
  })), children);
});
var CarouselHorizontal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarouselHorizontal24(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26H10a2 2 0 01-2-2V8a2 2 0 012-2H22a2 2 0 012 2V24A2 2 0 0122 26zM10 8V24H22V8zM4 24H0V22H4V10H0V8H4a2 2 0 012 2V22A2 2 0 014 24zM32 24H28a2 2 0 01-2-2V10a2 2 0 012-2h4v2H28V22h4z"
  })), children);
});
var CarouselHorizontal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarouselHorizontal20(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26H10a2 2 0 01-2-2V8a2 2 0 012-2H22a2 2 0 012 2V24A2 2 0 0122 26zM10 8V24H22V8zM4 24H0V22H4V10H0V8H4a2 2 0 012 2V22A2 2 0 014 24zM32 24H28a2 2 0 01-2-2V10a2 2 0 012-2h4v2H28V22h4z"
  })), children);
});
var CarouselHorizontal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarouselHorizontal16(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26H10a2 2 0 01-2-2V8a2 2 0 012-2H22a2 2 0 012 2V24A2 2 0 0122 26zM10 8V24H22V8zM4 24H0V22H4V10H0V8H4a2 2 0 012 2V22A2 2 0 014 24zM32 24H28a2 2 0 01-2-2V10a2 2 0 012-2h4v2H28V22h4z"
  })), children);
});
var CarouselVertical32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarouselVertical32(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 10V22a2 2 0 01-2 2H8a2 2 0 01-2-2V10A2 2 0 018 8H24A2 2 0 0126 10zM8 22H24V10H8zM24 28v4H22V28H10v4H8V28a2 2 0 012-2H22A2 2 0 0124 28zM24 0V4a2 2 0 01-2 2H10A2 2 0 018 4V0h2V4H22V0z"
  })), children);
});
var CarouselVertical24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarouselVertical24(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 10V22a2 2 0 01-2 2H8a2 2 0 01-2-2V10A2 2 0 018 8H24A2 2 0 0126 10zM8 22H24V10H8zM24 28v4H22V28H10v4H8V28a2 2 0 012-2H22A2 2 0 0124 28zM24 0V4a2 2 0 01-2 2H10A2 2 0 018 4V0h2V4H22V0z"
  })), children);
});
var CarouselVertical20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarouselVertical20(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 10V22a2 2 0 01-2 2H8a2 2 0 01-2-2V10A2 2 0 018 8H24A2 2 0 0126 10zM8 22H24V10H8zM24 28v4H22V28H10v4H8V28a2 2 0 012-2H22A2 2 0 0124 28zM24 0V4a2 2 0 01-2 2H10A2 2 0 018 4V0h2V4H22V0z"
  })), children);
});
var CarouselVertical16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CarouselVertical16(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 10V22a2 2 0 01-2 2H8a2 2 0 01-2-2V10A2 2 0 018 8H24A2 2 0 0126 10zM8 22H24V10H8zM24 28v4H22V28H10v4H8V28a2 2 0 012-2H22A2 2 0 0124 28zM24 0V4a2 2 0 01-2 2H10A2 2 0 018 4V0h2V4H22V0z"
  })), children);
});
var Catalog32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Catalog32(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2H8A2,2,0,0,0,6,4V8H4v2H6v5H4v2H6v5H4v2H6v4a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V4A2,2,0,0,0,26,2Zm0,26H8V24h2V22H8V17h2V15H8V10h2V8H8V4H26Z"
  })), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 8H22V10H14zM14 15H22V17H14zM14 22H22V24H14z"
  })), children);
});
var Catalog24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Catalog24(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2H8A2,2,0,0,0,6,4V8H4v2H6v5H4v2H6v5H4v2H6v4a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V4A2,2,0,0,0,26,2Zm0,26H8V24h2V22H8V17h2V15H8V10h2V8H8V4H26Z"
  })), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 8H22V10H14zM14 15H22V17H14zM14 22H22V24H14z"
  })), children);
});
var Catalog20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Catalog20(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2H8A2,2,0,0,0,6,4V8H4v2H6v5H4v2H6v5H4v2H6v4a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V4A2,2,0,0,0,26,2Zm0,26H8V24h2V22H8V17h2V15H8V10h2V8H8V4H26Z"
  })), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 8H22V10H14zM14 15H22V17H14zM14 22H22V24H14z"
  })), children);
});
var Catalog16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Catalog16(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,2H8A2,2,0,0,0,6,4V8H4v2H6v5H4v2H6v5H4v2H6v4a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V4A2,2,0,0,0,26,2Zm0,26H8V24h2V22H8V17h2V15H8V10h2V8H8V4H26Z"
  })), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 8H22V10H14zM14 15H22V17H14zM14 22H22V24H14z"
  })), children);
});
var Categories32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Categories32(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.76 6l.45.89L7.76 8H12v5H4V6H6.76m.62-2H3A1 1 0 002 5v9a1 1 0 001 1H13a1 1 0 001-1V7a1 1 0 00-1-1H9L8.28 4.55A1 1 0 007.38 4zM22.76 6l.45.89L23.76 8H28v5H20V6h2.76m.62-2H19a1 1 0 00-1 1v9a1 1 0 001 1H29a1 1 0 001-1V7a1 1 0 00-1-1H25l-.72-1.45a1 1 0 00-.9-.55zM6.76 19l.45.89L7.76 21H12v5H4V19H6.76m.62-2H3a1 1 0 00-1 1v9a1 1 0 001 1H13a1 1 0 001-1V20a1 1 0 00-1-1H9l-.72-1.45a1 1 0 00-.9-.55zM22.76 19l.45.89L23.76 21H28v5H20V19h2.76m.62-2H19a1 1 0 00-1 1v9a1 1 0 001 1H29a1 1 0 001-1V20a1 1 0 00-1-1H25l-.72-1.45a1 1 0 00-.9-.55z"
  })), children);
});
var Categories24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Categories24(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.76 6l.45.89L7.76 8H12v5H4V6H6.76m.62-2H3A1 1 0 002 5v9a1 1 0 001 1H13a1 1 0 001-1V7a1 1 0 00-1-1H9L8.28 4.55A1 1 0 007.38 4zM22.76 6l.45.89L23.76 8H28v5H20V6h2.76m.62-2H19a1 1 0 00-1 1v9a1 1 0 001 1H29a1 1 0 001-1V7a1 1 0 00-1-1H25l-.72-1.45a1 1 0 00-.9-.55zM6.76 19l.45.89L7.76 21H12v5H4V19H6.76m.62-2H3a1 1 0 00-1 1v9a1 1 0 001 1H13a1 1 0 001-1V20a1 1 0 00-1-1H9l-.72-1.45a1 1 0 00-.9-.55zM22.76 19l.45.89L23.76 21H28v5H20V19h2.76m.62-2H19a1 1 0 00-1 1v9a1 1 0 001 1H29a1 1 0 001-1V20a1 1 0 00-1-1H25l-.72-1.45a1 1 0 00-.9-.55z"
  })), children);
});
var Categories20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Categories20(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.76 6l.45.89L7.76 8H12v5H4V6H6.76m.62-2H3A1 1 0 002 5v9a1 1 0 001 1H13a1 1 0 001-1V7a1 1 0 00-1-1H9L8.28 4.55A1 1 0 007.38 4zM22.76 6l.45.89L23.76 8H28v5H20V6h2.76m.62-2H19a1 1 0 00-1 1v9a1 1 0 001 1H29a1 1 0 001-1V7a1 1 0 00-1-1H25l-.72-1.45a1 1 0 00-.9-.55zM6.76 19l.45.89L7.76 21H12v5H4V19H6.76m.62-2H3a1 1 0 00-1 1v9a1 1 0 001 1H13a1 1 0 001-1V20a1 1 0 00-1-1H9l-.72-1.45a1 1 0 00-.9-.55zM22.76 19l.45.89L23.76 21H28v5H20V19h2.76m.62-2H19a1 1 0 00-1 1v9a1 1 0 001 1H29a1 1 0 001-1V20a1 1 0 00-1-1H25l-.72-1.45a1 1 0 00-.9-.55z"
  })), children);
});
var Categories16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Categories16(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.76 6l.45.89L7.76 8H12v5H4V6H6.76m.62-2H3A1 1 0 002 5v9a1 1 0 001 1H13a1 1 0 001-1V7a1 1 0 00-1-1H9L8.28 4.55A1 1 0 007.38 4zM22.76 6l.45.89L23.76 8H28v5H20V6h2.76m.62-2H19a1 1 0 00-1 1v9a1 1 0 001 1H29a1 1 0 001-1V7a1 1 0 00-1-1H25l-.72-1.45a1 1 0 00-.9-.55zM6.76 19l.45.89L7.76 21H12v5H4V19H6.76m.62-2H3a1 1 0 00-1 1v9a1 1 0 001 1H13a1 1 0 001-1V20a1 1 0 00-1-1H9l-.72-1.45a1 1 0 00-.9-.55zM22.76 19l.45.89L23.76 21H28v5H20V19h2.76m.62-2H19a1 1 0 00-1 1v9a1 1 0 001 1H29a1 1 0 001-1V20a1 1 0 00-1-1H25l-.72-1.45a1 1 0 00-.9-.55z"
  })), children);
});
var Category32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Category32(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.1414V18a2,2,0,0,0-2-2H17V12h2a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H13a2.002,2.002,0,0,0-2,2v6a2.002,2.002,0,0,0,2,2h2v4H7a2,2,0,0,0-2,2v4.1421a4,4,0,1,0,2,0V18h8v4.142a4,4,0,1,0,2,0V18h8v4.1414a4,4,0,1,0,2,0ZM13,4h6l.001,6H13ZM8,26a2,2,0,1,1-2-2A2.0023,2.0023,0,0,1,8,26Zm10,0a2,2,0,1,1-2-2A2.0027,2.0027,0,0,1,18,26Zm8,2a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,26,28Z"
  })), children);
});
var Category24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Category24(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.1414V18a2,2,0,0,0-2-2H17V12h2a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H13a2.002,2.002,0,0,0-2,2v6a2.002,2.002,0,0,0,2,2h2v4H7a2,2,0,0,0-2,2v4.1421a4,4,0,1,0,2,0V18h8v4.142a4,4,0,1,0,2,0V18h8v4.1414a4,4,0,1,0,2,0ZM13,4h6l.001,6H13ZM8,26a2,2,0,1,1-2-2A2.0023,2.0023,0,0,1,8,26Zm10,0a2,2,0,1,1-2-2A2.0027,2.0027,0,0,1,18,26Zm8,2a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,26,28Z"
  })), children);
});
var Category20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Category20(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.1414V18a2,2,0,0,0-2-2H17V12h2a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H13a2.002,2.002,0,0,0-2,2v6a2.002,2.002,0,0,0,2,2h2v4H7a2,2,0,0,0-2,2v4.1421a4,4,0,1,0,2,0V18h8v4.142a4,4,0,1,0,2,0V18h8v4.1414a4,4,0,1,0,2,0ZM13,4h6l.001,6H13ZM8,26a2,2,0,1,1-2-2A2.0023,2.0023,0,0,1,8,26Zm10,0a2,2,0,1,1-2-2A2.0027,2.0027,0,0,1,18,26Zm8,2a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,26,28Z"
  })), children);
});
var Category16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Category16(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.1414V18a2,2,0,0,0-2-2H17V12h2a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H13a2.002,2.002,0,0,0-2,2v6a2.002,2.002,0,0,0,2,2h2v4H7a2,2,0,0,0-2,2v4.1421a4,4,0,1,0,2,0V18h8v4.142a4,4,0,1,0,2,0V18h8v4.1414a4,4,0,1,0,2,0ZM13,4h6l.001,6H13ZM8,26a2,2,0,1,1-2-2A2.0023,2.0023,0,0,1,8,26Zm10,0a2,2,0,1,1-2-2A2.0027,2.0027,0,0,1,18,26Zm8,2a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,26,28Z"
  })), children);
});
var CategoryAdd32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CategoryAdd32(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 6L13.59 7.41 17.17 11 13.59 14.59 15 16 20 11 15 6z"
  })), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24H17V20h6a2.0027,2.0027,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H9A2.002,2.002,0,0,0,7,4V18a2.0023,2.0023,0,0,0,2,2h6v4H4a2,2,0,0,0-2,2v4H4V26H15v4h2V26H28v4h2V26A2,2,0,0,0,28,24ZM9,4H23l.002,14H9Z"
  })), children);
});
var CategoryAdd24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CategoryAdd24(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 6L13.59 7.41 17.17 11 13.59 14.59 15 16 20 11 15 6z"
  })), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24H17V20h6a2.0027,2.0027,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H9A2.002,2.002,0,0,0,7,4V18a2.0023,2.0023,0,0,0,2,2h6v4H4a2,2,0,0,0-2,2v4H4V26H15v4h2V26H28v4h2V26A2,2,0,0,0,28,24ZM9,4H23l.002,14H9Z"
  })), children);
});
var CategoryAdd20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CategoryAdd20(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 6L13.59 7.41 17.17 11 13.59 14.59 15 16 20 11 15 6z"
  })), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24H17V20h6a2.0027,2.0027,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H9A2.002,2.002,0,0,0,7,4V18a2.0023,2.0023,0,0,0,2,2h6v4H4a2,2,0,0,0-2,2v4H4V26H15v4h2V26H28v4h2V26A2,2,0,0,0,28,24ZM9,4H23l.002,14H9Z"
  })), children);
});
var CategoryAdd16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CategoryAdd16(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 6L13.59 7.41 17.17 11 13.59 14.59 15 16 20 11 15 6z"
  })), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24H17V20h6a2.0027,2.0027,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H9A2.002,2.002,0,0,0,7,4V18a2.0023,2.0023,0,0,0,2,2h6v4H4a2,2,0,0,0-2,2v4H4V26H15v4h2V26H28v4h2V26A2,2,0,0,0,28,24ZM9,4H23l.002,14H9Z"
  })), children);
});
var CategoryAnd32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CategoryAnd32(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 30V26H15v4h2V26H28v4h2V26a2 2 0 00-2-2H17V19H15v5H4a2 2 0 00-2 2v4zM20.6953 13.9858A10.08 10.08 0 0021.9463 10H23V8H20V9a9.2634 9.2634 0 01-.6641 3.2705L16.6511 8.8816a5.1261 5.1261 0 002.1436-2.3694A3.2522 3.2522 0 0018.6062 3.81a3.38 3.38 0 00-2.2391-1.7056 3.4688 3.4688 0 00-4.2223 2.1186c-.5044 1.5518.4406 3.1158 1.2612 4.1077A4.7255 4.7255 0 0011.06 13.1587 4.4526 4.4526 0 0015.4268 17h.0058a5.7844 5.7844 0 003.9717-1.4233L20.532 17h2.5519zM14.047 4.8413A1.3224 1.3224 0 0115.4141 4a2.41 2.41 0 01.5214.0581 1.4018 1.4018 0 01.9111.7022 1.2493 1.2493 0 01.0791 1.042A3.6871 3.6871 0 0115.2441 7.395C14.5831 6.6816 13.8087 5.5732 14.047 4.8413zM15.4316 15h-.0039a2.4432 2.4432 0 01-2.3916-2.1509 2.8261 2.8261 0 011.81-3.0249l3.3115 4.1787A3.8853 3.8853 0 0115.4316 15z"
  })), children);
});
var CategoryAnd24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CategoryAnd24(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 30V26H15v4h2V26H28v4h2V26a2 2 0 00-2-2H17V19H15v5H4a2 2 0 00-2 2v4zM20.6953 13.9858A10.08 10.08 0 0021.9463 10H23V8H20V9a9.2634 9.2634 0 01-.6641 3.2705L16.6511 8.8816a5.1261 5.1261 0 002.1436-2.3694A3.2522 3.2522 0 0018.6062 3.81a3.38 3.38 0 00-2.2391-1.7056 3.4688 3.4688 0 00-4.2223 2.1186c-.5044 1.5518.4406 3.1158 1.2612 4.1077A4.7255 4.7255 0 0011.06 13.1587 4.4526 4.4526 0 0015.4268 17h.0058a5.7844 5.7844 0 003.9717-1.4233L20.532 17h2.5519zM14.047 4.8413A1.3224 1.3224 0 0115.4141 4a2.41 2.41 0 01.5214.0581 1.4018 1.4018 0 01.9111.7022 1.2493 1.2493 0 01.0791 1.042A3.6871 3.6871 0 0115.2441 7.395C14.5831 6.6816 13.8087 5.5732 14.047 4.8413zM15.4316 15h-.0039a2.4432 2.4432 0 01-2.3916-2.1509 2.8261 2.8261 0 011.81-3.0249l3.3115 4.1787A3.8853 3.8853 0 0115.4316 15z"
  })), children);
});
var CategoryAnd20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CategoryAnd20(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 30V26H15v4h2V26H28v4h2V26a2 2 0 00-2-2H17V19H15v5H4a2 2 0 00-2 2v4zM20.6953 13.9858A10.08 10.08 0 0021.9463 10H23V8H20V9a9.2634 9.2634 0 01-.6641 3.2705L16.6511 8.8816a5.1261 5.1261 0 002.1436-2.3694A3.2522 3.2522 0 0018.6062 3.81a3.38 3.38 0 00-2.2391-1.7056 3.4688 3.4688 0 00-4.2223 2.1186c-.5044 1.5518.4406 3.1158 1.2612 4.1077A4.7255 4.7255 0 0011.06 13.1587 4.4526 4.4526 0 0015.4268 17h.0058a5.7844 5.7844 0 003.9717-1.4233L20.532 17h2.5519zM14.047 4.8413A1.3224 1.3224 0 0115.4141 4a2.41 2.41 0 01.5214.0581 1.4018 1.4018 0 01.9111.7022 1.2493 1.2493 0 01.0791 1.042A3.6871 3.6871 0 0115.2441 7.395C14.5831 6.6816 13.8087 5.5732 14.047 4.8413zM15.4316 15h-.0039a2.4432 2.4432 0 01-2.3916-2.1509 2.8261 2.8261 0 011.81-3.0249l3.3115 4.1787A3.8853 3.8853 0 0115.4316 15z"
  })), children);
});
var CategoryAnd16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CategoryAnd16(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 30V26H15v4h2V26H28v4h2V26a2 2 0 00-2-2H17V19H15v5H4a2 2 0 00-2 2v4zM20.6953 13.9858A10.08 10.08 0 0021.9463 10H23V8H20V9a9.2634 9.2634 0 01-.6641 3.2705L16.6511 8.8816a5.1261 5.1261 0 002.1436-2.3694A3.2522 3.2522 0 0018.6062 3.81a3.38 3.38 0 00-2.2391-1.7056 3.4688 3.4688 0 00-4.2223 2.1186c-.5044 1.5518.4406 3.1158 1.2612 4.1077A4.7255 4.7255 0 0011.06 13.1587 4.4526 4.4526 0 0015.4268 17h.0058a5.7844 5.7844 0 003.9717-1.4233L20.532 17h2.5519zM14.047 4.8413A1.3224 1.3224 0 0115.4141 4a2.41 2.41 0 01.5214.0581 1.4018 1.4018 0 01.9111.7022 1.2493 1.2493 0 01.0791 1.042A3.6871 3.6871 0 0115.2441 7.395C14.5831 6.6816 13.8087 5.5732 14.047 4.8413zM15.4316 15h-.0039a2.4432 2.4432 0 01-2.3916-2.1509 2.8261 2.8261 0 011.81-3.0249l3.3115 4.1787A3.8853 3.8853 0 0115.4316 15z"
  })), children);
});
var CategoryNew32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CategoryNew32(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 10L17 10 17 6 15 6 15 10 11 10 11 12 15 12 15 16 17 16 17 12 21 12 21 10z"
  })), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24H17V20h6a2.0027,2.0027,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H9A2.002,2.002,0,0,0,7,4V18a2.0023,2.0023,0,0,0,2,2h6v4H4a2,2,0,0,0-2,2v4H4V26H15v4h2V26H28v4h2V26A2,2,0,0,0,28,24ZM9,4H23l.002,14H9Z"
  })), children);
});
var CategoryNew24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CategoryNew24(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 10L17 10 17 6 15 6 15 10 11 10 11 12 15 12 15 16 17 16 17 12 21 12 21 10z"
  })), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24H17V20h6a2.0027,2.0027,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H9A2.002,2.002,0,0,0,7,4V18a2.0023,2.0023,0,0,0,2,2h6v4H4a2,2,0,0,0-2,2v4H4V26H15v4h2V26H28v4h2V26A2,2,0,0,0,28,24ZM9,4H23l.002,14H9Z"
  })), children);
});
var CategoryNew20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CategoryNew20(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 10L17 10 17 6 15 6 15 10 11 10 11 12 15 12 15 16 17 16 17 12 21 12 21 10z"
  })), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24H17V20h6a2.0027,2.0027,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H9A2.002,2.002,0,0,0,7,4V18a2.0023,2.0023,0,0,0,2,2h6v4H4a2,2,0,0,0-2,2v4H4V26H15v4h2V26H28v4h2V26A2,2,0,0,0,28,24ZM9,4H23l.002,14H9Z"
  })), children);
});
var CategoryNew16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CategoryNew16(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 10L17 10 17 6 15 6 15 10 11 10 11 12 15 12 15 16 17 16 17 12 21 12 21 10z"
  })), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,24H17V20h6a2.0027,2.0027,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H9A2.002,2.002,0,0,0,7,4V18a2.0023,2.0023,0,0,0,2,2h6v4H4a2,2,0,0,0-2,2v4H4V26H15v4h2V26H28v4h2V26A2,2,0,0,0,28,24ZM9,4H23l.002,14H9Z"
  })), children);
});
var CategoryNewEach32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CategoryNewEach32(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 10H24v2h5v6H22v2h3v2.142a4 4 0 102 0V20h2a2.0027 2.0027 0 002-2V12A2.0023 2.0023 0 0029 10zM28 26a2 2 0 11-2-2A2.0027 2.0027 0 0128 26zM19 6H14V8h5v6H12v2h3v6.142a4 4 0 102 0V16h2a2.0023 2.0023 0 002-2V8A2.0023 2.0023 0 0019 6zM18 26a2 2 0 11-2-2A2.0027 2.0027 0 0118 26zM9 2H3A2.002 2.002 0 001 4v6a2.002 2.002 0 002 2H5V22.142a4 4 0 102 0V12H9a2.002 2.002 0 002-2V4A2.002 2.002 0 009 2zM8 26a2 2 0 11-2-2A2.0023 2.0023 0 018 26zM3 10V4H9l.0015 6z"
  })), children);
});
var CategoryNewEach24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CategoryNewEach24(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 10H24v2h5v6H22v2h3v2.142a4 4 0 102 0V20h2a2.0027 2.0027 0 002-2V12A2.0023 2.0023 0 0029 10zM28 26a2 2 0 11-2-2A2.0027 2.0027 0 0128 26zM19 6H14V8h5v6H12v2h3v6.142a4 4 0 102 0V16h2a2.0023 2.0023 0 002-2V8A2.0023 2.0023 0 0019 6zM18 26a2 2 0 11-2-2A2.0027 2.0027 0 0118 26zM9 2H3A2.002 2.002 0 001 4v6a2.002 2.002 0 002 2H5V22.142a4 4 0 102 0V12H9a2.002 2.002 0 002-2V4A2.002 2.002 0 009 2zM8 26a2 2 0 11-2-2A2.0023 2.0023 0 018 26zM3 10V4H9l.0015 6z"
  })), children);
});
var CategoryNewEach20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CategoryNewEach20(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 10H24v2h5v6H22v2h3v2.142a4 4 0 102 0V20h2a2.0027 2.0027 0 002-2V12A2.0023 2.0023 0 0029 10zM28 26a2 2 0 11-2-2A2.0027 2.0027 0 0128 26zM19 6H14V8h5v6H12v2h3v6.142a4 4 0 102 0V16h2a2.0023 2.0023 0 002-2V8A2.0023 2.0023 0 0019 6zM18 26a2 2 0 11-2-2A2.0027 2.0027 0 0118 26zM9 2H3A2.002 2.002 0 001 4v6a2.002 2.002 0 002 2H5V22.142a4 4 0 102 0V12H9a2.002 2.002 0 002-2V4A2.002 2.002 0 009 2zM8 26a2 2 0 11-2-2A2.0023 2.0023 0 018 26zM3 10V4H9l.0015 6z"
  })), children);
});
var CategoryNewEach16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CategoryNewEach16(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 10H24v2h5v6H22v2h3v2.142a4 4 0 102 0V20h2a2.0027 2.0027 0 002-2V12A2.0023 2.0023 0 0029 10zM28 26a2 2 0 11-2-2A2.0027 2.0027 0 0128 26zM19 6H14V8h5v6H12v2h3v6.142a4 4 0 102 0V16h2a2.0023 2.0023 0 002-2V8A2.0023 2.0023 0 0019 6zM18 26a2 2 0 11-2-2A2.0027 2.0027 0 0118 26zM9 2H3A2.002 2.002 0 001 4v6a2.002 2.002 0 002 2H5V22.142a4 4 0 102 0V12H9a2.002 2.002 0 002-2V4A2.002 2.002 0 009 2zM8 26a2 2 0 11-2-2A2.0023 2.0023 0 018 26zM3 10V4H9l.0015 6z"
  })), children);
});
var CautionGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CautionGlyph(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.3154,12H3.6846L8,4.0884,12.3154,12M14,13,8,2,2,13Z"
  })), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.315 12L3.685 12 8 4.088 12.315 12z"
  })), children);
});
var CautionInvertedGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CautionInvertedGlyph(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 14L2 3 14 3 8 14z"
  })), children);
});
var QCcX32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCcX32(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 23H5a2 2 0 01-2-2V15a2 2 0 012-2h5v2H5v6h5zM19 23H14a2 2 0 01-2-2V15a2 2 0 012-2h5v2H14v6h5zM29 9L27 9 25 15 23 9 21 9 23.75 16 21 23 23 23 25 17 27 23 29 23 26.25 16 29 9z"
  })), children);
});
var QCcX24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCcX24(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 23H5a2 2 0 01-2-2V15a2 2 0 012-2h5v2H5v6h5zM19 23H14a2 2 0 01-2-2V15a2 2 0 012-2h5v2H14v6h5zM29 9L27 9 25 15 23 9 21 9 23.75 16 21 23 23 23 25 17 27 23 29 23 26.25 16 29 9z"
  })), children);
});
var QCcX20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCcX20(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 23H5a2 2 0 01-2-2V15a2 2 0 012-2h5v2H5v6h5zM19 23H14a2 2 0 01-2-2V15a2 2 0 012-2h5v2H14v6h5zM29 9L27 9 25 15 23 9 21 9 23.75 16 21 23 23 23 25 17 27 23 29 23 26.25 16 29 9z"
  })), children);
});
var QCcX16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCcX16(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 23H5a2 2 0 01-2-2V15a2 2 0 012-2h5v2H5v6h5zM19 23H14a2 2 0 01-2-2V15a2 2 0 012-2h5v2H14v6h5zM29 9L27 9 25 15 23 9 21 9 23.75 16 21 23 23 23 25 17 27 23 29 23 26.25 16 29 9z"
  })), children);
});
var WatsonHealthCdArchive32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCdArchive32(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A12,12,0,1,1,28,16,12,12,0,0,1,16,28ZM16,6A10,10,0,1,0,26,16,10,10,0,0,0,16,6Z"
  })), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A6,6,0,0,1,16,22Zm0-10a4,4,0,1,0,4,4A4,4,0,0,0,16,12Z"
  })), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), children);
});
var WatsonHealthCdArchive24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCdArchive24(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A12,12,0,1,1,28,16,12,12,0,0,1,16,28ZM16,6A10,10,0,1,0,26,16,10,10,0,0,0,16,6Z"
  })), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A6,6,0,0,1,16,22Zm0-10a4,4,0,1,0,4,4A4,4,0,0,0,16,12Z"
  })), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), children);
});
var WatsonHealthCdArchive20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCdArchive20(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A12,12,0,1,1,28,16,12,12,0,0,1,16,28ZM16,6A10,10,0,1,0,26,16,10,10,0,0,0,16,6Z"
  })), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A6,6,0,0,1,16,22Zm0-10a4,4,0,1,0,4,4A4,4,0,0,0,16,12Z"
  })), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), children);
});
var WatsonHealthCdArchive16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCdArchive16(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28A12,12,0,1,1,28,16,12,12,0,0,1,16,28ZM16,6A10,10,0,1,0,26,16,10,10,0,0,0,16,6Z"
  })), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,1,6-6A6,6,0,0,1,16,22Zm0-10a4,4,0,1,0,4,4A4,4,0,0,0,16,12Z"
  })), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), children);
});
var WatsonHealthCdCreateArchive32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCdCreateArchive32(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a6,6,0,1,1,6-6A6,6,0,0,1,14,20Zm0-10a4,4,0,1,0,4,4A4,4,0,0,0,14,10Z"
  })), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "14",
    r: "2"
  })), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,23.54A10,10,0,1,1,24,14c0,.34,0,.67-.05,1h2c0-.33.05-.66.05-1A12,12,0,1,0,14,26a12.33,12.33,0,0,0,3-.39Z"
  })), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,30l-2.14-1A5,5,0,0,1,20,24.47V18H30v6.47A5,5,0,0,1,27.14,29ZM22,20v4.47a3,3,0,0,0,1.72,2.71l1.28.61,1.28-.61A3,3,0,0,0,28,24.47V20Z"
  })), children);
});
var WatsonHealthCdCreateArchive24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCdCreateArchive24(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a6,6,0,1,1,6-6A6,6,0,0,1,14,20Zm0-10a4,4,0,1,0,4,4A4,4,0,0,0,14,10Z"
  })), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "14",
    r: "2"
  })), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,23.54A10,10,0,1,1,24,14c0,.34,0,.67-.05,1h2c0-.33.05-.66.05-1A12,12,0,1,0,14,26a12.33,12.33,0,0,0,3-.39Z"
  })), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,30l-2.14-1A5,5,0,0,1,20,24.47V18H30v6.47A5,5,0,0,1,27.14,29ZM22,20v4.47a3,3,0,0,0,1.72,2.71l1.28.61,1.28-.61A3,3,0,0,0,28,24.47V20Z"
  })), children);
});
var WatsonHealthCdCreateArchive20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCdCreateArchive20(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a6,6,0,1,1,6-6A6,6,0,0,1,14,20Zm0-10a4,4,0,1,0,4,4A4,4,0,0,0,14,10Z"
  })), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "14",
    r: "2"
  })), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,23.54A10,10,0,1,1,24,14c0,.34,0,.67-.05,1h2c0-.33.05-.66.05-1A12,12,0,1,0,14,26a12.33,12.33,0,0,0,3-.39Z"
  })), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,30l-2.14-1A5,5,0,0,1,20,24.47V18H30v6.47A5,5,0,0,1,27.14,29ZM22,20v4.47a3,3,0,0,0,1.72,2.71l1.28.61,1.28-.61A3,3,0,0,0,28,24.47V20Z"
  })), children);
});
var WatsonHealthCdCreateArchive16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCdCreateArchive16(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a6,6,0,1,1,6-6A6,6,0,0,1,14,20Zm0-10a4,4,0,1,0,4,4A4,4,0,0,0,14,10Z"
  })), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "14",
    r: "2"
  })), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,23.54A10,10,0,1,1,24,14c0,.34,0,.67-.05,1h2c0-.33.05-.66.05-1A12,12,0,1,0,14,26a12.33,12.33,0,0,0,3-.39Z"
  })), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,30l-2.14-1A5,5,0,0,1,20,24.47V18H30v6.47A5,5,0,0,1,27.14,29ZM22,20v4.47a3,3,0,0,0,1.72,2.71l1.28.61,1.28-.61A3,3,0,0,0,28,24.47V20Z"
  })), children);
});
var WatsonHealthCdCreateExchange32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCdCreateExchange32(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle21 || (_circle21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "14",
    r: "2"
  })), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2a12,12,0,0,0,0,24V24A10,10,0,1,1,24,14,8.27,8.27,0,0,1,24,15h2c0-.33.05-.66.05-1A12,12,0,0,0,14,2Z"
  })), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 24L26.17 24 23.58 26.59 25 28 30 23 25 18 23.58 19.42 26.17 22 17 22 17 24zM14 20a6 6 0 116-6A6 6 0 0114 20zm0-10a4 4 0 104 4A4 4 0 0014 10z"
  })), children);
});
var WatsonHealthCdCreateExchange24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCdCreateExchange24(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle22 || (_circle22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "14",
    r: "2"
  })), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2a12,12,0,0,0,0,24V24A10,10,0,1,1,24,14,8.27,8.27,0,0,1,24,15h2c0-.33.05-.66.05-1A12,12,0,0,0,14,2Z"
  })), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 24L26.17 24 23.58 26.59 25 28 30 23 25 18 23.58 19.42 26.17 22 17 22 17 24zM14 20a6 6 0 116-6A6 6 0 0114 20zm0-10a4 4 0 104 4A4 4 0 0014 10z"
  })), children);
});
var WatsonHealthCdCreateExchange20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCdCreateExchange20(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle23 || (_circle23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "14",
    r: "2"
  })), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2a12,12,0,0,0,0,24V24A10,10,0,1,1,24,14,8.27,8.27,0,0,1,24,15h2c0-.33.05-.66.05-1A12,12,0,0,0,14,2Z"
  })), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 24L26.17 24 23.58 26.59 25 28 30 23 25 18 23.58 19.42 26.17 22 17 22 17 24zM14 20a6 6 0 116-6A6 6 0 0114 20zm0-10a4 4 0 104 4A4 4 0 0014 10z"
  })), children);
});
var WatsonHealthCdCreateExchange16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCdCreateExchange16(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle24 || (_circle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "14",
    r: "2"
  })), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2a12,12,0,0,0,0,24V24A10,10,0,1,1,24,14,8.27,8.27,0,0,1,24,15h2c0-.33.05-.66.05-1A12,12,0,0,0,14,2Z"
  })), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 24L26.17 24 23.58 26.59 25 28 30 23 25 18 23.58 19.42 26.17 22 17 22 17 24zM14 20a6 6 0 116-6A6 6 0 0114 20zm0-10a4 4 0 104 4A4 4 0 0014 10z"
  })), children);
});
var Cda32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cda32(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9H24a2.002 2.002 0 00-2 2V23h2V18h4v5h2V11A2.0023 2.0023 0 0028 9zm-4 7V11h4v5zM16 23H12V9h4a4.0042 4.0042 0 014 4v6A4.0039 4.0039 0 0116 23zm-2-2h2a2.0027 2.0027 0 002-2V13a2.0023 2.0023 0 00-2-2H14zM10 23H4a2.0023 2.0023 0 01-2-2V11A2.002 2.002 0 014 9h6v2H4V21h6z"
  })), children);
});
var Cda24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cda24(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9H24a2.002 2.002 0 00-2 2V23h2V18h4v5h2V11A2.0023 2.0023 0 0028 9zm-4 7V11h4v5zM16 23H12V9h4a4.0042 4.0042 0 014 4v6A4.0039 4.0039 0 0116 23zm-2-2h2a2.0027 2.0027 0 002-2V13a2.0023 2.0023 0 00-2-2H14zM10 23H4a2.0023 2.0023 0 01-2-2V11A2.002 2.002 0 014 9h6v2H4V21h6z"
  })), children);
});
var Cda20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cda20(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9H24a2.002 2.002 0 00-2 2V23h2V18h4v5h2V11A2.0023 2.0023 0 0028 9zm-4 7V11h4v5zM16 23H12V9h4a4.0042 4.0042 0 014 4v6A4.0039 4.0039 0 0116 23zm-2-2h2a2.0027 2.0027 0 002-2V13a2.0023 2.0023 0 00-2-2H14zM10 23H4a2.0023 2.0023 0 01-2-2V11A2.002 2.002 0 014 9h6v2H4V21h6z"
  })), children);
});
var Cda16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cda16(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9H24a2.002 2.002 0 00-2 2V23h2V18h4v5h2V11A2.0023 2.0023 0 0028 9zm-4 7V11h4v5zM16 23H12V9h4a4.0042 4.0042 0 014 4v6A4.0039 4.0039 0 0116 23zm-2-2h2a2.0027 2.0027 0 002-2V13a2.0023 2.0023 0 00-2-2H14zM10 23H4a2.0023 2.0023 0 01-2-2V11A2.002 2.002 0 014 9h6v2H4V21h6z"
  })), children);
});
var CellTower32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CellTower32(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 11L25 16 17 16 17 11 15 11 15 16 7 16 7 11 5 11 5 23 7 23 7 18 10 18 10 30 12 30 12 18 15 18 15 23 17 23 17 18 20 18 20 30 22 30 22 18 25 18 25 23 27 23 27 11zM16 6c-1.7 0-3.2.7-4.2 1.8l1.4 1.4C13.9 8.4 14.9 8 16 8s2.1.4 2.8 1.2l1.4-1.4C19.2 6.7 17.7 6 16 6z"
  })), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9,4.9l1.4,1.4C11.8,4.9,13.8,4,16,4s4.2,0.9,5.7,2.3l1.4-1.4C21.3,3.1,18.8,2,16,2S10.7,3.1,8.9,4.9z"
  })), children);
});
var CellTower24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CellTower24(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 11L25 16 17 16 17 11 15 11 15 16 7 16 7 11 5 11 5 23 7 23 7 18 10 18 10 30 12 30 12 18 15 18 15 23 17 23 17 18 20 18 20 30 22 30 22 18 25 18 25 23 27 23 27 11zM16 6c-1.7 0-3.2.7-4.2 1.8l1.4 1.4C13.9 8.4 14.9 8 16 8s2.1.4 2.8 1.2l1.4-1.4C19.2 6.7 17.7 6 16 6z"
  })), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9,4.9l1.4,1.4C11.8,4.9,13.8,4,16,4s4.2,0.9,5.7,2.3l1.4-1.4C21.3,3.1,18.8,2,16,2S10.7,3.1,8.9,4.9z"
  })), children);
});
var CellTower20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CellTower20(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 11L25 16 17 16 17 11 15 11 15 16 7 16 7 11 5 11 5 23 7 23 7 18 10 18 10 30 12 30 12 18 15 18 15 23 17 23 17 18 20 18 20 30 22 30 22 18 25 18 25 23 27 23 27 11zM16 6c-1.7 0-3.2.7-4.2 1.8l1.4 1.4C13.9 8.4 14.9 8 16 8s2.1.4 2.8 1.2l1.4-1.4C19.2 6.7 17.7 6 16 6z"
  })), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9,4.9l1.4,1.4C11.8,4.9,13.8,4,16,4s4.2,0.9,5.7,2.3l1.4-1.4C21.3,3.1,18.8,2,16,2S10.7,3.1,8.9,4.9z"
  })), children);
});
var CellTower16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CellTower16(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 11L25 16 17 16 17 11 15 11 15 16 7 16 7 11 5 11 5 23 7 23 7 18 10 18 10 30 12 30 12 18 15 18 15 23 17 23 17 18 20 18 20 30 22 30 22 18 25 18 25 23 27 23 27 11zM16 6c-1.7 0-3.2.7-4.2 1.8l1.4 1.4C13.9 8.4 14.9 8 16 8s2.1.4 2.8 1.2l1.4-1.4C19.2 6.7 17.7 6 16 6z"
  })), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.9,4.9l1.4,1.4C11.8,4.9,13.8,4,16,4s4.2,0.9,5.7,2.3l1.4-1.4C21.3,3.1,18.8,2,16,2S10.7,3.1,8.9,4.9z"
  })), children);
});
var CenterCircle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CenterCircle32(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H27.9492A12.0071,12.0071,0,0,0,17,4.0508V2H15V4.0508A12.0071,12.0071,0,0,0,4.0508,15H2v2H4.0508A12.0071,12.0071,0,0,0,15,27.9492V30h2V27.9492A12.0071,12.0071,0,0,0,27.9492,17H30ZM17,25.9492V22H15v3.9492A10.0166,10.0166,0,0,1,6.0508,17H10V15H6.0508A10.0166,10.0166,0,0,1,15,6.0508V10h2V6.0508A10.0166,10.0166,0,0,1,25.9492,15H22v2h3.9492A10.0166,10.0166,0,0,1,17,25.9492Z"
  })), children);
});
var CenterCircle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CenterCircle24(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H27.9492A12.0071,12.0071,0,0,0,17,4.0508V2H15V4.0508A12.0071,12.0071,0,0,0,4.0508,15H2v2H4.0508A12.0071,12.0071,0,0,0,15,27.9492V30h2V27.9492A12.0071,12.0071,0,0,0,27.9492,17H30ZM17,25.9492V22H15v3.9492A10.0166,10.0166,0,0,1,6.0508,17H10V15H6.0508A10.0166,10.0166,0,0,1,15,6.0508V10h2V6.0508A10.0166,10.0166,0,0,1,25.9492,15H22v2h3.9492A10.0166,10.0166,0,0,1,17,25.9492Z"
  })), children);
});
var CenterCircle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CenterCircle20(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H27.9492A12.0071,12.0071,0,0,0,17,4.0508V2H15V4.0508A12.0071,12.0071,0,0,0,4.0508,15H2v2H4.0508A12.0071,12.0071,0,0,0,15,27.9492V30h2V27.9492A12.0071,12.0071,0,0,0,27.9492,17H30ZM17,25.9492V22H15v3.9492A10.0166,10.0166,0,0,1,6.0508,17H10V15H6.0508A10.0166,10.0166,0,0,1,15,6.0508V10h2V6.0508A10.0166,10.0166,0,0,1,25.9492,15H22v2h3.9492A10.0166,10.0166,0,0,1,17,25.9492Z"
  })), children);
});
var CenterCircle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CenterCircle16(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H27.9492A12.0071,12.0071,0,0,0,17,4.0508V2H15V4.0508A12.0071,12.0071,0,0,0,4.0508,15H2v2H4.0508A12.0071,12.0071,0,0,0,15,27.9492V30h2V27.9492A12.0071,12.0071,0,0,0,27.9492,17H30ZM17,25.9492V22H15v3.9492A10.0166,10.0166,0,0,1,6.0508,17H10V15H6.0508A10.0166,10.0166,0,0,1,15,6.0508V10h2V6.0508A10.0166,10.0166,0,0,1,25.9492,15H22v2h3.9492A10.0166,10.0166,0,0,1,17,25.9492Z"
  })), children);
});
var CenterSquare32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CenterSquare32(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 12L4 12 4 4 12 4 12 6 6 6 6 12zM28 12L26 12 26 6 20 6 20 4 28 4 28 12zM12 28L4 28 4 20 6 20 6 26 12 26 12 28zM28 28L20 28 20 26 26 26 26 20 28 20 28 28zM15 10H17V14H15zM10 15H14V17H10zM18 15H22V17H18zM15 18H17V22H15z"
  })), children);
});
var CenterSquare24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CenterSquare24(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 12L4 12 4 4 12 4 12 6 6 6 6 12zM28 12L26 12 26 6 20 6 20 4 28 4 28 12zM12 28L4 28 4 20 6 20 6 26 12 26 12 28zM28 28L20 28 20 26 26 26 26 20 28 20 28 28zM15 10H17V14H15zM10 15H14V17H10zM18 15H22V17H18zM15 18H17V22H15z"
  })), children);
});
var CenterSquare20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CenterSquare20(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 12L4 12 4 4 12 4 12 6 6 6 6 12zM28 12L26 12 26 6 20 6 20 4 28 4 28 12zM12 28L4 28 4 20 6 20 6 26 12 26 12 28zM28 28L20 28 20 26 26 26 26 20 28 20 28 28zM15 10H17V14H15zM10 15H14V17H10zM18 15H22V17H18zM15 18H17V22H15z"
  })), children);
});
var CenterSquare16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CenterSquare16(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 12L4 12 4 4 12 4 12 6 6 6 6 12zM28 12L26 12 26 6 20 6 20 4 28 4 28 12zM12 28L4 28 4 20 6 20 6 26 12 26 12 28zM28 28L20 28 20 26 26 26 26 20 28 20 28 28zM15 10H17V14H15zM10 15H14V17H10zM18 15H22V17H18zM15 18H17V22H15z"
  })), children);
});
var CenterToFit32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CenterToFit32(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 2L2 2 2 8 4 8 4 4 8 4 8 2zM24 2L30 2 30 8 28 8 28 4 24 4 24 2zM8 30L2 30 2 24 4 24 4 28 8 28 8 30zM24 30L30 30 30 24 28 24 28 28 24 28 24 30zM24 24H8a2.0023 2.0023 0 01-2-2V10A2.0023 2.0023 0 018 8H24a2.0023 2.0023 0 012 2V22A2.0023 2.0023 0 0124 24zM8 10V22H24V10z"
  })), children);
});
var CenterToFit24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CenterToFit24(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 2L2 2 2 8 4 8 4 4 8 4 8 2zM24 2L30 2 30 8 28 8 28 4 24 4 24 2zM8 30L2 30 2 24 4 24 4 28 8 28 8 30zM24 30L30 30 30 24 28 24 28 28 24 28 24 30zM24 24H8a2.0023 2.0023 0 01-2-2V10A2.0023 2.0023 0 018 8H24a2.0023 2.0023 0 012 2V22A2.0023 2.0023 0 0124 24zM8 10V22H24V10z"
  })), children);
});
var CenterToFit20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CenterToFit20(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 2L2 2 2 8 4 8 4 4 8 4 8 2zM24 2L30 2 30 8 28 8 28 4 24 4 24 2zM8 30L2 30 2 24 4 24 4 28 8 28 8 30zM24 30L30 30 30 24 28 24 28 28 24 28 24 30zM24 24H8a2.0023 2.0023 0 01-2-2V10A2.0023 2.0023 0 018 8H24a2.0023 2.0023 0 012 2V22A2.0023 2.0023 0 0124 24zM8 10V22H24V10z"
  })), children);
});
var CenterToFit16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CenterToFit16(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 2L2 2 2 8 4 8 4 4 8 4 8 2zM24 2L30 2 30 8 28 8 28 4 24 4 24 2zM8 30L2 30 2 24 4 24 4 28 8 28 8 30zM24 30L30 30 30 24 28 24 28 28 24 28 24 30zM24 24H8a2.0023 2.0023 0 01-2-2V10A2.0023 2.0023 0 018 8H24a2.0023 2.0023 0 012 2V22A2.0023 2.0023 0 0124 24zM8 10V22H24V10z"
  })), children);
});
var Certificate32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Certificate32(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 17L25.912 20.703 30 21.297 27 24 27.771 28 24 25.75 20.229 28 21 24 18 21.297 22.2 20.703 24 17zM6 16H12V18H6zM6 12H16V14H6zM6 8H16V10H6z"
  })), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,26H4V6H28V16h2V6a2,2,0,0,0-2-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H16Z"
  })), children);
});
var Certificate24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Certificate24(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 17L25.912 20.703 30 21.297 27 24 27.771 28 24 25.75 20.229 28 21 24 18 21.297 22.2 20.703 24 17zM6 16H12V18H6zM6 12H16V14H6zM6 8H16V10H6z"
  })), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,26H4V6H28V16h2V6a2,2,0,0,0-2-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H16Z"
  })), children);
});
var Certificate20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Certificate20(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 17L25.912 20.703 30 21.297 27 24 27.771 28 24 25.75 20.229 28 21 24 18 21.297 22.2 20.703 24 17zM6 16H12V18H6zM6 12H16V14H6zM6 8H16V10H6z"
  })), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,26H4V6H28V16h2V6a2,2,0,0,0-2-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H16Z"
  })), children);
});
var Certificate16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Certificate16(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 17L25.912 20.703 30 21.297 27 24 27.771 28 24 25.75 20.229 28 21 24 18 21.297 22.2 20.703 24 17zM6 16H12V18H6zM6 12H16V14H6zM6 8H16V10H6z"
  })), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,26H4V6H28V16h2V6a2,2,0,0,0-2-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H16Z"
  })), children);
});
var CertificateCheck32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CertificateCheck32(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 16H12V18H6zM6 12H16V14H6zM6 8H16V10H6z"
  })), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,26H4V6H28V16h2V6a2,2,0,0,0-2-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H14Z"
  })), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 25.59L19.41 23 18 24.41 22 28.41 30 20.41 28.59 19 22 25.59z"
  })), children);
});
var CertificateCheck24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CertificateCheck24(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 16H12V18H6zM6 12H16V14H6zM6 8H16V10H6z"
  })), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,26H4V6H28V16h2V6a2,2,0,0,0-2-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H14Z"
  })), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 25.59L19.41 23 18 24.41 22 28.41 30 20.41 28.59 19 22 25.59z"
  })), children);
});
var CertificateCheck20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CertificateCheck20(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 16H12V18H6zM6 12H16V14H6zM6 8H16V10H6z"
  })), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,26H4V6H28V16h2V6a2,2,0,0,0-2-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H14Z"
  })), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 25.59L19.41 23 18 24.41 22 28.41 30 20.41 28.59 19 22 25.59z"
  })), children);
});
var CertificateCheck16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CertificateCheck16(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 16H12V18H6zM6 12H16V14H6zM6 8H16V10H6z"
  })), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,26H4V6H28V16h2V6a2,2,0,0,0-2-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H14Z"
  })), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 25.59L19.41 23 18 24.41 22 28.41 30 20.41 28.59 19 22 25.59z"
  })), children);
});
var ChangeCatalog32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChangeCatalog32(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 24v2h2.4592A5.94 5.94 0 0122 28a6.0066 6.0066 0 01-6-6H14a7.9841 7.9841 0 0014 5.2651V30h2V24zM22 14a8.04 8.04 0 00-6 2.7349V14H14v6h6V18H17.5408A5.94 5.94 0 0122 16a6.0066 6.0066 0 016 6h2A8.0092 8.0092 0 0022 14z"
  })), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,28H6V24H8V22H6V17H8V15H6V10H8V8H6V4H24v8h2V4a2,2,0,0,0-2-2H6A2,2,0,0,0,4,4V8H2v2H4v5H2v2H4v5H2v2H4v4a2,2,0,0,0,2,2h6Z"
  })), children);
});
var ChangeCatalog24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChangeCatalog24(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 24v2h2.4592A5.94 5.94 0 0122 28a6.0066 6.0066 0 01-6-6H14a7.9841 7.9841 0 0014 5.2651V30h2V24zM22 14a8.04 8.04 0 00-6 2.7349V14H14v6h6V18H17.5408A5.94 5.94 0 0122 16a6.0066 6.0066 0 016 6h2A8.0092 8.0092 0 0022 14z"
  })), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,28H6V24H8V22H6V17H8V15H6V10H8V8H6V4H24v8h2V4a2,2,0,0,0-2-2H6A2,2,0,0,0,4,4V8H2v2H4v5H2v2H4v5H2v2H4v4a2,2,0,0,0,2,2h6Z"
  })), children);
});
var ChangeCatalog20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChangeCatalog20(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 24v2h2.4592A5.94 5.94 0 0122 28a6.0066 6.0066 0 01-6-6H14a7.9841 7.9841 0 0014 5.2651V30h2V24zM22 14a8.04 8.04 0 00-6 2.7349V14H14v6h6V18H17.5408A5.94 5.94 0 0122 16a6.0066 6.0066 0 016 6h2A8.0092 8.0092 0 0022 14z"
  })), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,28H6V24H8V22H6V17H8V15H6V10H8V8H6V4H24v8h2V4a2,2,0,0,0-2-2H6A2,2,0,0,0,4,4V8H2v2H4v5H2v2H4v5H2v2H4v4a2,2,0,0,0,2,2h6Z"
  })), children);
});
var ChangeCatalog16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChangeCatalog16(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 24v2h2.4592A5.94 5.94 0 0122 28a6.0066 6.0066 0 01-6-6H14a7.9841 7.9841 0 0014 5.2651V30h2V24zM22 14a8.04 8.04 0 00-6 2.7349V14H14v6h6V18H17.5408A5.94 5.94 0 0122 16a6.0066 6.0066 0 016 6h2A8.0092 8.0092 0 0022 14z"
  })), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,28H6V24H8V22H6V17H8V15H6V10H8V8H6V4H24v8h2V4a2,2,0,0,0-2-2H6A2,2,0,0,0,4,4V8H2v2H4v5H2v2H4v5H2v2H4v4a2,2,0,0,0,2,2h6Z"
  })), children);
});
var CharacterDecimal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterDecimal32(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 15H23V17H21z"
  })), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 23H20a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h4a2.0023 2.0023 0 012 2V21A2.0027 2.0027 0 0124 23zM20 11h0V21h4V11zM11 15H13V17H11z"
  })), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 23H10a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h4a2.0023 2.0023 0 012 2V21A2.0027 2.0027 0 0114 23zM10 11h0V21h4V11zM4 21H6V23H4z"
  })), children);
});
var CharacterDecimal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterDecimal24(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 15H23V17H21z"
  })), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 23H20a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h4a2.0023 2.0023 0 012 2V21A2.0027 2.0027 0 0124 23zM20 11h0V21h4V11zM11 15H13V17H11z"
  })), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 23H10a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h4a2.0023 2.0023 0 012 2V21A2.0027 2.0027 0 0114 23zM10 11h0V21h4V11zM4 21H6V23H4z"
  })), children);
});
var CharacterDecimal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterDecimal20(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 15H23V17H21z"
  })), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 23H20a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h4a2.0023 2.0023 0 012 2V21A2.0027 2.0027 0 0124 23zM20 11h0V21h4V11zM11 15H13V17H11z"
  })), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 23H10a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h4a2.0023 2.0023 0 012 2V21A2.0027 2.0027 0 0114 23zM10 11h0V21h4V11zM4 21H6V23H4z"
  })), children);
});
var CharacterDecimal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterDecimal16(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 15H23V17H21z"
  })), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 23H20a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h4a2.0023 2.0023 0 012 2V21A2.0027 2.0027 0 0124 23zM20 11h0V21h4V11zM11 15H13V17H11z"
  })), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 23H10a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h4a2.0023 2.0023 0 012 2V21A2.0027 2.0027 0 0114 23zM10 11h0V21h4V11zM4 21H6V23H4z"
  })), children);
});
var CharacterFraction32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterFraction32(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H20V24a2.002,2.002,0,0,1,2-2h4V18H20V16h6a2.0023,2.0023,0,0,1,2,2v4a2.0023,2.0023,0,0,1-2,2H22v4h6Z"
  })), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.479 15.5H26.521V17.5H4.479z",
    transform: "rotate(-45 15.5 16.5)"
  })), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.5 15.5L4.5 14.5 7.5 14.5 7.5 3.5 4.5 3.5 4.5 2.5 8.5 2.5 8.5 14.5 11.5 14.5 11.5 15.5 4.5 15.5z"
  })), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,3V15H8V3M9,2H4V4H7V14H4v2h8V14H9V2Z"
  })), children);
});
var CharacterFraction24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterFraction24(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H20V24a2.002,2.002,0,0,1,2-2h4V18H20V16h6a2.0023,2.0023,0,0,1,2,2v4a2.0023,2.0023,0,0,1-2,2H22v4h6Z"
  })), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.479 15.5H26.521V17.5H4.479z",
    transform: "rotate(-45 15.5 16.5)"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.5 15.5L4.5 14.5 7.5 14.5 7.5 3.5 4.5 3.5 4.5 2.5 8.5 2.5 8.5 14.5 11.5 14.5 11.5 15.5 4.5 15.5z"
  })), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,3V15H8V3M9,2H4V4H7V14H4v2h8V14H9V2Z"
  })), children);
});
var CharacterFraction20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterFraction20(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H20V24a2.002,2.002,0,0,1,2-2h4V18H20V16h6a2.0023,2.0023,0,0,1,2,2v4a2.0023,2.0023,0,0,1-2,2H22v4h6Z"
  })), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.479 15.5H26.521V17.5H4.479z",
    transform: "rotate(-45 15.5 16.5)"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.5 15.5L4.5 14.5 7.5 14.5 7.5 3.5 4.5 3.5 4.5 2.5 8.5 2.5 8.5 14.5 11.5 14.5 11.5 15.5 4.5 15.5z"
  })), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,3V15H8V3M9,2H4V4H7V14H4v2h8V14H9V2Z"
  })), children);
});
var CharacterFraction16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterFraction16(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H20V24a2.002,2.002,0,0,1,2-2h4V18H20V16h6a2.0023,2.0023,0,0,1,2,2v4a2.0023,2.0023,0,0,1-2,2H22v4h6Z"
  })), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.479 15.5H26.521V17.5H4.479z",
    transform: "rotate(-45 15.5 16.5)"
  })), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.5 15.5L4.5 14.5 7.5 14.5 7.5 3.5 4.5 3.5 4.5 2.5 8.5 2.5 8.5 14.5 11.5 14.5 11.5 15.5 4.5 15.5z"
  })), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,3V15H8V3M9,2H4V4H7V14H4v2h8V14H9V2Z"
  })), children);
});
var CharacterInteger32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterInteger32(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.5 22.5L19.5 21.5 22.5 21.5 22.5 10.5 19.5 10.5 19.5 9.5 23.5 9.5 23.5 21.5 26.5 21.5 26.5 22.5 19.5 22.5z"
  })), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 10V22h0V10m1-1H19v2h3V21H19v2h8V21H24V9zM5 21H15V23H5zM15 13L11 13 11 9 9 9 9 13 5 13 5 15 9 15 9 19 11 19 11 15 15 15 15 13z"
  })), children);
});
var CharacterInteger24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterInteger24(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.5 22.5L19.5 21.5 22.5 21.5 22.5 10.5 19.5 10.5 19.5 9.5 23.5 9.5 23.5 21.5 26.5 21.5 26.5 22.5 19.5 22.5z"
  })), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 10V22h0V10m1-1H19v2h3V21H19v2h8V21H24V9zM5 21H15V23H5zM15 13L11 13 11 9 9 9 9 13 5 13 5 15 9 15 9 19 11 19 11 15 15 15 15 13z"
  })), children);
});
var CharacterInteger20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterInteger20(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.5 22.5L19.5 21.5 22.5 21.5 22.5 10.5 19.5 10.5 19.5 9.5 23.5 9.5 23.5 21.5 26.5 21.5 26.5 22.5 19.5 22.5z"
  })), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 10V22h0V10m1-1H19v2h3V21H19v2h8V21H24V9zM5 21H15V23H5zM15 13L11 13 11 9 9 9 9 13 5 13 5 15 9 15 9 19 11 19 11 15 15 15 15 13z"
  })), children);
});
var CharacterInteger16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterInteger16(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.5 22.5L19.5 21.5 22.5 21.5 22.5 10.5 19.5 10.5 19.5 9.5 23.5 9.5 23.5 21.5 26.5 21.5 26.5 22.5 19.5 22.5z"
  })), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 10V22h0V10m1-1H19v2h3V21H19v2h8V21H24V9zM5 21H15V23H5zM15 13L11 13 11 9 9 9 9 13 5 13 5 15 9 15 9 19 11 19 11 15 15 15 15 13z"
  })), children);
});
var CharacterLowerCase32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterLowerCase32(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 23H24a2.0027 2.0027 0 01-2-2V15a2.0023 2.0023 0 012-2h5v2H24v6h5zM18 13H14V9H12V23h6a2.0027 2.0027 0 002-2V15A2.0023 2.0023 0 0018 13zm-4 8V15h4v6zM8 13H3v2H8v2H4a2 2 0 00-2 2v2a2 2 0 002 2h6V15A2.0023 2.0023 0 008 13zm0 8H4V19H8z"
  })), children);
});
var CharacterLowerCase24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterLowerCase24(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 23H24a2.0027 2.0027 0 01-2-2V15a2.0023 2.0023 0 012-2h5v2H24v6h5zM18 13H14V9H12V23h6a2.0027 2.0027 0 002-2V15A2.0023 2.0023 0 0018 13zm-4 8V15h4v6zM8 13H3v2H8v2H4a2 2 0 00-2 2v2a2 2 0 002 2h6V15A2.0023 2.0023 0 008 13zm0 8H4V19H8z"
  })), children);
});
var CharacterLowerCase20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterLowerCase20(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 23H24a2.0027 2.0027 0 01-2-2V15a2.0023 2.0023 0 012-2h5v2H24v6h5zM18 13H14V9H12V23h6a2.0027 2.0027 0 002-2V15A2.0023 2.0023 0 0018 13zm-4 8V15h4v6zM8 13H3v2H8v2H4a2 2 0 00-2 2v2a2 2 0 002 2h6V15A2.0023 2.0023 0 008 13zm0 8H4V19H8z"
  })), children);
});
var CharacterLowerCase16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterLowerCase16(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 23H24a2.0027 2.0027 0 01-2-2V15a2.0023 2.0023 0 012-2h5v2H24v6h5zM18 13H14V9H12V23h6a2.0027 2.0027 0 002-2V15A2.0023 2.0023 0 0018 13zm-4 8V15h4v6zM8 13H3v2H8v2H4a2 2 0 00-2 2v2a2 2 0 002 2h6V15A2.0023 2.0023 0 008 13zm0 8H4V19H8z"
  })), children);
});
var CharacterNegativeNumber32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterNegativeNumber32(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.5 22.5L19.5 21.5 22.5 21.5 22.5 10.5 19.5 10.5 19.5 9.5 23.5 9.5 23.5 21.5 26.5 21.5 26.5 22.5 19.5 22.5z"
  })), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 10V22h0V10m1-1H19v2h3V21H19v2h8V21H24V9zM5 15H15V17H5z"
  })), children);
});
var CharacterNegativeNumber24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterNegativeNumber24(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.5 22.5L19.5 21.5 22.5 21.5 22.5 10.5 19.5 10.5 19.5 9.5 23.5 9.5 23.5 21.5 26.5 21.5 26.5 22.5 19.5 22.5z"
  })), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 10V22h0V10m1-1H19v2h3V21H19v2h8V21H24V9zM5 15H15V17H5z"
  })), children);
});
var CharacterNegativeNumber20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterNegativeNumber20(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.5 22.5L19.5 21.5 22.5 21.5 22.5 10.5 19.5 10.5 19.5 9.5 23.5 9.5 23.5 21.5 26.5 21.5 26.5 22.5 19.5 22.5z"
  })), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 10V22h0V10m1-1H19v2h3V21H19v2h8V21H24V9zM5 15H15V17H5z"
  })), children);
});
var CharacterNegativeNumber16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterNegativeNumber16(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.5 22.5L19.5 21.5 22.5 21.5 22.5 10.5 19.5 10.5 19.5 9.5 23.5 9.5 23.5 21.5 26.5 21.5 26.5 22.5 19.5 22.5z"
  })), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 10V22h0V10m1-1H19v2h3V21H19v2h8V21H24V9zM5 15H15V17H5z"
  })), children);
});
var CharacterSentenceCase32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterSentenceCase32(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 23H24a2.0027 2.0027 0 01-2-2V15a2.0023 2.0023 0 012-2h5v2H24v6h5zM18 13H14V9H12V23h6a2.0027 2.0027 0 002-2V15A2.0023 2.0023 0 0018 13zm-4 8V15h4v6zM8 9H4a2.002 2.002 0 00-2 2V23H4V18H8v5h2V11A2.002 2.002 0 008 9zM4 16V11H8v5z"
  })), children);
});
var CharacterSentenceCase24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterSentenceCase24(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 23H24a2.0027 2.0027 0 01-2-2V15a2.0023 2.0023 0 012-2h5v2H24v6h5zM18 13H14V9H12V23h6a2.0027 2.0027 0 002-2V15A2.0023 2.0023 0 0018 13zm-4 8V15h4v6zM8 9H4a2.002 2.002 0 00-2 2V23H4V18H8v5h2V11A2.002 2.002 0 008 9zM4 16V11H8v5z"
  })), children);
});
var CharacterSentenceCase20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterSentenceCase20(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 23H24a2.0027 2.0027 0 01-2-2V15a2.0023 2.0023 0 012-2h5v2H24v6h5zM18 13H14V9H12V23h6a2.0027 2.0027 0 002-2V15A2.0023 2.0023 0 0018 13zm-4 8V15h4v6zM8 9H4a2.002 2.002 0 00-2 2V23H4V18H8v5h2V11A2.002 2.002 0 008 9zM4 16V11H8v5z"
  })), children);
});
var CharacterSentenceCase16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterSentenceCase16(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 23H24a2.0027 2.0027 0 01-2-2V15a2.0023 2.0023 0 012-2h5v2H24v6h5zM18 13H14V9H12V23h6a2.0027 2.0027 0 002-2V15A2.0023 2.0023 0 0018 13zm-4 8V15h4v6zM8 9H4a2.002 2.002 0 00-2 2V23H4V18H8v5h2V11A2.002 2.002 0 008 9zM4 16V11H8v5z"
  })), children);
});
var CharacterUpperCase32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterUpperCase32(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h6v2H24V21h6zM20 12a3.0033 3.0033 0 00-3-3H12V23h5a3.0033 3.0033 0 003-3V18a2.977 2.977 0 00-.78-2A2.9768 2.9768 0 0020 14zm-6-1h3a1.0013 1.0013 0 011 1v2a1.0013 1.0013 0 01-1 1H14zm4 9a1.0009 1.0009 0 01-1 1H14V17h3a1.0009 1.0009 0 011 1zM8 9H4a2.002 2.002 0 00-2 2V23H4V18H8v5h2V11A2.002 2.002 0 008 9zM4 16V11H8v5z"
  })), children);
});
var CharacterUpperCase24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterUpperCase24(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h6v2H24V21h6zM20 12a3.0033 3.0033 0 00-3-3H12V23h5a3.0033 3.0033 0 003-3V18a2.977 2.977 0 00-.78-2A2.9768 2.9768 0 0020 14zm-6-1h3a1.0013 1.0013 0 011 1v2a1.0013 1.0013 0 01-1 1H14zm4 9a1.0009 1.0009 0 01-1 1H14V17h3a1.0009 1.0009 0 011 1zM8 9H4a2.002 2.002 0 00-2 2V23H4V18H8v5h2V11A2.002 2.002 0 008 9zM4 16V11H8v5z"
  })), children);
});
var CharacterUpperCase20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterUpperCase20(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h6v2H24V21h6zM20 12a3.0033 3.0033 0 00-3-3H12V23h5a3.0033 3.0033 0 003-3V18a2.977 2.977 0 00-.78-2A2.9768 2.9768 0 0020 14zm-6-1h3a1.0013 1.0013 0 011 1v2a1.0013 1.0013 0 01-1 1H14zm4 9a1.0009 1.0009 0 01-1 1H14V17h3a1.0009 1.0009 0 011 1zM8 9H4a2.002 2.002 0 00-2 2V23H4V18H8v5h2V11A2.002 2.002 0 008 9zM4 16V11H8v5z"
  })), children);
});
var CharacterUpperCase16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterUpperCase16(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h6v2H24V21h6zM20 12a3.0033 3.0033 0 00-3-3H12V23h5a3.0033 3.0033 0 003-3V18a2.977 2.977 0 00-.78-2A2.9768 2.9768 0 0020 14zm-6-1h3a1.0013 1.0013 0 011 1v2a1.0013 1.0013 0 01-1 1H14zm4 9a1.0009 1.0009 0 01-1 1H14V17h3a1.0009 1.0009 0 011 1zM8 9H4a2.002 2.002 0 00-2 2V23H4V18H8v5h2V11A2.002 2.002 0 008 9zM4 16V11H8v5z"
  })), children);
});
var CharacterWholeNumber32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterWholeNumber32(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9H22v2h6v4H24v2h4v4H22v2h6a2.0027 2.0027 0 002-2V11A2.0023 2.0023 0 0028 9zM20 23H12V17a2.002 2.002 0 012-2h4V11H12V9h6a2.0023 2.0023 0 012 2v4a2.0023 2.0023 0 01-2 2H14v4h6zM2.5 22.5L2.5 21.5 5.5 21.5 5.5 10.5 2.5 10.5 2.5 9.5 6.5 9.5 6.5 21.5 9.5 21.5 9.5 22.5 2.5 22.5z"
  })), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,10V22H6V10M7,9H2v2H5V21H2v2h8V21H7V9Z"
  })), children);
});
var CharacterWholeNumber24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterWholeNumber24(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9H22v2h6v4H24v2h4v4H22v2h6a2.0027 2.0027 0 002-2V11A2.0023 2.0023 0 0028 9zM20 23H12V17a2.002 2.002 0 012-2h4V11H12V9h6a2.0023 2.0023 0 012 2v4a2.0023 2.0023 0 01-2 2H14v4h6zM2.5 22.5L2.5 21.5 5.5 21.5 5.5 10.5 2.5 10.5 2.5 9.5 6.5 9.5 6.5 21.5 9.5 21.5 9.5 22.5 2.5 22.5z"
  })), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,10V22H6V10M7,9H2v2H5V21H2v2h8V21H7V9Z"
  })), children);
});
var CharacterWholeNumber20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterWholeNumber20(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9H22v2h6v4H24v2h4v4H22v2h6a2.0027 2.0027 0 002-2V11A2.0023 2.0023 0 0028 9zM20 23H12V17a2.002 2.002 0 012-2h4V11H12V9h6a2.0023 2.0023 0 012 2v4a2.0023 2.0023 0 01-2 2H14v4h6zM2.5 22.5L2.5 21.5 5.5 21.5 5.5 10.5 2.5 10.5 2.5 9.5 6.5 9.5 6.5 21.5 9.5 21.5 9.5 22.5 2.5 22.5z"
  })), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,10V22H6V10M7,9H2v2H5V21H2v2h8V21H7V9Z"
  })), children);
});
var CharacterWholeNumber16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterWholeNumber16(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9H22v2h6v4H24v2h4v4H22v2h6a2.0027 2.0027 0 002-2V11A2.0023 2.0023 0 0028 9zM20 23H12V17a2.002 2.002 0 012-2h4V11H12V9h6a2.0023 2.0023 0 012 2v4a2.0023 2.0023 0 01-2 2H14v4h6zM2.5 22.5L2.5 21.5 5.5 21.5 5.5 10.5 2.5 10.5 2.5 9.5 6.5 9.5 6.5 21.5 9.5 21.5 9.5 22.5 2.5 22.5z"
  })), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,10V22H6V10M7,9H2v2H5V21H2v2h8V21H7V9Z"
  })), children);
});
var CharacterPatterns32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterPatterns32(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 26V17.8281l-3.5859 3.586L1 20l6-6 6 6-1.4141 1.4141L8 17.8281V26H18v2H8A2.0024 2.0024 0 016 26zM30 22L30 20 22 20 22 22 27.5 22 22 28 22 30 30 30 30 28 24.507 28 30 22zM26 6v8.1719l3.5859-3.586L31 12l-6 6-6-6 1.4141-1.4141L24 14.1719V6H14V4H24A2.0024 2.0024 0 0126 6zM8 2H3V4H8V6H4A2 2 0 002 8v2a2 2 0 002 2h6V4A2.0023 2.0023 0 008 2zm0 8H4V8H8z"
  })), children);
});
var CharacterPatterns24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterPatterns24(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 26V17.8281l-3.5859 3.586L1 20l6-6 6 6-1.4141 1.4141L8 17.8281V26H18v2H8A2.0024 2.0024 0 016 26zM30 22L30 20 22 20 22 22 27.5 22 22 28 22 30 30 30 30 28 24.507 28 30 22zM26 6v8.1719l3.5859-3.586L31 12l-6 6-6-6 1.4141-1.4141L24 14.1719V6H14V4H24A2.0024 2.0024 0 0126 6zM8 2H3V4H8V6H4A2 2 0 002 8v2a2 2 0 002 2h6V4A2.0023 2.0023 0 008 2zm0 8H4V8H8z"
  })), children);
});
var CharacterPatterns20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterPatterns20(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 26V17.8281l-3.5859 3.586L1 20l6-6 6 6-1.4141 1.4141L8 17.8281V26H18v2H8A2.0024 2.0024 0 016 26zM30 22L30 20 22 20 22 22 27.5 22 22 28 22 30 30 30 30 28 24.507 28 30 22zM26 6v8.1719l3.5859-3.586L31 12l-6 6-6-6 1.4141-1.4141L24 14.1719V6H14V4H24A2.0024 2.0024 0 0126 6zM8 2H3V4H8V6H4A2 2 0 002 8v2a2 2 0 002 2h6V4A2.0023 2.0023 0 008 2zm0 8H4V8H8z"
  })), children);
});
var CharacterPatterns16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CharacterPatterns16(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 26V17.8281l-3.5859 3.586L1 20l6-6 6 6-1.4141 1.4141L8 17.8281V26H18v2H8A2.0024 2.0024 0 016 26zM30 22L30 20 22 20 22 22 27.5 22 22 28 22 30 30 30 30 28 24.507 28 30 22zM26 6v8.1719l3.5859-3.586L31 12l-6 6-6-6 1.4141-1.4141L24 14.1719V6H14V4H24A2.0024 2.0024 0 0126 6zM8 2H3V4H8V6H4A2 2 0 002 8v2a2 2 0 002 2h6V4A2.0023 2.0023 0 008 2zm0 8H4V8H8z"
  })), children);
});
var ChargingStation32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChargingStation32(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.857 21.514L10.143 20.486 12.234 17 7.234 17 11.143 10.486 12.857 11.514 10.766 15 15.766 15 11.857 21.514z"
  })), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,7H29V4H27V7H26v6h1V24.5a1.5,1.5,0,0,1-3,0V16a1,1,0,0,0-1-1H19V5a1,1,0,0,0-1-1H5A1,1,0,0,0,4,5V26H2v2H21V26H19V17h3v7.5a3.5,3.5,0,0,0,7,0V13h1ZM17,26H6V6H17Z"
  })), children);
});
var ChargingStation24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChargingStation24(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.857 21.514L10.143 20.486 12.234 17 7.234 17 11.143 10.486 12.857 11.514 10.766 15 15.766 15 11.857 21.514z"
  })), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,7H29V4H27V7H26v6h1V24.5a1.5,1.5,0,0,1-3,0V16a1,1,0,0,0-1-1H19V5a1,1,0,0,0-1-1H5A1,1,0,0,0,4,5V26H2v2H21V26H19V17h3v7.5a3.5,3.5,0,0,0,7,0V13h1ZM17,26H6V6H17Z"
  })), children);
});
var ChargingStation20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChargingStation20(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.857 21.514L10.143 20.486 12.234 17 7.234 17 11.143 10.486 12.857 11.514 10.766 15 15.766 15 11.857 21.514z"
  })), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,7H29V4H27V7H26v6h1V24.5a1.5,1.5,0,0,1-3,0V16a1,1,0,0,0-1-1H19V5a1,1,0,0,0-1-1H5A1,1,0,0,0,4,5V26H2v2H21V26H19V17h3v7.5a3.5,3.5,0,0,0,7,0V13h1ZM17,26H6V6H17Z"
  })), children);
});
var ChargingStation16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChargingStation16(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.857 21.514L10.143 20.486 12.234 17 7.234 17 11.143 10.486 12.857 11.514 10.766 15 15.766 15 11.857 21.514z"
  })), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,7H29V4H27V7H26v6h1V24.5a1.5,1.5,0,0,1-3,0V16a1,1,0,0,0-1-1H19V5a1,1,0,0,0-1-1H5A1,1,0,0,0,4,5V26H2v2H21V26H19V17h3v7.5a3.5,3.5,0,0,0,7,0V13h1ZM17,26H6V6H17Z"
  })), children);
});
var ChargingStationFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChargingStationFilled32(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,7V4H27V7H26v6h1V24.5a1.5,1.5,0,0,1-3,0V16a1,1,0,0,0-1-1H19V5a1,1,0,0,0-1-1H5A1,1,0,0,0,4,5V26H2v2H21V26H19V17h3v7.5a3.5,3.5,0,0,0,7,0V13h1V7ZM11.8574,21.5146l-1.7148-1.0292L12.2339,17h-5l3.9087-6.5146,1.7148,1.0292L10.7661,15h5Z"
  })), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11.857 21.514L10.143 20.486 12.234 17 7.234 17 11.143 10.486 12.857 11.514 10.766 15 15.766 15 11.857 21.514z",
    "data-icon-path": "inner-path"
  })), children);
});
var ChargingStationFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChargingStationFilled24(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,7V4H27V7H26v6h1V24.5a1.5,1.5,0,0,1-3,0V16a1,1,0,0,0-1-1H19V5a1,1,0,0,0-1-1H5A1,1,0,0,0,4,5V26H2v2H21V26H19V17h3v7.5a3.5,3.5,0,0,0,7,0V13h1V7ZM11.8574,21.5146l-1.7148-1.0292L12.2339,17h-5l3.9087-6.5146,1.7148,1.0292L10.7661,15h5Z"
  })), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11.857 21.514L10.143 20.486 12.234 17 7.234 17 11.143 10.486 12.857 11.514 10.766 15 15.766 15 11.857 21.514z",
    "data-icon-path": "inner-path"
  })), children);
});
var ChargingStationFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChargingStationFilled20(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,7V4H27V7H26v6h1V24.5a1.5,1.5,0,0,1-3,0V16a1,1,0,0,0-1-1H19V5a1,1,0,0,0-1-1H5A1,1,0,0,0,4,5V26H2v2H21V26H19V17h3v7.5a3.5,3.5,0,0,0,7,0V13h1V7ZM11.8574,21.5146l-1.7148-1.0292L12.2339,17h-5l3.9087-6.5146,1.7148,1.0292L10.7661,15h5Z"
  })), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11.857 21.514L10.143 20.486 12.234 17 7.234 17 11.143 10.486 12.857 11.514 10.766 15 15.766 15 11.857 21.514z",
    "data-icon-path": "inner-path"
  })), children);
});
var ChargingStationFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChargingStationFilled16(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,7V4H27V7H26v6h1V24.5a1.5,1.5,0,0,1-3,0V16a1,1,0,0,0-1-1H19V5a1,1,0,0,0-1-1H5A1,1,0,0,0,4,5V26H2v2H21V26H19V17h3v7.5a3.5,3.5,0,0,0,7,0V13h1V7ZM11.8574,21.5146l-1.7148-1.0292L12.2339,17h-5l3.9087-6.5146,1.7148,1.0292L10.7661,15h5Z"
  })), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11.857 21.514L10.143 20.486 12.234 17 7.234 17 11.143 10.486 12.857 11.514 10.766 15 15.766 15 11.857 21.514z",
    "data-icon-path": "inner-path"
  })), children);
});
var Chart_3D32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Chart_3D32(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,23v3.5859l-5-5V15a1,1,0,0,0-.5527-.8945L17,11.3818V5.8281l2.5859,2.586L21,7,16,2,11,7l1.4141,1.4141L15,5.8281v5.5537L9.5527,14.1055A1,1,0,0,0,9,15v6.5859l-5,5V23H2v7H9V28H5.4141l4.7832-4.7832,5.3554,2.6777a1.001,1.001,0,0,0,.8946,0l5.3554-2.6777L26.5859,28H23v2h7V23Zm-13,.3818-4-2V16.6182l4,2Zm1-6.5L12.2363,15,16,13.1182,19.7637,15Zm5,4.5-4,2V18.6182l4-2Z"
  })), children);
});
var Chart_3D24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Chart_3D24(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,23v3.5859l-5-5V15a1,1,0,0,0-.5527-.8945L17,11.3818V5.8281l2.5859,2.586L21,7,16,2,11,7l1.4141,1.4141L15,5.8281v5.5537L9.5527,14.1055A1,1,0,0,0,9,15v6.5859l-5,5V23H2v7H9V28H5.4141l4.7832-4.7832,5.3554,2.6777a1.001,1.001,0,0,0,.8946,0l5.3554-2.6777L26.5859,28H23v2h7V23Zm-13,.3818-4-2V16.6182l4,2Zm1-6.5L12.2363,15,16,13.1182,19.7637,15Zm5,4.5-4,2V18.6182l4-2Z"
  })), children);
});
var Chart_3D20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Chart_3D20(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,23v3.5859l-5-5V15a1,1,0,0,0-.5527-.8945L17,11.3818V5.8281l2.5859,2.586L21,7,16,2,11,7l1.4141,1.4141L15,5.8281v5.5537L9.5527,14.1055A1,1,0,0,0,9,15v6.5859l-5,5V23H2v7H9V28H5.4141l4.7832-4.7832,5.3554,2.6777a1.001,1.001,0,0,0,.8946,0l5.3554-2.6777L26.5859,28H23v2h7V23Zm-13,.3818-4-2V16.6182l4,2Zm1-6.5L12.2363,15,16,13.1182,19.7637,15Zm5,4.5-4,2V18.6182l4-2Z"
  })), children);
});
var Chart_3D16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Chart_3D16(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,23v3.5859l-5-5V15a1,1,0,0,0-.5527-.8945L17,11.3818V5.8281l2.5859,2.586L21,7,16,2,11,7l1.4141,1.4141L15,5.8281v5.5537L9.5527,14.1055A1,1,0,0,0,9,15v6.5859l-5,5V23H2v7H9V28H5.4141l4.7832-4.7832,5.3554,2.6777a1.001,1.001,0,0,0,.8946,0l5.3554-2.6777L26.5859,28H23v2h7V23Zm-13,.3818-4-2V16.6182l4,2Zm1-6.5L12.2363,15,16,13.1182,19.7637,15Zm5,4.5-4,2V18.6182l4-2Z"
  })), children);
});
var ChartArea32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartArea32(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.4761,8.0151,13.4473,4.2109a2.0076,2.0076,0,0,0-2.1158.2051L4,10.001V2H2V28a2,2,0,0,0,2,2H30V5.7354ZM28,20.209l-7.62,1.8022-7.0288-2.8838a1.99,1.99,0,0,0-2.022.37L4,25.8359v-4.455l8.375-9.4,7.0186,5.62a2.0155,2.0155,0,0,0,2.0459.2119L28,14.6025ZM12.5239,5.9849l7.03,3.8042a2.012,2.012,0,0,0,1.3408.16L28,8.2646v4.1138L20.6187,16.02,13.6,10.4a1.99,1.99,0,0,0-2.6885.2642L4,18.3838v-5.87ZM4.5513,28,12.62,20.9888l7.0288,2.8838a1.9977,1.9977,0,0,0,1.147.0771L28,22.2612V28Z"
  })), children);
});
var ChartArea24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartArea24(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.4761,8.0151,13.4473,4.2109a2.0076,2.0076,0,0,0-2.1158.2051L4,10.001V2H2V28a2,2,0,0,0,2,2H30V5.7354ZM28,20.209l-7.62,1.8022-7.0288-2.8838a1.99,1.99,0,0,0-2.022.37L4,25.8359v-4.455l8.375-9.4,7.0186,5.62a2.0155,2.0155,0,0,0,2.0459.2119L28,14.6025ZM12.5239,5.9849l7.03,3.8042a2.012,2.012,0,0,0,1.3408.16L28,8.2646v4.1138L20.6187,16.02,13.6,10.4a1.99,1.99,0,0,0-2.6885.2642L4,18.3838v-5.87ZM4.5513,28,12.62,20.9888l7.0288,2.8838a1.9977,1.9977,0,0,0,1.147.0771L28,22.2612V28Z"
  })), children);
});
var ChartArea20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartArea20(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.4761,8.0151,13.4473,4.2109a2.0076,2.0076,0,0,0-2.1158.2051L4,10.001V2H2V28a2,2,0,0,0,2,2H30V5.7354ZM28,20.209l-7.62,1.8022-7.0288-2.8838a1.99,1.99,0,0,0-2.022.37L4,25.8359v-4.455l8.375-9.4,7.0186,5.62a2.0155,2.0155,0,0,0,2.0459.2119L28,14.6025ZM12.5239,5.9849l7.03,3.8042a2.012,2.012,0,0,0,1.3408.16L28,8.2646v4.1138L20.6187,16.02,13.6,10.4a1.99,1.99,0,0,0-2.6885.2642L4,18.3838v-5.87ZM4.5513,28,12.62,20.9888l7.0288,2.8838a1.9977,1.9977,0,0,0,1.147.0771L28,22.2612V28Z"
  })), children);
});
var ChartArea16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartArea16(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.4761,8.0151,13.4473,4.2109a2.0076,2.0076,0,0,0-2.1158.2051L4,10.001V2H2V28a2,2,0,0,0,2,2H30V5.7354ZM28,20.209l-7.62,1.8022-7.0288-2.8838a1.99,1.99,0,0,0-2.022.37L4,25.8359v-4.455l8.375-9.4,7.0186,5.62a2.0155,2.0155,0,0,0,2.0459.2119L28,14.6025ZM12.5239,5.9849l7.03,3.8042a2.012,2.012,0,0,0,1.3408.16L28,8.2646v4.1138L20.6187,16.02,13.6,10.4a1.99,1.99,0,0,0-2.6885.2642L4,18.3838v-5.87ZM4.5513,28,12.62,20.9888l7.0288,2.8838a1.9977,1.9977,0,0,0,1.147.0771L28,22.2612V28Z"
  })), children);
});
var ChartAreaSmooth32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartAreaSmooth32(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6.6143l-1.3152.4365A20.9218,20.9218,0,0,1,23,8c-1.7344,0-3.3225-.9072-5.0039-1.8682C16.1621,5.084,14.2656,4,12,4,9.123,4,5.9146,6.2061,4,7.772V2H2V28a2.0025,2.0025,0,0,0,2,2H30ZM4,20.2944C5.874,17.3765,9.56,13,12,13c1.6379,0,2.96,1.1016,4.36,2.2686C17.8965,16.5488,19.6379,18,22,18a9.4686,9.4686,0,0,0,6-2.5288v4.9556A13.0026,13.0026,0,0,1,22,22a13.8619,13.8619,0,0,1-4.6838-.9487A15.682,15.682,0,0,0,12,20c-2.927,0-6.0676,2.959-8,5.1577ZM12,6c1.7344,0,3.3225.9072,5.0039,1.8682C18.8379,8.916,20.7344,10,23,10a21.432,21.432,0,0,0,5-.6782v3.3213C27.3167,13.4463,24.9155,16,22,16c-1.6379,0-2.96-1.1016-4.36-2.2686C16.1035,12.4512,14.3621,11,12,11c-2.9358,0-6.0632,3.3394-8,5.8447V10.4238C5.5461,8.9658,9.2588,6,12,6ZM4.249,28C5.8623,25.9087,9.41,22,12,22a13.8619,13.8619,0,0,1,4.6838.9487A15.682,15.682,0,0,0,22,24a14.7362,14.7362,0,0,0,6-1.34V28Z"
  })), children);
});
var ChartAreaSmooth24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartAreaSmooth24(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6.6143l-1.3152.4365A20.9218,20.9218,0,0,1,23,8c-1.7344,0-3.3225-.9072-5.0039-1.8682C16.1621,5.084,14.2656,4,12,4,9.123,4,5.9146,6.2061,4,7.772V2H2V28a2.0025,2.0025,0,0,0,2,2H30ZM4,20.2944C5.874,17.3765,9.56,13,12,13c1.6379,0,2.96,1.1016,4.36,2.2686C17.8965,16.5488,19.6379,18,22,18a9.4686,9.4686,0,0,0,6-2.5288v4.9556A13.0026,13.0026,0,0,1,22,22a13.8619,13.8619,0,0,1-4.6838-.9487A15.682,15.682,0,0,0,12,20c-2.927,0-6.0676,2.959-8,5.1577ZM12,6c1.7344,0,3.3225.9072,5.0039,1.8682C18.8379,8.916,20.7344,10,23,10a21.432,21.432,0,0,0,5-.6782v3.3213C27.3167,13.4463,24.9155,16,22,16c-1.6379,0-2.96-1.1016-4.36-2.2686C16.1035,12.4512,14.3621,11,12,11c-2.9358,0-6.0632,3.3394-8,5.8447V10.4238C5.5461,8.9658,9.2588,6,12,6ZM4.249,28C5.8623,25.9087,9.41,22,12,22a13.8619,13.8619,0,0,1,4.6838.9487A15.682,15.682,0,0,0,22,24a14.7362,14.7362,0,0,0,6-1.34V28Z"
  })), children);
});
var ChartAreaSmooth20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartAreaSmooth20(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6.6143l-1.3152.4365A20.9218,20.9218,0,0,1,23,8c-1.7344,0-3.3225-.9072-5.0039-1.8682C16.1621,5.084,14.2656,4,12,4,9.123,4,5.9146,6.2061,4,7.772V2H2V28a2.0025,2.0025,0,0,0,2,2H30ZM4,20.2944C5.874,17.3765,9.56,13,12,13c1.6379,0,2.96,1.1016,4.36,2.2686C17.8965,16.5488,19.6379,18,22,18a9.4686,9.4686,0,0,0,6-2.5288v4.9556A13.0026,13.0026,0,0,1,22,22a13.8619,13.8619,0,0,1-4.6838-.9487A15.682,15.682,0,0,0,12,20c-2.927,0-6.0676,2.959-8,5.1577ZM12,6c1.7344,0,3.3225.9072,5.0039,1.8682C18.8379,8.916,20.7344,10,23,10a21.432,21.432,0,0,0,5-.6782v3.3213C27.3167,13.4463,24.9155,16,22,16c-1.6379,0-2.96-1.1016-4.36-2.2686C16.1035,12.4512,14.3621,11,12,11c-2.9358,0-6.0632,3.3394-8,5.8447V10.4238C5.5461,8.9658,9.2588,6,12,6ZM4.249,28C5.8623,25.9087,9.41,22,12,22a13.8619,13.8619,0,0,1,4.6838.9487A15.682,15.682,0,0,0,22,24a14.7362,14.7362,0,0,0,6-1.34V28Z"
  })), children);
});
var ChartAreaSmooth16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartAreaSmooth16(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6.6143l-1.3152.4365A20.9218,20.9218,0,0,1,23,8c-1.7344,0-3.3225-.9072-5.0039-1.8682C16.1621,5.084,14.2656,4,12,4,9.123,4,5.9146,6.2061,4,7.772V2H2V28a2.0025,2.0025,0,0,0,2,2H30ZM4,20.2944C5.874,17.3765,9.56,13,12,13c1.6379,0,2.96,1.1016,4.36,2.2686C17.8965,16.5488,19.6379,18,22,18a9.4686,9.4686,0,0,0,6-2.5288v4.9556A13.0026,13.0026,0,0,1,22,22a13.8619,13.8619,0,0,1-4.6838-.9487A15.682,15.682,0,0,0,12,20c-2.927,0-6.0676,2.959-8,5.1577ZM12,6c1.7344,0,3.3225.9072,5.0039,1.8682C18.8379,8.916,20.7344,10,23,10a21.432,21.432,0,0,0,5-.6782v3.3213C27.3167,13.4463,24.9155,16,22,16c-1.6379,0-2.96-1.1016-4.36-2.2686C16.1035,12.4512,14.3621,11,12,11c-2.9358,0-6.0632,3.3394-8,5.8447V10.4238C5.5461,8.9658,9.2588,6,12,6ZM4.249,28C5.8623,25.9087,9.41,22,12,22a13.8619,13.8619,0,0,1,4.6838.9487A15.682,15.682,0,0,0,22,24a14.7362,14.7362,0,0,0,6-1.34V28Z"
  })), children);
});
var ChartAreaStepper32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartAreaStepper32(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,10V6H10v6H4V2H2V28a2.0025,2.0025,0,0,0,2,2H30V10ZM12,14V8h8v4h8V22H22V16H12v6H4V14ZM4,28V24H14V18h6v6h8v4Z"
  })), children);
});
var ChartAreaStepper24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartAreaStepper24(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,10V6H10v6H4V2H2V28a2.0025,2.0025,0,0,0,2,2H30V10ZM12,14V8h8v4h8V22H22V16H12v6H4V14ZM4,28V24H14V18h6v6h8v4Z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-30.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-30.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "QX16": () => (/* binding */ QX16),
/* harmony export */   "QX20": () => (/* binding */ QX20),
/* harmony export */   "QX24": () => (/* binding */ QX24),
/* harmony export */   "QX32": () => (/* binding */ QX32),
/* harmony export */   "QY16": () => (/* binding */ QY16),
/* harmony export */   "QY20": () => (/* binding */ QY20),
/* harmony export */   "QY24": () => (/* binding */ QY24),
/* harmony export */   "QY32": () => (/* binding */ QY32),
/* harmony export */   "QZ16": () => (/* binding */ QZ16),
/* harmony export */   "QZ20": () => (/* binding */ QZ20),
/* harmony export */   "QZ24": () => (/* binding */ QZ24),
/* harmony export */   "QZ32": () => (/* binding */ QZ32),
/* harmony export */   "WarningHexFilled16": () => (/* binding */ WarningHexFilled16),
/* harmony export */   "WarningHexFilled20": () => (/* binding */ WarningHexFilled20),
/* harmony export */   "WarningOther16": () => (/* binding */ WarningOther16),
/* harmony export */   "WarningOther20": () => (/* binding */ WarningOther20),
/* harmony export */   "WarningOther24": () => (/* binding */ WarningOther24),
/* harmony export */   "WarningOther32": () => (/* binding */ WarningOther32),
/* harmony export */   "WarningSquare16": () => (/* binding */ WarningSquare16),
/* harmony export */   "WarningSquare20": () => (/* binding */ WarningSquare20),
/* harmony export */   "WarningSquare24": () => (/* binding */ WarningSquare24),
/* harmony export */   "WarningSquare32": () => (/* binding */ WarningSquare32),
/* harmony export */   "WarningSquareFilled16": () => (/* binding */ WarningSquareFilled16),
/* harmony export */   "WarningSquareFilled20": () => (/* binding */ WarningSquareFilled20),
/* harmony export */   "WarningSquareFilled24": () => (/* binding */ WarningSquareFilled24),
/* harmony export */   "WarningSquareFilled32": () => (/* binding */ WarningSquareFilled32),
/* harmony export */   "Watch16": () => (/* binding */ Watch16),
/* harmony export */   "Watch20": () => (/* binding */ Watch20),
/* harmony export */   "Watch24": () => (/* binding */ Watch24),
/* harmony export */   "Watch32": () => (/* binding */ Watch32),
/* harmony export */   "Watson16": () => (/* binding */ Watson16),
/* harmony export */   "Watson20": () => (/* binding */ Watson20),
/* harmony export */   "Watson24": () => (/* binding */ Watson24),
/* harmony export */   "Watson32": () => (/* binding */ Watson32),
/* harmony export */   "WatsonHealthWindowAuto16": () => (/* binding */ WatsonHealthWindowAuto16),
/* harmony export */   "WatsonHealthWindowAuto20": () => (/* binding */ WatsonHealthWindowAuto20),
/* harmony export */   "WatsonHealthWindowAuto24": () => (/* binding */ WatsonHealthWindowAuto24),
/* harmony export */   "WatsonHealthWindowAuto32": () => (/* binding */ WatsonHealthWindowAuto32),
/* harmony export */   "WatsonHealthWindowBase16": () => (/* binding */ WatsonHealthWindowBase16),
/* harmony export */   "WatsonHealthWindowBase20": () => (/* binding */ WatsonHealthWindowBase20),
/* harmony export */   "WatsonHealthWindowBase24": () => (/* binding */ WatsonHealthWindowBase24),
/* harmony export */   "WatsonHealthWindowBase32": () => (/* binding */ WatsonHealthWindowBase32),
/* harmony export */   "WatsonHealthWindowBlackSaturation16": () => (/* binding */ WatsonHealthWindowBlackSaturation16),
/* harmony export */   "WatsonHealthWindowBlackSaturation20": () => (/* binding */ WatsonHealthWindowBlackSaturation20),
/* harmony export */   "WatsonHealthWindowBlackSaturation24": () => (/* binding */ WatsonHealthWindowBlackSaturation24),
/* harmony export */   "WatsonHealthWindowBlackSaturation32": () => (/* binding */ WatsonHealthWindowBlackSaturation32),
/* harmony export */   "WatsonHealthWindowOverlay16": () => (/* binding */ WatsonHealthWindowOverlay16),
/* harmony export */   "WatsonHealthWindowOverlay20": () => (/* binding */ WatsonHealthWindowOverlay20),
/* harmony export */   "WatsonHealthWindowOverlay24": () => (/* binding */ WatsonHealthWindowOverlay24),
/* harmony export */   "WatsonHealthWindowOverlay32": () => (/* binding */ WatsonHealthWindowOverlay32),
/* harmony export */   "WatsonHealthWindowPreset16": () => (/* binding */ WatsonHealthWindowPreset16),
/* harmony export */   "WatsonHealthWindowPreset20": () => (/* binding */ WatsonHealthWindowPreset20),
/* harmony export */   "WatsonHealthWindowPreset24": () => (/* binding */ WatsonHealthWindowPreset24),
/* harmony export */   "WatsonHealthWindowPreset32": () => (/* binding */ WatsonHealthWindowPreset32),
/* harmony export */   "WatsonMachineLearning16": () => (/* binding */ WatsonMachineLearning16),
/* harmony export */   "WatsonMachineLearning20": () => (/* binding */ WatsonMachineLearning20),
/* harmony export */   "WatsonMachineLearning24": () => (/* binding */ WatsonMachineLearning24),
/* harmony export */   "WatsonMachineLearning32": () => (/* binding */ WatsonMachineLearning32),
/* harmony export */   "WaveDirection16": () => (/* binding */ WaveDirection16),
/* harmony export */   "WaveDirection20": () => (/* binding */ WaveDirection20),
/* harmony export */   "WaveDirection24": () => (/* binding */ WaveDirection24),
/* harmony export */   "WaveDirection32": () => (/* binding */ WaveDirection32),
/* harmony export */   "WaveHeight16": () => (/* binding */ WaveHeight16),
/* harmony export */   "WaveHeight20": () => (/* binding */ WaveHeight20),
/* harmony export */   "WaveHeight24": () => (/* binding */ WaveHeight24),
/* harmony export */   "WaveHeight32": () => (/* binding */ WaveHeight32),
/* harmony export */   "WavePeriod16": () => (/* binding */ WavePeriod16),
/* harmony export */   "WavePeriod20": () => (/* binding */ WavePeriod20),
/* harmony export */   "WavePeriod24": () => (/* binding */ WavePeriod24),
/* harmony export */   "WavePeriod32": () => (/* binding */ WavePeriod32),
/* harmony export */   "WeatherFrontCold16": () => (/* binding */ WeatherFrontCold16),
/* harmony export */   "WeatherFrontCold20": () => (/* binding */ WeatherFrontCold20),
/* harmony export */   "WeatherFrontCold24": () => (/* binding */ WeatherFrontCold24),
/* harmony export */   "WeatherFrontCold32": () => (/* binding */ WeatherFrontCold32),
/* harmony export */   "WeatherFrontStationary16": () => (/* binding */ WeatherFrontStationary16),
/* harmony export */   "WeatherFrontStationary20": () => (/* binding */ WeatherFrontStationary20),
/* harmony export */   "WeatherFrontStationary24": () => (/* binding */ WeatherFrontStationary24),
/* harmony export */   "WeatherFrontStationary32": () => (/* binding */ WeatherFrontStationary32),
/* harmony export */   "WeatherFrontWarm16": () => (/* binding */ WeatherFrontWarm16),
/* harmony export */   "WeatherFrontWarm20": () => (/* binding */ WeatherFrontWarm20),
/* harmony export */   "WeatherFrontWarm24": () => (/* binding */ WeatherFrontWarm24),
/* harmony export */   "WeatherFrontWarm32": () => (/* binding */ WeatherFrontWarm32),
/* harmony export */   "WeatherStation16": () => (/* binding */ WeatherStation16),
/* harmony export */   "WeatherStation20": () => (/* binding */ WeatherStation20),
/* harmony export */   "WeatherStation24": () => (/* binding */ WeatherStation24),
/* harmony export */   "WeatherStation32": () => (/* binding */ WeatherStation32),
/* harmony export */   "Webhook16": () => (/* binding */ Webhook16),
/* harmony export */   "Webhook20": () => (/* binding */ Webhook20),
/* harmony export */   "Webhook24": () => (/* binding */ Webhook24),
/* harmony export */   "Webhook32": () => (/* binding */ Webhook32),
/* harmony export */   "Websheet16": () => (/* binding */ Websheet16),
/* harmony export */   "Websheet20": () => (/* binding */ Websheet20),
/* harmony export */   "Websheet24": () => (/* binding */ Websheet24),
/* harmony export */   "Websheet32": () => (/* binding */ Websheet32),
/* harmony export */   "Wheat16": () => (/* binding */ Wheat16),
/* harmony export */   "Wheat20": () => (/* binding */ Wheat20),
/* harmony export */   "Wheat24": () => (/* binding */ Wheat24),
/* harmony export */   "Wheat32": () => (/* binding */ Wheat32),
/* harmony export */   "Wifi16": () => (/* binding */ Wifi16),
/* harmony export */   "Wifi20": () => (/* binding */ Wifi20),
/* harmony export */   "Wifi24": () => (/* binding */ Wifi24),
/* harmony export */   "Wifi32": () => (/* binding */ Wifi32),
/* harmony export */   "WifiBridge16": () => (/* binding */ WifiBridge16),
/* harmony export */   "WifiBridge20": () => (/* binding */ WifiBridge20),
/* harmony export */   "WifiBridge24": () => (/* binding */ WifiBridge24),
/* harmony export */   "WifiBridge32": () => (/* binding */ WifiBridge32),
/* harmony export */   "WifiBridgeAlt16": () => (/* binding */ WifiBridgeAlt16),
/* harmony export */   "WifiBridgeAlt20": () => (/* binding */ WifiBridgeAlt20),
/* harmony export */   "WifiBridgeAlt24": () => (/* binding */ WifiBridgeAlt24),
/* harmony export */   "WifiBridgeAlt32": () => (/* binding */ WifiBridgeAlt32),
/* harmony export */   "WifiController16": () => (/* binding */ WifiController16),
/* harmony export */   "WifiController20": () => (/* binding */ WifiController20),
/* harmony export */   "WifiController24": () => (/* binding */ WifiController24),
/* harmony export */   "WifiController32": () => (/* binding */ WifiController32),
/* harmony export */   "WifiNotSecure16": () => (/* binding */ WifiNotSecure16),
/* harmony export */   "WifiNotSecure20": () => (/* binding */ WifiNotSecure20),
/* harmony export */   "WifiNotSecure24": () => (/* binding */ WifiNotSecure24),
/* harmony export */   "WifiNotSecure32": () => (/* binding */ WifiNotSecure32),
/* harmony export */   "WifiOff16": () => (/* binding */ WifiOff16),
/* harmony export */   "WifiOff20": () => (/* binding */ WifiOff20),
/* harmony export */   "WifiOff24": () => (/* binding */ WifiOff24),
/* harmony export */   "WifiOff32": () => (/* binding */ WifiOff32),
/* harmony export */   "WifiSecure16": () => (/* binding */ WifiSecure16),
/* harmony export */   "WifiSecure20": () => (/* binding */ WifiSecure20),
/* harmony export */   "WifiSecure24": () => (/* binding */ WifiSecure24),
/* harmony export */   "WifiSecure32": () => (/* binding */ WifiSecure32),
/* harmony export */   "Wikis16": () => (/* binding */ Wikis16),
/* harmony export */   "Wikis20": () => (/* binding */ Wikis20),
/* harmony export */   "Wikis24": () => (/* binding */ Wikis24),
/* harmony export */   "Wikis32": () => (/* binding */ Wikis32),
/* harmony export */   "WindGusts16": () => (/* binding */ WindGusts16),
/* harmony export */   "WindGusts20": () => (/* binding */ WindGusts20),
/* harmony export */   "WindGusts24": () => (/* binding */ WindGusts24),
/* harmony export */   "WindGusts32": () => (/* binding */ WindGusts32),
/* harmony export */   "WindPower16": () => (/* binding */ WindPower16),
/* harmony export */   "WindPower20": () => (/* binding */ WindPower20),
/* harmony export */   "WindPower24": () => (/* binding */ WindPower24),
/* harmony export */   "WindPower32": () => (/* binding */ WindPower32),
/* harmony export */   "WindStream16": () => (/* binding */ WindStream16),
/* harmony export */   "WindStream20": () => (/* binding */ WindStream20),
/* harmony export */   "WindStream24": () => (/* binding */ WindStream24),
/* harmony export */   "WindStream32": () => (/* binding */ WindStream32),
/* harmony export */   "Windy16": () => (/* binding */ Windy16),
/* harmony export */   "Windy20": () => (/* binding */ Windy20),
/* harmony export */   "Windy24": () => (/* binding */ Windy24),
/* harmony export */   "Windy32": () => (/* binding */ Windy32),
/* harmony export */   "WindyDust16": () => (/* binding */ WindyDust16),
/* harmony export */   "WindyDust20": () => (/* binding */ WindyDust20),
/* harmony export */   "WindyDust24": () => (/* binding */ WindyDust24),
/* harmony export */   "WindyDust32": () => (/* binding */ WindyDust32),
/* harmony export */   "WindySnow16": () => (/* binding */ WindySnow16),
/* harmony export */   "WindySnow20": () => (/* binding */ WindySnow20),
/* harmony export */   "WindySnow24": () => (/* binding */ WindySnow24),
/* harmony export */   "WindySnow32": () => (/* binding */ WindySnow32),
/* harmony export */   "WindyStrong16": () => (/* binding */ WindyStrong16),
/* harmony export */   "WindyStrong20": () => (/* binding */ WindyStrong20),
/* harmony export */   "WindyStrong24": () => (/* binding */ WindyStrong24),
/* harmony export */   "WindyStrong32": () => (/* binding */ WindyStrong32),
/* harmony export */   "WinterWarning16": () => (/* binding */ WinterWarning16),
/* harmony export */   "WinterWarning20": () => (/* binding */ WinterWarning20),
/* harmony export */   "WinterWarning24": () => (/* binding */ WinterWarning24),
/* harmony export */   "WinterWarning32": () => (/* binding */ WinterWarning32),
/* harmony export */   "WintryMix16": () => (/* binding */ WintryMix16),
/* harmony export */   "WintryMix20": () => (/* binding */ WintryMix20),
/* harmony export */   "WintryMix24": () => (/* binding */ WintryMix24),
/* harmony export */   "WintryMix32": () => (/* binding */ WintryMix32),
/* harmony export */   "WirelessCheckout16": () => (/* binding */ WirelessCheckout16),
/* harmony export */   "WirelessCheckout20": () => (/* binding */ WirelessCheckout20),
/* harmony export */   "WirelessCheckout24": () => (/* binding */ WirelessCheckout24),
/* harmony export */   "WirelessCheckout32": () => (/* binding */ WirelessCheckout32),
/* harmony export */   "Wmv16": () => (/* binding */ Wmv16),
/* harmony export */   "Wmv20": () => (/* binding */ Wmv20),
/* harmony export */   "Wmv24": () => (/* binding */ Wmv24),
/* harmony export */   "Wmv32": () => (/* binding */ Wmv32),
/* harmony export */   "WordCloud16": () => (/* binding */ WordCloud16),
/* harmony export */   "WordCloud20": () => (/* binding */ WordCloud20),
/* harmony export */   "WordCloud24": () => (/* binding */ WordCloud24),
/* harmony export */   "WordCloud32": () => (/* binding */ WordCloud32),
/* harmony export */   "Workspace16": () => (/* binding */ Workspace16),
/* harmony export */   "Workspace20": () => (/* binding */ Workspace20),
/* harmony export */   "Workspace24": () => (/* binding */ Workspace24),
/* harmony export */   "Workspace32": () => (/* binding */ Workspace32),
/* harmony export */   "WorkspaceImport16": () => (/* binding */ WorkspaceImport16),
/* harmony export */   "WorkspaceImport20": () => (/* binding */ WorkspaceImport20),
/* harmony export */   "WorkspaceImport24": () => (/* binding */ WorkspaceImport24),
/* harmony export */   "WorkspaceImport32": () => (/* binding */ WorkspaceImport32),
/* harmony export */   "Worship16": () => (/* binding */ Worship16),
/* harmony export */   "Worship20": () => (/* binding */ Worship20),
/* harmony export */   "Worship24": () => (/* binding */ Worship24),
/* harmony export */   "Worship32": () => (/* binding */ Worship32),
/* harmony export */   "WorshipChristian16": () => (/* binding */ WorshipChristian16),
/* harmony export */   "WorshipChristian20": () => (/* binding */ WorshipChristian20),
/* harmony export */   "WorshipChristian24": () => (/* binding */ WorshipChristian24),
/* harmony export */   "WorshipChristian32": () => (/* binding */ WorshipChristian32),
/* harmony export */   "WorshipJewish16": () => (/* binding */ WorshipJewish16),
/* harmony export */   "WorshipJewish20": () => (/* binding */ WorshipJewish20),
/* harmony export */   "WorshipJewish24": () => (/* binding */ WorshipJewish24),
/* harmony export */   "WorshipJewish32": () => (/* binding */ WorshipJewish32),
/* harmony export */   "WorshipMuslim16": () => (/* binding */ WorshipMuslim16),
/* harmony export */   "WorshipMuslim20": () => (/* binding */ WorshipMuslim20),
/* harmony export */   "WorshipMuslim24": () => (/* binding */ WorshipMuslim24),
/* harmony export */   "WorshipMuslim32": () => (/* binding */ WorshipMuslim32),
/* harmony export */   "XAxis16": () => (/* binding */ XAxis16),
/* harmony export */   "XAxis20": () => (/* binding */ XAxis20),
/* harmony export */   "XAxis24": () => (/* binding */ XAxis24),
/* harmony export */   "XAxis32": () => (/* binding */ XAxis32),
/* harmony export */   "Xls16": () => (/* binding */ Xls16),
/* harmony export */   "Xls20": () => (/* binding */ Xls20),
/* harmony export */   "Xls24": () => (/* binding */ Xls24),
/* harmony export */   "Xls32": () => (/* binding */ Xls32),
/* harmony export */   "Xml16": () => (/* binding */ Xml16),
/* harmony export */   "Xml20": () => (/* binding */ Xml20),
/* harmony export */   "Xml24": () => (/* binding */ Xml24),
/* harmony export */   "Xml32": () => (/* binding */ Xml32),
/* harmony export */   "YAxis16": () => (/* binding */ YAxis16),
/* harmony export */   "YAxis20": () => (/* binding */ YAxis20),
/* harmony export */   "YAxis24": () => (/* binding */ YAxis24),
/* harmony export */   "YAxis32": () => (/* binding */ YAxis32),
/* harmony export */   "ZAxis16": () => (/* binding */ ZAxis16),
/* harmony export */   "ZAxis20": () => (/* binding */ ZAxis20),
/* harmony export */   "ZAxis24": () => (/* binding */ ZAxis24),
/* harmony export */   "ZAxis32": () => (/* binding */ ZAxis32),
/* harmony export */   "Zip16": () => (/* binding */ Zip16),
/* harmony export */   "Zip20": () => (/* binding */ Zip20),
/* harmony export */   "Zip24": () => (/* binding */ Zip24),
/* harmony export */   "Zip32": () => (/* binding */ Zip32),
/* harmony export */   "ZipReference16": () => (/* binding */ ZipReference16),
/* harmony export */   "ZipReference20": () => (/* binding */ ZipReference20),
/* harmony export */   "ZipReference24": () => (/* binding */ ZipReference24),
/* harmony export */   "ZipReference32": () => (/* binding */ ZipReference32),
/* harmony export */   "ZoomArea16": () => (/* binding */ ZoomArea16),
/* harmony export */   "ZoomArea20": () => (/* binding */ ZoomArea20),
/* harmony export */   "ZoomArea24": () => (/* binding */ ZoomArea24),
/* harmony export */   "ZoomArea32": () => (/* binding */ ZoomArea32),
/* harmony export */   "ZoomFit16": () => (/* binding */ ZoomFit16),
/* harmony export */   "ZoomFit20": () => (/* binding */ ZoomFit20),
/* harmony export */   "ZoomFit24": () => (/* binding */ ZoomFit24),
/* harmony export */   "ZoomFit32": () => (/* binding */ ZoomFit32),
/* harmony export */   "ZoomIn16": () => (/* binding */ ZoomIn16),
/* harmony export */   "ZoomIn20": () => (/* binding */ ZoomIn20),
/* harmony export */   "ZoomIn24": () => (/* binding */ ZoomIn24),
/* harmony export */   "ZoomIn32": () => (/* binding */ ZoomIn32),
/* harmony export */   "ZoomInArea16": () => (/* binding */ ZoomInArea16),
/* harmony export */   "ZoomInArea20": () => (/* binding */ ZoomInArea20),
/* harmony export */   "ZoomInArea24": () => (/* binding */ ZoomInArea24),
/* harmony export */   "ZoomInArea32": () => (/* binding */ ZoomInArea32),
/* harmony export */   "ZoomOut16": () => (/* binding */ ZoomOut16),
/* harmony export */   "ZoomOut20": () => (/* binding */ ZoomOut20),
/* harmony export */   "ZoomOut24": () => (/* binding */ ZoomOut24),
/* harmony export */   "ZoomOut32": () => (/* binding */ ZoomOut32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _circle, _path43, _path44, _path45, _circle2, _path46, _path47, _path48, _circle3, _path49, _path50, _path51, _circle4, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _path65, _path66, _path67, _path68, _path69, _path70, _path71, _path72, _path73, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _circle5, _path105, _path106, _circle6, _path107, _path108, _circle7, _path109, _path110, _circle8, _path111, _path112, _path113, _path114, _path115, _path116, _circle9, _path117, _path118, _path119, _circle10, _path120, _path121, _path122, _circle11, _path123, _path124, _path125, _circle12, _path126, _path127, _path128, _path129, _circle13, _circle14, _path130, _path131, _path132, _circle15, _circle16, _path133, _path134, _path135, _circle17, _circle18, _path136, _path137, _path138, _circle19, _circle20, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _circle21, _path149, _circle22, _path150, _circle23, _path151, _circle24, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _path224, _path225, _path226, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388, _path389, _path390, _path391, _path392, _path393, _path394, _path395, _path396, _path397, _path398, _path399, _path400, _path401, _path402, _path403, _path404, _path405, _path406, _path407, _path408, _path409, _path410, _path411, _path412, _path413, _path414, _path415, _path416, _path417, _path418, _path419, _path420, _path421, _path422, _path423, _path424, _path425, _path426, _path427, _path428, _path429, _path430, _path431, _path432, _path433, _path434, _path435, _path436, _path437, _path438, _path439, _path440, _path441, _path442, _path443, _path444, _path445, _path446, _path447, _path448, _path449, _path450, _path451, _path452, _path453, _path454, _path455, _path456, _path457, _path458, _path459, _path460, _path461, _path462, _path463, _path464, _path465, _path466, _path467, _path468, _path469, _path470, _path471, _path472, _path473, _path474, _path475, _path476, _path477, _path478, _path479, _path480, _path481, _path482, _path483, _path484, _path485, _path486, _path487, _path488, _path489, _path490, _path491, _path492, _path493, _path494, _path495, _path496, _path497, _path498, _path499, _path500, _path501, _path502, _path503, _path504, _path505, _path506, _path507, _path508, _path509, _path510, _path511, _path512, _path513, _path514, _path515, _path516, _path517, _path518, _path519, _path520;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var WarningHexFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningHexFilled20(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M14.875,8h2.25V19h-2.25ZM16,25a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,25Z",
    "data-icon-path": "inner-path"
  })), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.8508,15.4487,23.8867,3.5322A1.0687,1.0687,0,0,0,22.9643,3H9.0357a1.0687,1.0687,0,0,0-.9224.5322L1.1492,15.4487a1.0933,1.0933,0,0,0,0,1.1026L8.1133,28.4678A1.0687,1.0687,0,0,0,9.0357,29H22.9643a1.0687,1.0687,0,0,0,.9224-.5322l6.9641-11.9165A1.0933,1.0933,0,0,0,30.8508,15.4487ZM14.875,8h2.25V19h-2.25ZM16,25a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,25Z"
  })), children);
});
var WarningHexFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningHexFilled16(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M14.875,8h2.25V19h-2.25ZM16,25a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,25Z",
    "data-icon-path": "inner-path"
  })), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.8508,15.4487,23.8867,3.5322A1.0687,1.0687,0,0,0,22.9643,3H9.0357a1.0687,1.0687,0,0,0-.9224.5322L1.1492,15.4487a1.0933,1.0933,0,0,0,0,1.1026L8.1133,28.4678A1.0687,1.0687,0,0,0,9.0357,29H22.9643a1.0687,1.0687,0,0,0,.9224-.5322l6.9641-11.9165A1.0933,1.0933,0,0,0,30.8508,15.4487ZM14.875,8h2.25V19h-2.25ZM16,25a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,25Z"
  })), children);
});
var WarningOther32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningOther32(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 20H30V22H18zM18 24H30V26H18zM18 28H30V30H18zM14 18a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0014 18zM13 7H15V16H13z"
  })), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,4A10.0111,10.0111,0,0,1,24,14h2A12,12,0,1,0,14,26V24A10,10,0,0,1,14,4Z"
  })), children);
});
var WarningOther24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningOther24(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 20H30V22H18zM18 24H30V26H18zM18 28H30V30H18zM14 18a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0014 18zM13 7H15V16H13z"
  })), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,4A10.0111,10.0111,0,0,1,24,14h2A12,12,0,1,0,14,26V24A10,10,0,0,1,14,4Z"
  })), children);
});
var WarningOther20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningOther20(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 20H30V22H18zM18 24H30V26H18zM18 28H30V30H18zM14 18a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0014 18zM13 7H15V16H13z"
  })), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,4A10.0111,10.0111,0,0,1,24,14h2A12,12,0,1,0,14,26V24A10,10,0,0,1,14,4Z"
  })), children);
});
var WarningOther16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningOther16(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 20H30V22H18zM18 24H30V26H18zM18 28H30V30H18zM14 18a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0014 18zM13 7H15V16H13z"
  })), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,4A10.0111,10.0111,0,0,1,24,14h2A12,12,0,1,0,14,26V24A10,10,0,0,1,14,4Z"
  })), children);
});
var WarningSquare32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningSquare32(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 20a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 20zM15 9H17V18H15z"
  })), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,6,4H26a2.0023,2.0023,0,0,1,2,2V26A2.0023,2.0023,0,0,1,26,28ZM6,6V26H26.0012L26,6Z"
  })), children);
});
var WarningSquare24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningSquare24(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 20a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 20zM15 9H17V18H15z"
  })), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,6,4H26a2.0023,2.0023,0,0,1,2,2V26A2.0023,2.0023,0,0,1,26,28ZM6,6V26H26.0012L26,6Z"
  })), children);
});
var WarningSquare20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningSquare20(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 20a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 20zM15 9H17V18H15z"
  })), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,6,4H26a2.0023,2.0023,0,0,1,2,2V26A2.0023,2.0023,0,0,1,26,28ZM6,6V26H26.0012L26,6Z"
  })), children);
});
var WarningSquare16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningSquare16(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 20a1.5 1.5 0 101.5 1.5A1.5 1.5 0 0016 20zM15 9H17V18H15z"
  })), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,6,4H26a2.0023,2.0023,0,0,1,2,2V26A2.0023,2.0023,0,0,1,26,28ZM6,6V26H26.0012L26,6Z"
  })), children);
});
var WarningSquareFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningSquareFilled32(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.0022,4H5.998A1.998,1.998,0,0,0,4,5.998V26.002A1.998,1.998,0,0,0,5.998,28H26.0022A1.9979,1.9979,0,0,0,28,26.002V5.998A1.9979,1.9979,0,0,0,26.0022,4ZM14.8752,8h2.25V18h-2.25ZM16,24a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,24Z"
  })), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M14.8751,8h2.25V18h-2.25ZM16,24a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,24Z",
    "data-icon-path": "inner-path"
  })), children);
});
var WarningSquareFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningSquareFilled24(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.0022,4H5.998A1.998,1.998,0,0,0,4,5.998V26.002A1.998,1.998,0,0,0,5.998,28H26.0022A1.9979,1.9979,0,0,0,28,26.002V5.998A1.9979,1.9979,0,0,0,26.0022,4ZM14.8752,8h2.25V18h-2.25ZM16,24a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,24Z"
  })), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M14.8751,8h2.25V18h-2.25ZM16,24a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,24Z",
    "data-icon-path": "inner-path"
  })), children);
});
var WarningSquareFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningSquareFilled20(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.0022,4H5.998A1.998,1.998,0,0,0,4,5.998V26.002A1.998,1.998,0,0,0,5.998,28H26.0022A1.9979,1.9979,0,0,0,28,26.002V5.998A1.9979,1.9979,0,0,0,26.0022,4ZM14.8752,8h2.25V18h-2.25ZM16,24a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,24Z"
  })), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M14.8751,8h2.25V18h-2.25ZM16,24a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,24Z",
    "data-icon-path": "inner-path"
  })), children);
});
var WarningSquareFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WarningSquareFilled16(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.0022,4H5.998A1.998,1.998,0,0,0,4,5.998V26.002A1.998,1.998,0,0,0,5.998,28H26.0022A1.9979,1.9979,0,0,0,28,26.002V5.998A1.9979,1.9979,0,0,0,26.0022,4ZM14.8752,8h2.25V18h-2.25ZM16,24a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,24Z"
  })), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M14.8751,8h2.25V18h-2.25ZM16,24a1.5,1.5,0,1,1,1.5-1.5A1.5,1.5,0,0,1,16,24Z",
    "data-icon-path": "inner-path"
  })), children);
});
var Watch32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Watch32(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 8H21V2H19V8H13V2H11V8H10a2 2 0 00-2 2V22a2 2 0 002 2h1v6h2V24h6v6h2V24h1a2 2 0 002-2V10A2 2 0 0022 8zM10 22V10H22V22zM25 14H27V18H25z"
  })), children);
});
var Watch24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Watch24(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 8H21V2H19V8H13V2H11V8H10a2 2 0 00-2 2V22a2 2 0 002 2h1v6h2V24h6v6h2V24h1a2 2 0 002-2V10A2 2 0 0022 8zM10 22V10H22V22zM25 14H27V18H25z"
  })), children);
});
var Watch20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Watch20(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 8H21V2H19V8H13V2H11V8H10a2 2 0 00-2 2V22a2 2 0 002 2h1v6h2V24h6v6h2V24h1a2 2 0 002-2V10A2 2 0 0022 8zM10 22V10H22V22zM25 14H27V18H25z"
  })), children);
});
var Watch16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Watch16(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 8H21V2H19V8H13V2H11V8H10a2 2 0 00-2 2V22a2 2 0 002 2h1v6h2V24h6v6h2V24h1a2 2 0 002-2V10A2 2 0 0022 8zM10 22V10H22V22zM25 14H27V18H25z"
  })), children);
});
var Watson32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Watson32(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.74 9.49h0A11.41 11.41 0 0016 8h0a.76.76 0 100 1.51 10.15 10.15 0 011.91.21c-2.26 1.08-4.76 3.58-6.73 7a22.48 22.48 0 00-2 4.44A9.58 9.58 0 017 17.22a3.43 3.43 0 01.28-2.66v0h0c.79-1.37 2.44-2.15 4.63-2.2a.76.76 0 00.74-.78.75.75 0 00-.78-.74C9.19 10.88 7.1 11.92 6 13.74H6v0s0 0 0 0a4.84 4.84 0 00-.44 3.79 12 12 0 003.2 5.22A11.36 11.36 0 008.52 26a10 10 0 01-2-3.48A.75.75 0 005.57 22a.76.76 0 00-.49 1 11.45 11.45 0 005.18 6.38h0A11.42 11.42 0 0016 30.92a11.74 11.74 0 003-.39 11.48 11.48 0 002.77-21zM18.58 29.06a9.9 9.9 0 01-7.56-1h0c-.86-.49-1.21-2-.94-4a18.85 18.85 0 002.48 1.72 13.92 13.92 0 006.93 2 11 11 0 002.42-.28A9.78 9.78 0 0118.58 29.06zm6.06-4.66c-2 2-6.66 2.74-11.32.05a17.36 17.36 0 01-2.89-2.12 21.08 21.08 0 012.08-4.91c2.94-5.08 6.83-7.57 8.47-6.62h0A10 10 0 0124.64 24.4zM4.16 11.72L1.14 10a.76.76 0 10-.76 1.31L3.4 13a.86.86 0 00.38.1.77.77 0 00.66-.38A.76.76 0 004.16 11.72zM8.29 7.59A.74.74 0 008.94 8a.75.75 0 00.38-.1.76.76 0 00.28-1l-1.74-3a.76.76 0 00-1-.27.75.75 0 00-.28 1zM16 6.08a.76.76 0 00.76-.76V1.83a.76.76 0 00-1.52 0V5.32A.76.76 0 0016 6.08zM22.68 7.87a.75.75 0 001-.28l1.75-3a.75.75 0 00-.28-1 .76.76 0 00-1 .27l-1.74 3A.76.76 0 0022.68 7.87zM31.9 10.25a.76.76 0 00-1-.27l-3 1.74a.76.76 0 00-.28 1 .77.77 0 00.66.38.86.86 0 00.38-.1l3-1.75A.76.76 0 0031.9 10.25z"
  })), children);
});
var Watson24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Watson24(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.74 9.49h0A11.41 11.41 0 0016 8h0a.76.76 0 100 1.51 10.15 10.15 0 011.91.21c-2.26 1.08-4.76 3.58-6.73 7a22.48 22.48 0 00-2 4.44A9.58 9.58 0 017 17.22a3.43 3.43 0 01.28-2.66v0h0c.79-1.37 2.44-2.15 4.63-2.2a.76.76 0 00.74-.78.75.75 0 00-.78-.74C9.19 10.88 7.1 11.92 6 13.74H6v0s0 0 0 0a4.84 4.84 0 00-.44 3.79 12 12 0 003.2 5.22A11.36 11.36 0 008.52 26a10 10 0 01-2-3.48A.75.75 0 005.57 22a.76.76 0 00-.49 1 11.45 11.45 0 005.18 6.38h0A11.42 11.42 0 0016 30.92a11.74 11.74 0 003-.39 11.48 11.48 0 002.77-21zM18.58 29.06a9.9 9.9 0 01-7.56-1h0c-.86-.49-1.21-2-.94-4a18.85 18.85 0 002.48 1.72 13.92 13.92 0 006.93 2 11 11 0 002.42-.28A9.78 9.78 0 0118.58 29.06zm6.06-4.66c-2 2-6.66 2.74-11.32.05a17.36 17.36 0 01-2.89-2.12 21.08 21.08 0 012.08-4.91c2.94-5.08 6.83-7.57 8.47-6.62h0A10 10 0 0124.64 24.4zM4.16 11.72L1.14 10a.76.76 0 10-.76 1.31L3.4 13a.86.86 0 00.38.1.77.77 0 00.66-.38A.76.76 0 004.16 11.72zM8.29 7.59A.74.74 0 008.94 8a.75.75 0 00.38-.1.76.76 0 00.28-1l-1.74-3a.76.76 0 00-1-.27.75.75 0 00-.28 1zM16 6.08a.76.76 0 00.76-.76V1.83a.76.76 0 00-1.52 0V5.32A.76.76 0 0016 6.08zM22.68 7.87a.75.75 0 001-.28l1.75-3a.75.75 0 00-.28-1 .76.76 0 00-1 .27l-1.74 3A.76.76 0 0022.68 7.87zM31.9 10.25a.76.76 0 00-1-.27l-3 1.74a.76.76 0 00-.28 1 .77.77 0 00.66.38.86.86 0 00.38-.1l3-1.75A.76.76 0 0031.9 10.25z"
  })), children);
});
var Watson20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Watson20(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.74 9.49h0A11.41 11.41 0 0016 8h0a.76.76 0 100 1.51 10.15 10.15 0 011.91.21c-2.26 1.08-4.76 3.58-6.73 7a22.48 22.48 0 00-2 4.44A9.58 9.58 0 017 17.22a3.43 3.43 0 01.28-2.66v0h0c.79-1.37 2.44-2.15 4.63-2.2a.76.76 0 00.74-.78.75.75 0 00-.78-.74C9.19 10.88 7.1 11.92 6 13.74H6v0s0 0 0 0a4.84 4.84 0 00-.44 3.79 12 12 0 003.2 5.22A11.36 11.36 0 008.52 26a10 10 0 01-2-3.48A.75.75 0 005.57 22a.76.76 0 00-.49 1 11.45 11.45 0 005.18 6.38h0A11.42 11.42 0 0016 30.92a11.74 11.74 0 003-.39 11.48 11.48 0 002.77-21zM18.58 29.06a9.9 9.9 0 01-7.56-1h0c-.86-.49-1.21-2-.94-4a18.85 18.85 0 002.48 1.72 13.92 13.92 0 006.93 2 11 11 0 002.42-.28A9.78 9.78 0 0118.58 29.06zm6.06-4.66c-2 2-6.66 2.74-11.32.05a17.36 17.36 0 01-2.89-2.12 21.08 21.08 0 012.08-4.91c2.94-5.08 6.83-7.57 8.47-6.62h0A10 10 0 0124.64 24.4zM4.16 11.72L1.14 10a.76.76 0 10-.76 1.31L3.4 13a.86.86 0 00.38.1.77.77 0 00.66-.38A.76.76 0 004.16 11.72zM8.29 7.59A.74.74 0 008.94 8a.75.75 0 00.38-.1.76.76 0 00.28-1l-1.74-3a.76.76 0 00-1-.27.75.75 0 00-.28 1zM16 6.08a.76.76 0 00.76-.76V1.83a.76.76 0 00-1.52 0V5.32A.76.76 0 0016 6.08zM22.68 7.87a.75.75 0 001-.28l1.75-3a.75.75 0 00-.28-1 .76.76 0 00-1 .27l-1.74 3A.76.76 0 0022.68 7.87zM31.9 10.25a.76.76 0 00-1-.27l-3 1.74a.76.76 0 00-.28 1 .77.77 0 00.66.38.86.86 0 00.38-.1l3-1.75A.76.76 0 0031.9 10.25z"
  })), children);
});
var Watson16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Watson16(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.74 9.49h0A11.41 11.41 0 0016 8h0a.76.76 0 100 1.51 10.15 10.15 0 011.91.21c-2.26 1.08-4.76 3.58-6.73 7a22.48 22.48 0 00-2 4.44A9.58 9.58 0 017 17.22a3.43 3.43 0 01.28-2.66v0h0c.79-1.37 2.44-2.15 4.63-2.2a.76.76 0 00.74-.78.75.75 0 00-.78-.74C9.19 10.88 7.1 11.92 6 13.74H6v0s0 0 0 0a4.84 4.84 0 00-.44 3.79 12 12 0 003.2 5.22A11.36 11.36 0 008.52 26a10 10 0 01-2-3.48A.75.75 0 005.57 22a.76.76 0 00-.49 1 11.45 11.45 0 005.18 6.38h0A11.42 11.42 0 0016 30.92a11.74 11.74 0 003-.39 11.48 11.48 0 002.77-21zM18.58 29.06a9.9 9.9 0 01-7.56-1h0c-.86-.49-1.21-2-.94-4a18.85 18.85 0 002.48 1.72 13.92 13.92 0 006.93 2 11 11 0 002.42-.28A9.78 9.78 0 0118.58 29.06zm6.06-4.66c-2 2-6.66 2.74-11.32.05a17.36 17.36 0 01-2.89-2.12 21.08 21.08 0 012.08-4.91c2.94-5.08 6.83-7.57 8.47-6.62h0A10 10 0 0124.64 24.4zM4.16 11.72L1.14 10a.76.76 0 10-.76 1.31L3.4 13a.86.86 0 00.38.1.77.77 0 00.66-.38A.76.76 0 004.16 11.72zM8.29 7.59A.74.74 0 008.94 8a.75.75 0 00.38-.1.76.76 0 00.28-1l-1.74-3a.76.76 0 00-1-.27.75.75 0 00-.28 1zM16 6.08a.76.76 0 00.76-.76V1.83a.76.76 0 00-1.52 0V5.32A.76.76 0 0016 6.08zM22.68 7.87a.75.75 0 001-.28l1.75-3a.75.75 0 00-.28-1 .76.76 0 00-1 .27l-1.74 3A.76.76 0 0022.68 7.87zM31.9 10.25a.76.76 0 00-1-.27l-3 1.74a.76.76 0 00-.28 1 .77.77 0 00.66.38.86.86 0 00.38-.1l3-1.75A.76.76 0 0031.9 10.25z"
  })), children);
});
var WatsonMachineLearning32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonMachineLearning32(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26H20V17.76l-3.23 3.88a1 1 0 01-1.54 0L12 17.76V26H10V15a1 1 0 01.66-.94 1 1 0 011.11.3L16 19.44l4.23-5.08a1 1 0 011.11-.3A1 1 0 0122 15zM4.16 14.65l-3-1.75a.76.76 0 10-.76 1.32L3.4 16a.76.76 0 10.76-1.31zM8.29 10.52a.73.73 0 001 .27.75.75 0 00.28-1l-1.74-3a.76.76 0 10-1.32.76zM16 9a.76.76 0 00.76-.76V4.76a.76.76 0 10-1.52 0V8.25A.76.76 0 0016 9zM22.68 10.79a.75.75 0 00.37.11.76.76 0 00.66-.38l1.75-3a.76.76 0 00-1.32-.76l-1.74 3A.75.75 0 0022.68 10.79zM31.9 13.18a.76.76 0 00-1-.28l-3 1.75A.76.76 0 0028.6 16l3-1.74A.77.77 0 0031.9 13.18z"
  })), children);
});
var WatsonMachineLearning24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonMachineLearning24(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26H20V17.76l-3.23 3.88a1 1 0 01-1.54 0L12 17.76V26H10V15a1 1 0 01.66-.94 1 1 0 011.11.3L16 19.44l4.23-5.08a1 1 0 011.11-.3A1 1 0 0122 15zM4.16 14.65l-3-1.75a.76.76 0 10-.76 1.32L3.4 16a.76.76 0 10.76-1.31zM8.29 10.52a.73.73 0 001 .27.75.75 0 00.28-1l-1.74-3a.76.76 0 10-1.32.76zM16 9a.76.76 0 00.76-.76V4.76a.76.76 0 10-1.52 0V8.25A.76.76 0 0016 9zM22.68 10.79a.75.75 0 00.37.11.76.76 0 00.66-.38l1.75-3a.76.76 0 00-1.32-.76l-1.74 3A.75.75 0 0022.68 10.79zM31.9 13.18a.76.76 0 00-1-.28l-3 1.75A.76.76 0 0028.6 16l3-1.74A.77.77 0 0031.9 13.18z"
  })), children);
});
var WatsonMachineLearning20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonMachineLearning20(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26H20V17.76l-3.23 3.88a1 1 0 01-1.54 0L12 17.76V26H10V15a1 1 0 01.66-.94 1 1 0 011.11.3L16 19.44l4.23-5.08a1 1 0 011.11-.3A1 1 0 0122 15zM4.16 14.65l-3-1.75a.76.76 0 10-.76 1.32L3.4 16a.76.76 0 10.76-1.31zM8.29 10.52a.73.73 0 001 .27.75.75 0 00.28-1l-1.74-3a.76.76 0 10-1.32.76zM16 9a.76.76 0 00.76-.76V4.76a.76.76 0 10-1.52 0V8.25A.76.76 0 0016 9zM22.68 10.79a.75.75 0 00.37.11.76.76 0 00.66-.38l1.75-3a.76.76 0 00-1.32-.76l-1.74 3A.75.75 0 0022.68 10.79zM31.9 13.18a.76.76 0 00-1-.28l-3 1.75A.76.76 0 0028.6 16l3-1.74A.77.77 0 0031.9 13.18z"
  })), children);
});
var WatsonMachineLearning16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonMachineLearning16(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 26H20V17.76l-3.23 3.88a1 1 0 01-1.54 0L12 17.76V26H10V15a1 1 0 01.66-.94 1 1 0 011.11.3L16 19.44l4.23-5.08a1 1 0 011.11-.3A1 1 0 0122 15zM4.16 14.65l-3-1.75a.76.76 0 10-.76 1.32L3.4 16a.76.76 0 10.76-1.31zM8.29 10.52a.73.73 0 001 .27.75.75 0 00.28-1l-1.74-3a.76.76 0 10-1.32.76zM16 9a.76.76 0 00.76-.76V4.76a.76.76 0 10-1.52 0V8.25A.76.76 0 0016 9zM22.68 10.79a.75.75 0 00.37.11.76.76 0 00.66-.38l1.75-3a.76.76 0 00-1.32-.76l-1.74 3A.75.75 0 0022.68 10.79zM31.9 13.18a.76.76 0 00-1-.28l-3 1.75A.76.76 0 0028.6 16l3-1.74A.77.77 0 0031.9 13.18z"
  })), children);
});
var WaveDirection32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WaveDirection32(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,30H17a7.0078,7.0078,0,0,1-7-7,6.6832,6.6832,0,0,1,2.0244-4.6967A6.7126,6.7126,0,0,0,10.0093,18C5.0425,18.0466,4,24.5513,4,30H2C2,18.4907,6.3452,16.0342,9.9907,16a10.0962,10.0962,0,0,1,4.4785,1.117,1,1,0,0,1,.0616,1.73A4.8773,4.8773,0,0,0,17,28h5Z"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,24V22a8,8,0,1,0-8-8H8A10,10,0,1,1,18,24Z"
  })), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18",
    cy: "8",
    r: "1"
  })), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,17.5859l-2.3-2.3007A2.9665,2.9665,0,0,0,21,14a3.0033,3.0033,0,0,0-3-3,2.9609,2.9609,0,0,0-1.2854.3008L14.4141,9,13,10.4141l2.3,2.3007A2.9665,2.9665,0,0,0,15,14a3.0033,3.0033,0,0,0,3,3,2.9609,2.9609,0,0,0,1.2854-.3008L21.5859,19ZM17,14a1,1,0,1,1,1,1A1.0009,1.0009,0,0,1,17,14Z"
  })), children);
});
var WaveDirection24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WaveDirection24(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,30H17a7.0078,7.0078,0,0,1-7-7,6.6832,6.6832,0,0,1,2.0244-4.6967A6.7126,6.7126,0,0,0,10.0093,18C5.0425,18.0466,4,24.5513,4,30H2C2,18.4907,6.3452,16.0342,9.9907,16a10.0962,10.0962,0,0,1,4.4785,1.117,1,1,0,0,1,.0616,1.73A4.8773,4.8773,0,0,0,17,28h5Z"
  })), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,24V22a8,8,0,1,0-8-8H8A10,10,0,1,1,18,24Z"
  })), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18",
    cy: "8",
    r: "1"
  })), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,17.5859l-2.3-2.3007A2.9665,2.9665,0,0,0,21,14a3.0033,3.0033,0,0,0-3-3,2.9609,2.9609,0,0,0-1.2854.3008L14.4141,9,13,10.4141l2.3,2.3007A2.9665,2.9665,0,0,0,15,14a3.0033,3.0033,0,0,0,3,3,2.9609,2.9609,0,0,0,1.2854-.3008L21.5859,19ZM17,14a1,1,0,1,1,1,1A1.0009,1.0009,0,0,1,17,14Z"
  })), children);
});
var WaveDirection20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WaveDirection20(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,30H17a7.0078,7.0078,0,0,1-7-7,6.6832,6.6832,0,0,1,2.0244-4.6967A6.7126,6.7126,0,0,0,10.0093,18C5.0425,18.0466,4,24.5513,4,30H2C2,18.4907,6.3452,16.0342,9.9907,16a10.0962,10.0962,0,0,1,4.4785,1.117,1,1,0,0,1,.0616,1.73A4.8773,4.8773,0,0,0,17,28h5Z"
  })), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,24V22a8,8,0,1,0-8-8H8A10,10,0,1,1,18,24Z"
  })), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18",
    cy: "8",
    r: "1"
  })), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,17.5859l-2.3-2.3007A2.9665,2.9665,0,0,0,21,14a3.0033,3.0033,0,0,0-3-3,2.9609,2.9609,0,0,0-1.2854.3008L14.4141,9,13,10.4141l2.3,2.3007A2.9665,2.9665,0,0,0,15,14a3.0033,3.0033,0,0,0,3,3,2.9609,2.9609,0,0,0,1.2854-.3008L21.5859,19ZM17,14a1,1,0,1,1,1,1A1.0009,1.0009,0,0,1,17,14Z"
  })), children);
});
var WaveDirection16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WaveDirection16(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,30H17a7.0078,7.0078,0,0,1-7-7,6.6832,6.6832,0,0,1,2.0244-4.6967A6.7126,6.7126,0,0,0,10.0093,18C5.0425,18.0466,4,24.5513,4,30H2C2,18.4907,6.3452,16.0342,9.9907,16a10.0962,10.0962,0,0,1,4.4785,1.117,1,1,0,0,1,.0616,1.73A4.8773,4.8773,0,0,0,17,28h5Z"
  })), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,24V22a8,8,0,1,0-8-8H8A10,10,0,1,1,18,24Z"
  })), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18",
    cy: "8",
    r: "1"
  })), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,17.5859l-2.3-2.3007A2.9665,2.9665,0,0,0,21,14a3.0033,3.0033,0,0,0-3-3,2.9609,2.9609,0,0,0-1.2854.3008L14.4141,9,13,10.4141l2.3,2.3007A2.9665,2.9665,0,0,0,15,14a3.0033,3.0033,0,0,0,3,3,2.9609,2.9609,0,0,0,1.2854-.3008L21.5859,19ZM17,14a1,1,0,1,1,1,1A1.0009,1.0009,0,0,1,17,14Z"
  })), children);
});
var WaveHeight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WaveHeight32(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 2H30V4H24zM24 8H28V10H24zM24 14H30V16H24zM24 20H28V22H24z"
  })), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,28H24a10.0349,10.0349,0,0,1-6.9268-17.2622A11.9629,11.9629,0,0,0,12.9937,10a6.9027,6.9027,0,0,0-6.0308,3.42C4.9966,16.4348,4,21.34,4,28H2c0-7.0542,1.106-12.3274,3.2871-15.6726A8.906,8.906,0,0,1,12.9937,8h.0068a14.762,14.762,0,0,1,6.4619,1.592,1,1,0,0,1,.0869,1.7222A8.0249,8.0249,0,0,0,24,26h6Z"
  })), children);
});
var WaveHeight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WaveHeight24(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 2H30V4H24zM24 8H28V10H24zM24 14H30V16H24zM24 20H28V22H24z"
  })), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,28H24a10.0349,10.0349,0,0,1-6.9268-17.2622A11.9629,11.9629,0,0,0,12.9937,10a6.9027,6.9027,0,0,0-6.0308,3.42C4.9966,16.4348,4,21.34,4,28H2c0-7.0542,1.106-12.3274,3.2871-15.6726A8.906,8.906,0,0,1,12.9937,8h.0068a14.762,14.762,0,0,1,6.4619,1.592,1,1,0,0,1,.0869,1.7222A8.0249,8.0249,0,0,0,24,26h6Z"
  })), children);
});
var WaveHeight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WaveHeight20(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 2H30V4H24zM24 8H28V10H24zM24 14H30V16H24zM24 20H28V22H24z"
  })), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,28H24a10.0349,10.0349,0,0,1-6.9268-17.2622A11.9629,11.9629,0,0,0,12.9937,10a6.9027,6.9027,0,0,0-6.0308,3.42C4.9966,16.4348,4,21.34,4,28H2c0-7.0542,1.106-12.3274,3.2871-15.6726A8.906,8.906,0,0,1,12.9937,8h.0068a14.762,14.762,0,0,1,6.4619,1.592,1,1,0,0,1,.0869,1.7222A8.0249,8.0249,0,0,0,24,26h6Z"
  })), children);
});
var WaveHeight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WaveHeight16(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 2H30V4H24zM24 8H28V10H24zM24 14H30V16H24zM24 20H28V22H24z"
  })), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,28H24a10.0349,10.0349,0,0,1-6.9268-17.2622A11.9629,11.9629,0,0,0,12.9937,10a6.9027,6.9027,0,0,0-6.0308,3.42C4.9966,16.4348,4,21.34,4,28H2c0-7.0542,1.106-12.3274,3.2871-15.6726A8.906,8.906,0,0,1,12.9937,8h.0068a14.762,14.762,0,0,1,6.4619,1.592,1,1,0,0,1,.0869,1.7222A8.0249,8.0249,0,0,0,24,26h6Z"
  })), children);
});
var WavePeriod32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WavePeriod32(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 30H17a7.0078 7.0078 0 01-7-7 6.6832 6.6832 0 012.0244-4.6967A6.7935 6.7935 0 0010.0093 18C5.0425 18.0466 4 24.5513 4 30H2C2 18.4907 6.3452 16.0342 9.9907 16a10.0717 10.0717 0 014.4785 1.117 1 1 0 01.0616 1.73A4.8773 4.8773 0 0017 28h5zM17 8H19V16H17z"
  })), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,5.4141,26.5859,4,24.3242,6.2617A9.95,9.95,0,0,0,19,4.0508V2H17V4.0508A10.0132,10.0132,0,0,0,8,14h2a8,8,0,1,1,8,8v2A9.9928,9.9928,0,0,0,25.7383,7.6758Z"
  })), children);
});
var WavePeriod24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WavePeriod24(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 30H17a7.0078 7.0078 0 01-7-7 6.6832 6.6832 0 012.0244-4.6967A6.7935 6.7935 0 0010.0093 18C5.0425 18.0466 4 24.5513 4 30H2C2 18.4907 6.3452 16.0342 9.9907 16a10.0717 10.0717 0 014.4785 1.117 1 1 0 01.0616 1.73A4.8773 4.8773 0 0017 28h5zM17 8H19V16H17z"
  })), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,5.4141,26.5859,4,24.3242,6.2617A9.95,9.95,0,0,0,19,4.0508V2H17V4.0508A10.0132,10.0132,0,0,0,8,14h2a8,8,0,1,1,8,8v2A9.9928,9.9928,0,0,0,25.7383,7.6758Z"
  })), children);
});
var WavePeriod20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WavePeriod20(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 30H17a7.0078 7.0078 0 01-7-7 6.6832 6.6832 0 012.0244-4.6967A6.7935 6.7935 0 0010.0093 18C5.0425 18.0466 4 24.5513 4 30H2C2 18.4907 6.3452 16.0342 9.9907 16a10.0717 10.0717 0 014.4785 1.117 1 1 0 01.0616 1.73A4.8773 4.8773 0 0017 28h5zM17 8H19V16H17z"
  })), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,5.4141,26.5859,4,24.3242,6.2617A9.95,9.95,0,0,0,19,4.0508V2H17V4.0508A10.0132,10.0132,0,0,0,8,14h2a8,8,0,1,1,8,8v2A9.9928,9.9928,0,0,0,25.7383,7.6758Z"
  })), children);
});
var WavePeriod16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WavePeriod16(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 30H17a7.0078 7.0078 0 01-7-7 6.6832 6.6832 0 012.0244-4.6967A6.7935 6.7935 0 0010.0093 18C5.0425 18.0466 4 24.5513 4 30H2C2 18.4907 6.3452 16.0342 9.9907 16a10.0717 10.0717 0 014.4785 1.117 1 1 0 01.0616 1.73A4.8773 4.8773 0 0017 28h5zM17 8H19V16H17z"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,5.4141,26.5859,4,24.3242,6.2617A9.95,9.95,0,0,0,19,4.0508V2H17V4.0508A10.0132,10.0132,0,0,0,8,14h2a8,8,0,1,1,8,8v2A9.9928,9.9928,0,0,0,25.7383,7.6758Z"
  })), children);
});
var WeatherFrontCold32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WeatherFrontCold32(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.1655 2a13.0289 13.0289 0 00-12.542 9.5791l-1.1767 4.3154A11.0237 11.0237 0 013.8345 24H2v2H3.8345c.2975 0 .5918-.0171.8853-.0371l7.9291 2.9736A1 1 0 0014 28V21.0923a12.9311 12.9311 0 00.9121-1.313l6.3628-1.8179a1 1 0 00.5059-1.5864L17.7843 11.38a10.9268 10.9268 0 011.1516-2.3472l5.7477 1.916A1 1 0 0026 10V4.2251A10.8956 10.8956 0 0128.1655 4H30V2zM8.3354 25.1826A13.047 13.047 0 0012 23.0943v3.4624zm7.74-7.8154c.1107-.3105.2136-.625.3013-.9463l.732-2.6846L19.28 16.4512zM24 8.6123l-3.7411-1.247A11.0712 11.0712 0 0124 4.8306zM10 4L10 8.586 3.414 2 2 3.414 8.586 10 4 10 4 12 12 12 12 4 10 4z"
  })), children);
});
var WeatherFrontCold24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WeatherFrontCold24(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.1655 2a13.0289 13.0289 0 00-12.542 9.5791l-1.1767 4.3154A11.0237 11.0237 0 013.8345 24H2v2H3.8345c.2975 0 .5918-.0171.8853-.0371l7.9291 2.9736A1 1 0 0014 28V21.0923a12.9311 12.9311 0 00.9121-1.313l6.3628-1.8179a1 1 0 00.5059-1.5864L17.7843 11.38a10.9268 10.9268 0 011.1516-2.3472l5.7477 1.916A1 1 0 0026 10V4.2251A10.8956 10.8956 0 0128.1655 4H30V2zM8.3354 25.1826A13.047 13.047 0 0012 23.0943v3.4624zm7.74-7.8154c.1107-.3105.2136-.625.3013-.9463l.732-2.6846L19.28 16.4512zM24 8.6123l-3.7411-1.247A11.0712 11.0712 0 0124 4.8306zM10 4L10 8.586 3.414 2 2 3.414 8.586 10 4 10 4 12 12 12 12 4 10 4z"
  })), children);
});
var WeatherFrontCold20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WeatherFrontCold20(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.1655 2a13.0289 13.0289 0 00-12.542 9.5791l-1.1767 4.3154A11.0237 11.0237 0 013.8345 24H2v2H3.8345c.2975 0 .5918-.0171.8853-.0371l7.9291 2.9736A1 1 0 0014 28V21.0923a12.9311 12.9311 0 00.9121-1.313l6.3628-1.8179a1 1 0 00.5059-1.5864L17.7843 11.38a10.9268 10.9268 0 011.1516-2.3472l5.7477 1.916A1 1 0 0026 10V4.2251A10.8956 10.8956 0 0128.1655 4H30V2zM8.3354 25.1826A13.047 13.047 0 0012 23.0943v3.4624zm7.74-7.8154c.1107-.3105.2136-.625.3013-.9463l.732-2.6846L19.28 16.4512zM24 8.6123l-3.7411-1.247A11.0712 11.0712 0 0124 4.8306zM10 4L10 8.586 3.414 2 2 3.414 8.586 10 4 10 4 12 12 12 12 4 10 4z"
  })), children);
});
var WeatherFrontCold16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WeatherFrontCold16(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.1655 2a13.0289 13.0289 0 00-12.542 9.5791l-1.1767 4.3154A11.0237 11.0237 0 013.8345 24H2v2H3.8345c.2975 0 .5918-.0171.8853-.0371l7.9291 2.9736A1 1 0 0014 28V21.0923a12.9311 12.9311 0 00.9121-1.313l6.3628-1.8179a1 1 0 00.5059-1.5864L17.7843 11.38a10.9268 10.9268 0 011.1516-2.3472l5.7477 1.916A1 1 0 0026 10V4.2251A10.8956 10.8956 0 0128.1655 4H30V2zM8.3354 25.1826A13.047 13.047 0 0012 23.0943v3.4624zm7.74-7.8154c.1107-.3105.2136-.625.3013-.9463l.732-2.6846L19.28 16.4512zM24 8.6123l-3.7411-1.247A11.0712 11.0712 0 0124 4.8306zM10 4L10 8.586 3.414 2 2 3.414 8.586 10 4 10 4 12 12 12 12 4 10 4z"
  })), children);
});
var WeatherFrontStationary32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WeatherFrontStationary32(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.1655 2a12.9848 12.9848 0 00-8.4074 3.1065A3.9947 3.9947 0 1015.583 11.728l-1.1362 4.1665c-.0725.2657-.1579.5254-.2489.7818a3.9864 3.9864 0 00-5.1547 6.0054A10.9541 10.9541 0 013.8345 24H2v2H3.8345c.2975 0 .5918-.0171.8853-.0371l7.9291 2.9736A1 1 0 0014 28V21.0923a12.9311 12.9311 0 00.9121-1.313l6.3628-1.8179a1 1 0 00.5059-1.5864L17.7843 11.38a10.9268 10.9268 0 011.1516-2.3472l5.7477 1.916A1 1 0 0026 10V4.2251A10.8956 10.8956 0 0128.1655 4H30V2zM17 6a1.98 1.98 0 011.3237.53A12.9413 12.9413 0 0016.24 9.8482 1.9988 1.9988 0 0117 6zM10 20a1.9879 1.9879 0 013.3374-1.4717 11.0157 11.0157 0 01-2.5959 3.0147A1.9975 1.9975 0 0110 20zM8.3354 25.1826A13.047 13.047 0 0012 23.0943v3.4624zm7.74-7.8154c.1107-.3105.2136-.625.3013-.9463l.732-2.6846L19.28 16.4512zM24 8.6123l-3.7411-1.247A11.0712 11.0712 0 0124 4.8306zM22 22L22 24 26.586 24 22 28.586 23.414 30 28 25.414 28 30 30 30 30 22 22 22zM2 2L2 4 6.586 4 2 8.586 3.414 10 8 5.414 8 10 10 10 10 2 2 2z"
  })), children);
});
var WeatherFrontStationary24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WeatherFrontStationary24(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.1655 2a12.9848 12.9848 0 00-8.4074 3.1065A3.9947 3.9947 0 1015.583 11.728l-1.1362 4.1665c-.0725.2657-.1579.5254-.2489.7818a3.9864 3.9864 0 00-5.1547 6.0054A10.9541 10.9541 0 013.8345 24H2v2H3.8345c.2975 0 .5918-.0171.8853-.0371l7.9291 2.9736A1 1 0 0014 28V21.0923a12.9311 12.9311 0 00.9121-1.313l6.3628-1.8179a1 1 0 00.5059-1.5864L17.7843 11.38a10.9268 10.9268 0 011.1516-2.3472l5.7477 1.916A1 1 0 0026 10V4.2251A10.8956 10.8956 0 0128.1655 4H30V2zM17 6a1.98 1.98 0 011.3237.53A12.9413 12.9413 0 0016.24 9.8482 1.9988 1.9988 0 0117 6zM10 20a1.9879 1.9879 0 013.3374-1.4717 11.0157 11.0157 0 01-2.5959 3.0147A1.9975 1.9975 0 0110 20zM8.3354 25.1826A13.047 13.047 0 0012 23.0943v3.4624zm7.74-7.8154c.1107-.3105.2136-.625.3013-.9463l.732-2.6846L19.28 16.4512zM24 8.6123l-3.7411-1.247A11.0712 11.0712 0 0124 4.8306zM22 22L22 24 26.586 24 22 28.586 23.414 30 28 25.414 28 30 30 30 30 22 22 22zM2 2L2 4 6.586 4 2 8.586 3.414 10 8 5.414 8 10 10 10 10 2 2 2z"
  })), children);
});
var WeatherFrontStationary20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WeatherFrontStationary20(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.1655 2a12.9848 12.9848 0 00-8.4074 3.1065A3.9947 3.9947 0 1015.583 11.728l-1.1362 4.1665c-.0725.2657-.1579.5254-.2489.7818a3.9864 3.9864 0 00-5.1547 6.0054A10.9541 10.9541 0 013.8345 24H2v2H3.8345c.2975 0 .5918-.0171.8853-.0371l7.9291 2.9736A1 1 0 0014 28V21.0923a12.9311 12.9311 0 00.9121-1.313l6.3628-1.8179a1 1 0 00.5059-1.5864L17.7843 11.38a10.9268 10.9268 0 011.1516-2.3472l5.7477 1.916A1 1 0 0026 10V4.2251A10.8956 10.8956 0 0128.1655 4H30V2zM17 6a1.98 1.98 0 011.3237.53A12.9413 12.9413 0 0016.24 9.8482 1.9988 1.9988 0 0117 6zM10 20a1.9879 1.9879 0 013.3374-1.4717 11.0157 11.0157 0 01-2.5959 3.0147A1.9975 1.9975 0 0110 20zM8.3354 25.1826A13.047 13.047 0 0012 23.0943v3.4624zm7.74-7.8154c.1107-.3105.2136-.625.3013-.9463l.732-2.6846L19.28 16.4512zM24 8.6123l-3.7411-1.247A11.0712 11.0712 0 0124 4.8306zM22 22L22 24 26.586 24 22 28.586 23.414 30 28 25.414 28 30 30 30 30 22 22 22zM2 2L2 4 6.586 4 2 8.586 3.414 10 8 5.414 8 10 10 10 10 2 2 2z"
  })), children);
});
var WeatherFrontStationary16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WeatherFrontStationary16(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.1655 2a12.9848 12.9848 0 00-8.4074 3.1065A3.9947 3.9947 0 1015.583 11.728l-1.1362 4.1665c-.0725.2657-.1579.5254-.2489.7818a3.9864 3.9864 0 00-5.1547 6.0054A10.9541 10.9541 0 013.8345 24H2v2H3.8345c.2975 0 .5918-.0171.8853-.0371l7.9291 2.9736A1 1 0 0014 28V21.0923a12.9311 12.9311 0 00.9121-1.313l6.3628-1.8179a1 1 0 00.5059-1.5864L17.7843 11.38a10.9268 10.9268 0 011.1516-2.3472l5.7477 1.916A1 1 0 0026 10V4.2251A10.8956 10.8956 0 0128.1655 4H30V2zM17 6a1.98 1.98 0 011.3237.53A12.9413 12.9413 0 0016.24 9.8482 1.9988 1.9988 0 0117 6zM10 20a1.9879 1.9879 0 013.3374-1.4717 11.0157 11.0157 0 01-2.5959 3.0147A1.9975 1.9975 0 0110 20zM8.3354 25.1826A13.047 13.047 0 0012 23.0943v3.4624zm7.74-7.8154c.1107-.3105.2136-.625.3013-.9463l.732-2.6846L19.28 16.4512zM24 8.6123l-3.7411-1.247A11.0712 11.0712 0 0124 4.8306zM22 22L22 24 26.586 24 22 28.586 23.414 30 28 25.414 28 30 30 30 30 22 22 22zM2 2L2 4 6.586 4 2 8.586 3.414 10 8 5.414 8 10 10 10 10 2 2 2z"
  })), children);
});
var WeatherFrontWarm32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WeatherFrontWarm32(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.1655 2a13.0289 13.0289 0 00-12.542 9.5791l-1.1767 4.3154A11.0237 11.0237 0 013.8345 24H2v2H3.8345a12.9139 12.9139 0 003.4687-.4819 3.9979 3.9979 0 106.5818-4.2866 12.9671 12.9671 0 001.6209-2.5269 3.9944 3.9944 0 102.3772-7.5991 10.95 10.95 0 011.7253-3.01 3.9825 3.9825 0 006.9058-3.9648A10.9435 10.9435 0 0128.1655 4H30V2zM11 26a1.9983 1.9983 0 01-1.8118-1.1655 13.0811 13.0811 0 003.2969-2.1426A1.9773 1.9773 0 0111 26zm8-11a1.9926 1.9926 0 01-2.759 1.8467c.0442-.1426.0959-.2813.1355-.4258L17.301 13.03A1.9976 1.9976 0 0119 15zm6-9a1.9942 1.9942 0 01-3.9011.5894 11.0511 11.0511 0 013.3623-1.9385A1.995 1.995 0 0125 6zM10 4L10 8.586 3.414 2 2 3.414 8.586 10 4 10 4 12 12 12 12 4 10 4z"
  })), children);
});
var WeatherFrontWarm24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WeatherFrontWarm24(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.1655 2a13.0289 13.0289 0 00-12.542 9.5791l-1.1767 4.3154A11.0237 11.0237 0 013.8345 24H2v2H3.8345a12.9139 12.9139 0 003.4687-.4819 3.9979 3.9979 0 106.5818-4.2866 12.9671 12.9671 0 001.6209-2.5269 3.9944 3.9944 0 102.3772-7.5991 10.95 10.95 0 011.7253-3.01 3.9825 3.9825 0 006.9058-3.9648A10.9435 10.9435 0 0128.1655 4H30V2zM11 26a1.9983 1.9983 0 01-1.8118-1.1655 13.0811 13.0811 0 003.2969-2.1426A1.9773 1.9773 0 0111 26zm8-11a1.9926 1.9926 0 01-2.759 1.8467c.0442-.1426.0959-.2813.1355-.4258L17.301 13.03A1.9976 1.9976 0 0119 15zm6-9a1.9942 1.9942 0 01-3.9011.5894 11.0511 11.0511 0 013.3623-1.9385A1.995 1.995 0 0125 6zM10 4L10 8.586 3.414 2 2 3.414 8.586 10 4 10 4 12 12 12 12 4 10 4z"
  })), children);
});
var WeatherFrontWarm20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WeatherFrontWarm20(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.1655 2a13.0289 13.0289 0 00-12.542 9.5791l-1.1767 4.3154A11.0237 11.0237 0 013.8345 24H2v2H3.8345a12.9139 12.9139 0 003.4687-.4819 3.9979 3.9979 0 106.5818-4.2866 12.9671 12.9671 0 001.6209-2.5269 3.9944 3.9944 0 102.3772-7.5991 10.95 10.95 0 011.7253-3.01 3.9825 3.9825 0 006.9058-3.9648A10.9435 10.9435 0 0128.1655 4H30V2zM11 26a1.9983 1.9983 0 01-1.8118-1.1655 13.0811 13.0811 0 003.2969-2.1426A1.9773 1.9773 0 0111 26zm8-11a1.9926 1.9926 0 01-2.759 1.8467c.0442-.1426.0959-.2813.1355-.4258L17.301 13.03A1.9976 1.9976 0 0119 15zm6-9a1.9942 1.9942 0 01-3.9011.5894 11.0511 11.0511 0 013.3623-1.9385A1.995 1.995 0 0125 6zM10 4L10 8.586 3.414 2 2 3.414 8.586 10 4 10 4 12 12 12 12 4 10 4z"
  })), children);
});
var WeatherFrontWarm16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WeatherFrontWarm16(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.1655 2a13.0289 13.0289 0 00-12.542 9.5791l-1.1767 4.3154A11.0237 11.0237 0 013.8345 24H2v2H3.8345a12.9139 12.9139 0 003.4687-.4819 3.9979 3.9979 0 106.5818-4.2866 12.9671 12.9671 0 001.6209-2.5269 3.9944 3.9944 0 102.3772-7.5991 10.95 10.95 0 011.7253-3.01 3.9825 3.9825 0 006.9058-3.9648A10.9435 10.9435 0 0128.1655 4H30V2zM11 26a1.9983 1.9983 0 01-1.8118-1.1655 13.0811 13.0811 0 003.2969-2.1426A1.9773 1.9773 0 0111 26zm8-11a1.9926 1.9926 0 01-2.759 1.8467c.0442-.1426.0959-.2813.1355-.4258L17.301 13.03A1.9976 1.9976 0 0119 15zm6-9a1.9942 1.9942 0 01-3.9011.5894 11.0511 11.0511 0 013.3623-1.9385A1.995 1.995 0 0125 6zM10 4L10 8.586 3.414 2 2 3.414 8.586 10 4 10 4 12 12 12 12 4 10 4z"
  })), children);
});
var WeatherStation32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WeatherStation32(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,28V17h1a2.0023,2.0023,0,0,0,2-2V11a2.0023,2.0023,0,0,0-2-2H14a2.0023,2.0023,0,0,0-2,2v4a2.0023,2.0023,0,0,0,2,2h1V28H2v2H30V28ZM14,11h4l.0015,4H14Z"
  })), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.3325 18.2168a7.0007 7.0007 0 010-10.4341l1.334 1.49a5 5 0 000 7.4537zM22.667 18.2168l-1.334-1.49a4.9995 4.9995 0 000-7.4537l1.334-1.49a7 7 0 010 10.4341z"
  })), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.3994 21.8008a11.0019 11.0019 0 010-17.6006L7.6 5.8a9.0009 9.0009 0 000 14.4014zM25.6006 21.8008l-1.2012-1.6a9.001 9.001 0 000-14.4019l1.2012-1.6a11.002 11.002 0 010 17.6011z"
  })), children);
});
var WeatherStation24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WeatherStation24(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,28V17h1a2.0023,2.0023,0,0,0,2-2V11a2.0023,2.0023,0,0,0-2-2H14a2.0023,2.0023,0,0,0-2,2v4a2.0023,2.0023,0,0,0,2,2h1V28H2v2H30V28ZM14,11h4l.0015,4H14Z"
  })), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.3325 18.2168a7.0007 7.0007 0 010-10.4341l1.334 1.49a5 5 0 000 7.4537zM22.667 18.2168l-1.334-1.49a4.9995 4.9995 0 000-7.4537l1.334-1.49a7 7 0 010 10.4341z"
  })), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.3994 21.8008a11.0019 11.0019 0 010-17.6006L7.6 5.8a9.0009 9.0009 0 000 14.4014zM25.6006 21.8008l-1.2012-1.6a9.001 9.001 0 000-14.4019l1.2012-1.6a11.002 11.002 0 010 17.6011z"
  })), children);
});
var WeatherStation20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WeatherStation20(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,28V17h1a2.0023,2.0023,0,0,0,2-2V11a2.0023,2.0023,0,0,0-2-2H14a2.0023,2.0023,0,0,0-2,2v4a2.0023,2.0023,0,0,0,2,2h1V28H2v2H30V28ZM14,11h4l.0015,4H14Z"
  })), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.3325 18.2168a7.0007 7.0007 0 010-10.4341l1.334 1.49a5 5 0 000 7.4537zM22.667 18.2168l-1.334-1.49a4.9995 4.9995 0 000-7.4537l1.334-1.49a7 7 0 010 10.4341z"
  })), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.3994 21.8008a11.0019 11.0019 0 010-17.6006L7.6 5.8a9.0009 9.0009 0 000 14.4014zM25.6006 21.8008l-1.2012-1.6a9.001 9.001 0 000-14.4019l1.2012-1.6a11.002 11.002 0 010 17.6011z"
  })), children);
});
var WeatherStation16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WeatherStation16(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,28V17h1a2.0023,2.0023,0,0,0,2-2V11a2.0023,2.0023,0,0,0-2-2H14a2.0023,2.0023,0,0,0-2,2v4a2.0023,2.0023,0,0,0,2,2h1V28H2v2H30V28ZM14,11h4l.0015,4H14Z"
  })), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9.3325 18.2168a7.0007 7.0007 0 010-10.4341l1.334 1.49a5 5 0 000 7.4537zM22.667 18.2168l-1.334-1.49a4.9995 4.9995 0 000-7.4537l1.334-1.49a7 7 0 010 10.4341z"
  })), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.3994 21.8008a11.0019 11.0019 0 010-17.6006L7.6 5.8a9.0009 9.0009 0 000 14.4014zM25.6006 21.8008l-1.2012-1.6a9.001 9.001 0 000-14.4019l1.2012-1.6a11.002 11.002 0 010 17.6011z"
  })), children);
});
var Webhook32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Webhook32(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,26a3,3,0,1,0-2.8164-4H13v1a5,5,0,1,1-5-5V16a7,7,0,1,0,6.9287,8h6.2549A2.9914,2.9914,0,0,0,24,26Z"
  })), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,16a7.024,7.024,0,0,0-2.57.4873l-3.1656-5.5395a3.0469,3.0469,0,1,0-1.7326.9985l4.1189,7.2085.8686-.4976a5.0006,5.0006,0,1,1-1.851,6.8418L17.937,26.501A7.0005,7.0005,0,1,0,24,16Z"
  })), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.532,20.0537a3.03,3.03,0,1,0,1.7326.9985C11.74,18.47,13.86,14.7607,13.89,14.708l.4976-.8682-.8677-.497a5,5,0,1,1,6.812-1.8438l1.7315,1.002a7.0008,7.0008,0,1,0-10.3462,2.0356c-.457.7427-1.1021,1.8716-2.0737,3.5728Z"
  })), children);
});
var Webhook24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Webhook24(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,26a3,3,0,1,0-2.8164-4H13v1a5,5,0,1,1-5-5V16a7,7,0,1,0,6.9287,8h6.2549A2.9914,2.9914,0,0,0,24,26Z"
  })), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,16a7.024,7.024,0,0,0-2.57.4873l-3.1656-5.5395a3.0469,3.0469,0,1,0-1.7326.9985l4.1189,7.2085.8686-.4976a5.0006,5.0006,0,1,1-1.851,6.8418L17.937,26.501A7.0005,7.0005,0,1,0,24,16Z"
  })), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.532,20.0537a3.03,3.03,0,1,0,1.7326.9985C11.74,18.47,13.86,14.7607,13.89,14.708l.4976-.8682-.8677-.497a5,5,0,1,1,6.812-1.8438l1.7315,1.002a7.0008,7.0008,0,1,0-10.3462,2.0356c-.457.7427-1.1021,1.8716-2.0737,3.5728Z"
  })), children);
});
var Webhook20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Webhook20(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,26a3,3,0,1,0-2.8164-4H13v1a5,5,0,1,1-5-5V16a7,7,0,1,0,6.9287,8h6.2549A2.9914,2.9914,0,0,0,24,26Z"
  })), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,16a7.024,7.024,0,0,0-2.57.4873l-3.1656-5.5395a3.0469,3.0469,0,1,0-1.7326.9985l4.1189,7.2085.8686-.4976a5.0006,5.0006,0,1,1-1.851,6.8418L17.937,26.501A7.0005,7.0005,0,1,0,24,16Z"
  })), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.532,20.0537a3.03,3.03,0,1,0,1.7326.9985C11.74,18.47,13.86,14.7607,13.89,14.708l.4976-.8682-.8677-.497a5,5,0,1,1,6.812-1.8438l1.7315,1.002a7.0008,7.0008,0,1,0-10.3462,2.0356c-.457.7427-1.1021,1.8716-2.0737,3.5728Z"
  })), children);
});
var Webhook16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Webhook16(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,26a3,3,0,1,0-2.8164-4H13v1a5,5,0,1,1-5-5V16a7,7,0,1,0,6.9287,8h6.2549A2.9914,2.9914,0,0,0,24,26Z"
  })), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,16a7.024,7.024,0,0,0-2.57.4873l-3.1656-5.5395a3.0469,3.0469,0,1,0-1.7326.9985l4.1189,7.2085.8686-.4976a5.0006,5.0006,0,1,1-1.851,6.8418L17.937,26.501A7.0005,7.0005,0,1,0,24,16Z"
  })), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.532,20.0537a3.03,3.03,0,1,0,1.7326.9985C11.74,18.47,13.86,14.7607,13.89,14.708l.4976-.8682-.8677-.497a5,5,0,1,1,6.812-1.8438l1.7315,1.002a7.0008,7.0008,0,1,0-10.3462,2.0356c-.457.7427-1.1021,1.8716-2.0737,3.5728Z"
  })), children);
});
var Websheet32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Websheet32(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "24",
    r: "2"
  })), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30a6,6,0,1,1,6-6A6.0069,6.0069,0,0,1,24,30Zm0-10a4,4,0,1,0,4,4A4.0045,4.0045,0,0,0,24,20Z"
  })), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var Websheet24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Websheet24(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "24",
    r: "2"
  })), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30a6,6,0,1,1,6-6A6.0069,6.0069,0,0,1,24,30Zm0-10a4,4,0,1,0,4,4A4.0045,4.0045,0,0,0,24,20Z"
  })), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var Websheet20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Websheet20(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "24",
    r: "2"
  })), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30a6,6,0,1,1,6-6A6.0069,6.0069,0,0,1,24,30Zm0-10a4,4,0,1,0,4,4A4.0045,4.0045,0,0,0,24,20Z"
  })), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var Websheet16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Websheet16(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "24",
    cy: "24",
    r: "2"
  })), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30a6,6,0,1,1,6-6A6.0069,6.0069,0,0,1,24,30Zm0-10a4,4,0,1,0,4,4A4.0045,4.0045,0,0,0,24,20Z"
  })), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var Wheat32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wheat32(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,3V5.5857l-4,4V1H15V9.5857l-4-4V3H9V19a7.004,7.004,0,0,0,6,6.92V30h2V25.92A7.004,7.004,0,0,0,23,19V3ZM15,23.8987A5.008,5.008,0,0,1,11,19v-2.586l4,4Zm0-6.313-4-4V8.4138l4,4Zm2-5.1719,4-4v5.1719l-4,4Zm0,11.4849V20.4138l4-4V19A5.008,5.008,0,0,1,17,23.8987Z"
  })), children);
});
var Wheat24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wheat24(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,3V5.5857l-4,4V1H15V9.5857l-4-4V3H9V19a7.004,7.004,0,0,0,6,6.92V30h2V25.92A7.004,7.004,0,0,0,23,19V3ZM15,23.8987A5.008,5.008,0,0,1,11,19v-2.586l4,4Zm0-6.313-4-4V8.4138l4,4Zm2-5.1719,4-4v5.1719l-4,4Zm0,11.4849V20.4138l4-4V19A5.008,5.008,0,0,1,17,23.8987Z"
  })), children);
});
var Wheat20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wheat20(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,3V5.5857l-4,4V1H15V9.5857l-4-4V3H9V19a7.004,7.004,0,0,0,6,6.92V30h2V25.92A7.004,7.004,0,0,0,23,19V3ZM15,23.8987A5.008,5.008,0,0,1,11,19v-2.586l4,4Zm0-6.313-4-4V8.4138l4,4Zm2-5.1719,4-4v5.1719l-4,4Zm0,11.4849V20.4138l4-4V19A5.008,5.008,0,0,1,17,23.8987Z"
  })), children);
});
var Wheat16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wheat16(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,3V5.5857l-4,4V1H15V9.5857l-4-4V3H9V19a7.004,7.004,0,0,0,6,6.92V30h2V25.92A7.004,7.004,0,0,0,23,19V3ZM15,23.8987A5.008,5.008,0,0,1,11,19v-2.586l4,4Zm0-6.313-4-4V8.4138l4,4Zm2-5.1719,4-4v5.1719l-4,4Zm0,11.4849V20.4138l4-4V19A5.008,5.008,0,0,1,17,23.8987Z"
  })), children);
});
var Wifi32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wifi32(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "25",
    r: "2"
  })), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.47,19.2334l1.4136,1.4131a5.9688,5.9688,0,0,1,8.2229-.0093L21.52,19.2236a7.9629,7.9629,0,0,0-11.05.01Z"
  })), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.229,14.9927l1.4136,1.4135a11.955,11.955,0,0,1,16.7041-.01L25.76,14.9829a13.9514,13.9514,0,0,0-19.5313.01Z"
  })), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10.7412a19.94,19.94,0,0,0-28,0v.0225L3.4043,12.168a17.9336,17.9336,0,0,1,25.1811-.01L30,10.7432Z"
  })), children);
});
var Wifi24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wifi24(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "25",
    r: "2"
  })), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.47,19.2334l1.4136,1.4131a5.9688,5.9688,0,0,1,8.2229-.0093L21.52,19.2236a7.9629,7.9629,0,0,0-11.05.01Z"
  })), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.229,14.9927l1.4136,1.4135a11.955,11.955,0,0,1,16.7041-.01L25.76,14.9829a13.9514,13.9514,0,0,0-19.5313.01Z"
  })), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10.7412a19.94,19.94,0,0,0-28,0v.0225L3.4043,12.168a17.9336,17.9336,0,0,1,25.1811-.01L30,10.7432Z"
  })), children);
});
var Wifi20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wifi20(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "25",
    r: "2"
  })), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.47,19.2334l1.4136,1.4131a5.9688,5.9688,0,0,1,8.2229-.0093L21.52,19.2236a7.9629,7.9629,0,0,0-11.05.01Z"
  })), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.229,14.9927l1.4136,1.4135a11.955,11.955,0,0,1,16.7041-.01L25.76,14.9829a13.9514,13.9514,0,0,0-19.5313.01Z"
  })), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10.7412a19.94,19.94,0,0,0-28,0v.0225L3.4043,12.168a17.9336,17.9336,0,0,1,25.1811-.01L30,10.7432Z"
  })), children);
});
var Wifi16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wifi16(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "25",
    r: "2"
  })), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.47,19.2334l1.4136,1.4131a5.9688,5.9688,0,0,1,8.2229-.0093L21.52,19.2236a7.9629,7.9629,0,0,0-11.05.01Z"
  })), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.229,14.9927l1.4136,1.4135a11.955,11.955,0,0,1,16.7041-.01L25.76,14.9829a13.9514,13.9514,0,0,0-19.5313.01Z"
  })), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10.7412a19.94,19.94,0,0,0-28,0v.0225L3.4043,12.168a17.9336,17.9336,0,0,1,25.1811-.01L30,10.7432Z"
  })), children);
});
var WifiController32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiController32(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H26a2,2,0,0,0,2-2V22a2,2,0,0,0-2-2H6a2,2,0,0,0-2,2v6A2,2,0,0,0,6,30Zm0-8H26v6H6Z"
  })), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "25",
    r: "1"
  })), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "14.5",
    r: "1.5"
  })), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.7832,10.3325a7.0007,7.0007,0,0,1,10.4341,0l-1.49,1.334a5,5,0,0,0-7.4537,0Z"
  })), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.1992,7.3994a11.0019,11.0019,0,0,1,17.6006,0L23.2,8.6a9.0009,9.0009,0,0,0-14.4014.0005Z"
  })), children);
});
var WifiController24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiController24(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H26a2,2,0,0,0,2-2V22a2,2,0,0,0-2-2H6a2,2,0,0,0-2,2v6A2,2,0,0,0,6,30Zm0-8H26v6H6Z"
  })), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "25",
    r: "1"
  })), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "14.5",
    r: "1.5"
  })), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.7832,10.3325a7.0007,7.0007,0,0,1,10.4341,0l-1.49,1.334a5,5,0,0,0-7.4537,0Z"
  })), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.1992,7.3994a11.0019,11.0019,0,0,1,17.6006,0L23.2,8.6a9.0009,9.0009,0,0,0-14.4014.0005Z"
  })), children);
});
var WifiController20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiController20(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H26a2,2,0,0,0,2-2V22a2,2,0,0,0-2-2H6a2,2,0,0,0-2,2v6A2,2,0,0,0,6,30Zm0-8H26v6H6Z"
  })), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "25",
    r: "1"
  })), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "14.5",
    r: "1.5"
  })), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.7832,10.3325a7.0007,7.0007,0,0,1,10.4341,0l-1.49,1.334a5,5,0,0,0-7.4537,0Z"
  })), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.1992,7.3994a11.0019,11.0019,0,0,1,17.6006,0L23.2,8.6a9.0009,9.0009,0,0,0-14.4014.0005Z"
  })), children);
});
var WifiController16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiController16(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,30H26a2,2,0,0,0,2-2V22a2,2,0,0,0-2-2H6a2,2,0,0,0-2,2v6A2,2,0,0,0,6,30Zm0-8H26v6H6Z"
  })), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "25",
    r: "1"
  })), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "14.5",
    r: "1.5"
  })), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.7832,10.3325a7.0007,7.0007,0,0,1,10.4341,0l-1.49,1.334a5,5,0,0,0-7.4537,0Z"
  })), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.1992,7.3994a11.0019,11.0019,0,0,1,17.6006,0L23.2,8.6a9.0009,9.0009,0,0,0-14.4014.0005Z"
  })), children);
});
var WifiNotSecure32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiNotSecure32(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20H14V17a2 2 0 014 0h2a4 4 0 00-8 0v3a2.0025 2.0025 0 00-2 2v6a2.0025 2.0025 0 002 2h8a2.0025 2.0025 0 002-2V22A2.0025 2.0025 0 0020 20zm0 8H12V22h8zM16 8a8.9709 8.9709 0 00-6.3608 2.6392l1.4133 1.4135a6.9887 6.9887 0 019.895 0l1.4135-1.4135A8.9717 8.9717 0 0016 8z"
  })), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.105,7.105,7.5188,8.5186a11.9808,11.9808,0,0,1,16.9624,0L25.8949,7.105a13.9782,13.9782,0,0,0-19.79,0Z"
  })), children);
});
var WifiNotSecure24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiNotSecure24(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20H14V17a2 2 0 014 0h2a4 4 0 00-8 0v3a2.0025 2.0025 0 00-2 2v6a2.0025 2.0025 0 002 2h8a2.0025 2.0025 0 002-2V22A2.0025 2.0025 0 0020 20zm0 8H12V22h8zM16 8a8.9709 8.9709 0 00-6.3608 2.6392l1.4133 1.4135a6.9887 6.9887 0 019.895 0l1.4135-1.4135A8.9717 8.9717 0 0016 8z"
  })), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.105,7.105,7.5188,8.5186a11.9808,11.9808,0,0,1,16.9624,0L25.8949,7.105a13.9782,13.9782,0,0,0-19.79,0Z"
  })), children);
});
var WifiNotSecure20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiNotSecure20(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20H14V17a2 2 0 014 0h2a4 4 0 00-8 0v3a2.0025 2.0025 0 00-2 2v6a2.0025 2.0025 0 002 2h8a2.0025 2.0025 0 002-2V22A2.0025 2.0025 0 0020 20zm0 8H12V22h8zM16 8a8.9709 8.9709 0 00-6.3608 2.6392l1.4133 1.4135a6.9887 6.9887 0 019.895 0l1.4135-1.4135A8.9717 8.9717 0 0016 8z"
  })), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.105,7.105,7.5188,8.5186a11.9808,11.9808,0,0,1,16.9624,0L25.8949,7.105a13.9782,13.9782,0,0,0-19.79,0Z"
  })), children);
});
var WifiNotSecure16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiNotSecure16(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20H14V17a2 2 0 014 0h2a4 4 0 00-8 0v3a2.0025 2.0025 0 00-2 2v6a2.0025 2.0025 0 002 2h8a2.0025 2.0025 0 002-2V22A2.0025 2.0025 0 0020 20zm0 8H12V22h8zM16 8a8.9709 8.9709 0 00-6.3608 2.6392l1.4133 1.4135a6.9887 6.9887 0 019.895 0l1.4135-1.4135A8.9717 8.9717 0 0016 8z"
  })), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.105,7.105,7.5188,8.5186a11.9808,11.9808,0,0,1,16.9624,0L25.8949,7.105a13.9782,13.9782,0,0,0-19.79,0Z"
  })), children);
});
var WifiOff32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiOff32(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle21 || (_circle21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "25",
    r: "2"
  })), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 3.4141L28.5859 2 2 28.5859 3.4141 30 14.0962 19.3179a5.9359 5.9359 0 016.01 1.3193L21.52 19.2236a7.9669 7.9669 0 00-5.125-2.2041l3.3875-3.3877a11.9908 11.9908 0 014.5647 2.7647L25.76 14.9829A13.975 13.975 0 0021.334 12.08L24.3308 9.083a17.9364 17.9364 0 014.2546 3.0747L30 10.7432v-.002a20.02 20.02 0 00-4.1895-3.1377zM14.68 13.0776l2.0415-2.0415C16.481 11.0234 16.2437 11 16 11a13.9447 13.9447 0 00-9.771 3.9927l1.4136 1.4136A11.97 11.97 0 0114.68 13.0776zM16 7a17.87 17.87 0 014.2324.5254L21.875 5.8828A19.9537 19.9537 0 002 10.7412v.0225L3.4043 12.168A17.9193 17.9193 0 0116 7z"
  })), children);
});
var WifiOff24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiOff24(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle22 || (_circle22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "25",
    r: "2"
  })), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 3.4141L28.5859 2 2 28.5859 3.4141 30 14.0962 19.3179a5.9359 5.9359 0 016.01 1.3193L21.52 19.2236a7.9669 7.9669 0 00-5.125-2.2041l3.3875-3.3877a11.9908 11.9908 0 014.5647 2.7647L25.76 14.9829A13.975 13.975 0 0021.334 12.08L24.3308 9.083a17.9364 17.9364 0 014.2546 3.0747L30 10.7432v-.002a20.02 20.02 0 00-4.1895-3.1377zM14.68 13.0776l2.0415-2.0415C16.481 11.0234 16.2437 11 16 11a13.9447 13.9447 0 00-9.771 3.9927l1.4136 1.4136A11.97 11.97 0 0114.68 13.0776zM16 7a17.87 17.87 0 014.2324.5254L21.875 5.8828A19.9537 19.9537 0 002 10.7412v.0225L3.4043 12.168A17.9193 17.9193 0 0116 7z"
  })), children);
});
var WifiOff20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiOff20(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle23 || (_circle23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "25",
    r: "2"
  })), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 3.4141L28.5859 2 2 28.5859 3.4141 30 14.0962 19.3179a5.9359 5.9359 0 016.01 1.3193L21.52 19.2236a7.9669 7.9669 0 00-5.125-2.2041l3.3875-3.3877a11.9908 11.9908 0 014.5647 2.7647L25.76 14.9829A13.975 13.975 0 0021.334 12.08L24.3308 9.083a17.9364 17.9364 0 014.2546 3.0747L30 10.7432v-.002a20.02 20.02 0 00-4.1895-3.1377zM14.68 13.0776l2.0415-2.0415C16.481 11.0234 16.2437 11 16 11a13.9447 13.9447 0 00-9.771 3.9927l1.4136 1.4136A11.97 11.97 0 0114.68 13.0776zM16 7a17.87 17.87 0 014.2324.5254L21.875 5.8828A19.9537 19.9537 0 002 10.7412v.0225L3.4043 12.168A17.9193 17.9193 0 0116 7z"
  })), children);
});
var WifiOff16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiOff16(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle24 || (_circle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "25",
    r: "2"
  })), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 3.4141L28.5859 2 2 28.5859 3.4141 30 14.0962 19.3179a5.9359 5.9359 0 016.01 1.3193L21.52 19.2236a7.9669 7.9669 0 00-5.125-2.2041l3.3875-3.3877a11.9908 11.9908 0 014.5647 2.7647L25.76 14.9829A13.975 13.975 0 0021.334 12.08L24.3308 9.083a17.9364 17.9364 0 014.2546 3.0747L30 10.7432v-.002a20.02 20.02 0 00-4.1895-3.1377zM14.68 13.0776l2.0415-2.0415C16.481 11.0234 16.2437 11 16 11a13.9447 13.9447 0 00-9.771 3.9927l1.4136 1.4136A11.97 11.97 0 0114.68 13.0776zM16 7a17.87 17.87 0 014.2324.5254L21.875 5.8828A19.9537 19.9537 0 002 10.7412v.0225L3.4043 12.168A17.9193 17.9193 0 0116 7z"
  })), children);
});
var WifiSecure32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiSecure32(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20V17a4 4 0 00-8 0v3a2.0025 2.0025 0 00-2 2v6a2.0025 2.0025 0 002 2h8a2.0025 2.0025 0 002-2V22A2.0025 2.0025 0 0020 20zm-6-3a2 2 0 014 0v3H14zM12 28V22h8v6zM6.105 7.105L7.5188 8.5186a11.9808 11.9808 0 0116.9624 0L25.8949 7.105a13.9782 13.9782 0 00-19.79 0z"
  })), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,8a8.9709,8.9709,0,0,0-6.3608,2.6392l1.4133,1.4135a6.9887,6.9887,0,0,1,9.895,0l1.4135-1.4135A8.9717,8.9717,0,0,0,16,8Z"
  })), children);
});
var WifiSecure24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiSecure24(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20V17a4 4 0 00-8 0v3a2.0025 2.0025 0 00-2 2v6a2.0025 2.0025 0 002 2h8a2.0025 2.0025 0 002-2V22A2.0025 2.0025 0 0020 20zm-6-3a2 2 0 014 0v3H14zM12 28V22h8v6zM6.105 7.105L7.5188 8.5186a11.9808 11.9808 0 0116.9624 0L25.8949 7.105a13.9782 13.9782 0 00-19.79 0z"
  })), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,8a8.9709,8.9709,0,0,0-6.3608,2.6392l1.4133,1.4135a6.9887,6.9887,0,0,1,9.895,0l1.4135-1.4135A8.9717,8.9717,0,0,0,16,8Z"
  })), children);
});
var WifiSecure20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiSecure20(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20V17a4 4 0 00-8 0v3a2.0025 2.0025 0 00-2 2v6a2.0025 2.0025 0 002 2h8a2.0025 2.0025 0 002-2V22A2.0025 2.0025 0 0020 20zm-6-3a2 2 0 014 0v3H14zM12 28V22h8v6zM6.105 7.105L7.5188 8.5186a11.9808 11.9808 0 0116.9624 0L25.8949 7.105a13.9782 13.9782 0 00-19.79 0z"
  })), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,8a8.9709,8.9709,0,0,0-6.3608,2.6392l1.4133,1.4135a6.9887,6.9887,0,0,1,9.895,0l1.4135-1.4135A8.9717,8.9717,0,0,0,16,8Z"
  })), children);
});
var WifiSecure16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiSecure16(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20V17a4 4 0 00-8 0v3a2.0025 2.0025 0 00-2 2v6a2.0025 2.0025 0 002 2h8a2.0025 2.0025 0 002-2V22A2.0025 2.0025 0 0020 20zm-6-3a2 2 0 014 0v3H14zM12 28V22h8v6zM6.105 7.105L7.5188 8.5186a11.9808 11.9808 0 0116.9624 0L25.8949 7.105a13.9782 13.9782 0 00-19.79 0z"
  })), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,8a8.9709,8.9709,0,0,0-6.3608,2.6392l1.4133,1.4135a6.9887,6.9887,0,0,1,9.895,0l1.4135-1.4135A8.9717,8.9717,0,0,0,16,8Z"
  })), children);
});
var WifiBridge32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiBridge32(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.9492,20.95l-1.414-1.4141a5,5,0,0,0,0-7.0715L6.9492,11.05a7,7,0,0,1,0,9.9Z"
  })), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.4854 24.4854L9.0713 23.0713a10.0011 10.0011 0 000-14.1426l1.4141-1.4141a12.0006 12.0006 0 010 16.9708zM25.0508 20.95a7 7 0 010-9.9l1.414 1.4146a5 5 0 000 7.0715z"
  })), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.5146 24.4854a12.0006 12.0006 0 010-16.9708l1.4141 1.4141a10.0011 10.0011 0 000 14.1426zM3 15H2V4H0V28H2V17H3a1 1 0 000-2zM30 4V15H29a1 1 0 000 2h1V28h2V4z"
  })), children);
});
var WifiBridge24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiBridge24(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.9492,20.95l-1.414-1.4141a5,5,0,0,0,0-7.0715L6.9492,11.05a7,7,0,0,1,0,9.9Z"
  })), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.4854 24.4854L9.0713 23.0713a10.0011 10.0011 0 000-14.1426l1.4141-1.4141a12.0006 12.0006 0 010 16.9708zM25.0508 20.95a7 7 0 010-9.9l1.414 1.4146a5 5 0 000 7.0715z"
  })), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.5146 24.4854a12.0006 12.0006 0 010-16.9708l1.4141 1.4141a10.0011 10.0011 0 000 14.1426zM3 15H2V4H0V28H2V17H3a1 1 0 000-2zM30 4V15H29a1 1 0 000 2h1V28h2V4z"
  })), children);
});
var WifiBridge20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiBridge20(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.9492,20.95l-1.414-1.4141a5,5,0,0,0,0-7.0715L6.9492,11.05a7,7,0,0,1,0,9.9Z"
  })), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.4854 24.4854L9.0713 23.0713a10.0011 10.0011 0 000-14.1426l1.4141-1.4141a12.0006 12.0006 0 010 16.9708zM25.0508 20.95a7 7 0 010-9.9l1.414 1.4146a5 5 0 000 7.0715z"
  })), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.5146 24.4854a12.0006 12.0006 0 010-16.9708l1.4141 1.4141a10.0011 10.0011 0 000 14.1426zM3 15H2V4H0V28H2V17H3a1 1 0 000-2zM30 4V15H29a1 1 0 000 2h1V28h2V4z"
  })), children);
});
var WifiBridge16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiBridge16(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.9492,20.95l-1.414-1.4141a5,5,0,0,0,0-7.0715L6.9492,11.05a7,7,0,0,1,0,9.9Z"
  })), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.4854 24.4854L9.0713 23.0713a10.0011 10.0011 0 000-14.1426l1.4141-1.4141a12.0006 12.0006 0 010 16.9708zM25.0508 20.95a7 7 0 010-9.9l1.414 1.4146a5 5 0 000 7.0715z"
  })), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.5146 24.4854a12.0006 12.0006 0 010-16.9708l1.4141 1.4141a10.0011 10.0011 0 000 14.1426zM3 15H2V4H0V28H2V17H3a1 1 0 000-2zM30 4V15H29a1 1 0 000 2h1V28h2V4z"
  })), children);
});
var WifiBridgeAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiBridgeAlt32(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,26H11a5.0057,5.0057,0,0,0-5-5V19A7.0078,7.0078,0,0,1,13,26Z"
  })), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 26H16A10.0113 10.0113 0 006 16V14A12.0137 12.0137 0 0118 26zM26 13a7.0078 7.0078 0 01-7-7h2a5.0057 5.0057 0 005 5z"
  })), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 18A12.0137 12.0137 0 0114 6h2A10.0113 10.0113 0 0026 16zM7.707 24.293a.9994.9994 0 00-1.414 0L2 28.5859 3.4143 30 7.707 25.707A.9994.9994 0 007.707 24.293zM28.5859 2L24.293 6.293a1 1 0 001.414 1.414L30 3.4141z"
  })), children);
});
var WifiBridgeAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiBridgeAlt24(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,26H11a5.0057,5.0057,0,0,0-5-5V19A7.0078,7.0078,0,0,1,13,26Z"
  })), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 26H16A10.0113 10.0113 0 006 16V14A12.0137 12.0137 0 0118 26zM26 13a7.0078 7.0078 0 01-7-7h2a5.0057 5.0057 0 005 5z"
  })), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 18A12.0137 12.0137 0 0114 6h2A10.0113 10.0113 0 0026 16zM7.707 24.293a.9994.9994 0 00-1.414 0L2 28.5859 3.4143 30 7.707 25.707A.9994.9994 0 007.707 24.293zM28.5859 2L24.293 6.293a1 1 0 001.414 1.414L30 3.4141z"
  })), children);
});
var WifiBridgeAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiBridgeAlt20(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,26H11a5.0057,5.0057,0,0,0-5-5V19A7.0078,7.0078,0,0,1,13,26Z"
  })), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 26H16A10.0113 10.0113 0 006 16V14A12.0137 12.0137 0 0118 26zM26 13a7.0078 7.0078 0 01-7-7h2a5.0057 5.0057 0 005 5z"
  })), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 18A12.0137 12.0137 0 0114 6h2A10.0113 10.0113 0 0026 16zM7.707 24.293a.9994.9994 0 00-1.414 0L2 28.5859 3.4143 30 7.707 25.707A.9994.9994 0 007.707 24.293zM28.5859 2L24.293 6.293a1 1 0 001.414 1.414L30 3.4141z"
  })), children);
});
var WifiBridgeAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WifiBridgeAlt16(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,26H11a5.0057,5.0057,0,0,0-5-5V19A7.0078,7.0078,0,0,1,13,26Z"
  })), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 26H16A10.0113 10.0113 0 006 16V14A12.0137 12.0137 0 0118 26zM26 13a7.0078 7.0078 0 01-7-7h2a5.0057 5.0057 0 005 5z"
  })), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 18A12.0137 12.0137 0 0114 6h2A10.0113 10.0113 0 0026 16zM7.707 24.293a.9994.9994 0 00-1.414 0L2 28.5859 3.4143 30 7.707 25.707A.9994.9994 0 007.707 24.293zM28.5859 2L24.293 6.293a1 1 0 001.414 1.414L30 3.4141z"
  })), children);
});
var Wikis32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wikis32(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM28,15H22A24.26,24.26,0,0,0,19.21,4.45,12,12,0,0,1,28,15ZM16,28a5,5,0,0,1-.67,0A21.85,21.85,0,0,1,12,17H20a21.85,21.85,0,0,1-3.3,11A5,5,0,0,1,16,28ZM12,15a21.85,21.85,0,0,1,3.3-11,6,6,0,0,1,1.34,0A21.85,21.85,0,0,1,20,15Zm.76-10.55A24.26,24.26,0,0,0,10,15h-6A12,12,0,0,1,12.79,4.45ZM4.05,17h6a24.26,24.26,0,0,0,2.75,10.55A12,12,0,0,1,4.05,17ZM19.21,27.55A24.26,24.26,0,0,0,22,17h6A12,12,0,0,1,19.21,27.55Z"
  })), children);
});
var Wikis24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wikis24(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM28,15H22A24.26,24.26,0,0,0,19.21,4.45,12,12,0,0,1,28,15ZM16,28a5,5,0,0,1-.67,0A21.85,21.85,0,0,1,12,17H20a21.85,21.85,0,0,1-3.3,11A5,5,0,0,1,16,28ZM12,15a21.85,21.85,0,0,1,3.3-11,6,6,0,0,1,1.34,0A21.85,21.85,0,0,1,20,15Zm.76-10.55A24.26,24.26,0,0,0,10,15h-6A12,12,0,0,1,12.79,4.45ZM4.05,17h6a24.26,24.26,0,0,0,2.75,10.55A12,12,0,0,1,4.05,17ZM19.21,27.55A24.26,24.26,0,0,0,22,17h6A12,12,0,0,1,19.21,27.55Z"
  })), children);
});
var Wikis20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wikis20(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM28,15H22A24.26,24.26,0,0,0,19.21,4.45,12,12,0,0,1,28,15ZM16,28a5,5,0,0,1-.67,0A21.85,21.85,0,0,1,12,17H20a21.85,21.85,0,0,1-3.3,11A5,5,0,0,1,16,28ZM12,15a21.85,21.85,0,0,1,3.3-11,6,6,0,0,1,1.34,0A21.85,21.85,0,0,1,20,15Zm.76-10.55A24.26,24.26,0,0,0,10,15h-6A12,12,0,0,1,12.79,4.45ZM4.05,17h6a24.26,24.26,0,0,0,2.75,10.55A12,12,0,0,1,4.05,17ZM19.21,27.55A24.26,24.26,0,0,0,22,17h6A12,12,0,0,1,19.21,27.55Z"
  })), children);
});
var Wikis16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wikis16(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM28,15H22A24.26,24.26,0,0,0,19.21,4.45,12,12,0,0,1,28,15ZM16,28a5,5,0,0,1-.67,0A21.85,21.85,0,0,1,12,17H20a21.85,21.85,0,0,1-3.3,11A5,5,0,0,1,16,28ZM12,15a21.85,21.85,0,0,1,3.3-11,6,6,0,0,1,1.34,0A21.85,21.85,0,0,1,20,15Zm.76-10.55A24.26,24.26,0,0,0,10,15h-6A12,12,0,0,1,12.79,4.45ZM4.05,17h6a24.26,24.26,0,0,0,2.75,10.55A12,12,0,0,1,4.05,17ZM19.21,27.55A24.26,24.26,0,0,0,22,17h6A12,12,0,0,1,19.21,27.55Z"
  })), children);
});
var WindGusts32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindGusts32(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3164,8.0513l-18-6A1,1,0,0,0,10.4,2.2L4,7V2H2V30H4V11l6.4,4.8a1,1,0,0,0,.9165.1489l18-6a1,1,0,0,0,0-1.8974ZM10,13,4.6665,9,10,5Zm4-.0542-2,.667V4.3872l2,.667Zm4-1.333-2,.6665V5.7207l2,.6665Zm2-.667V7.0542L25.8379,9Z"
  })), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,22a4,4,0,0,0-8,0h2a2,2,0,1,1,2,2H8v2h8A4.0045,4.0045,0,0,0,20,22Z"
  })), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,22a4.0045,4.0045,0,0,0-4,4h2a2,2,0,1,1,2,2H12v2H26a4,4,0,0,0,0-8Z"
  })), children);
});
var WindGusts24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindGusts24(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3164,8.0513l-18-6A1,1,0,0,0,10.4,2.2L4,7V2H2V30H4V11l6.4,4.8a1,1,0,0,0,.9165.1489l18-6a1,1,0,0,0,0-1.8974ZM10,13,4.6665,9,10,5Zm4-.0542-2,.667V4.3872l2,.667Zm4-1.333-2,.6665V5.7207l2,.6665Zm2-.667V7.0542L25.8379,9Z"
  })), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,22a4,4,0,0,0-8,0h2a2,2,0,1,1,2,2H8v2h8A4.0045,4.0045,0,0,0,20,22Z"
  })), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,22a4.0045,4.0045,0,0,0-4,4h2a2,2,0,1,1,2,2H12v2H26a4,4,0,0,0,0-8Z"
  })), children);
});
var WindGusts20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindGusts20(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3164,8.0513l-18-6A1,1,0,0,0,10.4,2.2L4,7V2H2V30H4V11l6.4,4.8a1,1,0,0,0,.9165.1489l18-6a1,1,0,0,0,0-1.8974ZM10,13,4.6665,9,10,5Zm4-.0542-2,.667V4.3872l2,.667Zm4-1.333-2,.6665V5.7207l2,.6665Zm2-.667V7.0542L25.8379,9Z"
  })), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,22a4,4,0,0,0-8,0h2a2,2,0,1,1,2,2H8v2h8A4.0045,4.0045,0,0,0,20,22Z"
  })), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,22a4.0045,4.0045,0,0,0-4,4h2a2,2,0,1,1,2,2H12v2H26a4,4,0,0,0,0-8Z"
  })), children);
});
var WindGusts16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindGusts16(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3164,8.0513l-18-6A1,1,0,0,0,10.4,2.2L4,7V2H2V30H4V11l6.4,4.8a1,1,0,0,0,.9165.1489l18-6a1,1,0,0,0,0-1.8974ZM10,13,4.6665,9,10,5Zm4-.0542-2,.667V4.3872l2,.667Zm4-1.333-2,.6665V5.7207l2,.6665Zm2-.667V7.0542L25.8379,9Z"
  })), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,22a4,4,0,0,0-8,0h2a2,2,0,1,1,2,2H8v2h8A4.0045,4.0045,0,0,0,20,22Z"
  })), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,22a4.0045,4.0045,0,0,0-4,4h2a2,2,0,1,1,2,2H12v2H26a4,4,0,0,0,0-8Z"
  })), children);
});
var WindPower32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindPower32(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,28V15.8159a3.0059,3.0059,0,0,0,1.47-1.1186L27.063,17l.5176-1.9321-8.6045-2.3052a2.985,2.985,0,0,0-2.63-2.7275L14.1938,2l-1.9316.5186,2.1318,7.956a2.9588,2.9588,0,0,0-1.093,3.8115L7,20.5859,8.415,22l6.3-6.3A2.8938,2.8938,0,0,0,15,15.8154V28H2v2H30V28Zm0-15a1,1,0,1,1-1-1A1.0008,1.0008,0,0,1,17,13Z"
  })), children);
});
var WindPower24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindPower24(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,28V15.8159a3.0059,3.0059,0,0,0,1.47-1.1186L27.063,17l.5176-1.9321-8.6045-2.3052a2.985,2.985,0,0,0-2.63-2.7275L14.1938,2l-1.9316.5186,2.1318,7.956a2.9588,2.9588,0,0,0-1.093,3.8115L7,20.5859,8.415,22l6.3-6.3A2.8938,2.8938,0,0,0,15,15.8154V28H2v2H30V28Zm0-15a1,1,0,1,1-1-1A1.0008,1.0008,0,0,1,17,13Z"
  })), children);
});
var WindPower20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindPower20(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,28V15.8159a3.0059,3.0059,0,0,0,1.47-1.1186L27.063,17l.5176-1.9321-8.6045-2.3052a2.985,2.985,0,0,0-2.63-2.7275L14.1938,2l-1.9316.5186,2.1318,7.956a2.9588,2.9588,0,0,0-1.093,3.8115L7,20.5859,8.415,22l6.3-6.3A2.8938,2.8938,0,0,0,15,15.8154V28H2v2H30V28Zm0-15a1,1,0,1,1-1-1A1.0008,1.0008,0,0,1,17,13Z"
  })), children);
});
var WindPower16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindPower16(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,28V15.8159a3.0059,3.0059,0,0,0,1.47-1.1186L27.063,17l.5176-1.9321-8.6045-2.3052a2.985,2.985,0,0,0-2.63-2.7275L14.1938,2l-1.9316.5186,2.1318,7.956a2.9588,2.9588,0,0,0-1.093,3.8115L7,20.5859,8.415,22l6.3-6.3A2.8938,2.8938,0,0,0,15,15.8154V28H2v2H30V28Zm0-15a1,1,0,1,1-1-1A1.0008,1.0008,0,0,1,17,13Z"
  })), children);
});
var WindStream32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindStream32(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,2,23.5859,3.4141,26.1719,6h-5.09a16.93,16.93,0,0,0-6.3139,1.2158L10.4893,8.9272A14.93,14.93,0,0,1,4.9185,10H2v2H4.9185a16.93,16.93,0,0,0,6.3139-1.2158l4.2783-1.7114A14.93,14.93,0,0,1,21.0815,8h5.09l-2.586,2.5859L25,12l5-5Z"
  })), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,11l-1.4141,1.4141L22.1719,15H18.9014a16.9422,16.9422,0,0,0-5.9693,1.0825l-2.5664.9624A14.9456,14.9456,0,0,1,5.0986,18H2v2H5.0986a16.9422,16.9422,0,0,0,5.9693-1.0825l2.5664-.9624A14.9456,14.9456,0,0,1,18.9014,17h3.2705l-2.586,2.5859L21,21l5-5Z"
  })), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,20l-1.4141,1.4141L18.1719,24H16.5967a16.9879,16.9879,0,0,0-5.3765.8721l-1.0727.3584A14.9852,14.9852,0,0,1,5.4033,26H2v2H5.4033a16.9879,16.9879,0,0,0,5.3765-.8721l1.0727-.3584A14.9852,14.9852,0,0,1,16.5967,26h1.5752l-2.586,2.5859L17,30l5-5Z"
  })), children);
});
var WindStream24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindStream24(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,2,23.5859,3.4141,26.1719,6h-5.09a16.93,16.93,0,0,0-6.3139,1.2158L10.4893,8.9272A14.93,14.93,0,0,1,4.9185,10H2v2H4.9185a16.93,16.93,0,0,0,6.3139-1.2158l4.2783-1.7114A14.93,14.93,0,0,1,21.0815,8h5.09l-2.586,2.5859L25,12l5-5Z"
  })), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,11l-1.4141,1.4141L22.1719,15H18.9014a16.9422,16.9422,0,0,0-5.9693,1.0825l-2.5664.9624A14.9456,14.9456,0,0,1,5.0986,18H2v2H5.0986a16.9422,16.9422,0,0,0,5.9693-1.0825l2.5664-.9624A14.9456,14.9456,0,0,1,18.9014,17h3.2705l-2.586,2.5859L21,21l5-5Z"
  })), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,20l-1.4141,1.4141L18.1719,24H16.5967a16.9879,16.9879,0,0,0-5.3765.8721l-1.0727.3584A14.9852,14.9852,0,0,1,5.4033,26H2v2H5.4033a16.9879,16.9879,0,0,0,5.3765-.8721l1.0727-.3584A14.9852,14.9852,0,0,1,16.5967,26h1.5752l-2.586,2.5859L17,30l5-5Z"
  })), children);
});
var WindStream20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindStream20(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,2,23.5859,3.4141,26.1719,6h-5.09a16.93,16.93,0,0,0-6.3139,1.2158L10.4893,8.9272A14.93,14.93,0,0,1,4.9185,10H2v2H4.9185a16.93,16.93,0,0,0,6.3139-1.2158l4.2783-1.7114A14.93,14.93,0,0,1,21.0815,8h5.09l-2.586,2.5859L25,12l5-5Z"
  })), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,11l-1.4141,1.4141L22.1719,15H18.9014a16.9422,16.9422,0,0,0-5.9693,1.0825l-2.5664.9624A14.9456,14.9456,0,0,1,5.0986,18H2v2H5.0986a16.9422,16.9422,0,0,0,5.9693-1.0825l2.5664-.9624A14.9456,14.9456,0,0,1,18.9014,17h3.2705l-2.586,2.5859L21,21l5-5Z"
  })), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,20l-1.4141,1.4141L18.1719,24H16.5967a16.9879,16.9879,0,0,0-5.3765.8721l-1.0727.3584A14.9852,14.9852,0,0,1,5.4033,26H2v2H5.4033a16.9879,16.9879,0,0,0,5.3765-.8721l1.0727-.3584A14.9852,14.9852,0,0,1,16.5967,26h1.5752l-2.586,2.5859L17,30l5-5Z"
  })), children);
});
var WindStream16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindStream16(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,2,23.5859,3.4141,26.1719,6h-5.09a16.93,16.93,0,0,0-6.3139,1.2158L10.4893,8.9272A14.93,14.93,0,0,1,4.9185,10H2v2H4.9185a16.93,16.93,0,0,0,6.3139-1.2158l4.2783-1.7114A14.93,14.93,0,0,1,21.0815,8h5.09l-2.586,2.5859L25,12l5-5Z"
  })), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,11l-1.4141,1.4141L22.1719,15H18.9014a16.9422,16.9422,0,0,0-5.9693,1.0825l-2.5664.9624A14.9456,14.9456,0,0,1,5.0986,18H2v2H5.0986a16.9422,16.9422,0,0,0,5.9693-1.0825l2.5664-.9624A14.9456,14.9456,0,0,1,18.9014,17h3.2705l-2.586,2.5859L21,21l5-5Z"
  })), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,20l-1.4141,1.4141L18.1719,24H16.5967a16.9879,16.9879,0,0,0-5.3765.8721l-1.0727.3584A14.9852,14.9852,0,0,1,5.4033,26H2v2H5.4033a16.9879,16.9879,0,0,0,5.3765-.8721l1.0727-.3584A14.9852,14.9852,0,0,1,16.5967,26h1.5752l-2.586,2.5859L17,30l5-5Z"
  })), children);
});
var WatsonHealthWindowAuto32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowAuto32(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 4H17V7H15zM25 15H28V17H25zM15 25H17V28H15zM4 15H7V17H4z"
  })), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.55 7.04H9.55V10.04H7.55z",
    transform: "rotate(-45 8.55 8.548)"
  })), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.96 7.55H24.96V9.55H21.96z",
    transform: "rotate(-45 23.454 8.555)"
  })), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.45 21.95H24.45V24.95H22.45z",
    transform: "rotate(-45 23.452 23.446)"
  })), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.05 22.45H10.05V24.45H7.05z",
    transform: "rotate(-45 8.544 23.451)"
  })), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 30H28V32H4zM4 0H28V2H4zM16 10a6 6 0 106 6A6 6 0 0016 10zm-4 6a4 4 0 014-4v8A4 4 0 0112 16z"
  })), children);
});
var WatsonHealthWindowAuto24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowAuto24(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 4H17V7H15zM25 15H28V17H25zM15 25H17V28H15zM4 15H7V17H4z"
  })), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.55 7.04H9.55V10.04H7.55z",
    transform: "rotate(-45 8.55 8.548)"
  })), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.96 7.55H24.96V9.55H21.96z",
    transform: "rotate(-45 23.454 8.555)"
  })), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.45 21.95H24.45V24.95H22.45z",
    transform: "rotate(-45 23.452 23.446)"
  })), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.05 22.45H10.05V24.45H7.05z",
    transform: "rotate(-45 8.544 23.451)"
  })), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 30H28V32H4zM4 0H28V2H4zM16 10a6 6 0 106 6A6 6 0 0016 10zm-4 6a4 4 0 014-4v8A4 4 0 0112 16z"
  })), children);
});
var WatsonHealthWindowAuto20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowAuto20(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 4H17V7H15zM25 15H28V17H25zM15 25H17V28H15zM4 15H7V17H4z"
  })), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.55 7.04H9.55V10.04H7.55z",
    transform: "rotate(-45 8.55 8.548)"
  })), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.96 7.55H24.96V9.55H21.96z",
    transform: "rotate(-45 23.454 8.555)"
  })), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.45 21.95H24.45V24.95H22.45z",
    transform: "rotate(-45 23.452 23.446)"
  })), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.05 22.45H10.05V24.45H7.05z",
    transform: "rotate(-45 8.544 23.451)"
  })), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 30H28V32H4zM4 0H28V2H4zM16 10a6 6 0 106 6A6 6 0 0016 10zm-4 6a4 4 0 014-4v8A4 4 0 0112 16z"
  })), children);
});
var WatsonHealthWindowAuto16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowAuto16(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 4H17V7H15zM25 15H28V17H25zM15 25H17V28H15zM4 15H7V17H4z"
  })), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.55 7.04H9.55V10.04H7.55z",
    transform: "rotate(-45 8.55 8.548)"
  })), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.96 7.55H24.96V9.55H21.96z",
    transform: "rotate(-45 23.454 8.555)"
  })), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.45 21.95H24.45V24.95H22.45z",
    transform: "rotate(-45 23.452 23.446)"
  })), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.05 22.45H10.05V24.45H7.05z",
    transform: "rotate(-45 8.544 23.451)"
  })), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 30H28V32H4zM4 0H28V2H4zM16 10a6 6 0 106 6A6 6 0 0016 10zm-4 6a4 4 0 014-4v8A4 4 0 0112 16z"
  })), children);
});
var WatsonHealthWindowBase32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowBase32(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V5H15zM25 13H28V15H25zM15 23H17V26H15zM4 13H7V15H4z"
  })), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.55 5.03H9.55V8.030000000000001H7.55z",
    transform: "rotate(-45 8.56 6.544)"
  })), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.96 5.54H24.96V7.54H21.96z",
    transform: "rotate(-45 23.469 6.539)"
  })), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.46 19.94H24.46V22.94H22.46z",
    transform: "rotate(-45 23.462 21.442)"
  })), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.04 20.45H10.04V22.45H7.04z",
    transform: "rotate(-45 8.554 21.447)"
  })), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 28H28V30H4zM16 20a6 6 0 10-6-6A6 6 0 0016 20zm0-10v8a4 4 0 010-8z"
  })), children);
});
var WatsonHealthWindowBase24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowBase24(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V5H15zM25 13H28V15H25zM15 23H17V26H15zM4 13H7V15H4z"
  })), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.55 5.03H9.55V8.030000000000001H7.55z",
    transform: "rotate(-45 8.56 6.544)"
  })), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.96 5.54H24.96V7.54H21.96z",
    transform: "rotate(-45 23.469 6.539)"
  })), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.46 19.94H24.46V22.94H22.46z",
    transform: "rotate(-45 23.462 21.442)"
  })), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.04 20.45H10.04V22.45H7.04z",
    transform: "rotate(-45 8.554 21.447)"
  })), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 28H28V30H4zM16 20a6 6 0 10-6-6A6 6 0 0016 20zm0-10v8a4 4 0 010-8z"
  })), children);
});
var WatsonHealthWindowBase20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowBase20(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V5H15zM25 13H28V15H25zM15 23H17V26H15zM4 13H7V15H4z"
  })), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.55 5.03H9.55V8.030000000000001H7.55z",
    transform: "rotate(-45 8.56 6.544)"
  })), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.96 5.54H24.96V7.54H21.96z",
    transform: "rotate(-45 23.469 6.539)"
  })), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.46 19.94H24.46V22.94H22.46z",
    transform: "rotate(-45 23.462 21.442)"
  })), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.04 20.45H10.04V22.45H7.04z",
    transform: "rotate(-45 8.554 21.447)"
  })), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 28H28V30H4zM16 20a6 6 0 10-6-6A6 6 0 0016 20zm0-10v8a4 4 0 010-8z"
  })), children);
});
var WatsonHealthWindowBase16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowBase16(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V5H15zM25 13H28V15H25zM15 23H17V26H15zM4 13H7V15H4z"
  })), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.55 5.03H9.55V8.030000000000001H7.55z",
    transform: "rotate(-45 8.56 6.544)"
  })), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.96 5.54H24.96V7.54H21.96z",
    transform: "rotate(-45 23.469 6.539)"
  })), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.46 19.94H24.46V22.94H22.46z",
    transform: "rotate(-45 23.462 21.442)"
  })), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.04 20.45H10.04V22.45H7.04z",
    transform: "rotate(-45 8.554 21.447)"
  })), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 28H28V30H4zM16 20a6 6 0 10-6-6A6 6 0 0016 20zm0-10v8a4 4 0 010-8z"
  })), children);
});
var WatsonHealthWindowBlackSaturation32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowBlackSaturation32(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V5H15zM27 15H30V17H27zM15 27H17V30H15zM2 15H5V17H2z"
  })), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.225 5.729H8.228V8.732H6.225z",
    transform: "rotate(-45 7.227 7.23)"
  })), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.267 6.227H26.267V8.227H23.267z",
    transform: "rotate(-45 24.767 7.227)"
  })), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.769 23.269H25.770999999999997V26.270999999999997H23.769z",
    transform: "rotate(-44.999 24.77 24.77)"
  })), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.47 25.126L7.591 23 9 24.419 6.884 26.54 5.47 25.126zM15 13H17V15H15zM19 13H21V15H19zM17 11H19V13H17zM17 15H19V17H17zM17 19H19V21H17zM15 17H17V19H15zM19 17H21V19H19z"
  })), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7a9,9,0,1,0,9,9A9.01,9.01,0,0,0,16,7ZM9,16a7.004,7.004,0,0,1,6-6.92V11h2V9.08a6.9231,6.9231,0,0,1,2,.605V11h1.89c.0374.0366.074.0732.11.11V13h1.3149a6.931,6.931,0,0,1,.6053,2H21v2h1.92a6.931,6.931,0,0,1-.6053,2H21v1.89c-.0364.0372-.073.0738-.11.11H19v1.3149a6.9231,6.9231,0,0,1-2,.605V21H15v1.92A7.004,7.004,0,0,1,9,16Z"
  })), children);
});
var WatsonHealthWindowBlackSaturation24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowBlackSaturation24(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V5H15zM27 15H30V17H27zM15 27H17V30H15zM2 15H5V17H2z"
  })), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.225 5.729H8.228V8.732H6.225z",
    transform: "rotate(-45 7.227 7.23)"
  })), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.267 6.227H26.267V8.227H23.267z",
    transform: "rotate(-45 24.767 7.227)"
  })), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.769 23.269H25.770999999999997V26.270999999999997H23.769z",
    transform: "rotate(-44.999 24.77 24.77)"
  })), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.47 25.126L7.591 23 9 24.419 6.884 26.54 5.47 25.126zM15 13H17V15H15zM19 13H21V15H19zM17 11H19V13H17zM17 15H19V17H17zM17 19H19V21H17zM15 17H17V19H15zM19 17H21V19H19z"
  })), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7a9,9,0,1,0,9,9A9.01,9.01,0,0,0,16,7ZM9,16a7.004,7.004,0,0,1,6-6.92V11h2V9.08a6.9231,6.9231,0,0,1,2,.605V11h1.89c.0374.0366.074.0732.11.11V13h1.3149a6.931,6.931,0,0,1,.6053,2H21v2h1.92a6.931,6.931,0,0,1-.6053,2H21v1.89c-.0364.0372-.073.0738-.11.11H19v1.3149a6.9231,6.9231,0,0,1-2,.605V21H15v1.92A7.004,7.004,0,0,1,9,16Z"
  })), children);
});
var WatsonHealthWindowBlackSaturation20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowBlackSaturation20(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V5H15zM27 15H30V17H27zM15 27H17V30H15zM2 15H5V17H2z"
  })), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.225 5.729H8.228V8.732H6.225z",
    transform: "rotate(-45 7.227 7.23)"
  })), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.267 6.227H26.267V8.227H23.267z",
    transform: "rotate(-45 24.767 7.227)"
  })), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.769 23.269H25.770999999999997V26.270999999999997H23.769z",
    transform: "rotate(-44.999 24.77 24.77)"
  })), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.47 25.126L7.591 23 9 24.419 6.884 26.54 5.47 25.126zM15 13H17V15H15zM19 13H21V15H19zM17 11H19V13H17zM17 15H19V17H17zM17 19H19V21H17zM15 17H17V19H15zM19 17H21V19H19z"
  })), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7a9,9,0,1,0,9,9A9.01,9.01,0,0,0,16,7ZM9,16a7.004,7.004,0,0,1,6-6.92V11h2V9.08a6.9231,6.9231,0,0,1,2,.605V11h1.89c.0374.0366.074.0732.11.11V13h1.3149a6.931,6.931,0,0,1,.6053,2H21v2h1.92a6.931,6.931,0,0,1-.6053,2H21v1.89c-.0364.0372-.073.0738-.11.11H19v1.3149a6.9231,6.9231,0,0,1-2,.605V21H15v1.92A7.004,7.004,0,0,1,9,16Z"
  })), children);
});
var WatsonHealthWindowBlackSaturation16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowBlackSaturation16(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 2H17V5H15zM27 15H30V17H27zM15 27H17V30H15zM2 15H5V17H2z"
  })), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6.225 5.729H8.228V8.732H6.225z",
    transform: "rotate(-45 7.227 7.23)"
  })), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.267 6.227H26.267V8.227H23.267z",
    transform: "rotate(-45 24.767 7.227)"
  })), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.769 23.269H25.770999999999997V26.270999999999997H23.769z",
    transform: "rotate(-44.999 24.77 24.77)"
  })), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.47 25.126L7.591 23 9 24.419 6.884 26.54 5.47 25.126zM15 13H17V15H15zM19 13H21V15H19zM17 11H19V13H17zM17 15H19V17H17zM17 19H19V21H17zM15 17H17V19H15zM19 17H21V19H19z"
  })), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7a9,9,0,1,0,9,9A9.01,9.01,0,0,0,16,7ZM9,16a7.004,7.004,0,0,1,6-6.92V11h2V9.08a6.9231,6.9231,0,0,1,2,.605V11h1.89c.0374.0366.074.0732.11.11V13h1.3149a6.931,6.931,0,0,1,.6053,2H21v2h1.92a6.931,6.931,0,0,1-.6053,2H21v1.89c-.0364.0372-.073.0738-.11.11H19v1.3149a6.9231,6.9231,0,0,1-2,.605V21H15v1.92A7.004,7.004,0,0,1,9,16Z"
  })), children);
});
var WatsonHealthWindowOverlay32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowOverlay32(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 6H17V9H15zM25 17H28V19H25zM15 27H17V30H15zM4 17H7V19H4z"
  })), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.55 9.03H9.55V12.03H7.55z",
    transform: "rotate(-45 8.558 10.545)"
  })), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.96 9.54H24.96V11.54H21.96z",
    transform: "rotate(-45 23.466 10.54)"
  })), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.46 23.94H24.46V26.94H22.46z",
    transform: "rotate(-45 23.459 25.443)"
  })), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.04 24.45H10.04V26.45H7.04z",
    transform: "rotate(-45 8.55 25.448)"
  })), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 2H28V4H4zM16 24a6 6 0 10-6-6A6 6 0 0016 24zm0-10v8a4 4 0 010-8z"
  })), children);
});
var WatsonHealthWindowOverlay24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowOverlay24(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 6H17V9H15zM25 17H28V19H25zM15 27H17V30H15zM4 17H7V19H4z"
  })), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.55 9.03H9.55V12.03H7.55z",
    transform: "rotate(-45 8.558 10.545)"
  })), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.96 9.54H24.96V11.54H21.96z",
    transform: "rotate(-45 23.466 10.54)"
  })), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.46 23.94H24.46V26.94H22.46z",
    transform: "rotate(-45 23.459 25.443)"
  })), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.04 24.45H10.04V26.45H7.04z",
    transform: "rotate(-45 8.55 25.448)"
  })), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 2H28V4H4zM16 24a6 6 0 10-6-6A6 6 0 0016 24zm0-10v8a4 4 0 010-8z"
  })), children);
});
var WatsonHealthWindowOverlay20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowOverlay20(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 6H17V9H15zM25 17H28V19H25zM15 27H17V30H15zM4 17H7V19H4z"
  })), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.55 9.03H9.55V12.03H7.55z",
    transform: "rotate(-45 8.558 10.545)"
  })), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.96 9.54H24.96V11.54H21.96z",
    transform: "rotate(-45 23.466 10.54)"
  })), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.46 23.94H24.46V26.94H22.46z",
    transform: "rotate(-45 23.459 25.443)"
  })), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.04 24.45H10.04V26.45H7.04z",
    transform: "rotate(-45 8.55 25.448)"
  })), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 2H28V4H4zM16 24a6 6 0 10-6-6A6 6 0 0016 24zm0-10v8a4 4 0 010-8z"
  })), children);
});
var WatsonHealthWindowOverlay16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowOverlay16(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 6H17V9H15zM25 17H28V19H25zM15 27H17V30H15zM4 17H7V19H4z"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.55 9.03H9.55V12.03H7.55z",
    transform: "rotate(-45 8.558 10.545)"
  })), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.96 9.54H24.96V11.54H21.96z",
    transform: "rotate(-45 23.466 10.54)"
  })), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.46 23.94H24.46V26.94H22.46z",
    transform: "rotate(-45 23.459 25.443)"
  })), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.04 24.45H10.04V26.45H7.04z",
    transform: "rotate(-45 8.55 25.448)"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 2H28V4H4zM16 24a6 6 0 10-6-6A6 6 0 0016 24zm0-10v8a4 4 0 010-8z"
  })), children);
});
var WatsonHealthWindowPreset32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowPreset32(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 6H17V8H15zM24 15H26V17H24zM15 24H17V26H15zM6 15H8V17H6z"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.586 8.586H10.586V10.586H8.586z",
    transform: "rotate(-45 9.586 9.586)"
  })), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.414 8.586H23.414V10.586H21.414z",
    transform: "rotate(-45 22.414 9.586)"
  })), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.414 21.414H23.414V23.414H21.414z",
    transform: "rotate(-45 22.414 22.414)"
  })), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.586 21.414H10.586V23.414H8.586z",
    transform: "rotate(-45 9.586 22.414)"
  })), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,0-6-6A6,6,0,0,0,16,22Zm0-10v8a4,4,0,0,1,0-8Z"
  })), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var WatsonHealthWindowPreset24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowPreset24(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 6H17V8H15zM24 15H26V17H24zM15 24H17V26H15zM6 15H8V17H6z"
  })), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.586 8.586H10.586V10.586H8.586z",
    transform: "rotate(-45 9.586 9.586)"
  })), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.414 8.586H23.414V10.586H21.414z",
    transform: "rotate(-45 22.414 9.586)"
  })), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.414 21.414H23.414V23.414H21.414z",
    transform: "rotate(-45 22.414 22.414)"
  })), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.586 21.414H10.586V23.414H8.586z",
    transform: "rotate(-45 9.586 22.414)"
  })), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,0-6-6A6,6,0,0,0,16,22Zm0-10v8a4,4,0,0,1,0-8Z"
  })), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var WatsonHealthWindowPreset20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowPreset20(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 6H17V8H15zM24 15H26V17H24zM15 24H17V26H15zM6 15H8V17H6z"
  })), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.586 8.586H10.586V10.586H8.586z",
    transform: "rotate(-45 9.586 9.586)"
  })), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.414 8.586H23.414V10.586H21.414z",
    transform: "rotate(-45 22.414 9.586)"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.414 21.414H23.414V23.414H21.414z",
    transform: "rotate(-45 22.414 22.414)"
  })), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.586 21.414H10.586V23.414H8.586z",
    transform: "rotate(-45 9.586 22.414)"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,0-6-6A6,6,0,0,0,16,22Zm0-10v8a4,4,0,0,1,0-8Z"
  })), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var WatsonHealthWindowPreset16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthWindowPreset16(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 6H17V8H15zM24 15H26V17H24zM15 24H17V26H15zM6 15H8V17H6z"
  })), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.586 8.586H10.586V10.586H8.586z",
    transform: "rotate(-45 9.586 9.586)"
  })), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.414 8.586H23.414V10.586H21.414z",
    transform: "rotate(-45 22.414 9.586)"
  })), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.414 21.414H23.414V23.414H21.414z",
    transform: "rotate(-45 22.414 22.414)"
  })), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.586 21.414H10.586V23.414H8.586z",
    transform: "rotate(-45 9.586 22.414)"
  })), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6,6,0,1,0-6-6A6,6,0,0,0,16,22Zm0-10v8a4,4,0,0,1,0-8Z"
  })), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var Windy32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Windy32(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 15H8V13H21a3 3 0 10-3-3H16a5 5 0 115 5zM23 28a5.0057 5.0057 0 01-5-5h2a3 3 0 103-3H4V18H23a5 5 0 010 10z"
  })), children);
});
var Windy24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Windy24(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 15H8V13H21a3 3 0 10-3-3H16a5 5 0 115 5zM23 28a5.0057 5.0057 0 01-5-5h2a3 3 0 103-3H4V18H23a5 5 0 010 10z"
  })), children);
});
var Windy20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Windy20(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 15H8V13H21a3 3 0 10-3-3H16a5 5 0 115 5zM23 28a5.0057 5.0057 0 01-5-5h2a3 3 0 103-3H4V18H23a5 5 0 010 10z"
  })), children);
});
var Windy16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Windy16(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 15H8V13H21a3 3 0 10-3-3H16a5 5 0 115 5zM23 28a5.0057 5.0057 0 01-5-5h2a3 3 0 103-3H4V18H23a5 5 0 010 10z"
  })), children);
});
var WindyDust32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindyDust32(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 28a5.0057 5.0057 0 01-5-5h2a3 3 0 103-3H22V18h1a5 5 0 010 10zM16 18H20V20H16zM10 18H14V20H10zM4 18H8V20H4zM21 15H20V13h1a3 3 0 10-3-3H16a5 5 0 115 5zM14 13H18V15H14zM8 13H12V15H8z"
  })), children);
});
var WindyDust24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindyDust24(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 28a5.0057 5.0057 0 01-5-5h2a3 3 0 103-3H22V18h1a5 5 0 010 10zM16 18H20V20H16zM10 18H14V20H10zM4 18H8V20H4zM21 15H20V13h1a3 3 0 10-3-3H16a5 5 0 115 5zM14 13H18V15H14zM8 13H12V15H8z"
  })), children);
});
var WindyDust20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindyDust20(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 28a5.0057 5.0057 0 01-5-5h2a3 3 0 103-3H22V18h1a5 5 0 010 10zM16 18H20V20H16zM10 18H14V20H10zM4 18H8V20H4zM21 15H20V13h1a3 3 0 10-3-3H16a5 5 0 115 5zM14 13H18V15H14zM8 13H12V15H8z"
  })), children);
});
var WindyDust16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindyDust16(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 28a5.0057 5.0057 0 01-5-5h2a3 3 0 103-3H22V18h1a5 5 0 010 10zM16 18H20V20H16zM10 18H14V20H10zM4 18H8V20H4zM21 15H20V13h1a3 3 0 10-3-3H16a5 5 0 115 5zM14 13H18V15H14zM8 13H12V15H8z"
  })), children);
});
var WindySnow32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindySnow32(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 28a5.0057 5.0057 0 01-5-5h2a3 3 0 103-3H6V18H25a5 5 0 010 10zM23 15H10V13H23a3 3 0 10-3-3H18a5 5 0 115 5z"
  })), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 23H13V25H11zM13 25H15V27H13zM15 27H17V29H15zM15 23H17V25H15zM11 27H13V29H11zM6 4H8V6H6zM8 6H10V8H8zM10 8H12V10H10zM10 4H12V6H10zM6 8H8V10H6zM2 26H4V28H2zM4 28H6V30H4zM6 30H8V32H6zM6 26H8V28H6zM2 30H4V32H2z"
  })), children);
});
var WindySnow24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindySnow24(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 28a5.0057 5.0057 0 01-5-5h2a3 3 0 103-3H6V18H25a5 5 0 010 10zM23 15H10V13H23a3 3 0 10-3-3H18a5 5 0 115 5z"
  })), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 23H13V25H11zM13 25H15V27H13zM15 27H17V29H15zM15 23H17V25H15zM11 27H13V29H11zM6 4H8V6H6zM8 6H10V8H8zM10 8H12V10H10zM10 4H12V6H10zM6 8H8V10H6zM2 26H4V28H2zM4 28H6V30H4zM6 30H8V32H6zM6 26H8V28H6zM2 30H4V32H2z"
  })), children);
});
var WindySnow20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindySnow20(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 28a5.0057 5.0057 0 01-5-5h2a3 3 0 103-3H6V18H25a5 5 0 010 10zM23 15H10V13H23a3 3 0 10-3-3H18a5 5 0 115 5z"
  })), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 23H13V25H11zM13 25H15V27H13zM15 27H17V29H15zM15 23H17V25H15zM11 27H13V29H11zM6 4H8V6H6zM8 6H10V8H8zM10 8H12V10H10zM10 4H12V6H10zM6 8H8V10H6zM2 26H4V28H2zM4 28H6V30H4zM6 30H8V32H6zM6 26H8V28H6zM2 30H4V32H2z"
  })), children);
});
var WindySnow16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindySnow16(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 28a5.0057 5.0057 0 01-5-5h2a3 3 0 103-3H6V18H25a5 5 0 010 10zM23 15H10V13H23a3 3 0 10-3-3H18a5 5 0 115 5z"
  })), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 23H13V25H11zM13 25H15V27H13zM15 27H17V29H15zM15 23H17V25H15zM11 27H13V29H11zM6 4H8V6H6zM8 6H10V8H8zM10 8H12V10H10zM10 4H12V6H10zM6 8H8V10H6zM2 26H4V28H2zM4 28H6V30H4zM6 30H8V32H6zM6 26H8V28H6zM2 30H4V32H2z"
  })), children);
});
var WindyStrong32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindyStrong32(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,30a5.0057,5.0057,0,0,1-5-5h2a3,3,0,1,0,3-3H4V20h9a5,5,0,0,1,0,10Z"
  })), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 25a5.0057 5.0057 0 01-5-5h2a3 3 0 103-3H2V15H25a5 5 0 010 10zM21 12H6V10H21a3 3 0 10-3-3H16a5 5 0 115 5z"
  })), children);
});
var WindyStrong24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindyStrong24(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,30a5.0057,5.0057,0,0,1-5-5h2a3,3,0,1,0,3-3H4V20h9a5,5,0,0,1,0,10Z"
  })), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 25a5.0057 5.0057 0 01-5-5h2a3 3 0 103-3H2V15H25a5 5 0 010 10zM21 12H6V10H21a3 3 0 10-3-3H16a5 5 0 115 5z"
  })), children);
});
var WindyStrong20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindyStrong20(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,30a5.0057,5.0057,0,0,1-5-5h2a3,3,0,1,0,3-3H4V20h9a5,5,0,0,1,0,10Z"
  })), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 25a5.0057 5.0057 0 01-5-5h2a3 3 0 103-3H2V15H25a5 5 0 010 10zM21 12H6V10H21a3 3 0 10-3-3H16a5 5 0 115 5z"
  })), children);
});
var WindyStrong16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WindyStrong16(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,30a5.0057,5.0057,0,0,1-5-5h2a3,3,0,1,0,3-3H4V20h9a5,5,0,0,1,0,10Z"
  })), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 25a5.0057 5.0057 0 01-5-5h2a3 3 0 103-3H2V15H25a5 5 0 010 10zM21 12H6V10H21a3 3 0 10-3-3H16a5 5 0 115 5z"
  })), children);
});
var WinterWarning32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WinterWarning32(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.684 19.051L19.167 19.891 13 15.486 13 7.369 15.555 5.665 14.445 4.001 12 5.631 9.555 4.001 8.445 5.665 11 7.369 11 14.057 6 10.486 6 8 4 8 4 10.279 1.684 11.051 2.316 12.949 4.833 12.11 10.28 16.001 4.833 19.891 2.316 19.051 1.684 20.949 4 21.721 4 24 6 24 6 21.515 11 17.944 11 24.631 8.445 26.335 9.555 27.999 12 26.368 14.445 27.999 15.555 26.335 13 24.631 13 17.943 18 21.515 18 24 20 24 20 21.721 22.316 20.949 21.684 19.051z"
  })), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,10h-1.5V6h1.5ZM23,11a1,1,0,1,0,1,1A1,1,0,0,0,23,11Z"
  })), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115,13.9355,23.6284,2.3706a.7181.7181,0,0,0-1.2568,0L16.0885,13.9355A.72.72,0,0,0,16.72,15H29.28A.72.72,0,0,0,29.9115,13.9355ZM22.25,6h1.5v4h-1.5ZM23,13a1,1,0,1,1,1-1A1,1,0,0,1,23,13Z"
  })), children);
});
var WinterWarning24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WinterWarning24(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.684 19.051L19.167 19.891 13 15.486 13 7.369 15.555 5.665 14.445 4.001 12 5.631 9.555 4.001 8.445 5.665 11 7.369 11 14.057 6 10.486 6 8 4 8 4 10.279 1.684 11.051 2.316 12.949 4.833 12.11 10.28 16.001 4.833 19.891 2.316 19.051 1.684 20.949 4 21.721 4 24 6 24 6 21.515 11 17.944 11 24.631 8.445 26.335 9.555 27.999 12 26.368 14.445 27.999 15.555 26.335 13 24.631 13 17.943 18 21.515 18 24 20 24 20 21.721 22.316 20.949 21.684 19.051z"
  })), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,10h-1.5V6h1.5ZM23,11a1,1,0,1,0,1,1A1,1,0,0,0,23,11Z"
  })), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115,13.9355,23.6284,2.3706a.7181.7181,0,0,0-1.2568,0L16.0885,13.9355A.72.72,0,0,0,16.72,15H29.28A.72.72,0,0,0,29.9115,13.9355ZM22.25,6h1.5v4h-1.5ZM23,13a1,1,0,1,1,1-1A1,1,0,0,1,23,13Z"
  })), children);
});
var WinterWarning20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WinterWarning20(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.684 19.051L19.167 19.891 13 15.486 13 7.369 15.555 5.665 14.445 4.001 12 5.631 9.555 4.001 8.445 5.665 11 7.369 11 14.057 6 10.486 6 8 4 8 4 10.279 1.684 11.051 2.316 12.949 4.833 12.11 10.28 16.001 4.833 19.891 2.316 19.051 1.684 20.949 4 21.721 4 24 6 24 6 21.515 11 17.944 11 24.631 8.445 26.335 9.555 27.999 12 26.368 14.445 27.999 15.555 26.335 13 24.631 13 17.943 18 21.515 18 24 20 24 20 21.721 22.316 20.949 21.684 19.051z"
  })), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,10h-1.5V6h1.5ZM23,11a1,1,0,1,0,1,1A1,1,0,0,0,23,11Z"
  })), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115,13.9355,23.6284,2.3706a.7181.7181,0,0,0-1.2568,0L16.0885,13.9355A.72.72,0,0,0,16.72,15H29.28A.72.72,0,0,0,29.9115,13.9355ZM22.25,6h1.5v4h-1.5ZM23,13a1,1,0,1,1,1-1A1,1,0,0,1,23,13Z"
  })), children);
});
var WinterWarning16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WinterWarning16(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.684 19.051L19.167 19.891 13 15.486 13 7.369 15.555 5.665 14.445 4.001 12 5.631 9.555 4.001 8.445 5.665 11 7.369 11 14.057 6 10.486 6 8 4 8 4 10.279 1.684 11.051 2.316 12.949 4.833 12.11 10.28 16.001 4.833 19.891 2.316 19.051 1.684 20.949 4 21.721 4 24 6 24 6 21.515 11 17.944 11 24.631 8.445 26.335 9.555 27.999 12 26.368 14.445 27.999 15.555 26.335 13 24.631 13 17.943 18 21.515 18 24 20 24 20 21.721 22.316 20.949 21.684 19.051z"
  })), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M23.75,10h-1.5V6h1.5ZM23,11a1,1,0,1,0,1,1A1,1,0,0,0,23,11Z"
  })), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.9115,13.9355,23.6284,2.3706a.7181.7181,0,0,0-1.2568,0L16.0885,13.9355A.72.72,0,0,0,16.72,15H29.28A.72.72,0,0,0,29.9115,13.9355ZM22.25,6h1.5v4h-1.5ZM23,13a1,1,0,1,1,1-1A1,1,0,0,1,23,13Z"
  })), children);
});
var WintryMix32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WintryMix32(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 26H17V28H15zM17 28H19V30H17zM19 30H21V32H19zM19 26H21V28H19zM15 30H17V32H15zM13 16H15V18H13zM15 18H17V20H15zM17 20H19V22H17zM17 16H19V18H17zM13 20H15V22H13zM10 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 0110 30z"
  })), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0A6.5321,6.5321,0,0,0,2,15.5V22l1,2,1-2V20.18a6.4891,6.4891,0,0,0,3.4294,1.7246L6.106,24.5527a1,1,0,1,0,1.7885.8946l2-4a1,1,0,0,0-.447-1.3418.977.977,0,0,0-.489-.0894V20H8.5a4.4975,4.4975,0,0,1-.356-8.981l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4975,4.4975,0,0,1,23.5,20h-.542v.0083A.9955.9955,0,0,0,22,21v3l1,2,1-2V21.9746a6.4473,6.4473,0,0,0,2-.4761V26l1,2,1-2V20.18A6.4876,6.4876,0,0,0,24.8008,9.1362Z"
  })), children);
});
var WintryMix24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WintryMix24(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 26H17V28H15zM17 28H19V30H17zM19 30H21V32H19zM19 26H21V28H19zM15 30H17V32H15zM13 16H15V18H13zM15 18H17V20H15zM17 20H19V22H17zM17 16H19V18H17zM13 20H15V22H13zM10 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 0110 30z"
  })), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0A6.5321,6.5321,0,0,0,2,15.5V22l1,2,1-2V20.18a6.4891,6.4891,0,0,0,3.4294,1.7246L6.106,24.5527a1,1,0,1,0,1.7885.8946l2-4a1,1,0,0,0-.447-1.3418.977.977,0,0,0-.489-.0894V20H8.5a4.4975,4.4975,0,0,1-.356-8.981l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4975,4.4975,0,0,1,23.5,20h-.542v.0083A.9955.9955,0,0,0,22,21v3l1,2,1-2V21.9746a6.4473,6.4473,0,0,0,2-.4761V26l1,2,1-2V20.18A6.4876,6.4876,0,0,0,24.8008,9.1362Z"
  })), children);
});
var WintryMix20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WintryMix20(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 26H17V28H15zM17 28H19V30H17zM19 30H21V32H19zM19 26H21V28H19zM15 30H17V32H15zM13 16H15V18H13zM15 18H17V20H15zM17 20H19V22H17zM17 16H19V18H17zM13 20H15V22H13zM10 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 0110 30z"
  })), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0A6.5321,6.5321,0,0,0,2,15.5V22l1,2,1-2V20.18a6.4891,6.4891,0,0,0,3.4294,1.7246L6.106,24.5527a1,1,0,1,0,1.7885.8946l2-4a1,1,0,0,0-.447-1.3418.977.977,0,0,0-.489-.0894V20H8.5a4.4975,4.4975,0,0,1-.356-8.981l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4975,4.4975,0,0,1,23.5,20h-.542v.0083A.9955.9955,0,0,0,22,21v3l1,2,1-2V21.9746a6.4473,6.4473,0,0,0,2-.4761V26l1,2,1-2V20.18A6.4876,6.4876,0,0,0,24.8008,9.1362Z"
  })), children);
});
var WintryMix16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WintryMix16(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 26H17V28H15zM17 28H19V30H17zM19 30H21V32H19zM19 26H21V28H19zM15 30H17V32H15zM13 16H15V18H13zM15 18H17V20H15zM17 20H19V22H17zM17 16H19V18H17zM13 20H15V22H13zM10 30a1 1 0 01-.8944-1.4474l2-4.0005a1 1 0 111.7888.8947l-2 4A.9981.9981 0 0110 30z"
  })), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008,9.1362a8.9943,8.9943,0,0,0-17.6006,0A6.5321,6.5321,0,0,0,2,15.5V22l1,2,1-2V20.18a6.4891,6.4891,0,0,0,3.4294,1.7246L6.106,24.5527a1,1,0,1,0,1.7885.8946l2-4a1,1,0,0,0-.447-1.3418.977.977,0,0,0-.489-.0894V20H8.5a4.4975,4.4975,0,0,1-.356-8.981l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639A4.4975,4.4975,0,0,1,23.5,20h-.542v.0083A.9955.9955,0,0,0,22,21v3l1,2,1-2V21.9746a6.4473,6.4473,0,0,0,2-.4761V26l1,2,1-2V20.18A6.4876,6.4876,0,0,0,24.8008,9.1362Z"
  })), children);
});
var WirelessCheckout32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WirelessCheckout32(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28V26A10,10,0,0,0,28,16h2A12,12,0,0,1,18,28Z"
  })), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,23V21a5,5,0,0,0,5-5h2A7,7,0,0,1,18,23Z"
  })), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,11H21V7a3,3,0,0,0-3-3H12A3,3,0,0,0,9,7v4H3a1,1,0,0,0-1,1.15L3.88,24.3a2,2,0,0,0,2,1.7H15V24H5.86L4.17,13H27ZM11,7a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1v4H11Z"
  })), children);
});
var WirelessCheckout24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WirelessCheckout24(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28V26A10,10,0,0,0,28,16h2A12,12,0,0,1,18,28Z"
  })), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,23V21a5,5,0,0,0,5-5h2A7,7,0,0,1,18,23Z"
  })), _path390 || (_path390 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,11H21V7a3,3,0,0,0-3-3H12A3,3,0,0,0,9,7v4H3a1,1,0,0,0-1,1.15L3.88,24.3a2,2,0,0,0,2,1.7H15V24H5.86L4.17,13H27ZM11,7a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1v4H11Z"
  })), children);
});
var WirelessCheckout20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WirelessCheckout20(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path391 || (_path391 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28V26A10,10,0,0,0,28,16h2A12,12,0,0,1,18,28Z"
  })), _path392 || (_path392 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,23V21a5,5,0,0,0,5-5h2A7,7,0,0,1,18,23Z"
  })), _path393 || (_path393 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,11H21V7a3,3,0,0,0-3-3H12A3,3,0,0,0,9,7v4H3a1,1,0,0,0-1,1.15L3.88,24.3a2,2,0,0,0,2,1.7H15V24H5.86L4.17,13H27ZM11,7a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1v4H11Z"
  })), children);
});
var WirelessCheckout16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WirelessCheckout16(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path394 || (_path394 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28V26A10,10,0,0,0,28,16h2A12,12,0,0,1,18,28Z"
  })), _path395 || (_path395 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,23V21a5,5,0,0,0,5-5h2A7,7,0,0,1,18,23Z"
  })), _path396 || (_path396 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,11H21V7a3,3,0,0,0-3-3H12A3,3,0,0,0,9,7v4H3a1,1,0,0,0-1,1.15L3.88,24.3a2,2,0,0,0,2,1.7H15V24H5.86L4.17,13H27ZM11,7a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1v4H11Z"
  })), children);
});
var Wmv32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wmv32(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path397 || (_path397 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 9L27 22 25 9 23 9 25.52 23 28.48 23 31 9 29 9zM19 9L17.48 14 17 15.98 16.54 14 15 9 13 9 13 23 15 23 15 15 14.84 13 15.42 15 17 19.63 18.58 15 19.16 13 19 15 19 23 21 23 21 9 19 9zM9.2 9L8.86 17 8.6 21.54 8.19 18 7.51 12.54 5.49 12.54 4.81 18 4.4 21.54 4.14 17 3.8 9 2 9 3 23 5.27 23 6.03 18.07 6.49 14 6.5 13.97 6.51 14 6.97 18.07 7.73 23 10 23 11 9 9.2 9z"
  })), children);
});
var Wmv24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wmv24(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path398 || (_path398 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 9L27 22 25 9 23 9 25.52 23 28.48 23 31 9 29 9zM19 9L17.48 14 17 15.98 16.54 14 15 9 13 9 13 23 15 23 15 15 14.84 13 15.42 15 17 19.63 18.58 15 19.16 13 19 15 19 23 21 23 21 9 19 9zM9.2 9L8.86 17 8.6 21.54 8.19 18 7.51 12.54 5.49 12.54 4.81 18 4.4 21.54 4.14 17 3.8 9 2 9 3 23 5.27 23 6.03 18.07 6.49 14 6.5 13.97 6.51 14 6.97 18.07 7.73 23 10 23 11 9 9.2 9z"
  })), children);
});
var Wmv20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wmv20(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path399 || (_path399 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 9L27 22 25 9 23 9 25.52 23 28.48 23 31 9 29 9zM19 9L17.48 14 17 15.98 16.54 14 15 9 13 9 13 23 15 23 15 15 14.84 13 15.42 15 17 19.63 18.58 15 19.16 13 19 15 19 23 21 23 21 9 19 9zM9.2 9L8.86 17 8.6 21.54 8.19 18 7.51 12.54 5.49 12.54 4.81 18 4.4 21.54 4.14 17 3.8 9 2 9 3 23 5.27 23 6.03 18.07 6.49 14 6.5 13.97 6.51 14 6.97 18.07 7.73 23 10 23 11 9 9.2 9z"
  })), children);
});
var Wmv16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Wmv16(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path400 || (_path400 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 9L27 22 25 9 23 9 25.52 23 28.48 23 31 9 29 9zM19 9L17.48 14 17 15.98 16.54 14 15 9 13 9 13 23 15 23 15 15 14.84 13 15.42 15 17 19.63 18.58 15 19.16 13 19 15 19 23 21 23 21 9 19 9zM9.2 9L8.86 17 8.6 21.54 8.19 18 7.51 12.54 5.49 12.54 4.81 18 4.4 21.54 4.14 17 3.8 9 2 9 3 23 5.27 23 6.03 18.07 6.49 14 6.5 13.97 6.51 14 6.97 18.07 7.73 23 10 23 11 9 9.2 9z"
  })), children);
});
var WordCloud32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WordCloud32(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path401 || (_path401 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16H22V18H10zM10 20H18V22H10z"
  })), _path402 || (_path402 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7h0a8.0233,8.0233,0,0,1,7.8649,6.4935l.2591,1.346,1.3488.244A5.5019,5.5019,0,0,1,24.5076,26H7.4954a5.5019,5.5019,0,0,1-.9695-10.9165l1.3488-.244.2591-1.346A8.0256,8.0256,0,0,1,16,7m0-2a10.0244,10.0244,0,0,0-9.83,8.1155A7.5019,7.5019,0,0,0,7.4911,28H24.5076a7.5019,7.5019,0,0,0,1.3213-14.8845A10.0229,10.0229,0,0,0,15.9883,5Z"
  })), children);
});
var WordCloud24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WordCloud24(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path403 || (_path403 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16H22V18H10zM10 20H18V22H10z"
  })), _path404 || (_path404 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7h0a8.0233,8.0233,0,0,1,7.8649,6.4935l.2591,1.346,1.3488.244A5.5019,5.5019,0,0,1,24.5076,26H7.4954a5.5019,5.5019,0,0,1-.9695-10.9165l1.3488-.244.2591-1.346A8.0256,8.0256,0,0,1,16,7m0-2a10.0244,10.0244,0,0,0-9.83,8.1155A7.5019,7.5019,0,0,0,7.4911,28H24.5076a7.5019,7.5019,0,0,0,1.3213-14.8845A10.0229,10.0229,0,0,0,15.9883,5Z"
  })), children);
});
var WordCloud20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WordCloud20(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path405 || (_path405 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16H22V18H10zM10 20H18V22H10z"
  })), _path406 || (_path406 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7h0a8.0233,8.0233,0,0,1,7.8649,6.4935l.2591,1.346,1.3488.244A5.5019,5.5019,0,0,1,24.5076,26H7.4954a5.5019,5.5019,0,0,1-.9695-10.9165l1.3488-.244.2591-1.346A8.0256,8.0256,0,0,1,16,7m0-2a10.0244,10.0244,0,0,0-9.83,8.1155A7.5019,7.5019,0,0,0,7.4911,28H24.5076a7.5019,7.5019,0,0,0,1.3213-14.8845A10.0229,10.0229,0,0,0,15.9883,5Z"
  })), children);
});
var WordCloud16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WordCloud16(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path407 || (_path407 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16H22V18H10zM10 20H18V22H10z"
  })), _path408 || (_path408 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7h0a8.0233,8.0233,0,0,1,7.8649,6.4935l.2591,1.346,1.3488.244A5.5019,5.5019,0,0,1,24.5076,26H7.4954a5.5019,5.5019,0,0,1-.9695-10.9165l1.3488-.244.2591-1.346A8.0256,8.0256,0,0,1,16,7m0-2a10.0244,10.0244,0,0,0-9.83,8.1155A7.5019,7.5019,0,0,0,7.4911,28H24.5076a7.5019,7.5019,0,0,0,1.3213-14.8845A10.0229,10.0229,0,0,0,15.9883,5Z"
  })), children);
});
var Workspace32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Workspace32(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path409 || (_path409 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 17v8H6V17H16m0-2H6a2 2 0 00-2 2v8a2 2 0 002 2H16a2 2 0 002-2V17a2 2 0 00-2-2zM27 6v5H17V6H27m0-2H17a2 2 0 00-2 2v5a2 2 0 002 2H27a2 2 0 002-2V6a2 2 0 00-2-2zM27 17v5H22V17h5m0-2H22a2 2 0 00-2 2v5a2 2 0 002 2h5a2 2 0 002-2V17a2 2 0 00-2-2zM11 6v5H6V6h5m0-2H6A2 2 0 004 6v5a2 2 0 002 2h5a2 2 0 002-2V6a2 2 0 00-2-2z"
  })), children);
});
var Workspace24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Workspace24(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path410 || (_path410 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 17v8H6V17H16m0-2H6a2 2 0 00-2 2v8a2 2 0 002 2H16a2 2 0 002-2V17a2 2 0 00-2-2zM27 6v5H17V6H27m0-2H17a2 2 0 00-2 2v5a2 2 0 002 2H27a2 2 0 002-2V6a2 2 0 00-2-2zM27 17v5H22V17h5m0-2H22a2 2 0 00-2 2v5a2 2 0 002 2h5a2 2 0 002-2V17a2 2 0 00-2-2zM11 6v5H6V6h5m0-2H6A2 2 0 004 6v5a2 2 0 002 2h5a2 2 0 002-2V6a2 2 0 00-2-2z"
  })), children);
});
var Workspace20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Workspace20(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path411 || (_path411 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 17v8H6V17H16m0-2H6a2 2 0 00-2 2v8a2 2 0 002 2H16a2 2 0 002-2V17a2 2 0 00-2-2zM27 6v5H17V6H27m0-2H17a2 2 0 00-2 2v5a2 2 0 002 2H27a2 2 0 002-2V6a2 2 0 00-2-2zM27 17v5H22V17h5m0-2H22a2 2 0 00-2 2v5a2 2 0 002 2h5a2 2 0 002-2V17a2 2 0 00-2-2zM11 6v5H6V6h5m0-2H6A2 2 0 004 6v5a2 2 0 002 2h5a2 2 0 002-2V6a2 2 0 00-2-2z"
  })), children);
});
var Workspace16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Workspace16(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path412 || (_path412 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 17v8H6V17H16m0-2H6a2 2 0 00-2 2v8a2 2 0 002 2H16a2 2 0 002-2V17a2 2 0 00-2-2zM27 6v5H17V6H27m0-2H17a2 2 0 00-2 2v5a2 2 0 002 2H27a2 2 0 002-2V6a2 2 0 00-2-2zM27 17v5H22V17h5m0-2H22a2 2 0 00-2 2v5a2 2 0 002 2h5a2 2 0 002-2V17a2 2 0 00-2-2zM11 6v5H6V6h5m0-2H6A2 2 0 004 6v5a2 2 0 002 2h5a2 2 0 002-2V6a2 2 0 00-2-2z"
  })), children);
});
var WorkspaceImport32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WorkspaceImport32(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path413 || (_path413 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 6v5H17V6H27m0-2H17a2 2 0 00-2 2v5a2 2 0 002 2H27a2 2 0 002-2V6a2 2 0 00-2-2zM12 25H6V17h6V15H6a2 2 0 00-2 2v8a2 2 0 002 2h6zM30 20L16.828 20 19.414 17.414 18 16 13 21 18 26 19.414 24.586 16.828 22 30 22 30 20zM11 6v5H6V6h5m0-2H6A2 2 0 004 6v5a2 2 0 002 2h5a2 2 0 002-2V6a2 2 0 00-2-2z"
  })), children);
});
var WorkspaceImport24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WorkspaceImport24(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path414 || (_path414 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 6v5H17V6H27m0-2H17a2 2 0 00-2 2v5a2 2 0 002 2H27a2 2 0 002-2V6a2 2 0 00-2-2zM12 25H6V17h6V15H6a2 2 0 00-2 2v8a2 2 0 002 2h6zM30 20L16.828 20 19.414 17.414 18 16 13 21 18 26 19.414 24.586 16.828 22 30 22 30 20zM11 6v5H6V6h5m0-2H6A2 2 0 004 6v5a2 2 0 002 2h5a2 2 0 002-2V6a2 2 0 00-2-2z"
  })), children);
});
var WorkspaceImport20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WorkspaceImport20(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path415 || (_path415 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 6v5H17V6H27m0-2H17a2 2 0 00-2 2v5a2 2 0 002 2H27a2 2 0 002-2V6a2 2 0 00-2-2zM12 25H6V17h6V15H6a2 2 0 00-2 2v8a2 2 0 002 2h6zM30 20L16.828 20 19.414 17.414 18 16 13 21 18 26 19.414 24.586 16.828 22 30 22 30 20zM11 6v5H6V6h5m0-2H6A2 2 0 004 6v5a2 2 0 002 2h5a2 2 0 002-2V6a2 2 0 00-2-2z"
  })), children);
});
var WorkspaceImport16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WorkspaceImport16(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path416 || (_path416 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 6v5H17V6H27m0-2H17a2 2 0 00-2 2v5a2 2 0 002 2H27a2 2 0 002-2V6a2 2 0 00-2-2zM12 25H6V17h6V15H6a2 2 0 00-2 2v8a2 2 0 002 2h6zM30 20L16.828 20 19.414 17.414 18 16 13 21 18 26 19.414 24.586 16.828 22 30 22 30 20zM11 6v5H6V6h5m0-2H6A2 2 0 004 6v5a2 2 0 002 2h5a2 2 0 002-2V6a2 2 0 00-2-2z"
  })), children);
});
var Worship32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Worship32(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path417 || (_path417 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5859,17,22,21.5859v0h0l-5-5a2.002,2.002,0,0,0-2.8286,0L9.585,21.1709A2.0031,2.0031,0,0,0,9.585,24l4.0009,4H6v2H16a1,1,0,0,0,.707-1.707L11,22.585,15.5852,18l5.7078,5.707a.9995.9995,0,0,0,1.414,0L28,18.4141Z"
  })), _path418 || (_path418 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.5,17A3.5,3.5,0,1,1,25,13.5,3.5042,3.5042,0,0,1,21.5,17Zm0-5A1.5,1.5,0,1,0,23,13.5,1.5017,1.5017,0,0,0,21.5,12Z"
  })), _path419 || (_path419 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,10.5977l12-6.462,12.5264,6.7452.9472-1.7618-13-7a1.0045,1.0045,0,0,0-.9472,0l-13,7A1,1,0,0,0,2,10V30H4Z"
  })), children);
});
var Worship24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Worship24(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path420 || (_path420 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5859,17,22,21.5859v0h0l-5-5a2.002,2.002,0,0,0-2.8286,0L9.585,21.1709A2.0031,2.0031,0,0,0,9.585,24l4.0009,4H6v2H16a1,1,0,0,0,.707-1.707L11,22.585,15.5852,18l5.7078,5.707a.9995.9995,0,0,0,1.414,0L28,18.4141Z"
  })), _path421 || (_path421 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.5,17A3.5,3.5,0,1,1,25,13.5,3.5042,3.5042,0,0,1,21.5,17Zm0-5A1.5,1.5,0,1,0,23,13.5,1.5017,1.5017,0,0,0,21.5,12Z"
  })), _path422 || (_path422 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,10.5977l12-6.462,12.5264,6.7452.9472-1.7618-13-7a1.0045,1.0045,0,0,0-.9472,0l-13,7A1,1,0,0,0,2,10V30H4Z"
  })), children);
});
var Worship20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Worship20(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path423 || (_path423 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5859,17,22,21.5859v0h0l-5-5a2.002,2.002,0,0,0-2.8286,0L9.585,21.1709A2.0031,2.0031,0,0,0,9.585,24l4.0009,4H6v2H16a1,1,0,0,0,.707-1.707L11,22.585,15.5852,18l5.7078,5.707a.9995.9995,0,0,0,1.414,0L28,18.4141Z"
  })), _path424 || (_path424 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.5,17A3.5,3.5,0,1,1,25,13.5,3.5042,3.5042,0,0,1,21.5,17Zm0-5A1.5,1.5,0,1,0,23,13.5,1.5017,1.5017,0,0,0,21.5,12Z"
  })), _path425 || (_path425 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,10.5977l12-6.462,12.5264,6.7452.9472-1.7618-13-7a1.0045,1.0045,0,0,0-.9472,0l-13,7A1,1,0,0,0,2,10V30H4Z"
  })), children);
});
var Worship16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Worship16(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path426 || (_path426 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5859,17,22,21.5859v0h0l-5-5a2.002,2.002,0,0,0-2.8286,0L9.585,21.1709A2.0031,2.0031,0,0,0,9.585,24l4.0009,4H6v2H16a1,1,0,0,0,.707-1.707L11,22.585,15.5852,18l5.7078,5.707a.9995.9995,0,0,0,1.414,0L28,18.4141Z"
  })), _path427 || (_path427 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.5,17A3.5,3.5,0,1,1,25,13.5,3.5042,3.5042,0,0,1,21.5,17Zm0-5A1.5,1.5,0,1,0,23,13.5,1.5017,1.5017,0,0,0,21.5,12Z"
  })), _path428 || (_path428 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,10.5977l12-6.462,12.5264,6.7452.9472-1.7618-13-7a1.0045,1.0045,0,0,0-.9472,0l-13,7A1,1,0,0,0,2,10V30H4Z"
  })), children);
});
var WorshipChristian32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WorshipChristian32(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path429 || (_path429 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,30H15a2.0021,2.0021,0,0,1-2-2V14H8a2.0021,2.0021,0,0,1-2-2V10A2.0021,2.0021,0,0,1,8,8h5V4a2.0021,2.0021,0,0,1,2-2h2a2.0021,2.0021,0,0,1,2,2V8h5a2.0021,2.0021,0,0,1,2,2v2a2.0021,2.0021,0,0,1-2,2H19V28A2.0021,2.0021,0,0,1,17,30ZM8,10v2h7V28h2V12h7V10H17V4H15v6Z"
  })), children);
});
var WorshipChristian24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WorshipChristian24(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path430 || (_path430 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,30H15a2.0021,2.0021,0,0,1-2-2V14H8a2.0021,2.0021,0,0,1-2-2V10A2.0021,2.0021,0,0,1,8,8h5V4a2.0021,2.0021,0,0,1,2-2h2a2.0021,2.0021,0,0,1,2,2V8h5a2.0021,2.0021,0,0,1,2,2v2a2.0021,2.0021,0,0,1-2,2H19V28A2.0021,2.0021,0,0,1,17,30ZM8,10v2h7V28h2V12h7V10H17V4H15v6Z"
  })), children);
});
var WorshipChristian20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WorshipChristian20(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path431 || (_path431 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,30H15a2.0021,2.0021,0,0,1-2-2V14H8a2.0021,2.0021,0,0,1-2-2V10A2.0021,2.0021,0,0,1,8,8h5V4a2.0021,2.0021,0,0,1,2-2h2a2.0021,2.0021,0,0,1,2,2V8h5a2.0021,2.0021,0,0,1,2,2v2a2.0021,2.0021,0,0,1-2,2H19V28A2.0021,2.0021,0,0,1,17,30ZM8,10v2h7V28h2V12h7V10H17V4H15v6Z"
  })), children);
});
var WorshipChristian16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WorshipChristian16(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path432 || (_path432 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,30H15a2.0021,2.0021,0,0,1-2-2V14H8a2.0021,2.0021,0,0,1-2-2V10A2.0021,2.0021,0,0,1,8,8h5V4a2.0021,2.0021,0,0,1,2-2h2a2.0021,2.0021,0,0,1,2,2V8h5a2.0021,2.0021,0,0,1,2,2v2a2.0021,2.0021,0,0,1-2,2H19V28A2.0021,2.0021,0,0,1,17,30ZM8,10v2h7V28h2V12h7V10H17V4H15v6Z"
  })), children);
});
var WorshipJewish32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WorshipJewish32(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path433 || (_path433 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.291,16l3.585-6.5181A1,1,0,0,0,27,8H19.8911L16.876,2.5181a1,1,0,0,0-1.752,0L12.1089,8H5a1,1,0,0,0-.876,1.4819L7.709,16,4.124,22.5181A1,1,0,0,0,5,24h7.1089l3.0151,5.4819a1,1,0,0,0,1.752,0L19.8911,24H27a1,1,0,0,0,.876-1.4819Zm-5.5823,6L16,26.9248,13.2913,22h-6.6l3.3-6-3.3-6h6.6L16,5.0752,18.7087,10h6.6l-3.3,6,3.3,6Z"
  })), children);
});
var WorshipJewish24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WorshipJewish24(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path434 || (_path434 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.291,16l3.585-6.5181A1,1,0,0,0,27,8H19.8911L16.876,2.5181a1,1,0,0,0-1.752,0L12.1089,8H5a1,1,0,0,0-.876,1.4819L7.709,16,4.124,22.5181A1,1,0,0,0,5,24h7.1089l3.0151,5.4819a1,1,0,0,0,1.752,0L19.8911,24H27a1,1,0,0,0,.876-1.4819Zm-5.5823,6L16,26.9248,13.2913,22h-6.6l3.3-6-3.3-6h6.6L16,5.0752,18.7087,10h6.6l-3.3,6,3.3,6Z"
  })), children);
});
var WorshipJewish20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WorshipJewish20(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path435 || (_path435 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.291,16l3.585-6.5181A1,1,0,0,0,27,8H19.8911L16.876,2.5181a1,1,0,0,0-1.752,0L12.1089,8H5a1,1,0,0,0-.876,1.4819L7.709,16,4.124,22.5181A1,1,0,0,0,5,24h7.1089l3.0151,5.4819a1,1,0,0,0,1.752,0L19.8911,24H27a1,1,0,0,0,.876-1.4819Zm-5.5823,6L16,26.9248,13.2913,22h-6.6l3.3-6-3.3-6h6.6L16,5.0752,18.7087,10h6.6l-3.3,6,3.3,6Z"
  })), children);
});
var WorshipJewish16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WorshipJewish16(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path436 || (_path436 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.291,16l3.585-6.5181A1,1,0,0,0,27,8H19.8911L16.876,2.5181a1,1,0,0,0-1.752,0L12.1089,8H5a1,1,0,0,0-.876,1.4819L7.709,16,4.124,22.5181A1,1,0,0,0,5,24h7.1089l3.0151,5.4819a1,1,0,0,0,1.752,0L19.8911,24H27a1,1,0,0,0,.876-1.4819Zm-5.5823,6L16,26.9248,13.2913,22h-6.6l3.3-6-3.3-6h6.6L16,5.0752,18.7087,10h6.6l-3.3,6,3.3,6Z"
  })), children);
});
var WorshipMuslim32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WorshipMuslim32(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path437 || (_path437 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,18a.9986.9986,0,0,1-.5415-.1594L22,14.9688l-4.4585,2.8718a1,1,0,0,1-1.5088-1.095l1.35-5.1318L14.3105,8.69a1,1,0,0,1,.5508-1.7146l4.3745-.6128,1.8663-3.8032A1.0008,1.0008,0,0,1,21.9878,2a1.0171,1.0171,0,0,1,.8989.5378L24.88,6.3625l4.2622.6133A1,1,0,0,1,29.69,8.69l-3.0723,2.9239,1.35,5.1318A1,1,0,0,1,27,18Zm-5-5.2207a.999.999,0,0,1,.5415.1594l2.8369,1.8272-.8457-3.2149a1.0006,1.0006,0,0,1,.2778-.9787l2.0074-1.91-2.73-.3929a.9994.9994,0,0,1-.7441-.5275L22.0269,5.2151,20.7979,7.72a1.0008,1.0008,0,0,1-.7593.55L17.19,8.6687l2,1.9036a1.0006,1.0006,0,0,1,.2778.9787l-.8457,3.2149,2.8369-1.8272A.999.999,0,0,1,22,12.7793Z"
  })), _path438 || (_path438 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.8169,30A13.8137,13.8137,0,0,1,9.0752,4.1277a1,1,0,0,1,1.3613,1.3611A11.8091,11.8091,0,0,0,26.5107,21.5635a1,1,0,0,1,1.3619,1.3611A13.8411,13.8411,0,0,1,15.8169,30ZM7.3271,7.9727a11.81,11.81,0,0,0,16.7,16.7,13.8086,13.8086,0,0,1-16.7-16.7Z"
  })), children);
});
var WorshipMuslim24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WorshipMuslim24(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path439 || (_path439 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,18a.9986.9986,0,0,1-.5415-.1594L22,14.9688l-4.4585,2.8718a1,1,0,0,1-1.5088-1.095l1.35-5.1318L14.3105,8.69a1,1,0,0,1,.5508-1.7146l4.3745-.6128,1.8663-3.8032A1.0008,1.0008,0,0,1,21.9878,2a1.0171,1.0171,0,0,1,.8989.5378L24.88,6.3625l4.2622.6133A1,1,0,0,1,29.69,8.69l-3.0723,2.9239,1.35,5.1318A1,1,0,0,1,27,18Zm-5-5.2207a.999.999,0,0,1,.5415.1594l2.8369,1.8272-.8457-3.2149a1.0006,1.0006,0,0,1,.2778-.9787l2.0074-1.91-2.73-.3929a.9994.9994,0,0,1-.7441-.5275L22.0269,5.2151,20.7979,7.72a1.0008,1.0008,0,0,1-.7593.55L17.19,8.6687l2,1.9036a1.0006,1.0006,0,0,1,.2778.9787l-.8457,3.2149,2.8369-1.8272A.999.999,0,0,1,22,12.7793Z"
  })), _path440 || (_path440 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.8169,30A13.8137,13.8137,0,0,1,9.0752,4.1277a1,1,0,0,1,1.3613,1.3611A11.8091,11.8091,0,0,0,26.5107,21.5635a1,1,0,0,1,1.3619,1.3611A13.8411,13.8411,0,0,1,15.8169,30ZM7.3271,7.9727a11.81,11.81,0,0,0,16.7,16.7,13.8086,13.8086,0,0,1-16.7-16.7Z"
  })), children);
});
var WorshipMuslim20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WorshipMuslim20(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path441 || (_path441 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,18a.9986.9986,0,0,1-.5415-.1594L22,14.9688l-4.4585,2.8718a1,1,0,0,1-1.5088-1.095l1.35-5.1318L14.3105,8.69a1,1,0,0,1,.5508-1.7146l4.3745-.6128,1.8663-3.8032A1.0008,1.0008,0,0,1,21.9878,2a1.0171,1.0171,0,0,1,.8989.5378L24.88,6.3625l4.2622.6133A1,1,0,0,1,29.69,8.69l-3.0723,2.9239,1.35,5.1318A1,1,0,0,1,27,18Zm-5-5.2207a.999.999,0,0,1,.5415.1594l2.8369,1.8272-.8457-3.2149a1.0006,1.0006,0,0,1,.2778-.9787l2.0074-1.91-2.73-.3929a.9994.9994,0,0,1-.7441-.5275L22.0269,5.2151,20.7979,7.72a1.0008,1.0008,0,0,1-.7593.55L17.19,8.6687l2,1.9036a1.0006,1.0006,0,0,1,.2778.9787l-.8457,3.2149,2.8369-1.8272A.999.999,0,0,1,22,12.7793Z"
  })), _path442 || (_path442 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.8169,30A13.8137,13.8137,0,0,1,9.0752,4.1277a1,1,0,0,1,1.3613,1.3611A11.8091,11.8091,0,0,0,26.5107,21.5635a1,1,0,0,1,1.3619,1.3611A13.8411,13.8411,0,0,1,15.8169,30ZM7.3271,7.9727a11.81,11.81,0,0,0,16.7,16.7,13.8086,13.8086,0,0,1-16.7-16.7Z"
  })), children);
});
var WorshipMuslim16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WorshipMuslim16(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path443 || (_path443 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,18a.9986.9986,0,0,1-.5415-.1594L22,14.9688l-4.4585,2.8718a1,1,0,0,1-1.5088-1.095l1.35-5.1318L14.3105,8.69a1,1,0,0,1,.5508-1.7146l4.3745-.6128,1.8663-3.8032A1.0008,1.0008,0,0,1,21.9878,2a1.0171,1.0171,0,0,1,.8989.5378L24.88,6.3625l4.2622.6133A1,1,0,0,1,29.69,8.69l-3.0723,2.9239,1.35,5.1318A1,1,0,0,1,27,18Zm-5-5.2207a.999.999,0,0,1,.5415.1594l2.8369,1.8272-.8457-3.2149a1.0006,1.0006,0,0,1,.2778-.9787l2.0074-1.91-2.73-.3929a.9994.9994,0,0,1-.7441-.5275L22.0269,5.2151,20.7979,7.72a1.0008,1.0008,0,0,1-.7593.55L17.19,8.6687l2,1.9036a1.0006,1.0006,0,0,1,.2778.9787l-.8457,3.2149,2.8369-1.8272A.999.999,0,0,1,22,12.7793Z"
  })), _path444 || (_path444 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.8169,30A13.8137,13.8137,0,0,1,9.0752,4.1277a1,1,0,0,1,1.3613,1.3611A11.8091,11.8091,0,0,0,26.5107,21.5635a1,1,0,0,1,1.3619,1.3611A13.8411,13.8411,0,0,1,15.8169,30ZM7.3271,7.9727a11.81,11.81,0,0,0,16.7,16.7,13.8086,13.8086,0,0,1-16.7-16.7Z"
  })), children);
});
var QX32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QX32(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path445 || (_path445 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L18 9 16 15 14 9 12 9 14.75 16 12 23 14 23 16 17 18 23 20 23 17.25 16 20 9z"
  })), children);
});
var QX24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QX24(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path446 || (_path446 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L18 9 16 15 14 9 12 9 14.75 16 12 23 14 23 16 17 18 23 20 23 17.25 16 20 9z"
  })), children);
});
var QX20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QX20(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path447 || (_path447 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L18 9 16 15 14 9 12 9 14.75 16 12 23 14 23 16 17 18 23 20 23 17.25 16 20 9z"
  })), children);
});
var QX16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QX16(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path448 || (_path448 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L18 9 16 15 14 9 12 9 14.75 16 12 23 14 23 16 17 18 23 20 23 17.25 16 20 9z"
  })), children);
});
var XAxis32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function XAxis32(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path449 || (_path449 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,20l-1.4141,1.4141L24.1719,24H6V4H4V24a2.0023,2.0023,0,0,0,2,2H24.1719l-2.586,2.5859L23,30l5-5Z"
  })), children);
});
var XAxis24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function XAxis24(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path450 || (_path450 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,20l-1.4141,1.4141L24.1719,24H6V4H4V24a2.0023,2.0023,0,0,0,2,2H24.1719l-2.586,2.5859L23,30l5-5Z"
  })), children);
});
var XAxis20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function XAxis20(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path451 || (_path451 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,20l-1.4141,1.4141L24.1719,24H6V4H4V24a2.0023,2.0023,0,0,0,2,2H24.1719l-2.586,2.5859L23,30l5-5Z"
  })), children);
});
var XAxis16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function XAxis16(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path452 || (_path452 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,20l-1.4141,1.4141L24.1719,24H6V4H4V24a2.0023,2.0023,0,0,0,2,2H24.1719l-2.586,2.5859L23,30l5-5Z"
  })), children);
});
var Xls32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Xls32(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path453 || (_path453 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 23H22V21h6V17H24a2.002 2.002 0 01-2-2V11a2.002 2.002 0 012-2h6v2H24v4h4a2.002 2.002 0 012 2v4A2.0023 2.0023 0 0128 23zM14 21L14 9 12 9 12 23 20 23 20 21 14 21zM10 9L8 9 6 15 4 9 2 9 4.752 16 2 23 4 23 6 17 8 23 10 23 7.245 16 10 9z"
  })), children);
});
var Xls24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Xls24(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path454 || (_path454 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 23H22V21h6V17H24a2.002 2.002 0 01-2-2V11a2.002 2.002 0 012-2h6v2H24v4h4a2.002 2.002 0 012 2v4A2.0023 2.0023 0 0128 23zM14 21L14 9 12 9 12 23 20 23 20 21 14 21zM10 9L8 9 6 15 4 9 2 9 4.752 16 2 23 4 23 6 17 8 23 10 23 7.245 16 10 9z"
  })), children);
});
var Xls20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Xls20(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path455 || (_path455 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 23H22V21h6V17H24a2.002 2.002 0 01-2-2V11a2.002 2.002 0 012-2h6v2H24v4h4a2.002 2.002 0 012 2v4A2.0023 2.0023 0 0128 23zM14 21L14 9 12 9 12 23 20 23 20 21 14 21zM10 9L8 9 6 15 4 9 2 9 4.752 16 2 23 4 23 6 17 8 23 10 23 7.245 16 10 9z"
  })), children);
});
var Xls16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Xls16(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path456 || (_path456 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 23H22V21h6V17H24a2.002 2.002 0 01-2-2V11a2.002 2.002 0 012-2h6v2H24v4h4a2.002 2.002 0 012 2v4A2.0023 2.0023 0 0128 23zM14 21L14 9 12 9 12 23 20 23 20 21 14 21zM10 9L8 9 6 15 4 9 2 9 4.752 16 2 23 4 23 6 17 8 23 10 23 7.245 16 10 9z"
  })), children);
});
var Xml32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Xml32(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path457 || (_path457 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21L24 9 22 9 22 23 30 23 30 21 24 21zM18 9L16.48 14 16 15.98 15.54 14 14 9 12 9 12 23 14 23 14 15 13.84 13 14.42 15 16 19.63 17.58 15 18.16 13 18 15 18 23 20 23 20 9 18 9zM10 9L8 9 6 15 4 9 2 9 4.75 16 2 23 4 23 6 17 8 23 10 23 7.25 16 10 9z"
  })), children);
});
var Xml24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Xml24(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path458 || (_path458 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21L24 9 22 9 22 23 30 23 30 21 24 21zM18 9L16.48 14 16 15.98 15.54 14 14 9 12 9 12 23 14 23 14 15 13.84 13 14.42 15 16 19.63 17.58 15 18.16 13 18 15 18 23 20 23 20 9 18 9zM10 9L8 9 6 15 4 9 2 9 4.75 16 2 23 4 23 6 17 8 23 10 23 7.25 16 10 9z"
  })), children);
});
var Xml20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Xml20(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path459 || (_path459 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21L24 9 22 9 22 23 30 23 30 21 24 21zM18 9L16.48 14 16 15.98 15.54 14 14 9 12 9 12 23 14 23 14 15 13.84 13 14.42 15 16 19.63 17.58 15 18.16 13 18 15 18 23 20 23 20 9 18 9zM10 9L8 9 6 15 4 9 2 9 4.75 16 2 23 4 23 6 17 8 23 10 23 7.25 16 10 9z"
  })), children);
});
var Xml16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Xml16(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path460 || (_path460 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21L24 9 22 9 22 23 30 23 30 21 24 21zM18 9L16.48 14 16 15.98 15.54 14 14 9 12 9 12 23 14 23 14 15 13.84 13 14.42 15 16 19.63 17.58 15 18.16 13 18 15 18 23 20 23 20 9 18 9zM10 9L8 9 6 15 4 9 2 9 4.75 16 2 23 4 23 6 17 8 23 10 23 7.25 16 10 9z"
  })), children);
});
var QY32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QY32(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path461 || (_path461 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L18 9 16 16 14 9 12 9 15 18 15 23 17 23 17 18 20 9z"
  })), children);
});
var QY24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QY24(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path462 || (_path462 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L18 9 16 16 14 9 12 9 15 18 15 23 17 23 17 18 20 9z"
  })), children);
});
var QY20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QY20(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path463 || (_path463 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L18 9 16 16 14 9 12 9 15 18 15 23 17 23 17 18 20 9z"
  })), children);
});
var QY16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QY16(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path464 || (_path464 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L18 9 16 16 14 9 12 9 15 18 15 23 17 23 17 18 20 9z"
  })), children);
});
var YAxis32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function YAxis32(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path465 || (_path465 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,26V7.8281l2.5859,2.586L12,9,7,4,2,9l1.4141,1.4141L6,7.8281V26a2.0023,2.0023,0,0,0,2,2H28V26Z"
  })), children);
});
var YAxis24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function YAxis24(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path466 || (_path466 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,26V7.8281l2.5859,2.586L12,9,7,4,2,9l1.4141,1.4141L6,7.8281V26a2.0023,2.0023,0,0,0,2,2H28V26Z"
  })), children);
});
var YAxis20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function YAxis20(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path467 || (_path467 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,26V7.8281l2.5859,2.586L12,9,7,4,2,9l1.4141,1.4141L6,7.8281V26a2.0023,2.0023,0,0,0,2,2H28V26Z"
  })), children);
});
var YAxis16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function YAxis16(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path468 || (_path468 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,26V7.8281l2.5859,2.586L12,9,7,4,2,9l1.4141,1.4141L6,7.8281V26a2.0023,2.0023,0,0,0,2,2H28V26Z"
  })), children);
});
var QZ32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QZ32(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path469 || (_path469 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L12 9 12 11 18 11 12 21 12 23 20 23 20 21 14 21 20 11 20 9z"
  })), children);
});
var QZ24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QZ24(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path470 || (_path470 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L12 9 12 11 18 11 12 21 12 23 20 23 20 21 14 21 20 11 20 9z"
  })), children);
});
var QZ20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QZ20(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path471 || (_path471 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L12 9 12 11 18 11 12 21 12 23 20 23 20 21 14 21 20 11 20 9z"
  })), children);
});
var QZ16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QZ16(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path472 || (_path472 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 9L12 9 12 11 18 11 12 21 12 23 20 23 20 21 14 21 20 11 20 9z"
  })), children);
});
var ZAxis32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZAxis32(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path473 || (_path473 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 22L26 25.586 17 16.586 17 10 17 6 17 5.828 19.586 8.414 21 7 16 2 11 7 12.414 8.414 15 5.828 15 6 15 10 15 16.586 6 25.586 6 22 4 22 4 29 11 29 11 27 7.414 27 16 18.414 24.586 27 21 27 21 29 28 29 28 22 26 22z"
  })), children);
});
var ZAxis24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZAxis24(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path474 || (_path474 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 22L26 25.586 17 16.586 17 10 17 6 17 5.828 19.586 8.414 21 7 16 2 11 7 12.414 8.414 15 5.828 15 6 15 10 15 16.586 6 25.586 6 22 4 22 4 29 11 29 11 27 7.414 27 16 18.414 24.586 27 21 27 21 29 28 29 28 22 26 22z"
  })), children);
});
var ZAxis20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZAxis20(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path475 || (_path475 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 22L26 25.586 17 16.586 17 10 17 6 17 5.828 19.586 8.414 21 7 16 2 11 7 12.414 8.414 15 5.828 15 6 15 10 15 16.586 6 25.586 6 22 4 22 4 29 11 29 11 27 7.414 27 16 18.414 24.586 27 21 27 21 29 28 29 28 22 26 22z"
  })), children);
});
var ZAxis16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZAxis16(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path476 || (_path476 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 22L26 25.586 17 16.586 17 10 17 6 17 5.828 19.586 8.414 21 7 16 2 11 7 12.414 8.414 15 5.828 15 6 15 10 15 16.586 6 25.586 6 22 4 22 4 29 11 29 11 27 7.414 27 16 18.414 24.586 27 21 27 21 29 28 29 28 22 26 22z"
  })), children);
});
var Zip32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Zip32(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path477 || (_path477 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9H22V23h2V18h4a2 2 0 002-2V11A2 2 0 0028 9zm0 7H24V11h4zM12 9L12 11 15 11 15 21 12 21 12 23 20 23 20 21 17 21 17 11 20 11 20 9 12 9zM10 9L2 9 2 11 8 11 2 21 2 23 10 23 10 21 4 21 10 11 10 9z"
  })), children);
});
var Zip24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Zip24(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path478 || (_path478 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9H22V23h2V18h4a2 2 0 002-2V11A2 2 0 0028 9zm0 7H24V11h4zM12 9L12 11 15 11 15 21 12 21 12 23 20 23 20 21 17 21 17 11 20 11 20 9 12 9zM10 9L2 9 2 11 8 11 2 21 2 23 10 23 10 21 4 21 10 11 10 9z"
  })), children);
});
var Zip20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Zip20(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path479 || (_path479 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9H22V23h2V18h4a2 2 0 002-2V11A2 2 0 0028 9zm0 7H24V11h4zM12 9L12 11 15 11 15 21 12 21 12 23 20 23 20 21 17 21 17 11 20 11 20 9 12 9zM10 9L2 9 2 11 8 11 2 21 2 23 10 23 10 21 4 21 10 11 10 9z"
  })), children);
});
var Zip16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Zip16(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path480 || (_path480 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9H22V23h2V18h4a2 2 0 002-2V11A2 2 0 0028 9zm0 7H24V11h4zM12 9L12 11 15 11 15 21 12 21 12 23 20 23 20 21 17 21 17 11 20 11 20 9 12 9zM10 9L2 9 2 11 8 11 2 21 2 23 10 23 10 21 4 21 10 11 10 9z"
  })), children);
});
var ZipReference32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZipReference32(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path481 || (_path481 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM28 2H22V16h2V11h4a2 2 0 002-2V4A2 2 0 0028 2zm0 7H24V4h4zM12 4L15 4 15 14 12 14 12 16 20 16 20 14 17 14 17 4 20 4 20 2 12 2 12 4zM2 4L8 4 2 14 2 16 10 16 10 14 4 14 10 4 10 2 2 2 2 4z"
  })), children);
});
var ZipReference24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZipReference24(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path482 || (_path482 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM28 2H22V16h2V11h4a2 2 0 002-2V4A2 2 0 0028 2zm0 7H24V4h4zM12 4L15 4 15 14 12 14 12 16 20 16 20 14 17 14 17 4 20 4 20 2 12 2 12 4zM2 4L8 4 2 14 2 16 10 16 10 14 4 14 10 4 10 2 2 2 2 4z"
  })), children);
});
var ZipReference20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZipReference20(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path483 || (_path483 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM28 2H22V16h2V11h4a2 2 0 002-2V4A2 2 0 0028 2zm0 7H24V4h4zM12 4L15 4 15 14 12 14 12 16 20 16 20 14 17 14 17 4 20 4 20 2 12 2 12 4zM2 4L8 4 2 14 2 16 10 16 10 14 4 14 10 4 10 2 2 2 2 4z"
  })), children);
});
var ZipReference16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZipReference16(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path484 || (_path484 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM28 2H22V16h2V11h4a2 2 0 002-2V4A2 2 0 0028 2zm0 7H24V4h4zM12 4L15 4 15 14 12 14 12 16 20 16 20 14 17 14 17 4 20 4 20 2 12 2 12 4zM2 4L8 4 2 14 2 16 10 16 10 14 4 14 10 4 10 2 2 2 2 4z"
  })), children);
});
var ZoomArea32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomArea32(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path485 || (_path485 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 29.5859l-4.6885-4.6884a8.028 8.028 0 10-1.414 1.414L29.5859 31zM20 26a6 6 0 116-6A6.0066 6.0066 0 0120 26zM8 26H4a2.0021 2.0021 0 01-2-2V20H4v4H8zM2 12H4V16H2zM26 8H24V4H20V2h4a2.0021 2.0021 0 012 2zM12 2H16V4H12zM4 8H2V4A2.0021 2.0021 0 014 2H8V4H4z"
  })), children);
});
var ZoomArea24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomArea24(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path486 || (_path486 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 29.5859l-4.6885-4.6884a8.028 8.028 0 10-1.414 1.414L29.5859 31zM20 26a6 6 0 116-6A6.0066 6.0066 0 0120 26zM8 26H4a2.0021 2.0021 0 01-2-2V20H4v4H8zM2 12H4V16H2zM26 8H24V4H20V2h4a2.0021 2.0021 0 012 2zM12 2H16V4H12zM4 8H2V4A2.0021 2.0021 0 014 2H8V4H4z"
  })), children);
});
var ZoomArea20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomArea20(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path487 || (_path487 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 29.5859l-4.6885-4.6884a8.028 8.028 0 10-1.414 1.414L29.5859 31zM20 26a6 6 0 116-6A6.0066 6.0066 0 0120 26zM8 26H4a2.0021 2.0021 0 01-2-2V20H4v4H8zM2 12H4V16H2zM26 8H24V4H20V2h4a2.0021 2.0021 0 012 2zM12 2H16V4H12zM4 8H2V4A2.0021 2.0021 0 014 2H8V4H4z"
  })), children);
});
var ZoomArea16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomArea16(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path488 || (_path488 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 29.5859l-4.6885-4.6884a8.028 8.028 0 10-1.414 1.414L29.5859 31zM20 26a6 6 0 116-6A6.0066 6.0066 0 0120 26zM8 26H4a2.0021 2.0021 0 01-2-2V20H4v4H8zM2 12H4V16H2zM26 8H24V4H20V2h4a2.0021 2.0021 0 012 2zM12 2H16V4H12zM4 8H2V4A2.0021 2.0021 0 014 2H8V4H4z"
  })), children);
});
var ZoomFit32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomFit32(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path489 || (_path489 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4479,20A10.856,10.856,0,0,0,24,13,11,11,0,1,0,13,24a10.856,10.856,0,0,0,7-2.5521L27.5859,29,29,27.5859ZM13,22a9,9,0,1,1,9-9A9.01,9.01,0,0,1,13,22Z"
  })), _path490 || (_path490 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 12H8V10a2.0023 2.0023 0 012-2h2v2H10zM18 12H16V10H14V8h2a2.0023 2.0023 0 012 2zM12 18H10a2.0023 2.0023 0 01-2-2V14h2v2h2zM16 18H14V16h2V14h2v2A2.0023 2.0023 0 0116 18z"
  })), children);
});
var ZoomFit24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomFit24(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path491 || (_path491 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4479,20A10.856,10.856,0,0,0,24,13,11,11,0,1,0,13,24a10.856,10.856,0,0,0,7-2.5521L27.5859,29,29,27.5859ZM13,22a9,9,0,1,1,9-9A9.01,9.01,0,0,1,13,22Z"
  })), _path492 || (_path492 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 12H8V10a2.0023 2.0023 0 012-2h2v2H10zM18 12H16V10H14V8h2a2.0023 2.0023 0 012 2zM12 18H10a2.0023 2.0023 0 01-2-2V14h2v2h2zM16 18H14V16h2V14h2v2A2.0023 2.0023 0 0116 18z"
  })), children);
});
var ZoomFit20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomFit20(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path493 || (_path493 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4479,20A10.856,10.856,0,0,0,24,13,11,11,0,1,0,13,24a10.856,10.856,0,0,0,7-2.5521L27.5859,29,29,27.5859ZM13,22a9,9,0,1,1,9-9A9.01,9.01,0,0,1,13,22Z"
  })), _path494 || (_path494 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 12H8V10a2.0023 2.0023 0 012-2h2v2H10zM18 12H16V10H14V8h2a2.0023 2.0023 0 012 2zM12 18H10a2.0023 2.0023 0 01-2-2V14h2v2h2zM16 18H14V16h2V14h2v2A2.0023 2.0023 0 0116 18z"
  })), children);
});
var ZoomFit16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomFit16(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path495 || (_path495 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4479,20A10.856,10.856,0,0,0,24,13,11,11,0,1,0,13,24a10.856,10.856,0,0,0,7-2.5521L27.5859,29,29,27.5859ZM13,22a9,9,0,1,1,9-9A9.01,9.01,0,0,1,13,22Z"
  })), _path496 || (_path496 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 12H8V10a2.0023 2.0023 0 012-2h2v2H10zM18 12H16V10H14V8h2a2.0023 2.0023 0 012 2zM12 18H10a2.0023 2.0023 0 01-2-2V14h2v2h2zM16 18H14V16h2V14h2v2A2.0023 2.0023 0 0116 18z"
  })), children);
});
var ZoomIn32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomIn32(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path497 || (_path497 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 12L14 12 14 8 12 8 12 12 8 12 8 14 12 14 12 18 14 18 14 14 18 14 18 12z"
  })), _path498 || (_path498 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4479,20A10.856,10.856,0,0,0,24,13,11,11,0,1,0,13,24a10.856,10.856,0,0,0,7-2.5521L27.5859,29,29,27.5859ZM13,22a9,9,0,1,1,9-9A9.01,9.01,0,0,1,13,22Z"
  })), children);
});
var ZoomIn24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomIn24(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path499 || (_path499 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 12L14 12 14 8 12 8 12 12 8 12 8 14 12 14 12 18 14 18 14 14 18 14 18 12z"
  })), _path500 || (_path500 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4479,20A10.856,10.856,0,0,0,24,13,11,11,0,1,0,13,24a10.856,10.856,0,0,0,7-2.5521L27.5859,29,29,27.5859ZM13,22a9,9,0,1,1,9-9A9.01,9.01,0,0,1,13,22Z"
  })), children);
});
var ZoomIn20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomIn20(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path501 || (_path501 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 12L14 12 14 8 12 8 12 12 8 12 8 14 12 14 12 18 14 18 14 14 18 14 18 12z"
  })), _path502 || (_path502 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4479,20A10.856,10.856,0,0,0,24,13,11,11,0,1,0,13,24a10.856,10.856,0,0,0,7-2.5521L27.5859,29,29,27.5859ZM13,22a9,9,0,1,1,9-9A9.01,9.01,0,0,1,13,22Z"
  })), children);
});
var ZoomIn16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomIn16(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path503 || (_path503 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9 6L7 6 7 4 6 4 6 6 4 6 4 7 6 7 6 9 7 9 7 7 9 7z"
  })), _path504 || (_path504 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.7,10C11.5,9,12,7.8,12,6.5C12,3.5,9.5,1,6.5,1S1,3.5,1,6.5S3.5,12,6.5,12c1.3,0,2.5-0.5,3.5-1.3l3.8,3.8l0.7-0.7\tL10.7,10z M6.5,11C4,11,2,9,2,6.5S4,2,6.5,2S11,4,11,6.5S9,11,6.5,11L6.5,11z"
  })), children);
});
var ZoomInArea32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomInArea32(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path505 || (_path505 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 19L21 19 21 16 19 16 19 19 16 19 16 21 19 21 19 24 21 24 21 21 24 21 24 19z"
  })), _path506 || (_path506 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 29.5859l-4.6885-4.6884a8.028 8.028 0 10-1.414 1.414L29.5859 31zM20 26a6 6 0 116-6A6.0066 6.0066 0 0120 26zM4 8H2V4A2.0021 2.0021 0 014 2H8V4H4zM26 8H24V4H20V2h4a2.0021 2.0021 0 012 2zM12 2H16V4H12zM8 26H4a2.0021 2.0021 0 01-2-2V20H4v4H8zM2 12H4V16H2z"
  })), children);
});
var ZoomInArea24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomInArea24(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path507 || (_path507 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 19L21 19 21 16 19 16 19 19 16 19 16 21 19 21 19 24 21 24 21 21 24 21 24 19z"
  })), _path508 || (_path508 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 29.5859l-4.6885-4.6884a8.028 8.028 0 10-1.414 1.414L29.5859 31zM20 26a6 6 0 116-6A6.0066 6.0066 0 0120 26zM4 8H2V4A2.0021 2.0021 0 014 2H8V4H4zM26 8H24V4H20V2h4a2.0021 2.0021 0 012 2zM12 2H16V4H12zM8 26H4a2.0021 2.0021 0 01-2-2V20H4v4H8zM2 12H4V16H2z"
  })), children);
});
var ZoomInArea20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomInArea20(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path509 || (_path509 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 19L21 19 21 16 19 16 19 19 16 19 16 21 19 21 19 24 21 24 21 21 24 21 24 19z"
  })), _path510 || (_path510 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 29.5859l-4.6885-4.6884a8.028 8.028 0 10-1.414 1.414L29.5859 31zM20 26a6 6 0 116-6A6.0066 6.0066 0 0120 26zM4 8H2V4A2.0021 2.0021 0 014 2H8V4H4zM26 8H24V4H20V2h4a2.0021 2.0021 0 012 2zM12 2H16V4H12zM8 26H4a2.0021 2.0021 0 01-2-2V20H4v4H8zM2 12H4V16H2z"
  })), children);
});
var ZoomInArea16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomInArea16(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path511 || (_path511 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 19L21 19 21 16 19 16 19 19 16 19 16 21 19 21 19 24 21 24 21 21 24 21 24 19z"
  })), _path512 || (_path512 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 29.5859l-4.6885-4.6884a8.028 8.028 0 10-1.414 1.414L29.5859 31zM20 26a6 6 0 116-6A6.0066 6.0066 0 0120 26zM4 8H2V4A2.0021 2.0021 0 014 2H8V4H4zM26 8H24V4H20V2h4a2.0021 2.0021 0 012 2zM12 2H16V4H12zM8 26H4a2.0021 2.0021 0 01-2-2V20H4v4H8zM2 12H4V16H2z"
  })), children);
});
var ZoomOut32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomOut32(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path513 || (_path513 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 12H18V14H8z"
  })), _path514 || (_path514 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4479,20A10.856,10.856,0,0,0,24,13,11,11,0,1,0,13,24a10.856,10.856,0,0,0,7-2.5521L27.5859,29,29,27.5859ZM13,22a9,9,0,1,1,9-9A9.01,9.01,0,0,1,13,22Z"
  })), children);
});
var ZoomOut24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomOut24(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path515 || (_path515 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 12H18V14H8z"
  })), _path516 || (_path516 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4479,20A10.856,10.856,0,0,0,24,13,11,11,0,1,0,13,24a10.856,10.856,0,0,0,7-2.5521L27.5859,29,29,27.5859ZM13,22a9,9,0,1,1,9-9A9.01,9.01,0,0,1,13,22Z"
  })), children);
});
var ZoomOut20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomOut20(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path517 || (_path517 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 12H18V14H8z"
  })), _path518 || (_path518 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4479,20A10.856,10.856,0,0,0,24,13,11,11,0,1,0,13,24a10.856,10.856,0,0,0,7-2.5521L27.5859,29,29,27.5859ZM13,22a9,9,0,1,1,9-9A9.01,9.01,0,0,1,13,22Z"
  })), children);
});
var ZoomOut16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ZoomOut16(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path519 || (_path519 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 6H9V7H4z"
  })), _path520 || (_path520 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.7,10C11.5,9,12,7.8,12,6.5C12,3.5,9.5,1,6.5,1S1,3.5,1,6.5S3.5,12,6.5,12c1.3,0,2.5-0.5,3.5-1.3l3.8,3.8l0.7-0.7\tL10.7,10z M6.5,11C4,11,2,9,2,6.5S4,2,6.5,2S11,4,11,6.5S9,11,6.5,11L6.5,11z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-4.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-4.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "ChartAreaStepper16": () => (/* binding */ ChartAreaStepper16),
/* harmony export */   "ChartAreaStepper20": () => (/* binding */ ChartAreaStepper20),
/* harmony export */   "ChartAverage16": () => (/* binding */ ChartAverage16),
/* harmony export */   "ChartAverage20": () => (/* binding */ ChartAverage20),
/* harmony export */   "ChartAverage24": () => (/* binding */ ChartAverage24),
/* harmony export */   "ChartAverage32": () => (/* binding */ ChartAverage32),
/* harmony export */   "ChartBar16": () => (/* binding */ ChartBar16),
/* harmony export */   "ChartBar20": () => (/* binding */ ChartBar20),
/* harmony export */   "ChartBar24": () => (/* binding */ ChartBar24),
/* harmony export */   "ChartBar32": () => (/* binding */ ChartBar32),
/* harmony export */   "ChartBarFloating16": () => (/* binding */ ChartBarFloating16),
/* harmony export */   "ChartBarFloating20": () => (/* binding */ ChartBarFloating20),
/* harmony export */   "ChartBarFloating24": () => (/* binding */ ChartBarFloating24),
/* harmony export */   "ChartBarFloating32": () => (/* binding */ ChartBarFloating32),
/* harmony export */   "ChartBarOverlay16": () => (/* binding */ ChartBarOverlay16),
/* harmony export */   "ChartBarOverlay20": () => (/* binding */ ChartBarOverlay20),
/* harmony export */   "ChartBarOverlay24": () => (/* binding */ ChartBarOverlay24),
/* harmony export */   "ChartBarOverlay32": () => (/* binding */ ChartBarOverlay32),
/* harmony export */   "ChartBarStacked16": () => (/* binding */ ChartBarStacked16),
/* harmony export */   "ChartBarStacked20": () => (/* binding */ ChartBarStacked20),
/* harmony export */   "ChartBarStacked24": () => (/* binding */ ChartBarStacked24),
/* harmony export */   "ChartBarStacked32": () => (/* binding */ ChartBarStacked32),
/* harmony export */   "ChartBarTarget16": () => (/* binding */ ChartBarTarget16),
/* harmony export */   "ChartBarTarget20": () => (/* binding */ ChartBarTarget20),
/* harmony export */   "ChartBarTarget24": () => (/* binding */ ChartBarTarget24),
/* harmony export */   "ChartBarTarget32": () => (/* binding */ ChartBarTarget32),
/* harmony export */   "ChartBubble16": () => (/* binding */ ChartBubble16),
/* harmony export */   "ChartBubble20": () => (/* binding */ ChartBubble20),
/* harmony export */   "ChartBubble24": () => (/* binding */ ChartBubble24),
/* harmony export */   "ChartBubble32": () => (/* binding */ ChartBubble32),
/* harmony export */   "ChartBubblePacked16": () => (/* binding */ ChartBubblePacked16),
/* harmony export */   "ChartBubblePacked20": () => (/* binding */ ChartBubblePacked20),
/* harmony export */   "ChartBubblePacked24": () => (/* binding */ ChartBubblePacked24),
/* harmony export */   "ChartBubblePacked32": () => (/* binding */ ChartBubblePacked32),
/* harmony export */   "ChartBullet16": () => (/* binding */ ChartBullet16),
/* harmony export */   "ChartBullet20": () => (/* binding */ ChartBullet20),
/* harmony export */   "ChartBullet24": () => (/* binding */ ChartBullet24),
/* harmony export */   "ChartBullet32": () => (/* binding */ ChartBullet32),
/* harmony export */   "ChartCandlestick16": () => (/* binding */ ChartCandlestick16),
/* harmony export */   "ChartCandlestick20": () => (/* binding */ ChartCandlestick20),
/* harmony export */   "ChartCandlestick24": () => (/* binding */ ChartCandlestick24),
/* harmony export */   "ChartCandlestick32": () => (/* binding */ ChartCandlestick32),
/* harmony export */   "ChartClusterBar16": () => (/* binding */ ChartClusterBar16),
/* harmony export */   "ChartClusterBar20": () => (/* binding */ ChartClusterBar20),
/* harmony export */   "ChartClusterBar24": () => (/* binding */ ChartClusterBar24),
/* harmony export */   "ChartClusterBar32": () => (/* binding */ ChartClusterBar32),
/* harmony export */   "ChartColumn16": () => (/* binding */ ChartColumn16),
/* harmony export */   "ChartColumn20": () => (/* binding */ ChartColumn20),
/* harmony export */   "ChartColumn24": () => (/* binding */ ChartColumn24),
/* harmony export */   "ChartColumn32": () => (/* binding */ ChartColumn32),
/* harmony export */   "ChartColumnFloating16": () => (/* binding */ ChartColumnFloating16),
/* harmony export */   "ChartColumnFloating20": () => (/* binding */ ChartColumnFloating20),
/* harmony export */   "ChartColumnFloating24": () => (/* binding */ ChartColumnFloating24),
/* harmony export */   "ChartColumnFloating32": () => (/* binding */ ChartColumnFloating32),
/* harmony export */   "ChartColumnTarget16": () => (/* binding */ ChartColumnTarget16),
/* harmony export */   "ChartColumnTarget20": () => (/* binding */ ChartColumnTarget20),
/* harmony export */   "ChartColumnTarget24": () => (/* binding */ ChartColumnTarget24),
/* harmony export */   "ChartColumnTarget32": () => (/* binding */ ChartColumnTarget32),
/* harmony export */   "ChartCombo16": () => (/* binding */ ChartCombo16),
/* harmony export */   "ChartCombo20": () => (/* binding */ ChartCombo20),
/* harmony export */   "ChartCombo24": () => (/* binding */ ChartCombo24),
/* harmony export */   "ChartCombo32": () => (/* binding */ ChartCombo32),
/* harmony export */   "ChartComboStacked16": () => (/* binding */ ChartComboStacked16),
/* harmony export */   "ChartComboStacked20": () => (/* binding */ ChartComboStacked20),
/* harmony export */   "ChartComboStacked24": () => (/* binding */ ChartComboStacked24),
/* harmony export */   "ChartComboStacked32": () => (/* binding */ ChartComboStacked32),
/* harmony export */   "ChartCustom16": () => (/* binding */ ChartCustom16),
/* harmony export */   "ChartCustom20": () => (/* binding */ ChartCustom20),
/* harmony export */   "ChartCustom24": () => (/* binding */ ChartCustom24),
/* harmony export */   "ChartCustom32": () => (/* binding */ ChartCustom32),
/* harmony export */   "ChartErrorBar16": () => (/* binding */ ChartErrorBar16),
/* harmony export */   "ChartErrorBar20": () => (/* binding */ ChartErrorBar20),
/* harmony export */   "ChartErrorBar24": () => (/* binding */ ChartErrorBar24),
/* harmony export */   "ChartErrorBar32": () => (/* binding */ ChartErrorBar32),
/* harmony export */   "ChartErrorBarAlt16": () => (/* binding */ ChartErrorBarAlt16),
/* harmony export */   "ChartErrorBarAlt20": () => (/* binding */ ChartErrorBarAlt20),
/* harmony export */   "ChartErrorBarAlt24": () => (/* binding */ ChartErrorBarAlt24),
/* harmony export */   "ChartErrorBarAlt32": () => (/* binding */ ChartErrorBarAlt32),
/* harmony export */   "ChartEvaluation16": () => (/* binding */ ChartEvaluation16),
/* harmony export */   "ChartEvaluation20": () => (/* binding */ ChartEvaluation20),
/* harmony export */   "ChartEvaluation24": () => (/* binding */ ChartEvaluation24),
/* harmony export */   "ChartEvaluation32": () => (/* binding */ ChartEvaluation32),
/* harmony export */   "ChartHighLow16": () => (/* binding */ ChartHighLow16),
/* harmony export */   "ChartHighLow20": () => (/* binding */ ChartHighLow20),
/* harmony export */   "ChartHighLow24": () => (/* binding */ ChartHighLow24),
/* harmony export */   "ChartHighLow32": () => (/* binding */ ChartHighLow32),
/* harmony export */   "ChartHistogram16": () => (/* binding */ ChartHistogram16),
/* harmony export */   "ChartHistogram20": () => (/* binding */ ChartHistogram20),
/* harmony export */   "ChartHistogram24": () => (/* binding */ ChartHistogram24),
/* harmony export */   "ChartHistogram32": () => (/* binding */ ChartHistogram32),
/* harmony export */   "ChartLine16": () => (/* binding */ ChartLine16),
/* harmony export */   "ChartLine20": () => (/* binding */ ChartLine20),
/* harmony export */   "ChartLine24": () => (/* binding */ ChartLine24),
/* harmony export */   "ChartLine32": () => (/* binding */ ChartLine32),
/* harmony export */   "ChartLineData16": () => (/* binding */ ChartLineData16),
/* harmony export */   "ChartLineData20": () => (/* binding */ ChartLineData20),
/* harmony export */   "ChartLineData24": () => (/* binding */ ChartLineData24),
/* harmony export */   "ChartLineData32": () => (/* binding */ ChartLineData32),
/* harmony export */   "ChartLineSmooth16": () => (/* binding */ ChartLineSmooth16),
/* harmony export */   "ChartLineSmooth20": () => (/* binding */ ChartLineSmooth20),
/* harmony export */   "ChartLineSmooth24": () => (/* binding */ ChartLineSmooth24),
/* harmony export */   "ChartLineSmooth32": () => (/* binding */ ChartLineSmooth32),
/* harmony export */   "ChartMarimekko16": () => (/* binding */ ChartMarimekko16),
/* harmony export */   "ChartMarimekko20": () => (/* binding */ ChartMarimekko20),
/* harmony export */   "ChartMarimekko24": () => (/* binding */ ChartMarimekko24),
/* harmony export */   "ChartMarimekko32": () => (/* binding */ ChartMarimekko32),
/* harmony export */   "ChartMaximum16": () => (/* binding */ ChartMaximum16),
/* harmony export */   "ChartMaximum20": () => (/* binding */ ChartMaximum20),
/* harmony export */   "ChartMaximum24": () => (/* binding */ ChartMaximum24),
/* harmony export */   "ChartMaximum32": () => (/* binding */ ChartMaximum32),
/* harmony export */   "ChartMedian16": () => (/* binding */ ChartMedian16),
/* harmony export */   "ChartMedian20": () => (/* binding */ ChartMedian20),
/* harmony export */   "ChartMedian24": () => (/* binding */ ChartMedian24),
/* harmony export */   "ChartMedian32": () => (/* binding */ ChartMedian32),
/* harmony export */   "ChartMinimum16": () => (/* binding */ ChartMinimum16),
/* harmony export */   "ChartMinimum20": () => (/* binding */ ChartMinimum20),
/* harmony export */   "ChartMinimum24": () => (/* binding */ ChartMinimum24),
/* harmony export */   "ChartMinimum32": () => (/* binding */ ChartMinimum32),
/* harmony export */   "ChartMultiLine16": () => (/* binding */ ChartMultiLine16),
/* harmony export */   "ChartMultiLine20": () => (/* binding */ ChartMultiLine20),
/* harmony export */   "ChartMultiLine24": () => (/* binding */ ChartMultiLine24),
/* harmony export */   "ChartMultiLine32": () => (/* binding */ ChartMultiLine32),
/* harmony export */   "ChartMultitype16": () => (/* binding */ ChartMultitype16),
/* harmony export */   "ChartMultitype20": () => (/* binding */ ChartMultitype20),
/* harmony export */   "ChartMultitype24": () => (/* binding */ ChartMultitype24),
/* harmony export */   "ChartMultitype32": () => (/* binding */ ChartMultitype32),
/* harmony export */   "ChartNetwork16": () => (/* binding */ ChartNetwork16),
/* harmony export */   "ChartNetwork20": () => (/* binding */ ChartNetwork20),
/* harmony export */   "ChartNetwork24": () => (/* binding */ ChartNetwork24),
/* harmony export */   "ChartNetwork32": () => (/* binding */ ChartNetwork32),
/* harmony export */   "ChartParallel16": () => (/* binding */ ChartParallel16),
/* harmony export */   "ChartParallel20": () => (/* binding */ ChartParallel20),
/* harmony export */   "ChartParallel24": () => (/* binding */ ChartParallel24),
/* harmony export */   "ChartParallel32": () => (/* binding */ ChartParallel32),
/* harmony export */   "ChartPie16": () => (/* binding */ ChartPie16),
/* harmony export */   "ChartPie20": () => (/* binding */ ChartPie20),
/* harmony export */   "ChartPie24": () => (/* binding */ ChartPie24),
/* harmony export */   "ChartPie32": () => (/* binding */ ChartPie32),
/* harmony export */   "ChartPoint16": () => (/* binding */ ChartPoint16),
/* harmony export */   "ChartPoint20": () => (/* binding */ ChartPoint20),
/* harmony export */   "ChartPoint24": () => (/* binding */ ChartPoint24),
/* harmony export */   "ChartPoint32": () => (/* binding */ ChartPoint32),
/* harmony export */   "ChartPopulation16": () => (/* binding */ ChartPopulation16),
/* harmony export */   "ChartPopulation20": () => (/* binding */ ChartPopulation20),
/* harmony export */   "ChartPopulation24": () => (/* binding */ ChartPopulation24),
/* harmony export */   "ChartPopulation32": () => (/* binding */ ChartPopulation32),
/* harmony export */   "ChartRadar16": () => (/* binding */ ChartRadar16),
/* harmony export */   "ChartRadar20": () => (/* binding */ ChartRadar20),
/* harmony export */   "ChartRadar24": () => (/* binding */ ChartRadar24),
/* harmony export */   "ChartRadar32": () => (/* binding */ ChartRadar32),
/* harmony export */   "ChartRadial16": () => (/* binding */ ChartRadial16),
/* harmony export */   "ChartRadial20": () => (/* binding */ ChartRadial20),
/* harmony export */   "ChartRadial24": () => (/* binding */ ChartRadial24),
/* harmony export */   "ChartRadial32": () => (/* binding */ ChartRadial32),
/* harmony export */   "ChartRelationship16": () => (/* binding */ ChartRelationship16),
/* harmony export */   "ChartRelationship20": () => (/* binding */ ChartRelationship20),
/* harmony export */   "ChartRelationship24": () => (/* binding */ ChartRelationship24),
/* harmony export */   "ChartRelationship32": () => (/* binding */ ChartRelationship32),
/* harmony export */   "ChartRing16": () => (/* binding */ ChartRing16),
/* harmony export */   "ChartRing20": () => (/* binding */ ChartRing20),
/* harmony export */   "ChartRing24": () => (/* binding */ ChartRing24),
/* harmony export */   "ChartRing32": () => (/* binding */ ChartRing32),
/* harmony export */   "ChartRiver16": () => (/* binding */ ChartRiver16),
/* harmony export */   "ChartRiver20": () => (/* binding */ ChartRiver20),
/* harmony export */   "ChartRiver24": () => (/* binding */ ChartRiver24),
/* harmony export */   "ChartRiver32": () => (/* binding */ ChartRiver32),
/* harmony export */   "ChartRose16": () => (/* binding */ ChartRose16),
/* harmony export */   "ChartRose20": () => (/* binding */ ChartRose20),
/* harmony export */   "ChartRose24": () => (/* binding */ ChartRose24),
/* harmony export */   "ChartRose32": () => (/* binding */ ChartRose32),
/* harmony export */   "ChartScatter16": () => (/* binding */ ChartScatter16),
/* harmony export */   "ChartScatter20": () => (/* binding */ ChartScatter20),
/* harmony export */   "ChartScatter24": () => (/* binding */ ChartScatter24),
/* harmony export */   "ChartScatter32": () => (/* binding */ ChartScatter32),
/* harmony export */   "ChartSpiral16": () => (/* binding */ ChartSpiral16),
/* harmony export */   "ChartSpiral20": () => (/* binding */ ChartSpiral20),
/* harmony export */   "ChartSpiral24": () => (/* binding */ ChartSpiral24),
/* harmony export */   "ChartSpiral32": () => (/* binding */ ChartSpiral32),
/* harmony export */   "ChartStacked16": () => (/* binding */ ChartStacked16),
/* harmony export */   "ChartStacked20": () => (/* binding */ ChartStacked20),
/* harmony export */   "ChartStacked24": () => (/* binding */ ChartStacked24),
/* harmony export */   "ChartStacked32": () => (/* binding */ ChartStacked32),
/* harmony export */   "ChartStepper16": () => (/* binding */ ChartStepper16),
/* harmony export */   "ChartStepper20": () => (/* binding */ ChartStepper20),
/* harmony export */   "ChartStepper24": () => (/* binding */ ChartStepper24),
/* harmony export */   "ChartStepper32": () => (/* binding */ ChartStepper32),
/* harmony export */   "ChartSunburst16": () => (/* binding */ ChartSunburst16),
/* harmony export */   "ChartSunburst20": () => (/* binding */ ChartSunburst20),
/* harmony export */   "ChartSunburst24": () => (/* binding */ ChartSunburst24),
/* harmony export */   "ChartSunburst32": () => (/* binding */ ChartSunburst32),
/* harmony export */   "ChartTSne16": () => (/* binding */ ChartTSne16),
/* harmony export */   "ChartTSne20": () => (/* binding */ ChartTSne20),
/* harmony export */   "ChartTSne24": () => (/* binding */ ChartTSne24),
/* harmony export */   "ChartTSne32": () => (/* binding */ ChartTSne32),
/* harmony export */   "ChartTreemap16": () => (/* binding */ ChartTreemap16),
/* harmony export */   "ChartTreemap20": () => (/* binding */ ChartTreemap20),
/* harmony export */   "ChartTreemap24": () => (/* binding */ ChartTreemap24),
/* harmony export */   "ChartTreemap32": () => (/* binding */ ChartTreemap32),
/* harmony export */   "ChartVennDiagram16": () => (/* binding */ ChartVennDiagram16),
/* harmony export */   "ChartVennDiagram20": () => (/* binding */ ChartVennDiagram20),
/* harmony export */   "ChartVennDiagram24": () => (/* binding */ ChartVennDiagram24),
/* harmony export */   "ChartVennDiagram32": () => (/* binding */ ChartVennDiagram32),
/* harmony export */   "ChartViolinPlot16": () => (/* binding */ ChartViolinPlot16),
/* harmony export */   "ChartViolinPlot20": () => (/* binding */ ChartViolinPlot20),
/* harmony export */   "ChartViolinPlot24": () => (/* binding */ ChartViolinPlot24),
/* harmony export */   "ChartViolinPlot32": () => (/* binding */ ChartViolinPlot32),
/* harmony export */   "ChartWaterfall16": () => (/* binding */ ChartWaterfall16),
/* harmony export */   "ChartWaterfall20": () => (/* binding */ ChartWaterfall20),
/* harmony export */   "ChartWaterfall24": () => (/* binding */ ChartWaterfall24),
/* harmony export */   "ChartWaterfall32": () => (/* binding */ ChartWaterfall32),
/* harmony export */   "ChartWinLoss16": () => (/* binding */ ChartWinLoss16),
/* harmony export */   "ChartWinLoss20": () => (/* binding */ ChartWinLoss20),
/* harmony export */   "ChartWinLoss24": () => (/* binding */ ChartWinLoss24),
/* harmony export */   "ChartWinLoss32": () => (/* binding */ ChartWinLoss32),
/* harmony export */   "Chat16": () => (/* binding */ Chat16),
/* harmony export */   "Chat20": () => (/* binding */ Chat20),
/* harmony export */   "Chat24": () => (/* binding */ Chat24),
/* harmony export */   "Chat32": () => (/* binding */ Chat32),
/* harmony export */   "ChatBot16": () => (/* binding */ ChatBot16),
/* harmony export */   "ChatBot20": () => (/* binding */ ChatBot20),
/* harmony export */   "ChatBot24": () => (/* binding */ ChatBot24),
/* harmony export */   "ChatBot32": () => (/* binding */ ChatBot32),
/* harmony export */   "ChatLaunch16": () => (/* binding */ ChatLaunch16),
/* harmony export */   "ChatLaunch20": () => (/* binding */ ChatLaunch20),
/* harmony export */   "ChatLaunch24": () => (/* binding */ ChatLaunch24),
/* harmony export */   "ChatLaunch32": () => (/* binding */ ChatLaunch32),
/* harmony export */   "ChatOff16": () => (/* binding */ ChatOff16),
/* harmony export */   "ChatOff20": () => (/* binding */ ChatOff20),
/* harmony export */   "ChatOff24": () => (/* binding */ ChatOff24),
/* harmony export */   "ChatOff32": () => (/* binding */ ChatOff32),
/* harmony export */   "ChatOperational16": () => (/* binding */ ChatOperational16),
/* harmony export */   "ChatOperational20": () => (/* binding */ ChatOperational20),
/* harmony export */   "ChatOperational24": () => (/* binding */ ChatOperational24),
/* harmony export */   "ChatOperational32": () => (/* binding */ ChatOperational32),
/* harmony export */   "Checkbox16": () => (/* binding */ Checkbox16),
/* harmony export */   "Checkbox20": () => (/* binding */ Checkbox20),
/* harmony export */   "Checkbox24": () => (/* binding */ Checkbox24),
/* harmony export */   "Checkbox32": () => (/* binding */ Checkbox32),
/* harmony export */   "CheckboxChecked16": () => (/* binding */ CheckboxChecked16),
/* harmony export */   "CheckboxChecked20": () => (/* binding */ CheckboxChecked20),
/* harmony export */   "CheckboxChecked24": () => (/* binding */ CheckboxChecked24),
/* harmony export */   "CheckboxChecked32": () => (/* binding */ CheckboxChecked32),
/* harmony export */   "CheckboxCheckedFilled16": () => (/* binding */ CheckboxCheckedFilled16),
/* harmony export */   "CheckboxCheckedFilled20": () => (/* binding */ CheckboxCheckedFilled20),
/* harmony export */   "CheckboxCheckedFilled24": () => (/* binding */ CheckboxCheckedFilled24),
/* harmony export */   "CheckboxCheckedFilled32": () => (/* binding */ CheckboxCheckedFilled32),
/* harmony export */   "CheckboxIndeterminate16": () => (/* binding */ CheckboxIndeterminate16),
/* harmony export */   "CheckboxIndeterminate20": () => (/* binding */ CheckboxIndeterminate20),
/* harmony export */   "CheckboxIndeterminate24": () => (/* binding */ CheckboxIndeterminate24),
/* harmony export */   "CheckboxIndeterminate32": () => (/* binding */ CheckboxIndeterminate32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _path65, _path66, _path67, _path68, _path69, _path70, _path71, _path72, _path73, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _path224, _path225, _path226, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _circle, _circle2, _circle3, _circle4, _circle5, _path236, _circle6, _circle7, _circle8, _circle9, _circle10, _path237, _circle11, _circle12, _circle13, _circle14, _circle15, _path238, _circle16, _circle17, _circle18, _circle19, _circle20, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _circle21, _circle22, _circle23, _path252, _circle24, _circle25, _path253, _path254, _circle26, _circle27, _circle28, _path255, _circle29, _circle30, _path256, _path257, _circle31, _circle32, _circle33, _path258, _circle34, _circle35, _path259, _path260, _circle36, _circle37, _circle38, _path261, _circle39, _circle40, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _circle41, _circle42, _circle43, _circle44, _circle45, _path300, _circle46, _circle47, _circle48, _circle49, _circle50, _path301, _circle51, _circle52, _circle53, _circle54, _circle55, _path302, _circle56, _circle57, _circle58, _circle59, _circle60, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _circle61, _circle62, _circle63, _circle64, _circle65, _circle66, _circle67, _circle68, _circle69, _circle70, _circle71, _circle72, _circle73, _circle74, _circle75, _circle76, _circle77, _circle78, _circle79, _circle80, _circle81, _circle82, _circle83, _circle84, _circle85, _circle86, _circle87, _circle88, _circle89, _circle90, _circle91, _circle92, _circle93, _circle94, _circle95, _circle96, _circle97, _circle98, _circle99, _circle100, _circle101, _circle102, _circle103, _circle104, _circle105, _circle106, _circle107, _circle108, _circle109, _circle110, _circle111, _circle112, _circle113, _circle114, _circle115, _circle116, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388, _path389, _path390, _path391, _path392, _path393, _path394, _path395, _path396, _path397, _path398, _path399, _path400, _path401, _path402, _path403, _path404, _path405, _path406, _path407, _path408, _path409, _path410;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var ChartAreaStepper20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartAreaStepper20(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,10V6H10v6H4V2H2V28a2.0025,2.0025,0,0,0,2,2H30V10ZM12,14V8h8v4h8V22H22V16H12v6H4V14ZM4,28V24H14V18h6v6h8v4Z"
  })), children);
});
var ChartAreaStepper16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartAreaStepper16(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,10V6H10v6H4V2H2V28a2.0025,2.0025,0,0,0,2,2H30V10ZM12,14V8h8v4h8V22H22V16H12v6H4V14ZM4,28V24H14V18h6v6h8v4Z"
  })), children);
});
var ChartAverage32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartAverage32(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,24c-3.5991,0-5.0293-4.1758-6.4126-8.2139C15.2764,11.9583,13.92,8,11,8a3.44,3.44,0,0,0-3.0532,2.3215L6.0513,9.6838C6.1016,9.5334,7.3218,6,11,6c4.3491,0,6.0122,4.8547,7.48,9.1379C19.6885,18.6667,20.83,22,23,22a3.44,3.44,0,0,0,3.0532-2.3215l1.8955.6377C27.8984,20.4666,26.6782,24,23,24Z"
  })), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V17H6V15H4V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 15H10V17H8zM12 15H14V17H12zM20 15H22V17H20zM24 15H26V17H24zM28 15H30V17H28z"
  })), children);
});
var ChartAverage24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartAverage24(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,24c-3.5991,0-5.0293-4.1758-6.4126-8.2139C15.2764,11.9583,13.92,8,11,8a3.44,3.44,0,0,0-3.0532,2.3215L6.0513,9.6838C6.1016,9.5334,7.3218,6,11,6c4.3491,0,6.0122,4.8547,7.48,9.1379C19.6885,18.6667,20.83,22,23,22a3.44,3.44,0,0,0,3.0532-2.3215l1.8955.6377C27.8984,20.4666,26.6782,24,23,24Z"
  })), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V17H6V15H4V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 15H10V17H8zM12 15H14V17H12zM20 15H22V17H20zM24 15H26V17H24zM28 15H30V17H28z"
  })), children);
});
var ChartAverage20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartAverage20(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,24c-3.5991,0-5.0293-4.1758-6.4126-8.2139C15.2764,11.9583,13.92,8,11,8a3.44,3.44,0,0,0-3.0532,2.3215L6.0513,9.6838C6.1016,9.5334,7.3218,6,11,6c4.3491,0,6.0122,4.8547,7.48,9.1379C19.6885,18.6667,20.83,22,23,22a3.44,3.44,0,0,0,3.0532-2.3215l1.8955.6377C27.8984,20.4666,26.6782,24,23,24Z"
  })), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V17H6V15H4V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 15H10V17H8zM12 15H14V17H12zM20 15H22V17H20zM24 15H26V17H24zM28 15H30V17H28z"
  })), children);
});
var ChartAverage16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartAverage16(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,24c-3.5991,0-5.0293-4.1758-6.4126-8.2139C15.2764,11.9583,13.92,8,11,8a3.44,3.44,0,0,0-3.0532,2.3215L6.0513,9.6838C6.1016,9.5334,7.3218,6,11,6c4.3491,0,6.0122,4.8547,7.48,9.1379C19.6885,18.6667,20.83,22,23,22a3.44,3.44,0,0,0,3.0532-2.3215l1.8955.6377C27.8984,20.4666,26.6782,24,23,24Z"
  })), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V17H6V15H4V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 15H10V17H8zM12 15H14V17H12zM20 15H22V17H20zM24 15H26V17H24zM28 15H30V17H28z"
  })), children);
});
var ChartBar32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBar32(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2H2V28a2,2,0,0,0,2,2H30V28H4V25H26V17H4V13H18V5H4ZM24,19v4H4V19ZM16,7v4H4V7Z"
  })), children);
});
var ChartBar24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBar24(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2H2V28a2,2,0,0,0,2,2H30V28H4V25H26V17H4V13H18V5H4ZM24,19v4H4V19ZM16,7v4H4V7Z"
  })), children);
});
var ChartBar20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBar20(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2H2V28a2,2,0,0,0,2,2H30V28H4V25H26V17H4V13H18V5H4ZM24,19v4H4V19ZM16,7v4H4V7Z"
  })), children);
});
var ChartBar16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBar16(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2H2V28a2,2,0,0,0,2,2H30V28H4V25H26V17H4V13H18V5H4ZM24,19v4H4V19ZM16,7v4H4V7Z"
  })), children);
});
var ChartBarFloating32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBarFloating32(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 24H14V16H28zM16 22H26V18H16zM26 12H8V4H26zM10 10H24V6H10z"
  })), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2.0023,2.0023,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartBarFloating24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBarFloating24(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 24H14V16H28zM16 22H26V18H16zM26 12H8V4H26zM10 10H24V6H10z"
  })), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2.0023,2.0023,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartBarFloating20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBarFloating20(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 24H14V16H28zM16 22H26V18H16zM26 12H8V4H26zM10 10H24V6H10z"
  })), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2.0023,2.0023,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartBarFloating16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBarFloating16(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 24H14V16H28zM16 22H26V18H16zM26 12H8V4H26zM10 10H24V6H10z"
  })), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2.0023,2.0023,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartBarOverlay32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBarOverlay32(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V26H26V16H4V14H18V4H4V2H2V28a2,2,0,0,0,2,2H30V28ZM24,18v6H4V22H20V20H4V18ZM16,6v6H4V10h8V8H4V6Z"
  })), children);
});
var ChartBarOverlay24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBarOverlay24(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V26H26V16H4V14H18V4H4V2H2V28a2,2,0,0,0,2,2H30V28ZM24,18v6H4V22H20V20H4V18ZM16,6v6H4V10h8V8H4V6Z"
  })), children);
});
var ChartBarOverlay20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBarOverlay20(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V26H26V16H4V14H18V4H4V2H2V28a2,2,0,0,0,2,2H30V28ZM24,18v6H4V22H20V20H4V18ZM16,6v6H4V10h8V8H4V6Z"
  })), children);
});
var ChartBarOverlay16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBarOverlay16(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V26H26V16H4V14H18V4H4V2H2V28a2,2,0,0,0,2,2H30V28ZM24,18v6H4V22H20V20H4V18ZM16,6v6H4V10h8V8H4V6Z"
  })), children);
});
var ChartBarStacked32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBarStacked32(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V25H26V17H4V13H18V5H4V2H2V28a2,2,0,0,0,2,2H30V28Zm20-5H14V19H24ZM16,11H10V7h6Z"
  })), children);
});
var ChartBarStacked24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBarStacked24(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V25H26V17H4V13H18V5H4V2H2V28a2,2,0,0,0,2,2H30V28Zm20-5H14V19H24ZM16,11H10V7h6Z"
  })), children);
});
var ChartBarStacked20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBarStacked20(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V25H26V17H4V13H18V5H4V2H2V28a2,2,0,0,0,2,2H30V28Zm20-5H14V19H24ZM16,11H10V7h6Z"
  })), children);
});
var ChartBarStacked16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBarStacked16(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V25H26V17H4V13H18V5H4V2H2V28a2,2,0,0,0,2,2H30V28Zm20-5H14V19H24ZM16,11H10V7h6Z"
  })), children);
});
var ChartBarTarget32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBarTarget32(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 17H30V25H28zM20 5H22V13H20z"
  })), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2H2V28a2,2,0,0,0,2,2H30V28H4V25H26V17H4V13H18V5H4ZM24,19v4H4V19ZM16,7v4H4V7Z"
  })), children);
});
var ChartBarTarget24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBarTarget24(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 17H30V25H28zM20 5H22V13H20z"
  })), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2H2V28a2,2,0,0,0,2,2H30V28H4V25H26V17H4V13H18V5H4ZM24,19v4H4V19ZM16,7v4H4V7Z"
  })), children);
});
var ChartBarTarget20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBarTarget20(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 17H30V25H28zM20 5H22V13H20z"
  })), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2H2V28a2,2,0,0,0,2,2H30V28H4V25H26V17H4V13H18V5H4ZM24,19v4H4V19ZM16,7v4H4V7Z"
  })), children);
});
var ChartBarTarget16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBarTarget16(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 17H30V25H28zM20 5H22V13H20z"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,2H2V28a2,2,0,0,0,2,2H30V28H4V25H26V17H4V13H18V5H4ZM24,19v4H4V19ZM16,7v4H4V7Z"
  })), children);
});
var ChartBubble32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBubble32(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16a2 2 0 11-2 2 2 2 0 012-2m0-2a4 4 0 104 4 4 4 0 00-4-4zM21 6a4 4 0 11-4 4 4 4 0 014-4m0-2a6 6 0 106 6 6 6 0 00-6-6zM24.5 21A1.5 1.5 0 1123 22.5 1.5 1.5 0 0124.5 21m0-2A3.5 3.5 0 1028 22.5 3.5 3.5 0 0024.5 19z"
  })), children);
});
var ChartBubble24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBubble24(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16a2 2 0 11-2 2 2 2 0 012-2m0-2a4 4 0 104 4 4 4 0 00-4-4zM21 6a4 4 0 11-4 4 4 4 0 014-4m0-2a6 6 0 106 6 6 6 0 00-6-6zM24.5 21A1.5 1.5 0 1123 22.5 1.5 1.5 0 0124.5 21m0-2A3.5 3.5 0 1028 22.5 3.5 3.5 0 0024.5 19z"
  })), children);
});
var ChartBubble20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBubble20(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16a2 2 0 11-2 2 2 2 0 012-2m0-2a4 4 0 104 4 4 4 0 00-4-4zM21 6a4 4 0 11-4 4 4 4 0 014-4m0-2a6 6 0 106 6 6 6 0 00-6-6zM24.5 21A1.5 1.5 0 1123 22.5 1.5 1.5 0 0124.5 21m0-2A3.5 3.5 0 1028 22.5 3.5 3.5 0 0024.5 19z"
  })), children);
});
var ChartBubble16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBubble16(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16a2 2 0 11-2 2 2 2 0 012-2m0-2a4 4 0 104 4 4 4 0 00-4-4zM21 6a4 4 0 11-4 4 4 4 0 014-4m0-2a6 6 0 106 6 6 6 0 00-6-6zM24.5 21A1.5 1.5 0 1123 22.5 1.5 1.5 0 0124.5 21m0-2A3.5 3.5 0 1028 22.5 3.5 3.5 0 0024.5 19z"
  })), children);
});
var ChartBubblePacked32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBubblePacked32(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.5322,17.1724A8.99,8.99,0,1,0,13.6074,5.88,5.9969,5.9969,0,1,0,5.051,13.2217a6.9967,6.9967,0,1,0,7.9942,11.4844A5.9981,5.9981,0,0,0,25,24c0-.1216-.011-.24-.0181-.3594a3.4873,3.4873,0,1,0,2.55-6.4682ZM21,4a7,7,0,1,1-7,7A7.0078,7.0078,0,0,1,21,4ZM8,4A4,4,0,1,1,4,8,4.0045,4.0045,0,0,1,8,4ZM19,28a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,19,28Z"
  })), children);
});
var ChartBubblePacked24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBubblePacked24(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.5322,17.1724A8.99,8.99,0,1,0,13.6074,5.88,5.9969,5.9969,0,1,0,5.051,13.2217a6.9967,6.9967,0,1,0,7.9942,11.4844A5.9981,5.9981,0,0,0,25,24c0-.1216-.011-.24-.0181-.3594a3.4873,3.4873,0,1,0,2.55-6.4682ZM21,4a7,7,0,1,1-7,7A7.0078,7.0078,0,0,1,21,4ZM8,4A4,4,0,1,1,4,8,4.0045,4.0045,0,0,1,8,4ZM19,28a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,19,28Z"
  })), children);
});
var ChartBubblePacked20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBubblePacked20(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.5322,17.1724A8.99,8.99,0,1,0,13.6074,5.88,5.9969,5.9969,0,1,0,5.051,13.2217a6.9967,6.9967,0,1,0,7.9942,11.4844A5.9981,5.9981,0,0,0,25,24c0-.1216-.011-.24-.0181-.3594a3.4873,3.4873,0,1,0,2.55-6.4682ZM21,4a7,7,0,1,1-7,7A7.0078,7.0078,0,0,1,21,4ZM8,4A4,4,0,1,1,4,8,4.0045,4.0045,0,0,1,8,4ZM19,28a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,19,28Z"
  })), children);
});
var ChartBubblePacked16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBubblePacked16(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.5322,17.1724A8.99,8.99,0,1,0,13.6074,5.88,5.9969,5.9969,0,1,0,5.051,13.2217a6.9967,6.9967,0,1,0,7.9942,11.4844A5.9981,5.9981,0,0,0,25,24c0-.1216-.011-.24-.0181-.3594a3.4873,3.4873,0,1,0,2.55-6.4682ZM21,4a7,7,0,1,1-7,7A7.0078,7.0078,0,0,1,21,4ZM8,4A4,4,0,1,1,4,8,4.0045,4.0045,0,0,1,8,4ZM19,28a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,19,28Z"
  })), children);
});
var ChartBullet32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBullet32(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 22H16V21H14v1H2v6H14v1h2V28H30zM4 26V24H14v2zm24 0H16V24H28zM30 13H24V12H22v1H2v6H22v1h2V19h6zM4 17V15H22v2zm24 0H24V15h4zM30 4H10V3H8V4H2v6H8v1h2V10H30zM4 8V6H8V8zM28 8H10V6H28z"
  })), children);
});
var ChartBullet24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBullet24(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 22H16V21H14v1H2v6H14v1h2V28H30zM4 26V24H14v2zm24 0H16V24H28zM30 13H24V12H22v1H2v6H22v1h2V19h6zM4 17V15H22v2zm24 0H24V15h4zM30 4H10V3H8V4H2v6H8v1h2V10H30zM4 8V6H8V8zM28 8H10V6H28z"
  })), children);
});
var ChartBullet20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBullet20(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 22H16V21H14v1H2v6H14v1h2V28H30zM4 26V24H14v2zm24 0H16V24H28zM30 13H24V12H22v1H2v6H22v1h2V19h6zM4 17V15H22v2zm24 0H24V15h4zM30 4H10V3H8V4H2v6H8v1h2V10H30zM4 8V6H8V8zM28 8H10V6H28z"
  })), children);
});
var ChartBullet16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartBullet16(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 22H16V21H14v1H2v6H14v1h2V28H30zM4 26V24H14v2zm24 0H16V24H28zM30 13H24V12H22v1H2v6H22v1h2V19h6zM4 17V15H22v2zm24 0H24V15h4zM30 4H10V3H8V4H2v6H8v1h2V10H30zM4 8V6H8V8zM28 8H10V6H28z"
  })), children);
});
var ChartCandlestick32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartCandlestick32(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 10H24V6H22v4H20V22h2v4h2V22h2zM24 20H22V12h2zM14 8H12V4H10V8H8V18h2v4h2V18h2zm-2 8H10V10h2z"
  })), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartCandlestick24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartCandlestick24(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 10H24V6H22v4H20V22h2v4h2V22h2zM24 20H22V12h2zM14 8H12V4H10V8H8V18h2v4h2V18h2zm-2 8H10V10h2z"
  })), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartCandlestick20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartCandlestick20(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 10H24V6H22v4H20V22h2v4h2V22h2zM24 20H22V12h2zM14 8H12V4H10V8H8V18h2v4h2V18h2zm-2 8H10V10h2z"
  })), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartCandlestick16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartCandlestick16(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 10H24V6H22v4H20V22h2v4h2V22h2zM24 20H22V12h2zM14 8H12V4H10V8H8V18h2v4h2V18h2zm-2 8H10V10h2z"
  })), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartClusterBar32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartClusterBar32(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16H12V26H10zM7 22H9V26H7zM26 8H28V26H26zM23 14H25V26H23z"
  })), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 12H17V26H15z",
    transform: "rotate(-180 16 19)"
  })), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 18H20V26H18z",
    transform: "rotate(-180 19 22)"
  })), children);
});
var ChartClusterBar24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartClusterBar24(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16H12V26H10zM7 22H9V26H7zM26 8H28V26H26zM23 14H25V26H23z"
  })), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 12H17V26H15z",
    transform: "rotate(-180 16 19)"
  })), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 18H20V26H18z",
    transform: "rotate(-180 19 22)"
  })), children);
});
var ChartClusterBar20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartClusterBar20(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16H12V26H10zM7 22H9V26H7zM26 8H28V26H26zM23 14H25V26H23z"
  })), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 12H17V26H15z",
    transform: "rotate(-180 16 19)"
  })), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 18H20V26H18z",
    transform: "rotate(-180 19 22)"
  })), children);
});
var ChartClusterBar16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartClusterBar16(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16H12V26H10zM7 22H9V26H7zM26 8H28V26H26zM23 14H25V26H23z"
  })), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 12H17V26H15z",
    transform: "rotate(-180 16 19)"
  })), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 18H20V26H18z",
    transform: "rotate(-180 19 22)"
  })), children);
});
var ChartColumn32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartColumn32(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,28V6H19V28H15V14H7V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM13,28H9V16h4Zm12,0H21V8h4Z"
  })), children);
});
var ChartColumn24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartColumn24(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,28V6H19V28H15V14H7V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM13,28H9V16h4Zm12,0H21V8h4Z"
  })), children);
});
var ChartColumn20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartColumn20(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,28V6H19V28H15V14H7V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM13,28H9V16h4Zm12,0H21V8h4Z"
  })), children);
});
var ChartColumn16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartColumn16(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,28V6H19V28H15V14H7V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM13,28H9V16h4Zm12,0H21V8h4Z"
  })), children);
});
var ChartColumnFloating32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartColumnFloating32(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 22H20V4h8zm-6-2h4V6H22zM16 24H8V10h8zm-6-2h4V12H10z"
  })), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2.0021,2.0021,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartColumnFloating24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartColumnFloating24(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 22H20V4h8zm-6-2h4V6H22zM16 24H8V10h8zm-6-2h4V12H10z"
  })), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2.0021,2.0021,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartColumnFloating20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartColumnFloating20(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 22H20V4h8zm-6-2h4V6H22zM16 24H8V10h8zm-6-2h4V12H10z"
  })), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2.0021,2.0021,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartColumnFloating16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartColumnFloating16(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 22H20V4h8zm-6-2h4V6H22zM16 24H8V10h8zm-6-2h4V12H10z"
  })), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2.0021,2.0021,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartColumnTarget32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartColumnTarget32(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 28V6H19V28H15V14H7V28H4V2H2V28a2 2 0 002 2H30V28zM13 28H9V16h4zm12 0H21V8h4zM19 2H27V4H19z"
  })), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 10H15V12H7z"
  })), children);
});
var ChartColumnTarget24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartColumnTarget24(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 28V6H19V28H15V14H7V28H4V2H2V28a2 2 0 002 2H30V28zM13 28H9V16h4zm12 0H21V8h4zM19 2H27V4H19z"
  })), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 10H15V12H7z"
  })), children);
});
var ChartColumnTarget20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartColumnTarget20(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 28V6H19V28H15V14H7V28H4V2H2V28a2 2 0 002 2H30V28zM13 28H9V16h4zm12 0H21V8h4zM19 2H27V4H19z"
  })), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 10H15V12H7z"
  })), children);
});
var ChartColumnTarget16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartColumnTarget16(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 28V6H19V28H15V14H7V28H4V2H2V28a2 2 0 002 2H30V28zM13 28H9V16h4zm12 0H21V8h4zM19 2H27V4H19z"
  })), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 10H15V12H7z"
  })), children);
});
var ChartCombo32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartCombo32(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,28V16H19V28H15V12H7V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM13,28H9V14h4Zm12,0H21V18h4Z"
  })), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.7856,14a1.9877,1.9877,0,0,1-1.1787-.3865L11.2041,5.987,8.2419,10,6.6374,8.8065l2.9812-4a1.9978,1.9978,0,0,1,2.749-.446l10.4214,7.64,3.6045-4.8613L28,8.3306l-3.6045,4.8611A2.0014,2.0014,0,0,1,22.7856,14Z"
  })), children);
});
var ChartCombo24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartCombo24(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,28V16H19V28H15V12H7V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM13,28H9V14h4Zm12,0H21V18h4Z"
  })), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.7856,14a1.9877,1.9877,0,0,1-1.1787-.3865L11.2041,5.987,8.2419,10,6.6374,8.8065l2.9812-4a1.9978,1.9978,0,0,1,2.749-.446l10.4214,7.64,3.6045-4.8613L28,8.3306l-3.6045,4.8611A2.0014,2.0014,0,0,1,22.7856,14Z"
  })), children);
});
var ChartCombo20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartCombo20(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,28V16H19V28H15V12H7V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM13,28H9V14h4Zm12,0H21V18h4Z"
  })), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.7856,14a1.9877,1.9877,0,0,1-1.1787-.3865L11.2041,5.987,8.2419,10,6.6374,8.8065l2.9812-4a1.9978,1.9978,0,0,1,2.749-.446l10.4214,7.64,3.6045-4.8613L28,8.3306l-3.6045,4.8611A2.0014,2.0014,0,0,1,22.7856,14Z"
  })), children);
});
var ChartCombo16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartCombo16(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,28V16H19V28H15V12H7V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM13,28H9V14h4Zm12,0H21V18h4Z"
  })), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.7856,14a1.9877,1.9877,0,0,1-1.1787-.3865L11.2041,5.987,8.2419,10,6.6374,8.8065l2.9812-4a1.9978,1.9978,0,0,1,2.749-.446l10.4214,7.64,3.6045-4.8613L28,8.3306l-3.6045,4.8611A2.0014,2.0014,0,0,1,22.7856,14Z"
  })), children);
});
var ChartComboStacked32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartComboStacked32(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,28V16H19V28H15V12H7V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM13,14v6H9V14Zm12,4v6H21V18Z"
  })), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.7856,14a1.9877,1.9877,0,0,1-1.1787-.3865L11.2041,5.987,8.2419,10,6.6374,8.8065l2.9812-4a1.9978,1.9978,0,0,1,2.749-.446l10.4214,7.64,3.6045-4.8613L28,8.3306l-3.6045,4.8611A2.0014,2.0014,0,0,1,22.7856,14Z"
  })), children);
});
var ChartComboStacked24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartComboStacked24(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,28V16H19V28H15V12H7V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM13,14v6H9V14Zm12,4v6H21V18Z"
  })), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.7856,14a1.9877,1.9877,0,0,1-1.1787-.3865L11.2041,5.987,8.2419,10,6.6374,8.8065l2.9812-4a1.9978,1.9978,0,0,1,2.749-.446l10.4214,7.64,3.6045-4.8613L28,8.3306l-3.6045,4.8611A2.0014,2.0014,0,0,1,22.7856,14Z"
  })), children);
});
var ChartComboStacked20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartComboStacked20(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,28V16H19V28H15V12H7V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM13,14v6H9V14Zm12,4v6H21V18Z"
  })), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.7856,14a1.9877,1.9877,0,0,1-1.1787-.3865L11.2041,5.987,8.2419,10,6.6374,8.8065l2.9812-4a1.9978,1.9978,0,0,1,2.749-.446l10.4214,7.64,3.6045-4.8613L28,8.3306l-3.6045,4.8611A2.0014,2.0014,0,0,1,22.7856,14Z"
  })), children);
});
var ChartComboStacked16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartComboStacked16(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,28V16H19V28H15V12H7V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM13,14v6H9V14Zm12,4v6H21V18Z"
  })), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22.7856,14a1.9877,1.9877,0,0,1-1.1787-.3865L11.2041,5.987,8.2419,10,6.6374,8.8065l2.9812-4a1.9978,1.9978,0,0,1,2.749-.446l10.4214,7.64,3.6045-4.8613L28,8.3306l-3.6045,4.8611A2.0014,2.0014,0,0,1,22.7856,14Z"
  })), children);
});
var ChartCustom32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartCustom32(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707,19.293l-3-3a.9994.9994,0,0,0-1.414,0L16,25.5859V30h4.4141l9.2929-9.293A.9994.9994,0,0,0,29.707,19.293ZM19.5859,28H18V26.4141l5-5L24.5859,23ZM26,21.5859,24.4141,20,26,18.4141,27.5859,20Z"
  })), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 15H21V17H17z",
    transform: "rotate(-90 19 16)"
  })), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 14H18V16H12z",
    transform: "rotate(-90 15 15)"
  })), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 12H16V14H6z",
    transform: "rotate(-90 11 13)"
  })), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h6Z"
  })), children);
});
var ChartCustom24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartCustom24(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707,19.293l-3-3a.9994.9994,0,0,0-1.414,0L16,25.5859V30h4.4141l9.2929-9.293A.9994.9994,0,0,0,29.707,19.293ZM19.5859,28H18V26.4141l5-5L24.5859,23ZM26,21.5859,24.4141,20,26,18.4141,27.5859,20Z"
  })), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 15H21V17H17z",
    transform: "rotate(-90 19 16)"
  })), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 14H18V16H12z",
    transform: "rotate(-90 15 15)"
  })), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 12H16V14H6z",
    transform: "rotate(-90 11 13)"
  })), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h6Z"
  })), children);
});
var ChartCustom20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartCustom20(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707,19.293l-3-3a.9994.9994,0,0,0-1.414,0L16,25.5859V30h4.4141l9.2929-9.293A.9994.9994,0,0,0,29.707,19.293ZM19.5859,28H18V26.4141l5-5L24.5859,23ZM26,21.5859,24.4141,20,26,18.4141,27.5859,20Z"
  })), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 15H21V17H17z",
    transform: "rotate(-90 19 16)"
  })), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 14H18V16H12z",
    transform: "rotate(-90 15 15)"
  })), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 12H16V14H6z",
    transform: "rotate(-90 11 13)"
  })), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h6Z"
  })), children);
});
var ChartCustom16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartCustom16(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.707,19.293l-3-3a.9994.9994,0,0,0-1.414,0L16,25.5859V30h4.4141l9.2929-9.293A.9994.9994,0,0,0,29.707,19.293ZM19.5859,28H18V26.4141l5-5L24.5859,23ZM26,21.5859,24.4141,20,26,18.4141,27.5859,20Z"
  })), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 15H21V17H17z",
    transform: "rotate(-90 19 16)"
  })), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 14H18V16H12z",
    transform: "rotate(-90 15 15)"
  })), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 12H16V14H6z",
    transform: "rotate(-90 11 13)"
  })), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2V14H22V4H6V28h6Z"
  })), children);
});
var ChartErrorBar32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartErrorBar32(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,28V12H18V8h2V6H14V8h2v4H12V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM14,14h2v4H14Zm6,14H14V20h6Zm0-10H18V14h2Z"
  })), children);
});
var ChartErrorBar24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartErrorBar24(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,28V12H18V8h2V6H14V8h2v4H12V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM14,14h2v4H14Zm6,14H14V20h6Zm0-10H18V14h2Z"
  })), children);
});
var ChartErrorBar20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartErrorBar20(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,28V12H18V8h2V6H14V8h2v4H12V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM14,14h2v4H14Zm6,14H14V20h6Zm0-10H18V14h2Z"
  })), children);
});
var ChartErrorBar16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartErrorBar16(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,28V12H18V8h2V6H14V8h2v4H12V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM14,14h2v4H14Zm6,14H14V20h6Zm0-10H18V14h2Z"
  })), children);
});
var ChartErrorBarAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartErrorBarAlt32(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 10V8H8v2h2v4.1836a2.983 2.983 0 000 5.6328V24H8v2h6V24H12V19.8164a2.983 2.983 0 000-5.6328V10zM26 6V4H20V6h2V8.1836a2.983 2.983 0 000 5.6328V18H20v2h6V18H24V13.8164a2.983 2.983 0 000-5.6328V6z"
  })), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartErrorBarAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartErrorBarAlt24(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 10V8H8v2h2v4.1836a2.983 2.983 0 000 5.6328V24H8v2h6V24H12V19.8164a2.983 2.983 0 000-5.6328V10zM26 6V4H20V6h2V8.1836a2.983 2.983 0 000 5.6328V18H20v2h6V18H24V13.8164a2.983 2.983 0 000-5.6328V6z"
  })), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartErrorBarAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartErrorBarAlt20(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 10V8H8v2h2v4.1836a2.983 2.983 0 000 5.6328V24H8v2h6V24H12V19.8164a2.983 2.983 0 000-5.6328V10zM26 6V4H20V6h2V8.1836a2.983 2.983 0 000 5.6328V18H20v2h6V18H24V13.8164a2.983 2.983 0 000-5.6328V6z"
  })), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartErrorBarAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartErrorBarAlt16(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 10V8H8v2h2v4.1836a2.983 2.983 0 000 5.6328V24H8v2h6V24H12V19.8164a2.983 2.983 0 000-5.6328V10zM26 6V4H20V6h2V8.1836a2.983 2.983 0 000 5.6328V18H20v2h6V18H24V13.8164a2.983 2.983 0 000-5.6328V6z"
  })), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartEvaluation32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartEvaluation32(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.672 6.207H29.915V8.206H25.672z",
    transform: "rotate(-45.02 27.793 7.207)"
  })), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 20.5L11 15.539 12.59 13.969 16 17.349 23.41 10 25 11.579 16 20.5z"
  })), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V25.4131L10.4141,19,9,17.585l-5,5V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), children);
});
var ChartEvaluation24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartEvaluation24(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.672 6.207H29.915V8.206H25.672z",
    transform: "rotate(-45.02 27.793 7.207)"
  })), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 20.5L11 15.539 12.59 13.969 16 17.349 23.41 10 25 11.579 16 20.5z"
  })), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V25.4131L10.4141,19,9,17.585l-5,5V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), children);
});
var ChartEvaluation20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartEvaluation20(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.672 6.207H29.915V8.206H25.672z",
    transform: "rotate(-45.02 27.793 7.207)"
  })), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 20.5L11 15.539 12.59 13.969 16 17.349 23.41 10 25 11.579 16 20.5z"
  })), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V25.4131L10.4141,19,9,17.585l-5,5V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), children);
});
var ChartEvaluation16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartEvaluation16(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.672 6.207H29.915V8.206H25.672z",
    transform: "rotate(-45.02 27.793 7.207)"
  })), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 20.5L11 15.539 12.59 13.969 16 17.349 23.41 10 25 11.579 16 20.5z"
  })), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V25.4131L10.4141,19,9,17.585l-5,5V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), children);
});
var ChartHighLow32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartHighLow32(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 8L12 8 12 6 10 6 10 20 7 20 7 22 10 22 10 24 12 24 12 10 15 10 15 8zM27 10L24 10 24 6 22 6 22 18 19 18 19 20 22 20 22 24 24 24 24 12 27 12 27 10z"
  })), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartHighLow24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartHighLow24(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 8L12 8 12 6 10 6 10 20 7 20 7 22 10 22 10 24 12 24 12 10 15 10 15 8zM27 10L24 10 24 6 22 6 22 18 19 18 19 20 22 20 22 24 24 24 24 12 27 12 27 10z"
  })), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartHighLow20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartHighLow20(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 8L12 8 12 6 10 6 10 20 7 20 7 22 10 22 10 24 12 24 12 10 15 10 15 8zM27 10L24 10 24 6 22 6 22 18 19 18 19 20 22 20 22 24 24 24 24 12 27 12 27 10z"
  })), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartHighLow16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartHighLow16(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 8L12 8 12 6 10 6 10 20 7 20 7 22 10 22 10 24 12 24 12 10 15 10 15 8zM27 10L24 10 24 6 22 6 22 18 19 18 19 20 22 20 22 24 24 24 24 12 27 12 27 10z"
  })), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), children);
});
var ChartHistogram32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartHistogram32(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,16c2.9727,0,4.2324-2.251,5.3447-4.2373C12.4741,9.7441,13.45,8,16,8s3.5259,1.7441,4.6553,3.7627C21.7676,13.749,23.0273,16,26,16h4V14H26c-1.7129,0-2.4834-1.2207-3.5991-3.2144C21.2075,8.6543,19.7231,6,16,6s-5.2075,2.6543-6.4009,4.7856C8.4834,12.7793,7.7129,14,6,14H4V2H2V28a2,2,0,0,0,2,2H30V28H28V22H26v6H21.9992L22,20H20v8H16V16H14V28H9.9992L10,20H8v8H4V16Z"
  })), children);
});
var ChartHistogram24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartHistogram24(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,16c2.9727,0,4.2324-2.251,5.3447-4.2373C12.4741,9.7441,13.45,8,16,8s3.5259,1.7441,4.6553,3.7627C21.7676,13.749,23.0273,16,26,16h4V14H26c-1.7129,0-2.4834-1.2207-3.5991-3.2144C21.2075,8.6543,19.7231,6,16,6s-5.2075,2.6543-6.4009,4.7856C8.4834,12.7793,7.7129,14,6,14H4V2H2V28a2,2,0,0,0,2,2H30V28H28V22H26v6H21.9992L22,20H20v8H16V16H14V28H9.9992L10,20H8v8H4V16Z"
  })), children);
});
var ChartHistogram20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartHistogram20(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,16c2.9727,0,4.2324-2.251,5.3447-4.2373C12.4741,9.7441,13.45,8,16,8s3.5259,1.7441,4.6553,3.7627C21.7676,13.749,23.0273,16,26,16h4V14H26c-1.7129,0-2.4834-1.2207-3.5991-3.2144C21.2075,8.6543,19.7231,6,16,6s-5.2075,2.6543-6.4009,4.7856C8.4834,12.7793,7.7129,14,6,14H4V2H2V28a2,2,0,0,0,2,2H30V28H28V22H26v6H21.9992L22,20H20v8H16V16H14V28H9.9992L10,20H8v8H4V16Z"
  })), children);
});
var ChartHistogram16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartHistogram16(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,16c2.9727,0,4.2324-2.251,5.3447-4.2373C12.4741,9.7441,13.45,8,16,8s3.5259,1.7441,4.6553,3.7627C21.7676,13.749,23.0273,16,26,16h4V14H26c-1.7129,0-2.4834-1.2207-3.5991-3.2144C21.2075,8.6543,19.7231,6,16,6s-5.2075,2.6543-6.4009,4.7856C8.4834,12.7793,7.7129,14,6,14H4V2H2V28a2,2,0,0,0,2,2H30V28H28V22H26v6H21.9992L22,20H20v8H16V16H14V28H9.9992L10,20H8v8H4V16Z"
  })), children);
});
var ChartLine32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartLine32(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.67,28l6.39-12,7.3,6.49a2,2,0,0,0,1.7.47,2,2,0,0,0,1.42-1.07L27,10.9,25.18,10,19.69,21l-7.3-6.49A2,2,0,0,0,10.71,14a2,2,0,0,0-1.42,1L4,25V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), children);
});
var ChartLine24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartLine24(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.67,28l6.39-12,7.3,6.49a2,2,0,0,0,1.7.47,2,2,0,0,0,1.42-1.07L27,10.9,25.18,10,19.69,21l-7.3-6.49A2,2,0,0,0,10.71,14a2,2,0,0,0-1.42,1L4,25V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), children);
});
var ChartLine20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartLine20(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.67,28l6.39-12,7.3,6.49a2,2,0,0,0,1.7.47,2,2,0,0,0,1.42-1.07L27,10.9,25.18,10,19.69,21l-7.3-6.49A2,2,0,0,0,10.71,14a2,2,0,0,0-1.42,1L4,25V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), children);
});
var ChartLine16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartLine16(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.67,28l6.39-12,7.3,6.49a2,2,0,0,0,1.7.47,2,2,0,0,0,1.42-1.07L27,10.9,25.18,10,19.69,21l-7.3-6.49A2,2,0,0,0,10.71,14a2,2,0,0,0-1.42,1L4,25V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), children);
});
var ChartLineData32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartLineData32(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.06,17.88A4.25,4.25,0,0,0,11,18a4,4,0,0,0,2.23-.68l3.22,2.87a3.88,3.88,0,0,0-.2,3.17A4,4,0,1,0,22.62,19l2.54-5.09a3.78,3.78,0,0,0,2.91-.53A4,4,0,1,0,23.38,13l-2.54,5.09A3.86,3.86,0,0,0,20,18a4,4,0,0,0-2.23.68l-3.22-2.87a3.88,3.88,0,0,0,.2-3.17A4,4,0,1,0,8.3,16.93L4,25V2H2V28a2,2,0,0,0,2,2H30V28H4.67ZM26,8a2,2,0,1,1-2,2A2,2,0,0,1,26,8ZM22,22a2,2,0,1,1-2-2A2,2,0,0,1,22,22ZM11,12a2,2,0,1,1-2,2A2,2,0,0,1,11,12Z"
  })), children);
});
var ChartLineData24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartLineData24(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.06,17.88A4.25,4.25,0,0,0,11,18a4,4,0,0,0,2.23-.68l3.22,2.87a3.88,3.88,0,0,0-.2,3.17A4,4,0,1,0,22.62,19l2.54-5.09a3.78,3.78,0,0,0,2.91-.53A4,4,0,1,0,23.38,13l-2.54,5.09A3.86,3.86,0,0,0,20,18a4,4,0,0,0-2.23.68l-3.22-2.87a3.88,3.88,0,0,0,.2-3.17A4,4,0,1,0,8.3,16.93L4,25V2H2V28a2,2,0,0,0,2,2H30V28H4.67ZM26,8a2,2,0,1,1-2,2A2,2,0,0,1,26,8ZM22,22a2,2,0,1,1-2-2A2,2,0,0,1,22,22ZM11,12a2,2,0,1,1-2,2A2,2,0,0,1,11,12Z"
  })), children);
});
var ChartLineData20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartLineData20(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.06,17.88A4.25,4.25,0,0,0,11,18a4,4,0,0,0,2.23-.68l3.22,2.87a3.88,3.88,0,0,0-.2,3.17A4,4,0,1,0,22.62,19l2.54-5.09a3.78,3.78,0,0,0,2.91-.53A4,4,0,1,0,23.38,13l-2.54,5.09A3.86,3.86,0,0,0,20,18a4,4,0,0,0-2.23.68l-3.22-2.87a3.88,3.88,0,0,0,.2-3.17A4,4,0,1,0,8.3,16.93L4,25V2H2V28a2,2,0,0,0,2,2H30V28H4.67ZM26,8a2,2,0,1,1-2,2A2,2,0,0,1,26,8ZM22,22a2,2,0,1,1-2-2A2,2,0,0,1,22,22ZM11,12a2,2,0,1,1-2,2A2,2,0,0,1,11,12Z"
  })), children);
});
var ChartLineData16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartLineData16(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.06,17.88A4.25,4.25,0,0,0,11,18a4,4,0,0,0,2.23-.68l3.22,2.87a3.88,3.88,0,0,0-.2,3.17A4,4,0,1,0,22.62,19l2.54-5.09a3.78,3.78,0,0,0,2.91-.53A4,4,0,1,0,23.38,13l-2.54,5.09A3.86,3.86,0,0,0,20,18a4,4,0,0,0-2.23.68l-3.22-2.87a3.88,3.88,0,0,0,.2-3.17A4,4,0,1,0,8.3,16.93L4,25V2H2V28a2,2,0,0,0,2,2H30V28H4.67ZM26,8a2,2,0,1,1-2,2A2,2,0,0,1,26,8ZM22,22a2,2,0,1,1-2-2A2,2,0,0,1,22,22ZM11,12a2,2,0,1,1-2,2A2,2,0,0,1,11,12Z"
  })), children);
});
var ChartLineSmooth32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartLineSmooth32(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,15c1.4854,0,2.5544,1.4966,3.6863,3.0811C17.9983,19.918,19.4854,22,22,22c5.6709,0,7.78-10.79,8-12l-1.9678-.3584C27.55,12.2827,25.3938,20,22,20c-1.4854,0-2.5544-1.4966-3.6863-3.0811C17.0017,15.082,15.5146,13,13,13c-4.186,0-7.4448,7.4043-9,11.7617V2H2V28a2.0025,2.0025,0,0,0,2,2H30V28H5.0439C6.5544,22.8574,9.9634,15,13,15Z"
  })), children);
});
var ChartLineSmooth24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartLineSmooth24(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,15c1.4854,0,2.5544,1.4966,3.6863,3.0811C17.9983,19.918,19.4854,22,22,22c5.6709,0,7.78-10.79,8-12l-1.9678-.3584C27.55,12.2827,25.3938,20,22,20c-1.4854,0-2.5544-1.4966-3.6863-3.0811C17.0017,15.082,15.5146,13,13,13c-4.186,0-7.4448,7.4043-9,11.7617V2H2V28a2.0025,2.0025,0,0,0,2,2H30V28H5.0439C6.5544,22.8574,9.9634,15,13,15Z"
  })), children);
});
var ChartLineSmooth20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartLineSmooth20(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,15c1.4854,0,2.5544,1.4966,3.6863,3.0811C17.9983,19.918,19.4854,22,22,22c5.6709,0,7.78-10.79,8-12l-1.9678-.3584C27.55,12.2827,25.3938,20,22,20c-1.4854,0-2.5544-1.4966-3.6863-3.0811C17.0017,15.082,15.5146,13,13,13c-4.186,0-7.4448,7.4043-9,11.7617V2H2V28a2.0025,2.0025,0,0,0,2,2H30V28H5.0439C6.5544,22.8574,9.9634,15,13,15Z"
  })), children);
});
var ChartLineSmooth16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartLineSmooth16(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13,15c1.4854,0,2.5544,1.4966,3.6863,3.0811C17.9983,19.918,19.4854,22,22,22c5.6709,0,7.78-10.79,8-12l-1.9678-.3584C27.55,12.2827,25.3938,20,22,20c-1.4854,0-2.5544-1.4966-3.6863-3.0811C17.0017,15.082,15.5146,13,13,13c-4.186,0-7.4448,7.4043-9,11.7617V2H2V28a2.0025,2.0025,0,0,0,2,2H30V28H5.0439C6.5544,22.8574,9.9634,15,13,15Z"
  })), children);
});
var ChartMarimekko32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMarimekko32(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2.0025,2.0025,0,0,0,3,5V27a2.0025,2.0025,0,0,0,2,2H27a2.0025,2.0025,0,0,0,2-2V5A2.0025,2.0025,0,0,0,27,3Zm0,7H21V5h6ZM19,8H13V5h6Zm0,2v8H13V10ZM11,22H5V12h6Zm2-2h6v7H13Zm8-8h6v4H21ZM11,5v5H5V5ZM5,24h6v3H5Zm16,3V18h6v9Z"
  })), children);
});
var ChartMarimekko24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMarimekko24(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2.0025,2.0025,0,0,0,3,5V27a2.0025,2.0025,0,0,0,2,2H27a2.0025,2.0025,0,0,0,2-2V5A2.0025,2.0025,0,0,0,27,3Zm0,7H21V5h6ZM19,8H13V5h6Zm0,2v8H13V10ZM11,22H5V12h6Zm2-2h6v7H13Zm8-8h6v4H21ZM11,5v5H5V5ZM5,24h6v3H5Zm16,3V18h6v9Z"
  })), children);
});
var ChartMarimekko20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMarimekko20(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2.0025,2.0025,0,0,0,3,5V27a2.0025,2.0025,0,0,0,2,2H27a2.0025,2.0025,0,0,0,2-2V5A2.0025,2.0025,0,0,0,27,3Zm0,7H21V5h6ZM19,8H13V5h6Zm0,2v8H13V10ZM11,22H5V12h6Zm2-2h6v7H13Zm8-8h6v4H21ZM11,5v5H5V5ZM5,24h6v3H5Zm16,3V18h6v9Z"
  })), children);
});
var ChartMarimekko16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMarimekko16(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2.0025,2.0025,0,0,0,3,5V27a2.0025,2.0025,0,0,0,2,2H27a2.0025,2.0025,0,0,0,2-2V5A2.0025,2.0025,0,0,0,27,3Zm0,7H21V5h6ZM19,8H13V5h6Zm0,2v8H13V10ZM11,22H5V12h6Zm2-2h6v7H13Zm8-8h6v4H21ZM11,5v5H5V5ZM5,24h6v3H5Zm16,3V18h6v9Z"
  })), children);
});
var ChartMaximum32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMaximum32(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 6H10V8H8zM12 6H14V8H12zM20 6H22V8H20zM24 6H26V8H24zM28 6H30V8H28z"
  })), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.989,28l-.0271-.1631C26.5105,19.0742,24.0662,9.0894,18,8.0889V6H16V8.085c-6.084.978-8.533,10.9775-9.9863,19.7519L5.9866,28H4V8H6V6H4V2H2V28a2,2,0,0,0,2,2H30V28ZM8.0151,28c2.024-12.1084,4.959-18,8.9727-18s6.9487,5.8916,8.9726,18Z"
  })), children);
});
var ChartMaximum24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMaximum24(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 6H10V8H8zM12 6H14V8H12zM20 6H22V8H20zM24 6H26V8H24zM28 6H30V8H28z"
  })), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.989,28l-.0271-.1631C26.5105,19.0742,24.0662,9.0894,18,8.0889V6H16V8.085c-6.084.978-8.533,10.9775-9.9863,19.7519L5.9866,28H4V8H6V6H4V2H2V28a2,2,0,0,0,2,2H30V28ZM8.0151,28c2.024-12.1084,4.959-18,8.9727-18s6.9487,5.8916,8.9726,18Z"
  })), children);
});
var ChartMaximum20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMaximum20(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 6H10V8H8zM12 6H14V8H12zM20 6H22V8H20zM24 6H26V8H24zM28 6H30V8H28z"
  })), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.989,28l-.0271-.1631C26.5105,19.0742,24.0662,9.0894,18,8.0889V6H16V8.085c-6.084.978-8.533,10.9775-9.9863,19.7519L5.9866,28H4V8H6V6H4V2H2V28a2,2,0,0,0,2,2H30V28ZM8.0151,28c2.024-12.1084,4.959-18,8.9727-18s6.9487,5.8916,8.9726,18Z"
  })), children);
});
var ChartMaximum16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMaximum16(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 6H10V8H8zM12 6H14V8H12zM20 6H22V8H20zM24 6H26V8H24zM28 6H30V8H28z"
  })), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.989,28l-.0271-.1631C26.5105,19.0742,24.0662,9.0894,18,8.0889V6H16V8.085c-6.084.978-8.533,10.9775-9.9863,19.7519L5.9866,28H4V8H6V6H4V2H2V28a2,2,0,0,0,2,2H30V28ZM8.0151,28c2.024-12.1084,4.959-18,8.9727-18s6.9487,5.8916,8.9726,18Z"
  })), children);
});
var ChartMedian32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMedian32(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22H18V24H16z",
    transform: "rotate(-90 17 23)"
  })), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28V26H16v2H4V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.0532,19.6787A3.44,3.44,0,0,1,23,22c-2.17,0-3.3115-3.333-4.52-6.8623-.3557-1.0386-.7239-2.1094-1.1382-3.1377H18V10H16.4221C15.2124,7.7148,13.5811,6,11,6,7.3218,6,6.1016,9.5332,6.0513,9.6836l1.8955.6377A3.44,3.44,0,0,1,11,8c2.92,0,4.2764,3.958,5.5874,7.7861.2544.7422.5105,1.4893.7813,2.2139H16v2h2.2019c1.0828,2.2886,2.4959,4,4.7981,4,3.6782,0,4.8984-3.5332,4.9487-3.6836Z"
  })), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 6H18V8H16z",
    transform: "rotate(-90 17 7)"
  })), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 2H18V4H16z",
    transform: "rotate(-90 17 3)"
  })), children);
});
var ChartMedian24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMedian24(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22H18V24H16z",
    transform: "rotate(-90 17 23)"
  })), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28V26H16v2H4V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.0532,19.6787A3.44,3.44,0,0,1,23,22c-2.17,0-3.3115-3.333-4.52-6.8623-.3557-1.0386-.7239-2.1094-1.1382-3.1377H18V10H16.4221C15.2124,7.7148,13.5811,6,11,6,7.3218,6,6.1016,9.5332,6.0513,9.6836l1.8955.6377A3.44,3.44,0,0,1,11,8c2.92,0,4.2764,3.958,5.5874,7.7861.2544.7422.5105,1.4893.7813,2.2139H16v2h2.2019c1.0828,2.2886,2.4959,4,4.7981,4,3.6782,0,4.8984-3.5332,4.9487-3.6836Z"
  })), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 6H18V8H16z",
    transform: "rotate(-90 17 7)"
  })), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 2H18V4H16z",
    transform: "rotate(-90 17 3)"
  })), children);
});
var ChartMedian20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMedian20(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22H18V24H16z",
    transform: "rotate(-90 17 23)"
  })), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28V26H16v2H4V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.0532,19.6787A3.44,3.44,0,0,1,23,22c-2.17,0-3.3115-3.333-4.52-6.8623-.3557-1.0386-.7239-2.1094-1.1382-3.1377H18V10H16.4221C15.2124,7.7148,13.5811,6,11,6,7.3218,6,6.1016,9.5332,6.0513,9.6836l1.8955.6377A3.44,3.44,0,0,1,11,8c2.92,0,4.2764,3.958,5.5874,7.7861.2544.7422.5105,1.4893.7813,2.2139H16v2h2.2019c1.0828,2.2886,2.4959,4,4.7981,4,3.6782,0,4.8984-3.5332,4.9487-3.6836Z"
  })), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 6H18V8H16z",
    transform: "rotate(-90 17 7)"
  })), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 2H18V4H16z",
    transform: "rotate(-90 17 3)"
  })), children);
});
var ChartMedian16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMedian16(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22H18V24H16z",
    transform: "rotate(-90 17 23)"
  })), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28V26H16v2H4V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.0532,19.6787A3.44,3.44,0,0,1,23,22c-2.17,0-3.3115-3.333-4.52-6.8623-.3557-1.0386-.7239-2.1094-1.1382-3.1377H18V10H16.4221C15.2124,7.7148,13.5811,6,11,6,7.3218,6,6.1016,9.5332,6.0513,9.6836l1.8955.6377A3.44,3.44,0,0,1,11,8c2.92,0,4.2764,3.958,5.5874,7.7861.2544.7422.5105,1.4893.7813,2.2139H16v2h2.2019c1.0828,2.2886,2.4959,4,4.7981,4,3.6782,0,4.8984-3.5332,4.9487-3.6836Z"
  })), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 6H18V8H16z",
    transform: "rotate(-90 17 7)"
  })), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 2H18V4H16z",
    transform: "rotate(-90 17 3)"
  })), children);
});
var ChartMinimum32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMinimum32(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V26H6V24H4V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 24H10V26H8zM12 24H14V26H12zM20 24H22V26H20zM24 24H26V26H24zM28 24H30V26H28z"
  })), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.9463,4.3281,25.9727,4C23.9487,16.1084,21.0137,22,17,22S10.0513,16.1084,8.0271,4l-1.9734.3281C7.51,13.0566,9.9631,22.93,16,23.9131V26h2V23.9131C24.0371,22.93,26.4907,13.0566,27.9463,4.3281Z"
  })), children);
});
var ChartMinimum24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMinimum24(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V26H6V24H4V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 24H10V26H8zM12 24H14V26H12zM20 24H22V26H20zM24 24H26V26H24zM28 24H30V26H28z"
  })), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.9463,4.3281,25.9727,4C23.9487,16.1084,21.0137,22,17,22S10.0513,16.1084,8.0271,4l-1.9734.3281C7.51,13.0566,9.9631,22.93,16,23.9131V26h2V23.9131C24.0371,22.93,26.4907,13.0566,27.9463,4.3281Z"
  })), children);
});
var ChartMinimum20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMinimum20(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V26H6V24H4V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 24H10V26H8zM12 24H14V26H12zM20 24H22V26H20zM24 24H26V26H24zM28 24H30V26H28z"
  })), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.9463,4.3281,25.9727,4C23.9487,16.1084,21.0137,22,17,22S10.0513,16.1084,8.0271,4l-1.9734.3281C7.51,13.0566,9.9631,22.93,16,23.9131V26h2V23.9131C24.0371,22.93,26.4907,13.0566,27.9463,4.3281Z"
  })), children);
});
var ChartMinimum16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMinimum16(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,28V26H6V24H4V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 24H10V26H8zM12 24H14V26H12zM20 24H22V26H20zM24 24H26V26H24zM28 24H30V26H28z"
  })), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.9463,4.3281,25.9727,4C23.9487,16.1084,21.0137,22,17,22S10.0513,16.1084,8.0271,4l-1.9734.3281C7.51,13.0566,9.9631,22.93,16,23.9131V26h2V23.9131C24.0371,22.93,26.4907,13.0566,27.9463,4.3281Z"
  })), children);
});
var ChartMultiLine32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMultiLine32(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.5859,28l7.1783-5.998L19.7578,23.94a2.021,2.021,0,0,0,1.314-.1206L28,20.5811l-.8479-1.8121-6.9163,3.229L12.2422,20.06a2.0033,2.0033,0,0,0-1.74.3838L4,25.8818V20.49l7.7642-6.4877L19.7578,15.94a2.021,2.021,0,0,0,1.314-.1206l6.9287-3.2383-.8467-1.812-6.918,3.2285L12.2422,12.06a2.0049,2.0049,0,0,0-1.74.3838L4,17.8818V12.49L11.7642,6.002,19.7578,7.94a2.021,2.021,0,0,0,1.314-.1206L28,4.5859l-.8457-1.8115L20.2358,5.998,12.2422,4.06a2.0033,2.0033,0,0,0-1.74.3838L4,9.8818V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), children);
});
var ChartMultiLine24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMultiLine24(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.5859,28l7.1783-5.998L19.7578,23.94a2.021,2.021,0,0,0,1.314-.1206L28,20.5811l-.8479-1.8121-6.9163,3.229L12.2422,20.06a2.0033,2.0033,0,0,0-1.74.3838L4,25.8818V20.49l7.7642-6.4877L19.7578,15.94a2.021,2.021,0,0,0,1.314-.1206l6.9287-3.2383-.8467-1.812-6.918,3.2285L12.2422,12.06a2.0049,2.0049,0,0,0-1.74.3838L4,17.8818V12.49L11.7642,6.002,19.7578,7.94a2.021,2.021,0,0,0,1.314-.1206L28,4.5859l-.8457-1.8115L20.2358,5.998,12.2422,4.06a2.0033,2.0033,0,0,0-1.74.3838L4,9.8818V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), children);
});
var ChartMultiLine20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMultiLine20(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.5859,28l7.1783-5.998L19.7578,23.94a2.021,2.021,0,0,0,1.314-.1206L28,20.5811l-.8479-1.8121-6.9163,3.229L12.2422,20.06a2.0033,2.0033,0,0,0-1.74.3838L4,25.8818V20.49l7.7642-6.4877L19.7578,15.94a2.021,2.021,0,0,0,1.314-.1206l6.9287-3.2383-.8467-1.812-6.918,3.2285L12.2422,12.06a2.0049,2.0049,0,0,0-1.74.3838L4,17.8818V12.49L11.7642,6.002,19.7578,7.94a2.021,2.021,0,0,0,1.314-.1206L28,4.5859l-.8457-1.8115L20.2358,5.998,12.2422,4.06a2.0033,2.0033,0,0,0-1.74.3838L4,9.8818V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), children);
});
var ChartMultiLine16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMultiLine16(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4.5859,28l7.1783-5.998L19.7578,23.94a2.021,2.021,0,0,0,1.314-.1206L28,20.5811l-.8479-1.8121-6.9163,3.229L12.2422,20.06a2.0033,2.0033,0,0,0-1.74.3838L4,25.8818V20.49l7.7642-6.4877L19.7578,15.94a2.021,2.021,0,0,0,1.314-.1206l6.9287-3.2383-.8467-1.812-6.918,3.2285L12.2422,12.06a2.0049,2.0049,0,0,0-1.74.3838L4,17.8818V12.49L11.7642,6.002,19.7578,7.94a2.021,2.021,0,0,0,1.314-.1206L28,4.5859l-.8457-1.8115L20.2358,5.998,12.2422,4.06a2.0033,2.0033,0,0,0-1.74.3838L4,9.8818V2H2V28a2,2,0,0,0,2,2H30V28Z"
  })), children);
});
var ChartMultitype32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMultitype32(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 22H30V30H28zM24 18H26V30H24zM20 26H22V30H20zM9 16a7 7 0 107 7A7.0078 7.0078 0 009 16zm4.8989 6H10V18.1011A5.0145 5.0145 0 0113.8989 22zM9 28a5 5 0 01-1-9.8989V22a2 2 0 002 2h3.8989A5.0081 5.0081 0 019 28zM22.5352 12l4-6H30V4H25.4648l-4 6H18V2H16V14a2 2 0 002 2H30V14H18V12z"
  })), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "7",
    r: "1"
  })), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "11",
    r: "1"
  })), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "5",
    r: "1"
  })), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "5",
    cy: "9",
    r: "1"
  })), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "13",
    r: "1"
  })), children);
});
var ChartMultitype24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMultitype24(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 22H30V30H28zM24 18H26V30H24zM20 26H22V30H20zM9 16a7 7 0 107 7A7.0078 7.0078 0 009 16zm4.8989 6H10V18.1011A5.0145 5.0145 0 0113.8989 22zM9 28a5 5 0 01-1-9.8989V22a2 2 0 002 2h3.8989A5.0081 5.0081 0 019 28zM22.5352 12l4-6H30V4H25.4648l-4 6H18V2H16V14a2 2 0 002 2H30V14H18V12z"
  })), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "7",
    r: "1"
  })), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "11",
    r: "1"
  })), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "5",
    r: "1"
  })), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "5",
    cy: "9",
    r: "1"
  })), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "13",
    r: "1"
  })), children);
});
var ChartMultitype20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMultitype20(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 22H30V30H28zM24 18H26V30H24zM20 26H22V30H20zM9 16a7 7 0 107 7A7.0078 7.0078 0 009 16zm4.8989 6H10V18.1011A5.0145 5.0145 0 0113.8989 22zM9 28a5 5 0 01-1-9.8989V22a2 2 0 002 2h3.8989A5.0081 5.0081 0 019 28zM22.5352 12l4-6H30V4H25.4648l-4 6H18V2H16V14a2 2 0 002 2H30V14H18V12z"
  })), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "7",
    r: "1"
  })), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "11",
    r: "1"
  })), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "5",
    r: "1"
  })), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "5",
    cy: "9",
    r: "1"
  })), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "13",
    r: "1"
  })), children);
});
var ChartMultitype16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartMultitype16(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 22H30V30H28zM24 18H26V30H24zM20 26H22V30H20zM9 16a7 7 0 107 7A7.0078 7.0078 0 009 16zm4.8989 6H10V18.1011A5.0145 5.0145 0 0113.8989 22zM9 28a5 5 0 01-1-9.8989V22a2 2 0 002 2h3.8989A5.0081 5.0081 0 019 28zM22.5352 12l4-6H30V4H25.4648l-4 6H18V2H16V14a2 2 0 002 2H30V14H18V12z"
  })), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "7",
    r: "1"
  })), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "11",
    r: "1"
  })), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "5",
    r: "1"
  })), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "5",
    cy: "9",
    r: "1"
  })), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "13",
    r: "1"
  })), children);
});
var ChartNetwork32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartNetwork32(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,14a2,2,0,0,0,2-2V6a2,2,0,0,0-2-2H20a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h2v4.1A5,5,0,0,0,18.1,22H14V20a2,2,0,0,0-2-2H10V13.9a5,5,0,1,0-2,0V18H6a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V24h4.1A5,5,0,1,0,24,18.1V14ZM6,9a3,3,0,1,1,3,3A3,3,0,0,1,6,9Zm6,17H6V20h6Zm14-3a3,3,0,1,1-3-3A3,3,0,0,1,26,23ZM20,6h6v6H20Z"
  })), children);
});
var ChartNetwork24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartNetwork24(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,14a2,2,0,0,0,2-2V6a2,2,0,0,0-2-2H20a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h2v4.1A5,5,0,0,0,18.1,22H14V20a2,2,0,0,0-2-2H10V13.9a5,5,0,1,0-2,0V18H6a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V24h4.1A5,5,0,1,0,24,18.1V14ZM6,9a3,3,0,1,1,3,3A3,3,0,0,1,6,9Zm6,17H6V20h6Zm14-3a3,3,0,1,1-3-3A3,3,0,0,1,26,23ZM20,6h6v6H20Z"
  })), children);
});
var ChartNetwork20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartNetwork20(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,14a2,2,0,0,0,2-2V6a2,2,0,0,0-2-2H20a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h2v4.1A5,5,0,0,0,18.1,22H14V20a2,2,0,0,0-2-2H10V13.9a5,5,0,1,0-2,0V18H6a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V24h4.1A5,5,0,1,0,24,18.1V14ZM6,9a3,3,0,1,1,3,3A3,3,0,0,1,6,9Zm6,17H6V20h6Zm14-3a3,3,0,1,1-3-3A3,3,0,0,1,26,23ZM20,6h6v6H20Z"
  })), children);
});
var ChartNetwork16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartNetwork16(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,14a2,2,0,0,0,2-2V6a2,2,0,0,0-2-2H20a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h2v4.1A5,5,0,0,0,18.1,22H14V20a2,2,0,0,0-2-2H10V13.9a5,5,0,1,0-2,0V18H6a2,2,0,0,0-2,2v6a2,2,0,0,0,2,2h6a2,2,0,0,0,2-2V24h4.1A5,5,0,1,0,24,18.1V14ZM6,9a3,3,0,1,1,3,3A3,3,0,0,1,6,9Zm6,17H6V20h6Zm14-3a3,3,0,1,1-3-3A3,3,0,0,1,26,23ZM20,6h6v6H20Z"
  })), children);
});
var ChartParallel32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartParallel32(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2V5.3071l-6,2.25V2H20V7.5229l-8-3.2V2H10V4.4458l-6,3.75V2H2V30H4V27.6182l6-3V30h2V24.3442l8,2.4V30h2V26.5542l6-3.75V30h2V2Zm0,5.4429V12.5L22,17V9.6929ZM20,9.6768v7.5571l-8-4.8V6.4771ZM10,6.8042v5.7417l-6,5.25V10.5542ZM4,25.3818V20.4541l6-5.25v7.1777Zm8-3.1259v-7.49l8,4.8v5.0894Zm10,1.94V19.5L28,15v5.4458Z"
  })), children);
});
var ChartParallel24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartParallel24(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2V5.3071l-6,2.25V2H20V7.5229l-8-3.2V2H10V4.4458l-6,3.75V2H2V30H4V27.6182l6-3V30h2V24.3442l8,2.4V30h2V26.5542l6-3.75V30h2V2Zm0,5.4429V12.5L22,17V9.6929ZM20,9.6768v7.5571l-8-4.8V6.4771ZM10,6.8042v5.7417l-6,5.25V10.5542ZM4,25.3818V20.4541l6-5.25v7.1777Zm8-3.1259v-7.49l8,4.8v5.0894Zm10,1.94V19.5L28,15v5.4458Z"
  })), children);
});
var ChartParallel20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartParallel20(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2V5.3071l-6,2.25V2H20V7.5229l-8-3.2V2H10V4.4458l-6,3.75V2H2V30H4V27.6182l6-3V30h2V24.3442l8,2.4V30h2V26.5542l6-3.75V30h2V2Zm0,5.4429V12.5L22,17V9.6929ZM20,9.6768v7.5571l-8-4.8V6.4771ZM10,6.8042v5.7417l-6,5.25V10.5542ZM4,25.3818V20.4541l6-5.25v7.1777Zm8-3.1259v-7.49l8,4.8v5.0894Zm10,1.94V19.5L28,15v5.4458Z"
  })), children);
});
var ChartParallel16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartParallel16(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2V5.3071l-6,2.25V2H20V7.5229l-8-3.2V2H10V4.4458l-6,3.75V2H2V30H4V27.6182l6-3V30h2V24.3442l8,2.4V30h2V26.5542l6-3.75V30h2V2Zm0,5.4429V12.5L22,17V9.6929ZM20,9.6768v7.5571l-8-4.8V6.4771ZM10,6.8042v5.7417l-6,5.25V10.5542ZM4,25.3818V20.4541l6-5.25v7.1777Zm8-3.1259v-7.49l8,4.8v5.0894Zm10,1.94V19.5L28,15v5.4458Z"
  })), children);
});
var ChartPie32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartPie32(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,0,28,16,12,12,0,0,0,16,4ZM26,15H17V6.05A10,10,0,0,1,26,15ZM15.42,26A10,10,0,0,1,15,6.05v9a2,2,0,0,0,2,2h9A10,10,0,0,1,15.42,26Z"
  })), children);
});
var ChartPie24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartPie24(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,0,28,16,12,12,0,0,0,16,4ZM26,15H17V6.05A10,10,0,0,1,26,15ZM15.42,26A10,10,0,0,1,15,6.05v9a2,2,0,0,0,2,2h9A10,10,0,0,1,15.42,26Z"
  })), children);
});
var ChartPie20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartPie20(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,0,28,16,12,12,0,0,0,16,4ZM26,15H17V6.05A10,10,0,0,1,26,15ZM15.42,26A10,10,0,0,1,15,6.05v9a2,2,0,0,0,2,2h9A10,10,0,0,1,15.42,26Z"
  })), children);
});
var ChartPie16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartPie16(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,0,28,16,12,12,0,0,0,16,4ZM26,15H17V6.05A10,10,0,0,1,26,15ZM15.42,26A10,10,0,0,1,15,6.05v9a2,2,0,0,0,2,2h9A10,10,0,0,1,15.42,26Z"
  })), children);
});
var ChartPoint32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartPoint32(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2.0023,2.0023,0,0,1-2-2V2H4V28H30Z"
  })), _circle21 || (_circle21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "6",
    r: "3"
  })), _circle22 || (_circle22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "22",
    r: "3"
  })), _circle23 || (_circle23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18",
    cy: "14",
    r: "3"
  })), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,17a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,9,17Zm0-4a1,1,0,1,0,1,1A1.001,1.001,0,0,0,9,13Z"
  })), _circle24 || (_circle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "27",
    cy: "6",
    r: "3"
  })), _circle25 || (_circle25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "27",
    cy: "22",
    r: "3"
  })), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 17a3 3 0 113-3A3.0033 3.0033 0 0127 17zm0-4a1 1 0 101 1A1.001 1.001 0 0027 13zM18 26a3 3 0 113-3A3.0033 3.0033 0 0118 26zm0-4a1 1 0 101 1A1.001 1.001 0 0018 22zM18 8a3 3 0 113-3A3.0033 3.0033 0 0118 8zm0-4a1 1 0 101 1A1.001 1.001 0 0018 4z"
  })), children);
});
var ChartPoint24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartPoint24(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2.0023,2.0023,0,0,1-2-2V2H4V28H30Z"
  })), _circle26 || (_circle26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "6",
    r: "3"
  })), _circle27 || (_circle27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "22",
    r: "3"
  })), _circle28 || (_circle28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18",
    cy: "14",
    r: "3"
  })), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,17a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,9,17Zm0-4a1,1,0,1,0,1,1A1.001,1.001,0,0,0,9,13Z"
  })), _circle29 || (_circle29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "27",
    cy: "6",
    r: "3"
  })), _circle30 || (_circle30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "27",
    cy: "22",
    r: "3"
  })), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 17a3 3 0 113-3A3.0033 3.0033 0 0127 17zm0-4a1 1 0 101 1A1.001 1.001 0 0027 13zM18 26a3 3 0 113-3A3.0033 3.0033 0 0118 26zm0-4a1 1 0 101 1A1.001 1.001 0 0018 22zM18 8a3 3 0 113-3A3.0033 3.0033 0 0118 8zm0-4a1 1 0 101 1A1.001 1.001 0 0018 4z"
  })), children);
});
var ChartPoint20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartPoint20(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2.0023,2.0023,0,0,1-2-2V2H4V28H30Z"
  })), _circle31 || (_circle31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "6",
    r: "3"
  })), _circle32 || (_circle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "22",
    r: "3"
  })), _circle33 || (_circle33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18",
    cy: "14",
    r: "3"
  })), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,17a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,9,17Zm0-4a1,1,0,1,0,1,1A1.001,1.001,0,0,0,9,13Z"
  })), _circle34 || (_circle34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "27",
    cy: "6",
    r: "3"
  })), _circle35 || (_circle35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "27",
    cy: "22",
    r: "3"
  })), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 17a3 3 0 113-3A3.0033 3.0033 0 0127 17zm0-4a1 1 0 101 1A1.001 1.001 0 0027 13zM18 26a3 3 0 113-3A3.0033 3.0033 0 0118 26zm0-4a1 1 0 101 1A1.001 1.001 0 0018 22zM18 8a3 3 0 113-3A3.0033 3.0033 0 0118 8zm0-4a1 1 0 101 1A1.001 1.001 0 0018 4z"
  })), children);
});
var ChartPoint16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartPoint16(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2.0023,2.0023,0,0,1-2-2V2H4V28H30Z"
  })), _circle36 || (_circle36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "6",
    r: "3"
  })), _circle37 || (_circle37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "22",
    r: "3"
  })), _circle38 || (_circle38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "18",
    cy: "14",
    r: "3"
  })), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,17a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,9,17Zm0-4a1,1,0,1,0,1,1A1.001,1.001,0,0,0,9,13Z"
  })), _circle39 || (_circle39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "27",
    cy: "6",
    r: "3"
  })), _circle40 || (_circle40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "27",
    cy: "22",
    r: "3"
  })), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27 17a3 3 0 113-3A3.0033 3.0033 0 0127 17zm0-4a1 1 0 101 1A1.001 1.001 0 0027 13zM18 26a3 3 0 113-3A3.0033 3.0033 0 0118 26zm0-4a1 1 0 101 1A1.001 1.001 0 0018 22zM18 8a3 3 0 113-3A3.0033 3.0033 0 0118 8zm0-4a1 1 0 101 1A1.001 1.001 0 0018 4z"
  })), children);
});
var ChartPopulation32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartPopulation32(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,22H17V20h9V14H17V12h5V6H17V2H15V6H10v6h5v2H6v6h9v2H2v6H15v2h2V28H30ZM20,8v2H17V8Zm-8,2V8h3v2Zm12,6v2H17V16ZM8,18V16h7v2ZM4,26V24H15v2Zm24,0H17V24H28Z"
  })), children);
});
var ChartPopulation24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartPopulation24(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,22H17V20h9V14H17V12h5V6H17V2H15V6H10v6h5v2H6v6h9v2H2v6H15v2h2V28H30ZM20,8v2H17V8Zm-8,2V8h3v2Zm12,6v2H17V16ZM8,18V16h7v2ZM4,26V24H15v2Zm24,0H17V24H28Z"
  })), children);
});
var ChartPopulation20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartPopulation20(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,22H17V20h9V14H17V12h5V6H17V2H15V6H10v6h5v2H6v6h9v2H2v6H15v2h2V28H30ZM20,8v2H17V8Zm-8,2V8h3v2Zm12,6v2H17V16ZM8,18V16h7v2ZM4,26V24H15v2Zm24,0H17V24H28Z"
  })), children);
});
var ChartPopulation16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartPopulation16(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,22H17V20h9V14H17V12h5V6H17V2H15V6H10v6h5v2H6v6h9v2H2v6H15v2h2V28H30ZM20,8v2H17V8Zm-8,2V8h3v2Zm12,6v2H17V16ZM8,18V16h7v2ZM4,26V24H15v2Zm24,0H17V24H28Z"
  })), children);
});
var ChartRadar32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRadar32(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2,2,13,8,30H24l6-17Zm2.5818,19.2651-5.9861,1.3306-1.4226-7.8252,4.91-4.209,5.4416,4.0816Zm.1977,2.0054L21.3264,28H10.6736l1.7912-3.3267ZM9.59,13.4937,5.74,12.605,15,5.3291V8.8569ZM17,8.75V5.3291l9.26,7.2759-3.15.727ZM4.6143,14.3979l4.6535,1.0738,1.4844,8.164-1.738,3.2281ZM22.9858,26.8638l-2.5766-4.7852,3.0063-6.7646,3.97-.9161Z"
  })), children);
});
var ChartRadar24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRadar24(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2,2,13,8,30H24l6-17Zm2.5818,19.2651-5.9861,1.3306-1.4226-7.8252,4.91-4.209,5.4416,4.0816Zm.1977,2.0054L21.3264,28H10.6736l1.7912-3.3267ZM9.59,13.4937,5.74,12.605,15,5.3291V8.8569ZM17,8.75V5.3291l9.26,7.2759-3.15.727ZM4.6143,14.3979l4.6535,1.0738,1.4844,8.164-1.738,3.2281ZM22.9858,26.8638l-2.5766-4.7852,3.0063-6.7646,3.97-.9161Z"
  })), children);
});
var ChartRadar20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRadar20(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2,2,13,8,30H24l6-17Zm2.5818,19.2651-5.9861,1.3306-1.4226-7.8252,4.91-4.209,5.4416,4.0816Zm.1977,2.0054L21.3264,28H10.6736l1.7912-3.3267ZM9.59,13.4937,5.74,12.605,15,5.3291V8.8569ZM17,8.75V5.3291l9.26,7.2759-3.15.727ZM4.6143,14.3979l4.6535,1.0738,1.4844,8.164-1.738,3.2281ZM22.9858,26.8638l-2.5766-4.7852,3.0063-6.7646,3.97-.9161Z"
  })), children);
});
var ChartRadar16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRadar16(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2,2,13,8,30H24l6-17Zm2.5818,19.2651-5.9861,1.3306-1.4226-7.8252,4.91-4.209,5.4416,4.0816Zm.1977,2.0054L21.3264,28H10.6736l1.7912-3.3267ZM9.59,13.4937,5.74,12.605,15,5.3291V8.8569ZM17,8.75V5.3291l9.26,7.2759-3.15.727ZM4.6143,14.3979l4.6535,1.0738,1.4844,8.164-1.738,3.2281ZM22.9858,26.8638l-2.5766-4.7852,3.0063-6.7646,3.97-.9161Z"
  })), children);
});
var ChartRadial32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRadial32(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14.0158,14.0158,0,0,1,2,16H4A12,12,0,1,0,16,4V2a14,14,0,0,1,0,28Z"
  })), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,26A10.0115,10.0115,0,0,1,6,16H8a8,8,0,1,0,8-8V6a10,10,0,0,1,0,20Z"
  })), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6.0069,6.0069,0,0,1-6-6h2a4,4,0,1,0,4-4V10a6,6,0,0,1,0,12Z"
  })), children);
});
var ChartRadial24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRadial24(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14.0158,14.0158,0,0,1,2,16H4A12,12,0,1,0,16,4V2a14,14,0,0,1,0,28Z"
  })), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,26A10.0115,10.0115,0,0,1,6,16H8a8,8,0,1,0,8-8V6a10,10,0,0,1,0,20Z"
  })), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6.0069,6.0069,0,0,1-6-6h2a4,4,0,1,0,4-4V10a6,6,0,0,1,0,12Z"
  })), children);
});
var ChartRadial20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRadial20(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14.0158,14.0158,0,0,1,2,16H4A12,12,0,1,0,16,4V2a14,14,0,0,1,0,28Z"
  })), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,26A10.0115,10.0115,0,0,1,6,16H8a8,8,0,1,0,8-8V6a10,10,0,0,1,0,20Z"
  })), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6.0069,6.0069,0,0,1-6-6h2a4,4,0,1,0,4-4V10a6,6,0,0,1,0,12Z"
  })), children);
});
var ChartRadial16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRadial16(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14.0158,14.0158,0,0,1,2,16H4A12,12,0,1,0,16,4V2a14,14,0,0,1,0,28Z"
  })), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,26A10.0115,10.0115,0,0,1,6,16H8a8,8,0,1,0,8-8V6a10,10,0,0,1,0,20Z"
  })), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,22a6.0069,6.0069,0,0,1-6-6h2a4,4,0,1,0,4-4V10a6,6,0,0,1,0,12Z"
  })), children);
});
var ChartRelationship32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRelationship32(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6a3.9963,3.9963,0,0,0-3.8579,3H17.9305A7.9964,7.9964,0,1,0,9,17.9307v4.2114a4,4,0,1,0,2,0V17.9307a7.951,7.951,0,0,0,3.8976-1.6192l3.6693,3.67A3.9529,3.9529,0,0,0,18,22a4,4,0,1,0,4-4,3.9521,3.9521,0,0,0-2.019.5669l-3.6694-3.6694A7.9493,7.9493,0,0,0,17.9305,11h4.2116A3.9934,3.9934,0,1,0,26,6ZM12,26a2,2,0,1,1-2-2A2.0023,2.0023,0,0,1,12,26ZM10,16a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,10,16Zm14,6a2,2,0,1,1-2-2A2.0023,2.0023,0,0,1,24,22Zm2-10a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,26,12Z"
  })), children);
});
var ChartRelationship24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRelationship24(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6a3.9963,3.9963,0,0,0-3.8579,3H17.9305A7.9964,7.9964,0,1,0,9,17.9307v4.2114a4,4,0,1,0,2,0V17.9307a7.951,7.951,0,0,0,3.8976-1.6192l3.6693,3.67A3.9529,3.9529,0,0,0,18,22a4,4,0,1,0,4-4,3.9521,3.9521,0,0,0-2.019.5669l-3.6694-3.6694A7.9493,7.9493,0,0,0,17.9305,11h4.2116A3.9934,3.9934,0,1,0,26,6ZM12,26a2,2,0,1,1-2-2A2.0023,2.0023,0,0,1,12,26ZM10,16a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,10,16Zm14,6a2,2,0,1,1-2-2A2.0023,2.0023,0,0,1,24,22Zm2-10a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,26,12Z"
  })), children);
});
var ChartRelationship20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRelationship20(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6a3.9963,3.9963,0,0,0-3.8579,3H17.9305A7.9964,7.9964,0,1,0,9,17.9307v4.2114a4,4,0,1,0,2,0V17.9307a7.951,7.951,0,0,0,3.8976-1.6192l3.6693,3.67A3.9529,3.9529,0,0,0,18,22a4,4,0,1,0,4-4,3.9521,3.9521,0,0,0-2.019.5669l-3.6694-3.6694A7.9493,7.9493,0,0,0,17.9305,11h4.2116A3.9934,3.9934,0,1,0,26,6ZM12,26a2,2,0,1,1-2-2A2.0023,2.0023,0,0,1,12,26ZM10,16a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,10,16Zm14,6a2,2,0,1,1-2-2A2.0023,2.0023,0,0,1,24,22Zm2-10a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,26,12Z"
  })), children);
});
var ChartRelationship16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRelationship16(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,6a3.9963,3.9963,0,0,0-3.8579,3H17.9305A7.9964,7.9964,0,1,0,9,17.9307v4.2114a4,4,0,1,0,2,0V17.9307a7.951,7.951,0,0,0,3.8976-1.6192l3.6693,3.67A3.9529,3.9529,0,0,0,18,22a4,4,0,1,0,4-4,3.9521,3.9521,0,0,0-2.019.5669l-3.6694-3.6694A7.9493,7.9493,0,0,0,17.9305,11h4.2116A3.9934,3.9934,0,1,0,26,6ZM12,26a2,2,0,1,1-2-2A2.0023,2.0023,0,0,1,12,26ZM10,16a6,6,0,1,1,6-6A6.0066,6.0066,0,0,1,10,16Zm14,6a2,2,0,1,1-2-2A2.0023,2.0023,0,0,1,24,22Zm2-10a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,26,12Z"
  })), children);
});
var ChartRing32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRing32(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM27.9493,15.001H21.91a5.9825,5.9825,0,0,0-9.3806-3.8853l-4.27-4.27a11.9783,11.9783,0,0,1,19.69,8.1548ZM16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20ZM4,16A11.937,11.937,0,0,1,6.8455,8.26l4.27,4.2695A5.9836,5.9836,0,0,0,15,21.9106v6.04A12.0105,12.0105,0,0,1,4,16ZM17,27.95v-6.04A6.0069,6.0069,0,0,0,21.91,17h6.04A12.0082,12.0082,0,0,1,17,27.95Z"
  })), children);
});
var ChartRing24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRing24(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM27.9493,15.001H21.91a5.9825,5.9825,0,0,0-9.3806-3.8853l-4.27-4.27a11.9783,11.9783,0,0,1,19.69,8.1548ZM16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20ZM4,16A11.937,11.937,0,0,1,6.8455,8.26l4.27,4.2695A5.9836,5.9836,0,0,0,15,21.9106v6.04A12.0105,12.0105,0,0,1,4,16ZM17,27.95v-6.04A6.0069,6.0069,0,0,0,21.91,17h6.04A12.0082,12.0082,0,0,1,17,27.95Z"
  })), children);
});
var ChartRing20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRing20(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM27.9493,15.001H21.91a5.9825,5.9825,0,0,0-9.3806-3.8853l-4.27-4.27a11.9783,11.9783,0,0,1,19.69,8.1548ZM16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20ZM4,16A11.937,11.937,0,0,1,6.8455,8.26l4.27,4.2695A5.9836,5.9836,0,0,0,15,21.9106v6.04A12.0105,12.0105,0,0,1,4,16ZM17,27.95v-6.04A6.0069,6.0069,0,0,0,21.91,17h6.04A12.0082,12.0082,0,0,1,17,27.95Z"
  })), children);
});
var ChartRing16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRing16(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14.0158,14.0158,0,0,0,16,2ZM27.9493,15.001H21.91a5.9825,5.9825,0,0,0-9.3806-3.8853l-4.27-4.27a11.9783,11.9783,0,0,1,19.69,8.1548ZM16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20ZM4,16A11.937,11.937,0,0,1,6.8455,8.26l4.27,4.2695A5.9836,5.9836,0,0,0,15,21.9106v6.04A12.0105,12.0105,0,0,1,4,16ZM17,27.95v-6.04A6.0069,6.0069,0,0,0,21.91,17h6.04A12.0082,12.0082,0,0,1,17,27.95Z"
  })), children);
});
var ChartRiver32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRiver32(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.4326,20.0171l8.0376,4.68a1.958,1.958,0,0,0,1.0508.3012,2.2412,2.2412,0,0,0,.4888-.0556l7.2532-1.9769A1,1,0,0,0,30,22.0007V7.996A1,1,0,0,0,28.74,7.0305L21.5034,8.9829l-8.0371-4.68a1.9917,1.9917,0,0,0-1.8652-.1352L4,7.4727V2H2V28a2,2,0,0,0,2,2H30V28H4V23.6577ZM28,21.2344l-6.4966,1.75-8.0371-4.68a1.9931,1.9931,0,0,0-1.8652-.1353L4,21.4746V16.6572l8.4326-3.6416L20.47,17.6968a1.962,1.962,0,0,0,1.0508.3008,2.2112,2.2112,0,0,0,.4888-.0557L28,16.31ZM12.4326,6.0156l8.0376,4.68a2.0091,2.0091,0,0,0,1.54.2451L28,9.3081v4.9258l-6.4966,1.7505-8.0371-4.6812a1.9917,1.9917,0,0,0-1.8652-.1352L4,14.4736V9.6562Z"
  })), children);
});
var ChartRiver24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRiver24(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.4326,20.0171l8.0376,4.68a1.958,1.958,0,0,0,1.0508.3012,2.2412,2.2412,0,0,0,.4888-.0556l7.2532-1.9769A1,1,0,0,0,30,22.0007V7.996A1,1,0,0,0,28.74,7.0305L21.5034,8.9829l-8.0371-4.68a1.9917,1.9917,0,0,0-1.8652-.1352L4,7.4727V2H2V28a2,2,0,0,0,2,2H30V28H4V23.6577ZM28,21.2344l-6.4966,1.75-8.0371-4.68a1.9931,1.9931,0,0,0-1.8652-.1353L4,21.4746V16.6572l8.4326-3.6416L20.47,17.6968a1.962,1.962,0,0,0,1.0508.3008,2.2112,2.2112,0,0,0,.4888-.0557L28,16.31ZM12.4326,6.0156l8.0376,4.68a2.0091,2.0091,0,0,0,1.54.2451L28,9.3081v4.9258l-6.4966,1.7505-8.0371-4.6812a1.9917,1.9917,0,0,0-1.8652-.1352L4,14.4736V9.6562Z"
  })), children);
});
var ChartRiver20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRiver20(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.4326,20.0171l8.0376,4.68a1.958,1.958,0,0,0,1.0508.3012,2.2412,2.2412,0,0,0,.4888-.0556l7.2532-1.9769A1,1,0,0,0,30,22.0007V7.996A1,1,0,0,0,28.74,7.0305L21.5034,8.9829l-8.0371-4.68a1.9917,1.9917,0,0,0-1.8652-.1352L4,7.4727V2H2V28a2,2,0,0,0,2,2H30V28H4V23.6577ZM28,21.2344l-6.4966,1.75-8.0371-4.68a1.9931,1.9931,0,0,0-1.8652-.1353L4,21.4746V16.6572l8.4326-3.6416L20.47,17.6968a1.962,1.962,0,0,0,1.0508.3008,2.2112,2.2112,0,0,0,.4888-.0557L28,16.31ZM12.4326,6.0156l8.0376,4.68a2.0091,2.0091,0,0,0,1.54.2451L28,9.3081v4.9258l-6.4966,1.7505-8.0371-4.6812a1.9917,1.9917,0,0,0-1.8652-.1352L4,14.4736V9.6562Z"
  })), children);
});
var ChartRiver16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRiver16(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.4326,20.0171l8.0376,4.68a1.958,1.958,0,0,0,1.0508.3012,2.2412,2.2412,0,0,0,.4888-.0556l7.2532-1.9769A1,1,0,0,0,30,22.0007V7.996A1,1,0,0,0,28.74,7.0305L21.5034,8.9829l-8.0371-4.68a1.9917,1.9917,0,0,0-1.8652-.1352L4,7.4727V2H2V28a2,2,0,0,0,2,2H30V28H4V23.6577ZM28,21.2344l-6.4966,1.75-8.0371-4.68a1.9931,1.9931,0,0,0-1.8652-.1353L4,21.4746V16.6572l8.4326-3.6416L20.47,17.6968a1.962,1.962,0,0,0,1.0508.3008,2.2112,2.2112,0,0,0,.4888-.0557L28,16.31ZM12.4326,6.0156l8.0376,4.68a2.0091,2.0091,0,0,0,1.54.2451L28,9.3081v4.9258l-6.4966,1.7505-8.0371-4.6812a1.9917,1.9917,0,0,0-1.8652-.1352L4,14.4736V9.6562Z"
  })), children);
});
var ChartRose32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRose32(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,17A15.017,15.017,0,0,0,15,2H14V8.0591A9.0122,9.0122,0,0,0,6.0591,16H4v1A11.0109,11.0109,0,0,0,14,27.9492V30h1A13.0084,13.0084,0,0,0,27.9492,18H30ZM16,4.0381A13.0217,13.0217,0,0,1,27.9619,16H16ZM14,10.08V16H8.08A7.0037,7.0037,0,0,1,14,10.08ZM6.0552,18H14v7.939A9.0134,9.0134,0,0,1,6.0552,18ZM16,27.9551V18h9.9551A11.0191,11.0191,0,0,1,16,27.9551Z"
  })), children);
});
var ChartRose24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRose24(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,17A15.017,15.017,0,0,0,15,2H14V8.0591A9.0122,9.0122,0,0,0,6.0591,16H4v1A11.0109,11.0109,0,0,0,14,27.9492V30h1A13.0084,13.0084,0,0,0,27.9492,18H30ZM16,4.0381A13.0217,13.0217,0,0,1,27.9619,16H16ZM14,10.08V16H8.08A7.0037,7.0037,0,0,1,14,10.08ZM6.0552,18H14v7.939A9.0134,9.0134,0,0,1,6.0552,18ZM16,27.9551V18h9.9551A11.0191,11.0191,0,0,1,16,27.9551Z"
  })), children);
});
var ChartRose20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRose20(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,17A15.017,15.017,0,0,0,15,2H14V8.0591A9.0122,9.0122,0,0,0,6.0591,16H4v1A11.0109,11.0109,0,0,0,14,27.9492V30h1A13.0084,13.0084,0,0,0,27.9492,18H30ZM16,4.0381A13.0217,13.0217,0,0,1,27.9619,16H16ZM14,10.08V16H8.08A7.0037,7.0037,0,0,1,14,10.08ZM6.0552,18H14v7.939A9.0134,9.0134,0,0,1,6.0552,18ZM16,27.9551V18h9.9551A11.0191,11.0191,0,0,1,16,27.9551Z"
  })), children);
});
var ChartRose16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartRose16(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,17A15.017,15.017,0,0,0,15,2H14V8.0591A9.0122,9.0122,0,0,0,6.0591,16H4v1A11.0109,11.0109,0,0,0,14,27.9492V30h1A13.0084,13.0084,0,0,0,27.9492,18H30ZM16,4.0381A13.0217,13.0217,0,0,1,27.9619,16H16ZM14,10.08V16H8.08A7.0037,7.0037,0,0,1,14,10.08ZM6.0552,18H14v7.939A9.0134,9.0134,0,0,1,6.0552,18ZM16,27.9551V18h9.9551A11.0191,11.0191,0,0,1,16,27.9551Z"
  })), children);
});
var ChartScatter32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartScatter32(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), _circle41 || (_circle41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "22",
    r: "2"
  })), _circle42 || (_circle42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "15",
    r: "2"
  })), _circle43 || (_circle43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "15",
    r: "2"
  })), _circle44 || (_circle44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "6",
    r: "2"
  })), _circle45 || (_circle45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "8",
    r: "2"
  })), children);
});
var ChartScatter24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartScatter24(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), _circle46 || (_circle46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "22",
    r: "2"
  })), _circle47 || (_circle47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "15",
    r: "2"
  })), _circle48 || (_circle48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "15",
    r: "2"
  })), _circle49 || (_circle49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "6",
    r: "2"
  })), _circle50 || (_circle50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "8",
    r: "2"
  })), children);
});
var ChartScatter20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartScatter20(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), _circle51 || (_circle51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "22",
    r: "2"
  })), _circle52 || (_circle52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "15",
    r: "2"
  })), _circle53 || (_circle53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "15",
    r: "2"
  })), _circle54 || (_circle54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "6",
    r: "2"
  })), _circle55 || (_circle55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "8",
    r: "2"
  })), children);
});
var ChartScatter16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartScatter16(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), _circle56 || (_circle56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "22",
    r: "2"
  })), _circle57 || (_circle57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "15",
    r: "2"
  })), _circle58 || (_circle58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "15",
    r: "2"
  })), _circle59 || (_circle59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "6",
    r: "2"
  })), _circle60 || (_circle60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "8",
    r: "2"
  })), children);
});
var ChartSpiral32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartSpiral32(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.919,13.919,0,0,0,7.3245,5.0327,1.9728,1.9728,0,0,0,7,5,2,2,0,0,0,5,7a1.9752,1.9752,0,0,0,.0327.3247A13.986,13.986,0,1,0,16,2Zm0,26A11.977,11.977,0,0,1,6.3589,8.8857a1.8311,1.8311,0,0,0,1.1528.04l1.4634,1.4634a8.9862,8.9862,0,0,0,11.8311,13.207,1.9916,1.9916,0,0,0,2.79-2.79,8.9294,8.9294,0,0,0,0-9.6124,1.9916,1.9916,0,0,0-2.79-2.79,8.9445,8.9445,0,0,0-10.417.5713L8.9258,7.5117a1.8294,1.8294,0,0,0-.04-1.1528A11.9925,11.9925,0,1,1,16,28Zm0-14a2,2,0,1,1-2,2A2.0025,2.0025,0,0,1,16,14Zm3.4331-.019,2.0552-2.0552a2.0443,2.0443,0,0,0,.2265.0454,6.9573,6.9573,0,0,1,0,8.0576,2.0443,2.0443,0,0,0-.2265.0454L19.4331,18.019a3.8788,3.8788,0,0,0,0-4.038Zm.5957-3.6958a1.9993,1.9993,0,0,0,.0454.2265L18.019,12.5669a3.8788,3.8788,0,0,0-4.038,0l-2.1653-2.1655a6.9522,6.9522,0,0,1,8.2131-.1162ZM12.5669,13.981A3.951,3.951,0,0,0,12,16a4.0045,4.0045,0,0,0,4,4,3.9521,3.9521,0,0,0,2.019-.5669l2.0552,2.0552a1.9993,1.9993,0,0,0-.0454.2265,6.988,6.988,0,0,1-9.6272-9.8994Z"
  })), children);
});
var ChartSpiral24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartSpiral24(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.919,13.919,0,0,0,7.3245,5.0327,1.9728,1.9728,0,0,0,7,5,2,2,0,0,0,5,7a1.9752,1.9752,0,0,0,.0327.3247A13.986,13.986,0,1,0,16,2Zm0,26A11.977,11.977,0,0,1,6.3589,8.8857a1.8311,1.8311,0,0,0,1.1528.04l1.4634,1.4634a8.9862,8.9862,0,0,0,11.8311,13.207,1.9916,1.9916,0,0,0,2.79-2.79,8.9294,8.9294,0,0,0,0-9.6124,1.9916,1.9916,0,0,0-2.79-2.79,8.9445,8.9445,0,0,0-10.417.5713L8.9258,7.5117a1.8294,1.8294,0,0,0-.04-1.1528A11.9925,11.9925,0,1,1,16,28Zm0-14a2,2,0,1,1-2,2A2.0025,2.0025,0,0,1,16,14Zm3.4331-.019,2.0552-2.0552a2.0443,2.0443,0,0,0,.2265.0454,6.9573,6.9573,0,0,1,0,8.0576,2.0443,2.0443,0,0,0-.2265.0454L19.4331,18.019a3.8788,3.8788,0,0,0,0-4.038Zm.5957-3.6958a1.9993,1.9993,0,0,0,.0454.2265L18.019,12.5669a3.8788,3.8788,0,0,0-4.038,0l-2.1653-2.1655a6.9522,6.9522,0,0,1,8.2131-.1162ZM12.5669,13.981A3.951,3.951,0,0,0,12,16a4.0045,4.0045,0,0,0,4,4,3.9521,3.9521,0,0,0,2.019-.5669l2.0552,2.0552a1.9993,1.9993,0,0,0-.0454.2265,6.988,6.988,0,0,1-9.6272-9.8994Z"
  })), children);
});
var ChartSpiral20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartSpiral20(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.919,13.919,0,0,0,7.3245,5.0327,1.9728,1.9728,0,0,0,7,5,2,2,0,0,0,5,7a1.9752,1.9752,0,0,0,.0327.3247A13.986,13.986,0,1,0,16,2Zm0,26A11.977,11.977,0,0,1,6.3589,8.8857a1.8311,1.8311,0,0,0,1.1528.04l1.4634,1.4634a8.9862,8.9862,0,0,0,11.8311,13.207,1.9916,1.9916,0,0,0,2.79-2.79,8.9294,8.9294,0,0,0,0-9.6124,1.9916,1.9916,0,0,0-2.79-2.79,8.9445,8.9445,0,0,0-10.417.5713L8.9258,7.5117a1.8294,1.8294,0,0,0-.04-1.1528A11.9925,11.9925,0,1,1,16,28Zm0-14a2,2,0,1,1-2,2A2.0025,2.0025,0,0,1,16,14Zm3.4331-.019,2.0552-2.0552a2.0443,2.0443,0,0,0,.2265.0454,6.9573,6.9573,0,0,1,0,8.0576,2.0443,2.0443,0,0,0-.2265.0454L19.4331,18.019a3.8788,3.8788,0,0,0,0-4.038Zm.5957-3.6958a1.9993,1.9993,0,0,0,.0454.2265L18.019,12.5669a3.8788,3.8788,0,0,0-4.038,0l-2.1653-2.1655a6.9522,6.9522,0,0,1,8.2131-.1162ZM12.5669,13.981A3.951,3.951,0,0,0,12,16a4.0045,4.0045,0,0,0,4,4,3.9521,3.9521,0,0,0,2.019-.5669l2.0552,2.0552a1.9993,1.9993,0,0,0-.0454.2265,6.988,6.988,0,0,1-9.6272-9.8994Z"
  })), children);
});
var ChartSpiral16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartSpiral16(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A13.919,13.919,0,0,0,7.3245,5.0327,1.9728,1.9728,0,0,0,7,5,2,2,0,0,0,5,7a1.9752,1.9752,0,0,0,.0327.3247A13.986,13.986,0,1,0,16,2Zm0,26A11.977,11.977,0,0,1,6.3589,8.8857a1.8311,1.8311,0,0,0,1.1528.04l1.4634,1.4634a8.9862,8.9862,0,0,0,11.8311,13.207,1.9916,1.9916,0,0,0,2.79-2.79,8.9294,8.9294,0,0,0,0-9.6124,1.9916,1.9916,0,0,0-2.79-2.79,8.9445,8.9445,0,0,0-10.417.5713L8.9258,7.5117a1.8294,1.8294,0,0,0-.04-1.1528A11.9925,11.9925,0,1,1,16,28Zm0-14a2,2,0,1,1-2,2A2.0025,2.0025,0,0,1,16,14Zm3.4331-.019,2.0552-2.0552a2.0443,2.0443,0,0,0,.2265.0454,6.9573,6.9573,0,0,1,0,8.0576,2.0443,2.0443,0,0,0-.2265.0454L19.4331,18.019a3.8788,3.8788,0,0,0,0-4.038Zm.5957-3.6958a1.9993,1.9993,0,0,0,.0454.2265L18.019,12.5669a3.8788,3.8788,0,0,0-4.038,0l-2.1653-2.1655a6.9522,6.9522,0,0,1,8.2131-.1162ZM12.5669,13.981A3.951,3.951,0,0,0,12,16a4.0045,4.0045,0,0,0,4,4,3.9521,3.9521,0,0,0,2.019-.5669l2.0552,2.0552a1.9993,1.9993,0,0,0-.0454.2265,6.988,6.988,0,0,1-9.6272-9.8994Z"
  })), children);
});
var ChartStacked32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartStacked32(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,28V6H20V28H16V14H8V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM22,8h4V18H22ZM10,16h4v6H10Z"
  })), children);
});
var ChartStacked24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartStacked24(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,28V6H20V28H16V14H8V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM22,8h4V18H22ZM10,16h4v6H10Z"
  })), children);
});
var ChartStacked20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartStacked20(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,28V6H20V28H16V14H8V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM22,8h4V18H22ZM10,16h4v6H10Z"
  })), children);
});
var ChartStacked16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartStacked16(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,28V6H20V28H16V14H8V28H4V2H2V28a2,2,0,0,0,2,2H30V28ZM22,8h4V18H22ZM10,16h4v6H10Z"
  })), children);
});
var ChartStepper32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartStepper32(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,22V14h8V6h8V4H20v8H12v8H4V2H2V28a2.0025,2.0025,0,0,0,2,2H30V28H4V22Z"
  })), children);
});
var ChartStepper24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartStepper24(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,22V14h8V6h8V4H20v8H12v8H4V2H2V28a2.0025,2.0025,0,0,0,2,2H30V28H4V22Z"
  })), children);
});
var ChartStepper20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartStepper20(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,22V14h8V6h8V4H20v8H12v8H4V2H2V28a2.0025,2.0025,0,0,0,2,2H30V28H4V22Z"
  })), children);
});
var ChartStepper16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartStepper16(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,22V14h8V6h8V4H20v8H12v8H4V2H2V28a2.0025,2.0025,0,0,0,2,2H30V28H4V22Z"
  })), children);
});
var ChartSunburst32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartSunburst32(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2a1,1,0,0,0-1,1v7.09a5.9618,5.9618,0,0,0-2.46,1.043L7.8384,6.4311a1.4554,1.4554,0,0,0-2.087.0244A14.05,14.05,0,0,0,9.8047,28.5972a10.8482,10.8482,0,0,0,1.8989.7676,14.0982,14.0982,0,0,0,13.8443-3.1319,1.4336,1.4336,0,0,0,.0278-2.0639L20.877,19.47A5.963,5.963,0,0,0,21.91,17H29a1,1,0,0,0,1-1A14.0158,14.0158,0,0,0,16,2Zm0,10a4,4,0,1,1-4,4A4.0045,4.0045,0,0,1,16,12ZM6.83,8.251l4.2959,4.2959a5.91,5.91,0,0,0-.0113,6.9243L6.8381,23.7481A12.0168,12.0168,0,0,1,6.83,8.251Zm1.4228,16.91,4.2759-4.2759A5.9589,5.9589,0,0,0,15,21.91v6.042A11.8783,11.8783,0,0,1,8.2529,25.1612ZM17,27.9561V21.9092a5.9631,5.9631,0,0,0,2.4609-1.0273l4.2818,4.2817A11.8905,11.8905,0,0,1,17,27.9561ZM21.91,15A6.0063,6.0063,0,0,0,17,10.09V4.041A12.0208,12.0208,0,0,1,27.9585,15Z"
  })), children);
});
var ChartSunburst24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartSunburst24(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2a1,1,0,0,0-1,1v7.09a5.9618,5.9618,0,0,0-2.46,1.043L7.8384,6.4311a1.4554,1.4554,0,0,0-2.087.0244A14.05,14.05,0,0,0,9.8047,28.5972a10.8482,10.8482,0,0,0,1.8989.7676,14.0982,14.0982,0,0,0,13.8443-3.1319,1.4336,1.4336,0,0,0,.0278-2.0639L20.877,19.47A5.963,5.963,0,0,0,21.91,17H29a1,1,0,0,0,1-1A14.0158,14.0158,0,0,0,16,2Zm0,10a4,4,0,1,1-4,4A4.0045,4.0045,0,0,1,16,12ZM6.83,8.251l4.2959,4.2959a5.91,5.91,0,0,0-.0113,6.9243L6.8381,23.7481A12.0168,12.0168,0,0,1,6.83,8.251Zm1.4228,16.91,4.2759-4.2759A5.9589,5.9589,0,0,0,15,21.91v6.042A11.8783,11.8783,0,0,1,8.2529,25.1612ZM17,27.9561V21.9092a5.9631,5.9631,0,0,0,2.4609-1.0273l4.2818,4.2817A11.8905,11.8905,0,0,1,17,27.9561ZM21.91,15A6.0063,6.0063,0,0,0,17,10.09V4.041A12.0208,12.0208,0,0,1,27.9585,15Z"
  })), children);
});
var ChartSunburst20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartSunburst20(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2a1,1,0,0,0-1,1v7.09a5.9618,5.9618,0,0,0-2.46,1.043L7.8384,6.4311a1.4554,1.4554,0,0,0-2.087.0244A14.05,14.05,0,0,0,9.8047,28.5972a10.8482,10.8482,0,0,0,1.8989.7676,14.0982,14.0982,0,0,0,13.8443-3.1319,1.4336,1.4336,0,0,0,.0278-2.0639L20.877,19.47A5.963,5.963,0,0,0,21.91,17H29a1,1,0,0,0,1-1A14.0158,14.0158,0,0,0,16,2Zm0,10a4,4,0,1,1-4,4A4.0045,4.0045,0,0,1,16,12ZM6.83,8.251l4.2959,4.2959a5.91,5.91,0,0,0-.0113,6.9243L6.8381,23.7481A12.0168,12.0168,0,0,1,6.83,8.251Zm1.4228,16.91,4.2759-4.2759A5.9589,5.9589,0,0,0,15,21.91v6.042A11.8783,11.8783,0,0,1,8.2529,25.1612ZM17,27.9561V21.9092a5.9631,5.9631,0,0,0,2.4609-1.0273l4.2818,4.2817A11.8905,11.8905,0,0,1,17,27.9561ZM21.91,15A6.0063,6.0063,0,0,0,17,10.09V4.041A12.0208,12.0208,0,0,1,27.9585,15Z"
  })), children);
});
var ChartSunburst16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartSunburst16(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2a1,1,0,0,0-1,1v7.09a5.9618,5.9618,0,0,0-2.46,1.043L7.8384,6.4311a1.4554,1.4554,0,0,0-2.087.0244A14.05,14.05,0,0,0,9.8047,28.5972a10.8482,10.8482,0,0,0,1.8989.7676,14.0982,14.0982,0,0,0,13.8443-3.1319,1.4336,1.4336,0,0,0,.0278-2.0639L20.877,19.47A5.963,5.963,0,0,0,21.91,17H29a1,1,0,0,0,1-1A14.0158,14.0158,0,0,0,16,2Zm0,10a4,4,0,1,1-4,4A4.0045,4.0045,0,0,1,16,12ZM6.83,8.251l4.2959,4.2959a5.91,5.91,0,0,0-.0113,6.9243L6.8381,23.7481A12.0168,12.0168,0,0,1,6.83,8.251Zm1.4228,16.91,4.2759-4.2759A5.9589,5.9589,0,0,0,15,21.91v6.042A11.8783,11.8783,0,0,1,8.2529,25.1612ZM17,27.9561V21.9092a5.9631,5.9631,0,0,0,2.4609-1.0273l4.2818,4.2817A11.8905,11.8905,0,0,1,17,27.9561ZM21.91,15A6.0063,6.0063,0,0,0,17,10.09V4.041A12.0208,12.0208,0,0,1,27.9585,15Z"
  })), children);
});
var ChartTSne32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartTSne32(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle61 || (_circle61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "20",
    r: "2"
  })), _circle62 || (_circle62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle63 || (_circle63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "14",
    r: "2"
  })), _circle64 || (_circle64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "4",
    r: "2"
  })), _circle65 || (_circle65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "6",
    r: "2"
  })), _circle66 || (_circle66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "10",
    r: "2"
  })), _circle67 || (_circle67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20",
    cy: "12",
    r: "2"
  })), _circle68 || (_circle68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "22",
    r: "2"
  })), _circle69 || (_circle69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "28",
    r: "2"
  })), _circle70 || (_circle70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20",
    cy: "26",
    r: "2"
  })), _circle71 || (_circle71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "20",
    r: "2"
  })), _circle72 || (_circle72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "4",
    r: "2"
  })), _circle73 || (_circle73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4",
    cy: "24",
    r: "2"
  })), _circle74 || (_circle74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4",
    cy: "16",
    r: "2"
  })), children);
});
var ChartTSne24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartTSne24(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle75 || (_circle75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "20",
    r: "2"
  })), _circle76 || (_circle76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle77 || (_circle77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "14",
    r: "2"
  })), _circle78 || (_circle78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "4",
    r: "2"
  })), _circle79 || (_circle79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "6",
    r: "2"
  })), _circle80 || (_circle80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "10",
    r: "2"
  })), _circle81 || (_circle81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20",
    cy: "12",
    r: "2"
  })), _circle82 || (_circle82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "22",
    r: "2"
  })), _circle83 || (_circle83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "28",
    r: "2"
  })), _circle84 || (_circle84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20",
    cy: "26",
    r: "2"
  })), _circle85 || (_circle85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "20",
    r: "2"
  })), _circle86 || (_circle86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "4",
    r: "2"
  })), _circle87 || (_circle87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4",
    cy: "24",
    r: "2"
  })), _circle88 || (_circle88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4",
    cy: "16",
    r: "2"
  })), children);
});
var ChartTSne20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartTSne20(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle89 || (_circle89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "20",
    r: "2"
  })), _circle90 || (_circle90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle91 || (_circle91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "14",
    r: "2"
  })), _circle92 || (_circle92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "4",
    r: "2"
  })), _circle93 || (_circle93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "6",
    r: "2"
  })), _circle94 || (_circle94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "10",
    r: "2"
  })), _circle95 || (_circle95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20",
    cy: "12",
    r: "2"
  })), _circle96 || (_circle96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "22",
    r: "2"
  })), _circle97 || (_circle97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "28",
    r: "2"
  })), _circle98 || (_circle98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20",
    cy: "26",
    r: "2"
  })), _circle99 || (_circle99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "20",
    r: "2"
  })), _circle100 || (_circle100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "4",
    r: "2"
  })), _circle101 || (_circle101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4",
    cy: "24",
    r: "2"
  })), _circle102 || (_circle102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4",
    cy: "16",
    r: "2"
  })), children);
});
var ChartTSne16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartTSne16(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle103 || (_circle103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "20",
    r: "2"
  })), _circle104 || (_circle104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "28",
    r: "2"
  })), _circle105 || (_circle105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "14",
    r: "2"
  })), _circle106 || (_circle106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "4",
    r: "2"
  })), _circle107 || (_circle107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "6",
    r: "2"
  })), _circle108 || (_circle108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "10",
    r: "2"
  })), _circle109 || (_circle109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20",
    cy: "12",
    r: "2"
  })), _circle110 || (_circle110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "22",
    r: "2"
  })), _circle111 || (_circle111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "26",
    cy: "28",
    r: "2"
  })), _circle112 || (_circle112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20",
    cy: "26",
    r: "2"
  })), _circle113 || (_circle113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "20",
    r: "2"
  })), _circle114 || (_circle114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "4",
    r: "2"
  })), _circle115 || (_circle115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4",
    cy: "24",
    r: "2"
  })), _circle116 || (_circle116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "4",
    cy: "16",
    r: "2"
  })), children);
});
var ChartTreemap32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartTreemap32(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2.0023,2.0023,0,0,0,2,4V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2Zm0,12H23V4h5ZM16,4h5V14H16ZM14,4V20H4V4ZM4,22H14v6H4Zm12,6V16H28V28Z"
  })), children);
});
var ChartTreemap24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartTreemap24(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2.0023,2.0023,0,0,0,2,4V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2Zm0,12H23V4h5ZM16,4h5V14H16ZM14,4V20H4V4ZM4,22H14v6H4Zm12,6V16H28V28Z"
  })), children);
});
var ChartTreemap20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartTreemap20(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2.0023,2.0023,0,0,0,2,4V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2Zm0,12H23V4h5ZM16,4h5V14H16ZM14,4V20H4V4ZM4,22H14v6H4Zm12,6V16H28V28Z"
  })), children);
});
var ChartTreemap16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartTreemap16(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2.0023,2.0023,0,0,0,2,4V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2Zm0,12H23V4h5ZM16,4h5V14H16ZM14,4V20H4V4ZM4,22H14v6H4Zm12,6V16H28V28Z"
  })), children);
});
var ChartVennDiagram32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartVennDiagram32(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.92,9.92,0,0,0-4,.84A9.92,9.92,0,0,0,12,6a10,10,0,0,0,0,20,9.92,9.92,0,0,0,4-.84A9.92,9.92,0,0,0,20,26,10,10,0,0,0,20,6ZM12,24A8,8,0,0,1,12,8a7.91,7.91,0,0,1,1.76.2,10,10,0,0,0,0,15.6A7.91,7.91,0,0,1,12,24Zm8-8a8,8,0,0,1-4,6.92A8,8,0,0,1,16,9.08,8,8,0,0,1,20,16Zm0,8a7.91,7.91,0,0,1-1.76-.2,10,10,0,0,0,0-15.6A7.91,7.91,0,0,1,20,8a8,8,0,0,1,0,16Z"
  })), children);
});
var ChartVennDiagram24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartVennDiagram24(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.92,9.92,0,0,0-4,.84A9.92,9.92,0,0,0,12,6a10,10,0,0,0,0,20,9.92,9.92,0,0,0,4-.84A9.92,9.92,0,0,0,20,26,10,10,0,0,0,20,6ZM12,24A8,8,0,0,1,12,8a7.91,7.91,0,0,1,1.76.2,10,10,0,0,0,0,15.6A7.91,7.91,0,0,1,12,24Zm8-8a8,8,0,0,1-4,6.92A8,8,0,0,1,16,9.08,8,8,0,0,1,20,16Zm0,8a7.91,7.91,0,0,1-1.76-.2,10,10,0,0,0,0-15.6A7.91,7.91,0,0,1,20,8a8,8,0,0,1,0,16Z"
  })), children);
});
var ChartVennDiagram20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartVennDiagram20(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.92,9.92,0,0,0-4,.84A9.92,9.92,0,0,0,12,6a10,10,0,0,0,0,20,9.92,9.92,0,0,0,4-.84A9.92,9.92,0,0,0,20,26,10,10,0,0,0,20,6ZM12,24A8,8,0,0,1,12,8a7.91,7.91,0,0,1,1.76.2,10,10,0,0,0,0,15.6A7.91,7.91,0,0,1,12,24Zm8-8a8,8,0,0,1-4,6.92A8,8,0,0,1,16,9.08,8,8,0,0,1,20,16Zm0,8a7.91,7.91,0,0,1-1.76-.2,10,10,0,0,0,0-15.6A7.91,7.91,0,0,1,20,8a8,8,0,0,1,0,16Z"
  })), children);
});
var ChartVennDiagram16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartVennDiagram16(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,6a9.92,9.92,0,0,0-4,.84A9.92,9.92,0,0,0,12,6a10,10,0,0,0,0,20,9.92,9.92,0,0,0,4-.84A9.92,9.92,0,0,0,20,26,10,10,0,0,0,20,6ZM12,24A8,8,0,0,1,12,8a7.91,7.91,0,0,1,1.76.2,10,10,0,0,0,0,15.6A7.91,7.91,0,0,1,12,24Zm8-8a8,8,0,0,1-4,6.92A8,8,0,0,1,16,9.08,8,8,0,0,1,20,16Zm0,8a7.91,7.91,0,0,1-1.76-.2,10,10,0,0,0,0-15.6A7.91,7.91,0,0,1,20,8a8,8,0,0,1,0,16Z"
  })), children);
});
var ChartViolinPlot32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartViolinPlot32(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.86 7.8232L13 4.7231V2H11V4.7231l-1.86 3.1A7.9986 7.9986 0 008 11.939v.122a7.9961 7.9961 0 001.14 4.1158l1.86 3.1V26h2V19.2769l1.86-3.1A7.9986 7.9986 0 0016 12.061v-.122A7.9961 7.9961 0 0014.86 7.8232zM12 6.9434l1.145 1.9087A6.0027 6.0027 0 0113.9185 11h-3.837a6.0086 6.0086 0 01.7735-2.1484zm0 10.1132l-1.145-1.9087A6.0027 6.0027 0 0110.0815 13h3.837a6.0086 6.0086 0 01-.7735 2.1484zM27.86 11.8232L26 8.7231V2H24V8.7231l-1.86 3.1A7.9986 7.9986 0 0021 15.939v.122a7.9961 7.9961 0 001.14 4.1158l1.86 3.1V26h2V23.2769l1.86-3.1A7.9986 7.9986 0 0029 16.061v-.122A7.9961 7.9961 0 0027.86 11.8232zm-2.86-.88l1.145 1.9087A6.0027 6.0027 0 0126.9185 15h-3.837a6.0086 6.0086 0 01.7735-2.1484zm0 10.1132l-1.145-1.9087A6.0027 6.0027 0 0123.0815 17h3.837a6.0086 6.0086 0 01-.7735 2.1484z"
  })), children);
});
var ChartViolinPlot24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartViolinPlot24(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.86 7.8232L13 4.7231V2H11V4.7231l-1.86 3.1A7.9986 7.9986 0 008 11.939v.122a7.9961 7.9961 0 001.14 4.1158l1.86 3.1V26h2V19.2769l1.86-3.1A7.9986 7.9986 0 0016 12.061v-.122A7.9961 7.9961 0 0014.86 7.8232zM12 6.9434l1.145 1.9087A6.0027 6.0027 0 0113.9185 11h-3.837a6.0086 6.0086 0 01.7735-2.1484zm0 10.1132l-1.145-1.9087A6.0027 6.0027 0 0110.0815 13h3.837a6.0086 6.0086 0 01-.7735 2.1484zM27.86 11.8232L26 8.7231V2H24V8.7231l-1.86 3.1A7.9986 7.9986 0 0021 15.939v.122a7.9961 7.9961 0 001.14 4.1158l1.86 3.1V26h2V23.2769l1.86-3.1A7.9986 7.9986 0 0029 16.061v-.122A7.9961 7.9961 0 0027.86 11.8232zm-2.86-.88l1.145 1.9087A6.0027 6.0027 0 0126.9185 15h-3.837a6.0086 6.0086 0 01.7735-2.1484zm0 10.1132l-1.145-1.9087A6.0027 6.0027 0 0123.0815 17h3.837a6.0086 6.0086 0 01-.7735 2.1484z"
  })), children);
});
var ChartViolinPlot20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartViolinPlot20(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.86 7.8232L13 4.7231V2H11V4.7231l-1.86 3.1A7.9986 7.9986 0 008 11.939v.122a7.9961 7.9961 0 001.14 4.1158l1.86 3.1V26h2V19.2769l1.86-3.1A7.9986 7.9986 0 0016 12.061v-.122A7.9961 7.9961 0 0014.86 7.8232zM12 6.9434l1.145 1.9087A6.0027 6.0027 0 0113.9185 11h-3.837a6.0086 6.0086 0 01.7735-2.1484zm0 10.1132l-1.145-1.9087A6.0027 6.0027 0 0110.0815 13h3.837a6.0086 6.0086 0 01-.7735 2.1484zM27.86 11.8232L26 8.7231V2H24V8.7231l-1.86 3.1A7.9986 7.9986 0 0021 15.939v.122a7.9961 7.9961 0 001.14 4.1158l1.86 3.1V26h2V23.2769l1.86-3.1A7.9986 7.9986 0 0029 16.061v-.122A7.9961 7.9961 0 0027.86 11.8232zm-2.86-.88l1.145 1.9087A6.0027 6.0027 0 0126.9185 15h-3.837a6.0086 6.0086 0 01.7735-2.1484zm0 10.1132l-1.145-1.9087A6.0027 6.0027 0 0123.0815 17h3.837a6.0086 6.0086 0 01-.7735 2.1484z"
  })), children);
});
var ChartViolinPlot16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartViolinPlot16(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
  })), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.86 7.8232L13 4.7231V2H11V4.7231l-1.86 3.1A7.9986 7.9986 0 008 11.939v.122a7.9961 7.9961 0 001.14 4.1158l1.86 3.1V26h2V19.2769l1.86-3.1A7.9986 7.9986 0 0016 12.061v-.122A7.9961 7.9961 0 0014.86 7.8232zM12 6.9434l1.145 1.9087A6.0027 6.0027 0 0113.9185 11h-3.837a6.0086 6.0086 0 01.7735-2.1484zm0 10.1132l-1.145-1.9087A6.0027 6.0027 0 0110.0815 13h3.837a6.0086 6.0086 0 01-.7735 2.1484zM27.86 11.8232L26 8.7231V2H24V8.7231l-1.86 3.1A7.9986 7.9986 0 0021 15.939v.122a7.9961 7.9961 0 001.14 4.1158l1.86 3.1V26h2V23.2769l1.86-3.1A7.9986 7.9986 0 0029 16.061v-.122A7.9961 7.9961 0 0027.86 11.8232zm-2.86-.88l1.145 1.9087A6.0027 6.0027 0 0126.9185 15h-3.837a6.0086 6.0086 0 01.7735-2.1484zm0 10.1132l-1.145-1.9087A6.0027 6.0027 0 0123.0815 17h3.837a6.0086 6.0086 0 01-.7735 2.1484z"
  })), children);
});
var ChartWaterfall32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartWaterfall32(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,28V18H26V28H22V4H20V28H10V14H8V28H4V2H2V28a2.0023,2.0023,0,0,0,2,2H30V28Z"
  })), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 4H16V18H14z"
  })), children);
});
var ChartWaterfall24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartWaterfall24(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,28V18H26V28H22V4H20V28H10V14H8V28H4V2H2V28a2.0023,2.0023,0,0,0,2,2H30V28Z"
  })), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 4H16V18H14z"
  })), children);
});
var ChartWaterfall20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartWaterfall20(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,28V18H26V28H22V4H20V28H10V14H8V28H4V2H2V28a2.0023,2.0023,0,0,0,2,2H30V28Z"
  })), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 4H16V18H14z"
  })), children);
});
var ChartWaterfall16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartWaterfall16(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,28V18H26V28H22V4H20V28H10V14H8V28H4V2H2V28a2.0023,2.0023,0,0,0,2,2H30V28Z"
  })), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 4H16V18H14z"
  })), children);
});
var ChartWinLoss32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartWinLoss32(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H16V6a2.0023,2.0023,0,0,0-2-2H6A2.0023,2.0023,0,0,0,4,6v9H2v2H16v9a2.0023,2.0023,0,0,0,2,2h8a2.0023,2.0023,0,0,0,2-2V17h2ZM6,6h8v9H6ZM26,26H18V17h8Z"
  })), children);
});
var ChartWinLoss24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartWinLoss24(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H16V6a2.0023,2.0023,0,0,0-2-2H6A2.0023,2.0023,0,0,0,4,6v9H2v2H16v9a2.0023,2.0023,0,0,0,2,2h8a2.0023,2.0023,0,0,0,2-2V17h2ZM6,6h8v9H6ZM26,26H18V17h8Z"
  })), children);
});
var ChartWinLoss20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartWinLoss20(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H16V6a2.0023,2.0023,0,0,0-2-2H6A2.0023,2.0023,0,0,0,4,6v9H2v2H16v9a2.0023,2.0023,0,0,0,2,2h8a2.0023,2.0023,0,0,0,2-2V17h2ZM6,6h8v9H6ZM26,26H18V17h8Z"
  })), children);
});
var ChartWinLoss16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChartWinLoss16(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H16V6a2.0023,2.0023,0,0,0-2-2H6A2.0023,2.0023,0,0,0,4,6v9H2v2H16v9a2.0023,2.0023,0,0,0,2,2h8a2.0023,2.0023,0,0,0,2-2V17h2ZM6,6h8v9H6ZM26,26H18V17h8Z"
  })), children);
});
var Chat32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Chat32(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.74,30,16,29l4-7h6a2,2,0,0,0,2-2V8a2,2,0,0,0-2-2H6A2,2,0,0,0,4,8V20a2,2,0,0,0,2,2h9v2H6a4,4,0,0,1-4-4V8A4,4,0,0,1,6,4H26a4,4,0,0,1,4,4V20a4,4,0,0,1-4,4H21.16Z"
  })), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 10H24V12H8zM8 16H18V18H8z"
  })), children);
});
var Chat24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Chat24(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.74,30,16,29l4-7h6a2,2,0,0,0,2-2V8a2,2,0,0,0-2-2H6A2,2,0,0,0,4,8V20a2,2,0,0,0,2,2h9v2H6a4,4,0,0,1-4-4V8A4,4,0,0,1,6,4H26a4,4,0,0,1,4,4V20a4,4,0,0,1-4,4H21.16Z"
  })), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 10H24V12H8zM8 16H18V18H8z"
  })), children);
});
var Chat20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Chat20(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.74,30,16,29l4-7h6a2,2,0,0,0,2-2V8a2,2,0,0,0-2-2H6A2,2,0,0,0,4,8V20a2,2,0,0,0,2,2h9v2H6a4,4,0,0,1-4-4V8A4,4,0,0,1,6,4H26a4,4,0,0,1,4,4V20a4,4,0,0,1-4,4H21.16Z"
  })), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 10H24V12H8zM8 16H18V18H8z"
  })), children);
});
var Chat16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Chat16(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.74,30,16,29l4-7h6a2,2,0,0,0,2-2V8a2,2,0,0,0-2-2H6A2,2,0,0,0,4,8V20a2,2,0,0,0,2,2h9v2H6a4,4,0,0,1-4-4V8A4,4,0,0,1,6,4H26a4,4,0,0,1,4,4V20a4,4,0,0,1-4,4H21.16Z"
  })), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 10H24V12H8zM8 16H18V18H8z"
  })), children);
});
var ChatLaunch32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChatLaunch32(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 4L22 6 26.586 6 20 12.586 21.414 14 28 7.414 28 12 30 12 30 4 22 4zM28 16v4a1.9965 1.9965 0 01-2 2H20l-4 7 1.7358 1 3.4288-6H26a3.9992 3.9992 0 004-4V16zM4 20V8A1.9965 1.9965 0 016 6H18V4H6A3.9986 3.9986 0 002 8V20a3.9992 3.9992 0 004 4h9V22H6A1.9965 1.9965 0 014 20z"
  })), children);
});
var ChatLaunch24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChatLaunch24(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 4L22 6 26.586 6 20 12.586 21.414 14 28 7.414 28 12 30 12 30 4 22 4zM28 16v4a1.9965 1.9965 0 01-2 2H20l-4 7 1.7358 1 3.4288-6H26a3.9992 3.9992 0 004-4V16zM4 20V8A1.9965 1.9965 0 016 6H18V4H6A3.9986 3.9986 0 002 8V20a3.9992 3.9992 0 004 4h9V22H6A1.9965 1.9965 0 014 20z"
  })), children);
});
var ChatLaunch20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChatLaunch20(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 4L22 6 26.586 6 20 12.586 21.414 14 28 7.414 28 12 30 12 30 4 22 4zM28 16v4a1.9965 1.9965 0 01-2 2H20l-4 7 1.7358 1 3.4288-6H26a3.9992 3.9992 0 004-4V16zM4 20V8A1.9965 1.9965 0 016 6H18V4H6A3.9986 3.9986 0 002 8V20a3.9992 3.9992 0 004 4h9V22H6A1.9965 1.9965 0 014 20z"
  })), children);
});
var ChatLaunch16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChatLaunch16(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 4L22 6 26.586 6 20 12.586 21.414 14 28 7.414 28 12 30 12 30 4 22 4zM28 16v4a1.9965 1.9965 0 01-2 2H20l-4 7 1.7358 1 3.4288-6H26a3.9992 3.9992 0 004-4V16zM4 20V8A1.9965 1.9965 0 016 6H18V4H6A3.9986 3.9986 0 002 8V20a3.9992 3.9992 0 004 4h9V22H6A1.9965 1.9965 0 014 20z"
  })), children);
});
var ChatOff32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChatOff32(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 8V21h2V8a3.9986 3.9986 0 00-4-4H8.2429l2 2H26A1.9965 1.9965 0 0128 8zM30 28.5859L3.4141 2 2 3.4141 3.5039 4.918A3.9181 3.9181 0 002 8V20a3.9992 3.9992 0 004 4h6V22H6a1.9965 1.9965 0 01-2-2V8a1.9814 1.9814 0 01.9194-1.6665L20.5859 22H17l-4 7 1.7358 1 3.4288-6h4.4213l6 6z"
  })), children);
});
var ChatOff24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChatOff24(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 8V21h2V8a3.9986 3.9986 0 00-4-4H8.2429l2 2H26A1.9965 1.9965 0 0128 8zM30 28.5859L3.4141 2 2 3.4141 3.5039 4.918A3.9181 3.9181 0 002 8V20a3.9992 3.9992 0 004 4h6V22H6a1.9965 1.9965 0 01-2-2V8a1.9814 1.9814 0 01.9194-1.6665L20.5859 22H17l-4 7 1.7358 1 3.4288-6h4.4213l6 6z"
  })), children);
});
var ChatOff20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChatOff20(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 8V21h2V8a3.9986 3.9986 0 00-4-4H8.2429l2 2H26A1.9965 1.9965 0 0128 8zM30 28.5859L3.4141 2 2 3.4141 3.5039 4.918A3.9181 3.9181 0 002 8V20a3.9992 3.9992 0 004 4h6V22H6a1.9965 1.9965 0 01-2-2V8a1.9814 1.9814 0 01.9194-1.6665L20.5859 22H17l-4 7 1.7358 1 3.4288-6h4.4213l6 6z"
  })), children);
});
var ChatOff16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChatOff16(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 8V21h2V8a3.9986 3.9986 0 00-4-4H8.2429l2 2H26A1.9965 1.9965 0 0128 8zM30 28.5859L3.4141 2 2 3.4141 3.5039 4.918A3.9181 3.9181 0 002 8V20a3.9992 3.9992 0 004 4h6V22H6a1.9965 1.9965 0 01-2-2V8a1.9814 1.9814 0 01.9194-1.6665L20.5859 22H17l-4 7 1.7358 1 3.4288-6h4.4213l6 6z"
  })), children);
});
var ChatOperational32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChatOperational32(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.586 10.414L19.166 14 19.166 14 15.584 17.587 17 19 22 14 17 9 15.586 10.414z"
  })), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.586 10.414L24.166 14 24.166 14 20.584 17.587 22 19 27 14 22 9 20.586 10.414zM10 9L11.593 12 15 12.414 12.5 14.667 13 18 10 16.125 7 18 7.5 14.667 5 12.414 8.5 12 10 9z"
  })), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V8a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,8V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V8A3.9988,3.9988,0,0,1,6,4H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var ChatOperational24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChatOperational24(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.586 10.414L19.166 14 19.166 14 15.584 17.587 17 19 22 14 17 9 15.586 10.414z"
  })), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.586 10.414L24.166 14 24.166 14 20.584 17.587 22 19 27 14 22 9 20.586 10.414zM10 9L11.593 12 15 12.414 12.5 14.667 13 18 10 16.125 7 18 7.5 14.667 5 12.414 8.5 12 10 9z"
  })), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V8a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,8V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V8A3.9988,3.9988,0,0,1,6,4H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var ChatOperational20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChatOperational20(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.586 10.414L19.166 14 19.166 14 15.584 17.587 17 19 22 14 17 9 15.586 10.414z"
  })), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.586 10.414L24.166 14 24.166 14 20.584 17.587 22 19 27 14 22 9 20.586 10.414zM10 9L11.593 12 15 12.414 12.5 14.667 13 18 10 16.125 7 18 7.5 14.667 5 12.414 8.5 12 10 9z"
  })), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V8a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,8V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V8A3.9988,3.9988,0,0,1,6,4H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var ChatOperational16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChatOperational16(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.586 10.414L19.166 14 19.166 14 15.584 17.587 17 19 22 14 17 9 15.586 10.414z"
  })), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.586 10.414L24.166 14 24.166 14 20.584 17.587 22 19 27 14 22 9 20.586 10.414zM10 9L11.593 12 15 12.414 12.5 14.667 13 18 10 16.125 7 18 7.5 14.667 5 12.414 8.5 12 10 9z"
  })), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V8a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,8V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V8A3.9988,3.9988,0,0,1,6,4H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var ChatBot32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChatBot32(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 19a6.9908 6.9908 0 01-5.833-3.1287l1.666-1.1074a5.0007 5.0007 0 008.334 0l1.666 1.1074A6.9908 6.9908 0 0116 19zM20 8a2 2 0 102 2A1.9806 1.9806 0 0020 8zM12 8a2 2 0 102 2A1.9806 1.9806 0 0012 8z"
  })), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V6a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,6V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V6A3.9988,3.9988,0,0,1,6,2H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var ChatBot24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChatBot24(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 19a6.9908 6.9908 0 01-5.833-3.1287l1.666-1.1074a5.0007 5.0007 0 008.334 0l1.666 1.1074A6.9908 6.9908 0 0116 19zM20 8a2 2 0 102 2A1.9806 1.9806 0 0020 8zM12 8a2 2 0 102 2A1.9806 1.9806 0 0012 8z"
  })), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V6a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,6V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V6A3.9988,3.9988,0,0,1,6,2H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var ChatBot20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChatBot20(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 19a6.9908 6.9908 0 01-5.833-3.1287l1.666-1.1074a5.0007 5.0007 0 008.334 0l1.666 1.1074A6.9908 6.9908 0 0116 19zM20 8a2 2 0 102 2A1.9806 1.9806 0 0020 8zM12 8a2 2 0 102 2A1.9806 1.9806 0 0012 8z"
  })), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V6a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,6V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V6A3.9988,3.9988,0,0,1,6,2H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var ChatBot16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChatBot16(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 19a6.9908 6.9908 0 01-5.833-3.1287l1.666-1.1074a5.0007 5.0007 0 008.334 0l1.666 1.1074A6.9908 6.9908 0 0116 19zM20 8a2 2 0 102 2A1.9806 1.9806 0 0020 8zM12 8a2 2 0 102 2A1.9806 1.9806 0 0012 8z"
  })), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V6a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,6V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V6A3.9988,3.9988,0,0,1,6,2H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var Checkbox32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Checkbox32(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM6,26V6H26V26Z"
  })), children);
});
var Checkbox24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Checkbox24(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM6,26V6H26V26Z"
  })), children);
});
var Checkbox20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Checkbox20(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM6,26V6H26V26Z"
  })), children);
});
var Checkbox16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Checkbox16(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM6,26V6H26V26Z"
  })), children);
});
var CheckboxChecked32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxChecked32(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM6,26V6H26V26Z"
  })), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 21.5L9 16.54 10.59 15 14 18.35 21.41 11 23 12.58 14 21.5z"
  })), children);
});
var CheckboxChecked24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxChecked24(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM6,26V6H26V26Z"
  })), _path390 || (_path390 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 21.5L9 16.54 10.59 15 14 18.35 21.41 11 23 12.58 14 21.5z"
  })), children);
});
var CheckboxChecked20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxChecked20(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path391 || (_path391 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM6,26V6H26V26Z"
  })), _path392 || (_path392 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 21.5L9 16.54 10.59 15 14 18.35 21.41 11 23 12.58 14 21.5z"
  })), children);
});
var CheckboxChecked16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxChecked16(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path393 || (_path393 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM6,26V6H26V26Z"
  })), _path394 || (_path394 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 21.5L9 16.54 10.59 15 14 18.35 21.41 11 23 12.58 14 21.5z"
  })), children);
});
var CheckboxCheckedFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxCheckedFilled32(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path395 || (_path395 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM14,21.5,9,16.5427,10.5908,15,14,18.3456,21.4087,11l1.5918,1.5772Z"
  })), _path396 || (_path396 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M14,21.5,9,16.5427,10.5908,15,14,18.3456,21.4087,11l1.5918,1.5772Z",
    "data-icon-path": "inner-path"
  })), children);
});
var CheckboxCheckedFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxCheckedFilled24(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path397 || (_path397 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM14,21.5,9,16.5427,10.5908,15,14,18.3456,21.4087,11l1.5918,1.5772Z"
  })), _path398 || (_path398 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M14,21.5,9,16.5427,10.5908,15,14,18.3456,21.4087,11l1.5918,1.5772Z",
    "data-icon-path": "inner-path"
  })), children);
});
var CheckboxCheckedFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxCheckedFilled20(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path399 || (_path399 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM14,21.5,9,16.5427,10.5908,15,14,18.3456,21.4087,11l1.5918,1.5772Z"
  })), _path400 || (_path400 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M14,21.5,9,16.5427,10.5908,15,14,18.3456,21.4087,11l1.5918,1.5772Z",
    "data-icon-path": "inner-path"
  })), children);
});
var CheckboxCheckedFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxCheckedFilled16(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path401 || (_path401 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM14,21.5,9,16.5427,10.5908,15,14,18.3456,21.4087,11l1.5918,1.5772Z"
  })), _path402 || (_path402 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M14,21.5,9,16.5427,10.5908,15,14,18.3456,21.4087,11l1.5918,1.5772Z",
    "data-icon-path": "inner-path"
  })), children);
});
var CheckboxIndeterminate32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxIndeterminate32(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path403 || (_path403 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 14H22V18H10z"
  })), _path404 || (_path404 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM6,26V6H26V26Z"
  })), children);
});
var CheckboxIndeterminate24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxIndeterminate24(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path405 || (_path405 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 14H22V18H10z"
  })), _path406 || (_path406 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM6,26V6H26V26Z"
  })), children);
});
var CheckboxIndeterminate20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxIndeterminate20(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path407 || (_path407 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 14H22V18H10z"
  })), _path408 || (_path408 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM6,26V6H26V26Z"
  })), children);
});
var CheckboxIndeterminate16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxIndeterminate16(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path409 || (_path409 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 14H22V18H10z"
  })), _path410 || (_path410 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM6,26V6H26V26Z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "CheckboxIndeterminateFilled16": () => (/* binding */ CheckboxIndeterminateFilled16),
/* harmony export */   "CheckboxIndeterminateFilled20": () => (/* binding */ CheckboxIndeterminateFilled20),
/* harmony export */   "CheckboxIndeterminateFilled24": () => (/* binding */ CheckboxIndeterminateFilled24),
/* harmony export */   "CheckboxIndeterminateFilled32": () => (/* binding */ CheckboxIndeterminateFilled32),
/* harmony export */   "CheckboxUndeterminate16": () => (/* binding */ CheckboxUndeterminate16),
/* harmony export */   "CheckboxUndeterminate20": () => (/* binding */ CheckboxUndeterminate20),
/* harmony export */   "CheckboxUndeterminate24": () => (/* binding */ CheckboxUndeterminate24),
/* harmony export */   "CheckboxUndeterminate32": () => (/* binding */ CheckboxUndeterminate32),
/* harmony export */   "CheckboxUndeterminateFilled16": () => (/* binding */ CheckboxUndeterminateFilled16),
/* harmony export */   "CheckboxUndeterminateFilled20": () => (/* binding */ CheckboxUndeterminateFilled20),
/* harmony export */   "CheckboxUndeterminateFilled24": () => (/* binding */ CheckboxUndeterminateFilled24),
/* harmony export */   "CheckboxUndeterminateFilled32": () => (/* binding */ CheckboxUndeterminateFilled32),
/* harmony export */   "Checkmark16": () => (/* binding */ Checkmark16),
/* harmony export */   "Checkmark20": () => (/* binding */ Checkmark20),
/* harmony export */   "Checkmark24": () => (/* binding */ Checkmark24),
/* harmony export */   "Checkmark32": () => (/* binding */ Checkmark32),
/* harmony export */   "CheckmarkFilled16": () => (/* binding */ CheckmarkFilled16),
/* harmony export */   "CheckmarkFilled20": () => (/* binding */ CheckmarkFilled20),
/* harmony export */   "CheckmarkFilled24": () => (/* binding */ CheckmarkFilled24),
/* harmony export */   "CheckmarkFilled32": () => (/* binding */ CheckmarkFilled32),
/* harmony export */   "CheckmarkFilledError16": () => (/* binding */ CheckmarkFilledError16),
/* harmony export */   "CheckmarkFilledError20": () => (/* binding */ CheckmarkFilledError20),
/* harmony export */   "CheckmarkFilledError24": () => (/* binding */ CheckmarkFilledError24),
/* harmony export */   "CheckmarkFilledError32": () => (/* binding */ CheckmarkFilledError32),
/* harmony export */   "CheckmarkFilledWarning16": () => (/* binding */ CheckmarkFilledWarning16),
/* harmony export */   "CheckmarkFilledWarning20": () => (/* binding */ CheckmarkFilledWarning20),
/* harmony export */   "CheckmarkFilledWarning24": () => (/* binding */ CheckmarkFilledWarning24),
/* harmony export */   "CheckmarkFilledWarning32": () => (/* binding */ CheckmarkFilledWarning32),
/* harmony export */   "CheckmarkOutline16": () => (/* binding */ CheckmarkOutline16),
/* harmony export */   "CheckmarkOutline20": () => (/* binding */ CheckmarkOutline20),
/* harmony export */   "CheckmarkOutline24": () => (/* binding */ CheckmarkOutline24),
/* harmony export */   "CheckmarkOutline32": () => (/* binding */ CheckmarkOutline32),
/* harmony export */   "CheckmarkOutlineError16": () => (/* binding */ CheckmarkOutlineError16),
/* harmony export */   "CheckmarkOutlineError20": () => (/* binding */ CheckmarkOutlineError20),
/* harmony export */   "CheckmarkOutlineError24": () => (/* binding */ CheckmarkOutlineError24),
/* harmony export */   "CheckmarkOutlineError32": () => (/* binding */ CheckmarkOutlineError32),
/* harmony export */   "CheckmarkOutlineWarning16": () => (/* binding */ CheckmarkOutlineWarning16),
/* harmony export */   "CheckmarkOutlineWarning20": () => (/* binding */ CheckmarkOutlineWarning20),
/* harmony export */   "CheckmarkOutlineWarning24": () => (/* binding */ CheckmarkOutlineWarning24),
/* harmony export */   "CheckmarkOutlineWarning32": () => (/* binding */ CheckmarkOutlineWarning32),
/* harmony export */   "Chemistry16": () => (/* binding */ Chemistry16),
/* harmony export */   "Chemistry20": () => (/* binding */ Chemistry20),
/* harmony export */   "Chemistry24": () => (/* binding */ Chemistry24),
/* harmony export */   "Chemistry32": () => (/* binding */ Chemistry32),
/* harmony export */   "ChemistryReference16": () => (/* binding */ ChemistryReference16),
/* harmony export */   "ChemistryReference20": () => (/* binding */ ChemistryReference20),
/* harmony export */   "ChemistryReference24": () => (/* binding */ ChemistryReference24),
/* harmony export */   "ChemistryReference32": () => (/* binding */ ChemistryReference32),
/* harmony export */   "ChevronDown16": () => (/* binding */ ChevronDown16),
/* harmony export */   "ChevronDown20": () => (/* binding */ ChevronDown20),
/* harmony export */   "ChevronDown24": () => (/* binding */ ChevronDown24),
/* harmony export */   "ChevronDown32": () => (/* binding */ ChevronDown32),
/* harmony export */   "ChevronDownGlyph": () => (/* binding */ ChevronDownGlyph),
/* harmony export */   "ChevronLeft16": () => (/* binding */ ChevronLeft16),
/* harmony export */   "ChevronLeft20": () => (/* binding */ ChevronLeft20),
/* harmony export */   "ChevronLeft24": () => (/* binding */ ChevronLeft24),
/* harmony export */   "ChevronLeft32": () => (/* binding */ ChevronLeft32),
/* harmony export */   "ChevronLeftGlyph": () => (/* binding */ ChevronLeftGlyph),
/* harmony export */   "ChevronMini16": () => (/* binding */ ChevronMini16),
/* harmony export */   "ChevronMini20": () => (/* binding */ ChevronMini20),
/* harmony export */   "ChevronMini24": () => (/* binding */ ChevronMini24),
/* harmony export */   "ChevronMini32": () => (/* binding */ ChevronMini32),
/* harmony export */   "ChevronRight16": () => (/* binding */ ChevronRight16),
/* harmony export */   "ChevronRight20": () => (/* binding */ ChevronRight20),
/* harmony export */   "ChevronRight24": () => (/* binding */ ChevronRight24),
/* harmony export */   "ChevronRight32": () => (/* binding */ ChevronRight32),
/* harmony export */   "ChevronRightGlyph": () => (/* binding */ ChevronRightGlyph),
/* harmony export */   "ChevronSort16": () => (/* binding */ ChevronSort16),
/* harmony export */   "ChevronSort20": () => (/* binding */ ChevronSort20),
/* harmony export */   "ChevronSort24": () => (/* binding */ ChevronSort24),
/* harmony export */   "ChevronSort32": () => (/* binding */ ChevronSort32),
/* harmony export */   "ChevronSortDown16": () => (/* binding */ ChevronSortDown16),
/* harmony export */   "ChevronSortDown20": () => (/* binding */ ChevronSortDown20),
/* harmony export */   "ChevronSortDown24": () => (/* binding */ ChevronSortDown24),
/* harmony export */   "ChevronSortDown32": () => (/* binding */ ChevronSortDown32),
/* harmony export */   "ChevronSortUp16": () => (/* binding */ ChevronSortUp16),
/* harmony export */   "ChevronSortUp20": () => (/* binding */ ChevronSortUp20),
/* harmony export */   "ChevronSortUp24": () => (/* binding */ ChevronSortUp24),
/* harmony export */   "ChevronSortUp32": () => (/* binding */ ChevronSortUp32),
/* harmony export */   "ChevronUp16": () => (/* binding */ ChevronUp16),
/* harmony export */   "ChevronUp20": () => (/* binding */ ChevronUp20),
/* harmony export */   "ChevronUp24": () => (/* binding */ ChevronUp24),
/* harmony export */   "ChevronUp32": () => (/* binding */ ChevronUp32),
/* harmony export */   "ChevronUpGlyph": () => (/* binding */ ChevronUpGlyph),
/* harmony export */   "Chip16": () => (/* binding */ Chip16),
/* harmony export */   "Chip20": () => (/* binding */ Chip20),
/* harmony export */   "Chip24": () => (/* binding */ Chip24),
/* harmony export */   "Chip32": () => (/* binding */ Chip32),
/* harmony export */   "Choices16": () => (/* binding */ Choices16),
/* harmony export */   "Choices20": () => (/* binding */ Choices20),
/* harmony export */   "Choices24": () => (/* binding */ Choices24),
/* harmony export */   "Choices32": () => (/* binding */ Choices32),
/* harmony export */   "ChooseItem16": () => (/* binding */ ChooseItem16),
/* harmony export */   "ChooseItem20": () => (/* binding */ ChooseItem20),
/* harmony export */   "ChooseItem24": () => (/* binding */ ChooseItem24),
/* harmony export */   "ChooseItem32": () => (/* binding */ ChooseItem32),
/* harmony export */   "ChoroplethMap16": () => (/* binding */ ChoroplethMap16),
/* harmony export */   "ChoroplethMap20": () => (/* binding */ ChoroplethMap20),
/* harmony export */   "ChoroplethMap24": () => (/* binding */ ChoroplethMap24),
/* harmony export */   "ChoroplethMap32": () => (/* binding */ ChoroplethMap32),
/* harmony export */   "CicsCmas16": () => (/* binding */ CicsCmas16),
/* harmony export */   "CicsCmas20": () => (/* binding */ CicsCmas20),
/* harmony export */   "CicsCmas24": () => (/* binding */ CicsCmas24),
/* harmony export */   "CicsCmas32": () => (/* binding */ CicsCmas32),
/* harmony export */   "CicsExplorer16": () => (/* binding */ CicsExplorer16),
/* harmony export */   "CicsExplorer20": () => (/* binding */ CicsExplorer20),
/* harmony export */   "CicsExplorer24": () => (/* binding */ CicsExplorer24),
/* harmony export */   "CicsExplorer32": () => (/* binding */ CicsExplorer32),
/* harmony export */   "CicsRegion16": () => (/* binding */ CicsRegion16),
/* harmony export */   "CicsRegion20": () => (/* binding */ CicsRegion20),
/* harmony export */   "CicsRegion24": () => (/* binding */ CicsRegion24),
/* harmony export */   "CicsRegion32": () => (/* binding */ CicsRegion32),
/* harmony export */   "CicsRegionRouting16": () => (/* binding */ CicsRegionRouting16),
/* harmony export */   "CicsRegionRouting20": () => (/* binding */ CicsRegionRouting20),
/* harmony export */   "CicsRegionRouting24": () => (/* binding */ CicsRegionRouting24),
/* harmony export */   "CicsRegionRouting32": () => (/* binding */ CicsRegionRouting32),
/* harmony export */   "CicsRegionTarget16": () => (/* binding */ CicsRegionTarget16),
/* harmony export */   "CicsRegionTarget20": () => (/* binding */ CicsRegionTarget20),
/* harmony export */   "CicsRegionTarget24": () => (/* binding */ CicsRegionTarget24),
/* harmony export */   "CicsRegionTarget32": () => (/* binding */ CicsRegionTarget32),
/* harmony export */   "CicsSystemGroup16": () => (/* binding */ CicsSystemGroup16),
/* harmony export */   "CicsSystemGroup20": () => (/* binding */ CicsSystemGroup20),
/* harmony export */   "CicsSystemGroup24": () => (/* binding */ CicsSystemGroup24),
/* harmony export */   "CicsSystemGroup32": () => (/* binding */ CicsSystemGroup32),
/* harmony export */   "CicsWuiRegion16": () => (/* binding */ CicsWuiRegion16),
/* harmony export */   "CicsWuiRegion20": () => (/* binding */ CicsWuiRegion20),
/* harmony export */   "CicsWuiRegion24": () => (/* binding */ CicsWuiRegion24),
/* harmony export */   "CicsWuiRegion32": () => (/* binding */ CicsWuiRegion32),
/* harmony export */   "Cicsplex16": () => (/* binding */ Cicsplex16),
/* harmony export */   "Cicsplex20": () => (/* binding */ Cicsplex20),
/* harmony export */   "Cicsplex24": () => (/* binding */ Cicsplex24),
/* harmony export */   "Cicsplex32": () => (/* binding */ Cicsplex32),
/* harmony export */   "CircleDash16": () => (/* binding */ CircleDash16),
/* harmony export */   "CircleDash20": () => (/* binding */ CircleDash20),
/* harmony export */   "CircleDash24": () => (/* binding */ CircleDash24),
/* harmony export */   "CircleDash32": () => (/* binding */ CircleDash32),
/* harmony export */   "CircleFillGlyph": () => (/* binding */ CircleFillGlyph),
/* harmony export */   "CircleFilled16": () => (/* binding */ CircleFilled16),
/* harmony export */   "CircleFilled20": () => (/* binding */ CircleFilled20),
/* harmony export */   "CircleFilled24": () => (/* binding */ CircleFilled24),
/* harmony export */   "CircleFilled32": () => (/* binding */ CircleFilled32),
/* harmony export */   "CirclePacking16": () => (/* binding */ CirclePacking16),
/* harmony export */   "CirclePacking20": () => (/* binding */ CirclePacking20),
/* harmony export */   "CirclePacking24": () => (/* binding */ CirclePacking24),
/* harmony export */   "CirclePacking32": () => (/* binding */ CirclePacking32),
/* harmony export */   "CircleSolid16": () => (/* binding */ CircleSolid16),
/* harmony export */   "CircleSolid20": () => (/* binding */ CircleSolid20),
/* harmony export */   "CircleSolid24": () => (/* binding */ CircleSolid24),
/* harmony export */   "CircleSolid32": () => (/* binding */ CircleSolid32),
/* harmony export */   "CircleStrokeGlyph": () => (/* binding */ CircleStrokeGlyph),
/* harmony export */   "Classification16": () => (/* binding */ Classification16),
/* harmony export */   "Classification20": () => (/* binding */ Classification20),
/* harmony export */   "Classification24": () => (/* binding */ Classification24),
/* harmony export */   "Classification32": () => (/* binding */ Classification32),
/* harmony export */   "ClassifierLanguage16": () => (/* binding */ ClassifierLanguage16),
/* harmony export */   "ClassifierLanguage20": () => (/* binding */ ClassifierLanguage20),
/* harmony export */   "ClassifierLanguage24": () => (/* binding */ ClassifierLanguage24),
/* harmony export */   "ClassifierLanguage32": () => (/* binding */ ClassifierLanguage32),
/* harmony export */   "Clean16": () => (/* binding */ Clean16),
/* harmony export */   "Clean20": () => (/* binding */ Clean20),
/* harmony export */   "Clean24": () => (/* binding */ Clean24),
/* harmony export */   "Clean32": () => (/* binding */ Clean32),
/* harmony export */   "Close16": () => (/* binding */ Close16),
/* harmony export */   "Close20": () => (/* binding */ Close20),
/* harmony export */   "Close24": () => (/* binding */ Close24),
/* harmony export */   "Close32": () => (/* binding */ Close32),
/* harmony export */   "CloseFilled16": () => (/* binding */ CloseFilled16),
/* harmony export */   "CloseFilled20": () => (/* binding */ CloseFilled20),
/* harmony export */   "CloseFilled24": () => (/* binding */ CloseFilled24),
/* harmony export */   "CloseFilled32": () => (/* binding */ CloseFilled32),
/* harmony export */   "CloseOutline16": () => (/* binding */ CloseOutline16),
/* harmony export */   "CloseOutline20": () => (/* binding */ CloseOutline20),
/* harmony export */   "CloseOutline24": () => (/* binding */ CloseOutline24),
/* harmony export */   "CloseOutline32": () => (/* binding */ CloseOutline32),
/* harmony export */   "ClosedCaption16": () => (/* binding */ ClosedCaption16),
/* harmony export */   "ClosedCaption20": () => (/* binding */ ClosedCaption20),
/* harmony export */   "ClosedCaption24": () => (/* binding */ ClosedCaption24),
/* harmony export */   "ClosedCaption32": () => (/* binding */ ClosedCaption32),
/* harmony export */   "ClosedCaptionAlt16": () => (/* binding */ ClosedCaptionAlt16),
/* harmony export */   "ClosedCaptionAlt20": () => (/* binding */ ClosedCaptionAlt20),
/* harmony export */   "ClosedCaptionAlt24": () => (/* binding */ ClosedCaptionAlt24),
/* harmony export */   "ClosedCaptionAlt32": () => (/* binding */ ClosedCaptionAlt32),
/* harmony export */   "ClosedCaptionFilled16": () => (/* binding */ ClosedCaptionFilled16),
/* harmony export */   "ClosedCaptionFilled20": () => (/* binding */ ClosedCaptionFilled20),
/* harmony export */   "ClosedCaptionFilled24": () => (/* binding */ ClosedCaptionFilled24),
/* harmony export */   "ClosedCaptionFilled32": () => (/* binding */ ClosedCaptionFilled32),
/* harmony export */   "Cloud16": () => (/* binding */ Cloud16),
/* harmony export */   "Cloud20": () => (/* binding */ Cloud20),
/* harmony export */   "Cloud24": () => (/* binding */ Cloud24),
/* harmony export */   "Cloud32": () => (/* binding */ Cloud32),
/* harmony export */   "CloudAlerting16": () => (/* binding */ CloudAlerting16),
/* harmony export */   "CloudAlerting20": () => (/* binding */ CloudAlerting20),
/* harmony export */   "CloudAlerting24": () => (/* binding */ CloudAlerting24),
/* harmony export */   "CloudAlerting32": () => (/* binding */ CloudAlerting32),
/* harmony export */   "CloudApp16": () => (/* binding */ CloudApp16),
/* harmony export */   "CloudApp20": () => (/* binding */ CloudApp20),
/* harmony export */   "CloudApp24": () => (/* binding */ CloudApp24),
/* harmony export */   "CloudApp32": () => (/* binding */ CloudApp32),
/* harmony export */   "CloudAuditing16": () => (/* binding */ CloudAuditing16),
/* harmony export */   "CloudAuditing20": () => (/* binding */ CloudAuditing20),
/* harmony export */   "CloudAuditing24": () => (/* binding */ CloudAuditing24),
/* harmony export */   "CloudAuditing32": () => (/* binding */ CloudAuditing32),
/* harmony export */   "CloudDataOps16": () => (/* binding */ CloudDataOps16),
/* harmony export */   "CloudDataOps20": () => (/* binding */ CloudDataOps20),
/* harmony export */   "CloudDataOps24": () => (/* binding */ CloudDataOps24),
/* harmony export */   "CloudDataOps32": () => (/* binding */ CloudDataOps32),
/* harmony export */   "CloudDownload16": () => (/* binding */ CloudDownload16),
/* harmony export */   "CloudDownload20": () => (/* binding */ CloudDownload20),
/* harmony export */   "CloudDownload24": () => (/* binding */ CloudDownload24),
/* harmony export */   "CloudDownload32": () => (/* binding */ CloudDownload32),
/* harmony export */   "CloudLightning16": () => (/* binding */ CloudLightning16),
/* harmony export */   "CloudLightning20": () => (/* binding */ CloudLightning20),
/* harmony export */   "CloudLightning24": () => (/* binding */ CloudLightning24),
/* harmony export */   "CloudLightning32": () => (/* binding */ CloudLightning32),
/* harmony export */   "CloudLogging16": () => (/* binding */ CloudLogging16),
/* harmony export */   "CloudLogging20": () => (/* binding */ CloudLogging20),
/* harmony export */   "CloudLogging24": () => (/* binding */ CloudLogging24),
/* harmony export */   "CloudLogging32": () => (/* binding */ CloudLogging32),
/* harmony export */   "CloudMonitoring16": () => (/* binding */ CloudMonitoring16),
/* harmony export */   "CloudMonitoring20": () => (/* binding */ CloudMonitoring20),
/* harmony export */   "CloudMonitoring24": () => (/* binding */ CloudMonitoring24),
/* harmony export */   "CloudMonitoring32": () => (/* binding */ CloudMonitoring32),
/* harmony export */   "CloudOffline16": () => (/* binding */ CloudOffline16),
/* harmony export */   "CloudOffline20": () => (/* binding */ CloudOffline20),
/* harmony export */   "CloudOffline24": () => (/* binding */ CloudOffline24),
/* harmony export */   "CloudOffline32": () => (/* binding */ CloudOffline32),
/* harmony export */   "CloudRain16": () => (/* binding */ CloudRain16),
/* harmony export */   "CloudRain20": () => (/* binding */ CloudRain20),
/* harmony export */   "CloudRain24": () => (/* binding */ CloudRain24),
/* harmony export */   "CloudRain32": () => (/* binding */ CloudRain32),
/* harmony export */   "CloudServiceManagement16": () => (/* binding */ CloudServiceManagement16),
/* harmony export */   "CloudServiceManagement20": () => (/* binding */ CloudServiceManagement20),
/* harmony export */   "CloudServiceManagement24": () => (/* binding */ CloudServiceManagement24),
/* harmony export */   "CloudServiceManagement32": () => (/* binding */ CloudServiceManagement32),
/* harmony export */   "CloudSnow16": () => (/* binding */ CloudSnow16),
/* harmony export */   "CloudSnow20": () => (/* binding */ CloudSnow20),
/* harmony export */   "CloudSnow24": () => (/* binding */ CloudSnow24),
/* harmony export */   "CloudSnow32": () => (/* binding */ CloudSnow32),
/* harmony export */   "CloudUpload16": () => (/* binding */ CloudUpload16),
/* harmony export */   "CloudUpload20": () => (/* binding */ CloudUpload20),
/* harmony export */   "CloudUpload24": () => (/* binding */ CloudUpload24),
/* harmony export */   "CloudUpload32": () => (/* binding */ CloudUpload32),
/* harmony export */   "QCircuitComposer16": () => (/* binding */ QCircuitComposer16),
/* harmony export */   "QCircuitComposer20": () => (/* binding */ QCircuitComposer20),
/* harmony export */   "QCircuitComposer24": () => (/* binding */ QCircuitComposer24),
/* harmony export */   "QCircuitComposer32": () => (/* binding */ QCircuitComposer32),
/* harmony export */   "WatsonHealthCircleMeasurement16": () => (/* binding */ WatsonHealthCircleMeasurement16),
/* harmony export */   "WatsonHealthCircleMeasurement20": () => (/* binding */ WatsonHealthCircleMeasurement20),
/* harmony export */   "WatsonHealthCircleMeasurement24": () => (/* binding */ WatsonHealthCircleMeasurement24),
/* harmony export */   "WatsonHealthCircleMeasurement32": () => (/* binding */ WatsonHealthCircleMeasurement32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _path65, _path66, _path67, _path68, _path69, _path70, _path71, _path72, _path73, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _circle, _path214, _circle2, _path215, _circle3, _path216, _circle4, _path217, _circle5, _circle6, _circle7, _circle8, _path218, _path219, _path220, _path221, _circle9, _path222, _path223, _path224, _path225, _path226, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _circle10, _path243, _circle11, _path244, _circle12, _path245, _circle13, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _path351, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388, _path389;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var didWarnAboutDeprecation = {};
var CheckboxIndeterminateFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxIndeterminateFilled32(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM22,18H10V14H22Z"
  })), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M22,18H10V14H22Z",
    "data-icon-path": "inner-path"
  })), children);
});
var CheckboxIndeterminateFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxIndeterminateFilled24(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM22,18H10V14H22Z"
  })), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M22,18H10V14H22Z",
    "data-icon-path": "inner-path"
  })), children);
});
var CheckboxIndeterminateFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxIndeterminateFilled20(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM22,18H10V14H22Z"
  })), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M22,18H10V14H22Z",
    "data-icon-path": "inner-path"
  })), children);
});
var CheckboxIndeterminateFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxIndeterminateFilled16(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM22,18H10V14H22Z"
  })), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M22,18H10V14H22Z",
    "data-icon-path": "inner-path"
  })), children);
});
var CheckboxUndeterminate32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxUndeterminate32(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  if (true) {
    if (!didWarnAboutDeprecation['CheckboxUndeterminate32']) {
      didWarnAboutDeprecation['CheckboxUndeterminate32'] = true;
      console.warn("The CheckboxUndeterminate32 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 14H22V18H10z"
  })), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM6,26V6H26V26Z"
  })), children);
});
var CheckboxUndeterminate24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxUndeterminate24(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  if (true) {
    if (!didWarnAboutDeprecation['CheckboxUndeterminate24']) {
      didWarnAboutDeprecation['CheckboxUndeterminate24'] = true;
      console.warn("The CheckboxUndeterminate24 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 14H22V18H10z"
  })), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM6,26V6H26V26Z"
  })), children);
});
var CheckboxUndeterminate20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxUndeterminate20(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  if (true) {
    if (!didWarnAboutDeprecation['CheckboxUndeterminate20']) {
      didWarnAboutDeprecation['CheckboxUndeterminate20'] = true;
      console.warn("The CheckboxUndeterminate20 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 14H22V18H10z"
  })), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM6,26V6H26V26Z"
  })), children);
});
var CheckboxUndeterminate16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxUndeterminate16(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  if (true) {
    if (!didWarnAboutDeprecation['CheckboxUndeterminate16']) {
      didWarnAboutDeprecation['CheckboxUndeterminate16'] = true;
      console.warn("The CheckboxUndeterminate16 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 14H22V18H10z"
  })), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM6,26V6H26V26Z"
  })), children);
});
var CheckboxUndeterminateFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxUndeterminateFilled32(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  if (true) {
    if (!didWarnAboutDeprecation['CheckboxUndeterminateFilled32']) {
      didWarnAboutDeprecation['CheckboxUndeterminateFilled32'] = true;
      console.warn("The CheckboxUndeterminateFilled32 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM22,18H10V14H22Z"
  })), children);
});
var CheckboxUndeterminateFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxUndeterminateFilled24(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  if (true) {
    if (!didWarnAboutDeprecation['CheckboxUndeterminateFilled24']) {
      didWarnAboutDeprecation['CheckboxUndeterminateFilled24'] = true;
      console.warn("The CheckboxUndeterminateFilled24 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM22,18H10V14H22Z"
  })), children);
});
var CheckboxUndeterminateFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxUndeterminateFilled20(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  if (true) {
    if (!didWarnAboutDeprecation['CheckboxUndeterminateFilled20']) {
      didWarnAboutDeprecation['CheckboxUndeterminateFilled20'] = true;
      console.warn("The CheckboxUndeterminateFilled20 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM22,18H10V14H22Z"
  })), children);
});
var CheckboxUndeterminateFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckboxUndeterminateFilled16(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  if (true) {
    if (!didWarnAboutDeprecation['CheckboxUndeterminateFilled16']) {
      didWarnAboutDeprecation['CheckboxUndeterminateFilled16'] = true;
      console.warn("The CheckboxUndeterminateFilled16 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2,2,0,0,0,4,6V26a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V6A2,2,0,0,0,26,4ZM22,18H10V14H22Z"
  })), children);
});
var Checkmark32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Checkmark32(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 24L4 15 5.414 13.586 13 21.171 26.586 7.586 28 9 13 24z"
  })), children);
});
var Checkmark24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Checkmark24(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 24 24",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 15.9L4.7 10.6 3.6 11.6 8.9 16.9 10 18 20.6 7.4 19.5 6.3z"
  })), children);
});
var Checkmark20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Checkmark20(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 20 20",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 13.2L3.6 8.8 2.7 9.7 7.1 14.1 8 15 16.5 6.5 15.6 5.6z"
  })), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.6 5.6L8 13.2 3.6 8.8 2.7 9.7 7.1 14.1 8 15 16.5 6.5 15.6 5.6z"
  })), children);
});
var Checkmark16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Checkmark16(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 24L4 15 5.414 13.586 13 21.171 26.586 7.586 28 9 13 24z"
  })), children);
});
var CheckmarkFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkFilled32(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2ZM14,21.5908l-5-5L10.5906,15,14,18.4092,21.41,11l1.5957,1.5859Z"
  })), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M14 21.591L9 16.591 10.591 15 14 18.409 21.41 11 23.005 12.585 14 21.591z",
    "data-icon-path": "inner-path"
  })), children);
});
var CheckmarkFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkFilled24(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 24 24",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,1C6,1,1,6,1,12s5,11,11,11s11-4.9,11-11S18.1,1,12,1z M10.4,16.3l-3.9-3.9l1.3-1.2l2.7,2.7l5.8-5.8l1.3,1.3L10.4,16.3z"
  })), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M10.4,16.3l-3.9-3.9l1.3-1.2l2.7,2.7l5.8-5.8l1.3,1.3L10.4,16.3z",
    "data-icon-path": "inner-path",
    opacity: "0"
  })), children);
});
var CheckmarkFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkFilled20(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 20 20",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,1c-4.9,0-9,4.1-9,9s4.1,9,9,9s9-4,9-9S15,1,10,1z M8.7,13.5l-3.2-3.2l1-1l2.2,2.2l4.8-4.8l1,1L8.7,13.5z"
  })), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M8.7,13.5l-3.2-3.2l1-1l2.2,2.2l4.8-4.8l1,1L8.7,13.5z",
    "data-icon-path": "inner-path",
    opacity: "0"
  })), children);
});
var CheckmarkFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkFilled16(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,1C4.1,1,1,4.1,1,8c0,3.9,3.1,7,7,7s7-3.1,7-7C15,4.1,11.9,1,8,1z M7,11L4.3,8.3l0.9-0.8L7,9.3l4-3.9l0.9,0.8L7,11z"
  })), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7,11L4.3,8.3l0.9-0.8L7,9.3l4-3.9l0.9,0.8L7,11z",
    "data-icon-path": "inner-path",
    opacity: "0"
  })), children);
});
var CheckmarkFilledError32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkFilledError32(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,24a6,6,0,1,0-6,6A6.0066,6.0066,0,0,0,30,24Zm-2,0a3.9521,3.9521,0,0,1-.5669,2.019L21.981,20.5669A3.9529,3.9529,0,0,1,24,20,4.0045,4.0045,0,0,1,28,24Zm-8,0a3.9521,3.9521,0,0,1,.5669-2.019l5.4521,5.4521A3.9529,3.9529,0,0,1,24,28,4.0045,4.0045,0,0,1,20,24Z"
  })), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2a12,12,0,1,0,2,23.82V24a8,8,0,0,1,8-8h1.82A11.9348,11.9348,0,0,0,14,2ZM12,18.5908l-4-4L9.5908,13,12,15.4092,17.4092,10,19,11.5908Z"
  })), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M12 18.591L8 14.591 9.591 13 12 15.409 17.409 10 19 11.591 12 18.591z",
    "data-icon-path": "inner-path"
  })), children);
});
var CheckmarkFilledError24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkFilledError24(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,24a6,6,0,1,0-6,6A6.0066,6.0066,0,0,0,30,24Zm-2,0a3.9521,3.9521,0,0,1-.5669,2.019L21.981,20.5669A3.9529,3.9529,0,0,1,24,20,4.0045,4.0045,0,0,1,28,24Zm-8,0a3.9521,3.9521,0,0,1,.5669-2.019l5.4521,5.4521A3.9529,3.9529,0,0,1,24,28,4.0045,4.0045,0,0,1,20,24Z"
  })), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2a12,12,0,1,0,2,23.82V24a8,8,0,0,1,8-8h1.82A11.9348,11.9348,0,0,0,14,2ZM12,18.5908l-4-4L9.5908,13,12,15.4092,17.4092,10,19,11.5908Z"
  })), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M12 18.591L8 14.591 9.591 13 12 15.409 17.409 10 19 11.591 12 18.591z",
    "data-icon-path": "inner-path"
  })), children);
});
var CheckmarkFilledError20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkFilledError20(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,24a6,6,0,1,0-6,6A6.0066,6.0066,0,0,0,30,24Zm-2,0a3.9521,3.9521,0,0,1-.5669,2.019L21.981,20.5669A3.9529,3.9529,0,0,1,24,20,4.0045,4.0045,0,0,1,28,24Zm-8,0a3.9521,3.9521,0,0,1,.5669-2.019l5.4521,5.4521A3.9529,3.9529,0,0,1,24,28,4.0045,4.0045,0,0,1,20,24Z"
  })), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2a12,12,0,1,0,2,23.82V24a8,8,0,0,1,8-8h1.82A11.9348,11.9348,0,0,0,14,2ZM12,18.5908l-4-4L9.5908,13,12,15.4092,17.4092,10,19,11.5908Z"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M12 18.591L8 14.591 9.591 13 12 15.409 17.409 10 19 11.591 12 18.591z",
    "data-icon-path": "inner-path"
  })), children);
});
var CheckmarkFilledError16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkFilledError16(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,24a6,6,0,1,0-6,6A6.0066,6.0066,0,0,0,30,24Zm-2,0a3.9521,3.9521,0,0,1-.5669,2.019L21.981,20.5669A3.9529,3.9529,0,0,1,24,20,4.0045,4.0045,0,0,1,28,24Zm-8,0a3.9521,3.9521,0,0,1,.5669-2.019l5.4521,5.4521A3.9529,3.9529,0,0,1,24,28,4.0045,4.0045,0,0,1,20,24Z"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2a12,12,0,1,0,2,23.82V24a8,8,0,0,1,8-8h1.82A11.9348,11.9348,0,0,0,14,2ZM12,18.5908l-4-4L9.5908,13,12,15.4092,17.4092,10,19,11.5908Z"
  })), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M12 18.591L8 14.591 9.591 13 12 15.409 17.409 10 19 11.591 12 18.591z",
    "data-icon-path": "inner-path"
  })), children);
});
var CheckmarkFilledWarning32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkFilledWarning32(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2a12,12,0,1,0,3.3928,23.5059l3.9246-7.8492A2.9846,2.9846,0,0,1,24,16h1.82A11.9348,11.9348,0,0,0,14,2ZM12,18.5908l-4-4L9.5908,13,12,15.4092,17.4092,10,19,11.5908Z"
  })), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.38,28H20.6178L24,21.2358ZM24,18a1,1,0,0,0-.8947.5527l-5,10A1.0005,1.0005,0,0,0,19,30H29a1,1,0,0,0,.9214-1.3892L24.8946,18.5527A1,1,0,0,0,24,18Z"
  })), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M12 18.591L8 14.591 9.591 13 12 15.409 17.409 10 19 11.591 12 18.591z",
    "data-icon-path": "inner-path"
  })), children);
});
var CheckmarkFilledWarning24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkFilledWarning24(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2a12,12,0,1,0,3.3928,23.5059l3.9246-7.8492A2.9846,2.9846,0,0,1,24,16h1.82A11.9348,11.9348,0,0,0,14,2ZM12,18.5908l-4-4L9.5908,13,12,15.4092,17.4092,10,19,11.5908Z"
  })), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.38,28H20.6178L24,21.2358ZM24,18a1,1,0,0,0-.8947.5527l-5,10A1.0005,1.0005,0,0,0,19,30H29a1,1,0,0,0,.9214-1.3892L24.8946,18.5527A1,1,0,0,0,24,18Z"
  })), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M12 18.591L8 14.591 9.591 13 12 15.409 17.409 10 19 11.591 12 18.591z",
    "data-icon-path": "inner-path"
  })), children);
});
var CheckmarkFilledWarning20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkFilledWarning20(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2a12,12,0,1,0,3.3928,23.5059l3.9246-7.8492A2.9846,2.9846,0,0,1,24,16h1.82A11.9348,11.9348,0,0,0,14,2ZM12,18.5908l-4-4L9.5908,13,12,15.4092,17.4092,10,19,11.5908Z"
  })), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.38,28H20.6178L24,21.2358ZM24,18a1,1,0,0,0-.8947.5527l-5,10A1.0005,1.0005,0,0,0,19,30H29a1,1,0,0,0,.9214-1.3892L24.8946,18.5527A1,1,0,0,0,24,18Z"
  })), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M12 18.591L8 14.591 9.591 13 12 15.409 17.409 10 19 11.591 12 18.591z",
    "data-icon-path": "inner-path"
  })), children);
});
var CheckmarkFilledWarning16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkFilledWarning16(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,2a12,12,0,1,0,3.3928,23.5059l3.9246-7.8492A2.9846,2.9846,0,0,1,24,16h1.82A11.9348,11.9348,0,0,0,14,2ZM12,18.5908l-4-4L9.5908,13,12,15.4092,17.4092,10,19,11.5908Z"
  })), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.38,28H20.6178L24,21.2358ZM24,18a1,1,0,0,0-.8947.5527l-5,10A1.0005,1.0005,0,0,0,19,30H29a1,1,0,0,0,.9214-1.3892L24.8946,18.5527A1,1,0,0,0,24,18Z"
  })), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M12 18.591L8 14.591 9.591 13 12 15.409 17.409 10 19 11.591 12 18.591z",
    "data-icon-path": "inner-path"
  })), children);
});
var CheckmarkOutline32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkOutline32(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 21.414L9 16.413 10.413 15 14 18.586 21.585 11 23 12.415 14 21.414z"
  })), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), children);
});
var CheckmarkOutline24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkOutline24(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 21.414L9 16.413 10.413 15 14 18.586 21.585 11 23 12.415 14 21.414z"
  })), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), children);
});
var CheckmarkOutline20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkOutline20(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 21.414L9 16.413 10.413 15 14 18.586 21.585 11 23 12.415 14 21.414z"
  })), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), children);
});
var CheckmarkOutline16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkOutline16(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 21.414L9 16.413 10.413 15 14 18.586 21.585 11 23 12.415 14 21.414z"
  })), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,26A12,12,0,1,1,28,16,12,12,0,0,1,16,28Z"
  })), children);
});
var CheckmarkOutlineError32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkOutlineError32(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,24A10,10,0,1,1,24,14h2A12,12,0,1,0,14,26Z"
  })), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 15.59L9.41 13 8 14.41 12 18.41 19 11.41 17.59 10 12 15.59zM30 24a6 6 0 10-6 6A6.0066 6.0066 0 0030 24zm-2 0a3.9521 3.9521 0 01-.5669 2.019L21.981 20.5669A3.9529 3.9529 0 0124 20 4.0045 4.0045 0 0128 24zm-8 0a3.9521 3.9521 0 01.5669-2.019l5.4521 5.4521A3.9529 3.9529 0 0124 28 4.0045 4.0045 0 0120 24z"
  })), children);
});
var CheckmarkOutlineError24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkOutlineError24(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,24A10,10,0,1,1,24,14h2A12,12,0,1,0,14,26Z"
  })), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 15.59L9.41 13 8 14.41 12 18.41 19 11.41 17.59 10 12 15.59zM30 24a6 6 0 10-6 6A6.0066 6.0066 0 0030 24zm-2 0a3.9521 3.9521 0 01-.5669 2.019L21.981 20.5669A3.9529 3.9529 0 0124 20 4.0045 4.0045 0 0128 24zm-8 0a3.9521 3.9521 0 01.5669-2.019l5.4521 5.4521A3.9529 3.9529 0 0124 28 4.0045 4.0045 0 0120 24z"
  })), children);
});
var CheckmarkOutlineError20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkOutlineError20(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,24A10,10,0,1,1,24,14h2A12,12,0,1,0,14,26Z"
  })), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 15.59L9.41 13 8 14.41 12 18.41 19 11.41 17.59 10 12 15.59zM30 24a6 6 0 10-6 6A6.0066 6.0066 0 0030 24zm-2 0a3.9521 3.9521 0 01-.5669 2.019L21.981 20.5669A3.9529 3.9529 0 0124 20 4.0045 4.0045 0 0128 24zm-8 0a3.9521 3.9521 0 01.5669-2.019l5.4521 5.4521A3.9529 3.9529 0 0124 28 4.0045 4.0045 0 0120 24z"
  })), children);
});
var CheckmarkOutlineError16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkOutlineError16(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,24A10,10,0,1,1,24,14h2A12,12,0,1,0,14,26Z"
  })), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 15.59L9.41 13 8 14.41 12 18.41 19 11.41 17.59 10 12 15.59zM30 24a6 6 0 10-6 6A6.0066 6.0066 0 0030 24zm-2 0a3.9521 3.9521 0 01-.5669 2.019L21.981 20.5669A3.9529 3.9529 0 0124 20 4.0045 4.0045 0 0128 24zm-8 0a3.9521 3.9521 0 01.5669-2.019l5.4521 5.4521A3.9529 3.9529 0 0124 28 4.0045 4.0045 0 0120 24z"
  })), children);
});
var CheckmarkOutlineWarning32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkOutlineWarning32(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,24A10,10,0,1,1,24,14h2A12,12,0,1,0,14,26Z"
  })), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 15.59L9.41 13 8 14.41 12 18.41 19 11.41 17.59 10 12 15.59zM27.38 28H20.6178L24 21.2358zM24 18a1 1 0 00-.8947.5527l-5 10A1.0005 1.0005 0 0019 30H29a1 1 0 00.9214-1.3892L24.8946 18.5527A1 1 0 0024 18z"
  })), children);
});
var CheckmarkOutlineWarning24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkOutlineWarning24(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,24A10,10,0,1,1,24,14h2A12,12,0,1,0,14,26Z"
  })), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 15.59L9.41 13 8 14.41 12 18.41 19 11.41 17.59 10 12 15.59zM27.38 28H20.6178L24 21.2358zM24 18a1 1 0 00-.8947.5527l-5 10A1.0005 1.0005 0 0019 30H29a1 1 0 00.9214-1.3892L24.8946 18.5527A1 1 0 0024 18z"
  })), children);
});
var CheckmarkOutlineWarning20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkOutlineWarning20(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,24A10,10,0,1,1,24,14h2A12,12,0,1,0,14,26Z"
  })), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 15.59L9.41 13 8 14.41 12 18.41 19 11.41 17.59 10 12 15.59zM27.38 28H20.6178L24 21.2358zM24 18a1 1 0 00-.8947.5527l-5 10A1.0005 1.0005 0 0019 30H29a1 1 0 00.9214-1.3892L24.8946 18.5527A1 1 0 0024 18z"
  })), children);
});
var CheckmarkOutlineWarning16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CheckmarkOutlineWarning16(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,24A10,10,0,1,1,24,14h2A12,12,0,1,0,14,26Z"
  })), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12 15.59L9.41 13 8 14.41 12 18.41 19 11.41 17.59 10 12 15.59zM27.38 28H20.6178L24 21.2358zM24 18a1 1 0 00-.8947.5527l-5 10A1.0005 1.0005 0 0019 30H29a1 1 0 00.9214-1.3892L24.8946 18.5527A1 1 0 0024 18z"
  })), children);
});
var Chemistry32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Chemistry32(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.2314,23.6182,20,13.6748V4h2V2H10V4h2v9.6748L4.7686,23.6182A4.0183,4.0183,0,0,0,8.0186,30H23.9814a4.0183,4.0183,0,0,0,3.25-6.3818ZM14,14.3252V4h4V14.3252L20.6728,18H11.3272ZM23.9814,28H8.0186a2.0192,2.0192,0,0,1-1.6329-3.2061L9.8726,20H22.1274l3.4869,4.7939A2.0192,2.0192,0,0,1,23.9814,28Z"
  })), children);
});
var Chemistry24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Chemistry24(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.2314,23.6182,20,13.6748V4h2V2H10V4h2v9.6748L4.7686,23.6182A4.0183,4.0183,0,0,0,8.0186,30H23.9814a4.0183,4.0183,0,0,0,3.25-6.3818ZM14,14.3252V4h4V14.3252L20.6728,18H11.3272ZM23.9814,28H8.0186a2.0192,2.0192,0,0,1-1.6329-3.2061L9.8726,20H22.1274l3.4869,4.7939A2.0192,2.0192,0,0,1,23.9814,28Z"
  })), children);
});
var Chemistry20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Chemistry20(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.2314,23.6182,20,13.6748V4h2V2H10V4h2v9.6748L4.7686,23.6182A4.0183,4.0183,0,0,0,8.0186,30H23.9814a4.0183,4.0183,0,0,0,3.25-6.3818ZM14,14.3252V4h4V14.3252L20.6728,18H11.3272ZM23.9814,28H8.0186a2.0192,2.0192,0,0,1-1.6329-3.2061L9.8726,20H22.1274l3.4869,4.7939A2.0192,2.0192,0,0,1,23.9814,28Z"
  })), children);
});
var Chemistry16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Chemistry16(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.2314,23.6182,20,13.6748V4h2V2H10V4h2v9.6748L4.7686,23.6182A4.0183,4.0183,0,0,0,8.0186,30H23.9814a4.0183,4.0183,0,0,0,3.25-6.3818ZM14,14.3252V4h4V14.3252L20.6728,18H11.3272ZM23.9814,28H8.0186a2.0192,2.0192,0,0,1-1.6329-3.2061L9.8726,20H22.1274l3.4869,4.7939A2.0192,2.0192,0,0,1,23.9814,28Z"
  })), children);
});
var ChemistryReference32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChemistryReference32(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20z"
  })), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,13.67V4h2V2H10V4h2v9.67L9.58,17h2.4767L14,14.33V4h4V14.33l7.61,10.46a2.0133,2.0133,0,0,1-.44,2.82,2.0406,2.0406,0,0,1-1.19.39H15v2h8.98a4.0154,4.0154,0,0,0,3.25-6.38Z"
  })), children);
});
var ChemistryReference24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChemistryReference24(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20z"
  })), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,13.67V4h2V2H10V4h2v9.67L9.58,17h2.4767L14,14.33V4h4V14.33l7.61,10.46a2.0133,2.0133,0,0,1-.44,2.82,2.0406,2.0406,0,0,1-1.19.39H15v2h8.98a4.0154,4.0154,0,0,0,3.25-6.38Z"
  })), children);
});
var ChemistryReference20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChemistryReference20(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20z"
  })), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,13.67V4h2V2H10V4h2v9.67L9.58,17h2.4767L14,14.33V4h4V14.33l7.61,10.46a2.0133,2.0133,0,0,1-.44,2.82,2.0406,2.0406,0,0,1-1.19.39H15v2h8.98a4.0154,4.0154,0,0,0,3.25-6.38Z"
  })), children);
});
var ChemistryReference16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChemistryReference16(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20z"
  })), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,13.67V4h2V2H10V4h2v9.67L9.58,17h2.4767L14,14.33V4h4V14.33l7.61,10.46a2.0133,2.0133,0,0,1-.44,2.82,2.0406,2.0406,0,0,1-1.19.39H15v2h8.98a4.0154,4.0154,0,0,0,3.25-6.38Z"
  })), children);
});
var ChevronDown32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronDown32(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22L6 12 7.4 10.6 16 19.2 24.6 10.6 26 12z"
  })), children);
});
var ChevronDown24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronDown24(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22L6 12 7.4 10.6 16 19.2 24.6 10.6 26 12z"
  })), children);
});
var ChevronDown20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronDown20(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22L6 12 7.4 10.6 16 19.2 24.6 10.6 26 12z"
  })), children);
});
var ChevronDown16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronDown16(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 11L3 6 3.7 5.3 8 9.6 12.3 5.3 13 6z"
  })), children);
});
var ChevronDownGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronDownGlyph(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 10,
    height: 6,
    viewBox: "0 0 10 6",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 6L0 1 0.7 0.3 5 4.6 9.3 0.3 10 1z"
  })), children);
});
var ChevronLeft32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronLeft32(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16L20 6 21.4 7.4 12.8 16 21.4 24.6 20 26z"
  })), children);
});
var ChevronLeft24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronLeft24(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16L20 6 21.4 7.4 12.8 16 21.4 24.6 20 26z"
  })), children);
});
var ChevronLeft20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronLeft20(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 16L20 6 21.4 7.4 12.8 16 21.4 24.6 20 26z"
  })), children);
});
var ChevronLeft16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronLeft16(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 8L10 3 10.7 3.7 6.4 8 10.7 12.3 10 13z"
  })), children);
});
var ChevronLeftGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronLeftGlyph(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 6,
    height: 10,
    viewBox: "0 0 6 10",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M0 5L5 0 5.7 0.7 1.4 5 5.7 9.3 5 10z"
  })), children);
});
var ChevronMini32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronMini32(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 19L31 31 19 31 31 19z"
  })), children);
});
var ChevronMini24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronMini24(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 19L31 31 19 31 31 19z"
  })), children);
});
var ChevronMini20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronMini20(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 19L31 31 19 31 31 19z"
  })), children);
});
var ChevronMini16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronMini16(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 9L15 15 9 15z"
  })), children);
});
var ChevronRight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronRight32(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 16L12 26 10.6 24.6 19.2 16 10.6 7.4 12 6z"
  })), children);
});
var ChevronRight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronRight24(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 16L12 26 10.6 24.6 19.2 16 10.6 7.4 12 6z"
  })), children);
});
var ChevronRight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronRight20(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 16L12 26 10.6 24.6 19.2 16 10.6 7.4 12 6z"
  })), children);
});
var ChevronRight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronRight16(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 8L6 13 5.3 12.3 9.6 8 5.3 3.7 6 3z"
  })), children);
});
var ChevronRightGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronRightGlyph(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 6,
    height: 10,
    viewBox: "0 0 6 10",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 5L1 10 0.3 9.3 4.6 5 0.3 0.7 1 0z"
  })), children);
});
var ChevronSort32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronSort32(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 28L9 21 10.41 19.59 16 25.17 21.59 19.59 23 21 16 28zM16 4L23 11 21.59 12.41 16 6.83 10.41 12.41 9 11 16 4z"
  })), children);
});
var ChevronSort24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronSort24(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 28L9 21 10.41 19.59 16 25.17 21.59 19.59 23 21 16 28zM16 4L23 11 21.59 12.41 16 6.83 10.41 12.41 9 11 16 4z"
  })), children);
});
var ChevronSort20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronSort20(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 28L9 21 10.41 19.59 16 25.17 21.59 19.59 23 21 16 28zM16 4L23 11 21.59 12.41 16 6.83 10.41 12.41 9 11 16 4z"
  })), children);
});
var ChevronSort16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronSort16(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 14L4.5 10.5 5.2 9.8 8 12.6 10.8 9.8 11.5 10.5zM8 2L11.5 5.5 10.8 6.2 8 3.4 5.2 6.2 4.5 5.5z"
  })), children);
});
var ChevronSortDown32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronSortDown32(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 28L9 21 10.4 19.6 16 25.2 21.6 19.6 23 21z"
  })), children);
});
var ChevronSortDown24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronSortDown24(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 28L9 21 10.4 19.6 16 25.2 21.6 19.6 23 21z"
  })), children);
});
var ChevronSortDown20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronSortDown20(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 28L9 21 10.4 19.6 16 25.2 21.6 19.6 23 21z"
  })), children);
});
var ChevronSortDown16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronSortDown16(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 14L4.5 10.5 5.2 9.8 8 12.6 10.8 9.8 11.5 10.5z"
  })), children);
});
var ChevronSortUp32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronSortUp32(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 4L23 11 21.6 12.4 16 6.8 10.4 12.4 9 11z"
  })), children);
});
var ChevronSortUp24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronSortUp24(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 4L23 11 21.6 12.4 16 6.8 10.4 12.4 9 11z"
  })), children);
});
var ChevronSortUp20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronSortUp20(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 4L23 11 21.6 12.4 16 6.8 10.4 12.4 9 11z"
  })), children);
});
var ChevronSortUp16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronSortUp16(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 2L11.5 5.5 10.8 6.2 8 3.4 5.2 6.2 4.5 5.5z"
  })), children);
});
var ChevronUp32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronUp32(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 10L26 20 24.6 21.4 16 12.8 7.4 21.4 6 20z"
  })), children);
});
var ChevronUp24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronUp24(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 10L26 20 24.6 21.4 16 12.8 7.4 21.4 6 20z"
  })), children);
});
var ChevronUp20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronUp20(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 10L26 20 24.6 21.4 16 12.8 7.4 21.4 6 20z"
  })), children);
});
var ChevronUp16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronUp16(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 5L13 10 12.3 10.7 8 6.4 3.7 10.7 3 10z"
  })), children);
});
var ChevronUpGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChevronUpGlyph(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 10,
    height: 6,
    viewBox: "0 0 10 6",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5 0L10 5 9.3 5.7 5 1.4 0.7 5.7 0 5z"
  })), children);
});
var Chip32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Chip32(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,11V21H21V11Zm8,8H13V13h6Z"
  })), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,13V11H26V8a2,2,0,0,0-2-2H21V2H19V6H13V2H11V6H8A2,2,0,0,0,6,8v3H2v2H6v6H2v2H6v3a2,2,0,0,0,2,2h3v4h2V26h6v4h2V26h3a2,2,0,0,0,2-2V21h4V19H26V13ZM24,24H8V8H24Z"
  })), children);
});
var Chip24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Chip24(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,11V21H21V11Zm8,8H13V13h6Z"
  })), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,13V11H26V8a2,2,0,0,0-2-2H21V2H19V6H13V2H11V6H8A2,2,0,0,0,6,8v3H2v2H6v6H2v2H6v3a2,2,0,0,0,2,2h3v4h2V26h6v4h2V26h3a2,2,0,0,0,2-2V21h4V19H26V13ZM24,24H8V8H24Z"
  })), children);
});
var Chip20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Chip20(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,11V21H21V11Zm8,8H13V13h6Z"
  })), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,13V11H26V8a2,2,0,0,0-2-2H21V2H19V6H13V2H11V6H8A2,2,0,0,0,6,8v3H2v2H6v6H2v2H6v3a2,2,0,0,0,2,2h3v4h2V26h6v4h2V26h3a2,2,0,0,0,2-2V21h4V19H26V13ZM24,24H8V8H24Z"
  })), children);
});
var Chip16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Chip16(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11,11V21H21V11Zm8,8H13V13h6Z"
  })), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,13V11H26V8a2,2,0,0,0-2-2H21V2H19V6H13V2H11V6H8A2,2,0,0,0,6,8v3H2v2H6v6H2v2H6v3a2,2,0,0,0,2,2h3v4h2V26h6v4h2V26h3a2,2,0,0,0,2-2V21h4V19H26V13ZM24,24H8V8H24Z"
  })), children);
});
var Choices32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Choices32(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 13L28 4 19 4 19 6 24.586 6 16 14.586 7.414 6 13 6 13 4 4 4 4 13 6 13 6 7.414 15 16.414 15 26 4 26 4 28 28 28 28 26 17 26 17 16.414 26 7.414 26 13 28 13z"
  })), children);
});
var Choices24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Choices24(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 13L28 4 19 4 19 6 24.586 6 16 14.586 7.414 6 13 6 13 4 4 4 4 13 6 13 6 7.414 15 16.414 15 26 4 26 4 28 28 28 28 26 17 26 17 16.414 26 7.414 26 13 28 13z"
  })), children);
});
var Choices20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Choices20(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 13L28 4 19 4 19 6 24.586 6 16 14.586 7.414 6 13 6 13 4 4 4 4 13 6 13 6 7.414 15 16.414 15 26 4 26 4 28 28 28 28 26 17 26 17 16.414 26 7.414 26 13 28 13z"
  })), children);
});
var Choices16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Choices16(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 13L28 4 19 4 19 6 24.586 6 16 14.586 7.414 6 13 6 13 4 4 4 4 13 6 13 6 7.414 15 16.414 15 26 4 26 4 28 28 28 28 26 17 26 17 16.414 26 7.414 26 13 28 13z"
  })), children);
});
var ChooseItem32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChooseItem32(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 6H30V26H28zM17 6L15.57 7.393 23.15 15 2 15 2 17 23.15 17 15.57 24.573 17 26 27 16 17 6z"
  })), children);
});
var ChooseItem24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChooseItem24(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 6H30V26H28zM17 6L15.57 7.393 23.15 15 2 15 2 17 23.15 17 15.57 24.573 17 26 27 16 17 6z"
  })), children);
});
var ChooseItem20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChooseItem20(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 6H30V26H28zM17 6L15.57 7.393 23.15 15 2 15 2 17 23.15 17 15.57 24.573 17 26 27 16 17 6z"
  })), children);
});
var ChooseItem16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChooseItem16(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 6H30V26H28zM17 6L15.57 7.393 23.15 15 2 15 2 17 23.15 17 15.57 24.573 17 26 27 16 17 6z"
  })), children);
});
var ChoroplethMap32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChoroplethMap32(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.2427,4.03l-8-2a1.0065,1.0065,0,0,0-.6143.0415l-9.7,3.88L3.2427,4.03A1,1,0,0,0,2,5V27a1,1,0,0,0,.7573.97l8,2A1.0244,1.0244,0,0,0,11,30a.9953.9953,0,0,0,.3716-.0718l9.7-3.88,7.686,1.9219A1,1,0,0,0,30,27V5A1,1,0,0,0,29.2427,4.03ZM28,11H22V4.2806l6,1.5ZM10,19H4V13h6Zm2-8V7.6771l8-3.2V11Zm8,2v6H12V13Zm-8,8h8v3.3227l-8,3.2Zm10-8h6v6H22ZM10,7.7806V11H4V6.2806ZM4,21h6v6.7192l-6-1.5Zm18,3.2187V21h6v4.7192Z"
  })), children);
});
var ChoroplethMap24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChoroplethMap24(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.2427,4.03l-8-2a1.0065,1.0065,0,0,0-.6143.0415l-9.7,3.88L3.2427,4.03A1,1,0,0,0,2,5V27a1,1,0,0,0,.7573.97l8,2A1.0244,1.0244,0,0,0,11,30a.9953.9953,0,0,0,.3716-.0718l9.7-3.88,7.686,1.9219A1,1,0,0,0,30,27V5A1,1,0,0,0,29.2427,4.03ZM28,11H22V4.2806l6,1.5ZM10,19H4V13h6Zm2-8V7.6771l8-3.2V11Zm8,2v6H12V13Zm-8,8h8v3.3227l-8,3.2Zm10-8h6v6H22ZM10,7.7806V11H4V6.2806ZM4,21h6v6.7192l-6-1.5Zm18,3.2187V21h6v4.7192Z"
  })), children);
});
var ChoroplethMap20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChoroplethMap20(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.2427,4.03l-8-2a1.0065,1.0065,0,0,0-.6143.0415l-9.7,3.88L3.2427,4.03A1,1,0,0,0,2,5V27a1,1,0,0,0,.7573.97l8,2A1.0244,1.0244,0,0,0,11,30a.9953.9953,0,0,0,.3716-.0718l9.7-3.88,7.686,1.9219A1,1,0,0,0,30,27V5A1,1,0,0,0,29.2427,4.03ZM28,11H22V4.2806l6,1.5ZM10,19H4V13h6Zm2-8V7.6771l8-3.2V11Zm8,2v6H12V13Zm-8,8h8v3.3227l-8,3.2Zm10-8h6v6H22ZM10,7.7806V11H4V6.2806ZM4,21h6v6.7192l-6-1.5Zm18,3.2187V21h6v4.7192Z"
  })), children);
});
var ChoroplethMap16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ChoroplethMap16(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.2427,4.03l-8-2a1.0065,1.0065,0,0,0-.6143.0415l-9.7,3.88L3.2427,4.03A1,1,0,0,0,2,5V27a1,1,0,0,0,.7573.97l8,2A1.0244,1.0244,0,0,0,11,30a.9953.9953,0,0,0,.3716-.0718l9.7-3.88,7.686,1.9219A1,1,0,0,0,30,27V5A1,1,0,0,0,29.2427,4.03ZM28,11H22V4.2806l6,1.5ZM10,19H4V13h6Zm2-8V7.6771l8-3.2V11Zm8,2v6H12V13Zm-8,8h8v3.3227l-8,3.2Zm10-8h6v6H22ZM10,7.7806V11H4V6.2806ZM4,21h6v6.7192l-6-1.5Zm18,3.2187V21h6v4.7192Z"
  })), children);
});
var CicsCmas32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsCmas32(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.3335 30H26V28h4V26H28a2.002 2.002 0 01-2-2V21.6665A1.6684 1.6684 0 0127.6665 20H32v2H28v2h2a2.002 2.002 0 012 2v2.3335A1.6684 1.6684 0 0130.3335 30zM22.3335 20h-2.667A1.6665 1.6665 0 0018 21.6665V30h2V26h2v4h2V21.6665A1.6665 1.6665 0 0022.3335 20zM20 24V22h2v2zM12.5 24L11 20 9 20 9 30 11 30 11 23 12.5 27 14 23 14 30 16 30 16 20 14 20 12.5 24zM1 22v6.5A1.4727 1.4727 0 002.5 30H7V28H3V22H7V20H3A2.0059 2.0059 0 001 22zM13 8L11 8 11 11 8 11 8 13 11 13 11 16 13 16 13 13 16 13 16 11 13 11 13 8z"
  })), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,6H26V18h2V6a2.0059,2.0059,0,0,0-2-2H6A2.0059,2.0059,0,0,0,4,6V18H6Z"
  })), children);
});
var CicsCmas24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsCmas24(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.3335 30H26V28h4V26H28a2.002 2.002 0 01-2-2V21.6665A1.6684 1.6684 0 0127.6665 20H32v2H28v2h2a2.002 2.002 0 012 2v2.3335A1.6684 1.6684 0 0130.3335 30zM22.3335 20h-2.667A1.6665 1.6665 0 0018 21.6665V30h2V26h2v4h2V21.6665A1.6665 1.6665 0 0022.3335 20zM20 24V22h2v2zM12.5 24L11 20 9 20 9 30 11 30 11 23 12.5 27 14 23 14 30 16 30 16 20 14 20 12.5 24zM1 22v6.5A1.4727 1.4727 0 002.5 30H7V28H3V22H7V20H3A2.0059 2.0059 0 001 22zM13 8L11 8 11 11 8 11 8 13 11 13 11 16 13 16 13 13 16 13 16 11 13 11 13 8z"
  })), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,6H26V18h2V6a2.0059,2.0059,0,0,0-2-2H6A2.0059,2.0059,0,0,0,4,6V18H6Z"
  })), children);
});
var CicsCmas20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsCmas20(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.3335 30H26V28h4V26H28a2.002 2.002 0 01-2-2V21.6665A1.6684 1.6684 0 0127.6665 20H32v2H28v2h2a2.002 2.002 0 012 2v2.3335A1.6684 1.6684 0 0130.3335 30zM22.3335 20h-2.667A1.6665 1.6665 0 0018 21.6665V30h2V26h2v4h2V21.6665A1.6665 1.6665 0 0022.3335 20zM20 24V22h2v2zM12.5 24L11 20 9 20 9 30 11 30 11 23 12.5 27 14 23 14 30 16 30 16 20 14 20 12.5 24zM1 22v6.5A1.4727 1.4727 0 002.5 30H7V28H3V22H7V20H3A2.0059 2.0059 0 001 22zM13 8L11 8 11 11 8 11 8 13 11 13 11 16 13 16 13 13 16 13 16 11 13 11 13 8z"
  })), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,6H26V18h2V6a2.0059,2.0059,0,0,0-2-2H6A2.0059,2.0059,0,0,0,4,6V18H6Z"
  })), children);
});
var CicsCmas16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsCmas16(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.3335 30H26V28h4V26H28a2.002 2.002 0 01-2-2V21.6665A1.6684 1.6684 0 0127.6665 20H32v2H28v2h2a2.002 2.002 0 012 2v2.3335A1.6684 1.6684 0 0130.3335 30zM22.3335 20h-2.667A1.6665 1.6665 0 0018 21.6665V30h2V26h2v4h2V21.6665A1.6665 1.6665 0 0022.3335 20zM20 24V22h2v2zM12.5 24L11 20 9 20 9 30 11 30 11 23 12.5 27 14 23 14 30 16 30 16 20 14 20 12.5 24zM1 22v6.5A1.4727 1.4727 0 002.5 30H7V28H3V22H7V20H3A2.0059 2.0059 0 001 22zM13 8L11 8 11 11 8 11 8 13 11 13 11 16 13 16 13 13 16 13 16 11 13 11 13 8z"
  })), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,6H26V18h2V6a2.0059,2.0059,0,0,0-2-2H6A2.0059,2.0059,0,0,0,4,6V18H6Z"
  })), children);
});
var CicsExplorer32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsExplorer32(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 16L19.4 14.6 21.7 10.3 17.4 12.6 16 8 14.6 12.6 10.3 10.3 12.6 14.6 8 16 12.6 17.4 10.3 21.7 14.6 19.4 16 24 17.4 19.4 21.7 21.7 19.4 17.4 24 16z"
  })), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var CicsExplorer24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsExplorer24(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 16L19.4 14.6 21.7 10.3 17.4 12.6 16 8 14.6 12.6 10.3 10.3 12.6 14.6 8 16 12.6 17.4 10.3 21.7 14.6 19.4 16 24 17.4 19.4 21.7 21.7 19.4 17.4 24 16z"
  })), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var CicsExplorer20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsExplorer20(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 16L19.4 14.6 21.7 10.3 17.4 12.6 16 8 14.6 12.6 10.3 10.3 12.6 14.6 8 16 12.6 17.4 10.3 21.7 14.6 19.4 16 24 17.4 19.4 21.7 21.7 19.4 17.4 24 16z"
  })), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var CicsExplorer16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsExplorer16(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 16L19.4 14.6 21.7 10.3 17.4 12.6 16 8 14.6 12.6 10.3 10.3 12.6 14.6 8 16 12.6 17.4 10.3 21.7 14.6 19.4 16 24 17.4 19.4 21.7 21.7 19.4 17.4 24 16z"
  })), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var CicsSystemGroup32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsSystemGroup32(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 2H23V4h5V28H23v2h5a2.0059 2.0059 0 002-2V4A2.0059 2.0059 0 0028 2zM14 17H8a.9448.9448 0 00-1 1v6a.9448.9448 0 001 1h6a.9448.9448 0 001-1V18A.9448.9448 0 0014 17zm-1 6H9V19h4z"
  })), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 24V18a.9448.9448 0 00-1-1H18a.9448.9448 0 00-1 1v6a.9448.9448 0 001 1h6A1.0021 1.0021 0 0025 24zm-2-1H19V19h4zM14 7H8A.9448.9448 0 007 8v6a.9448.9448 0 001 1h6a.9448.9448 0 001-1V8A.9448.9448 0 0014 7zm-1 6H9V9h4zM18 15h6a.9448.9448 0 001-1V8a.9448.9448 0 00-1-1H18a.9448.9448 0 00-1 1v6A1.0021 1.0021 0 0018 15zm1-6h4v4H19z"
  })), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,4H9V2H4A2.0059,2.0059,0,0,0,2,4V28a2.0059,2.0059,0,0,0,2,2H9V28H4Z"
  })), children);
});
var CicsSystemGroup24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsSystemGroup24(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 2H23V4h5V28H23v2h5a2.0059 2.0059 0 002-2V4A2.0059 2.0059 0 0028 2zM14 17H8a.9448.9448 0 00-1 1v6a.9448.9448 0 001 1h6a.9448.9448 0 001-1V18A.9448.9448 0 0014 17zm-1 6H9V19h4z"
  })), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 24V18a.9448.9448 0 00-1-1H18a.9448.9448 0 00-1 1v6a.9448.9448 0 001 1h6A1.0021 1.0021 0 0025 24zm-2-1H19V19h4zM14 7H8A.9448.9448 0 007 8v6a.9448.9448 0 001 1h6a.9448.9448 0 001-1V8A.9448.9448 0 0014 7zm-1 6H9V9h4zM18 15h6a.9448.9448 0 001-1V8a.9448.9448 0 00-1-1H18a.9448.9448 0 00-1 1v6A1.0021 1.0021 0 0018 15zm1-6h4v4H19z"
  })), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,4H9V2H4A2.0059,2.0059,0,0,0,2,4V28a2.0059,2.0059,0,0,0,2,2H9V28H4Z"
  })), children);
});
var CicsSystemGroup20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsSystemGroup20(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 2H23V4h5V28H23v2h5a2.0059 2.0059 0 002-2V4A2.0059 2.0059 0 0028 2zM14 17H8a.9448.9448 0 00-1 1v6a.9448.9448 0 001 1h6a.9448.9448 0 001-1V18A.9448.9448 0 0014 17zm-1 6H9V19h4z"
  })), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 24V18a.9448.9448 0 00-1-1H18a.9448.9448 0 00-1 1v6a.9448.9448 0 001 1h6A1.0021 1.0021 0 0025 24zm-2-1H19V19h4zM14 7H8A.9448.9448 0 007 8v6a.9448.9448 0 001 1h6a.9448.9448 0 001-1V8A.9448.9448 0 0014 7zm-1 6H9V9h4zM18 15h6a.9448.9448 0 001-1V8a.9448.9448 0 00-1-1H18a.9448.9448 0 00-1 1v6A1.0021 1.0021 0 0018 15zm1-6h4v4H19z"
  })), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,4H9V2H4A2.0059,2.0059,0,0,0,2,4V28a2.0059,2.0059,0,0,0,2,2H9V28H4Z"
  })), children);
});
var CicsSystemGroup16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsSystemGroup16(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 2H23V4h5V28H23v2h5a2.0059 2.0059 0 002-2V4A2.0059 2.0059 0 0028 2zM14 17H8a.9448.9448 0 00-1 1v6a.9448.9448 0 001 1h6a.9448.9448 0 001-1V18A.9448.9448 0 0014 17zm-1 6H9V19h4z"
  })), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 24V18a.9448.9448 0 00-1-1H18a.9448.9448 0 00-1 1v6a.9448.9448 0 001 1h6A1.0021 1.0021 0 0025 24zm-2-1H19V19h4zM14 7H8A.9448.9448 0 007 8v6a.9448.9448 0 001 1h6a.9448.9448 0 001-1V8A.9448.9448 0 0014 7zm-1 6H9V9h4zM18 15h6a.9448.9448 0 001-1V8a.9448.9448 0 00-1-1H18a.9448.9448 0 00-1 1v6A1.0021 1.0021 0 0018 15zm1-6h4v4H19z"
  })), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,4H9V2H4A2.0059,2.0059,0,0,0,2,4V28a2.0059,2.0059,0,0,0,2,2H9V28H4Z"
  })), children);
});
var CicsWuiRegion32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsWuiRegion32(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 22L24 22 24 28 22 28 22 30 28 30 28 28 26 28 26 22 28 22 28 20 22 20 22 22zM18 28H16V20H14v8.6A1.4529 1.4529 0 0015.5 30h3A1.4529 1.4529 0 0020 28.6V20H18zM10.2 20L10 28.5 9 22 7 22 6 28.5 5.8 20 4 20 4.72 30 7 30 8 23.5 9 30 11.28 30 12 20 10.2 20zM16 11L13 11 13 8 11 8 11 11 8 11 8 13 11 13 11 16 13 16 13 13 16 13 16 11z"
  })), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0059,2.0059,0,0,0,4,6V18H6V6H26V18h2V6A2.0059,2.0059,0,0,0,26,4Z"
  })), children);
});
var CicsWuiRegion24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsWuiRegion24(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 22L24 22 24 28 22 28 22 30 28 30 28 28 26 28 26 22 28 22 28 20 22 20 22 22zM18 28H16V20H14v8.6A1.4529 1.4529 0 0015.5 30h3A1.4529 1.4529 0 0020 28.6V20H18zM10.2 20L10 28.5 9 22 7 22 6 28.5 5.8 20 4 20 4.72 30 7 30 8 23.5 9 30 11.28 30 12 20 10.2 20zM16 11L13 11 13 8 11 8 11 11 8 11 8 13 11 13 11 16 13 16 13 13 16 13 16 11z"
  })), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0059,2.0059,0,0,0,4,6V18H6V6H26V18h2V6A2.0059,2.0059,0,0,0,26,4Z"
  })), children);
});
var CicsWuiRegion20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsWuiRegion20(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 22L24 22 24 28 22 28 22 30 28 30 28 28 26 28 26 22 28 22 28 20 22 20 22 22zM18 28H16V20H14v8.6A1.4529 1.4529 0 0015.5 30h3A1.4529 1.4529 0 0020 28.6V20H18zM10.2 20L10 28.5 9 22 7 22 6 28.5 5.8 20 4 20 4.72 30 7 30 8 23.5 9 30 11.28 30 12 20 10.2 20zM16 11L13 11 13 8 11 8 11 11 8 11 8 13 11 13 11 16 13 16 13 13 16 13 16 11z"
  })), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0059,2.0059,0,0,0,4,6V18H6V6H26V18h2V6A2.0059,2.0059,0,0,0,26,4Z"
  })), children);
});
var CicsWuiRegion16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsWuiRegion16(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 22L24 22 24 28 22 28 22 30 28 30 28 28 26 28 26 22 28 22 28 20 22 20 22 22zM18 28H16V20H14v8.6A1.4529 1.4529 0 0015.5 30h3A1.4529 1.4529 0 0020 28.6V20H18zM10.2 20L10 28.5 9 22 7 22 6 28.5 5.8 20 4 20 4.72 30 7 30 8 23.5 9 30 11.28 30 12 20 10.2 20zM16 11L13 11 13 8 11 8 11 11 8 11 8 13 11 13 11 16 13 16 13 13 16 13 16 11z"
  })), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0059,2.0059,0,0,0,4,6V18H6V6H26V18h2V6A2.0059,2.0059,0,0,0,26,4Z"
  })), children);
});
var CicsRegion32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsRegion32(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 18L21 18.7 21 16 19 16 19 18.7 16.5 18 16 19.9 18.4 20.6 17 23 18.7 24 20 21.8 21.3 24 23 23 21.6 20.6 24 19.9 23.5 18zM16 13L16 11 13 11 13 8 11 8 11 11 8 11 8 13 11 13 11 16 13 16 13 13 16 13z"
  })), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0059,2.0059,0,0,0,4,6V26a2.0059,2.0059,0,0,0,2,2H26a2.0059,2.0059,0,0,0,2-2V6A2.0059,2.0059,0,0,0,26,4ZM6,26V6H26V26Z"
  })), children);
});
var CicsRegion24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsRegion24(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 18L21 18.7 21 16 19 16 19 18.7 16.5 18 16 19.9 18.4 20.6 17 23 18.7 24 20 21.8 21.3 24 23 23 21.6 20.6 24 19.9 23.5 18zM16 13L16 11 13 11 13 8 11 8 11 11 8 11 8 13 11 13 11 16 13 16 13 13 16 13z"
  })), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0059,2.0059,0,0,0,4,6V26a2.0059,2.0059,0,0,0,2,2H26a2.0059,2.0059,0,0,0,2-2V6A2.0059,2.0059,0,0,0,26,4ZM6,26V6H26V26Z"
  })), children);
});
var CicsRegion20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsRegion20(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 18L21 18.7 21 16 19 16 19 18.7 16.5 18 16 19.9 18.4 20.6 17 23 18.7 24 20 21.8 21.3 24 23 23 21.6 20.6 24 19.9 23.5 18zM16 13L16 11 13 11 13 8 11 8 11 11 8 11 8 13 11 13 11 16 13 16 13 13 16 13z"
  })), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0059,2.0059,0,0,0,4,6V26a2.0059,2.0059,0,0,0,2,2H26a2.0059,2.0059,0,0,0,2-2V6A2.0059,2.0059,0,0,0,26,4ZM6,26V6H26V26Z"
  })), children);
});
var CicsRegion16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsRegion16(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 18L21 18.7 21 16 19 16 19 18.7 16.5 18 16 19.9 18.4 20.6 17 23 18.7 24 20 21.8 21.3 24 23 23 21.6 20.6 24 19.9 23.5 18zM16 13L16 11 13 11 13 8 11 8 11 11 8 11 8 13 11 13 11 16 13 16 13 13 16 13z"
  })), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0059,2.0059,0,0,0,4,6V26a2.0059,2.0059,0,0,0,2,2H26a2.0059,2.0059,0,0,0,2-2V6A2.0059,2.0059,0,0,0,26,4ZM6,26V6H26V26Z"
  })), children);
});
var CicsRegionRouting32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsRegionRouting32(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 2L22 4 26.6 4 20 10.6 21.4 12 28 5.4 28 10 30 10 30 2 22 2zM19 16L19 18.7 16.5 18 16 19.9 18.4 20.6 17 23 18.7 24 20 21.8 21.3 24 23 23 21.6 20.6 24 19.9 23.5 18 21 18.7 21 16 19 16zM13 16L13 13 16 13 16 11 13 11 13 8 11 8 11 11 8 11 8 13 11 13 11 16 13 16z"
  })), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,26H6V6H19V4H6A2.0059,2.0059,0,0,0,4,6V26a2.0059,2.0059,0,0,0,2,2H26a2.0059,2.0059,0,0,0,2-2V13H26Z"
  })), children);
});
var CicsRegionRouting24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsRegionRouting24(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 2L22 4 26.6 4 20 10.6 21.4 12 28 5.4 28 10 30 10 30 2 22 2zM19 16L19 18.7 16.5 18 16 19.9 18.4 20.6 17 23 18.7 24 20 21.8 21.3 24 23 23 21.6 20.6 24 19.9 23.5 18 21 18.7 21 16 19 16zM13 16L13 13 16 13 16 11 13 11 13 8 11 8 11 11 8 11 8 13 11 13 11 16 13 16z"
  })), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,26H6V6H19V4H6A2.0059,2.0059,0,0,0,4,6V26a2.0059,2.0059,0,0,0,2,2H26a2.0059,2.0059,0,0,0,2-2V13H26Z"
  })), children);
});
var CicsRegionRouting20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsRegionRouting20(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 2L22 4 26.6 4 20 10.6 21.4 12 28 5.4 28 10 30 10 30 2 22 2zM19 16L19 18.7 16.5 18 16 19.9 18.4 20.6 17 23 18.7 24 20 21.8 21.3 24 23 23 21.6 20.6 24 19.9 23.5 18 21 18.7 21 16 19 16zM13 16L13 13 16 13 16 11 13 11 13 8 11 8 11 11 8 11 8 13 11 13 11 16 13 16z"
  })), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,26H6V6H19V4H6A2.0059,2.0059,0,0,0,4,6V26a2.0059,2.0059,0,0,0,2,2H26a2.0059,2.0059,0,0,0,2-2V13H26Z"
  })), children);
});
var CicsRegionRouting16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsRegionRouting16(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 2L22 4 26.6 4 20 10.6 21.4 12 28 5.4 28 10 30 10 30 2 22 2zM19 16L19 18.7 16.5 18 16 19.9 18.4 20.6 17 23 18.7 24 20 21.8 21.3 24 23 23 21.6 20.6 24 19.9 23.5 18 21 18.7 21 16 19 16zM13 16L13 13 16 13 16 11 13 11 13 8 11 8 11 11 8 11 8 13 11 13 11 16 13 16z"
  })), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,26H6V6H19V4H6A2.0059,2.0059,0,0,0,4,6V26a2.0059,2.0059,0,0,0,2,2H26a2.0059,2.0059,0,0,0,2-2V13H26Z"
  })), children);
});
var CicsRegionTarget32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsRegionTarget32(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 7H28V10H26zM29 4H32V6H29zM26 0H28V3H26zM22 4H25V6H22zM19 16L19 18.7 16.5 18 16 19.9 18.4 20.6 17 23 18.7 24 20 21.8 21.3 24 23 23 21.6 20.6 24 19.9 23.5 18 21 18.7 21 16 19 16zM13 16L13 13 16 13 16 11 13 11 13 8 11 8 11 11 8 11 8 13 11 13 11 16 13 16z"
  })), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,26H6V6H19V4H6A2.0059,2.0059,0,0,0,4,6V26a2.0059,2.0059,0,0,0,2,2H26a2.0059,2.0059,0,0,0,2-2V13H26Z"
  })), children);
});
var CicsRegionTarget24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsRegionTarget24(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 7H28V10H26zM29 4H32V6H29zM26 0H28V3H26zM22 4H25V6H22zM19 16L19 18.7 16.5 18 16 19.9 18.4 20.6 17 23 18.7 24 20 21.8 21.3 24 23 23 21.6 20.6 24 19.9 23.5 18 21 18.7 21 16 19 16zM13 16L13 13 16 13 16 11 13 11 13 8 11 8 11 11 8 11 8 13 11 13 11 16 13 16z"
  })), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,26H6V6H19V4H6A2.0059,2.0059,0,0,0,4,6V26a2.0059,2.0059,0,0,0,2,2H26a2.0059,2.0059,0,0,0,2-2V13H26Z"
  })), children);
});
var CicsRegionTarget20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsRegionTarget20(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 7H28V10H26zM29 4H32V6H29zM26 0H28V3H26zM22 4H25V6H22zM19 16L19 18.7 16.5 18 16 19.9 18.4 20.6 17 23 18.7 24 20 21.8 21.3 24 23 23 21.6 20.6 24 19.9 23.5 18 21 18.7 21 16 19 16zM13 16L13 13 16 13 16 11 13 11 13 8 11 8 11 11 8 11 8 13 11 13 11 16 13 16z"
  })), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,26H6V6H19V4H6A2.0059,2.0059,0,0,0,4,6V26a2.0059,2.0059,0,0,0,2,2H26a2.0059,2.0059,0,0,0,2-2V13H26Z"
  })), children);
});
var CicsRegionTarget16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CicsRegionTarget16(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 7H28V10H26zM29 4H32V6H29zM26 0H28V3H26zM22 4H25V6H22zM19 16L19 18.7 16.5 18 16 19.9 18.4 20.6 17 23 18.7 24 20 21.8 21.3 24 23 23 21.6 20.6 24 19.9 23.5 18 21 18.7 21 16 19 16zM13 16L13 13 16 13 16 11 13 11 13 8 11 8 11 11 8 11 8 13 11 13 11 16 13 16z"
  })), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,26H6V6H19V4H6A2.0059,2.0059,0,0,0,4,6V26a2.0059,2.0059,0,0,0,2,2H26a2.0059,2.0059,0,0,0,2-2V13H26Z"
  })), children);
});
var Cicsplex32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cicsplex32(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 18.6V17H6v1.6A7.3833 7.3833 0 0013.4 26H15V24H13.4A5.3775 5.3775 0 018 18.6zM28 18H20a2.0059 2.0059 0 00-2 2v8a2.0059 2.0059 0 002 2h8a2.0059 2.0059 0 002-2V20A2.0059 2.0059 0 0028 18zM20 28V20h8v8zM24 13.4V15h2V13.4A7.3833 7.3833 0 0018.6 6H17V8h1.6A5.3775 5.3775 0 0124 13.4zM12 2H4A2.0059 2.0059 0 002 4v8a2.0059 2.0059 0 002 2h8a2.0059 2.0059 0 002-2V4A2.0059 2.0059 0 0012 2zM4 12V4h8v8z"
  })), children);
});
var Cicsplex24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cicsplex24(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 18.6V17H6v1.6A7.3833 7.3833 0 0013.4 26H15V24H13.4A5.3775 5.3775 0 018 18.6zM28 18H20a2.0059 2.0059 0 00-2 2v8a2.0059 2.0059 0 002 2h8a2.0059 2.0059 0 002-2V20A2.0059 2.0059 0 0028 18zM20 28V20h8v8zM24 13.4V15h2V13.4A7.3833 7.3833 0 0018.6 6H17V8h1.6A5.3775 5.3775 0 0124 13.4zM12 2H4A2.0059 2.0059 0 002 4v8a2.0059 2.0059 0 002 2h8a2.0059 2.0059 0 002-2V4A2.0059 2.0059 0 0012 2zM4 12V4h8v8z"
  })), children);
});
var Cicsplex20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cicsplex20(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 18.6V17H6v1.6A7.3833 7.3833 0 0013.4 26H15V24H13.4A5.3775 5.3775 0 018 18.6zM28 18H20a2.0059 2.0059 0 00-2 2v8a2.0059 2.0059 0 002 2h8a2.0059 2.0059 0 002-2V20A2.0059 2.0059 0 0028 18zM20 28V20h8v8zM24 13.4V15h2V13.4A7.3833 7.3833 0 0018.6 6H17V8h1.6A5.3775 5.3775 0 0124 13.4zM12 2H4A2.0059 2.0059 0 002 4v8a2.0059 2.0059 0 002 2h8a2.0059 2.0059 0 002-2V4A2.0059 2.0059 0 0012 2zM4 12V4h8v8z"
  })), children);
});
var Cicsplex16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cicsplex16(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 18.6V17H6v1.6A7.3833 7.3833 0 0013.4 26H15V24H13.4A5.3775 5.3775 0 018 18.6zM28 18H20a2.0059 2.0059 0 00-2 2v8a2.0059 2.0059 0 002 2h8a2.0059 2.0059 0 002-2V20A2.0059 2.0059 0 0028 18zM20 28V20h8v8zM24 13.4V15h2V13.4A7.3833 7.3833 0 0018.6 6H17V8h1.6A5.3775 5.3775 0 0124 13.4zM12 2H4A2.0059 2.0059 0 002 4v8a2.0059 2.0059 0 002 2h8a2.0059 2.0059 0 002-2V4A2.0059 2.0059 0 0012 2zM4 12V4h8v8z"
  })), children);
});
var CircleFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CircleFilled32(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "10"
  })), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var CircleFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CircleFilled24(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "10"
  })), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var CircleFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CircleFilled20(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "10"
  })), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var CircleFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CircleFilled16(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "10"
  })), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14.0158,14.0158,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12.0137,12.0137,0,0,0,16,4Z"
  })), children);
});
var CircleSolid32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CircleSolid32(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "14"
  })), children);
});
var CircleSolid24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CircleSolid24(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "14"
  })), children);
});
var CircleSolid20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CircleSolid20(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "14"
  })), children);
});
var CircleSolid16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CircleSolid16(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "14"
  })), children);
});
var CircleDash32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CircleDash32(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.7 4.7a14.7 14.7 0 00-3 3.1L6.3 9A13.26 13.26 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.51 12.51 0 002 16H4A11.48 11.48 0 014.6 12.3zM2.7 20.4a14.4 14.4 0 002 3.9l1.6-1.2a12.89 12.89 0 01-1.7-3.3zM7.8 27.3a14.4 14.4 0 003.9 2l.6-1.9A12.89 12.89 0 019 25.7zM11.7 2.7l.6 1.9A11.48 11.48 0 0116 4V2A12.51 12.51 0 0011.7 2.7zM24.2 27.3a15.18 15.18 0 003.1-3.1L25.7 23A11.53 11.53 0 0123 25.7zM27.4 19.7l1.9.6A15.47 15.47 0 0030 16H28A11.48 11.48 0 0127.4 19.7zM29.2 11.6a14.4 14.4 0 00-2-3.9L25.6 8.9a12.89 12.89 0 011.7 3.3zM24.1 4.6a14.4 14.4 0 00-3.9-2l-.6 1.9a12.89 12.89 0 013.3 1.7zM20.3 29.3l-.6-1.9A11.48 11.48 0 0116 28v2A21.42 21.42 0 0020.3 29.3z"
  })), children);
});
var CircleDash24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CircleDash24(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.7 4.7a14.7 14.7 0 00-3 3.1L6.3 9A13.26 13.26 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.51 12.51 0 002 16H4A11.48 11.48 0 014.6 12.3zM2.7 20.4a14.4 14.4 0 002 3.9l1.6-1.2a12.89 12.89 0 01-1.7-3.3zM7.8 27.3a14.4 14.4 0 003.9 2l.6-1.9A12.89 12.89 0 019 25.7zM11.7 2.7l.6 1.9A11.48 11.48 0 0116 4V2A12.51 12.51 0 0011.7 2.7zM24.2 27.3a15.18 15.18 0 003.1-3.1L25.7 23A11.53 11.53 0 0123 25.7zM27.4 19.7l1.9.6A15.47 15.47 0 0030 16H28A11.48 11.48 0 0127.4 19.7zM29.2 11.6a14.4 14.4 0 00-2-3.9L25.6 8.9a12.89 12.89 0 011.7 3.3zM24.1 4.6a14.4 14.4 0 00-3.9-2l-.6 1.9a12.89 12.89 0 013.3 1.7zM20.3 29.3l-.6-1.9A11.48 11.48 0 0116 28v2A21.42 21.42 0 0020.3 29.3z"
  })), children);
});
var CircleDash20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CircleDash20(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.7 4.7a14.7 14.7 0 00-3 3.1L6.3 9A13.26 13.26 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.51 12.51 0 002 16H4A11.48 11.48 0 014.6 12.3zM2.7 20.4a14.4 14.4 0 002 3.9l1.6-1.2a12.89 12.89 0 01-1.7-3.3zM7.8 27.3a14.4 14.4 0 003.9 2l.6-1.9A12.89 12.89 0 019 25.7zM11.7 2.7l.6 1.9A11.48 11.48 0 0116 4V2A12.51 12.51 0 0011.7 2.7zM24.2 27.3a15.18 15.18 0 003.1-3.1L25.7 23A11.53 11.53 0 0123 25.7zM27.4 19.7l1.9.6A15.47 15.47 0 0030 16H28A11.48 11.48 0 0127.4 19.7zM29.2 11.6a14.4 14.4 0 00-2-3.9L25.6 8.9a12.89 12.89 0 011.7 3.3zM24.1 4.6a14.4 14.4 0 00-3.9-2l-.6 1.9a12.89 12.89 0 013.3 1.7zM20.3 29.3l-.6-1.9A11.48 11.48 0 0116 28v2A21.42 21.42 0 0020.3 29.3z"
  })), children);
});
var CircleDash16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CircleDash16(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.7 4.7a14.7 14.7 0 00-3 3.1L6.3 9A13.26 13.26 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.51 12.51 0 002 16H4A11.48 11.48 0 014.6 12.3zM2.7 20.4a14.4 14.4 0 002 3.9l1.6-1.2a12.89 12.89 0 01-1.7-3.3zM7.8 27.3a14.4 14.4 0 003.9 2l.6-1.9A12.89 12.89 0 019 25.7zM11.7 2.7l.6 1.9A11.48 11.48 0 0116 4V2A12.51 12.51 0 0011.7 2.7zM24.2 27.3a15.18 15.18 0 003.1-3.1L25.7 23A11.53 11.53 0 0123 25.7zM27.4 19.7l1.9.6A15.47 15.47 0 0030 16H28A11.48 11.48 0 0127.4 19.7zM29.2 11.6a14.4 14.4 0 00-2-3.9L25.6 8.9a12.89 12.89 0 011.7 3.3zM24.1 4.6a14.4 14.4 0 00-3.9-2l-.6 1.9a12.89 12.89 0 013.3 1.7zM20.3 29.3l-.6-1.9A11.48 11.48 0 0116 28v2A21.42 21.42 0 0020.3 29.3z"
  })), children);
});
var CircleFillGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CircleFillGlyph(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "8",
    r: "6"
  })), children);
});
var WatsonHealthCircleMeasurement32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCircleMeasurement32(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14,14,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12,12,0,0,0,16,4Z"
  })), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,12.41V16h2V9H16v2h3.59L11,19.59V16H9v7h7V21H12.41Z"
  })), children);
});
var WatsonHealthCircleMeasurement24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCircleMeasurement24(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14,14,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12,12,0,0,0,16,4Z"
  })), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,12.41V16h2V9H16v2h3.59L11,19.59V16H9v7h7V21H12.41Z"
  })), children);
});
var WatsonHealthCircleMeasurement20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCircleMeasurement20(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14,14,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12,12,0,0,0,16,4Z"
  })), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,12.41V16h2V9H16v2h3.59L11,19.59V16H9v7h7V21H12.41Z"
  })), children);
});
var WatsonHealthCircleMeasurement16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCircleMeasurement16(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30A14,14,0,1,1,30,16,14,14,0,0,1,16,30ZM16,4A12,12,0,1,0,28,16,12,12,0,0,0,16,4Z"
  })), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,12.41V16h2V9H16v2h3.59L11,19.59V16H9v7h7V21H12.41Z"
  })), children);
});
var CirclePacking32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CirclePacking32(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm7.5,7A3.5,3.5,0,1,1,20,12.5,3.5041,3.5041,0,0,1,23.5,9Zm.4348-1.978C23.791,7.0107,23.6467,7,23.5,7a5.4826,5.4826,0,0,0-4.1323,1.8784,8.0109,8.0109,0,0,0-5.5664-4.6675A11.8554,11.8554,0,0,1,23.9348,7.022ZM16,28a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,28ZM12,18a6,6,0,1,1,6-6A6.0067,6.0067,0,0,1,12,18ZM4,16a11.97,11.97,0,0,1,.2112-2.1987,7.9921,7.9921,0,0,0,7.3459,6.1762,5.9581,5.9581,0,0,0-.89,6.7564A12.0025,12.0025,0,0,1,4,16ZM21.3325,26.7339a5.9834,5.9834,0,0,0-4.1782-8.6206,8.02,8.02,0,0,0,1.9126-2.3672,5.4883,5.4883,0,0,0,8.9167-.0679c.003.1079.0164.2134.0164.3218A12.0025,12.0025,0,0,1,21.3325,26.7339Z"
  })), children);
});
var CirclePacking24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CirclePacking24(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm7.5,7A3.5,3.5,0,1,1,20,12.5,3.5041,3.5041,0,0,1,23.5,9Zm.4348-1.978C23.791,7.0107,23.6467,7,23.5,7a5.4826,5.4826,0,0,0-4.1323,1.8784,8.0109,8.0109,0,0,0-5.5664-4.6675A11.8554,11.8554,0,0,1,23.9348,7.022ZM16,28a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,28ZM12,18a6,6,0,1,1,6-6A6.0067,6.0067,0,0,1,12,18ZM4,16a11.97,11.97,0,0,1,.2112-2.1987,7.9921,7.9921,0,0,0,7.3459,6.1762,5.9581,5.9581,0,0,0-.89,6.7564A12.0025,12.0025,0,0,1,4,16ZM21.3325,26.7339a5.9834,5.9834,0,0,0-4.1782-8.6206,8.02,8.02,0,0,0,1.9126-2.3672,5.4883,5.4883,0,0,0,8.9167-.0679c.003.1079.0164.2134.0164.3218A12.0025,12.0025,0,0,1,21.3325,26.7339Z"
  })), children);
});
var CirclePacking20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CirclePacking20(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm7.5,7A3.5,3.5,0,1,1,20,12.5,3.5041,3.5041,0,0,1,23.5,9Zm.4348-1.978C23.791,7.0107,23.6467,7,23.5,7a5.4826,5.4826,0,0,0-4.1323,1.8784,8.0109,8.0109,0,0,0-5.5664-4.6675A11.8554,11.8554,0,0,1,23.9348,7.022ZM16,28a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,28ZM12,18a6,6,0,1,1,6-6A6.0067,6.0067,0,0,1,12,18ZM4,16a11.97,11.97,0,0,1,.2112-2.1987,7.9921,7.9921,0,0,0,7.3459,6.1762,5.9581,5.9581,0,0,0-.89,6.7564A12.0025,12.0025,0,0,1,4,16ZM21.3325,26.7339a5.9834,5.9834,0,0,0-4.1782-8.6206,8.02,8.02,0,0,0,1.9126-2.3672,5.4883,5.4883,0,0,0,8.9167-.0679c.003.1079.0164.2134.0164.3218A12.0025,12.0025,0,0,1,21.3325,26.7339Z"
  })), children);
});
var CirclePacking16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CirclePacking16(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm7.5,7A3.5,3.5,0,1,1,20,12.5,3.5041,3.5041,0,0,1,23.5,9Zm.4348-1.978C23.791,7.0107,23.6467,7,23.5,7a5.4826,5.4826,0,0,0-4.1323,1.8784,8.0109,8.0109,0,0,0-5.5664-4.6675A11.8554,11.8554,0,0,1,23.9348,7.022ZM16,28a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,28ZM12,18a6,6,0,1,1,6-6A6.0067,6.0067,0,0,1,12,18ZM4,16a11.97,11.97,0,0,1,.2112-2.1987,7.9921,7.9921,0,0,0,7.3459,6.1762,5.9581,5.9581,0,0,0-.89,6.7564A12.0025,12.0025,0,0,1,4,16ZM21.3325,26.7339a5.9834,5.9834,0,0,0-4.1782-8.6206,8.02,8.02,0,0,0,1.9126-2.3672,5.4883,5.4883,0,0,0,8.9167-.0679c.003.1079.0164.2134.0164.3218A12.0025,12.0025,0,0,1,21.3325,26.7339Z"
  })), children);
});
var CircleStrokeGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CircleStrokeGlyph(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,4A4,4,0,1,1,4,8,4.0045,4.0045,0,0,1,8,4M8,2a6,6,0,1,0,6,6A6,6,0,0,0,8,2Z"
  })), children);
});
var QCircuitComposer32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCircuitComposer32(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 9L18 15 14 15 14 9 12 9 12 23 14 23 14 17 18 17 18 23 20 23 20 9 18 9z"
  })), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H26V6a2,2,0,0,0-2-2H8A2,2,0,0,0,6,6v9H2v2H6v9a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V17h4ZM8,26V6H24V26Z"
  })), children);
});
var QCircuitComposer24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCircuitComposer24(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 9L18 15 14 15 14 9 12 9 12 23 14 23 14 17 18 17 18 23 20 23 20 9 18 9z"
  })), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H26V6a2,2,0,0,0-2-2H8A2,2,0,0,0,6,6v9H2v2H6v9a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V17h4ZM8,26V6H24V26Z"
  })), children);
});
var QCircuitComposer20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCircuitComposer20(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 9L18 15 14 15 14 9 12 9 12 23 14 23 14 17 18 17 18 23 20 23 20 9 18 9z"
  })), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H26V6a2,2,0,0,0-2-2H8A2,2,0,0,0,6,6v9H2v2H6v9a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V17h4ZM8,26V6H24V26Z"
  })), children);
});
var QCircuitComposer16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCircuitComposer16(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 9L18 15 14 15 14 9 12 9 12 23 14 23 14 17 18 17 18 23 20 23 20 9 18 9z"
  })), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H26V6a2,2,0,0,0-2-2H8A2,2,0,0,0,6,6v9H2v2H6v9a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V17h4ZM8,26V6H24V26Z"
  })), children);
});
var Classification32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Classification32(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "19",
    r: "1"
  })), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.7,9.3l-7-7A.9087.9087,0,0,0,20,2H10A2.0058,2.0058,0,0,0,8,4V14H6a2.0023,2.0023,0,0,0-2,2v6a2.0023,2.0023,0,0,0,2,2H8v4a2.0058,2.0058,0,0,0,2,2H26a2.0058,2.0058,0,0,0,2-2V10A.9092.9092,0,0,0,27.7,9.3ZM20,4.4,25.6,10H20ZM6,16h9.5972L19,19l-3.3926,3H6ZM26,28H10V24h5.6089a2.0076,2.0076,0,0,0,1.3135-.4927l3.3833-2.9917a2.0015,2.0015,0,0,0,.01-3.0229l-3.4033-3.0083A1.9961,1.9961,0,0,0,15.6089,14H10V4h8v6a2.0058,2.0058,0,0,0,2,2h6Z"
  })), children);
});
var Classification24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Classification24(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "19",
    r: "1"
  })), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.7,9.3l-7-7A.9087.9087,0,0,0,20,2H10A2.0058,2.0058,0,0,0,8,4V14H6a2.0023,2.0023,0,0,0-2,2v6a2.0023,2.0023,0,0,0,2,2H8v4a2.0058,2.0058,0,0,0,2,2H26a2.0058,2.0058,0,0,0,2-2V10A.9092.9092,0,0,0,27.7,9.3ZM20,4.4,25.6,10H20ZM6,16h9.5972L19,19l-3.3926,3H6ZM26,28H10V24h5.6089a2.0076,2.0076,0,0,0,1.3135-.4927l3.3833-2.9917a2.0015,2.0015,0,0,0,.01-3.0229l-3.4033-3.0083A1.9961,1.9961,0,0,0,15.6089,14H10V4h8v6a2.0058,2.0058,0,0,0,2,2h6Z"
  })), children);
});
var Classification20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Classification20(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "19",
    r: "1"
  })), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.7,9.3l-7-7A.9087.9087,0,0,0,20,2H10A2.0058,2.0058,0,0,0,8,4V14H6a2.0023,2.0023,0,0,0-2,2v6a2.0023,2.0023,0,0,0,2,2H8v4a2.0058,2.0058,0,0,0,2,2H26a2.0058,2.0058,0,0,0,2-2V10A.9092.9092,0,0,0,27.7,9.3ZM20,4.4,25.6,10H20ZM6,16h9.5972L19,19l-3.3926,3H6ZM26,28H10V24h5.6089a2.0076,2.0076,0,0,0,1.3135-.4927l3.3833-2.9917a2.0015,2.0015,0,0,0,.01-3.0229l-3.4033-3.0083A1.9961,1.9961,0,0,0,15.6089,14H10V4h8v6a2.0058,2.0058,0,0,0,2,2h6Z"
  })), children);
});
var Classification16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Classification16(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15",
    cy: "19",
    r: "1"
  })), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.7,9.3l-7-7A.9087.9087,0,0,0,20,2H10A2.0058,2.0058,0,0,0,8,4V14H6a2.0023,2.0023,0,0,0-2,2v6a2.0023,2.0023,0,0,0,2,2H8v4a2.0058,2.0058,0,0,0,2,2H26a2.0058,2.0058,0,0,0,2-2V10A.9092.9092,0,0,0,27.7,9.3ZM20,4.4,25.6,10H20ZM6,16h9.5972L19,19l-3.3926,3H6ZM26,28H10V24h5.6089a2.0076,2.0076,0,0,0,1.3135-.4927l3.3833-2.9917a2.0015,2.0015,0,0,0,.01-3.0229l-3.4033-3.0083A1.9961,1.9961,0,0,0,15.6089,14H10V4h8v6a2.0058,2.0058,0,0,0,2,2h6Z"
  })), children);
});
var ClassifierLanguage32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ClassifierLanguage32(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 10V2H22v8h3v4H23v2h7V14H27V10zM24 4h4V8H24zM20 23.41L18.59 22 16 24.59 13.41 22 12 23.41 14.59 26 12 28.59 13.41 30 16 27.41 18.59 30 20 28.59 17.41 26 20 23.41zM20 14L12 14 12 16 15 16 15 21 17 21 17 16 20 16 20 14zM7 9.86a4 4 0 10-2 0V14H2v2H9V14H7zM4 6A2 2 0 116 8 2 2 0 014 6z"
  })), children);
});
var ClassifierLanguage24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ClassifierLanguage24(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 10V2H22v8h3v4H23v2h7V14H27V10zM24 4h4V8H24zM20 23.41L18.59 22 16 24.59 13.41 22 12 23.41 14.59 26 12 28.59 13.41 30 16 27.41 18.59 30 20 28.59 17.41 26 20 23.41zM20 14L12 14 12 16 15 16 15 21 17 21 17 16 20 16 20 14zM7 9.86a4 4 0 10-2 0V14H2v2H9V14H7zM4 6A2 2 0 116 8 2 2 0 014 6z"
  })), children);
});
var ClassifierLanguage20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ClassifierLanguage20(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 10V2H22v8h3v4H23v2h7V14H27V10zM24 4h4V8H24zM20 23.41L18.59 22 16 24.59 13.41 22 12 23.41 14.59 26 12 28.59 13.41 30 16 27.41 18.59 30 20 28.59 17.41 26 20 23.41zM20 14L12 14 12 16 15 16 15 21 17 21 17 16 20 16 20 14zM7 9.86a4 4 0 10-2 0V14H2v2H9V14H7zM4 6A2 2 0 116 8 2 2 0 014 6z"
  })), children);
});
var ClassifierLanguage16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ClassifierLanguage16(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 10V2H22v8h3v4H23v2h7V14H27V10zM24 4h4V8H24zM20 23.41L18.59 22 16 24.59 13.41 22 12 23.41 14.59 26 12 28.59 13.41 30 16 27.41 18.59 30 20 28.59 17.41 26 20 23.41zM20 14L12 14 12 16 15 16 15 21 17 21 17 16 20 16 20 14zM7 9.86a4 4 0 10-2 0V14H2v2H9V14H7zM4 6A2 2 0 116 8 2 2 0 014 6z"
  })), children);
});
var Clean32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Clean32(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 18H26V20H20z",
    transform: "rotate(-180 23 19)"
  })), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 26H30V28H24z",
    transform: "rotate(-180 27 27)"
  })), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 22H28V24H22z",
    transform: "rotate(-180 25 23)"
  })), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.0029,20a4.8952,4.8952,0,0,0-2.4044-4.1729L22,3,20.2691,2,12.6933,15.126A5.6988,5.6988,0,0,0,7.45,16.6289C3.7064,20.24,3.9963,28.6821,4.01,29.04a1,1,0,0,0,1,.96H20.0012a1,1,0,0,0,.6-1.8C17.0615,25.5439,17.0029,20.0537,17.0029,20ZM11.93,16.9971A3.11,3.11,0,0,1,15.0041,20c0,.0381.0019.208.0168.4688L9.1215,17.8452A3.8,3.8,0,0,1,11.93,16.9971ZM15.4494,28A5.2,5.2,0,0,1,14,25H12a6.4993,6.4993,0,0,0,.9684,3H10.7451A16.6166,16.6166,0,0,1,10,24H8a17.3424,17.3424,0,0,0,.6652,4H6c.031-1.8364.29-5.8921,1.8027-8.5527l7.533,3.35A13.0253,13.0253,0,0,0,17.5968,28Z"
  })), children);
});
var Clean24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Clean24(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 18H26V20H20z",
    transform: "rotate(-180 23 19)"
  })), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 26H30V28H24z",
    transform: "rotate(-180 27 27)"
  })), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 22H28V24H22z",
    transform: "rotate(-180 25 23)"
  })), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.0029,20a4.8952,4.8952,0,0,0-2.4044-4.1729L22,3,20.2691,2,12.6933,15.126A5.6988,5.6988,0,0,0,7.45,16.6289C3.7064,20.24,3.9963,28.6821,4.01,29.04a1,1,0,0,0,1,.96H20.0012a1,1,0,0,0,.6-1.8C17.0615,25.5439,17.0029,20.0537,17.0029,20ZM11.93,16.9971A3.11,3.11,0,0,1,15.0041,20c0,.0381.0019.208.0168.4688L9.1215,17.8452A3.8,3.8,0,0,1,11.93,16.9971ZM15.4494,28A5.2,5.2,0,0,1,14,25H12a6.4993,6.4993,0,0,0,.9684,3H10.7451A16.6166,16.6166,0,0,1,10,24H8a17.3424,17.3424,0,0,0,.6652,4H6c.031-1.8364.29-5.8921,1.8027-8.5527l7.533,3.35A13.0253,13.0253,0,0,0,17.5968,28Z"
  })), children);
});
var Clean20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Clean20(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 18H26V20H20z",
    transform: "rotate(-180 23 19)"
  })), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 26H30V28H24z",
    transform: "rotate(-180 27 27)"
  })), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 22H28V24H22z",
    transform: "rotate(-180 25 23)"
  })), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.0029,20a4.8952,4.8952,0,0,0-2.4044-4.1729L22,3,20.2691,2,12.6933,15.126A5.6988,5.6988,0,0,0,7.45,16.6289C3.7064,20.24,3.9963,28.6821,4.01,29.04a1,1,0,0,0,1,.96H20.0012a1,1,0,0,0,.6-1.8C17.0615,25.5439,17.0029,20.0537,17.0029,20ZM11.93,16.9971A3.11,3.11,0,0,1,15.0041,20c0,.0381.0019.208.0168.4688L9.1215,17.8452A3.8,3.8,0,0,1,11.93,16.9971ZM15.4494,28A5.2,5.2,0,0,1,14,25H12a6.4993,6.4993,0,0,0,.9684,3H10.7451A16.6166,16.6166,0,0,1,10,24H8a17.3424,17.3424,0,0,0,.6652,4H6c.031-1.8364.29-5.8921,1.8027-8.5527l7.533,3.35A13.0253,13.0253,0,0,0,17.5968,28Z"
  })), children);
});
var Clean16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Clean16(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 18H26V20H20z",
    transform: "rotate(-180 23 19)"
  })), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 26H30V28H24z",
    transform: "rotate(-180 27 27)"
  })), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 22H28V24H22z",
    transform: "rotate(-180 25 23)"
  })), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.0029,20a4.8952,4.8952,0,0,0-2.4044-4.1729L22,3,20.2691,2,12.6933,15.126A5.6988,5.6988,0,0,0,7.45,16.6289C3.7064,20.24,3.9963,28.6821,4.01,29.04a1,1,0,0,0,1,.96H20.0012a1,1,0,0,0,.6-1.8C17.0615,25.5439,17.0029,20.0537,17.0029,20ZM11.93,16.9971A3.11,3.11,0,0,1,15.0041,20c0,.0381.0019.208.0168.4688L9.1215,17.8452A3.8,3.8,0,0,1,11.93,16.9971ZM15.4494,28A5.2,5.2,0,0,1,14,25H12a6.4993,6.4993,0,0,0,.9684,3H10.7451A16.6166,16.6166,0,0,1,10,24H8a17.3424,17.3424,0,0,0,.6652,4H6c.031-1.8364.29-5.8921,1.8027-8.5527l7.533,3.35A13.0253,13.0253,0,0,0,17.5968,28Z"
  })), children);
});
var Close32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Close32(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 9.4L22.6 8 16 14.6 9.4 8 8 9.4 14.6 16 8 22.6 9.4 24 16 17.4 22.6 24 24 22.6 17.4 16 24 9.4z"
  })), children);
});
var Close24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Close24(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 9.4L22.6 8 16 14.6 9.4 8 8 9.4 14.6 16 8 22.6 9.4 24 16 17.4 22.6 24 24 22.6 17.4 16 24 9.4z"
  })), children);
});
var Close20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Close20(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 9.4L22.6 8 16 14.6 9.4 8 8 9.4 14.6 16 8 22.6 9.4 24 16 17.4 22.6 24 24 22.6 17.4 16 24 9.4z"
  })), children);
});
var Close16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Close16(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 9.4L22.6 8 16 14.6 9.4 8 8 9.4 14.6 16 8 22.6 9.4 24 16 17.4 22.6 24 24 22.6 17.4 16 24 9.4z"
  })), children);
});
var CloseFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloseFilled32(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2C8.2,2,2,8.2,2,16s6.2,14,14,14s14-6.2,14-14S23.8,2,16,2z M21.4,23L16,17.6L10.6,23L9,21.4l5.4-5.4L9,10.6L10.6,9\tl5.4,5.4L21.4,9l1.6,1.6L17.6,16l5.4,5.4L21.4,23z"
  })), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.4 16L9 10.6 10.6 9 16 14.4 21.4 9 23 10.6 17.6 16 23 21.4 21.4 23 16 17.6 10.6 23 9 21.4 14.4 16",
    "data-icon-path": "inner-path",
    opacity: "0"
  })), children);
});
var CloseFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloseFilled24(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2C8.2,2,2,8.2,2,16s6.2,14,14,14s14-6.2,14-14S23.8,2,16,2z M21.4,23L16,17.6L10.6,23L9,21.4l5.4-5.4L9,10.6L10.6,9\tl5.4,5.4L21.4,9l1.6,1.6L17.6,16l5.4,5.4L21.4,23z"
  })), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.4 16L9 10.6 10.6 9 16 14.4 21.4 9 23 10.6 17.6 16 23 21.4 21.4 23 16 17.6 10.6 23 9 21.4 14.4 16",
    "data-icon-path": "inner-path",
    opacity: "0"
  })), children);
});
var CloseFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloseFilled20(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2C8.2,2,2,8.2,2,16s6.2,14,14,14s14-6.2,14-14S23.8,2,16,2z M21.4,23L16,17.6L10.6,23L9,21.4l5.4-5.4L9,10.6L10.6,9\tl5.4,5.4L21.4,9l1.6,1.6L17.6,16l5.4,5.4L21.4,23z"
  })), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14.4 16L9 10.6 10.6 9 16 14.4 21.4 9 23 10.6 17.6 16 23 21.4 21.4 23 16 17.6 10.6 23 9 21.4 14.4 16",
    "data-icon-path": "inner-path",
    opacity: "0"
  })), children);
});
var CloseFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloseFilled16(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8,1C4.1,1,1,4.1,1,8s3.1,7,7,7s7-3.1,7-7S11.9,1,8,1z M10.7,11.5L8,8.8l-2.7,2.7l-0.8-0.8L7.2,8L4.5,5.3l0.8-0.8L8,7.2\tl2.7-2.7l0.8,0.8L8.8,8l2.7,2.7L10.7,11.5z"
  })), children);
});
var CloseOutline32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloseOutline32(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2C8.2,2,2,8.2,2,16s6.2,14,14,14s14-6.2,14-14S23.8,2,16,2z M16,28C9.4,28,4,22.6,4,16S9.4,4,16,4s12,5.4,12,12\tS22.6,28,16,28z"
  })), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4 23L16 17.6 10.6 23 9 21.4 14.4 16 9 10.6 10.6 9 16 14.4 21.4 9 23 10.6 17.6 16 23 21.4z"
  })), children);
});
var CloseOutline24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloseOutline24(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2C8.2,2,2,8.2,2,16s6.2,14,14,14s14-6.2,14-14S23.8,2,16,2z M16,28C9.4,28,4,22.6,4,16S9.4,4,16,4s12,5.4,12,12\tS22.6,28,16,28z"
  })), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4 23L16 17.6 10.6 23 9 21.4 14.4 16 9 10.6 10.6 9 16 14.4 21.4 9 23 10.6 17.6 16 23 21.4z"
  })), children);
});
var CloseOutline20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloseOutline20(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2C8.2,2,2,8.2,2,16s6.2,14,14,14s14-6.2,14-14S23.8,2,16,2z M16,28C9.4,28,4,22.6,4,16S9.4,4,16,4s12,5.4,12,12\tS22.6,28,16,28z"
  })), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4 23L16 17.6 10.6 23 9 21.4 14.4 16 9 10.6 10.6 9 16 14.4 21.4 9 23 10.6 17.6 16 23 21.4z"
  })), children);
});
var CloseOutline16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloseOutline16(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2C8.2,2,2,8.2,2,16s6.2,14,14,14s14-6.2,14-14S23.8,2,16,2z M16,28C9.4,28,4,22.6,4,16S9.4,4,16,4s12,5.4,12,12\tS22.6,28,16,28z"
  })), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4 23L16 17.6 10.6 23 9 21.4 14.4 16 9 10.6 10.6 9 16 14.4 21.4 9 23 10.6 17.6 16 23 21.4z"
  })), children);
});
var ClosedCaption32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ClosedCaption32(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 21H10a2 2 0 01-2-2V13a2 2 0 012-2h5v2H10v6h5zM25 21H20a2 2 0 01-2-2V13a2 2 0 012-2h5v2H20v6h5z"
  })), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H4a2,2,0,0,1-2-2V8A2,2,0,0,1,4,6H28a2,2,0,0,1,2,2V24A2,2,0,0,1,28,26ZM4,8V24H28V8Z"
  })), children);
});
var ClosedCaption24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ClosedCaption24(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 21H10a2 2 0 01-2-2V13a2 2 0 012-2h5v2H10v6h5zM25 21H20a2 2 0 01-2-2V13a2 2 0 012-2h5v2H20v6h5z"
  })), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H4a2,2,0,0,1-2-2V8A2,2,0,0,1,4,6H28a2,2,0,0,1,2,2V24A2,2,0,0,1,28,26ZM4,8V24H28V8Z"
  })), children);
});
var ClosedCaption20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ClosedCaption20(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 21H10a2 2 0 01-2-2V13a2 2 0 012-2h5v2H10v6h5zM25 21H20a2 2 0 01-2-2V13a2 2 0 012-2h5v2H20v6h5z"
  })), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H4a2,2,0,0,1-2-2V8A2,2,0,0,1,4,6H28a2,2,0,0,1,2,2V24A2,2,0,0,1,28,26ZM4,8V24H28V8Z"
  })), children);
});
var ClosedCaption16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ClosedCaption16(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 21H10a2 2 0 01-2-2V13a2 2 0 012-2h5v2H10v6h5zM25 21H20a2 2 0 01-2-2V13a2 2 0 012-2h5v2H20v6h5z"
  })), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H4a2,2,0,0,1-2-2V8A2,2,0,0,1,4,6H28a2,2,0,0,1,2,2V24A2,2,0,0,1,28,26ZM4,8V24H28V8Z"
  })), children);
});
var ClosedCaptionAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ClosedCaptionAlt32(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 17H25V19H19zM11 17H17V19H11zM6 17H9V19H6zM22 13H26V15H22zM13 13H20V15H13zM6 13H11V15H6z"
  })), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V8a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,8V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V8A3.9988,3.9988,0,0,1,6,4H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var ClosedCaptionAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ClosedCaptionAlt24(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 17H25V19H19zM11 17H17V19H11zM6 17H9V19H6zM22 13H26V15H22zM13 13H20V15H13zM6 13H11V15H6z"
  })), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V8a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,8V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V8A3.9988,3.9988,0,0,1,6,4H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var ClosedCaptionAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ClosedCaptionAlt20(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 17H25V19H19zM11 17H17V19H11zM6 17H9V19H6zM22 13H26V15H22zM13 13H20V15H13zM6 13H11V15H6z"
  })), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V8a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,8V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V8A3.9988,3.9988,0,0,1,6,4H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var ClosedCaptionAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ClosedCaptionAlt16(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 17H25V19H19zM11 17H17V19H11zM6 17H9V19H6zM22 13H26V15H22zM13 13H20V15H13zM6 13H11V15H6z"
  })), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.7358,30,16,29l4-7h6a1.9966,1.9966,0,0,0,2-2V8a1.9966,1.9966,0,0,0-2-2H6A1.9966,1.9966,0,0,0,4,8V20a1.9966,1.9966,0,0,0,2,2h9v2H6a3.9993,3.9993,0,0,1-4-4V8A3.9988,3.9988,0,0,1,6,4H26a3.9988,3.9988,0,0,1,4,4V20a3.9993,3.9993,0,0,1-4,4H21.1646Z"
  })), children);
});
var ClosedCaptionFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ClosedCaptionFilled32(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM15,13H10v6h5v2H10a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h5Zm10,0H20v6h5v2H20a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h5Z"
  })), children);
});
var ClosedCaptionFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ClosedCaptionFilled24(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM15,13H10v6h5v2H10a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h5Zm10,0H20v6h5v2H20a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h5Z"
  })), children);
});
var ClosedCaptionFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ClosedCaptionFilled20(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM15,13H10v6h5v2H10a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h5Zm10,0H20v6h5v2H20a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h5Z"
  })), children);
});
var ClosedCaptionFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ClosedCaptionFilled16(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2,2,0,0,0,2,8V24a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM15,13H10v6h5v2H10a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h5Zm10,0H20v6h5v2H20a2,2,0,0,1-2-2V13a2,2,0,0,1,2-2h5Z"
  })), children);
});
var Cloud32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cloud32(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7h0a7.66,7.66,0,0,1,1.51.15,8,8,0,0,1,6.35,6.34l.26,1.35,1.35.24a5.5,5.5,0,0,1-1,10.92H7.5a5.5,5.5,0,0,1-1-10.92l1.34-.24.26-1.35A8,8,0,0,1,16,7m0-2a10,10,0,0,0-9.83,8.12A7.5,7.5,0,0,0,7.49,28h17a7.5,7.5,0,0,0,1.32-14.88,10,10,0,0,0-7.94-7.94A10.27,10.27,0,0,0,16,5Z"
  })), children);
});
var Cloud24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cloud24(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7h0a7.66,7.66,0,0,1,1.51.15,8,8,0,0,1,6.35,6.34l.26,1.35,1.35.24a5.5,5.5,0,0,1-1,10.92H7.5a5.5,5.5,0,0,1-1-10.92l1.34-.24.26-1.35A8,8,0,0,1,16,7m0-2a10,10,0,0,0-9.83,8.12A7.5,7.5,0,0,0,7.49,28h17a7.5,7.5,0,0,0,1.32-14.88,10,10,0,0,0-7.94-7.94A10.27,10.27,0,0,0,16,5Z"
  })), children);
});
var Cloud20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cloud20(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7h0a7.66,7.66,0,0,1,1.51.15,8,8,0,0,1,6.35,6.34l.26,1.35,1.35.24a5.5,5.5,0,0,1-1,10.92H7.5a5.5,5.5,0,0,1-1-10.92l1.34-.24.26-1.35A8,8,0,0,1,16,7m0-2a10,10,0,0,0-9.83,8.12A7.5,7.5,0,0,0,7.49,28h17a7.5,7.5,0,0,0,1.32-14.88,10,10,0,0,0-7.94-7.94A10.27,10.27,0,0,0,16,5Z"
  })), children);
});
var Cloud16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cloud16(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7h0a7.66,7.66,0,0,1,1.51.15,8,8,0,0,1,6.35,6.34l.26,1.35,1.35.24a5.5,5.5,0,0,1-1,10.92H7.5a5.5,5.5,0,0,1-1-10.92l1.34-.24.26-1.35A8,8,0,0,1,16,7m0-2a10,10,0,0,0-9.83,8.12A7.5,7.5,0,0,0,7.49,28h17a7.5,7.5,0,0,0,1.32-14.88,10,10,0,0,0-7.94-7.94A10.27,10.27,0,0,0,16,5Z"
  })), children);
});
var CloudAlerting32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudAlerting32(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,17v5H4V6H15V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V17ZM18,28H14V24h4Z"
  })), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,14H17a1,1,0,0,1-.8574-1.5144l6-10a1,1,0,0,1,1.7154,0l6,10A1,1,0,0,1,29,14ZM18.7661,12h8.4678L23,4.9436Z"
  })), children);
});
var CloudAlerting24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudAlerting24(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,17v5H4V6H15V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V17ZM18,28H14V24h4Z"
  })), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,14H17a1,1,0,0,1-.8574-1.5144l6-10a1,1,0,0,1,1.7154,0l6,10A1,1,0,0,1,29,14ZM18.7661,12h8.4678L23,4.9436Z"
  })), children);
});
var CloudAlerting20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudAlerting20(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,17v5H4V6H15V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V17ZM18,28H14V24h4Z"
  })), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,14H17a1,1,0,0,1-.8574-1.5144l6-10a1,1,0,0,1,1.7154,0l6,10A1,1,0,0,1,29,14ZM18.7661,12h8.4678L23,4.9436Z"
  })), children);
});
var CloudAlerting16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudAlerting16(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,17v5H4V6H15V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V17ZM18,28H14V24h4Z"
  })), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,14H17a1,1,0,0,1-.8574-1.5144l6-10a1,1,0,0,1,1.7154,0l6,10A1,1,0,0,1,29,14ZM18.7661,12h8.4678L23,4.9436Z"
  })), children);
});
var CloudAuditing32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudAuditing32(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16v6H4V6H16V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V16ZM18,28H14V24h4Z"
  })), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 15L16 10.04 17.59 8.47 21 11.85 28.41 4.5 30 6.08 21 15z"
  })), children);
});
var CloudAuditing24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudAuditing24(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16v6H4V6H16V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V16ZM18,28H14V24h4Z"
  })), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 15L16 10.04 17.59 8.47 21 11.85 28.41 4.5 30 6.08 21 15z"
  })), children);
});
var CloudAuditing20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudAuditing20(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16v6H4V6H16V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V16ZM18,28H14V24h4Z"
  })), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 15L16 10.04 17.59 8.47 21 11.85 28.41 4.5 30 6.08 21 15z"
  })), children);
});
var CloudAuditing16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudAuditing16(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16v6H4V6H16V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V16ZM18,28H14V24h4Z"
  })), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 15L16 10.04 17.59 8.47 21 11.85 28.41 4.5 30 6.08 21 15z"
  })), children);
});
var CloudDataOps32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudDataOps32(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 18H30V28H28zM24 14H26V28H24zM20 22H22V28H20zM22.175 10L23.76 8.7339A9.9522 9.9522 0 0017.89 5.1816 10.0025 10.0025 0 006.17 13.1152 7.5054 7.5054 0 00.0544 21.4087 7.6843 7.6843 0 007.7692 28H16V26H7.6945a5.632 5.632 0 01-5.6023-4.4858 5.5064 5.5064 0 014.4339-6.4307l1.3486-.2441.2139-1.11a8.206 8.206 0 016.7426-6.6426 7.9666 7.9666 0 013.0137.13A7.8037 7.8037 0 0122.175 10z"
  })), children);
});
var CloudDataOps24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudDataOps24(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 18H30V28H28zM24 14H26V28H24zM20 22H22V28H20zM22.175 10L23.76 8.7339A9.9522 9.9522 0 0017.89 5.1816 10.0025 10.0025 0 006.17 13.1152 7.5054 7.5054 0 00.0544 21.4087 7.6843 7.6843 0 007.7692 28H16V26H7.6945a5.632 5.632 0 01-5.6023-4.4858 5.5064 5.5064 0 014.4339-6.4307l1.3486-.2441.2139-1.11a8.206 8.206 0 016.7426-6.6426 7.9666 7.9666 0 013.0137.13A7.8037 7.8037 0 0122.175 10z"
  })), children);
});
var CloudDataOps20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudDataOps20(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 18H30V28H28zM24 14H26V28H24zM20 22H22V28H20zM22.175 10L23.76 8.7339A9.9522 9.9522 0 0017.89 5.1816 10.0025 10.0025 0 006.17 13.1152 7.5054 7.5054 0 00.0544 21.4087 7.6843 7.6843 0 007.7692 28H16V26H7.6945a5.632 5.632 0 01-5.6023-4.4858 5.5064 5.5064 0 014.4339-6.4307l1.3486-.2441.2139-1.11a8.206 8.206 0 016.7426-6.6426 7.9666 7.9666 0 013.0137.13A7.8037 7.8037 0 0122.175 10z"
  })), children);
});
var CloudDataOps16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudDataOps16(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 18H30V28H28zM24 14H26V28H24zM20 22H22V28H20zM22.175 10L23.76 8.7339A9.9522 9.9522 0 0017.89 5.1816 10.0025 10.0025 0 006.17 13.1152 7.5054 7.5054 0 00.0544 21.4087 7.6843 7.6843 0 007.7692 28H16V26H7.6945a5.632 5.632 0 01-5.6023-4.4858 5.5064 5.5064 0 014.4339-6.4307l1.3486-.2441.2139-1.11a8.206 8.206 0 016.7426-6.6426 7.9666 7.9666 0 013.0137.13A7.8037 7.8037 0 0122.175 10z"
  })), children);
});
var CloudDownload32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudDownload32(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,22H23V20h.5a4.5,4.5,0,0,0,.36-9L23,11l-.1-.82a7,7,0,0,0-13.88,0L9,11,8.14,11a4.5,4.5,0,0,0,.36,9H9v2H8.5A6.5,6.5,0,0,1,7.2,9.14a9,9,0,0,1,17.6,0A6.5,6.5,0,0,1,23.5,22Z"
  })), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 26.17L17 14 15 14 15 26.17 12.41 23.59 11 25 16 30 21 25 19.59 23.59 17 26.17z"
  })), children);
});
var CloudDownload24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudDownload24(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,22H23V20h.5a4.5,4.5,0,0,0,.36-9L23,11l-.1-.82a7,7,0,0,0-13.88,0L9,11,8.14,11a4.5,4.5,0,0,0,.36,9H9v2H8.5A6.5,6.5,0,0,1,7.2,9.14a9,9,0,0,1,17.6,0A6.5,6.5,0,0,1,23.5,22Z"
  })), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 26.17L17 14 15 14 15 26.17 12.41 23.59 11 25 16 30 21 25 19.59 23.59 17 26.17z"
  })), children);
});
var CloudDownload20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudDownload20(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,22H23V20h.5a4.5,4.5,0,0,0,.36-9L23,11l-.1-.82a7,7,0,0,0-13.88,0L9,11,8.14,11a4.5,4.5,0,0,0,.36,9H9v2H8.5A6.5,6.5,0,0,1,7.2,9.14a9,9,0,0,1,17.6,0A6.5,6.5,0,0,1,23.5,22Z"
  })), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 26.17L17 14 15 14 15 26.17 12.41 23.59 11 25 16 30 21 25 19.59 23.59 17 26.17z"
  })), children);
});
var CloudDownload16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudDownload16(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,22H23V20h.5a4.5,4.5,0,0,0,.36-9L23,11l-.1-.82a7,7,0,0,0-13.88,0L9,11,8.14,11a4.5,4.5,0,0,0,.36,9H9v2H8.5A6.5,6.5,0,0,1,7.2,9.14a9,9,0,0,1,17.6,0A6.5,6.5,0,0,1,23.5,22Z"
  })), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 26.17L17 14 15 14 15 26.17 12.41 23.59 11 25 16 30 21 25 19.59 23.59 17 26.17z"
  })), children);
});
var CloudLightning32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudLightning32(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  if (true) {
    if (!didWarnAboutDeprecation['CloudLightning32']) {
      didWarnAboutDeprecation['CloudLightning32'] = true;
      console.warn("The CloudLightning32 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.61,29.92a1,1,0,0,1-.6-1.07L12.83,17H8a1,1,0,0,1-1-1.23l3-13A1,1,0,0,1,11,2H21a1,1,0,0,1,.78.37,1,1,0,0,1,.2.85L20.25,11H25a1,1,0,0,1,.9.56,1,1,0,0,1-.11,1l-13,17A1,1,0,0,1,12,30,1.09,1.09,0,0,1,11.61,29.92ZM17.75,13l2-9H11.8L9.26,15h5.91L13.58,25.28,23,13Z"
  })), children);
});
var CloudLightning24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudLightning24(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  if (true) {
    if (!didWarnAboutDeprecation['CloudLightning24']) {
      didWarnAboutDeprecation['CloudLightning24'] = true;
      console.warn("The CloudLightning24 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.61,29.92a1,1,0,0,1-.6-1.07L12.83,17H8a1,1,0,0,1-1-1.23l3-13A1,1,0,0,1,11,2H21a1,1,0,0,1,.78.37,1,1,0,0,1,.2.85L20.25,11H25a1,1,0,0,1,.9.56,1,1,0,0,1-.11,1l-13,17A1,1,0,0,1,12,30,1.09,1.09,0,0,1,11.61,29.92ZM17.75,13l2-9H11.8L9.26,15h5.91L13.58,25.28,23,13Z"
  })), children);
});
var CloudLightning20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudLightning20(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  if (true) {
    if (!didWarnAboutDeprecation['CloudLightning20']) {
      didWarnAboutDeprecation['CloudLightning20'] = true;
      console.warn("The CloudLightning20 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.61,29.92a1,1,0,0,1-.6-1.07L12.83,17H8a1,1,0,0,1-1-1.23l3-13A1,1,0,0,1,11,2H21a1,1,0,0,1,.78.37,1,1,0,0,1,.2.85L20.25,11H25a1,1,0,0,1,.9.56,1,1,0,0,1-.11,1l-13,17A1,1,0,0,1,12,30,1.09,1.09,0,0,1,11.61,29.92ZM17.75,13l2-9H11.8L9.26,15h5.91L13.58,25.28,23,13Z"
  })), children);
});
var CloudLightning16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudLightning16(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  if (true) {
    if (!didWarnAboutDeprecation['CloudLightning16']) {
      didWarnAboutDeprecation['CloudLightning16'] = true;
      console.warn("The CloudLightning16 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.61,29.92a1,1,0,0,1-.6-1.07L12.83,17H8a1,1,0,0,1-1-1.23l3-13A1,1,0,0,1,11,2H21a1,1,0,0,1,.78.37,1,1,0,0,1,.2.85L20.25,11H25a1,1,0,0,1,.9.56,1,1,0,0,1-.11,1l-13,17A1,1,0,0,1,12,30,1.09,1.09,0,0,1,11.61,29.92ZM17.75,13l2-9H11.8L9.26,15h5.91L13.58,25.28,23,13Z"
  })), children);
});
var CloudLogging32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudLogging32(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 16v6H4V6H15V4H4A2 2 0 002 6V22a2 2 0 002 2h8v4H8v2H24V28H20V24h8a2 2 0 002-2V16zM18 28H14V24h4zM18 4H30V6H18z"
  })), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 8H30V10H18zM18 12H24V14H18z"
  })), children);
});
var CloudLogging24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudLogging24(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 16v6H4V6H15V4H4A2 2 0 002 6V22a2 2 0 002 2h8v4H8v2H24V28H20V24h8a2 2 0 002-2V16zM18 28H14V24h4zM18 4H30V6H18z"
  })), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 8H30V10H18zM18 12H24V14H18z"
  })), children);
});
var CloudLogging20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudLogging20(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 16v6H4V6H15V4H4A2 2 0 002 6V22a2 2 0 002 2h8v4H8v2H24V28H20V24h8a2 2 0 002-2V16zM18 28H14V24h4zM18 4H30V6H18z"
  })), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 8H30V10H18zM18 12H24V14H18z"
  })), children);
});
var CloudLogging16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudLogging16(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 16v6H4V6H15V4H4A2 2 0 002 6V22a2 2 0 002 2h8v4H8v2H24V28H20V24h8a2 2 0 002-2V16zM18 28H14V24h4zM18 4H30V6H18z"
  })), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 8H30V10H18zM18 12H24V14H18z"
  })), children);
});
var CloudMonitoring32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudMonitoring32(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16v6H4V6h7V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V16ZM18,28H14V24h4Z"
  })), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,18h-.01a1,1,0,0,1-.9511-.7253L15.2456,11H11V9h5a1,1,0,0,1,.9615.7252l1.0742,3.7589,3.0088-9.7783A1.0142,1.0142,0,0,1,22,3a.98.98,0,0,1,.9487.6838L24.7207,9H30v2H24a1,1,0,0,1-.9487-.6838l-1.0132-3.04L18.9556,17.2942A1,1,0,0,1,18,18Z"
  })), children);
});
var CloudMonitoring24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudMonitoring24(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16v6H4V6h7V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V16ZM18,28H14V24h4Z"
  })), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,18h-.01a1,1,0,0,1-.9511-.7253L15.2456,11H11V9h5a1,1,0,0,1,.9615.7252l1.0742,3.7589,3.0088-9.7783A1.0142,1.0142,0,0,1,22,3a.98.98,0,0,1,.9487.6838L24.7207,9H30v2H24a1,1,0,0,1-.9487-.6838l-1.0132-3.04L18.9556,17.2942A1,1,0,0,1,18,18Z"
  })), children);
});
var CloudMonitoring20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudMonitoring20(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16v6H4V6h7V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V16ZM18,28H14V24h4Z"
  })), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,18h-.01a1,1,0,0,1-.9511-.7253L15.2456,11H11V9h5a1,1,0,0,1,.9615.7252l1.0742,3.7589,3.0088-9.7783A1.0142,1.0142,0,0,1,22,3a.98.98,0,0,1,.9487.6838L24.7207,9H30v2H24a1,1,0,0,1-.9487-.6838l-1.0132-3.04L18.9556,17.2942A1,1,0,0,1,18,18Z"
  })), children);
});
var CloudMonitoring16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudMonitoring16(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,16v6H4V6h7V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V16ZM18,28H14V24h4Z"
  })), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,18h-.01a1,1,0,0,1-.9511-.7253L15.2456,11H11V9h5a1,1,0,0,1,.9615.7252l1.0742,3.7589,3.0088-9.7783A1.0142,1.0142,0,0,1,22,3a.98.98,0,0,1,.9487.6838L24.7207,9H30v2H24a1,1,0,0,1-.9487-.6838l-1.0132-3.04L18.9556,17.2942A1,1,0,0,1,18,18Z"
  })), children);
});
var CloudOffline32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudOffline32(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008 12.1362a8.8694 8.8694 0 00-.9795-2.5434L30 3.4142 28.5872 2 2 28.5872 3.4142 30l5-5H23.5a6.4974 6.4974 0 001.3008-12.8638zM23.5 23H10.4141L22.3418 11.0723a6.9049 6.9049 0 01.6006 2.0708l.0986.812.8154.0639A4.4975 4.4975 0 0123.5 23zM4.2964 23.4487l1.4313-1.4311A4.4774 4.4774 0 018.144 14.019l.8155-.0639.0991-.812a6.9867 6.9867 0 0110.63-5.0865l1.4431-1.4428A8.9859 8.9859 0 007.2 12.1362 6.4891 6.4891 0 004.2964 23.4487z"
  })), children);
});
var CloudOffline24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudOffline24(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008 12.1362a8.8694 8.8694 0 00-.9795-2.5434L30 3.4142 28.5872 2 2 28.5872 3.4142 30l5-5H23.5a6.4974 6.4974 0 001.3008-12.8638zM23.5 23H10.4141L22.3418 11.0723a6.9049 6.9049 0 01.6006 2.0708l.0986.812.8154.0639A4.4975 4.4975 0 0123.5 23zM4.2964 23.4487l1.4313-1.4311A4.4774 4.4774 0 018.144 14.019l.8155-.0639.0991-.812a6.9867 6.9867 0 0110.63-5.0865l1.4431-1.4428A8.9859 8.9859 0 007.2 12.1362 6.4891 6.4891 0 004.2964 23.4487z"
  })), children);
});
var CloudOffline20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudOffline20(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008 12.1362a8.8694 8.8694 0 00-.9795-2.5434L30 3.4142 28.5872 2 2 28.5872 3.4142 30l5-5H23.5a6.4974 6.4974 0 001.3008-12.8638zM23.5 23H10.4141L22.3418 11.0723a6.9049 6.9049 0 01.6006 2.0708l.0986.812.8154.0639A4.4975 4.4975 0 0123.5 23zM4.2964 23.4487l1.4313-1.4311A4.4774 4.4774 0 018.144 14.019l.8155-.0639.0991-.812a6.9867 6.9867 0 0110.63-5.0865l1.4431-1.4428A8.9859 8.9859 0 007.2 12.1362 6.4891 6.4891 0 004.2964 23.4487z"
  })), children);
});
var CloudOffline16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudOffline16(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.8008 12.1362a8.8694 8.8694 0 00-.9795-2.5434L30 3.4142 28.5872 2 2 28.5872 3.4142 30l5-5H23.5a6.4974 6.4974 0 001.3008-12.8638zM23.5 23H10.4141L22.3418 11.0723a6.9049 6.9049 0 01.6006 2.0708l.0986.812.8154.0639A4.4975 4.4975 0 0123.5 23zM4.2964 23.4487l1.4313-1.4311A4.4774 4.4774 0 018.144 14.019l.8155-.0639.0991-.812a6.9867 6.9867 0 0110.63-5.0865l1.4431-1.4428A8.9859 8.9859 0 007.2 12.1362 6.4891 6.4891 0 004.2964 23.4487z"
  })), children);
});
var CloudRain32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudRain32(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  if (true) {
    if (!didWarnAboutDeprecation['CloudRain32']) {
      didWarnAboutDeprecation['CloudRain32'] = true;
      console.warn("The CloudRain32 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 22H8.5A6.5 6.5 0 017.2 9.14a9 9 0 0117.6 0A6.5 6.5 0 0123.5 22zM16 4a7 7 0 00-6.94 6.14L9 11 8.14 11a4.5 4.5 0 00.36 9h15a4.5 4.5 0 00.36-9L23 11l-.1-.82A7 7 0 0016 4zM14 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 0114 30zM20 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 0120 30zM8 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 018 30z"
  })), children);
});
var CloudRain24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudRain24(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  if (true) {
    if (!didWarnAboutDeprecation['CloudRain24']) {
      didWarnAboutDeprecation['CloudRain24'] = true;
      console.warn("The CloudRain24 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 22H8.5A6.5 6.5 0 017.2 9.14a9 9 0 0117.6 0A6.5 6.5 0 0123.5 22zM16 4a7 7 0 00-6.94 6.14L9 11 8.14 11a4.5 4.5 0 00.36 9h15a4.5 4.5 0 00.36-9L23 11l-.1-.82A7 7 0 0016 4zM14 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 0114 30zM20 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 0120 30zM8 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 018 30z"
  })), children);
});
var CloudRain20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudRain20(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  if (true) {
    if (!didWarnAboutDeprecation['CloudRain20']) {
      didWarnAboutDeprecation['CloudRain20'] = true;
      console.warn("The CloudRain20 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 22H8.5A6.5 6.5 0 017.2 9.14a9 9 0 0117.6 0A6.5 6.5 0 0123.5 22zM16 4a7 7 0 00-6.94 6.14L9 11 8.14 11a4.5 4.5 0 00.36 9h15a4.5 4.5 0 00.36-9L23 11l-.1-.82A7 7 0 0016 4zM14 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 0114 30zM20 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 0120 30zM8 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 018 30z"
  })), children);
});
var CloudRain16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudRain16(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  if (true) {
    if (!didWarnAboutDeprecation['CloudRain16']) {
      didWarnAboutDeprecation['CloudRain16'] = true;
      console.warn("The CloudRain16 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 22H8.5A6.5 6.5 0 017.2 9.14a9 9 0 0117.6 0A6.5 6.5 0 0123.5 22zM16 4a7 7 0 00-6.94 6.14L9 11 8.14 11a4.5 4.5 0 00.36 9h15a4.5 4.5 0 00.36-9L23 11l-.1-.82A7 7 0 0016 4zM14 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 0114 30zM20 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 0120 30zM8 30a.93.93 0 01-.45-.11 1 1 0 01-.44-1.34l2-4a1 1 0 111.78.9l-2 4A1 1 0 018 30z"
  })), children);
});
var CloudServiceManagement32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudServiceManagement32(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,17v5H4V6H14V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V17ZM18,28H14V24h4Z"
  })), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10V8H27.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,24,4.1011V2H22V4.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,18.1011,8H16v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,22,13.8989V16h2V13.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,27.8989,10Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,23,12Z"
  })), children);
});
var CloudServiceManagement24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudServiceManagement24(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,17v5H4V6H14V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V17ZM18,28H14V24h4Z"
  })), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10V8H27.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,24,4.1011V2H22V4.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,18.1011,8H16v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,22,13.8989V16h2V13.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,27.8989,10Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,23,12Z"
  })), children);
});
var CloudServiceManagement20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudServiceManagement20(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,17v5H4V6H14V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V17ZM18,28H14V24h4Z"
  })), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10V8H27.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,24,4.1011V2H22V4.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,18.1011,8H16v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,22,13.8989V16h2V13.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,27.8989,10Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,23,12Z"
  })), children);
});
var CloudServiceManagement16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudServiceManagement16(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,17v5H4V6H14V4H4A2,2,0,0,0,2,6V22a2,2,0,0,0,2,2h8v4H8v2H24V28H20V24h8a2,2,0,0,0,2-2V17ZM18,28H14V24h4Z"
  })), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10V8H27.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,24,4.1011V2H22V4.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,18.1011,8H16v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,22,13.8989V16h2V13.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,27.8989,10Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,23,12Z"
  })), children);
});
var CloudSnow32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSnow32(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  if (true) {
    if (!didWarnAboutDeprecation['CloudSnow32']) {
      didWarnAboutDeprecation['CloudSnow32'] = true;
      console.warn("The CloudSnow32 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 22H8.5A6.5 6.5 0 017.2 9.14a9 9 0 0117.6 0A6.5 6.5 0 0123.5 22zM16 4a7 7 0 00-6.94 6.14L9 11 8.14 11a4.5 4.5 0 00.36 9h15a4.5 4.5 0 00.36-9L23 11l-.1-.82A7 7 0 0016 4zM12 25.05L10.95 24 9.5 25.45 8.05 24 7 25.05 8.45 26.5 7 27.95 8.05 29 9.5 27.55 10.95 29 12 27.95 10.55 26.5 12 25.05zM26 25.05L24.95 24 23.5 25.45 22.05 24 21 25.05 22.45 26.5 21 27.95 22.05 29 23.5 27.55 24.95 29 26 27.95 24.55 26.5 26 25.05zM19 27.05L17.95 26 16.5 27.45 15.05 26 14 27.05 15.45 28.5 14 29.95 15.05 31 16.5 29.55 17.95 31 19 29.95 17.55 28.5 19 27.05z"
  })), children);
});
var CloudSnow24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSnow24(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  if (true) {
    if (!didWarnAboutDeprecation['CloudSnow24']) {
      didWarnAboutDeprecation['CloudSnow24'] = true;
      console.warn("The CloudSnow24 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 22H8.5A6.5 6.5 0 017.2 9.14a9 9 0 0117.6 0A6.5 6.5 0 0123.5 22zM16 4a7 7 0 00-6.94 6.14L9 11 8.14 11a4.5 4.5 0 00.36 9h15a4.5 4.5 0 00.36-9L23 11l-.1-.82A7 7 0 0016 4zM12 25.05L10.95 24 9.5 25.45 8.05 24 7 25.05 8.45 26.5 7 27.95 8.05 29 9.5 27.55 10.95 29 12 27.95 10.55 26.5 12 25.05zM26 25.05L24.95 24 23.5 25.45 22.05 24 21 25.05 22.45 26.5 21 27.95 22.05 29 23.5 27.55 24.95 29 26 27.95 24.55 26.5 26 25.05zM19 27.05L17.95 26 16.5 27.45 15.05 26 14 27.05 15.45 28.5 14 29.95 15.05 31 16.5 29.55 17.95 31 19 29.95 17.55 28.5 19 27.05z"
  })), children);
});
var CloudSnow20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSnow20(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  if (true) {
    if (!didWarnAboutDeprecation['CloudSnow20']) {
      didWarnAboutDeprecation['CloudSnow20'] = true;
      console.warn("The CloudSnow20 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 22H8.5A6.5 6.5 0 017.2 9.14a9 9 0 0117.6 0A6.5 6.5 0 0123.5 22zM16 4a7 7 0 00-6.94 6.14L9 11 8.14 11a4.5 4.5 0 00.36 9h15a4.5 4.5 0 00.36-9L23 11l-.1-.82A7 7 0 0016 4zM12 25.05L10.95 24 9.5 25.45 8.05 24 7 25.05 8.45 26.5 7 27.95 8.05 29 9.5 27.55 10.95 29 12 27.95 10.55 26.5 12 25.05zM26 25.05L24.95 24 23.5 25.45 22.05 24 21 25.05 22.45 26.5 21 27.95 22.05 29 23.5 27.55 24.95 29 26 27.95 24.55 26.5 26 25.05zM19 27.05L17.95 26 16.5 27.45 15.05 26 14 27.05 15.45 28.5 14 29.95 15.05 31 16.5 29.55 17.95 31 19 29.95 17.55 28.5 19 27.05z"
  })), children);
});
var CloudSnow16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSnow16(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  if (true) {
    if (!didWarnAboutDeprecation['CloudSnow16']) {
      didWarnAboutDeprecation['CloudSnow16'] = true;
      console.warn("The CloudSnow16 component has been deprecated and will be " + "removed in the next major version of @carbon/icons-react.");
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5 22H8.5A6.5 6.5 0 017.2 9.14a9 9 0 0117.6 0A6.5 6.5 0 0123.5 22zM16 4a7 7 0 00-6.94 6.14L9 11 8.14 11a4.5 4.5 0 00.36 9h15a4.5 4.5 0 00.36-9L23 11l-.1-.82A7 7 0 0016 4zM12 25.05L10.95 24 9.5 25.45 8.05 24 7 25.05 8.45 26.5 7 27.95 8.05 29 9.5 27.55 10.95 29 12 27.95 10.55 26.5 12 25.05zM26 25.05L24.95 24 23.5 25.45 22.05 24 21 25.05 22.45 26.5 21 27.95 22.05 29 23.5 27.55 24.95 29 26 27.95 24.55 26.5 26 25.05zM19 27.05L17.95 26 16.5 27.45 15.05 26 14 27.05 15.45 28.5 14 29.95 15.05 31 16.5 29.55 17.95 31 19 29.95 17.55 28.5 19 27.05z"
  })), children);
});
var CloudUpload32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudUpload32(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 18L12.41 19.41 15 16.83 15 29 17 29 17 16.83 19.59 19.41 21 18 16 13 11 18z"
  })), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,22H23V20h.5a4.5,4.5,0,0,0,.36-9L23,11l-.1-.82a7,7,0,0,0-13.88,0L9,11,8.14,11a4.5,4.5,0,0,0,.36,9H9v2H8.5A6.5,6.5,0,0,1,7.2,9.14a9,9,0,0,1,17.6,0A6.5,6.5,0,0,1,23.5,22Z"
  })), children);
});
var CloudUpload24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudUpload24(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 18L12.41 19.41 15 16.83 15 29 17 29 17 16.83 19.59 19.41 21 18 16 13 11 18z"
  })), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,22H23V20h.5a4.5,4.5,0,0,0,.36-9L23,11l-.1-.82a7,7,0,0,0-13.88,0L9,11,8.14,11a4.5,4.5,0,0,0,.36,9H9v2H8.5A6.5,6.5,0,0,1,7.2,9.14a9,9,0,0,1,17.6,0A6.5,6.5,0,0,1,23.5,22Z"
  })), children);
});
var CloudUpload20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudUpload20(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 18L12.41 19.41 15 16.83 15 29 17 29 17 16.83 19.59 19.41 21 18 16 13 11 18z"
  })), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,22H23V20h.5a4.5,4.5,0,0,0,.36-9L23,11l-.1-.82a7,7,0,0,0-13.88,0L9,11,8.14,11a4.5,4.5,0,0,0,.36,9H9v2H8.5A6.5,6.5,0,0,1,7.2,9.14a9,9,0,0,1,17.6,0A6.5,6.5,0,0,1,23.5,22Z"
  })), children);
});
var CloudUpload16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudUpload16(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 18L12.41 19.41 15 16.83 15 29 17 29 17 16.83 19.59 19.41 21 18 16 13 11 18z"
  })), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.5,22H23V20h.5a4.5,4.5,0,0,0,.36-9L23,11l-.1-.82a7,7,0,0,0-13.88,0L9,11,8.14,11a4.5,4.5,0,0,0,.36,9H9v2H8.5A6.5,6.5,0,0,1,7.2,9.14a9,9,0,0,1,17.6,0A6.5,6.5,0,0,1,23.5,22Z"
  })), children);
});
var CloudApp32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudApp32(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.8289 13.1155A10.02 10.02 0 0016 5.0005V7a8.0233 8.0233 0 017.8649 6.4934l.2591 1.346 1.3488.2441A5.5019 5.5019 0 0124.5076 26H16v2h8.5076a7.5019 7.5019 0 001.3213-14.8845zM8 24H14V26H8zM4 24H6V26H4zM6 20H14V22H6zM2 20H4V22H2zM8 16H14V18H8zM4 16H6V18H4zM10 12H14V14H10zM6 12H8V14H6zM12 8H14V10H12z"
  })), children);
});
var CloudApp24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudApp24(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.8289 13.1155A10.02 10.02 0 0016 5.0005V7a8.0233 8.0233 0 017.8649 6.4934l.2591 1.346 1.3488.2441A5.5019 5.5019 0 0124.5076 26H16v2h8.5076a7.5019 7.5019 0 001.3213-14.8845zM8 24H14V26H8zM4 24H6V26H4zM6 20H14V22H6zM2 20H4V22H2zM8 16H14V18H8zM4 16H6V18H4zM10 12H14V14H10zM6 12H8V14H6zM12 8H14V10H12z"
  })), children);
});
var CloudApp20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudApp20(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.8289 13.1155A10.02 10.02 0 0016 5.0005V7a8.0233 8.0233 0 017.8649 6.4934l.2591 1.346 1.3488.2441A5.5019 5.5019 0 0124.5076 26H16v2h8.5076a7.5019 7.5019 0 001.3213-14.8845zM8 24H14V26H8zM4 24H6V26H4zM6 20H14V22H6zM2 20H4V22H2zM8 16H14V18H8zM4 16H6V18H4zM10 12H14V14H10zM6 12H8V14H6zM12 8H14V10H12z"
  })), children);
});
var CloudApp16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudApp16(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.8289 13.1155A10.02 10.02 0 0016 5.0005V7a8.0233 8.0233 0 017.8649 6.4934l.2591 1.346 1.3488.2441A5.5019 5.5019 0 0124.5076 26H16v2h8.5076a7.5019 7.5019 0 001.3213-14.8845zM8 24H14V26H8zM4 24H6V26H4zM6 20H14V22H6zM2 20H4V22H2zM8 16H14V18H8zM4 16H6V18H4zM10 12H14V14H10zM6 12H8V14H6zM12 8H14V10H12z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-6.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-6.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "CloudCeiling16": () => (/* binding */ CloudCeiling16),
/* harmony export */   "CloudCeiling20": () => (/* binding */ CloudCeiling20),
/* harmony export */   "CloudCeiling24": () => (/* binding */ CloudCeiling24),
/* harmony export */   "CloudCeiling32": () => (/* binding */ CloudCeiling32),
/* harmony export */   "CloudFoundry_116": () => (/* binding */ CloudFoundry_116),
/* harmony export */   "CloudFoundry_120": () => (/* binding */ CloudFoundry_120),
/* harmony export */   "CloudFoundry_124": () => (/* binding */ CloudFoundry_124),
/* harmony export */   "CloudFoundry_132": () => (/* binding */ CloudFoundry_132),
/* harmony export */   "CloudFoundry_216": () => (/* binding */ CloudFoundry_216),
/* harmony export */   "CloudFoundry_220": () => (/* binding */ CloudFoundry_220),
/* harmony export */   "CloudFoundry_224": () => (/* binding */ CloudFoundry_224),
/* harmony export */   "CloudFoundry_232": () => (/* binding */ CloudFoundry_232),
/* harmony export */   "CloudRegistry16": () => (/* binding */ CloudRegistry16),
/* harmony export */   "CloudRegistry20": () => (/* binding */ CloudRegistry20),
/* harmony export */   "CloudRegistry24": () => (/* binding */ CloudRegistry24),
/* harmony export */   "CloudRegistry32": () => (/* binding */ CloudRegistry32),
/* harmony export */   "CloudSatellite16": () => (/* binding */ CloudSatellite16),
/* harmony export */   "CloudSatellite20": () => (/* binding */ CloudSatellite20),
/* harmony export */   "CloudSatellite24": () => (/* binding */ CloudSatellite24),
/* harmony export */   "CloudSatellite32": () => (/* binding */ CloudSatellite32),
/* harmony export */   "CloudSatelliteConfig16": () => (/* binding */ CloudSatelliteConfig16),
/* harmony export */   "CloudSatelliteConfig20": () => (/* binding */ CloudSatelliteConfig20),
/* harmony export */   "CloudSatelliteConfig24": () => (/* binding */ CloudSatelliteConfig24),
/* harmony export */   "CloudSatelliteConfig32": () => (/* binding */ CloudSatelliteConfig32),
/* harmony export */   "CloudSatelliteLink16": () => (/* binding */ CloudSatelliteLink16),
/* harmony export */   "CloudSatelliteLink20": () => (/* binding */ CloudSatelliteLink20),
/* harmony export */   "CloudSatelliteLink24": () => (/* binding */ CloudSatelliteLink24),
/* harmony export */   "CloudSatelliteLink32": () => (/* binding */ CloudSatelliteLink32),
/* harmony export */   "CloudSatelliteServices16": () => (/* binding */ CloudSatelliteServices16),
/* harmony export */   "CloudSatelliteServices20": () => (/* binding */ CloudSatelliteServices20),
/* harmony export */   "CloudSatelliteServices24": () => (/* binding */ CloudSatelliteServices24),
/* harmony export */   "CloudSatelliteServices32": () => (/* binding */ CloudSatelliteServices32),
/* harmony export */   "CloudServices16": () => (/* binding */ CloudServices16),
/* harmony export */   "CloudServices20": () => (/* binding */ CloudServices20),
/* harmony export */   "CloudServices24": () => (/* binding */ CloudServices24),
/* harmony export */   "CloudServices32": () => (/* binding */ CloudServices32),
/* harmony export */   "Cloudy16": () => (/* binding */ Cloudy16),
/* harmony export */   "Cloudy20": () => (/* binding */ Cloudy20),
/* harmony export */   "Cloudy24": () => (/* binding */ Cloudy24),
/* harmony export */   "Cloudy32": () => (/* binding */ Cloudy32),
/* harmony export */   "Code16": () => (/* binding */ Code16),
/* harmony export */   "Code20": () => (/* binding */ Code20),
/* harmony export */   "Code24": () => (/* binding */ Code24),
/* harmony export */   "Code32": () => (/* binding */ Code32),
/* harmony export */   "CodeHide16": () => (/* binding */ CodeHide16),
/* harmony export */   "CodeHide20": () => (/* binding */ CodeHide20),
/* harmony export */   "CodeHide24": () => (/* binding */ CodeHide24),
/* harmony export */   "CodeHide32": () => (/* binding */ CodeHide32),
/* harmony export */   "CodeReference16": () => (/* binding */ CodeReference16),
/* harmony export */   "CodeReference20": () => (/* binding */ CodeReference20),
/* harmony export */   "CodeReference24": () => (/* binding */ CodeReference24),
/* harmony export */   "CodeReference32": () => (/* binding */ CodeReference32),
/* harmony export */   "CodeSigningService16": () => (/* binding */ CodeSigningService16),
/* harmony export */   "CodeSigningService20": () => (/* binding */ CodeSigningService20),
/* harmony export */   "CodeSigningService24": () => (/* binding */ CodeSigningService24),
/* harmony export */   "CodeSigningService32": () => (/* binding */ CodeSigningService32),
/* harmony export */   "Cognitive16": () => (/* binding */ Cognitive16),
/* harmony export */   "Cognitive20": () => (/* binding */ Cognitive20),
/* harmony export */   "Cognitive24": () => (/* binding */ Cognitive24),
/* harmony export */   "Cognitive32": () => (/* binding */ Cognitive32),
/* harmony export */   "Collaborate16": () => (/* binding */ Collaborate16),
/* harmony export */   "Collaborate20": () => (/* binding */ Collaborate20),
/* harmony export */   "Collaborate24": () => (/* binding */ Collaborate24),
/* harmony export */   "Collaborate32": () => (/* binding */ Collaborate32),
/* harmony export */   "CollapseAll16": () => (/* binding */ CollapseAll16),
/* harmony export */   "CollapseAll20": () => (/* binding */ CollapseAll20),
/* harmony export */   "CollapseAll24": () => (/* binding */ CollapseAll24),
/* harmony export */   "CollapseAll32": () => (/* binding */ CollapseAll32),
/* harmony export */   "CollapseCategories16": () => (/* binding */ CollapseCategories16),
/* harmony export */   "CollapseCategories20": () => (/* binding */ CollapseCategories20),
/* harmony export */   "CollapseCategories24": () => (/* binding */ CollapseCategories24),
/* harmony export */   "CollapseCategories32": () => (/* binding */ CollapseCategories32),
/* harmony export */   "ColorPalette16": () => (/* binding */ ColorPalette16),
/* harmony export */   "ColorPalette20": () => (/* binding */ ColorPalette20),
/* harmony export */   "ColorPalette24": () => (/* binding */ ColorPalette24),
/* harmony export */   "ColorPalette32": () => (/* binding */ ColorPalette32),
/* harmony export */   "ColorSwitch16": () => (/* binding */ ColorSwitch16),
/* harmony export */   "ColorSwitch20": () => (/* binding */ ColorSwitch20),
/* harmony export */   "ColorSwitch24": () => (/* binding */ ColorSwitch24),
/* harmony export */   "ColorSwitch32": () => (/* binding */ ColorSwitch32),
/* harmony export */   "Column16": () => (/* binding */ Column16),
/* harmony export */   "Column20": () => (/* binding */ Column20),
/* harmony export */   "Column24": () => (/* binding */ Column24),
/* harmony export */   "Column32": () => (/* binding */ Column32),
/* harmony export */   "ColumnDelete16": () => (/* binding */ ColumnDelete16),
/* harmony export */   "ColumnDelete20": () => (/* binding */ ColumnDelete20),
/* harmony export */   "ColumnDelete24": () => (/* binding */ ColumnDelete24),
/* harmony export */   "ColumnDelete32": () => (/* binding */ ColumnDelete32),
/* harmony export */   "ColumnDependency16": () => (/* binding */ ColumnDependency16),
/* harmony export */   "ColumnDependency20": () => (/* binding */ ColumnDependency20),
/* harmony export */   "ColumnDependency24": () => (/* binding */ ColumnDependency24),
/* harmony export */   "ColumnDependency32": () => (/* binding */ ColumnDependency32),
/* harmony export */   "ColumnInsert16": () => (/* binding */ ColumnInsert16),
/* harmony export */   "ColumnInsert20": () => (/* binding */ ColumnInsert20),
/* harmony export */   "ColumnInsert24": () => (/* binding */ ColumnInsert24),
/* harmony export */   "ColumnInsert32": () => (/* binding */ ColumnInsert32),
/* harmony export */   "Commit16": () => (/* binding */ Commit16),
/* harmony export */   "Commit20": () => (/* binding */ Commit20),
/* harmony export */   "Commit24": () => (/* binding */ Commit24),
/* harmony export */   "Commit32": () => (/* binding */ Commit32),
/* harmony export */   "CommunicationUnified16": () => (/* binding */ CommunicationUnified16),
/* harmony export */   "CommunicationUnified20": () => (/* binding */ CommunicationUnified20),
/* harmony export */   "CommunicationUnified24": () => (/* binding */ CommunicationUnified24),
/* harmony export */   "CommunicationUnified32": () => (/* binding */ CommunicationUnified32),
/* harmony export */   "Compare16": () => (/* binding */ Compare16),
/* harmony export */   "Compare20": () => (/* binding */ Compare20),
/* harmony export */   "Compare24": () => (/* binding */ Compare24),
/* harmony export */   "Compare32": () => (/* binding */ Compare32),
/* harmony export */   "Compass16": () => (/* binding */ Compass16),
/* harmony export */   "Compass20": () => (/* binding */ Compass20),
/* harmony export */   "Compass24": () => (/* binding */ Compass24),
/* harmony export */   "Compass32": () => (/* binding */ Compass32),
/* harmony export */   "Concept16": () => (/* binding */ Concept16),
/* harmony export */   "Concept20": () => (/* binding */ Concept20),
/* harmony export */   "Concept24": () => (/* binding */ Concept24),
/* harmony export */   "Concept32": () => (/* binding */ Concept32),
/* harmony export */   "ConditionPoint16": () => (/* binding */ ConditionPoint16),
/* harmony export */   "ConditionPoint20": () => (/* binding */ ConditionPoint20),
/* harmony export */   "ConditionPoint24": () => (/* binding */ ConditionPoint24),
/* harmony export */   "ConditionPoint32": () => (/* binding */ ConditionPoint32),
/* harmony export */   "ConditionWaitPoint16": () => (/* binding */ ConditionWaitPoint16),
/* harmony export */   "ConditionWaitPoint20": () => (/* binding */ ConditionWaitPoint20),
/* harmony export */   "ConditionWaitPoint24": () => (/* binding */ ConditionWaitPoint24),
/* harmony export */   "ConditionWaitPoint32": () => (/* binding */ ConditionWaitPoint32),
/* harmony export */   "Connect16": () => (/* binding */ Connect16),
/* harmony export */   "Connect20": () => (/* binding */ Connect20),
/* harmony export */   "Connect24": () => (/* binding */ Connect24),
/* harmony export */   "Connect32": () => (/* binding */ Connect32),
/* harmony export */   "ConnectRecursive16": () => (/* binding */ ConnectRecursive16),
/* harmony export */   "ConnectRecursive20": () => (/* binding */ ConnectRecursive20),
/* harmony export */   "ConnectRecursive24": () => (/* binding */ ConnectRecursive24),
/* harmony export */   "ConnectRecursive32": () => (/* binding */ ConnectRecursive32),
/* harmony export */   "ConnectSource16": () => (/* binding */ ConnectSource16),
/* harmony export */   "ConnectSource20": () => (/* binding */ ConnectSource20),
/* harmony export */   "ConnectSource24": () => (/* binding */ ConnectSource24),
/* harmony export */   "ConnectSource32": () => (/* binding */ ConnectSource32),
/* harmony export */   "ConnectTarget16": () => (/* binding */ ConnectTarget16),
/* harmony export */   "ConnectTarget20": () => (/* binding */ ConnectTarget20),
/* harmony export */   "ConnectTarget24": () => (/* binding */ ConnectTarget24),
/* harmony export */   "ConnectTarget32": () => (/* binding */ ConnectTarget32),
/* harmony export */   "ConnectionReceive16": () => (/* binding */ ConnectionReceive16),
/* harmony export */   "ConnectionReceive20": () => (/* binding */ ConnectionReceive20),
/* harmony export */   "ConnectionReceive24": () => (/* binding */ ConnectionReceive24),
/* harmony export */   "ConnectionReceive32": () => (/* binding */ ConnectionReceive32),
/* harmony export */   "ConnectionSend16": () => (/* binding */ ConnectionSend16),
/* harmony export */   "ConnectionSend20": () => (/* binding */ ConnectionSend20),
/* harmony export */   "ConnectionSend24": () => (/* binding */ ConnectionSend24),
/* harmony export */   "ConnectionSend32": () => (/* binding */ ConnectionSend32),
/* harmony export */   "ConnectionSignal16": () => (/* binding */ ConnectionSignal16),
/* harmony export */   "ConnectionSignal20": () => (/* binding */ ConnectionSignal20),
/* harmony export */   "ConnectionSignal24": () => (/* binding */ ConnectionSignal24),
/* harmony export */   "ConnectionSignal32": () => (/* binding */ ConnectionSignal32),
/* harmony export */   "ConnectionSignalOff16": () => (/* binding */ ConnectionSignalOff16),
/* harmony export */   "ConnectionSignalOff20": () => (/* binding */ ConnectionSignalOff20),
/* harmony export */   "ConnectionSignalOff24": () => (/* binding */ ConnectionSignalOff24),
/* harmony export */   "ConnectionSignalOff32": () => (/* binding */ ConnectionSignalOff32),
/* harmony export */   "ConnectionTwoWay16": () => (/* binding */ ConnectionTwoWay16),
/* harmony export */   "ConnectionTwoWay20": () => (/* binding */ ConnectionTwoWay20),
/* harmony export */   "ConnectionTwoWay24": () => (/* binding */ ConnectionTwoWay24),
/* harmony export */   "ConnectionTwoWay32": () => (/* binding */ ConnectionTwoWay32),
/* harmony export */   "Construction16": () => (/* binding */ Construction16),
/* harmony export */   "Construction20": () => (/* binding */ Construction20),
/* harmony export */   "Construction24": () => (/* binding */ Construction24),
/* harmony export */   "Construction32": () => (/* binding */ Construction32),
/* harmony export */   "ContainerRegistry16": () => (/* binding */ ContainerRegistry16),
/* harmony export */   "ContainerRegistry20": () => (/* binding */ ContainerRegistry20),
/* harmony export */   "ContainerRegistry24": () => (/* binding */ ContainerRegistry24),
/* harmony export */   "ContainerRegistry32": () => (/* binding */ ContainerRegistry32),
/* harmony export */   "ContainerServices16": () => (/* binding */ ContainerServices16),
/* harmony export */   "ContainerServices20": () => (/* binding */ ContainerServices20),
/* harmony export */   "ContainerServices24": () => (/* binding */ ContainerServices24),
/* harmony export */   "ContainerServices32": () => (/* binding */ ContainerServices32),
/* harmony export */   "ContainerSoftware16": () => (/* binding */ ContainerSoftware16),
/* harmony export */   "ContainerSoftware20": () => (/* binding */ ContainerSoftware20),
/* harmony export */   "ContainerSoftware24": () => (/* binding */ ContainerSoftware24),
/* harmony export */   "ContainerSoftware32": () => (/* binding */ ContainerSoftware32),
/* harmony export */   "ContentDeliveryNetwork16": () => (/* binding */ ContentDeliveryNetwork16),
/* harmony export */   "ContentDeliveryNetwork20": () => (/* binding */ ContentDeliveryNetwork20),
/* harmony export */   "ContentDeliveryNetwork24": () => (/* binding */ ContentDeliveryNetwork24),
/* harmony export */   "ContentDeliveryNetwork32": () => (/* binding */ ContentDeliveryNetwork32),
/* harmony export */   "ContentView16": () => (/* binding */ ContentView16),
/* harmony export */   "ContentView20": () => (/* binding */ ContentView20),
/* harmony export */   "ContentView24": () => (/* binding */ ContentView24),
/* harmony export */   "ContentView32": () => (/* binding */ ContentView32),
/* harmony export */   "Continue16": () => (/* binding */ Continue16),
/* harmony export */   "Continue20": () => (/* binding */ Continue20),
/* harmony export */   "Continue24": () => (/* binding */ Continue24),
/* harmony export */   "Continue32": () => (/* binding */ Continue32),
/* harmony export */   "ContinueFilled16": () => (/* binding */ ContinueFilled16),
/* harmony export */   "ContinueFilled20": () => (/* binding */ ContinueFilled20),
/* harmony export */   "ContinueFilled24": () => (/* binding */ ContinueFilled24),
/* harmony export */   "ContinueFilled32": () => (/* binding */ ContinueFilled32),
/* harmony export */   "Contrast16": () => (/* binding */ Contrast16),
/* harmony export */   "Contrast20": () => (/* binding */ Contrast20),
/* harmony export */   "Contrast24": () => (/* binding */ Contrast24),
/* harmony export */   "Contrast32": () => (/* binding */ Contrast32),
/* harmony export */   "ConvertToCloud16": () => (/* binding */ ConvertToCloud16),
/* harmony export */   "ConvertToCloud20": () => (/* binding */ ConvertToCloud20),
/* harmony export */   "ConvertToCloud24": () => (/* binding */ ConvertToCloud24),
/* harmony export */   "ConvertToCloud32": () => (/* binding */ ConvertToCloud32),
/* harmony export */   "Cookie16": () => (/* binding */ Cookie16),
/* harmony export */   "Cookie20": () => (/* binding */ Cookie20),
/* harmony export */   "Cookie24": () => (/* binding */ Cookie24),
/* harmony export */   "Cookie32": () => (/* binding */ Cookie32),
/* harmony export */   "Copy16": () => (/* binding */ Copy16),
/* harmony export */   "Copy20": () => (/* binding */ Copy20),
/* harmony export */   "Copy24": () => (/* binding */ Copy24),
/* harmony export */   "Copy32": () => (/* binding */ Copy32),
/* harmony export */   "CopyFile16": () => (/* binding */ CopyFile16),
/* harmony export */   "CopyFile20": () => (/* binding */ CopyFile20),
/* harmony export */   "CopyFile24": () => (/* binding */ CopyFile24),
/* harmony export */   "CopyFile32": () => (/* binding */ CopyFile32),
/* harmony export */   "CopyLink16": () => (/* binding */ CopyLink16),
/* harmony export */   "CopyLink20": () => (/* binding */ CopyLink20),
/* harmony export */   "CopyLink24": () => (/* binding */ CopyLink24),
/* harmony export */   "CopyLink32": () => (/* binding */ CopyLink32),
/* harmony export */   "Corn16": () => (/* binding */ Corn16),
/* harmony export */   "Corn20": () => (/* binding */ Corn20),
/* harmony export */   "Corn24": () => (/* binding */ Corn24),
/* harmony export */   "Corn32": () => (/* binding */ Corn32),
/* harmony export */   "Corner16": () => (/* binding */ Corner16),
/* harmony export */   "Corner20": () => (/* binding */ Corner20),
/* harmony export */   "Corner24": () => (/* binding */ Corner24),
/* harmony export */   "Corner32": () => (/* binding */ Corner32),
/* harmony export */   "Coronavirus16": () => (/* binding */ Coronavirus16),
/* harmony export */   "Coronavirus20": () => (/* binding */ Coronavirus20),
/* harmony export */   "Coronavirus24": () => (/* binding */ Coronavirus24),
/* harmony export */   "Coronavirus32": () => (/* binding */ Coronavirus32),
/* harmony export */   "Cost24": () => (/* binding */ Cost24),
/* harmony export */   "Cost32": () => (/* binding */ Cost32),
/* harmony export */   "QComposerEdit16": () => (/* binding */ QComposerEdit16),
/* harmony export */   "QComposerEdit20": () => (/* binding */ QComposerEdit20),
/* harmony export */   "QComposerEdit24": () => (/* binding */ QComposerEdit24),
/* harmony export */   "QComposerEdit32": () => (/* binding */ QComposerEdit32),
/* harmony export */   "WatsonHealthCobbAngle16": () => (/* binding */ WatsonHealthCobbAngle16),
/* harmony export */   "WatsonHealthCobbAngle20": () => (/* binding */ WatsonHealthCobbAngle20),
/* harmony export */   "WatsonHealthCobbAngle24": () => (/* binding */ WatsonHealthCobbAngle24),
/* harmony export */   "WatsonHealthCobbAngle32": () => (/* binding */ WatsonHealthCobbAngle32),
/* harmony export */   "WatsonHealthContourDraw16": () => (/* binding */ WatsonHealthContourDraw16),
/* harmony export */   "WatsonHealthContourDraw20": () => (/* binding */ WatsonHealthContourDraw20),
/* harmony export */   "WatsonHealthContourDraw24": () => (/* binding */ WatsonHealthContourDraw24),
/* harmony export */   "WatsonHealthContourDraw32": () => (/* binding */ WatsonHealthContourDraw32),
/* harmony export */   "WatsonHealthContourEdit16": () => (/* binding */ WatsonHealthContourEdit16),
/* harmony export */   "WatsonHealthContourEdit20": () => (/* binding */ WatsonHealthContourEdit20),
/* harmony export */   "WatsonHealthContourEdit24": () => (/* binding */ WatsonHealthContourEdit24),
/* harmony export */   "WatsonHealthContourEdit32": () => (/* binding */ WatsonHealthContourEdit32),
/* harmony export */   "WatsonHealthContourFinding16": () => (/* binding */ WatsonHealthContourFinding16),
/* harmony export */   "WatsonHealthContourFinding20": () => (/* binding */ WatsonHealthContourFinding20),
/* harmony export */   "WatsonHealthContourFinding24": () => (/* binding */ WatsonHealthContourFinding24),
/* harmony export */   "WatsonHealthContourFinding32": () => (/* binding */ WatsonHealthContourFinding32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _circle, _path29, _circle2, _path30, _circle3, _path31, _circle4, _path32, _circle5, _path33, _circle6, _path34, _circle7, _path35, _circle8, _path36, _path37, _circle9, _path38, _circle10, _path39, _path40, _circle11, _path41, _circle12, _path42, _path43, _circle13, _path44, _circle14, _path45, _path46, _circle15, _path47, _circle16, _path48, _path49, _path50, _circle17, _path51, _circle18, _path52, _path53, _path54, _circle19, _path55, _circle20, _path56, _path57, _path58, _circle21, _path59, _circle22, _path60, _path61, _path62, _circle23, _path63, _circle24, _path64, _path65, _circle25, _path66, _circle26, _path67, _path68, _circle27, _path69, _circle28, _path70, _path71, _circle29, _path72, _circle30, _path73, _path74, _circle31, _path75, _circle32, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _circle33, _path117, _circle34, _path118, _circle35, _path119, _circle36, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _circle37, _circle38, _circle39, _circle40, _circle41, _path145, _circle42, _circle43, _circle44, _circle45, _circle46, _path146, _circle47, _circle48, _circle49, _circle50, _circle51, _path147, _circle52, _circle53, _circle54, _circle55, _circle56, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _circle57, _path187, _path188, _circle58, _path189, _path190, _circle59, _path191, _path192, _circle60, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _path224, _path225, _path226, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _circle61, _path279, _path280, _circle62, _path281, _path282, _circle63, _path283, _path284, _circle64, _path285, _path286, _path287, _path288, _path289, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _circle65, _circle66, _path301, _path302, _circle67, _circle68, _path303, _path304, _circle69, _circle70, _path305, _path306, _circle71, _circle72, _path307, _path308, _circle73, _path309, _path310, _circle74, _path311, _path312, _circle75, _path313, _path314, _circle76, _path315, _path316, _path317, _path318, _path319, _path320, _path321, _path322, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _circle77, _circle78, _circle79, _circle80, _circle81, _circle82, _circle83, _path349, _circle84, _circle85, _circle86, _circle87, _circle88, _circle89, _circle90, _path350, _circle91, _circle92, _circle93, _circle94, _circle95, _circle96, _circle97, _path351, _circle98, _circle99, _circle100, _circle101, _circle102, _circle103, _circle104, _path352, _path353, _path354, _path355, _path356, _path357, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388, _circle105, _circle106, _circle107, _circle108, _circle109, _path389, _circle110, _circle111, _circle112, _circle113, _circle114, _path390, _circle115, _circle116, _circle117, _circle118, _circle119, _path391, _circle120, _circle121, _circle122, _circle123, _circle124, _path392, _path393, _path394, _path395, _path396;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var CloudCeiling32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudCeiling32(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H11V30H2zM21 28H30V30H21zM17 26.167L17 17.832 19.586 20.414 21 19 16 14 11 19 12.413 20.415 15 17.832 15 26.167 12.413 23.584 11 25 16 30 21 25 19.586 23.586 17 26.167z"
  })), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,16H21V14h2a3,3,0,0,0,0-6c-.0938.0144-.1538.0219-.2153.0263l-.8037.0572L21.7544,7.31a5.9927,5.9927,0,0,0-11.1758-.8655l-.2832.5994-.8423-.0455A3.5008,3.5008,0,0,0,9.5,14H11v2H9.5A5.5,5.5,0,0,1,9.07,5.0166,7.9909,7.9909,0,0,1,23.42,6.0175,5,5,0,0,1,23,16Z"
  })), children);
});
var CloudCeiling24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudCeiling24(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H11V30H2zM21 28H30V30H21zM17 26.167L17 17.832 19.586 20.414 21 19 16 14 11 19 12.413 20.415 15 17.832 15 26.167 12.413 23.584 11 25 16 30 21 25 19.586 23.586 17 26.167z"
  })), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,16H21V14h2a3,3,0,0,0,0-6c-.0938.0144-.1538.0219-.2153.0263l-.8037.0572L21.7544,7.31a5.9927,5.9927,0,0,0-11.1758-.8655l-.2832.5994-.8423-.0455A3.5008,3.5008,0,0,0,9.5,14H11v2H9.5A5.5,5.5,0,0,1,9.07,5.0166,7.9909,7.9909,0,0,1,23.42,6.0175,5,5,0,0,1,23,16Z"
  })), children);
});
var CloudCeiling20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudCeiling20(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H11V30H2zM21 28H30V30H21zM17 26.167L17 17.832 19.586 20.414 21 19 16 14 11 19 12.413 20.415 15 17.832 15 26.167 12.413 23.584 11 25 16 30 21 25 19.586 23.586 17 26.167z"
  })), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,16H21V14h2a3,3,0,0,0,0-6c-.0938.0144-.1538.0219-.2153.0263l-.8037.0572L21.7544,7.31a5.9927,5.9927,0,0,0-11.1758-.8655l-.2832.5994-.8423-.0455A3.5008,3.5008,0,0,0,9.5,14H11v2H9.5A5.5,5.5,0,0,1,9.07,5.0166,7.9909,7.9909,0,0,1,23.42,6.0175,5,5,0,0,1,23,16Z"
  })), children);
});
var CloudCeiling16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudCeiling16(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H11V30H2zM21 28H30V30H21zM17 26.167L17 17.832 19.586 20.414 21 19 16 14 11 19 12.413 20.415 15 17.832 15 26.167 12.413 23.584 11 25 16 30 21 25 19.586 23.586 17 26.167z"
  })), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,16H21V14h2a3,3,0,0,0,0-6c-.0938.0144-.1538.0219-.2153.0263l-.8037.0572L21.7544,7.31a5.9927,5.9927,0,0,0-11.1758-.8655l-.2832.5994-.8423-.0455A3.5008,3.5008,0,0,0,9.5,14H11v2H9.5A5.5,5.5,0,0,1,9.07,5.0166,7.9909,7.9909,0,0,1,23.42,6.0175,5,5,0,0,1,23,16Z"
  })), children);
});
var CloudFoundry_132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudFoundry_132(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7h0a7.66,7.66,0,0,1,1.51.15,8,8,0,0,1,6.35,6.34l.26,1.35,1.35.24a5.5,5.5,0,0,1-1,10.92H7.5a5.5,5.5,0,0,1-1-10.92l1.34-.24.26-1.35A8,8,0,0,1,16,7m0-2a10,10,0,0,0-9.83,8.12A7.5,7.5,0,0,0,7.49,28h17a7.5,7.5,0,0,0,1.32-14.88,10,10,0,0,0-7.94-7.94A10.27,10.27,0,0,0,16,5Z"
  })), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 24H11a2 2 0 01-2-2V19a2 2 0 012-2h3v2H11v3h3zM21 15V13H19a2 2 0 00-2 2v2H16v2h1v5h2V19h2V17H19V15z"
  })), children);
});
var CloudFoundry_124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudFoundry_124(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7h0a7.66,7.66,0,0,1,1.51.15,8,8,0,0,1,6.35,6.34l.26,1.35,1.35.24a5.5,5.5,0,0,1-1,10.92H7.5a5.5,5.5,0,0,1-1-10.92l1.34-.24.26-1.35A8,8,0,0,1,16,7m0-2a10,10,0,0,0-9.83,8.12A7.5,7.5,0,0,0,7.49,28h17a7.5,7.5,0,0,0,1.32-14.88,10,10,0,0,0-7.94-7.94A10.27,10.27,0,0,0,16,5Z"
  })), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 24H11a2 2 0 01-2-2V19a2 2 0 012-2h3v2H11v3h3zM21 15V13H19a2 2 0 00-2 2v2H16v2h1v5h2V19h2V17H19V15z"
  })), children);
});
var CloudFoundry_120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudFoundry_120(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7h0a7.66,7.66,0,0,1,1.51.15,8,8,0,0,1,6.35,6.34l.26,1.35,1.35.24a5.5,5.5,0,0,1-1,10.92H7.5a5.5,5.5,0,0,1-1-10.92l1.34-.24.26-1.35A8,8,0,0,1,16,7m0-2a10,10,0,0,0-9.83,8.12A7.5,7.5,0,0,0,7.49,28h17a7.5,7.5,0,0,0,1.32-14.88,10,10,0,0,0-7.94-7.94A10.27,10.27,0,0,0,16,5Z"
  })), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 24H11a2 2 0 01-2-2V19a2 2 0 012-2h3v2H11v3h3zM21 15V13H19a2 2 0 00-2 2v2H16v2h1v5h2V19h2V17H19V15z"
  })), children);
});
var CloudFoundry_116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudFoundry_116(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,7h0a7.66,7.66,0,0,1,1.51.15,8,8,0,0,1,6.35,6.34l.26,1.35,1.35.24a5.5,5.5,0,0,1-1,10.92H7.5a5.5,5.5,0,0,1-1-10.92l1.34-.24.26-1.35A8,8,0,0,1,16,7m0-2a10,10,0,0,0-9.83,8.12A7.5,7.5,0,0,0,7.49,28h17a7.5,7.5,0,0,0,1.32-14.88,10,10,0,0,0-7.94-7.94A10.27,10.27,0,0,0,16,5Z"
  })), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 24H11a2 2 0 01-2-2V19a2 2 0 012-2h3v2H11v3h3zM21 15V13H19a2 2 0 00-2 2v2H16v2h1v5h2V19h2V17H19V15z"
  })), children);
});
var CloudFoundry_232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudFoundry_232(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 11L25 9 17 9 17 23 19 23 19 17 24 17 24 15 19 15 19 11 25 11zM15 23H9a2 2 0 01-2-2V11A2 2 0 019 9h6v2H9V21h6z"
  })), children);
});
var CloudFoundry_224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudFoundry_224(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 11L25 9 17 9 17 23 19 23 19 17 24 17 24 15 19 15 19 11 25 11zM15 23H9a2 2 0 01-2-2V11A2 2 0 019 9h6v2H9V21h6z"
  })), children);
});
var CloudFoundry_220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudFoundry_220(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 11L25 9 17 9 17 23 19 23 19 17 24 17 24 15 19 15 19 11 25 11zM15 23H9a2 2 0 01-2-2V11A2 2 0 019 9h6v2H9V21h6z"
  })), children);
});
var CloudFoundry_216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudFoundry_216(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 11L25 9 17 9 17 23 19 23 19 17 24 17 24 15 19 15 19 11 25 11zM15 23H9a2 2 0 01-2-2V11A2 2 0 019 9h6v2H9V21h6z"
  })), children);
});
var CloudRegistry32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudRegistry32(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H23a2.0023 2.0023 0 01-2-2V23a2.0023 2.0023 0 012-2h5a2.0023 2.0023 0 012 2v5A2.0023 2.0023 0 0128 30zm-5-7h-.0012L23 28h5V23zM16 23H11a2.0023 2.0023 0 01-2-2V11a2.0023 2.0023 0 012-2H21a2.0023 2.0023 0 012 2v5H21V11H11V21h5z"
  })), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30H4a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,4,2H28a2.0023,2.0023,0,0,1,2,2V16H28V4H4V28H16Z"
  })), children);
});
var CloudRegistry24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudRegistry24(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H23a2.0023 2.0023 0 01-2-2V23a2.0023 2.0023 0 012-2h5a2.0023 2.0023 0 012 2v5A2.0023 2.0023 0 0128 30zm-5-7h-.0012L23 28h5V23zM16 23H11a2.0023 2.0023 0 01-2-2V11a2.0023 2.0023 0 012-2H21a2.0023 2.0023 0 012 2v5H21V11H11V21h5z"
  })), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30H4a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,4,2H28a2.0023,2.0023,0,0,1,2,2V16H28V4H4V28H16Z"
  })), children);
});
var CloudRegistry20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudRegistry20(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H23a2.0023 2.0023 0 01-2-2V23a2.0023 2.0023 0 012-2h5a2.0023 2.0023 0 012 2v5A2.0023 2.0023 0 0128 30zm-5-7h-.0012L23 28h5V23zM16 23H11a2.0023 2.0023 0 01-2-2V11a2.0023 2.0023 0 012-2H21a2.0023 2.0023 0 012 2v5H21V11H11V21h5z"
  })), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30H4a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,4,2H28a2.0023,2.0023,0,0,1,2,2V16H28V4H4V28H16Z"
  })), children);
});
var CloudRegistry16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudRegistry16(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H23a2.0023 2.0023 0 01-2-2V23a2.0023 2.0023 0 012-2h5a2.0023 2.0023 0 012 2v5A2.0023 2.0023 0 0128 30zm-5-7h-.0012L23 28h5V23zM16 23H11a2.0023 2.0023 0 01-2-2V11a2.0023 2.0023 0 012-2H21a2.0023 2.0023 0 012 2v5H21V11H11V21h5z"
  })), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30H4a2.0023,2.0023,0,0,1-2-2V4A2.0023,2.0023,0,0,1,4,2H28a2.0023,2.0023,0,0,1,2,2V16H28V4H4V28H16Z"
  })), children);
});
var CloudSatellite32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSatellite32(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "20",
    r: "2"
  })), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,20a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,16,20Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,16,14Z"
  })), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "12",
    r: "2"
  })), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,31a.9988.9988,0,0,1-.5039-.1357l-12-7A1.0008,1.0008,0,0,1,3,23V9a.9994.9994,0,0,1,.4961-.8638l12-7a1,1,0,0,1,1.0078,0l12,7L27.4961,9.8638,16,3.1577,5,9.5742V22.4258l11,6.417,11-6.417V15h2v8a1.0008,1.0008,0,0,1-.4961.8643l-12,7A.9988.9988,0,0,1,16,31Z"
  })), children);
});
var CloudSatellite24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSatellite24(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "20",
    r: "2"
  })), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,20a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,16,20Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,16,14Z"
  })), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "12",
    r: "2"
  })), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,31a.9988.9988,0,0,1-.5039-.1357l-12-7A1.0008,1.0008,0,0,1,3,23V9a.9994.9994,0,0,1,.4961-.8638l12-7a1,1,0,0,1,1.0078,0l12,7L27.4961,9.8638,16,3.1577,5,9.5742V22.4258l11,6.417,11-6.417V15h2v8a1.0008,1.0008,0,0,1-.4961.8643l-12,7A.9988.9988,0,0,1,16,31Z"
  })), children);
});
var CloudSatellite20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSatellite20(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "20",
    r: "2"
  })), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,20a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,16,20Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,16,14Z"
  })), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "12",
    r: "2"
  })), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,31a.9988.9988,0,0,1-.5039-.1357l-12-7A1.0008,1.0008,0,0,1,3,23V9a.9994.9994,0,0,1,.4961-.8638l12-7a1,1,0,0,1,1.0078,0l12,7L27.4961,9.8638,16,3.1577,5,9.5742V22.4258l11,6.417,11-6.417V15h2v8a1.0008,1.0008,0,0,1-.4961.8643l-12,7A.9988.9988,0,0,1,16,31Z"
  })), children);
});
var CloudSatellite16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSatellite16(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "20",
    r: "2"
  })), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,20a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,16,20Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,16,14Z"
  })), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "12",
    r: "2"
  })), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,31a.9988.9988,0,0,1-.5039-.1357l-12-7A1.0008,1.0008,0,0,1,3,23V9a.9994.9994,0,0,1,.4961-.8638l12-7a1,1,0,0,1,1.0078,0l12,7L27.4961,9.8638,16,3.1577,5,9.5742V22.4258l11,6.417,11-6.417V15h2v8a1.0008,1.0008,0,0,1-.4961.8643l-12,7A.9988.9988,0,0,1,16,31Z"
  })), children);
});
var CloudSatelliteConfig32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSatelliteConfig32(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32,26V24H29.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,26,20.1011V18H24v2.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,20.1011,24H18v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,24,29.8989V32h2V29.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,29.8989,26Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,25,28Z"
  })), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "20",
    r: "2"
  })), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,14,20Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,14,14Z"
  })), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "12",
    r: "2"
  })), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.0205,28.2715,3,22.4258V9.5742L14,3.1577,25.4961,9.8638l1.0078-1.7276-12-7a1,1,0,0,0-1.0078,0l-12,7A.9994.9994,0,0,0,1,9V23a1.0008,1.0008,0,0,0,.4961.8643L12.0127,30Z"
  })), children);
});
var CloudSatelliteConfig24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSatelliteConfig24(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32,26V24H29.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,26,20.1011V18H24v2.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,20.1011,24H18v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,24,29.8989V32h2V29.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,29.8989,26Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,25,28Z"
  })), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "20",
    r: "2"
  })), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,14,20Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,14,14Z"
  })), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "12",
    r: "2"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.0205,28.2715,3,22.4258V9.5742L14,3.1577,25.4961,9.8638l1.0078-1.7276-12-7a1,1,0,0,0-1.0078,0l-12,7A.9994.9994,0,0,0,1,9V23a1.0008,1.0008,0,0,0,.4961.8643L12.0127,30Z"
  })), children);
});
var CloudSatelliteConfig20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSatelliteConfig20(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32,26V24H29.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,26,20.1011V18H24v2.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,20.1011,24H18v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,24,29.8989V32h2V29.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,29.8989,26Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,25,28Z"
  })), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "20",
    r: "2"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,14,20Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,14,14Z"
  })), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "12",
    r: "2"
  })), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.0205,28.2715,3,22.4258V9.5742L14,3.1577,25.4961,9.8638l1.0078-1.7276-12-7a1,1,0,0,0-1.0078,0l-12,7A.9994.9994,0,0,0,1,9V23a1.0008,1.0008,0,0,0,.4961.8643L12.0127,30Z"
  })), children);
});
var CloudSatelliteConfig16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSatelliteConfig16(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M32,26V24H29.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,26,20.1011V18H24v2.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,20.1011,24H18v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,24,29.8989V32h2V29.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,29.8989,26Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,25,28Z"
  })), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "20",
    r: "2"
  })), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,14,20Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,14,14Z"
  })), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "12",
    r: "2"
  })), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.0205,28.2715,3,22.4258V9.5742L14,3.1577,25.4961,9.8638l1.0078-1.7276-12-7a1,1,0,0,0-1.0078,0l-12,7A.9994.9994,0,0,0,1,9V23a1.0008,1.0008,0,0,0,.4961.8643L12.0127,30Z"
  })), children);
});
var CloudSatelliteLink32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSatelliteLink32(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.9763,24.9748l-5.0015,5.0015a3.501,3.501,0,0,1-4.9511-4.9511L22.4383,26.44A1.5,1.5,0,0,0,24.56,28.5617L29.5617,23.56A1.5,1.5,0,0,0,27.44,21.4383l-1.4146-1.4146a3.501,3.501,0,0,1,4.9511,4.9511Z"
  })), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.0252,21.0237l-5.0015,5.0015a3.501,3.501,0,0,0,4.9511,4.9511L18.56,29.5617A1.5,1.5,0,0,1,16.4383,27.44L21.44,22.4383A1.5,1.5,0,0,1,23.5617,24.56l1.4146,1.4146a3.501,3.501,0,0,0-4.9511-4.9511Z"
  })), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "20",
    r: "2"
  })), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,14,20Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,14,14Z"
  })), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "12",
    r: "2"
  })), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.3076,27.2725,3,22.4258V9.5742L14,3.1577,25.4961,9.8638l1.0078-1.7276-12-7a1,1,0,0,0-1.0078,0l-12,7A.9994.9994,0,0,0,1,9V23a1.0008,1.0008,0,0,0,.4961.8643L10.3,29Z"
  })), children);
});
var CloudSatelliteLink24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSatelliteLink24(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.9763,24.9748l-5.0015,5.0015a3.501,3.501,0,0,1-4.9511-4.9511L22.4383,26.44A1.5,1.5,0,0,0,24.56,28.5617L29.5617,23.56A1.5,1.5,0,0,0,27.44,21.4383l-1.4146-1.4146a3.501,3.501,0,0,1,4.9511,4.9511Z"
  })), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.0252,21.0237l-5.0015,5.0015a3.501,3.501,0,0,0,4.9511,4.9511L18.56,29.5617A1.5,1.5,0,0,1,16.4383,27.44L21.44,22.4383A1.5,1.5,0,0,1,23.5617,24.56l1.4146,1.4146a3.501,3.501,0,0,0-4.9511-4.9511Z"
  })), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "20",
    r: "2"
  })), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,14,20Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,14,14Z"
  })), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "12",
    r: "2"
  })), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.3076,27.2725,3,22.4258V9.5742L14,3.1577,25.4961,9.8638l1.0078-1.7276-12-7a1,1,0,0,0-1.0078,0l-12,7A.9994.9994,0,0,0,1,9V23a1.0008,1.0008,0,0,0,.4961.8643L10.3,29Z"
  })), children);
});
var CloudSatelliteLink20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSatelliteLink20(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.9763,24.9748l-5.0015,5.0015a3.501,3.501,0,0,1-4.9511-4.9511L22.4383,26.44A1.5,1.5,0,0,0,24.56,28.5617L29.5617,23.56A1.5,1.5,0,0,0,27.44,21.4383l-1.4146-1.4146a3.501,3.501,0,0,1,4.9511,4.9511Z"
  })), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.0252,21.0237l-5.0015,5.0015a3.501,3.501,0,0,0,4.9511,4.9511L18.56,29.5617A1.5,1.5,0,0,1,16.4383,27.44L21.44,22.4383A1.5,1.5,0,0,1,23.5617,24.56l1.4146,1.4146a3.501,3.501,0,0,0-4.9511-4.9511Z"
  })), _circle21 || (_circle21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "20",
    r: "2"
  })), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,14,20Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,14,14Z"
  })), _circle22 || (_circle22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "12",
    r: "2"
  })), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.3076,27.2725,3,22.4258V9.5742L14,3.1577,25.4961,9.8638l1.0078-1.7276-12-7a1,1,0,0,0-1.0078,0l-12,7A.9994.9994,0,0,0,1,9V23a1.0008,1.0008,0,0,0,.4961.8643L10.3,29Z"
  })), children);
});
var CloudSatelliteLink16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSatelliteLink16(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.9763,24.9748l-5.0015,5.0015a3.501,3.501,0,0,1-4.9511-4.9511L22.4383,26.44A1.5,1.5,0,0,0,24.56,28.5617L29.5617,23.56A1.5,1.5,0,0,0,27.44,21.4383l-1.4146-1.4146a3.501,3.501,0,0,1,4.9511,4.9511Z"
  })), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.0252,21.0237l-5.0015,5.0015a3.501,3.501,0,0,0,4.9511,4.9511L18.56,29.5617A1.5,1.5,0,0,1,16.4383,27.44L21.44,22.4383A1.5,1.5,0,0,1,23.5617,24.56l1.4146,1.4146a3.501,3.501,0,0,0-4.9511-4.9511Z"
  })), _circle23 || (_circle23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "20",
    r: "2"
  })), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,14,20Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,14,14Z"
  })), _circle24 || (_circle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "12",
    r: "2"
  })), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.3076,27.2725,3,22.4258V9.5742L14,3.1577,25.4961,9.8638l1.0078-1.7276-12-7a1,1,0,0,0-1.0078,0l-12,7A.9994.9994,0,0,0,1,9V23a1.0008,1.0008,0,0,0,.4961.8643L10.3,29Z"
  })), children);
});
var CloudSatelliteServices32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSatelliteServices32(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,26a2.97,2.97,0,0,0-1.8551.6607L25,25.4224V23.8157a3,3,0,1,0-2,0v1.6067l-2.1449,1.2383A2.97,2.97,0,0,0,19,26a3.02,3.02,0,1,0,2.9254,2.3525L24,27.1548l2.0746,1.1977A2.9978,2.9978,0,1,0,29,26ZM19,30a1,1,0,1,1,1-1A1.0006,1.0006,0,0,1,19,30Zm5-10a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,24,20Zm5,10a1,1,0,1,1,1-1A1.0006,1.0006,0,0,1,29,30Z"
  })), _circle25 || (_circle25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "20",
    r: "2"
  })), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,14,20Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,14,14Z"
  })), _circle26 || (_circle26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "12",
    r: "2"
  })), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.0205,28.2715,3,22.4258V9.5742L14,3.1577,25.4961,9.8638l1.0078-1.7276-12-7a1,1,0,0,0-1.0078,0l-12,7A.9994.9994,0,0,0,1,9V23a1.0008,1.0008,0,0,0,.4961.8643L12.0127,30Z"
  })), children);
});
var CloudSatelliteServices24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSatelliteServices24(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,26a2.97,2.97,0,0,0-1.8551.6607L25,25.4224V23.8157a3,3,0,1,0-2,0v1.6067l-2.1449,1.2383A2.97,2.97,0,0,0,19,26a3.02,3.02,0,1,0,2.9254,2.3525L24,27.1548l2.0746,1.1977A2.9978,2.9978,0,1,0,29,26ZM19,30a1,1,0,1,1,1-1A1.0006,1.0006,0,0,1,19,30Zm5-10a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,24,20Zm5,10a1,1,0,1,1,1-1A1.0006,1.0006,0,0,1,29,30Z"
  })), _circle27 || (_circle27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "20",
    r: "2"
  })), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,14,20Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,14,14Z"
  })), _circle28 || (_circle28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "12",
    r: "2"
  })), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.0205,28.2715,3,22.4258V9.5742L14,3.1577,25.4961,9.8638l1.0078-1.7276-12-7a1,1,0,0,0-1.0078,0l-12,7A.9994.9994,0,0,0,1,9V23a1.0008,1.0008,0,0,0,.4961.8643L12.0127,30Z"
  })), children);
});
var CloudSatelliteServices20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSatelliteServices20(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,26a2.97,2.97,0,0,0-1.8551.6607L25,25.4224V23.8157a3,3,0,1,0-2,0v1.6067l-2.1449,1.2383A2.97,2.97,0,0,0,19,26a3.02,3.02,0,1,0,2.9254,2.3525L24,27.1548l2.0746,1.1977A2.9978,2.9978,0,1,0,29,26ZM19,30a1,1,0,1,1,1-1A1.0006,1.0006,0,0,1,19,30Zm5-10a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,24,20Zm5,10a1,1,0,1,1,1-1A1.0006,1.0006,0,0,1,29,30Z"
  })), _circle29 || (_circle29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "20",
    r: "2"
  })), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,14,20Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,14,14Z"
  })), _circle30 || (_circle30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "12",
    r: "2"
  })), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.0205,28.2715,3,22.4258V9.5742L14,3.1577,25.4961,9.8638l1.0078-1.7276-12-7a1,1,0,0,0-1.0078,0l-12,7A.9994.9994,0,0,0,1,9V23a1.0008,1.0008,0,0,0,.4961.8643L12.0127,30Z"
  })), children);
});
var CloudSatelliteServices16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudSatelliteServices16(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,26a2.97,2.97,0,0,0-1.8551.6607L25,25.4224V23.8157a3,3,0,1,0-2,0v1.6067l-2.1449,1.2383A2.97,2.97,0,0,0,19,26a3.02,3.02,0,1,0,2.9254,2.3525L24,27.1548l2.0746,1.1977A2.9978,2.9978,0,1,0,29,26ZM19,30a1,1,0,1,1,1-1A1.0006,1.0006,0,0,1,19,30Zm5-10a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,24,20Zm5,10a1,1,0,1,1,1-1A1.0006,1.0006,0,0,1,29,30Z"
  })), _circle31 || (_circle31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "20",
    r: "2"
  })), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14,20a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,14,20Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,14,14Z"
  })), _circle32 || (_circle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "12",
    r: "2"
  })), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13.0205,28.2715,3,22.4258V9.5742L14,3.1577,25.4961,9.8638l1.0078-1.7276-12-7a1,1,0,0,0-1.0078,0l-12,7A.9994.9994,0,0,0,1,9V23a1.0008,1.0008,0,0,0,.4961.8643L12.0127,30Z"
  })), children);
});
var CloudServices32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudServices32(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.8218,10.124a9.9991,9.9991,0,0,0-19.6435,0A7.4964,7.4964,0,0,0,7.5,25H8V23H7.5a5.4961,5.4961,0,0,1-.3769-10.9795l.8364-.0571.09-.8335a7.9979,7.9979,0,0,1,15.9013,0l.09.8335.8364.0571A5.4961,5.4961,0,0,1,24.5,23H24v2h.5a7.4964,7.4964,0,0,0,1.3218-14.876Z"
  })), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,22V20H20.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,17,16.1011V14H15v2.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,11.1011,20H9v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,15,25.8989V28h2V25.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,20.8989,22Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,16,24Z"
  })), children);
});
var CloudServices24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudServices24(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.8218,10.124a9.9991,9.9991,0,0,0-19.6435,0A7.4964,7.4964,0,0,0,7.5,25H8V23H7.5a5.4961,5.4961,0,0,1-.3769-10.9795l.8364-.0571.09-.8335a7.9979,7.9979,0,0,1,15.9013,0l.09.8335.8364.0571A5.4961,5.4961,0,0,1,24.5,23H24v2h.5a7.4964,7.4964,0,0,0,1.3218-14.876Z"
  })), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,22V20H20.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,17,16.1011V14H15v2.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,11.1011,20H9v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,15,25.8989V28h2V25.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,20.8989,22Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,16,24Z"
  })), children);
});
var CloudServices20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudServices20(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.8218,10.124a9.9991,9.9991,0,0,0-19.6435,0A7.4964,7.4964,0,0,0,7.5,25H8V23H7.5a5.4961,5.4961,0,0,1-.3769-10.9795l.8364-.0571.09-.8335a7.9979,7.9979,0,0,1,15.9013,0l.09.8335.8364.0571A5.4961,5.4961,0,0,1,24.5,23H24v2h.5a7.4964,7.4964,0,0,0,1.3218-14.876Z"
  })), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,22V20H20.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,17,16.1011V14H15v2.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,11.1011,20H9v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,15,25.8989V28h2V25.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,20.8989,22Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,16,24Z"
  })), children);
});
var CloudServices16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CloudServices16(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.8218,10.124a9.9991,9.9991,0,0,0-19.6435,0A7.4964,7.4964,0,0,0,7.5,25H8V23H7.5a5.4961,5.4961,0,0,1-.3769-10.9795l.8364-.0571.09-.8335a7.9979,7.9979,0,0,1,15.9013,0l.09.8335.8364.0571A5.4961,5.4961,0,0,1,24.5,23H24v2h.5a7.4964,7.4964,0,0,0,1.3218-14.876Z"
  })), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,22V20H20.8989a4.9678,4.9678,0,0,0-.7319-1.7529l1.49-1.49-1.414-1.414-1.49,1.49A4.9678,4.9678,0,0,0,17,16.1011V14H15v2.1011a4.9678,4.9678,0,0,0-1.7529.7319l-1.49-1.49-1.414,1.414,1.49,1.49A4.9678,4.9678,0,0,0,11.1011,20H9v2h2.1011a4.9678,4.9678,0,0,0,.7319,1.7529l-1.49,1.49,1.414,1.414,1.49-1.49A4.9678,4.9678,0,0,0,15,25.8989V28h2V25.8989a4.9678,4.9678,0,0,0,1.7529-.7319l1.49,1.49,1.414-1.414-1.49-1.49A4.9678,4.9678,0,0,0,20.8989,22Zm-7,2a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,16,24Z"
  })), children);
});
var Cloudy32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cloudy32(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.0005,15.5005a6.5324,6.5324,0,0,0-5.1992-6.3638,8.9943,8.9943,0,0,0-17.6006,0,6.5321,6.5321,0,0,0-5.2,6.3638,6.4543,6.4543,0,0,0,1.6887,4.35A5.9829,5.9829,0,0,0,8,30H19a5.9764,5.9764,0,0,0,5.6094-8.1016A6.5051,6.5051,0,0,0,30.0005,15.5005ZM19,28H8a3.9925,3.9925,0,0,1-.6731-7.9292L7.99,19.958l.1458-.6562a5.496,5.496,0,0,1,10.7294,0l.1458.6562.6626.1128A3.9925,3.9925,0,0,1,19,28Zm4.5-8h-.0554a5.9562,5.9562,0,0,0-2.7959-1.7564,7.4952,7.4952,0,0,0-14.2984,0,5.9877,5.9877,0,0,0-1.0315.4073A4.4446,4.4446,0,0,1,4,15.5005a4.5171,4.5171,0,0,1,4.144-4.481l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639a4.4975,4.4975,0,0,1-.3564,8.981Z"
  })), children);
});
var Cloudy24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cloudy24(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.0005,15.5005a6.5324,6.5324,0,0,0-5.1992-6.3638,8.9943,8.9943,0,0,0-17.6006,0,6.5321,6.5321,0,0,0-5.2,6.3638,6.4543,6.4543,0,0,0,1.6887,4.35A5.9829,5.9829,0,0,0,8,30H19a5.9764,5.9764,0,0,0,5.6094-8.1016A6.5051,6.5051,0,0,0,30.0005,15.5005ZM19,28H8a3.9925,3.9925,0,0,1-.6731-7.9292L7.99,19.958l.1458-.6562a5.496,5.496,0,0,1,10.7294,0l.1458.6562.6626.1128A3.9925,3.9925,0,0,1,19,28Zm4.5-8h-.0554a5.9562,5.9562,0,0,0-2.7959-1.7564,7.4952,7.4952,0,0,0-14.2984,0,5.9877,5.9877,0,0,0-1.0315.4073A4.4446,4.4446,0,0,1,4,15.5005a4.5171,4.5171,0,0,1,4.144-4.481l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639a4.4975,4.4975,0,0,1-.3564,8.981Z"
  })), children);
});
var Cloudy20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cloudy20(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.0005,15.5005a6.5324,6.5324,0,0,0-5.1992-6.3638,8.9943,8.9943,0,0,0-17.6006,0,6.5321,6.5321,0,0,0-5.2,6.3638,6.4543,6.4543,0,0,0,1.6887,4.35A5.9829,5.9829,0,0,0,8,30H19a5.9764,5.9764,0,0,0,5.6094-8.1016A6.5051,6.5051,0,0,0,30.0005,15.5005ZM19,28H8a3.9925,3.9925,0,0,1-.6731-7.9292L7.99,19.958l.1458-.6562a5.496,5.496,0,0,1,10.7294,0l.1458.6562.6626.1128A3.9925,3.9925,0,0,1,19,28Zm4.5-8h-.0554a5.9562,5.9562,0,0,0-2.7959-1.7564,7.4952,7.4952,0,0,0-14.2984,0,5.9877,5.9877,0,0,0-1.0315.4073A4.4446,4.4446,0,0,1,4,15.5005a4.5171,4.5171,0,0,1,4.144-4.481l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639a4.4975,4.4975,0,0,1-.3564,8.981Z"
  })), children);
});
var Cloudy16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cloudy16(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30.0005,15.5005a6.5324,6.5324,0,0,0-5.1992-6.3638,8.9943,8.9943,0,0,0-17.6006,0,6.5321,6.5321,0,0,0-5.2,6.3638,6.4543,6.4543,0,0,0,1.6887,4.35A5.9829,5.9829,0,0,0,8,30H19a5.9764,5.9764,0,0,0,5.6094-8.1016A6.5051,6.5051,0,0,0,30.0005,15.5005ZM19,28H8a3.9925,3.9925,0,0,1-.6731-7.9292L7.99,19.958l.1458-.6562a5.496,5.496,0,0,1,10.7294,0l.1458.6562.6626.1128A3.9925,3.9925,0,0,1,19,28Zm4.5-8h-.0554a5.9562,5.9562,0,0,0-2.7959-1.7564,7.4952,7.4952,0,0,0-14.2984,0,5.9877,5.9877,0,0,0-1.0315.4073A4.4446,4.4446,0,0,1,4,15.5005a4.5171,4.5171,0,0,1,4.144-4.481l.8155-.0639.0991-.812a6.9938,6.9938,0,0,1,13.8838,0l.0986.812.8154.0639a4.4975,4.4975,0,0,1-.3564,8.981Z"
  })), children);
});
var WatsonHealthCobbAngle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCobbAngle32(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 17V15a2 2 0 00-2-2H10a2 2 0 00-2 2v2a2 2 0 002 2h8A2 2 0 0020 17zM10 15h8v2H10zM23.42 24.48A2 2 0 0021 23.06l-7.73 2.07a2 2 0 00-1.42 2.44h0l.52 1.93A2 2 0 0014.27 31a3 3 0 00.52-.07l7.73-2.07h0a2 2 0 001.41-2.45zM14.27 29l-.51-1.94L21.48 25 22 26.92zM13.24 6.86L21 8.93h0a2.24 2.24 0 00.51.07 2 2 0 001.94-1.48L24 5.58a2 2 0 00-1.41-2.45L14.79 1.06a2 2 0 00-2.45 1.41h0l-.52 1.93a2 2 0 001.42 2.44zm1-3.86L22 5.07 21.48 7 13.76 4.93zM14 21H16V23H14zM14 9H16V11H14z"
  })), children);
});
var WatsonHealthCobbAngle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCobbAngle24(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 17V15a2 2 0 00-2-2H10a2 2 0 00-2 2v2a2 2 0 002 2h8A2 2 0 0020 17zM10 15h8v2H10zM23.42 24.48A2 2 0 0021 23.06l-7.73 2.07a2 2 0 00-1.42 2.44h0l.52 1.93A2 2 0 0014.27 31a3 3 0 00.52-.07l7.73-2.07h0a2 2 0 001.41-2.45zM14.27 29l-.51-1.94L21.48 25 22 26.92zM13.24 6.86L21 8.93h0a2.24 2.24 0 00.51.07 2 2 0 001.94-1.48L24 5.58a2 2 0 00-1.41-2.45L14.79 1.06a2 2 0 00-2.45 1.41h0l-.52 1.93a2 2 0 001.42 2.44zm1-3.86L22 5.07 21.48 7 13.76 4.93zM14 21H16V23H14zM14 9H16V11H14z"
  })), children);
});
var WatsonHealthCobbAngle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCobbAngle20(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 17V15a2 2 0 00-2-2H10a2 2 0 00-2 2v2a2 2 0 002 2h8A2 2 0 0020 17zM10 15h8v2H10zM23.42 24.48A2 2 0 0021 23.06l-7.73 2.07a2 2 0 00-1.42 2.44h0l.52 1.93A2 2 0 0014.27 31a3 3 0 00.52-.07l7.73-2.07h0a2 2 0 001.41-2.45zM14.27 29l-.51-1.94L21.48 25 22 26.92zM13.24 6.86L21 8.93h0a2.24 2.24 0 00.51.07 2 2 0 001.94-1.48L24 5.58a2 2 0 00-1.41-2.45L14.79 1.06a2 2 0 00-2.45 1.41h0l-.52 1.93a2 2 0 001.42 2.44zm1-3.86L22 5.07 21.48 7 13.76 4.93zM14 21H16V23H14zM14 9H16V11H14z"
  })), children);
});
var WatsonHealthCobbAngle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCobbAngle16(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 17V15a2 2 0 00-2-2H10a2 2 0 00-2 2v2a2 2 0 002 2h8A2 2 0 0020 17zM10 15h8v2H10zM23.42 24.48A2 2 0 0021 23.06l-7.73 2.07a2 2 0 00-1.42 2.44h0l.52 1.93A2 2 0 0014.27 31a3 3 0 00.52-.07l7.73-2.07h0a2 2 0 001.41-2.45zM14.27 29l-.51-1.94L21.48 25 22 26.92zM13.24 6.86L21 8.93h0a2.24 2.24 0 00.51.07 2 2 0 001.94-1.48L24 5.58a2 2 0 00-1.41-2.45L14.79 1.06a2 2 0 00-2.45 1.41h0l-.52 1.93a2 2 0 001.42 2.44zm1-3.86L22 5.07 21.48 7 13.76 4.93zM14 21H16V23H14zM14 9H16V11H14z"
  })), children);
});
var Code32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Code32(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 16L24 23 22.59 21.59 28.17 16 22.59 10.41 24 9 31 16zM1 16L8 9 9.41 10.41 3.83 16 9.41 21.59 8 23 1 16z"
  })), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.91 15H26.080000000000002V17H5.91z",
    transform: "rotate(-75 15.996 16)"
  })), children);
});
var Code24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Code24(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 16L24 23 22.59 21.59 28.17 16 22.59 10.41 24 9 31 16zM1 16L8 9 9.41 10.41 3.83 16 9.41 21.59 8 23 1 16z"
  })), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.91 15H26.080000000000002V17H5.91z",
    transform: "rotate(-75 15.996 16)"
  })), children);
});
var Code20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Code20(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 16L24 23 22.59 21.59 28.17 16 22.59 10.41 24 9 31 16zM1 16L8 9 9.41 10.41 3.83 16 9.41 21.59 8 23 1 16z"
  })), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.91 15H26.080000000000002V17H5.91z",
    transform: "rotate(-75 15.996 16)"
  })), children);
});
var Code16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Code16(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M31 16L24 23 22.59 21.59 28.17 16 22.59 10.41 24 9 31 16zM1 16L8 9 9.41 10.41 3.83 16 9.41 21.59 8 23 1 16z"
  })), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5.91 15H26.080000000000002V17H5.91z",
    transform: "rotate(-75 15.996 16)"
  })), children);
});
var CodeHide32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CodeHide32(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.713 13.471L19.576 6.518 17.645 6 16.08 11.838 17.713 13.471zM24.207 19.965L25.621 21.379 31 16 24 9 22.586 10.414 28.172 16 24.207 19.965zM30 28.586L3.414 2 2 3.414 7.793 9.207 1 16 8 23 9.414 21.586 3.828 16 9.207 10.621 14.884 16.298 12.423 25.482 14.355 26 16.517 17.931 28.586 30 30 28.586z"
  })), children);
});
var CodeHide24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CodeHide24(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.713 13.471L19.576 6.518 17.645 6 16.08 11.838 17.713 13.471zM24.207 19.965L25.621 21.379 31 16 24 9 22.586 10.414 28.172 16 24.207 19.965zM30 28.586L3.414 2 2 3.414 7.793 9.207 1 16 8 23 9.414 21.586 3.828 16 9.207 10.621 14.884 16.298 12.423 25.482 14.355 26 16.517 17.931 28.586 30 30 28.586z"
  })), children);
});
var CodeHide20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CodeHide20(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.713 13.471L19.576 6.518 17.645 6 16.08 11.838 17.713 13.471zM24.207 19.965L25.621 21.379 31 16 24 9 22.586 10.414 28.172 16 24.207 19.965zM30 28.586L3.414 2 2 3.414 7.793 9.207 1 16 8 23 9.414 21.586 3.828 16 9.207 10.621 14.884 16.298 12.423 25.482 14.355 26 16.517 17.931 28.586 30 30 28.586z"
  })), children);
});
var CodeHide16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CodeHide16(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.713 13.471L19.576 6.518 17.645 6 16.08 11.838 17.713 13.471zM24.207 19.965L25.621 21.379 31 16 24 9 22.586 10.414 28.172 16 24.207 19.965zM30 28.586L3.414 2 2 3.414 7.793 9.207 1 16 8 23 9.414 21.586 3.828 16 9.207 10.621 14.884 16.298 12.423 25.482 14.355 26 16.517 17.931 28.586 30 30 28.586z"
  })), children);
});
var CodeReference32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CodeReference32(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM30 10L24 4 22.586 5.414 27.172 10 22.586 14.586 24 16 30 10z"
  })), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.944 9.001H24.974000000000004V11.001H8.944z",
    transform: "rotate(-74.995 16.96 10)"
  })), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 10L10 4 11.414 5.414 6.828 10 11.414 14.586 10 16 4 10z"
  })), children);
});
var CodeReference24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CodeReference24(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM30 10L24 4 22.586 5.414 27.172 10 22.586 14.586 24 16 30 10z"
  })), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.944 9.001H24.974000000000004V11.001H8.944z",
    transform: "rotate(-74.995 16.96 10)"
  })), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 10L10 4 11.414 5.414 6.828 10 11.414 14.586 10 16 4 10z"
  })), children);
});
var CodeReference20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CodeReference20(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM30 10L24 4 22.586 5.414 27.172 10 22.586 14.586 24 16 30 10z"
  })), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.944 9.001H24.974000000000004V11.001H8.944z",
    transform: "rotate(-74.995 16.96 10)"
  })), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 10L10 4 11.414 5.414 6.828 10 11.414 14.586 10 16 4 10z"
  })), children);
});
var CodeReference16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CodeReference16(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM30 10L24 4 22.586 5.414 27.172 10 22.586 14.586 24 16 30 10z"
  })), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.944 9.001H24.974000000000004V11.001H8.944z",
    transform: "rotate(-74.995 16.96 10)"
  })), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 10L10 4 11.414 5.414 6.828 10 11.414 14.586 10 16 4 10z"
  })), children);
});
var CodeSigningService32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CodeSigningService32(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle33 || (_circle33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "20",
    r: "1"
  })), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.4141 30H15V25.5857l5.0337-5.0337A4.6069 4.6069 0 0120 20a5 5 0 114.4478 4.9663zM17 28h1.5859l5.2061-5.2063.5395.1238a3.0351 3.0351 0 10-2.249-2.2488l.1236.5393L17 26.4143zM6 8H8V16H6zM2 8H4V16H2zM18 8H20V14H18zM14 16H12a2 2 0 01-2-2V10a2 2 0 012-2h2a2 2 0 012 2v4A2 2 0 0114 16zm-2-2h2V10H12zM2 18H4V26H2zM14 18H16V22H14zM10 26H8a2 2 0 01-2-2V20a2 2 0 012-2h2a2 2 0 012 2v4A2 2 0 0110 26zM8 24h2V20H8zM2 2H4V6H2zM14 2H16V6H14zM18 2H20V6H18zM10 6H8A2 2 0 016 4V2H8V4h2V2h2V4A2 2 0 0110 6z"
  })), children);
});
var CodeSigningService24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CodeSigningService24(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle34 || (_circle34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "20",
    r: "1"
  })), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.4141 30H15V25.5857l5.0337-5.0337A4.6069 4.6069 0 0120 20a5 5 0 114.4478 4.9663zM17 28h1.5859l5.2061-5.2063.5395.1238a3.0351 3.0351 0 10-2.249-2.2488l.1236.5393L17 26.4143zM6 8H8V16H6zM2 8H4V16H2zM18 8H20V14H18zM14 16H12a2 2 0 01-2-2V10a2 2 0 012-2h2a2 2 0 012 2v4A2 2 0 0114 16zm-2-2h2V10H12zM2 18H4V26H2zM14 18H16V22H14zM10 26H8a2 2 0 01-2-2V20a2 2 0 012-2h2a2 2 0 012 2v4A2 2 0 0110 26zM8 24h2V20H8zM2 2H4V6H2zM14 2H16V6H14zM18 2H20V6H18zM10 6H8A2 2 0 016 4V2H8V4h2V2h2V4A2 2 0 0110 6z"
  })), children);
});
var CodeSigningService20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CodeSigningService20(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle35 || (_circle35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "20",
    r: "1"
  })), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.4141 30H15V25.5857l5.0337-5.0337A4.6069 4.6069 0 0120 20a5 5 0 114.4478 4.9663zM17 28h1.5859l5.2061-5.2063.5395.1238a3.0351 3.0351 0 10-2.249-2.2488l.1236.5393L17 26.4143zM6 8H8V16H6zM2 8H4V16H2zM18 8H20V14H18zM14 16H12a2 2 0 01-2-2V10a2 2 0 012-2h2a2 2 0 012 2v4A2 2 0 0114 16zm-2-2h2V10H12zM2 18H4V26H2zM14 18H16V22H14zM10 26H8a2 2 0 01-2-2V20a2 2 0 012-2h2a2 2 0 012 2v4A2 2 0 0110 26zM8 24h2V20H8zM2 2H4V6H2zM14 2H16V6H14zM18 2H20V6H18zM10 6H8A2 2 0 016 4V2H8V4h2V2h2V4A2 2 0 0110 6z"
  })), children);
});
var CodeSigningService16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CodeSigningService16(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle36 || (_circle36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "20",
    r: "1"
  })), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.4141 30H15V25.5857l5.0337-5.0337A4.6069 4.6069 0 0120 20a5 5 0 114.4478 4.9663zM17 28h1.5859l5.2061-5.2063.5395.1238a3.0351 3.0351 0 10-2.249-2.2488l.1236.5393L17 26.4143zM6 8H8V16H6zM2 8H4V16H2zM18 8H20V14H18zM14 16H12a2 2 0 01-2-2V10a2 2 0 012-2h2a2 2 0 012 2v4A2 2 0 0114 16zm-2-2h2V10H12zM2 18H4V26H2zM14 18H16V22H14zM10 26H8a2 2 0 01-2-2V20a2 2 0 012-2h2a2 2 0 012 2v4A2 2 0 0110 26zM8 24h2V20H8zM2 2H4V6H2zM14 2H16V6H14zM18 2H20V6H18zM10 6H8A2 2 0 016 4V2H8V4h2V2h2V4A2 2 0 0110 6z"
  })), children);
});
var Cognitive32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cognitive32(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,13A11,11,0,0,0,19,2H11a9,9,0,0,0-9,9v3a5,5,0,0,0,5,5H8.1A5,5,0,0,0,13,23h1.38l4,7,1.73-1-4-6.89A2,2,0,0,0,14.38,21H13a3,3,0,0,1,0-6h1V13H13a5,5,0,0,0-4.9,4H7a3,3,0,0,1-3-3V12H6A3,3,0,0,0,9,9V8H7V9a1,1,0,0,1-1,1H4.08A7,7,0,0,1,11,4h6V6a1,1,0,0,1-1,1H14V9h2a3,3,0,0,0,3-3V4a9,9,0,0,1,8.05,5H26a3,3,0,0,0-3,3v1h2V12a1,1,0,0,1,1-1h1.77A8.76,8.76,0,0,1,28,13v1a5,5,0,0,1-5,5H20v2h3a7,7,0,0,0,3-.68V21a3,3,0,0,1-3,3H22v2h1a5,5,0,0,0,5-5V18.89A7,7,0,0,0,30,14Z"
  })), children);
});
var Cognitive24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cognitive24(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,13A11,11,0,0,0,19,2H11a9,9,0,0,0-9,9v3a5,5,0,0,0,5,5H8.1A5,5,0,0,0,13,23h1.38l4,7,1.73-1-4-6.89A2,2,0,0,0,14.38,21H13a3,3,0,0,1,0-6h1V13H13a5,5,0,0,0-4.9,4H7a3,3,0,0,1-3-3V12H6A3,3,0,0,0,9,9V8H7V9a1,1,0,0,1-1,1H4.08A7,7,0,0,1,11,4h6V6a1,1,0,0,1-1,1H14V9h2a3,3,0,0,0,3-3V4a9,9,0,0,1,8.05,5H26a3,3,0,0,0-3,3v1h2V12a1,1,0,0,1,1-1h1.77A8.76,8.76,0,0,1,28,13v1a5,5,0,0,1-5,5H20v2h3a7,7,0,0,0,3-.68V21a3,3,0,0,1-3,3H22v2h1a5,5,0,0,0,5-5V18.89A7,7,0,0,0,30,14Z"
  })), children);
});
var Cognitive20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cognitive20(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,13A11,11,0,0,0,19,2H11a9,9,0,0,0-9,9v3a5,5,0,0,0,5,5H8.1A5,5,0,0,0,13,23h1.38l4,7,1.73-1-4-6.89A2,2,0,0,0,14.38,21H13a3,3,0,0,1,0-6h1V13H13a5,5,0,0,0-4.9,4H7a3,3,0,0,1-3-3V12H6A3,3,0,0,0,9,9V8H7V9a1,1,0,0,1-1,1H4.08A7,7,0,0,1,11,4h6V6a1,1,0,0,1-1,1H14V9h2a3,3,0,0,0,3-3V4a9,9,0,0,1,8.05,5H26a3,3,0,0,0-3,3v1h2V12a1,1,0,0,1,1-1h1.77A8.76,8.76,0,0,1,28,13v1a5,5,0,0,1-5,5H20v2h3a7,7,0,0,0,3-.68V21a3,3,0,0,1-3,3H22v2h1a5,5,0,0,0,5-5V18.89A7,7,0,0,0,30,14Z"
  })), children);
});
var Cognitive16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cognitive16(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,13A11,11,0,0,0,19,2H11a9,9,0,0,0-9,9v3a5,5,0,0,0,5,5H8.1A5,5,0,0,0,13,23h1.38l4,7,1.73-1-4-6.89A2,2,0,0,0,14.38,21H13a3,3,0,0,1,0-6h1V13H13a5,5,0,0,0-4.9,4H7a3,3,0,0,1-3-3V12H6A3,3,0,0,0,9,9V8H7V9a1,1,0,0,1-1,1H4.08A7,7,0,0,1,11,4h6V6a1,1,0,0,1-1,1H14V9h2a3,3,0,0,0,3-3V4a9,9,0,0,1,8.05,5H26a3,3,0,0,0-3,3v1h2V12a1,1,0,0,1,1-1h1.77A8.76,8.76,0,0,1,28,13v1a5,5,0,0,1-5,5H20v2h3a7,7,0,0,0,3-.68V21a3,3,0,0,1-3,3H22v2h1a5,5,0,0,0,5-5V18.89A7,7,0,0,0,30,14Z"
  })), children);
});
var Collaborate32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Collaborate32(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 21V20H4v1a7 7 0 007 7h3V26H11A5 5 0 016 21zM24 11v1h2V11a7 7 0 00-7-7H16V6h3A5 5 0 0124 11zM11 11H5a3 3 0 00-3 3v2H4V14a1 1 0 011-1h6a1 1 0 011 1v2h2V14A3 3 0 0011 11zM8 10A4 4 0 104 6 4 4 0 008 10zM8 4A2 2 0 116 6 2 2 0 018 4zM27 25H21a3 3 0 00-3 3v2h2V28a1 1 0 011-1h6a1 1 0 011 1v2h2V28A3 3 0 0027 25zM20 20a4 4 0 104-4A4 4 0 0020 20zm6 0a2 2 0 11-2-2A2 2 0 0126 20z"
  })), children);
});
var Collaborate24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Collaborate24(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 21V20H4v1a7 7 0 007 7h3V26H11A5 5 0 016 21zM24 11v1h2V11a7 7 0 00-7-7H16V6h3A5 5 0 0124 11zM11 11H5a3 3 0 00-3 3v2H4V14a1 1 0 011-1h6a1 1 0 011 1v2h2V14A3 3 0 0011 11zM8 10A4 4 0 104 6 4 4 0 008 10zM8 4A2 2 0 116 6 2 2 0 018 4zM27 25H21a3 3 0 00-3 3v2h2V28a1 1 0 011-1h6a1 1 0 011 1v2h2V28A3 3 0 0027 25zM20 20a4 4 0 104-4A4 4 0 0020 20zm6 0a2 2 0 11-2-2A2 2 0 0126 20z"
  })), children);
});
var Collaborate20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Collaborate20(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 21V20H4v1a7 7 0 007 7h3V26H11A5 5 0 016 21zM24 11v1h2V11a7 7 0 00-7-7H16V6h3A5 5 0 0124 11zM11 11H5a3 3 0 00-3 3v2H4V14a1 1 0 011-1h6a1 1 0 011 1v2h2V14A3 3 0 0011 11zM8 10A4 4 0 104 6 4 4 0 008 10zM8 4A2 2 0 116 6 2 2 0 018 4zM27 25H21a3 3 0 00-3 3v2h2V28a1 1 0 011-1h6a1 1 0 011 1v2h2V28A3 3 0 0027 25zM20 20a4 4 0 104-4A4 4 0 0020 20zm6 0a2 2 0 11-2-2A2 2 0 0126 20z"
  })), children);
});
var Collaborate16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Collaborate16(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 21V20H4v1a7 7 0 007 7h3V26H11A5 5 0 016 21zM24 11v1h2V11a7 7 0 00-7-7H16V6h3A5 5 0 0124 11zM11 11H5a3 3 0 00-3 3v2H4V14a1 1 0 011-1h6a1 1 0 011 1v2h2V14A3 3 0 0011 11zM8 10A4 4 0 104 6 4 4 0 008 10zM8 4A2 2 0 116 6 2 2 0 018 4zM27 25H21a3 3 0 00-3 3v2h2V28a1 1 0 011-1h6a1 1 0 011 1v2h2V28A3 3 0 0027 25zM20 20a4 4 0 104-4A4 4 0 0020 20zm6 0a2 2 0 11-2-2A2 2 0 0126 20z"
  })), children);
});
var CollapseAll32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CollapseAll32(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H28V7H13V5H28a2.0023,2.0023,0,0,1,2,2Z"
  })), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,20H23V12H8V10H23a2.0023,2.0023,0,0,1,2,2Z"
  })), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,27H4a2.0023,2.0023,0,0,1-2-2V17a2.0023,2.0023,0,0,1,2-2H18a2.0023,2.0023,0,0,1,2,2v8A2.0023,2.0023,0,0,1,18,27ZM4,17v8H18.0012L18,17Z"
  })), children);
});
var CollapseAll24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CollapseAll24(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H28V7H13V5H28a2.0023,2.0023,0,0,1,2,2Z"
  })), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,20H23V12H8V10H23a2.0023,2.0023,0,0,1,2,2Z"
  })), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,27H4a2.0023,2.0023,0,0,1-2-2V17a2.0023,2.0023,0,0,1,2-2H18a2.0023,2.0023,0,0,1,2,2v8A2.0023,2.0023,0,0,1,18,27ZM4,17v8H18.0012L18,17Z"
  })), children);
});
var CollapseAll20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CollapseAll20(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H28V7H13V5H28a2.0023,2.0023,0,0,1,2,2Z"
  })), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,20H23V12H8V10H23a2.0023,2.0023,0,0,1,2,2Z"
  })), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,27H4a2.0023,2.0023,0,0,1-2-2V17a2.0023,2.0023,0,0,1,2-2H18a2.0023,2.0023,0,0,1,2,2v8A2.0023,2.0023,0,0,1,18,27ZM4,17v8H18.0012L18,17Z"
  })), children);
});
var CollapseAll16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CollapseAll16(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H28V7H13V5H28a2.0023,2.0023,0,0,1,2,2Z"
  })), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,20H23V12H8V10H23a2.0023,2.0023,0,0,1,2,2Z"
  })), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,27H4a2.0023,2.0023,0,0,1-2-2V17a2.0023,2.0023,0,0,1,2-2H18a2.0023,2.0023,0,0,1,2,2v8A2.0023,2.0023,0,0,1,18,27ZM4,17v8H18.0012L18,17Z"
  })), children);
});
var CollapseCategories32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CollapseCategories32(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 25H28V27H14zM7.17 26L4.59 28.58 6 30 10 26 6 22 4.58 23.41 7.17 26zM14 15H28V17H14zM7.17 16L4.59 18.58 6 20 10 16 6 12 4.58 13.41 7.17 16zM14 5H28V7H14zM7.17 6L4.59 8.58 6 10 10 6 6 2 4.58 3.41 7.17 6z"
  })), children);
});
var CollapseCategories24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CollapseCategories24(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 25H28V27H14zM7.17 26L4.59 28.58 6 30 10 26 6 22 4.58 23.41 7.17 26zM14 15H28V17H14zM7.17 16L4.59 18.58 6 20 10 16 6 12 4.58 13.41 7.17 16zM14 5H28V7H14zM7.17 6L4.59 8.58 6 10 10 6 6 2 4.58 3.41 7.17 6z"
  })), children);
});
var CollapseCategories20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CollapseCategories20(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 25H28V27H14zM7.17 26L4.59 28.58 6 30 10 26 6 22 4.58 23.41 7.17 26zM14 15H28V17H14zM7.17 16L4.59 18.58 6 20 10 16 6 12 4.58 13.41 7.17 16zM14 5H28V7H14zM7.17 6L4.59 8.58 6 10 10 6 6 2 4.58 3.41 7.17 6z"
  })), children);
});
var CollapseCategories16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CollapseCategories16(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 25H28V27H14zM7.17 26L4.59 28.58 6 30 10 26 6 22 4.58 23.41 7.17 26zM14 15H28V17H14zM7.17 16L4.59 18.58 6 20 10 16 6 12 4.58 13.41 7.17 16zM14 5H28V7H14zM7.17 6L4.59 8.58 6 10 10 6 6 2 4.58 3.41 7.17 6z"
  })), children);
});
var ColorPalette32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColorPalette32(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle37 || (_circle37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "12",
    r: "2"
  })), _circle38 || (_circle38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "9",
    r: "2"
  })), _circle39 || (_circle39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "12",
    r: "2"
  })), _circle40 || (_circle40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "18",
    r: "2"
  })), _circle41 || (_circle41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "19",
    cy: "23",
    r: "2"
  })), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.54,2A14,14,0,0,0,2,16a4.82,4.82,0,0,0,6.09,4.65l1.12-.31A3,3,0,0,1,13,23.24V27a3,3,0,0,0,3,3A14,14,0,0,0,30,15.46,14.05,14.05,0,0,0,16.54,2Zm8.11,22.31A11.93,11.93,0,0,1,16,28a1,1,0,0,1-1-1V23.24a5,5,0,0,0-5-5,5.07,5.07,0,0,0-1.33.18l-1.12.31A2.82,2.82,0,0,1,4,16,12,12,0,0,1,16.47,4,12.18,12.18,0,0,1,28,15.53,11.89,11.89,0,0,1,24.65,24.32Z"
  })), children);
});
var ColorPalette24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColorPalette24(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle42 || (_circle42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "12",
    r: "2"
  })), _circle43 || (_circle43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "9",
    r: "2"
  })), _circle44 || (_circle44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "12",
    r: "2"
  })), _circle45 || (_circle45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "18",
    r: "2"
  })), _circle46 || (_circle46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "19",
    cy: "23",
    r: "2"
  })), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.54,2A14,14,0,0,0,2,16a4.82,4.82,0,0,0,6.09,4.65l1.12-.31A3,3,0,0,1,13,23.24V27a3,3,0,0,0,3,3A14,14,0,0,0,30,15.46,14.05,14.05,0,0,0,16.54,2Zm8.11,22.31A11.93,11.93,0,0,1,16,28a1,1,0,0,1-1-1V23.24a5,5,0,0,0-5-5,5.07,5.07,0,0,0-1.33.18l-1.12.31A2.82,2.82,0,0,1,4,16,12,12,0,0,1,16.47,4,12.18,12.18,0,0,1,28,15.53,11.89,11.89,0,0,1,24.65,24.32Z"
  })), children);
});
var ColorPalette20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColorPalette20(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle47 || (_circle47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "12",
    r: "2"
  })), _circle48 || (_circle48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "9",
    r: "2"
  })), _circle49 || (_circle49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "12",
    r: "2"
  })), _circle50 || (_circle50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "18",
    r: "2"
  })), _circle51 || (_circle51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "19",
    cy: "23",
    r: "2"
  })), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.54,2A14,14,0,0,0,2,16a4.82,4.82,0,0,0,6.09,4.65l1.12-.31A3,3,0,0,1,13,23.24V27a3,3,0,0,0,3,3A14,14,0,0,0,30,15.46,14.05,14.05,0,0,0,16.54,2Zm8.11,22.31A11.93,11.93,0,0,1,16,28a1,1,0,0,1-1-1V23.24a5,5,0,0,0-5-5,5.07,5.07,0,0,0-1.33.18l-1.12.31A2.82,2.82,0,0,1,4,16,12,12,0,0,1,16.47,4,12.18,12.18,0,0,1,28,15.53,11.89,11.89,0,0,1,24.65,24.32Z"
  })), children);
});
var ColorPalette16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColorPalette16(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle52 || (_circle52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "12",
    r: "2"
  })), _circle53 || (_circle53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "9",
    r: "2"
  })), _circle54 || (_circle54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "12",
    r: "2"
  })), _circle55 || (_circle55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "18",
    r: "2"
  })), _circle56 || (_circle56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "19",
    cy: "23",
    r: "2"
  })), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.54,2A14,14,0,0,0,2,16a4.82,4.82,0,0,0,6.09,4.65l1.12-.31A3,3,0,0,1,13,23.24V27a3,3,0,0,0,3,3A14,14,0,0,0,30,15.46,14.05,14.05,0,0,0,16.54,2Zm8.11,22.31A11.93,11.93,0,0,1,16,28a1,1,0,0,1-1-1V23.24a5,5,0,0,0-5-5,5.07,5.07,0,0,0-1.33.18l-1.12.31A2.82,2.82,0,0,1,4,16,12,12,0,0,1,16.47,4,12.18,12.18,0,0,1,28,15.53,11.89,11.89,0,0,1,24.65,24.32Z"
  })), children);
});
var ColorSwitch32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColorSwitch32(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0025,2.0025,0,0,0,4,6V26a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V6A2.0025,2.0025,0,0,0,26,4ZM6,26,26,6V26Z"
  })), children);
});
var ColorSwitch24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColorSwitch24(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0025,2.0025,0,0,0,4,6V26a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V6A2.0025,2.0025,0,0,0,26,4ZM6,26,26,6V26Z"
  })), children);
});
var ColorSwitch20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColorSwitch20(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0025,2.0025,0,0,0,4,6V26a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V6A2.0025,2.0025,0,0,0,26,4ZM6,26,26,6V26Z"
  })), children);
});
var ColorSwitch16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColorSwitch16(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,4H6A2.0025,2.0025,0,0,0,4,6V26a2.0025,2.0025,0,0,0,2,2H26a2.0025,2.0025,0,0,0,2-2V6A2.0025,2.0025,0,0,0,26,4ZM6,26,26,6V26Z"
  })), children);
});
var Column32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Column32(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 4H26V28H24zM18 6V26H14V6h4m0-2H14a2 2 0 00-2 2V26a2 2 0 002 2h4a2 2 0 002-2V6a2 2 0 00-2-2zM6 4H8V28H6z"
  })), children);
});
var Column24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Column24(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 4H26V28H24zM18 6V26H14V6h4m0-2H14a2 2 0 00-2 2V26a2 2 0 002 2h4a2 2 0 002-2V6a2 2 0 00-2-2zM6 4H8V28H6z"
  })), children);
});
var Column20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Column20(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 4H26V28H24zM18 6V26H14V6h4m0-2H14a2 2 0 00-2 2V26a2 2 0 002 2h4a2 2 0 002-2V6a2 2 0 00-2-2zM6 4H8V28H6z"
  })), children);
});
var Column16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Column16(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 4H26V28H24zM18 6V26H14V6h4m0-2H14a2 2 0 00-2 2V26a2 2 0 002 2h4a2 2 0 002-2V6a2 2 0 00-2-2zM6 4H8V28H6z"
  })), children);
});
var ColumnDelete32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColumnDelete32(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 3.41L28.59 2 25 5.59 21.41 2 20 3.41 23.59 7 20 10.59 21.41 12 25 8.41 28.59 12 30 10.59 26.41 7 30 3.41z"
  })), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 14V28H18V6H16V28a2.0023 2.0023 0 002 2h6a2.0023 2.0023 0 002-2V14zM10 30H4a2.0021 2.0021 0 01-2-2V8A2.0021 2.0021 0 014 6h6a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0110 30zM4 8V28h6V8z"
  })), children);
});
var ColumnDelete24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColumnDelete24(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 3.41L28.59 2 25 5.59 21.41 2 20 3.41 23.59 7 20 10.59 21.41 12 25 8.41 28.59 12 30 10.59 26.41 7 30 3.41z"
  })), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 14V28H18V6H16V28a2.0023 2.0023 0 002 2h6a2.0023 2.0023 0 002-2V14zM10 30H4a2.0021 2.0021 0 01-2-2V8A2.0021 2.0021 0 014 6h6a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0110 30zM4 8V28h6V8z"
  })), children);
});
var ColumnDelete20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColumnDelete20(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 3.41L28.59 2 25 5.59 21.41 2 20 3.41 23.59 7 20 10.59 21.41 12 25 8.41 28.59 12 30 10.59 26.41 7 30 3.41z"
  })), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 14V28H18V6H16V28a2.0023 2.0023 0 002 2h6a2.0023 2.0023 0 002-2V14zM10 30H4a2.0021 2.0021 0 01-2-2V8A2.0021 2.0021 0 014 6h6a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0110 30zM4 8V28h6V8z"
  })), children);
});
var ColumnDelete16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColumnDelete16(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 3.41L28.59 2 25 5.59 21.41 2 20 3.41 23.59 7 20 10.59 21.41 12 25 8.41 28.59 12 30 10.59 26.41 7 30 3.41z"
  })), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 14V28H18V6H16V28a2.0023 2.0023 0 002 2h6a2.0023 2.0023 0 002-2V14zM10 30H4a2.0021 2.0021 0 01-2-2V8A2.0021 2.0021 0 014 6h6a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0110 30zM4 8V28h6V8z"
  })), children);
});
var ColumnInsert32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColumnInsert32(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H22a2.0021 2.0021 0 01-2-2V10a2.0021 2.0021 0 012-2h6a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0128 30zM22 10V28h6V10zM16 9L21.586 3.414 20.172 2 16 6.172 11.828 2 10.414 3.414 16 9zM10 30H4a2.0021 2.0021 0 01-2-2V10A2.0021 2.0021 0 014 8h6a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0110 30zM4 10V28h6V10z"
  })), children);
});
var ColumnInsert24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColumnInsert24(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H22a2.0021 2.0021 0 01-2-2V10a2.0021 2.0021 0 012-2h6a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0128 30zM22 10V28h6V10zM16 9L21.586 3.414 20.172 2 16 6.172 11.828 2 10.414 3.414 16 9zM10 30H4a2.0021 2.0021 0 01-2-2V10A2.0021 2.0021 0 014 8h6a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0110 30zM4 10V28h6V10z"
  })), children);
});
var ColumnInsert20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColumnInsert20(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H22a2.0021 2.0021 0 01-2-2V10a2.0021 2.0021 0 012-2h6a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0128 30zM22 10V28h6V10zM16 9L21.586 3.414 20.172 2 16 6.172 11.828 2 10.414 3.414 16 9zM10 30H4a2.0021 2.0021 0 01-2-2V10A2.0021 2.0021 0 014 8h6a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0110 30zM4 10V28h6V10z"
  })), children);
});
var ColumnInsert16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColumnInsert16(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 30H22a2.0021 2.0021 0 01-2-2V10a2.0021 2.0021 0 012-2h6a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0128 30zM22 10V28h6V10zM16 9L21.586 3.414 20.172 2 16 6.172 11.828 2 10.414 3.414 16 9zM10 30H4a2.0021 2.0021 0 01-2-2V10A2.0021 2.0021 0 014 8h6a2.0021 2.0021 0 012 2V28A2.0021 2.0021 0 0110 30zM4 10V28h6V10z"
  })), children);
});
var ColumnDependency32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColumnDependency32(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10V2H22V5H17a2.0023,2.0023,0,0,0-2,2v8H10V12H2v8h8V17h5v8a2.0023,2.0023,0,0,0,2,2h5v3h8V22H22v3H17V17h5v3h8V12H22v3H17V7h5v3ZM8,18H4V14H8Zm16,6h4v4H24Zm0-10h4v4H24ZM24,4h4V8H24Z"
  })), children);
});
var ColumnDependency24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColumnDependency24(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10V2H22V5H17a2.0023,2.0023,0,0,0-2,2v8H10V12H2v8h8V17h5v8a2.0023,2.0023,0,0,0,2,2h5v3h8V22H22v3H17V17h5v3h8V12H22v3H17V7h5v3ZM8,18H4V14H8Zm16,6h4v4H24Zm0-10h4v4H24ZM24,4h4V8H24Z"
  })), children);
});
var ColumnDependency20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColumnDependency20(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10V2H22V5H17a2.0023,2.0023,0,0,0-2,2v8H10V12H2v8h8V17h5v8a2.0023,2.0023,0,0,0,2,2h5v3h8V22H22v3H17V17h5v3h8V12H22v3H17V7h5v3ZM8,18H4V14H8Zm16,6h4v4H24Zm0-10h4v4H24ZM24,4h4V8H24Z"
  })), children);
});
var ColumnDependency16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ColumnDependency16(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,10V2H22V5H17a2.0023,2.0023,0,0,0-2,2v8H10V12H2v8h8V17h5v8a2.0023,2.0023,0,0,0,2,2h5v3h8V22H22v3H17V17h5v3h8V12H22v3H17V7h5v3ZM8,18H4V14H8Zm16,6h4v4H24Zm0-10h4v4H24ZM24,4h4V8H24Z"
  })), children);
});
var Commit32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Commit32(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H21.91A5.9925,5.9925,0,0,0,10.09,15H2v2h8.09A5.9925,5.9925,0,0,0,21.91,17H30ZM16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Z"
  })), children);
});
var Commit24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Commit24(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H21.91A5.9925,5.9925,0,0,0,10.09,15H2v2h8.09A5.9925,5.9925,0,0,0,21.91,17H30ZM16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Z"
  })), children);
});
var Commit20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Commit20(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H21.91A5.9925,5.9925,0,0,0,10.09,15H2v2h8.09A5.9925,5.9925,0,0,0,21.91,17H30ZM16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Z"
  })), children);
});
var Commit16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Commit16(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H21.91A5.9925,5.9925,0,0,0,10.09,15H2v2h8.09A5.9925,5.9925,0,0,0,21.91,17H30ZM16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Z"
  })), children);
});
var CommunicationUnified32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CommunicationUnified32(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 17H18a2.0025 2.0025 0 00-2 2v6a2.0025 2.0025 0 002 2h4V25H18V19H28v6H25.4648l-2.5937 3.8906L24.5352 30l2-3H28a2.0025 2.0025 0 002-2V19A2.0025 2.0025 0 0028 17zM8.6667 24.1086l.8614-.8615a.8334.8334 0 01.8988-.1844l1.0493.42A.8334.8334 0 0112 24.2561v1.9082a.8334.8334 0 01-.8786.8341c-7.3546-.4578-8.84-6.6863-9.1158-9.0723A.8316.8316 0 012.8343 17H4.7085a.8335.8335 0 01.7737.5238l.42 1.0493a.8332.8332 0 01-.1845.8988l-.8614.8614A4.5267 4.5267 0 008.6667 24.1086zM21 9H28V11H21zM21 5H30V7H21zM17 6L14 8.2V6a2.0024 2.0024 0 00-2-2H4A2.0024 2.0024 0 002 6v6a2.0024 2.0024 0 002 2h8a2.0024 2.0024 0 002-2V9.8L17 12zM4 12V6h8v6z"
  })), children);
});
var CommunicationUnified24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CommunicationUnified24(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 17H18a2.0025 2.0025 0 00-2 2v6a2.0025 2.0025 0 002 2h4V25H18V19H28v6H25.4648l-2.5937 3.8906L24.5352 30l2-3H28a2.0025 2.0025 0 002-2V19A2.0025 2.0025 0 0028 17zM8.6667 24.1086l.8614-.8615a.8334.8334 0 01.8988-.1844l1.0493.42A.8334.8334 0 0112 24.2561v1.9082a.8334.8334 0 01-.8786.8341c-7.3546-.4578-8.84-6.6863-9.1158-9.0723A.8316.8316 0 012.8343 17H4.7085a.8335.8335 0 01.7737.5238l.42 1.0493a.8332.8332 0 01-.1845.8988l-.8614.8614A4.5267 4.5267 0 008.6667 24.1086zM21 9H28V11H21zM21 5H30V7H21zM17 6L14 8.2V6a2.0024 2.0024 0 00-2-2H4A2.0024 2.0024 0 002 6v6a2.0024 2.0024 0 002 2h8a2.0024 2.0024 0 002-2V9.8L17 12zM4 12V6h8v6z"
  })), children);
});
var CommunicationUnified20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CommunicationUnified20(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 17H18a2.0025 2.0025 0 00-2 2v6a2.0025 2.0025 0 002 2h4V25H18V19H28v6H25.4648l-2.5937 3.8906L24.5352 30l2-3H28a2.0025 2.0025 0 002-2V19A2.0025 2.0025 0 0028 17zM8.6667 24.1086l.8614-.8615a.8334.8334 0 01.8988-.1844l1.0493.42A.8334.8334 0 0112 24.2561v1.9082a.8334.8334 0 01-.8786.8341c-7.3546-.4578-8.84-6.6863-9.1158-9.0723A.8316.8316 0 012.8343 17H4.7085a.8335.8335 0 01.7737.5238l.42 1.0493a.8332.8332 0 01-.1845.8988l-.8614.8614A4.5267 4.5267 0 008.6667 24.1086zM21 9H28V11H21zM21 5H30V7H21zM17 6L14 8.2V6a2.0024 2.0024 0 00-2-2H4A2.0024 2.0024 0 002 6v6a2.0024 2.0024 0 002 2h8a2.0024 2.0024 0 002-2V9.8L17 12zM4 12V6h8v6z"
  })), children);
});
var CommunicationUnified16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CommunicationUnified16(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 17H18a2.0025 2.0025 0 00-2 2v6a2.0025 2.0025 0 002 2h4V25H18V19H28v6H25.4648l-2.5937 3.8906L24.5352 30l2-3H28a2.0025 2.0025 0 002-2V19A2.0025 2.0025 0 0028 17zM8.6667 24.1086l.8614-.8615a.8334.8334 0 01.8988-.1844l1.0493.42A.8334.8334 0 0112 24.2561v1.9082a.8334.8334 0 01-.8786.8341c-7.3546-.4578-8.84-6.6863-9.1158-9.0723A.8316.8316 0 012.8343 17H4.7085a.8335.8335 0 01.7737.5238l.42 1.0493a.8332.8332 0 01-.1845.8988l-.8614.8614A4.5267 4.5267 0 008.6667 24.1086zM21 9H28V11H21zM21 5H30V7H21zM17 6L14 8.2V6a2.0024 2.0024 0 00-2-2H4A2.0024 2.0024 0 002 6v6a2.0024 2.0024 0 002 2h8a2.0024 2.0024 0 002-2V9.8L17 12zM4 12V6h8v6z"
  })), children);
});
var Compare32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Compare32(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H18V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V24a2,2,0,0,0,2,2H14v2a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM4,15h6.17L7.59,17.59,9,19l5-5L9,9,7.59,10.41,10.17,13H4V4H16V24H4ZM16,28V26a2,2,0,0,0,2-2V8H28v9H21.83l2.58-2.59L23,13l-5,5,5,5,1.41-1.41L21.83,19H28v9Z"
  })), children);
});
var Compare24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Compare24(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H18V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V24a2,2,0,0,0,2,2H14v2a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM4,15h6.17L7.59,17.59,9,19l5-5L9,9,7.59,10.41,10.17,13H4V4H16V24H4ZM16,28V26a2,2,0,0,0,2-2V8H28v9H21.83l2.58-2.59L23,13l-5,5,5,5,1.41-1.41L21.83,19H28v9Z"
  })), children);
});
var Compare20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Compare20(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H18V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V24a2,2,0,0,0,2,2H14v2a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM4,15h6.17L7.59,17.59,9,19l5-5L9,9,7.59,10.41,10.17,13H4V4H16V24H4ZM16,28V26a2,2,0,0,0,2-2V8H28v9H21.83l2.58-2.59L23,13l-5,5,5,5,1.41-1.41L21.83,19H28v9Z"
  })), children);
});
var Compare16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Compare16(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H18V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V24a2,2,0,0,0,2,2H14v2a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V8A2,2,0,0,0,28,6ZM4,15h6.17L7.59,17.59,9,19l5-5L9,9,7.59,10.41,10.17,13H4V4H16V24H4ZM16,28V26a2,2,0,0,0,2-2V8H28v9H21.83l2.58-2.59L23,13l-5,5,5,5,1.41-1.41L21.83,19H28v9Z"
  })), children);
});
var Compass32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Compass32(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12,12,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,10.41,21.59,9l-4.3,4.3a3,3,0,0,0-4,4L9,21.59,10.41,23l4.3-4.3a3,3,0,0,0,4-4ZM17,16a1,1,0,1,1-1-1A1,1,0,0,1,17,16Z"
  })), _circle57 || (_circle57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "7.5",
    r: "1.5"
  })), children);
});
var Compass24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Compass24(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12,12,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,10.41,21.59,9l-4.3,4.3a3,3,0,0,0-4,4L9,21.59,10.41,23l4.3-4.3a3,3,0,0,0,4-4ZM17,16a1,1,0,1,1-1-1A1,1,0,0,1,17,16Z"
  })), _circle58 || (_circle58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "7.5",
    r: "1.5"
  })), children);
});
var Compass20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Compass20(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12,12,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,10.41,21.59,9l-4.3,4.3a3,3,0,0,0-4,4L9,21.59,10.41,23l4.3-4.3a3,3,0,0,0,4-4ZM17,16a1,1,0,1,1-1-1A1,1,0,0,1,17,16Z"
  })), _circle59 || (_circle59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "7.5",
    r: "1.5"
  })), children);
});
var Compass16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Compass16(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12,12,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,10.41,21.59,9l-4.3,4.3a3,3,0,0,0-4,4L9,21.59,10.41,23l4.3-4.3a3,3,0,0,0,4-4ZM17,16a1,1,0,1,1-1-1A1,1,0,0,1,17,16Z"
  })), _circle60 || (_circle60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "7.5",
    r: "1.5"
  })), children);
});
var QComposerEdit32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QComposerEdit32(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.82,10H30V8H25.82a3,3,0,0,0-5.64,0H13V5H5V8H2v2H5v3h8V10h7.18A3,3,0,0,0,22,11.82v7.32A4,4,0,0,0,19.14,22H2v2H19.14a4,4,0,0,0,7.72,0H30V22H26.86A4,4,0,0,0,24,19.14V11.82A3,3,0,0,0,25.82,10ZM11,11H7V7h4ZM25,23a2,2,0,1,1-2-2A2,2,0,0,1,25,23Z"
  })), children);
});
var QComposerEdit24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QComposerEdit24(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.82,10H30V8H25.82a3,3,0,0,0-5.64,0H13V5H5V8H2v2H5v3h8V10h7.18A3,3,0,0,0,22,11.82v7.32A4,4,0,0,0,19.14,22H2v2H19.14a4,4,0,0,0,7.72,0H30V22H26.86A4,4,0,0,0,24,19.14V11.82A3,3,0,0,0,25.82,10ZM11,11H7V7h4ZM25,23a2,2,0,1,1-2-2A2,2,0,0,1,25,23Z"
  })), children);
});
var QComposerEdit20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QComposerEdit20(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.82,10H30V8H25.82a3,3,0,0,0-5.64,0H13V5H5V8H2v2H5v3h8V10h7.18A3,3,0,0,0,22,11.82v7.32A4,4,0,0,0,19.14,22H2v2H19.14a4,4,0,0,0,7.72,0H30V22H26.86A4,4,0,0,0,24,19.14V11.82A3,3,0,0,0,25.82,10ZM11,11H7V7h4ZM25,23a2,2,0,1,1-2-2A2,2,0,0,1,25,23Z"
  })), children);
});
var QComposerEdit16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QComposerEdit16(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.82,10H30V8H25.82a3,3,0,0,0-5.64,0H13V5H5V8H2v2H5v3h8V10h7.18A3,3,0,0,0,22,11.82v7.32A4,4,0,0,0,19.14,22H2v2H19.14a4,4,0,0,0,7.72,0H30V22H26.86A4,4,0,0,0,24,19.14V11.82A3,3,0,0,0,25.82,10ZM11,11H7V7h4ZM25,23a2,2,0,1,1-2-2A2,2,0,0,1,25,23Z"
  })), children);
});
var Concept32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Concept32(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.8851,19.4711a5.9609,5.9609,0,0,0,0-6.9422L23,10.4141l1.293,1.2929a.9995.9995,0,0,0,1.414,0l4-4a.9994.9994,0,0,0,0-1.414l-4-4a.9994.9994,0,0,0-1.414,0l-4,4a.9994.9994,0,0,0,0,1.414L21.5859,9l-2.1148,2.1149a5.9609,5.9609,0,0,0-6.9422,0L10,8.5859V2H2v8H8.5859l2.529,2.5289a5.9609,5.9609,0,0,0,0,6.9422L9,21.5859,7.707,20.293a.9994.9994,0,0,0-1.414,0l-4,4a.9994.9994,0,0,0,0,1.414l4,4a.9995.9995,0,0,0,1.414,0l4-4a.9994.9994,0,0,0,0-1.414L10.4141,23l2.1148-2.1149a5.9609,5.9609,0,0,0,6.9422,0L22,23.4141V30h8V22H23.4141ZM25,4.4141,27.5859,7,25,9.5859,22.4141,7ZM7,27.5859,4.4141,25,7,22.4141,9.5859,25ZM8,8H4V4H8Zm4,8a4,4,0,1,1,4,4A4.0045,4.0045,0,0,1,12,16Zm12,8h4v4H24Z"
  })), children);
});
var Concept24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Concept24(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.8851,19.4711a5.9609,5.9609,0,0,0,0-6.9422L23,10.4141l1.293,1.2929a.9995.9995,0,0,0,1.414,0l4-4a.9994.9994,0,0,0,0-1.414l-4-4a.9994.9994,0,0,0-1.414,0l-4,4a.9994.9994,0,0,0,0,1.414L21.5859,9l-2.1148,2.1149a5.9609,5.9609,0,0,0-6.9422,0L10,8.5859V2H2v8H8.5859l2.529,2.5289a5.9609,5.9609,0,0,0,0,6.9422L9,21.5859,7.707,20.293a.9994.9994,0,0,0-1.414,0l-4,4a.9994.9994,0,0,0,0,1.414l4,4a.9995.9995,0,0,0,1.414,0l4-4a.9994.9994,0,0,0,0-1.414L10.4141,23l2.1148-2.1149a5.9609,5.9609,0,0,0,6.9422,0L22,23.4141V30h8V22H23.4141ZM25,4.4141,27.5859,7,25,9.5859,22.4141,7ZM7,27.5859,4.4141,25,7,22.4141,9.5859,25ZM8,8H4V4H8Zm4,8a4,4,0,1,1,4,4A4.0045,4.0045,0,0,1,12,16Zm12,8h4v4H24Z"
  })), children);
});
var Concept20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Concept20(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.8851,19.4711a5.9609,5.9609,0,0,0,0-6.9422L23,10.4141l1.293,1.2929a.9995.9995,0,0,0,1.414,0l4-4a.9994.9994,0,0,0,0-1.414l-4-4a.9994.9994,0,0,0-1.414,0l-4,4a.9994.9994,0,0,0,0,1.414L21.5859,9l-2.1148,2.1149a5.9609,5.9609,0,0,0-6.9422,0L10,8.5859V2H2v8H8.5859l2.529,2.5289a5.9609,5.9609,0,0,0,0,6.9422L9,21.5859,7.707,20.293a.9994.9994,0,0,0-1.414,0l-4,4a.9994.9994,0,0,0,0,1.414l4,4a.9995.9995,0,0,0,1.414,0l4-4a.9994.9994,0,0,0,0-1.414L10.4141,23l2.1148-2.1149a5.9609,5.9609,0,0,0,6.9422,0L22,23.4141V30h8V22H23.4141ZM25,4.4141,27.5859,7,25,9.5859,22.4141,7ZM7,27.5859,4.4141,25,7,22.4141,9.5859,25ZM8,8H4V4H8Zm4,8a4,4,0,1,1,4,4A4.0045,4.0045,0,0,1,12,16Zm12,8h4v4H24Z"
  })), children);
});
var Concept16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Concept16(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20.8851,19.4711a5.9609,5.9609,0,0,0,0-6.9422L23,10.4141l1.293,1.2929a.9995.9995,0,0,0,1.414,0l4-4a.9994.9994,0,0,0,0-1.414l-4-4a.9994.9994,0,0,0-1.414,0l-4,4a.9994.9994,0,0,0,0,1.414L21.5859,9l-2.1148,2.1149a5.9609,5.9609,0,0,0-6.9422,0L10,8.5859V2H2v8H8.5859l2.529,2.5289a5.9609,5.9609,0,0,0,0,6.9422L9,21.5859,7.707,20.293a.9994.9994,0,0,0-1.414,0l-4,4a.9994.9994,0,0,0,0,1.414l4,4a.9995.9995,0,0,0,1.414,0l4-4a.9994.9994,0,0,0,0-1.414L10.4141,23l2.1148-2.1149a5.9609,5.9609,0,0,0,6.9422,0L22,23.4141V30h8V22H23.4141ZM25,4.4141,27.5859,7,25,9.5859,22.4141,7ZM7,27.5859,4.4141,25,7,22.4141,9.5859,25ZM8,8H4V4H8Zm4,8a4,4,0,1,1,4,4A4.0045,4.0045,0,0,1,12,16Zm12,8h4v4H24Z"
  })), children);
});
var ConditionPoint32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConditionPoint32(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.343 10.343H21.657V21.657H10.343z",
    transform: "rotate(-45 16 16)"
  })), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3906,14.5269,17.4731,2.6094a2.0852,2.0852,0,0,0-2.9462,0L2.6094,14.5269a2.0852,2.0852,0,0,0,0,2.9462L14.5269,29.3906a2.0852,2.0852,0,0,0,2.9462,0L29.3906,17.4731a2.0852,2.0852,0,0,0,0-2.9462ZM16,28.0356,3.9646,16,16,3.9644,28.0356,16Z"
  })), children);
});
var ConditionPoint24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConditionPoint24(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.343 10.343H21.657V21.657H10.343z",
    transform: "rotate(-45 16 16)"
  })), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3906,14.5269,17.4731,2.6094a2.0852,2.0852,0,0,0-2.9462,0L2.6094,14.5269a2.0852,2.0852,0,0,0,0,2.9462L14.5269,29.3906a2.0852,2.0852,0,0,0,2.9462,0L29.3906,17.4731a2.0852,2.0852,0,0,0,0-2.9462ZM16,28.0356,3.9646,16,16,3.9644,28.0356,16Z"
  })), children);
});
var ConditionPoint20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConditionPoint20(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.343 10.343H21.657V21.657H10.343z",
    transform: "rotate(-45 16 16)"
  })), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3906,14.5269,17.4731,2.6094a2.0852,2.0852,0,0,0-2.9462,0L2.6094,14.5269a2.0852,2.0852,0,0,0,0,2.9462L14.5269,29.3906a2.0852,2.0852,0,0,0,2.9462,0L29.3906,17.4731a2.0852,2.0852,0,0,0,0-2.9462ZM16,28.0356,3.9646,16,16,3.9644,28.0356,16Z"
  })), children);
});
var ConditionPoint16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConditionPoint16(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.343 10.343H21.657V21.657H10.343z",
    transform: "rotate(-45 16 16)"
  })), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.3906,14.5269,17.4731,2.6094a2.0852,2.0852,0,0,0-2.9462,0L2.6094,14.5269a2.0852,2.0852,0,0,0,0,2.9462L14.5269,29.3906a2.0852,2.0852,0,0,0,2.9462,0L29.3906,17.4731a2.0852,2.0852,0,0,0,0-2.9462ZM16,28.0356,3.9646,16,16,3.9644,28.0356,16Z"
  })), children);
});
var ConditionWaitPoint32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConditionWaitPoint32(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.343 10.343H21.657V21.657H10.343z",
    transform: "rotate(-45 16 16)"
  })), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12.0136,12.0136,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), children);
});
var ConditionWaitPoint24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConditionWaitPoint24(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.343 10.343H21.657V21.657H10.343z",
    transform: "rotate(-45 16 16)"
  })), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12.0136,12.0136,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), children);
});
var ConditionWaitPoint20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConditionWaitPoint20(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.343 10.343H21.657V21.657H10.343z",
    transform: "rotate(-45 16 16)"
  })), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12.0136,12.0136,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), children);
});
var ConditionWaitPoint16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConditionWaitPoint16(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10.343 10.343H21.657V21.657H10.343z",
    transform: "rotate(-45 16 16)"
  })), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12.0136,12.0136,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Z"
  })), children);
});
var Connect32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Connect32(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,16a7,7,0,0,0-4.18,1.39L14.6,13.17A6.86,6.86,0,0,0,16,9a7,7,0,1,0-2.81,5.59l4.21,4.22A7,7,0,1,0,23,16ZM4,9a5,5,0,1,1,5,5A5,5,0,0,1,4,9Z",
    transform: "translate(0 .01)"
  })), children);
});
var Connect24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Connect24(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,16a7,7,0,0,0-4.18,1.39L14.6,13.17A6.86,6.86,0,0,0,16,9a7,7,0,1,0-2.81,5.59l4.21,4.22A7,7,0,1,0,23,16ZM4,9a5,5,0,1,1,5,5A5,5,0,0,1,4,9Z",
    transform: "translate(0 .01)"
  })), children);
});
var Connect20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Connect20(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,16a7,7,0,0,0-4.18,1.39L14.6,13.17A6.86,6.86,0,0,0,16,9a7,7,0,1,0-2.81,5.59l4.21,4.22A7,7,0,1,0,23,16ZM4,9a5,5,0,1,1,5,5A5,5,0,0,1,4,9Z",
    transform: "translate(0 .01)"
  })), children);
});
var Connect16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Connect16(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,16a7,7,0,0,0-4.18,1.39L14.6,13.17A6.86,6.86,0,0,0,16,9a7,7,0,1,0-2.81,5.59l4.21,4.22A7,7,0,1,0,23,16ZM4,9a5,5,0,1,1,5,5A5,5,0,0,1,4,9Z",
    transform: "translate(0 .01)"
  })), children);
});
var ConnectRecursive32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectRecursive32(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,7H13.8281l3.586-3.5859L16,2,10,8l6,6,1.4141-1.4141L13.8281,9H28V20H11.8989A5.0145,5.0145,0,0,0,8,16.1011V2H6V16.1011a5,5,0,0,0,0,9.7978V30H8V25.8989A5.0145,5.0145,0,0,0,11.8989,22H28a2.0023,2.0023,0,0,0,2-2V9A2.0023,2.0023,0,0,0,28,7ZM7,24a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,7,24Z"
  })), children);
});
var ConnectRecursive24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectRecursive24(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,7H13.8281l3.586-3.5859L16,2,10,8l6,6,1.4141-1.4141L13.8281,9H28V20H11.8989A5.0145,5.0145,0,0,0,8,16.1011V2H6V16.1011a5,5,0,0,0,0,9.7978V30H8V25.8989A5.0145,5.0145,0,0,0,11.8989,22H28a2.0023,2.0023,0,0,0,2-2V9A2.0023,2.0023,0,0,0,28,7ZM7,24a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,7,24Z"
  })), children);
});
var ConnectRecursive20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectRecursive20(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,7H13.8281l3.586-3.5859L16,2,10,8l6,6,1.4141-1.4141L13.8281,9H28V20H11.8989A5.0145,5.0145,0,0,0,8,16.1011V2H6V16.1011a5,5,0,0,0,0,9.7978V30H8V25.8989A5.0145,5.0145,0,0,0,11.8989,22H28a2.0023,2.0023,0,0,0,2-2V9A2.0023,2.0023,0,0,0,28,7ZM7,24a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,7,24Z"
  })), children);
});
var ConnectRecursive16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectRecursive16(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,7H13.8281l3.586-3.5859L16,2,10,8l6,6,1.4141-1.4141L13.8281,9H28V20H11.8989A5.0145,5.0145,0,0,0,8,16.1011V2H6V16.1011a5,5,0,0,0,0,9.7978V30H8V25.8989A5.0145,5.0145,0,0,0,11.8989,22H28a2.0023,2.0023,0,0,0,2-2V9A2.0023,2.0023,0,0,0,28,7ZM7,24a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,7,24Z"
  })), children);
});
var ConnectSource32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectSource32(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,10l-1.4141,1.4141L26.1719,15H11.8989A5.0145,5.0145,0,0,0,8,11.1011V2H6v9.1011a5,5,0,0,0,0,9.7978V30H8V20.8989A5.0145,5.0145,0,0,0,11.8989,17h14.273l-3.586,3.5859L24,22l6-6ZM7,19a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,7,19Z"
  })), children);
});
var ConnectSource24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectSource24(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,10l-1.4141,1.4141L26.1719,15H11.8989A5.0145,5.0145,0,0,0,8,11.1011V2H6v9.1011a5,5,0,0,0,0,9.7978V30H8V20.8989A5.0145,5.0145,0,0,0,11.8989,17h14.273l-3.586,3.5859L24,22l6-6ZM7,19a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,7,19Z"
  })), children);
});
var ConnectSource20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectSource20(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,10l-1.4141,1.4141L26.1719,15H11.8989A5.0145,5.0145,0,0,0,8,11.1011V2H6v9.1011a5,5,0,0,0,0,9.7978V30H8V20.8989A5.0145,5.0145,0,0,0,11.8989,17h14.273l-3.586,3.5859L24,22l6-6ZM7,19a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,7,19Z"
  })), children);
});
var ConnectSource16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectSource16(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,10l-1.4141,1.4141L26.1719,15H11.8989A5.0145,5.0145,0,0,0,8,11.1011V2H6v9.1011a5,5,0,0,0,0,9.7978V30H8V20.8989A5.0145,5.0145,0,0,0,11.8989,17h14.273l-3.586,3.5859L24,22l6-6ZM7,19a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,7,19Z"
  })), children);
});
var ConnectTarget32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectTarget32(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 2H30V30H28zM20 10l-1.4141 1.4141L22.1719 15H11.8989a5 5 0 100 2h10.273l-3.586 3.5859L20 22l6-6zM7 19a3 3 0 113-3A3.0033 3.0033 0 017 19z"
  })), children);
});
var ConnectTarget24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectTarget24(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 2H30V30H28zM20 10l-1.4141 1.4141L22.1719 15H11.8989a5 5 0 100 2h10.273l-3.586 3.5859L20 22l6-6zM7 19a3 3 0 113-3A3.0033 3.0033 0 017 19z"
  })), children);
});
var ConnectTarget20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectTarget20(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 2H30V30H28zM20 10l-1.4141 1.4141L22.1719 15H11.8989a5 5 0 100 2h10.273l-3.586 3.5859L20 22l6-6zM7 19a3 3 0 113-3A3.0033 3.0033 0 017 19z"
  })), children);
});
var ConnectTarget16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectTarget16(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 2H30V30H28zM20 10l-1.4141 1.4141L22.1719 15H11.8989a5 5 0 100 2h10.273l-3.586 3.5859L20 22l6-6zM7 19a3 3 0 113-3A3.0033 3.0033 0 017 19z"
  })), children);
});
var ConnectionReceive32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionReceive32(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8H10V12H8zM8 14H10V18H8zM14 8H16V12H14zM14 14H16V18H14zM8 20H10V24H8zM14 20H16V24H14zM30 14L21.83 14 24.41 16.59 23 18 18 13 23 8 24.41 9.41 21.83 12 30 12 30 14z"
  })), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20v8H22V20H20v8H4V4H20V6h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V30H30V20Z"
  })), children);
});
var ConnectionReceive24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionReceive24(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8H10V12H8zM8 14H10V18H8zM14 8H16V12H14zM14 14H16V18H14zM8 20H10V24H8zM14 20H16V24H14zM30 14L21.83 14 24.41 16.59 23 18 18 13 23 8 24.41 9.41 21.83 12 30 12 30 14z"
  })), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20v8H22V20H20v8H4V4H20V6h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V30H30V20Z"
  })), children);
});
var ConnectionReceive20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionReceive20(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8H10V12H8zM8 14H10V18H8zM14 8H16V12H14zM14 14H16V18H14zM8 20H10V24H8zM14 20H16V24H14zM30 14L21.83 14 24.41 16.59 23 18 18 13 23 8 24.41 9.41 21.83 12 30 12 30 14z"
  })), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20v8H22V20H20v8H4V4H20V6h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V30H30V20Z"
  })), children);
});
var ConnectionReceive16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionReceive16(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8H10V12H8zM8 14H10V18H8zM14 8H16V12H14zM14 14H16V18H14zM8 20H10V24H8zM14 20H16V24H14zM30 14L21.83 14 24.41 16.59 23 18 18 13 23 8 24.41 9.41 21.83 12 30 12 30 14z"
  })), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20v8H22V20H20v8H4V4H20V6h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V30H30V20Z"
  })), children);
});
var ConnectionSend32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionSend32(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8H10V12H8zM8 14H10V18H8zM14 8H16V12H14zM14 14H16V18H14zM8 20H10V24H8zM14 20H16V24H14zM18 14L26.17 14 23.59 16.59 25 18 30 13 25 8 23.59 9.41 26.17 12 18 12 18 14z"
  })), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20v8H22V20H20v8H4V4H20V6h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V30H30V20Z"
  })), children);
});
var ConnectionSend24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionSend24(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8H10V12H8zM8 14H10V18H8zM14 8H16V12H14zM14 14H16V18H14zM8 20H10V24H8zM14 20H16V24H14zM18 14L26.17 14 23.59 16.59 25 18 30 13 25 8 23.59 9.41 26.17 12 18 12 18 14z"
  })), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20v8H22V20H20v8H4V4H20V6h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V30H30V20Z"
  })), children);
});
var ConnectionSend20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionSend20(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8H10V12H8zM8 14H10V18H8zM14 8H16V12H14zM14 14H16V18H14zM8 20H10V24H8zM14 20H16V24H14zM18 14L26.17 14 23.59 16.59 25 18 30 13 25 8 23.59 9.41 26.17 12 18 12 18 14z"
  })), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20v8H22V20H20v8H4V4H20V6h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V30H30V20Z"
  })), children);
});
var ConnectionSend16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionSend16(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8H10V12H8zM8 14H10V18H8zM14 8H16V12H14zM14 14H16V18H14zM8 20H10V24H8zM14 20H16V24H14zM18 14L26.17 14 23.59 16.59 25 18 30 13 25 8 23.59 9.41 26.17 12 18 12 18 14z"
  })), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20v8H22V20H20v8H4V4H20V6h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V30H30V20Z"
  })), children);
});
var ConnectionTwoWay32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionTwoWay32(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8H10V12H8zM8 14H10V18H8zM14 8H16V12H14zM14 14H16V18H14zM8 20H10V24H8zM14 20H16V24H14zM30 22L21.83 22 24.41 24.59 23 26 18 21 23 16 24.41 17.41 21.83 20 30 20 30 22zM19 12L27.17 12 24.59 14.59 26 16 31 11 26 6 24.59 7.41 27.17 10 19 10 19 12z"
  })), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26v2H4V4H20V6h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V30H30V26Z"
  })), children);
});
var ConnectionTwoWay24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionTwoWay24(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8H10V12H8zM8 14H10V18H8zM14 8H16V12H14zM14 14H16V18H14zM8 20H10V24H8zM14 20H16V24H14zM30 22L21.83 22 24.41 24.59 23 26 18 21 23 16 24.41 17.41 21.83 20 30 20 30 22zM19 12L27.17 12 24.59 14.59 26 16 31 11 26 6 24.59 7.41 27.17 10 19 10 19 12z"
  })), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26v2H4V4H20V6h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V30H30V26Z"
  })), children);
});
var ConnectionTwoWay20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionTwoWay20(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8H10V12H8zM8 14H10V18H8zM14 8H16V12H14zM14 14H16V18H14zM8 20H10V24H8zM14 20H16V24H14zM30 22L21.83 22 24.41 24.59 23 26 18 21 23 16 24.41 17.41 21.83 20 30 20 30 22zM19 12L27.17 12 24.59 14.59 26 16 31 11 26 6 24.59 7.41 27.17 10 19 10 19 12z"
  })), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26v2H4V4H20V6h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V30H30V26Z"
  })), children);
});
var ConnectionTwoWay16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionTwoWay16(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 8H10V12H8zM8 14H10V18H8zM14 8H16V12H14zM14 14H16V18H14zM8 20H10V24H8zM14 20H16V24H14zM30 22L21.83 22 24.41 24.59 23 26 18 21 23 16 24.41 17.41 21.83 20 30 20 30 22zM19 12L27.17 12 24.59 14.59 26 16 31 11 26 6 24.59 7.41 27.17 10 19 10 19 12z"
  })), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26v2H4V4H20V6h2V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V30H30V26Z"
  })), children);
});
var ConnectionSignal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionSignal32(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 12H17V30H15zM11.33 18.22a7 7 0 010-10.44l1.34 1.49a5 5 0 000 7.46zM20.67 18.22l-1.34-1.49a5 5 0 000-7.46l1.34-1.49a7 7 0 010 10.44z"
  })), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.4 21.8a11 11 0 010-17.6L9.6 5.8a9 9 0 000 14.4zM23.6 21.8l-1.2-1.6a9 9 0 000-14.4l1.2-1.6a11 11 0 010 17.6z"
  })), children);
});
var ConnectionSignal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionSignal24(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 12H17V30H15zM11.33 18.22a7 7 0 010-10.44l1.34 1.49a5 5 0 000 7.46zM20.67 18.22l-1.34-1.49a5 5 0 000-7.46l1.34-1.49a7 7 0 010 10.44z"
  })), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.4 21.8a11 11 0 010-17.6L9.6 5.8a9 9 0 000 14.4zM23.6 21.8l-1.2-1.6a9 9 0 000-14.4l1.2-1.6a11 11 0 010 17.6z"
  })), children);
});
var ConnectionSignal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionSignal20(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 12H17V30H15zM11.33 18.22a7 7 0 010-10.44l1.34 1.49a5 5 0 000 7.46zM20.67 18.22l-1.34-1.49a5 5 0 000-7.46l1.34-1.49a7 7 0 010 10.44z"
  })), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.4 21.8a11 11 0 010-17.6L9.6 5.8a9 9 0 000 14.4zM23.6 21.8l-1.2-1.6a9 9 0 000-14.4l1.2-1.6a11 11 0 010 17.6z"
  })), children);
});
var ConnectionSignal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionSignal16(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 12H17V30H15zM11.33 18.22a7 7 0 010-10.44l1.34 1.49a5 5 0 000 7.46zM20.67 18.22l-1.34-1.49a5 5 0 000-7.46l1.34-1.49a7 7 0 010 10.44z"
  })), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8.4 21.8a11 11 0 010-17.6L9.6 5.8a9 9 0 000 14.4zM23.6 21.8l-1.2-1.6a9 9 0 000-14.4l1.2-1.6a11 11 0 010 17.6z"
  })), children);
});
var ConnectionSignalOff32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionSignalOff32(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,13a8.9089,8.9089,0,0,1-2.5249,6.2339l1.4133,1.4131A10.9795,10.9795,0,0,0,23.6006,4.2l-1.2012,1.6A8.932,8.932,0,0,1,26,13Z"
  })), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 13a5.0022 5.0022 0 01-.9023 2.8564l1.4277 1.4278a6.9831 6.9831 0 00-.8584-9.5015l-1.334 1.49A5.0077 5.0077 0 0121 13zM30 28.5859L3.4143 2 2 3.4141l3.71 3.71A10.9824 10.9824 0 008.3994 21.8008l1.2012-1.6A8.9678 8.9678 0 017.1714 8.5854l2.1963 2.1963a6.9664 6.9664 0 001.9648 7.4351l1.334-1.49A5.0072 5.0072 0 0111 13a4.8854 4.8854 0 01.0393-.5464L15 16.4141V30h2V18.4141L28.5857 30z"
  })), children);
});
var ConnectionSignalOff24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionSignalOff24(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,13a8.9089,8.9089,0,0,1-2.5249,6.2339l1.4133,1.4131A10.9795,10.9795,0,0,0,23.6006,4.2l-1.2012,1.6A8.932,8.932,0,0,1,26,13Z"
  })), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 13a5.0022 5.0022 0 01-.9023 2.8564l1.4277 1.4278a6.9831 6.9831 0 00-.8584-9.5015l-1.334 1.49A5.0077 5.0077 0 0121 13zM30 28.5859L3.4143 2 2 3.4141l3.71 3.71A10.9824 10.9824 0 008.3994 21.8008l1.2012-1.6A8.9678 8.9678 0 017.1714 8.5854l2.1963 2.1963a6.9664 6.9664 0 001.9648 7.4351l1.334-1.49A5.0072 5.0072 0 0111 13a4.8854 4.8854 0 01.0393-.5464L15 16.4141V30h2V18.4141L28.5857 30z"
  })), children);
});
var ConnectionSignalOff20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionSignalOff20(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,13a8.9089,8.9089,0,0,1-2.5249,6.2339l1.4133,1.4131A10.9795,10.9795,0,0,0,23.6006,4.2l-1.2012,1.6A8.932,8.932,0,0,1,26,13Z"
  })), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 13a5.0022 5.0022 0 01-.9023 2.8564l1.4277 1.4278a6.9831 6.9831 0 00-.8584-9.5015l-1.334 1.49A5.0077 5.0077 0 0121 13zM30 28.5859L3.4143 2 2 3.4141l3.71 3.71A10.9824 10.9824 0 008.3994 21.8008l1.2012-1.6A8.9678 8.9678 0 017.1714 8.5854l2.1963 2.1963a6.9664 6.9664 0 001.9648 7.4351l1.334-1.49A5.0072 5.0072 0 0111 13a4.8854 4.8854 0 01.0393-.5464L15 16.4141V30h2V18.4141L28.5857 30z"
  })), children);
});
var ConnectionSignalOff16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConnectionSignalOff16(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,13a8.9089,8.9089,0,0,1-2.5249,6.2339l1.4133,1.4131A10.9795,10.9795,0,0,0,23.6006,4.2l-1.2012,1.6A8.932,8.932,0,0,1,26,13Z"
  })), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21 13a5.0022 5.0022 0 01-.9023 2.8564l1.4277 1.4278a6.9831 6.9831 0 00-.8584-9.5015l-1.334 1.49A5.0077 5.0077 0 0121 13zM30 28.5859L3.4143 2 2 3.4141l3.71 3.71A10.9824 10.9824 0 008.3994 21.8008l1.2012-1.6A8.9678 8.9678 0 017.1714 8.5854l2.1963 2.1963a6.9664 6.9664 0 001.9648 7.4351l1.334-1.49A5.0072 5.0072 0 0111 13a4.8854 4.8854 0 01.0393-.5464L15 16.4141V30h2V18.4141L28.5857 30z"
  })), children);
});
var Construction32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Construction32(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.34 16.06a1.0007 1.0007 0 00-1.1084.3L24.46 20.8857l-5.4355-.9882-3.602-8.9512A3.014 3.014 0 0012.6138 9h-4.06A3.0018 3.0018 0 007.01 9.4277L2 12.4336v6.4009l5 .9092V30H9V20.1074l3.5652.648L14 24.2V30h2V23.8l-1.0911-2.6182L22.99 22.6509 18.2319 28.36A1 1 0 0019 30H29a1 1 0 001-1V17A1 1 0 0029.34 16.06zM4 17.1655V13.5664l3-1.8v5.9448zm5 .9092V11h3.6138a1.0141 1.0141 0 01.9453.6709l3.14 7.8037zM28 28H21.1353L28 19.7617zM12.5 8A3.5 3.5 0 1116 4.5 3.5042 3.5042 0 0112.5 8zm0-5A1.5 1.5 0 1014 4.5 1.5017 1.5017 0 0012.5 3z"
  })), children);
});
var Construction24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Construction24(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.34 16.06a1.0007 1.0007 0 00-1.1084.3L24.46 20.8857l-5.4355-.9882-3.602-8.9512A3.014 3.014 0 0012.6138 9h-4.06A3.0018 3.0018 0 007.01 9.4277L2 12.4336v6.4009l5 .9092V30H9V20.1074l3.5652.648L14 24.2V30h2V23.8l-1.0911-2.6182L22.99 22.6509 18.2319 28.36A1 1 0 0019 30H29a1 1 0 001-1V17A1 1 0 0029.34 16.06zM4 17.1655V13.5664l3-1.8v5.9448zm5 .9092V11h3.6138a1.0141 1.0141 0 01.9453.6709l3.14 7.8037zM28 28H21.1353L28 19.7617zM12.5 8A3.5 3.5 0 1116 4.5 3.5042 3.5042 0 0112.5 8zm0-5A1.5 1.5 0 1014 4.5 1.5017 1.5017 0 0012.5 3z"
  })), children);
});
var Construction20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Construction20(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.34 16.06a1.0007 1.0007 0 00-1.1084.3L24.46 20.8857l-5.4355-.9882-3.602-8.9512A3.014 3.014 0 0012.6138 9h-4.06A3.0018 3.0018 0 007.01 9.4277L2 12.4336v6.4009l5 .9092V30H9V20.1074l3.5652.648L14 24.2V30h2V23.8l-1.0911-2.6182L22.99 22.6509 18.2319 28.36A1 1 0 0019 30H29a1 1 0 001-1V17A1 1 0 0029.34 16.06zM4 17.1655V13.5664l3-1.8v5.9448zm5 .9092V11h3.6138a1.0141 1.0141 0 01.9453.6709l3.14 7.8037zM28 28H21.1353L28 19.7617zM12.5 8A3.5 3.5 0 1116 4.5 3.5042 3.5042 0 0112.5 8zm0-5A1.5 1.5 0 1014 4.5 1.5017 1.5017 0 0012.5 3z"
  })), children);
});
var Construction16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Construction16(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.34 16.06a1.0007 1.0007 0 00-1.1084.3L24.46 20.8857l-5.4355-.9882-3.602-8.9512A3.014 3.014 0 0012.6138 9h-4.06A3.0018 3.0018 0 007.01 9.4277L2 12.4336v6.4009l5 .9092V30H9V20.1074l3.5652.648L14 24.2V30h2V23.8l-1.0911-2.6182L22.99 22.6509 18.2319 28.36A1 1 0 0019 30H29a1 1 0 001-1V17A1 1 0 0029.34 16.06zM4 17.1655V13.5664l3-1.8v5.9448zm5 .9092V11h3.6138a1.0141 1.0141 0 01.9453.6709l3.14 7.8037zM28 28H21.1353L28 19.7617zM12.5 8A3.5 3.5 0 1116 4.5 3.5042 3.5042 0 0112.5 8zm0-5A1.5 1.5 0 1014 4.5 1.5017 1.5017 0 0012.5 3z"
  })), children);
});
var ContainerRegistry32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContainerRegistry32(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,13V6H8V22H24V13ZM10,8h5v5H10Zm0,7h5v5H10Zm12,5H17V15h5Z"
  })), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 11H19V2h9zM21 9h5V4H21zM28 20H26v2h2v6H4V22H6V20H4a2.0024 2.0024 0 00-2 2v6a2.0024 2.0024 0 002 2H28a2.0024 2.0024 0 002-2V22A2.0024 2.0024 0 0028 20z"
  })), _circle61 || (_circle61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), children);
});
var ContainerRegistry24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContainerRegistry24(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,13V6H8V22H24V13ZM10,8h5v5H10Zm0,7h5v5H10Zm12,5H17V15h5Z"
  })), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 11H19V2h9zM21 9h5V4H21zM28 20H26v2h2v6H4V22H6V20H4a2.0024 2.0024 0 00-2 2v6a2.0024 2.0024 0 002 2H28a2.0024 2.0024 0 002-2V22A2.0024 2.0024 0 0028 20z"
  })), _circle62 || (_circle62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), children);
});
var ContainerRegistry20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContainerRegistry20(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,13V6H8V22H24V13ZM10,8h5v5H10Zm0,7h5v5H10Zm12,5H17V15h5Z"
  })), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 11H19V2h9zM21 9h5V4H21zM28 20H26v2h2v6H4V22H6V20H4a2.0024 2.0024 0 00-2 2v6a2.0024 2.0024 0 002 2H28a2.0024 2.0024 0 002-2V22A2.0024 2.0024 0 0028 20z"
  })), _circle63 || (_circle63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), children);
});
var ContainerRegistry16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContainerRegistry16(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,13V6H8V22H24V13ZM10,8h5v5H10Zm0,7h5v5H10Zm12,5H17V15h5Z"
  })), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 11H19V2h9zM21 9h5V4H21zM28 20H26v2h2v6H4V22H6V20H4a2.0024 2.0024 0 00-2 2v6a2.0024 2.0024 0 002 2H28a2.0024 2.0024 0 002-2V22A2.0024 2.0024 0 0028 20z"
  })), _circle64 || (_circle64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), children);
});
var ContainerServices32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContainerServices32(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22V17a2.0023,2.0023,0,0,0-2-2H17V10h3a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H12a2.0023,2.0023,0,0,0-2,2V8a2.0023,2.0023,0,0,0,2,2h3v5H7a2.0023,2.0023,0,0,0-2,2v5H2v8h8V22H7V17h8v5H12v8h8V22H17V17h8v5H22v8h8V22ZM12,4h8V8H12ZM8,28H4V24H8Zm10,0H14V24h4Zm10,0H24V24h4Z"
  })), children);
});
var ContainerServices24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContainerServices24(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22V17a2.0023,2.0023,0,0,0-2-2H17V10h3a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H12a2.0023,2.0023,0,0,0-2,2V8a2.0023,2.0023,0,0,0,2,2h3v5H7a2.0023,2.0023,0,0,0-2,2v5H2v8h8V22H7V17h8v5H12v8h8V22H17V17h8v5H22v8h8V22ZM12,4h8V8H12ZM8,28H4V24H8Zm10,0H14V24h4Zm10,0H24V24h4Z"
  })), children);
});
var ContainerServices20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContainerServices20(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22V17a2.0023,2.0023,0,0,0-2-2H17V10h3a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H12a2.0023,2.0023,0,0,0-2,2V8a2.0023,2.0023,0,0,0,2,2h3v5H7a2.0023,2.0023,0,0,0-2,2v5H2v8h8V22H7V17h8v5H12v8h8V22H17V17h8v5H22v8h8V22ZM12,4h8V8H12ZM8,28H4V24H8Zm10,0H14V24h4Zm10,0H24V24h4Z"
  })), children);
});
var ContainerServices16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContainerServices16(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22V17a2.0023,2.0023,0,0,0-2-2H17V10h3a2.0023,2.0023,0,0,0,2-2V4a2.0023,2.0023,0,0,0-2-2H12a2.0023,2.0023,0,0,0-2,2V8a2.0023,2.0023,0,0,0,2,2h3v5H7a2.0023,2.0023,0,0,0-2,2v5H2v8h8V22H7V17h8v5H12v8h8V22H17V17h8v5H22v8h8V22ZM12,4h8V8H12ZM8,28H4V24H8Zm10,0H14V24h4Zm10,0H24V24h4Z"
  })), children);
});
var ContainerSoftware32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContainerSoftware32(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12H20V4h8Zm-6-2h4V6H22Z"
  })), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,15V9H9V23H23V15Zm-6-4h4v4H11Zm4,10H11V17h4Zm6,0H17V17h4Z"
  })), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,6,4H16V6H6V26H26V16h2V26A2.0023,2.0023,0,0,1,26,28Z"
  })), children);
});
var ContainerSoftware24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContainerSoftware24(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12H20V4h8Zm-6-2h4V6H22Z"
  })), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,15V9H9V23H23V15Zm-6-4h4v4H11Zm4,10H11V17h4Zm6,0H17V17h4Z"
  })), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,6,4H16V6H6V26H26V16h2V26A2.0023,2.0023,0,0,1,26,28Z"
  })), children);
});
var ContainerSoftware20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContainerSoftware20(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12H20V4h8Zm-6-2h4V6H22Z"
  })), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,15V9H9V23H23V15Zm-6-4h4v4H11Zm4,10H11V17h4Zm6,0H17V17h4Z"
  })), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,6,4H16V6H6V26H26V16h2V26A2.0023,2.0023,0,0,1,26,28Z"
  })), children);
});
var ContainerSoftware16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContainerSoftware16(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,12H20V4h8Zm-6-2h4V6H22Z"
  })), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,15V9H9V23H23V15Zm-6-4h4v4H11Zm4,10H11V17h4Zm6,0H17V17h4Z"
  })), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,28H6a2.0023,2.0023,0,0,1-2-2V6A2.0023,2.0023,0,0,1,6,4H16V6H6V26H26V16h2V26A2.0023,2.0023,0,0,1,26,28Z"
  })), children);
});
var ContentDeliveryNetwork32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContentDeliveryNetwork32(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle65 || (_circle65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "21",
    r: "2"
  })), _circle66 || (_circle66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "7",
    r: "2"
  })), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,31a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,27,31Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,27,25Z"
  })), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16A14.0412,14.0412,0,0,0,16,2,13.0426,13.0426,0,0,0,9.2,3.8l1.1,1.7a24.4254,24.4254,0,0,1,2.4-1A25.1349,25.1349,0,0,0,10,15H4a11.1489,11.1489,0,0,1,1.4-4.7L3.9,9A13.8418,13.8418,0,0,0,2,16,13.9983,13.9983,0,0,0,16,30a13.3656,13.3656,0,0,0,5.2-1l-.6-1.9a11.4416,11.4416,0,0,1-5.2.9h0A21.0713,21.0713,0,0,1,12,17H29.9A3.4019,3.4019,0,0,0,30,16ZM12.8,27.6h0a13.02,13.02,0,0,1-5.3-3.1A12.5053,12.5053,0,0,1,4,17h6A25.0022,25.0022,0,0,0,12.8,27.6ZM12,15A21.4461,21.4461,0,0,1,15.3,4h1.4A21.4461,21.4461,0,0,1,20,15Zm10,0A23.2777,23.2777,0,0,0,19.2,4.4,12.0919,12.0919,0,0,1,27.9,15Z"
  })), children);
});
var ContentDeliveryNetwork24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContentDeliveryNetwork24(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle67 || (_circle67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "21",
    r: "2"
  })), _circle68 || (_circle68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "7",
    r: "2"
  })), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,31a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,27,31Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,27,25Z"
  })), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16A14.0412,14.0412,0,0,0,16,2,13.0426,13.0426,0,0,0,9.2,3.8l1.1,1.7a24.4254,24.4254,0,0,1,2.4-1A25.1349,25.1349,0,0,0,10,15H4a11.1489,11.1489,0,0,1,1.4-4.7L3.9,9A13.8418,13.8418,0,0,0,2,16,13.9983,13.9983,0,0,0,16,30a13.3656,13.3656,0,0,0,5.2-1l-.6-1.9a11.4416,11.4416,0,0,1-5.2.9h0A21.0713,21.0713,0,0,1,12,17H29.9A3.4019,3.4019,0,0,0,30,16ZM12.8,27.6h0a13.02,13.02,0,0,1-5.3-3.1A12.5053,12.5053,0,0,1,4,17h6A25.0022,25.0022,0,0,0,12.8,27.6ZM12,15A21.4461,21.4461,0,0,1,15.3,4h1.4A21.4461,21.4461,0,0,1,20,15Zm10,0A23.2777,23.2777,0,0,0,19.2,4.4,12.0919,12.0919,0,0,1,27.9,15Z"
  })), children);
});
var ContentDeliveryNetwork20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContentDeliveryNetwork20(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle69 || (_circle69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "21",
    r: "2"
  })), _circle70 || (_circle70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "7",
    r: "2"
  })), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,31a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,27,31Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,27,25Z"
  })), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16A14.0412,14.0412,0,0,0,16,2,13.0426,13.0426,0,0,0,9.2,3.8l1.1,1.7a24.4254,24.4254,0,0,1,2.4-1A25.1349,25.1349,0,0,0,10,15H4a11.1489,11.1489,0,0,1,1.4-4.7L3.9,9A13.8418,13.8418,0,0,0,2,16,13.9983,13.9983,0,0,0,16,30a13.3656,13.3656,0,0,0,5.2-1l-.6-1.9a11.4416,11.4416,0,0,1-5.2.9h0A21.0713,21.0713,0,0,1,12,17H29.9A3.4019,3.4019,0,0,0,30,16ZM12.8,27.6h0a13.02,13.02,0,0,1-5.3-3.1A12.5053,12.5053,0,0,1,4,17h6A25.0022,25.0022,0,0,0,12.8,27.6ZM12,15A21.4461,21.4461,0,0,1,15.3,4h1.4A21.4461,21.4461,0,0,1,20,15Zm10,0A23.2777,23.2777,0,0,0,19.2,4.4,12.0919,12.0919,0,0,1,27.9,15Z"
  })), children);
});
var ContentDeliveryNetwork16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContentDeliveryNetwork16(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle71 || (_circle71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "21",
    r: "2"
  })), _circle72 || (_circle72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "7",
    r: "2"
  })), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,31a4,4,0,1,1,4-4A4.0118,4.0118,0,0,1,27,31Zm0-6a2,2,0,1,0,2,2A2.0059,2.0059,0,0,0,27,25Z"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,16A14.0412,14.0412,0,0,0,16,2,13.0426,13.0426,0,0,0,9.2,3.8l1.1,1.7a24.4254,24.4254,0,0,1,2.4-1A25.1349,25.1349,0,0,0,10,15H4a11.1489,11.1489,0,0,1,1.4-4.7L3.9,9A13.8418,13.8418,0,0,0,2,16,13.9983,13.9983,0,0,0,16,30a13.3656,13.3656,0,0,0,5.2-1l-.6-1.9a11.4416,11.4416,0,0,1-5.2.9h0A21.0713,21.0713,0,0,1,12,17H29.9A3.4019,3.4019,0,0,0,30,16ZM12.8,27.6h0a13.02,13.02,0,0,1-5.3-3.1A12.5053,12.5053,0,0,1,4,17h6A25.0022,25.0022,0,0,0,12.8,27.6ZM12,15A21.4461,21.4461,0,0,1,15.3,4h1.4A21.4461,21.4461,0,0,1,20,15Zm10,0A23.2777,23.2777,0,0,0,19.2,4.4,12.0919,12.0919,0,0,1,27.9,15Z"
  })), children);
});
var ContentView32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContentView32(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle73 || (_circle73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "19",
    r: "2"
  })), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.7769,18.4785A8.64,8.64,0,0,0,16,13a8.64,8.64,0,0,0-7.7769,5.4785L8,19l.2231.5215A8.64,8.64,0,0,0,16,25a8.64,8.64,0,0,0,7.7769-5.4785L24,19ZM16,23a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,23Z"
  })), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2,2,0,0,0,3,5V27a2,2,0,0,0,2,2H27a2,2,0,0,0,2-2V5A2,2,0,0,0,27,3ZM5,5H27V9H5ZM5,27V11H27V27Z"
  })), children);
});
var ContentView24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContentView24(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle74 || (_circle74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "19",
    r: "2"
  })), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.7769,18.4785A8.64,8.64,0,0,0,16,13a8.64,8.64,0,0,0-7.7769,5.4785L8,19l.2231.5215A8.64,8.64,0,0,0,16,25a8.64,8.64,0,0,0,7.7769-5.4785L24,19ZM16,23a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,23Z"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2,2,0,0,0,3,5V27a2,2,0,0,0,2,2H27a2,2,0,0,0,2-2V5A2,2,0,0,0,27,3ZM5,5H27V9H5ZM5,27V11H27V27Z"
  })), children);
});
var ContentView20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContentView20(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle75 || (_circle75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "19",
    r: "2"
  })), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.7769,18.4785A8.64,8.64,0,0,0,16,13a8.64,8.64,0,0,0-7.7769,5.4785L8,19l.2231.5215A8.64,8.64,0,0,0,16,25a8.64,8.64,0,0,0,7.7769-5.4785L24,19ZM16,23a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,23Z"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2,2,0,0,0,3,5V27a2,2,0,0,0,2,2H27a2,2,0,0,0,2-2V5A2,2,0,0,0,27,3ZM5,5H27V9H5ZM5,27V11H27V27Z"
  })), children);
});
var ContentView16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContentView16(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle76 || (_circle76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "19",
    r: "2"
  })), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.7769,18.4785A8.64,8.64,0,0,0,16,13a8.64,8.64,0,0,0-7.7769,5.4785L8,19l.2231.5215A8.64,8.64,0,0,0,16,25a8.64,8.64,0,0,0,7.7769-5.4785L24,19ZM16,23a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,23Z"
  })), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,3H5A2,2,0,0,0,3,5V27a2,2,0,0,0,2,2H27a2,2,0,0,0,2-2V5A2,2,0,0,0,27,3ZM5,5H27V9H5ZM5,27V11H27V27Z"
  })), children);
});
var Continue32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Continue32(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 28a1 1 0 01-1-1V5a1 1 0 011.501-.8652l19 11a1 1 0 010 1.73l-19 11A.9975.9975 0 0110 28zM11 6.7344V25.2656L27 16zM4 4H6V28H4z"
  })), children);
});
var Continue24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Continue24(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 28a1 1 0 01-1-1V5a1 1 0 011.501-.8652l19 11a1 1 0 010 1.73l-19 11A.9975.9975 0 0110 28zM11 6.7344V25.2656L27 16zM4 4H6V28H4z"
  })), children);
});
var Continue20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Continue20(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 28a1 1 0 01-1-1V5a1 1 0 011.501-.8652l19 11a1 1 0 010 1.73l-19 11A.9975.9975 0 0110 28zM11 6.7344V25.2656L27 16zM4 4H6V28H4z"
  })), children);
});
var Continue16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Continue16(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 28a1 1 0 01-1-1V5a1 1 0 011.501-.8652l19 11a1 1 0 010 1.73l-19 11A.9975.9975 0 0110 28zM11 6.7344V25.2656L27 16zM4 4H6V28H4z"
  })), children);
});
var ContinueFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContinueFilled32(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 28a1 1 0 01-1-1V5a1 1 0 011.501-.8652l19 11a1 1 0 010 1.73l-19 11A.9975.9975 0 0110 28zM4 4H6V28H4z"
  })), children);
});
var ContinueFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContinueFilled24(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 28a1 1 0 01-1-1V5a1 1 0 011.501-.8652l19 11a1 1 0 010 1.73l-19 11A.9975.9975 0 0110 28zM4 4H6V28H4z"
  })), children);
});
var ContinueFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContinueFilled20(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 28a1 1 0 01-1-1V5a1 1 0 011.501-.8652l19 11a1 1 0 010 1.73l-19 11A.9975.9975 0 0110 28zM4 4H6V28H4z"
  })), children);
});
var ContinueFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ContinueFilled16(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 28a1 1 0 01-1-1V5a1 1 0 011.501-.8652l19 11a1 1 0 010 1.73l-19 11A.9975.9975 0 0110 28zM4 4H6V28H4z"
  })), children);
});
var WatsonHealthContourDraw32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthContourDraw32(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.7 4.7a14.7029 14.7029 0 00-3 3.1L6.3 9A13.2634 13.2634 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.5111 12.5111 0 002 16H4A11.4756 11.4756 0 014.6 12.3zM11.7 2.7l.6 1.9A11.4756 11.4756 0 0116 4V2A12.5111 12.5111 0 0011.7 2.7zM24.2 27.3a15.18 15.18 0 003.1-3.1L25.7 23A11.526 11.526 0 0123 25.7zM27.4 19.7l1.9.6A15.4747 15.4747 0 0030 16H28A11.4756 11.4756 0 0127.4 19.7zM29.2 11.6a14.4029 14.4029 0 00-2-3.9L25.6 8.9a12.8867 12.8867 0 011.7 3.3zM24.1 4.6a14.4029 14.4029 0 00-3.9-2l-.6 1.9a12.8867 12.8867 0 013.3 1.7zM20.3 29.3l-.6-1.9A11.4756 11.4756 0 0116 28v2A21.4206 21.4206 0 0020.3 29.3zM15.4023 24.248a11.9488 11.9488 0 00-1.7182-3.3354L15.2974 19.73a13.9486 13.9486 0 012.0044 3.893zM11.02 18.2668a11.9215 11.9215 0 00-3.3467-1.6943l.6114-1.9043a13.9242 13.9242 0 013.9072 1.978z"
  })), children);
});
var WatsonHealthContourDraw24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthContourDraw24(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.7 4.7a14.7029 14.7029 0 00-3 3.1L6.3 9A13.2634 13.2634 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.5111 12.5111 0 002 16H4A11.4756 11.4756 0 014.6 12.3zM11.7 2.7l.6 1.9A11.4756 11.4756 0 0116 4V2A12.5111 12.5111 0 0011.7 2.7zM24.2 27.3a15.18 15.18 0 003.1-3.1L25.7 23A11.526 11.526 0 0123 25.7zM27.4 19.7l1.9.6A15.4747 15.4747 0 0030 16H28A11.4756 11.4756 0 0127.4 19.7zM29.2 11.6a14.4029 14.4029 0 00-2-3.9L25.6 8.9a12.8867 12.8867 0 011.7 3.3zM24.1 4.6a14.4029 14.4029 0 00-3.9-2l-.6 1.9a12.8867 12.8867 0 013.3 1.7zM20.3 29.3l-.6-1.9A11.4756 11.4756 0 0116 28v2A21.4206 21.4206 0 0020.3 29.3zM15.4023 24.248a11.9488 11.9488 0 00-1.7182-3.3354L15.2974 19.73a13.9486 13.9486 0 012.0044 3.893zM11.02 18.2668a11.9215 11.9215 0 00-3.3467-1.6943l.6114-1.9043a13.9242 13.9242 0 013.9072 1.978z"
  })), children);
});
var WatsonHealthContourDraw20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthContourDraw20(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.7 4.7a14.7029 14.7029 0 00-3 3.1L6.3 9A13.2634 13.2634 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.5111 12.5111 0 002 16H4A11.4756 11.4756 0 014.6 12.3zM11.7 2.7l.6 1.9A11.4756 11.4756 0 0116 4V2A12.5111 12.5111 0 0011.7 2.7zM24.2 27.3a15.18 15.18 0 003.1-3.1L25.7 23A11.526 11.526 0 0123 25.7zM27.4 19.7l1.9.6A15.4747 15.4747 0 0030 16H28A11.4756 11.4756 0 0127.4 19.7zM29.2 11.6a14.4029 14.4029 0 00-2-3.9L25.6 8.9a12.8867 12.8867 0 011.7 3.3zM24.1 4.6a14.4029 14.4029 0 00-3.9-2l-.6 1.9a12.8867 12.8867 0 013.3 1.7zM20.3 29.3l-.6-1.9A11.4756 11.4756 0 0116 28v2A21.4206 21.4206 0 0020.3 29.3zM15.4023 24.248a11.9488 11.9488 0 00-1.7182-3.3354L15.2974 19.73a13.9486 13.9486 0 012.0044 3.893zM11.02 18.2668a11.9215 11.9215 0 00-3.3467-1.6943l.6114-1.9043a13.9242 13.9242 0 013.9072 1.978z"
  })), children);
});
var WatsonHealthContourDraw16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthContourDraw16(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.7 4.7a14.7029 14.7029 0 00-3 3.1L6.3 9A13.2634 13.2634 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.5111 12.5111 0 002 16H4A11.4756 11.4756 0 014.6 12.3zM11.7 2.7l.6 1.9A11.4756 11.4756 0 0116 4V2A12.5111 12.5111 0 0011.7 2.7zM24.2 27.3a15.18 15.18 0 003.1-3.1L25.7 23A11.526 11.526 0 0123 25.7zM27.4 19.7l1.9.6A15.4747 15.4747 0 0030 16H28A11.4756 11.4756 0 0127.4 19.7zM29.2 11.6a14.4029 14.4029 0 00-2-3.9L25.6 8.9a12.8867 12.8867 0 011.7 3.3zM24.1 4.6a14.4029 14.4029 0 00-3.9-2l-.6 1.9a12.8867 12.8867 0 013.3 1.7zM20.3 29.3l-.6-1.9A11.4756 11.4756 0 0116 28v2A21.4206 21.4206 0 0020.3 29.3zM15.4023 24.248a11.9488 11.9488 0 00-1.7182-3.3354L15.2974 19.73a13.9486 13.9486 0 012.0044 3.893zM11.02 18.2668a11.9215 11.9215 0 00-3.3467-1.6943l.6114-1.9043a13.9242 13.9242 0 013.9072 1.978z"
  })), children);
});
var WatsonHealthContourEdit32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthContourEdit32(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30V28A12.0021 12.0021 0 0019.6924 4.5786l.6152-1.9033A14.0022 14.0022 0 0116 30zM7.7 4.7a14.7029 14.7029 0 00-3 3.1L6.3 9A13.2634 13.2634 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.5111 12.5111 0 002 16H4A11.4756 11.4756 0 014.6 12.3zM11.7 2.7l.6 1.9A11.4756 11.4756 0 0116 4V2A12.5111 12.5111 0 0011.7 2.7z"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4023 24.248a11.9488 11.9488 0 00-1.7182-3.3354L15.2974 19.73a13.9486 13.9486 0 012.0044 3.893zM11.02 18.2668a11.9215 11.9215 0 00-3.3467-1.6943l.6114-1.9043a13.9242 13.9242 0 013.9072 1.978z"
  })), children);
});
var WatsonHealthContourEdit24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthContourEdit24(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30V28A12.0021 12.0021 0 0019.6924 4.5786l.6152-1.9033A14.0022 14.0022 0 0116 30zM7.7 4.7a14.7029 14.7029 0 00-3 3.1L6.3 9A13.2634 13.2634 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.5111 12.5111 0 002 16H4A11.4756 11.4756 0 014.6 12.3zM11.7 2.7l.6 1.9A11.4756 11.4756 0 0116 4V2A12.5111 12.5111 0 0011.7 2.7z"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4023 24.248a11.9488 11.9488 0 00-1.7182-3.3354L15.2974 19.73a13.9486 13.9486 0 012.0044 3.893zM11.02 18.2668a11.9215 11.9215 0 00-3.3467-1.6943l.6114-1.9043a13.9242 13.9242 0 013.9072 1.978z"
  })), children);
});
var WatsonHealthContourEdit20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthContourEdit20(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30V28A12.0021 12.0021 0 0019.6924 4.5786l.6152-1.9033A14.0022 14.0022 0 0116 30zM7.7 4.7a14.7029 14.7029 0 00-3 3.1L6.3 9A13.2634 13.2634 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.5111 12.5111 0 002 16H4A11.4756 11.4756 0 014.6 12.3zM11.7 2.7l.6 1.9A11.4756 11.4756 0 0116 4V2A12.5111 12.5111 0 0011.7 2.7z"
  })), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4023 24.248a11.9488 11.9488 0 00-1.7182-3.3354L15.2974 19.73a13.9486 13.9486 0 012.0044 3.893zM11.02 18.2668a11.9215 11.9215 0 00-3.3467-1.6943l.6114-1.9043a13.9242 13.9242 0 013.9072 1.978z"
  })), children);
});
var WatsonHealthContourEdit16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthContourEdit16(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30V28A12.0021 12.0021 0 0019.6924 4.5786l.6152-1.9033A14.0022 14.0022 0 0116 30zM7.7 4.7a14.7029 14.7029 0 00-3 3.1L6.3 9A13.2634 13.2634 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.5111 12.5111 0 002 16H4A11.4756 11.4756 0 014.6 12.3zM11.7 2.7l.6 1.9A11.4756 11.4756 0 0116 4V2A12.5111 12.5111 0 0011.7 2.7z"
  })), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15.4023 24.248a11.9488 11.9488 0 00-1.7182-3.3354L15.2974 19.73a13.9486 13.9486 0 012.0044 3.893zM11.02 18.2668a11.9215 11.9215 0 00-3.3467-1.6943l.6114-1.9043a13.9242 13.9242 0 013.9072 1.978z"
  })), children);
});
var WatsonHealthContourFinding32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthContourFinding32(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.7 4.7a14.7029 14.7029 0 00-3 3.1L6.3 9A13.2634 13.2634 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.5111 12.5111 0 002 16H4A11.4756 11.4756 0 014.6 12.3zM2.7 20.4a14.4029 14.4029 0 002 3.9l1.6-1.2a12.8867 12.8867 0 01-1.7-3.3zM7.8 27.3a14.4029 14.4029 0 003.9 2l.6-1.9A12.8867 12.8867 0 019 25.7zM11.7 2.7l.6 1.9A11.4756 11.4756 0 0116 4V2A12.5111 12.5111 0 0011.7 2.7zM24.2 27.3a15.18 15.18 0 003.1-3.1L25.7 23A11.526 11.526 0 0123 25.7zM27.4 19.7l1.9.6A15.4747 15.4747 0 0030 16H28A11.4756 11.4756 0 0127.4 19.7zM29.2 11.6a14.4029 14.4029 0 00-2-3.9L25.6 8.9a12.8867 12.8867 0 011.7 3.3zM24.1 4.6a14.4029 14.4029 0 00-3.9-2l-.6 1.9a12.8867 12.8867 0 013.3 1.7zM20.3 29.3l-.6-1.9A11.4756 11.4756 0 0116 28v2A21.4206 21.4206 0 0020.3 29.3zM16 26A10 10 0 1126 16 10.0115 10.0115 0 0116 26zM16 8a8 8 0 108 8A8.0092 8.0092 0 0016 8z"
  })), children);
});
var WatsonHealthContourFinding24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthContourFinding24(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.7 4.7a14.7029 14.7029 0 00-3 3.1L6.3 9A13.2634 13.2634 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.5111 12.5111 0 002 16H4A11.4756 11.4756 0 014.6 12.3zM2.7 20.4a14.4029 14.4029 0 002 3.9l1.6-1.2a12.8867 12.8867 0 01-1.7-3.3zM7.8 27.3a14.4029 14.4029 0 003.9 2l.6-1.9A12.8867 12.8867 0 019 25.7zM11.7 2.7l.6 1.9A11.4756 11.4756 0 0116 4V2A12.5111 12.5111 0 0011.7 2.7zM24.2 27.3a15.18 15.18 0 003.1-3.1L25.7 23A11.526 11.526 0 0123 25.7zM27.4 19.7l1.9.6A15.4747 15.4747 0 0030 16H28A11.4756 11.4756 0 0127.4 19.7zM29.2 11.6a14.4029 14.4029 0 00-2-3.9L25.6 8.9a12.8867 12.8867 0 011.7 3.3zM24.1 4.6a14.4029 14.4029 0 00-3.9-2l-.6 1.9a12.8867 12.8867 0 013.3 1.7zM20.3 29.3l-.6-1.9A11.4756 11.4756 0 0116 28v2A21.4206 21.4206 0 0020.3 29.3zM16 26A10 10 0 1126 16 10.0115 10.0115 0 0116 26zM16 8a8 8 0 108 8A8.0092 8.0092 0 0016 8z"
  })), children);
});
var WatsonHealthContourFinding20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthContourFinding20(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.7 4.7a14.7029 14.7029 0 00-3 3.1L6.3 9A13.2634 13.2634 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.5111 12.5111 0 002 16H4A11.4756 11.4756 0 014.6 12.3zM2.7 20.4a14.4029 14.4029 0 002 3.9l1.6-1.2a12.8867 12.8867 0 01-1.7-3.3zM7.8 27.3a14.4029 14.4029 0 003.9 2l.6-1.9A12.8867 12.8867 0 019 25.7zM11.7 2.7l.6 1.9A11.4756 11.4756 0 0116 4V2A12.5111 12.5111 0 0011.7 2.7zM24.2 27.3a15.18 15.18 0 003.1-3.1L25.7 23A11.526 11.526 0 0123 25.7zM27.4 19.7l1.9.6A15.4747 15.4747 0 0030 16H28A11.4756 11.4756 0 0127.4 19.7zM29.2 11.6a14.4029 14.4029 0 00-2-3.9L25.6 8.9a12.8867 12.8867 0 011.7 3.3zM24.1 4.6a14.4029 14.4029 0 00-3.9-2l-.6 1.9a12.8867 12.8867 0 013.3 1.7zM20.3 29.3l-.6-1.9A11.4756 11.4756 0 0116 28v2A21.4206 21.4206 0 0020.3 29.3zM16 26A10 10 0 1126 16 10.0115 10.0115 0 0116 26zM16 8a8 8 0 108 8A8.0092 8.0092 0 0016 8z"
  })), children);
});
var WatsonHealthContourFinding16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthContourFinding16(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7.7 4.7a14.7029 14.7029 0 00-3 3.1L6.3 9A13.2634 13.2634 0 018.9 6.3zM4.6 12.3l-1.9-.6A12.5111 12.5111 0 002 16H4A11.4756 11.4756 0 014.6 12.3zM2.7 20.4a14.4029 14.4029 0 002 3.9l1.6-1.2a12.8867 12.8867 0 01-1.7-3.3zM7.8 27.3a14.4029 14.4029 0 003.9 2l.6-1.9A12.8867 12.8867 0 019 25.7zM11.7 2.7l.6 1.9A11.4756 11.4756 0 0116 4V2A12.5111 12.5111 0 0011.7 2.7zM24.2 27.3a15.18 15.18 0 003.1-3.1L25.7 23A11.526 11.526 0 0123 25.7zM27.4 19.7l1.9.6A15.4747 15.4747 0 0030 16H28A11.4756 11.4756 0 0127.4 19.7zM29.2 11.6a14.4029 14.4029 0 00-2-3.9L25.6 8.9a12.8867 12.8867 0 011.7 3.3zM24.1 4.6a14.4029 14.4029 0 00-3.9-2l-.6 1.9a12.8867 12.8867 0 013.3 1.7zM20.3 29.3l-.6-1.9A11.4756 11.4756 0 0116 28v2A21.4206 21.4206 0 0020.3 29.3zM16 26A10 10 0 1126 16 10.0115 10.0115 0 0116 26zM16 8a8 8 0 108 8A8.0092 8.0092 0 0016 8z"
  })), children);
});
var Contrast32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Contrast32(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.37,11.84a13.6,13.6,0,0,0-1.06-2.51A14.17,14.17,0,0,0,25.9,6.1a14,14,0,1,0,0,19.8,14.17,14.17,0,0,0,2.41-3.23,13.6,13.6,0,0,0,1.06-2.51,14,14,0,0,0,0-8.32ZM4,16A12,12,0,0,1,16,4V28A12,12,0,0,1,4,16Z"
  })), children);
});
var Contrast24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Contrast24(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.37,11.84a13.6,13.6,0,0,0-1.06-2.51A14.17,14.17,0,0,0,25.9,6.1a14,14,0,1,0,0,19.8,14.17,14.17,0,0,0,2.41-3.23,13.6,13.6,0,0,0,1.06-2.51,14,14,0,0,0,0-8.32ZM4,16A12,12,0,0,1,16,4V28A12,12,0,0,1,4,16Z"
  })), children);
});
var Contrast20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Contrast20(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.37,11.84a13.6,13.6,0,0,0-1.06-2.51A14.17,14.17,0,0,0,25.9,6.1a14,14,0,1,0,0,19.8,14.17,14.17,0,0,0,2.41-3.23,13.6,13.6,0,0,0,1.06-2.51,14,14,0,0,0,0-8.32ZM4,16A12,12,0,0,1,16,4V28A12,12,0,0,1,4,16Z"
  })), children);
});
var Contrast16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Contrast16(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.37,11.84a13.6,13.6,0,0,0-1.06-2.51A14.17,14.17,0,0,0,25.9,6.1a14,14,0,1,0,0,19.8,14.17,14.17,0,0,0,2.41-3.23,13.6,13.6,0,0,0,1.06-2.51,14,14,0,0,0,0-8.32ZM4,16A12,12,0,0,1,16,4V28A12,12,0,0,1,4,16Z"
  })), children);
});
var ConvertToCloud32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConvertToCloud32(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5 12H19a4 4 0 010-8h.0835A4.7864 4.7864 0 0123 2a4.9816 4.9816 0 014.6543 3.2034A3.4667 3.4667 0 0130 8.5 3.5041 3.5041 0 0126.5 12zM19 6a2 2 0 000 4h7.5A1.5017 1.5017 0 0028 8.5a1.4855 1.4855 0 00-1.2778-1.4739L26.061 6.927l-.1616-.6487a2.9568 2.9568 0 00-5.4873-.7121L20.1143 6zM23 14l-5 5 1.4141 1.4141L22 17.8325V24H16v2h6a2.0025 2.0025 0 002-2V17.8325l2.5874 2.583L28 19zM2 20H12V22H2zM2 24H12V26H2zM2 28H12V30H2z"
  })), children);
});
var ConvertToCloud24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConvertToCloud24(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5 12H19a4 4 0 010-8h.0835A4.7864 4.7864 0 0123 2a4.9816 4.9816 0 014.6543 3.2034A3.4667 3.4667 0 0130 8.5 3.5041 3.5041 0 0126.5 12zM19 6a2 2 0 000 4h7.5A1.5017 1.5017 0 0028 8.5a1.4855 1.4855 0 00-1.2778-1.4739L26.061 6.927l-.1616-.6487a2.9568 2.9568 0 00-5.4873-.7121L20.1143 6zM23 14l-5 5 1.4141 1.4141L22 17.8325V24H16v2h6a2.0025 2.0025 0 002-2V17.8325l2.5874 2.583L28 19zM2 20H12V22H2zM2 24H12V26H2zM2 28H12V30H2z"
  })), children);
});
var ConvertToCloud20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConvertToCloud20(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5 12H19a4 4 0 010-8h.0835A4.7864 4.7864 0 0123 2a4.9816 4.9816 0 014.6543 3.2034A3.4667 3.4667 0 0130 8.5 3.5041 3.5041 0 0126.5 12zM19 6a2 2 0 000 4h7.5A1.5017 1.5017 0 0028 8.5a1.4855 1.4855 0 00-1.2778-1.4739L26.061 6.927l-.1616-.6487a2.9568 2.9568 0 00-5.4873-.7121L20.1143 6zM23 14l-5 5 1.4141 1.4141L22 17.8325V24H16v2h6a2.0025 2.0025 0 002-2V17.8325l2.5874 2.583L28 19zM2 20H12V22H2zM2 24H12V26H2zM2 28H12V30H2z"
  })), children);
});
var ConvertToCloud16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function ConvertToCloud16(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5 12H19a4 4 0 010-8h.0835A4.7864 4.7864 0 0123 2a4.9816 4.9816 0 014.6543 3.2034A3.4667 3.4667 0 0130 8.5 3.5041 3.5041 0 0126.5 12zM19 6a2 2 0 000 4h7.5A1.5017 1.5017 0 0028 8.5a1.4855 1.4855 0 00-1.2778-1.4739L26.061 6.927l-.1616-.6487a2.9568 2.9568 0 00-5.4873-.7121L20.1143 6zM23 14l-5 5 1.4141 1.4141L22 17.8325V24H16v2h6a2.0025 2.0025 0 002-2V17.8325l2.5874 2.583L28 19zM2 20H12V22H2zM2 24H12V26H2zM2 28H12V30H2z"
  })), children);
});
var Cookie32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cookie32(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle77 || (_circle77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "21",
    r: "2"
  })), _circle78 || (_circle78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "20",
    r: "2"
  })), _circle79 || (_circle79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13",
    cy: "10",
    r: "2"
  })), _circle80 || (_circle80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "15",
    r: "1"
  })), _circle81 || (_circle81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "5",
    r: "2"
  })), _circle82 || (_circle82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "29",
    cy: "3",
    r: "1"
  })), _circle83 || (_circle83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "23",
    r: "1"
  })), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30C8.3,30,2,23.7,2,16S8.3,2,16,2c0.1,0,0.2,0,0.3,0l1.4,0.1l-0.3,1.2c-0.1,0.4-0.2,0.9-0.2,1.3c0,2.8,2.2,5,5,5\tc1,0,2-0.3,2.9-0.9l1.3,1.5c-0.4,0.4-0.6,0.9-0.6,1.4c0,1.3,1.3,2.4,2.7,1.9l1.2-0.5l0.2,1.3C30,14.9,30,15.5,30,16\tC30,23.7,23.7,30,16,30z M15.3,4C9,4.4,4,9.6,4,16c0,6.6,5.4,12,12,12s12-5.4,12-12c0-0.1,0-0.3,0-0.4c-2.3,0.1-4.2-1.7-4.2-4\tc0-0.1,0-0.1,0-0.2c-0.5,0.1-1,0.2-1.6,0.2c-3.9,0-7-3.1-7-7C15.2,4.4,15.2,4.2,15.3,4z"
  })), children);
});
var Cookie24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cookie24(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle84 || (_circle84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "21",
    r: "2"
  })), _circle85 || (_circle85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "20",
    r: "2"
  })), _circle86 || (_circle86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13",
    cy: "10",
    r: "2"
  })), _circle87 || (_circle87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "15",
    r: "1"
  })), _circle88 || (_circle88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "5",
    r: "2"
  })), _circle89 || (_circle89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "29",
    cy: "3",
    r: "1"
  })), _circle90 || (_circle90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "23",
    r: "1"
  })), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30C8.3,30,2,23.7,2,16S8.3,2,16,2c0.1,0,0.2,0,0.3,0l1.4,0.1l-0.3,1.2c-0.1,0.4-0.2,0.9-0.2,1.3c0,2.8,2.2,5,5,5\tc1,0,2-0.3,2.9-0.9l1.3,1.5c-0.4,0.4-0.6,0.9-0.6,1.4c0,1.3,1.3,2.4,2.7,1.9l1.2-0.5l0.2,1.3C30,14.9,30,15.5,30,16\tC30,23.7,23.7,30,16,30z M15.3,4C9,4.4,4,9.6,4,16c0,6.6,5.4,12,12,12s12-5.4,12-12c0-0.1,0-0.3,0-0.4c-2.3,0.1-4.2-1.7-4.2-4\tc0-0.1,0-0.1,0-0.2c-0.5,0.1-1,0.2-1.6,0.2c-3.9,0-7-3.1-7-7C15.2,4.4,15.2,4.2,15.3,4z"
  })), children);
});
var Cookie20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cookie20(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle91 || (_circle91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "21",
    r: "2"
  })), _circle92 || (_circle92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "20",
    r: "2"
  })), _circle93 || (_circle93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13",
    cy: "10",
    r: "2"
  })), _circle94 || (_circle94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "15",
    r: "1"
  })), _circle95 || (_circle95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "5",
    r: "2"
  })), _circle96 || (_circle96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "29",
    cy: "3",
    r: "1"
  })), _circle97 || (_circle97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "23",
    r: "1"
  })), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30C8.3,30,2,23.7,2,16S8.3,2,16,2c0.1,0,0.2,0,0.3,0l1.4,0.1l-0.3,1.2c-0.1,0.4-0.2,0.9-0.2,1.3c0,2.8,2.2,5,5,5\tc1,0,2-0.3,2.9-0.9l1.3,1.5c-0.4,0.4-0.6,0.9-0.6,1.4c0,1.3,1.3,2.4,2.7,1.9l1.2-0.5l0.2,1.3C30,14.9,30,15.5,30,16\tC30,23.7,23.7,30,16,30z M15.3,4C9,4.4,4,9.6,4,16c0,6.6,5.4,12,12,12s12-5.4,12-12c0-0.1,0-0.3,0-0.4c-2.3,0.1-4.2-1.7-4.2-4\tc0-0.1,0-0.1,0-0.2c-0.5,0.1-1,0.2-1.6,0.2c-3.9,0-7-3.1-7-7C15.2,4.4,15.2,4.2,15.3,4z"
  })), children);
});
var Cookie16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cookie16(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle98 || (_circle98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "10",
    cy: "21",
    r: "2"
  })), _circle99 || (_circle99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "20",
    r: "2"
  })), _circle100 || (_circle100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "13",
    cy: "10",
    r: "2"
  })), _circle101 || (_circle101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "15",
    r: "1"
  })), _circle102 || (_circle102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "23",
    cy: "5",
    r: "2"
  })), _circle103 || (_circle103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "29",
    cy: "3",
    r: "1"
  })), _circle104 || (_circle104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "23",
    r: "1"
  })), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30C8.3,30,2,23.7,2,16S8.3,2,16,2c0.1,0,0.2,0,0.3,0l1.4,0.1l-0.3,1.2c-0.1,0.4-0.2,0.9-0.2,1.3c0,2.8,2.2,5,5,5\tc1,0,2-0.3,2.9-0.9l1.3,1.5c-0.4,0.4-0.6,0.9-0.6,1.4c0,1.3,1.3,2.4,2.7,1.9l1.2-0.5l0.2,1.3C30,14.9,30,15.5,30,16\tC30,23.7,23.7,30,16,30z M15.3,4C9,4.4,4,9.6,4,16c0,6.6,5.4,12,12,12s12-5.4,12-12c0-0.1,0-0.3,0-0.4c-2.3,0.1-4.2-1.7-4.2-4\tc0-0.1,0-0.1,0-0.2c-0.5,0.1-1,0.2-1.6,0.2c-3.9,0-7-3.1-7-7C15.2,4.4,15.2,4.2,15.3,4z"
  })), children);
});
var Copy32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Copy32(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10V28H10V10H28m0-2H10a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V10a2,2,0,0,0-2-2Z"
  })), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18H2V4A2,2,0,0,1,4,2H18V4H4Z"
  })), children);
});
var Copy24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Copy24(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10V28H10V10H28m0-2H10a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V10a2,2,0,0,0-2-2Z"
  })), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18H2V4A2,2,0,0,1,4,2H18V4H4Z"
  })), children);
});
var Copy20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Copy20(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10V28H10V10H28m0-2H10a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V10a2,2,0,0,0-2-2Z"
  })), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18H2V4A2,2,0,0,1,4,2H18V4H4Z"
  })), children);
});
var Copy16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Copy16(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10V28H10V10H28m0-2H10a2,2,0,0,0-2,2V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V10a2,2,0,0,0-2-2Z"
  })), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4,18H2V4A2,2,0,0,1,4,2H18V4H4Z"
  })), children);
});
var CopyFile32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CopyFile32(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.4,14.7l-6.1-6.1C21,8.2,20.5,8,20,8h-8c-1.1,0-2,0.9-2,2v18c0,1.1,0.9,2,2,2h14c1.1,0,2-0.9,2-2V16.1\tC28,15.6,27.8,15.1,27.4,14.7z M20,10l5.9,6H20V10z M12,28V10h6v6c0,1.1,0.9,2,2,2h6l0,10H12z"
  })), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,18H4V4c0-1.1,0.9-2,2-2h14v2H6V18z"
  })), children);
});
var CopyFile24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CopyFile24(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.4,14.7l-6.1-6.1C21,8.2,20.5,8,20,8h-8c-1.1,0-2,0.9-2,2v18c0,1.1,0.9,2,2,2h14c1.1,0,2-0.9,2-2V16.1\tC28,15.6,27.8,15.1,27.4,14.7z M20,10l5.9,6H20V10z M12,28V10h6v6c0,1.1,0.9,2,2,2h6l0,10H12z"
  })), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,18H4V4c0-1.1,0.9-2,2-2h14v2H6V18z"
  })), children);
});
var CopyFile20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CopyFile20(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.4,14.7l-6.1-6.1C21,8.2,20.5,8,20,8h-8c-1.1,0-2,0.9-2,2v18c0,1.1,0.9,2,2,2h14c1.1,0,2-0.9,2-2V16.1\tC28,15.6,27.8,15.1,27.4,14.7z M20,10l5.9,6H20V10z M12,28V10h6v6c0,1.1,0.9,2,2,2h6l0,10H12z"
  })), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,18H4V4c0-1.1,0.9-2,2-2h14v2H6V18z"
  })), children);
});
var CopyFile16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CopyFile16(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.4,14.7l-6.1-6.1C21,8.2,20.5,8,20,8h-8c-1.1,0-2,0.9-2,2v18c0,1.1,0.9,2,2,2h14c1.1,0,2-0.9,2-2V16.1\tC28,15.6,27.8,15.1,27.4,14.7z M20,10l5.9,6H20V10z M12,28V10h6v6c0,1.1,0.9,2,2,2h6l0,10H12z"
  })), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6,18H4V4c0-1.1,0.9-2,2-2h14v2H6V18z"
  })), children);
});
var CopyLink32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CopyLink32(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.9474,19a4.9476,4.9476,0,0,1-3.4991-8.4465l5.1053-5.1043a4.9482,4.9482,0,0,1,6.9981,6.9976l-.5523.5526-1.4158-1.4129.5577-.5579a2.95,2.95,0,0,0-.0039-4.1653,3.02,3.02,0,0,0-4.17,0l-5.1047,5.104a2.9474,2.9474,0,0,0,0,4.1692,3.02,3.02,0,0,0,4.17,0l1.4143,1.4145A4.9176,4.9176,0,0,1,11.9474,19Z"
  })), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.9474,17a4.9476,4.9476,0,0,1-3.4991-8.4465l.5526-.5526,1.4143,1.4146-.5526.5523a2.9476,2.9476,0,0,0,0,4.1689,3.02,3.02,0,0,0,4.17,0c.26-.26,4.7293-4.7293,5.1053-5.1045a2.951,2.951,0,0,0,0-4.1687,3.02,3.02,0,0,0-4.17,0L21.5536,3.449a4.9483,4.9483,0,0,1,6.9981,6.9978c-.3765.376-4.844,4.8428-5.1038,5.1035A4.9193,4.9193,0,0,1,19.9474,17Z"
  })), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30H4a2.0021,2.0021,0,0,1-2-2V8A2.0021,2.0021,0,0,1,4,6H8V8H4V28H24V18h2V28A2.0021,2.0021,0,0,1,24,30Z"
  })), children);
});
var CopyLink24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CopyLink24(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.9474,19a4.9476,4.9476,0,0,1-3.4991-8.4465l5.1053-5.1043a4.9482,4.9482,0,0,1,6.9981,6.9976l-.5523.5526-1.4158-1.4129.5577-.5579a2.95,2.95,0,0,0-.0039-4.1653,3.02,3.02,0,0,0-4.17,0l-5.1047,5.104a2.9474,2.9474,0,0,0,0,4.1692,3.02,3.02,0,0,0,4.17,0l1.4143,1.4145A4.9176,4.9176,0,0,1,11.9474,19Z"
  })), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.9474,17a4.9476,4.9476,0,0,1-3.4991-8.4465l.5526-.5526,1.4143,1.4146-.5526.5523a2.9476,2.9476,0,0,0,0,4.1689,3.02,3.02,0,0,0,4.17,0c.26-.26,4.7293-4.7293,5.1053-5.1045a2.951,2.951,0,0,0,0-4.1687,3.02,3.02,0,0,0-4.17,0L21.5536,3.449a4.9483,4.9483,0,0,1,6.9981,6.9978c-.3765.376-4.844,4.8428-5.1038,5.1035A4.9193,4.9193,0,0,1,19.9474,17Z"
  })), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30H4a2.0021,2.0021,0,0,1-2-2V8A2.0021,2.0021,0,0,1,4,6H8V8H4V28H24V18h2V28A2.0021,2.0021,0,0,1,24,30Z"
  })), children);
});
var CopyLink20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CopyLink20(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.9474,19a4.9476,4.9476,0,0,1-3.4991-8.4465l5.1053-5.1043a4.9482,4.9482,0,0,1,6.9981,6.9976l-.5523.5526-1.4158-1.4129.5577-.5579a2.95,2.95,0,0,0-.0039-4.1653,3.02,3.02,0,0,0-4.17,0l-5.1047,5.104a2.9474,2.9474,0,0,0,0,4.1692,3.02,3.02,0,0,0,4.17,0l1.4143,1.4145A4.9176,4.9176,0,0,1,11.9474,19Z"
  })), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.9474,17a4.9476,4.9476,0,0,1-3.4991-8.4465l.5526-.5526,1.4143,1.4146-.5526.5523a2.9476,2.9476,0,0,0,0,4.1689,3.02,3.02,0,0,0,4.17,0c.26-.26,4.7293-4.7293,5.1053-5.1045a2.951,2.951,0,0,0,0-4.1687,3.02,3.02,0,0,0-4.17,0L21.5536,3.449a4.9483,4.9483,0,0,1,6.9981,6.9978c-.3765.376-4.844,4.8428-5.1038,5.1035A4.9193,4.9193,0,0,1,19.9474,17Z"
  })), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30H4a2.0021,2.0021,0,0,1-2-2V8A2.0021,2.0021,0,0,1,4,6H8V8H4V28H24V18h2V28A2.0021,2.0021,0,0,1,24,30Z"
  })), children);
});
var CopyLink16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CopyLink16(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11.9474,19a4.9476,4.9476,0,0,1-3.4991-8.4465l5.1053-5.1043a4.9482,4.9482,0,0,1,6.9981,6.9976l-.5523.5526-1.4158-1.4129.5577-.5579a2.95,2.95,0,0,0-.0039-4.1653,3.02,3.02,0,0,0-4.17,0l-5.1047,5.104a2.9474,2.9474,0,0,0,0,4.1692,3.02,3.02,0,0,0,4.17,0l1.4143,1.4145A4.9176,4.9176,0,0,1,11.9474,19Z"
  })), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.9474,17a4.9476,4.9476,0,0,1-3.4991-8.4465l.5526-.5526,1.4143,1.4146-.5526.5523a2.9476,2.9476,0,0,0,0,4.1689,3.02,3.02,0,0,0,4.17,0c.26-.26,4.7293-4.7293,5.1053-5.1045a2.951,2.951,0,0,0,0-4.1687,3.02,3.02,0,0,0-4.17,0L21.5536,3.449a4.9483,4.9483,0,0,1,6.9981,6.9978c-.3765.376-4.844,4.8428-5.1038,5.1035A4.9193,4.9193,0,0,1,19.9474,17Z"
  })), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30H4a2.0021,2.0021,0,0,1-2-2V8A2.0021,2.0021,0,0,1,4,6H8V8H4V28H24V18h2V28A2.0021,2.0021,0,0,1,24,30Z"
  })), children);
});
var Corn32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Corn32(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,16c-.3374,0-.67.02-1,.0508V16C22,8.115,19.0435,2,16.5,2S11,8.115,11,16v5H6v3a6.0067,6.0067,0,0,0,6,6h3A11.0125,11.0125,0,0,0,26,19V16ZM13,16h2V14H13.0728a25.8942,25.8942,0,0,1,.5654-4H16V8H14.2c.81-2.4058,1.8149-3.7715,2.3-3.9863.66.2919,2.2842,2.7036,3.0654,6.9863H18v2h1.8442A29.1625,29.1625,0,0,1,20,16v.4263A11.0554,11.0554,0,0,0,13.79,21H13ZM12,28a4.0045,4.0045,0,0,1-4-4V23h4.7639A10.9033,10.9033,0,0,0,12,27Zm12-9a9.01,9.01,0,0,1-9,9H14V27a9.01,9.01,0,0,1,9-9h1Z"
  })), children);
});
var Corn24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Corn24(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,16c-.3374,0-.67.02-1,.0508V16C22,8.115,19.0435,2,16.5,2S11,8.115,11,16v5H6v3a6.0067,6.0067,0,0,0,6,6h3A11.0125,11.0125,0,0,0,26,19V16ZM13,16h2V14H13.0728a25.8942,25.8942,0,0,1,.5654-4H16V8H14.2c.81-2.4058,1.8149-3.7715,2.3-3.9863.66.2919,2.2842,2.7036,3.0654,6.9863H18v2h1.8442A29.1625,29.1625,0,0,1,20,16v.4263A11.0554,11.0554,0,0,0,13.79,21H13ZM12,28a4.0045,4.0045,0,0,1-4-4V23h4.7639A10.9033,10.9033,0,0,0,12,27Zm12-9a9.01,9.01,0,0,1-9,9H14V27a9.01,9.01,0,0,1,9-9h1Z"
  })), children);
});
var Corn20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Corn20(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,16c-.3374,0-.67.02-1,.0508V16C22,8.115,19.0435,2,16.5,2S11,8.115,11,16v5H6v3a6.0067,6.0067,0,0,0,6,6h3A11.0125,11.0125,0,0,0,26,19V16ZM13,16h2V14H13.0728a25.8942,25.8942,0,0,1,.5654-4H16V8H14.2c.81-2.4058,1.8149-3.7715,2.3-3.9863.66.2919,2.2842,2.7036,3.0654,6.9863H18v2h1.8442A29.1625,29.1625,0,0,1,20,16v.4263A11.0554,11.0554,0,0,0,13.79,21H13ZM12,28a4.0045,4.0045,0,0,1-4-4V23h4.7639A10.9033,10.9033,0,0,0,12,27Zm12-9a9.01,9.01,0,0,1-9,9H14V27a9.01,9.01,0,0,1,9-9h1Z"
  })), children);
});
var Corn16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Corn16(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,16c-.3374,0-.67.02-1,.0508V16C22,8.115,19.0435,2,16.5,2S11,8.115,11,16v5H6v3a6.0067,6.0067,0,0,0,6,6h3A11.0125,11.0125,0,0,0,26,19V16ZM13,16h2V14H13.0728a25.8942,25.8942,0,0,1,.5654-4H16V8H14.2c.81-2.4058,1.8149-3.7715,2.3-3.9863.66.2919,2.2842,2.7036,3.0654,6.9863H18v2h1.8442A29.1625,29.1625,0,0,1,20,16v.4263A11.0554,11.0554,0,0,0,13.79,21H13ZM12,28a4.0045,4.0045,0,0,1-4-4V23h4.7639A10.9033,10.9033,0,0,0,12,27Zm12-9a9.01,9.01,0,0,1-9,9H14V27a9.01,9.01,0,0,1,9-9h1Z"
  })), children);
});
var Corner32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Corner32(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,9H14V6H6v8H9V28h2V14h3V11H28ZM12,12H8V8h4Z"
  })), children);
});
var Corner24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Corner24(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,9H14V6H6v8H9V28h2V14h3V11H28ZM12,12H8V8h4Z"
  })), children);
});
var Corner20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Corner20(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,9H14V6H6v8H9V28h2V14h3V11H28ZM12,12H8V8h4Z"
  })), children);
});
var Corner16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Corner16(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,9H14V6H6v8H9V28h2V14h3V11H28ZM12,12H8V8h4Z"
  })), children);
});
var Coronavirus32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Coronavirus32(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle105 || (_circle105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15.5",
    cy: "11.5",
    r: "1.5"
  })), _circle106 || (_circle106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20.5",
    cy: "15.5",
    r: "1.5"
  })), _circle107 || (_circle107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "1"
  })), _circle108 || (_circle108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16.5",
    cy: "20.5",
    r: "1.5"
  })), _circle109 || (_circle109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11.5",
    cy: "16.5",
    r: "1.5"
  })), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,13v2H25.9492a9.9476,9.9476,0,0,0-2.2143-5.3213l1.4367-1.4365,1.4143,1.4145L28,8.2427,23.7578,4l-1.414,1.4141,1.414,1.414-1.437,1.4365A9.9464,9.9464,0,0,0,17,6.0508V4h2V2H13V4h2V6.0508A9.9464,9.9464,0,0,0,9.6792,8.2646L8.2422,6.8281l1.414-1.414L8.2422,4,4,8.2427l1.4141,1.414L6.8284,8.2422,8.2651,9.6787A9.9476,9.9476,0,0,0,6.0508,15H4V13H2v6H4V17H6.0508a9.9476,9.9476,0,0,0,2.2143,5.3213L6.8284,23.7578,5.4141,22.3433,4,23.7573,8.2422,28l1.414-1.4141-1.414-1.414,1.437-1.4365A9.9464,9.9464,0,0,0,15,25.9492V28H13v2h6V28H17V25.9492a9.9464,9.9464,0,0,0,5.3208-2.2138l1.437,1.4365-1.414,1.414L23.7578,28,28,23.7573l-1.4141-1.414-1.4143,1.4145-1.4367-1.4365A9.9476,9.9476,0,0,0,25.9492,17H28v2h2V13ZM16,24a8,8,0,1,1,8-8A8.0092,8.0092,0,0,1,16,24Z"
  })), children);
});
var Coronavirus24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Coronavirus24(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle110 || (_circle110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15.5",
    cy: "11.5",
    r: "1.5"
  })), _circle111 || (_circle111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20.5",
    cy: "15.5",
    r: "1.5"
  })), _circle112 || (_circle112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "1"
  })), _circle113 || (_circle113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16.5",
    cy: "20.5",
    r: "1.5"
  })), _circle114 || (_circle114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11.5",
    cy: "16.5",
    r: "1.5"
  })), _path390 || (_path390 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,13v2H25.9492a9.9476,9.9476,0,0,0-2.2143-5.3213l1.4367-1.4365,1.4143,1.4145L28,8.2427,23.7578,4l-1.414,1.4141,1.414,1.414-1.437,1.4365A9.9464,9.9464,0,0,0,17,6.0508V4h2V2H13V4h2V6.0508A9.9464,9.9464,0,0,0,9.6792,8.2646L8.2422,6.8281l1.414-1.414L8.2422,4,4,8.2427l1.4141,1.414L6.8284,8.2422,8.2651,9.6787A9.9476,9.9476,0,0,0,6.0508,15H4V13H2v6H4V17H6.0508a9.9476,9.9476,0,0,0,2.2143,5.3213L6.8284,23.7578,5.4141,22.3433,4,23.7573,8.2422,28l1.414-1.4141-1.414-1.414,1.437-1.4365A9.9464,9.9464,0,0,0,15,25.9492V28H13v2h6V28H17V25.9492a9.9464,9.9464,0,0,0,5.3208-2.2138l1.437,1.4365-1.414,1.414L23.7578,28,28,23.7573l-1.4141-1.414-1.4143,1.4145-1.4367-1.4365A9.9476,9.9476,0,0,0,25.9492,17H28v2h2V13ZM16,24a8,8,0,1,1,8-8A8.0092,8.0092,0,0,1,16,24Z"
  })), children);
});
var Coronavirus20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Coronavirus20(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle115 || (_circle115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15.5",
    cy: "11.5",
    r: "1.5"
  })), _circle116 || (_circle116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20.5",
    cy: "15.5",
    r: "1.5"
  })), _circle117 || (_circle117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "1"
  })), _circle118 || (_circle118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16.5",
    cy: "20.5",
    r: "1.5"
  })), _circle119 || (_circle119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11.5",
    cy: "16.5",
    r: "1.5"
  })), _path391 || (_path391 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,13v2H25.9492a9.9476,9.9476,0,0,0-2.2143-5.3213l1.4367-1.4365,1.4143,1.4145L28,8.2427,23.7578,4l-1.414,1.4141,1.414,1.414-1.437,1.4365A9.9464,9.9464,0,0,0,17,6.0508V4h2V2H13V4h2V6.0508A9.9464,9.9464,0,0,0,9.6792,8.2646L8.2422,6.8281l1.414-1.414L8.2422,4,4,8.2427l1.4141,1.414L6.8284,8.2422,8.2651,9.6787A9.9476,9.9476,0,0,0,6.0508,15H4V13H2v6H4V17H6.0508a9.9476,9.9476,0,0,0,2.2143,5.3213L6.8284,23.7578,5.4141,22.3433,4,23.7573,8.2422,28l1.414-1.4141-1.414-1.414,1.437-1.4365A9.9464,9.9464,0,0,0,15,25.9492V28H13v2h6V28H17V25.9492a9.9464,9.9464,0,0,0,5.3208-2.2138l1.437,1.4365-1.414,1.414L23.7578,28,28,23.7573l-1.4141-1.414-1.4143,1.4145-1.4367-1.4365A9.9476,9.9476,0,0,0,25.9492,17H28v2h2V13ZM16,24a8,8,0,1,1,8-8A8.0092,8.0092,0,0,1,16,24Z"
  })), children);
});
var Coronavirus16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Coronavirus16(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle120 || (_circle120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "15.5",
    cy: "11.5",
    r: "1.5"
  })), _circle121 || (_circle121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "20.5",
    cy: "15.5",
    r: "1.5"
  })), _circle122 || (_circle122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "1"
  })), _circle123 || (_circle123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16.5",
    cy: "20.5",
    r: "1.5"
  })), _circle124 || (_circle124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11.5",
    cy: "16.5",
    r: "1.5"
  })), _path392 || (_path392 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,13v2H25.9492a9.9476,9.9476,0,0,0-2.2143-5.3213l1.4367-1.4365,1.4143,1.4145L28,8.2427,23.7578,4l-1.414,1.4141,1.414,1.414-1.437,1.4365A9.9464,9.9464,0,0,0,17,6.0508V4h2V2H13V4h2V6.0508A9.9464,9.9464,0,0,0,9.6792,8.2646L8.2422,6.8281l1.414-1.414L8.2422,4,4,8.2427l1.4141,1.414L6.8284,8.2422,8.2651,9.6787A9.9476,9.9476,0,0,0,6.0508,15H4V13H2v6H4V17H6.0508a9.9476,9.9476,0,0,0,2.2143,5.3213L6.8284,23.7578,5.4141,22.3433,4,23.7573,8.2422,28l1.414-1.4141-1.414-1.414,1.437-1.4365A9.9464,9.9464,0,0,0,15,25.9492V28H13v2h6V28H17V25.9492a9.9464,9.9464,0,0,0,5.3208-2.2138l1.437,1.4365-1.414,1.414L23.7578,28,28,23.7573l-1.4141-1.414-1.4143,1.4145-1.4367-1.4365A9.9476,9.9476,0,0,0,25.9492,17H28v2h2V13ZM16,24a8,8,0,1,1,8-8A8.0092,8.0092,0,0,1,16,24Z"
  })), children);
});
var Cost32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cost32(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path393 || (_path393 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,23a7,7,0,1,1,7-7A7.0078,7.0078,0,0,1,16,23Zm0-12a5,5,0,1,0,5,5A5.0057,5.0057,0,0,0,16,11Z"
  })), _path394 || (_path394 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6.4141,28.5859,5l-3.35,3.35A12.0812,12.0812,0,0,0,23.65,6.7637L27,3.4141,25.5859,2,21.9766,5.6094A11.9792,11.9792,0,0,0,5.6094,21.9766L2,25.5859,3.4141,27l3.35-3.35A12.0812,12.0812,0,0,0,8.35,25.2363L5,28.5859,6.4141,30l3.6093-3.6094A11.9792,11.9792,0,0,0,26.3906,10.0234ZM16,26A10,10,0,1,1,26,16,10.0114,10.0114,0,0,1,16,26Z"
  })), children);
});
var Cost24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cost24(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path395 || (_path395 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,23a7,7,0,1,1,7-7A7.0078,7.0078,0,0,1,16,23Zm0-12a5,5,0,1,0,5,5A5.0057,5.0057,0,0,0,16,11Z"
  })), _path396 || (_path396 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6.4141,28.5859,5l-3.35,3.35A12.0812,12.0812,0,0,0,23.65,6.7637L27,3.4141,25.5859,2,21.9766,5.6094A11.9792,11.9792,0,0,0,5.6094,21.9766L2,25.5859,3.4141,27l3.35-3.35A12.0812,12.0812,0,0,0,8.35,25.2363L5,28.5859,6.4141,30l3.6093-3.6094A11.9792,11.9792,0,0,0,26.3906,10.0234ZM16,26A10,10,0,1,1,26,16,10.0114,10.0114,0,0,1,16,26Z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-7.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-7.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Cost16": () => (/* binding */ Cost16),
/* harmony export */   "Cost20": () => (/* binding */ Cost20),
/* harmony export */   "CostTotal16": () => (/* binding */ CostTotal16),
/* harmony export */   "CostTotal20": () => (/* binding */ CostTotal20),
/* harmony export */   "CostTotal24": () => (/* binding */ CostTotal24),
/* harmony export */   "CostTotal32": () => (/* binding */ CostTotal32),
/* harmony export */   "Cough16": () => (/* binding */ Cough16),
/* harmony export */   "Cough20": () => (/* binding */ Cough20),
/* harmony export */   "Cough24": () => (/* binding */ Cough24),
/* harmony export */   "Cough32": () => (/* binding */ Cough32),
/* harmony export */   "Course16": () => (/* binding */ Course16),
/* harmony export */   "Course20": () => (/* binding */ Course20),
/* harmony export */   "Course24": () => (/* binding */ Course24),
/* harmony export */   "Course32": () => (/* binding */ Course32),
/* harmony export */   "Covariate16": () => (/* binding */ Covariate16),
/* harmony export */   "Covariate20": () => (/* binding */ Covariate20),
/* harmony export */   "Covariate24": () => (/* binding */ Covariate24),
/* harmony export */   "Covariate32": () => (/* binding */ Covariate32),
/* harmony export */   "Credentials16": () => (/* binding */ Credentials16),
/* harmony export */   "Credentials20": () => (/* binding */ Credentials20),
/* harmony export */   "Credentials24": () => (/* binding */ Credentials24),
/* harmony export */   "Credentials32": () => (/* binding */ Credentials32),
/* harmony export */   "CriticalGlyph": () => (/* binding */ CriticalGlyph),
/* harmony export */   "CriticalSeverityGlyph": () => (/* binding */ CriticalSeverityGlyph),
/* harmony export */   "Crop16": () => (/* binding */ Crop16),
/* harmony export */   "Crop20": () => (/* binding */ Crop20),
/* harmony export */   "Crop24": () => (/* binding */ Crop24),
/* harmony export */   "Crop32": () => (/* binding */ Crop32),
/* harmony export */   "CropGrowth16": () => (/* binding */ CropGrowth16),
/* harmony export */   "CropGrowth20": () => (/* binding */ CropGrowth20),
/* harmony export */   "CropGrowth24": () => (/* binding */ CropGrowth24),
/* harmony export */   "CropGrowth32": () => (/* binding */ CropGrowth32),
/* harmony export */   "CropHealth16": () => (/* binding */ CropHealth16),
/* harmony export */   "CropHealth20": () => (/* binding */ CropHealth20),
/* harmony export */   "CropHealth24": () => (/* binding */ CropHealth24),
/* harmony export */   "CropHealth32": () => (/* binding */ CropHealth32),
/* harmony export */   "CrossTab16": () => (/* binding */ CrossTab16),
/* harmony export */   "CrossTab20": () => (/* binding */ CrossTab20),
/* harmony export */   "CrossTab24": () => (/* binding */ CrossTab24),
/* harmony export */   "CrossTab32": () => (/* binding */ CrossTab32),
/* harmony export */   "Crossroads16": () => (/* binding */ Crossroads16),
/* harmony export */   "Crossroads20": () => (/* binding */ Crossroads20),
/* harmony export */   "Crossroads24": () => (/* binding */ Crossroads24),
/* harmony export */   "Crossroads32": () => (/* binding */ Crossroads32),
/* harmony export */   "CrowdReport16": () => (/* binding */ CrowdReport16),
/* harmony export */   "CrowdReport20": () => (/* binding */ CrowdReport20),
/* harmony export */   "CrowdReport24": () => (/* binding */ CrowdReport24),
/* harmony export */   "CrowdReport32": () => (/* binding */ CrowdReport32),
/* harmony export */   "CrowdReportFilled16": () => (/* binding */ CrowdReportFilled16),
/* harmony export */   "CrowdReportFilled20": () => (/* binding */ CrowdReportFilled20),
/* harmony export */   "CrowdReportFilled24": () => (/* binding */ CrowdReportFilled24),
/* harmony export */   "CrowdReportFilled32": () => (/* binding */ CrowdReportFilled32),
/* harmony export */   "Csv16": () => (/* binding */ Csv16),
/* harmony export */   "Csv20": () => (/* binding */ Csv20),
/* harmony export */   "Csv24": () => (/* binding */ Csv24),
/* harmony export */   "Csv32": () => (/* binding */ Csv32),
/* harmony export */   "Cube16": () => (/* binding */ Cube16),
/* harmony export */   "Cube20": () => (/* binding */ Cube20),
/* harmony export */   "Cube24": () => (/* binding */ Cube24),
/* harmony export */   "Cube32": () => (/* binding */ Cube32),
/* harmony export */   "CubeView16": () => (/* binding */ CubeView16),
/* harmony export */   "CubeView20": () => (/* binding */ CubeView20),
/* harmony export */   "CubeView24": () => (/* binding */ CubeView24),
/* harmony export */   "CubeView32": () => (/* binding */ CubeView32),
/* harmony export */   "Currency16": () => (/* binding */ Currency16),
/* harmony export */   "Currency20": () => (/* binding */ Currency20),
/* harmony export */   "Currency24": () => (/* binding */ Currency24),
/* harmony export */   "Currency32": () => (/* binding */ Currency32),
/* harmony export */   "CurrencyBaht16": () => (/* binding */ CurrencyBaht16),
/* harmony export */   "CurrencyBaht20": () => (/* binding */ CurrencyBaht20),
/* harmony export */   "CurrencyBaht24": () => (/* binding */ CurrencyBaht24),
/* harmony export */   "CurrencyBaht32": () => (/* binding */ CurrencyBaht32),
/* harmony export */   "CurrencyDollar16": () => (/* binding */ CurrencyDollar16),
/* harmony export */   "CurrencyDollar20": () => (/* binding */ CurrencyDollar20),
/* harmony export */   "CurrencyDollar24": () => (/* binding */ CurrencyDollar24),
/* harmony export */   "CurrencyDollar32": () => (/* binding */ CurrencyDollar32),
/* harmony export */   "CurrencyEuro16": () => (/* binding */ CurrencyEuro16),
/* harmony export */   "CurrencyEuro20": () => (/* binding */ CurrencyEuro20),
/* harmony export */   "CurrencyEuro24": () => (/* binding */ CurrencyEuro24),
/* harmony export */   "CurrencyEuro32": () => (/* binding */ CurrencyEuro32),
/* harmony export */   "CurrencyLira16": () => (/* binding */ CurrencyLira16),
/* harmony export */   "CurrencyLira20": () => (/* binding */ CurrencyLira20),
/* harmony export */   "CurrencyLira24": () => (/* binding */ CurrencyLira24),
/* harmony export */   "CurrencyLira32": () => (/* binding */ CurrencyLira32),
/* harmony export */   "CurrencyPound16": () => (/* binding */ CurrencyPound16),
/* harmony export */   "CurrencyPound20": () => (/* binding */ CurrencyPound20),
/* harmony export */   "CurrencyPound24": () => (/* binding */ CurrencyPound24),
/* harmony export */   "CurrencyPound32": () => (/* binding */ CurrencyPound32),
/* harmony export */   "CurrencyRuble16": () => (/* binding */ CurrencyRuble16),
/* harmony export */   "CurrencyRuble20": () => (/* binding */ CurrencyRuble20),
/* harmony export */   "CurrencyRuble24": () => (/* binding */ CurrencyRuble24),
/* harmony export */   "CurrencyRuble32": () => (/* binding */ CurrencyRuble32),
/* harmony export */   "CurrencyRupee16": () => (/* binding */ CurrencyRupee16),
/* harmony export */   "CurrencyRupee20": () => (/* binding */ CurrencyRupee20),
/* harmony export */   "CurrencyRupee24": () => (/* binding */ CurrencyRupee24),
/* harmony export */   "CurrencyRupee32": () => (/* binding */ CurrencyRupee32),
/* harmony export */   "CurrencyShekel16": () => (/* binding */ CurrencyShekel16),
/* harmony export */   "CurrencyShekel20": () => (/* binding */ CurrencyShekel20),
/* harmony export */   "CurrencyShekel24": () => (/* binding */ CurrencyShekel24),
/* harmony export */   "CurrencyShekel32": () => (/* binding */ CurrencyShekel32),
/* harmony export */   "CurrencyWon16": () => (/* binding */ CurrencyWon16),
/* harmony export */   "CurrencyWon20": () => (/* binding */ CurrencyWon20),
/* harmony export */   "CurrencyWon24": () => (/* binding */ CurrencyWon24),
/* harmony export */   "CurrencyWon32": () => (/* binding */ CurrencyWon32),
/* harmony export */   "CurrencyYen16": () => (/* binding */ CurrencyYen16),
/* harmony export */   "CurrencyYen20": () => (/* binding */ CurrencyYen20),
/* harmony export */   "CurrencyYen24": () => (/* binding */ CurrencyYen24),
/* harmony export */   "CurrencyYen32": () => (/* binding */ CurrencyYen32),
/* harmony export */   "Cursor_116": () => (/* binding */ Cursor_116),
/* harmony export */   "Cursor_120": () => (/* binding */ Cursor_120),
/* harmony export */   "Cursor_124": () => (/* binding */ Cursor_124),
/* harmony export */   "Cursor_132": () => (/* binding */ Cursor_132),
/* harmony export */   "Cursor_216": () => (/* binding */ Cursor_216),
/* harmony export */   "Cursor_220": () => (/* binding */ Cursor_220),
/* harmony export */   "Cursor_224": () => (/* binding */ Cursor_224),
/* harmony export */   "Cursor_232": () => (/* binding */ Cursor_232),
/* harmony export */   "Cut16": () => (/* binding */ Cut16),
/* harmony export */   "Cut20": () => (/* binding */ Cut20),
/* harmony export */   "Cut24": () => (/* binding */ Cut24),
/* harmony export */   "Cut32": () => (/* binding */ Cut32),
/* harmony export */   "CutOut16": () => (/* binding */ CutOut16),
/* harmony export */   "CutOut20": () => (/* binding */ CutOut20),
/* harmony export */   "CutOut24": () => (/* binding */ CutOut24),
/* harmony export */   "CutOut32": () => (/* binding */ CutOut32),
/* harmony export */   "Cyclist16": () => (/* binding */ Cyclist16),
/* harmony export */   "Cyclist20": () => (/* binding */ Cyclist20),
/* harmony export */   "Cyclist24": () => (/* binding */ Cyclist24),
/* harmony export */   "Cyclist32": () => (/* binding */ Cyclist32),
/* harmony export */   "Dashboard16": () => (/* binding */ Dashboard16),
/* harmony export */   "Dashboard20": () => (/* binding */ Dashboard20),
/* harmony export */   "Dashboard24": () => (/* binding */ Dashboard24),
/* harmony export */   "Dashboard32": () => (/* binding */ Dashboard32),
/* harmony export */   "DashboardReference16": () => (/* binding */ DashboardReference16),
/* harmony export */   "DashboardReference20": () => (/* binding */ DashboardReference20),
/* harmony export */   "DashboardReference24": () => (/* binding */ DashboardReference24),
/* harmony export */   "DashboardReference32": () => (/* binding */ DashboardReference32),
/* harmony export */   "DataAccessor16": () => (/* binding */ DataAccessor16),
/* harmony export */   "DataAccessor20": () => (/* binding */ DataAccessor20),
/* harmony export */   "DataAccessor24": () => (/* binding */ DataAccessor24),
/* harmony export */   "DataAccessor32": () => (/* binding */ DataAccessor32),
/* harmony export */   "DataBackup16": () => (/* binding */ DataBackup16),
/* harmony export */   "DataBackup20": () => (/* binding */ DataBackup20),
/* harmony export */   "DataBackup24": () => (/* binding */ DataBackup24),
/* harmony export */   "DataBackup32": () => (/* binding */ DataBackup32),
/* harmony export */   "DataBase16": () => (/* binding */ DataBase16),
/* harmony export */   "DataBase20": () => (/* binding */ DataBase20),
/* harmony export */   "DataBase24": () => (/* binding */ DataBase24),
/* harmony export */   "DataBase32": () => (/* binding */ DataBase32),
/* harmony export */   "DataBaseAlt16": () => (/* binding */ DataBaseAlt16),
/* harmony export */   "DataBaseAlt20": () => (/* binding */ DataBaseAlt20),
/* harmony export */   "DataBaseAlt24": () => (/* binding */ DataBaseAlt24),
/* harmony export */   "DataBaseAlt32": () => (/* binding */ DataBaseAlt32),
/* harmony export */   "DataBin16": () => (/* binding */ DataBin16),
/* harmony export */   "DataBin20": () => (/* binding */ DataBin20),
/* harmony export */   "DataBin24": () => (/* binding */ DataBin24),
/* harmony export */   "DataBin32": () => (/* binding */ DataBin32),
/* harmony export */   "DataBlob16": () => (/* binding */ DataBlob16),
/* harmony export */   "DataBlob20": () => (/* binding */ DataBlob20),
/* harmony export */   "DataBlob24": () => (/* binding */ DataBlob24),
/* harmony export */   "DataBlob32": () => (/* binding */ DataBlob32),
/* harmony export */   "DataCenter16": () => (/* binding */ DataCenter16),
/* harmony export */   "DataCenter20": () => (/* binding */ DataCenter20),
/* harmony export */   "DataCenter24": () => (/* binding */ DataCenter24),
/* harmony export */   "DataCenter32": () => (/* binding */ DataCenter32),
/* harmony export */   "DataCheck16": () => (/* binding */ DataCheck16),
/* harmony export */   "DataCheck20": () => (/* binding */ DataCheck20),
/* harmony export */   "DataCheck24": () => (/* binding */ DataCheck24),
/* harmony export */   "DataCheck32": () => (/* binding */ DataCheck32),
/* harmony export */   "DataClass16": () => (/* binding */ DataClass16),
/* harmony export */   "DataClass20": () => (/* binding */ DataClass20),
/* harmony export */   "DataClass24": () => (/* binding */ DataClass24),
/* harmony export */   "DataClass32": () => (/* binding */ DataClass32),
/* harmony export */   "DataCollection16": () => (/* binding */ DataCollection16),
/* harmony export */   "DataCollection20": () => (/* binding */ DataCollection20),
/* harmony export */   "DataCollection24": () => (/* binding */ DataCollection24),
/* harmony export */   "DataCollection32": () => (/* binding */ DataCollection32),
/* harmony export */   "DataConnected16": () => (/* binding */ DataConnected16),
/* harmony export */   "DataConnected20": () => (/* binding */ DataConnected20),
/* harmony export */   "DataConnected24": () => (/* binding */ DataConnected24),
/* harmony export */   "DataConnected32": () => (/* binding */ DataConnected32),
/* harmony export */   "DataDefinition16": () => (/* binding */ DataDefinition16),
/* harmony export */   "DataDefinition20": () => (/* binding */ DataDefinition20),
/* harmony export */   "DataDefinition24": () => (/* binding */ DataDefinition24),
/* harmony export */   "DataDefinition32": () => (/* binding */ DataDefinition32),
/* harmony export */   "DataDiode24": () => (/* binding */ DataDiode24),
/* harmony export */   "DataDiode32": () => (/* binding */ DataDiode32),
/* harmony export */   "DataError16": () => (/* binding */ DataError16),
/* harmony export */   "DataError20": () => (/* binding */ DataError20),
/* harmony export */   "DataError24": () => (/* binding */ DataError24),
/* harmony export */   "DataError32": () => (/* binding */ DataError32),
/* harmony export */   "DataFormat16": () => (/* binding */ DataFormat16),
/* harmony export */   "DataFormat20": () => (/* binding */ DataFormat20),
/* harmony export */   "DataFormat24": () => (/* binding */ DataFormat24),
/* harmony export */   "DataFormat32": () => (/* binding */ DataFormat32),
/* harmony export */   "DataReference16": () => (/* binding */ DataReference16),
/* harmony export */   "DataReference20": () => (/* binding */ DataReference20),
/* harmony export */   "DataReference24": () => (/* binding */ DataReference24),
/* harmony export */   "DataReference32": () => (/* binding */ DataReference32),
/* harmony export */   "DataSet16": () => (/* binding */ DataSet16),
/* harmony export */   "DataSet20": () => (/* binding */ DataSet20),
/* harmony export */   "DataSet24": () => (/* binding */ DataSet24),
/* harmony export */   "DataSet32": () => (/* binding */ DataSet32),
/* harmony export */   "DataStructured16": () => (/* binding */ DataStructured16),
/* harmony export */   "DataStructured20": () => (/* binding */ DataStructured20),
/* harmony export */   "DataStructured24": () => (/* binding */ DataStructured24),
/* harmony export */   "DataStructured32": () => (/* binding */ DataStructured32),
/* harmony export */   "DataUnstructured16": () => (/* binding */ DataUnstructured16),
/* harmony export */   "DataUnstructured20": () => (/* binding */ DataUnstructured20),
/* harmony export */   "DataUnstructured24": () => (/* binding */ DataUnstructured24),
/* harmony export */   "DataUnstructured32": () => (/* binding */ DataUnstructured32),
/* harmony export */   "DataView16": () => (/* binding */ DataView16),
/* harmony export */   "DataView20": () => (/* binding */ DataView20),
/* harmony export */   "DataView24": () => (/* binding */ DataView24),
/* harmony export */   "DataView32": () => (/* binding */ DataView32),
/* harmony export */   "DataViewAlt16": () => (/* binding */ DataViewAlt16),
/* harmony export */   "DataViewAlt20": () => (/* binding */ DataViewAlt20),
/* harmony export */   "DataViewAlt24": () => (/* binding */ DataViewAlt24),
/* harmony export */   "DataViewAlt32": () => (/* binding */ DataViewAlt32),
/* harmony export */   "Data_116": () => (/* binding */ Data_116),
/* harmony export */   "Data_120": () => (/* binding */ Data_120),
/* harmony export */   "Data_124": () => (/* binding */ Data_124),
/* harmony export */   "Data_132": () => (/* binding */ Data_132),
/* harmony export */   "Data_216": () => (/* binding */ Data_216),
/* harmony export */   "Data_220": () => (/* binding */ Data_220),
/* harmony export */   "Data_224": () => (/* binding */ Data_224),
/* harmony export */   "Data_232": () => (/* binding */ Data_232),
/* harmony export */   "QCU116": () => (/* binding */ QCU116),
/* harmony export */   "QCU120": () => (/* binding */ QCU120),
/* harmony export */   "QCU124": () => (/* binding */ QCU124),
/* harmony export */   "QCU132": () => (/* binding */ QCU132),
/* harmony export */   "QCU316": () => (/* binding */ QCU316),
/* harmony export */   "QCU320": () => (/* binding */ QCU320),
/* harmony export */   "QCU324": () => (/* binding */ QCU324),
/* harmony export */   "QCU332": () => (/* binding */ QCU332),
/* harmony export */   "QCY16": () => (/* binding */ QCY16),
/* harmony export */   "QCY20": () => (/* binding */ QCY20),
/* harmony export */   "QCY24": () => (/* binding */ QCY24),
/* harmony export */   "QCY32": () => (/* binding */ QCY32),
/* harmony export */   "QCZ16": () => (/* binding */ QCZ16),
/* harmony export */   "QCZ20": () => (/* binding */ QCZ20),
/* harmony export */   "QCZ24": () => (/* binding */ QCZ24),
/* harmony export */   "QCZ32": () => (/* binding */ QCZ32),
/* harmony export */   "WatsonHealthCrossReference16": () => (/* binding */ WatsonHealthCrossReference16),
/* harmony export */   "WatsonHealthCrossReference20": () => (/* binding */ WatsonHealthCrossReference20),
/* harmony export */   "WatsonHealthCrossReference24": () => (/* binding */ WatsonHealthCrossReference24),
/* harmony export */   "WatsonHealthCrossReference32": () => (/* binding */ WatsonHealthCrossReference32),
/* harmony export */   "WatsonHealthCutInHalf16": () => (/* binding */ WatsonHealthCutInHalf16),
/* harmony export */   "WatsonHealthCutInHalf20": () => (/* binding */ WatsonHealthCutInHalf20),
/* harmony export */   "WatsonHealthCutInHalf24": () => (/* binding */ WatsonHealthCutInHalf24),
/* harmony export */   "WatsonHealthCutInHalf32": () => (/* binding */ WatsonHealthCutInHalf32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _circle, _circle2, _circle3, _circle4, _circle5, _circle6, _path14, _path15, _circle7, _circle8, _circle9, _circle10, _circle11, _circle12, _path16, _path17, _circle13, _circle14, _circle15, _circle16, _circle17, _circle18, _path18, _path19, _circle19, _circle20, _circle21, _circle22, _circle23, _circle24, _path20, _path21, _path22, _path23, _path24, _circle25, _circle26, _circle27, _circle28, _path25, _circle29, _circle30, _circle31, _circle32, _path26, _circle33, _circle34, _circle35, _circle36, _path27, _circle37, _circle38, _circle39, _circle40, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _path49, _path50, _path51, _path52, _path53, _path54, _path55, _path56, _path57, _path58, _path59, _path60, _path61, _path62, _path63, _path64, _path65, _path66, _path67, _path68, _path69, _path70, _path71, _path72, _path73, _path74, _path75, _path76, _path77, _path78, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _circle41, _path99, _path100, _circle42, _path101, _path102, _circle43, _path103, _path104, _circle44, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _circle45, _circle46, _circle47, _path224, _circle48, _circle49, _circle50, _path225, _circle51, _circle52, _circle53, _path226, _circle54, _circle55, _circle56, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _circle57, _circle58, _circle59, _path244, _path245, _circle60, _circle61, _circle62, _path246, _path247, _circle63, _circle64, _circle65, _path248, _path249, _circle66, _circle67, _circle68, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _circle69, _circle70, _circle71, _path263, _path264, _circle72, _circle73, _circle74, _path265, _path266, _circle75, _circle76, _circle77, _path267, _path268, _circle78, _circle79, _circle80, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _path282, _path283, _path284, _path285, _path286, _circle81, _path287, _circle82, _path288, _circle83, _path289, _circle84, _path290, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _circle85, _path299, _circle86, _circle87, _circle88, _path300, _circle89, _path301, _circle90, _circle91, _circle92, _path302, _circle93, _path303, _circle94, _circle95, _circle96, _path304, _circle97, _path305, _circle98, _circle99, _circle100, _path306, _circle101, _path307, _path308, _circle102, _path309, _path310, _circle103, _path311, _path312, _circle104, _path313, _path314, _path315, _circle105, _path316, _path317, _circle106, _path318, _path319, _circle107, _path320, _path321, _circle108, _path322, _circle109, _circle110, _circle111, _path323, _path324, _circle112, _circle113, _circle114, _path325, _path326, _circle115, _circle116, _circle117, _path327, _path328, _circle118, _circle119, _circle120, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _path349, _path350, _circle121, _path351, _circle122, _path352, _circle123, _path353, _circle124, _path354, _circle125, _path355, _path356, _circle126, _path357, _path358, _circle127, _path359, _path360, _circle128, _path361, _path362, _path363, _path364;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var Cost20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cost20(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,23a7,7,0,1,1,7-7A7.0078,7.0078,0,0,1,16,23Zm0-12a5,5,0,1,0,5,5A5.0057,5.0057,0,0,0,16,11Z"
  })), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6.4141,28.5859,5l-3.35,3.35A12.0812,12.0812,0,0,0,23.65,6.7637L27,3.4141,25.5859,2,21.9766,5.6094A11.9792,11.9792,0,0,0,5.6094,21.9766L2,25.5859,3.4141,27l3.35-3.35A12.0812,12.0812,0,0,0,8.35,25.2363L5,28.5859,6.4141,30l3.6093-3.6094A11.9792,11.9792,0,0,0,26.3906,10.0234ZM16,26A10,10,0,1,1,26,16,10.0114,10.0114,0,0,1,16,26Z"
  })), children);
});
var Cost16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cost16(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,23a7,7,0,1,1,7-7A7.0078,7.0078,0,0,1,16,23Zm0-12a5,5,0,1,0,5,5A5.0057,5.0057,0,0,0,16,11Z"
  })), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6.4141,28.5859,5l-3.35,3.35A12.0812,12.0812,0,0,0,23.65,6.7637L27,3.4141,25.5859,2,21.9766,5.6094A11.9792,11.9792,0,0,0,5.6094,21.9766L2,25.5859,3.4141,27l3.35-3.35A12.0812,12.0812,0,0,0,8.35,25.2363L5,28.5859,6.4141,30l3.6093-3.6094A11.9792,11.9792,0,0,0,26.3906,10.0234ZM16,26A10,10,0,1,1,26,16,10.0114,10.0114,0,0,1,16,26Z"
  })), children);
});
var CostTotal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CostTotal32(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 13H22V15H10zM10 18H22V20H10z"
  })), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6.4141,28.5859,5l-3.35,3.35A12.0812,12.0812,0,0,0,23.65,6.7637L27,3.4141,25.5859,2,21.9766,5.6094A11.9792,11.9792,0,0,0,5.6094,21.9766L2,25.5859,3.4141,27l3.35-3.35A12.0812,12.0812,0,0,0,8.35,25.2363L5,28.5859,6.4141,30l3.6093-3.6094A11.9792,11.9792,0,0,0,26.3906,10.0234ZM16,26A10,10,0,1,1,26,16,10.0114,10.0114,0,0,1,16,26Z"
  })), children);
});
var CostTotal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CostTotal24(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 13H22V15H10zM10 18H22V20H10z"
  })), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6.4141,28.5859,5l-3.35,3.35A12.0812,12.0812,0,0,0,23.65,6.7637L27,3.4141,25.5859,2,21.9766,5.6094A11.9792,11.9792,0,0,0,5.6094,21.9766L2,25.5859,3.4141,27l3.35-3.35A12.0812,12.0812,0,0,0,8.35,25.2363L5,28.5859,6.4141,30l3.6093-3.6094A11.9792,11.9792,0,0,0,26.3906,10.0234ZM16,26A10,10,0,1,1,26,16,10.0114,10.0114,0,0,1,16,26Z"
  })), children);
});
var CostTotal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CostTotal20(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 13H22V15H10zM10 18H22V20H10z"
  })), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6.4141,28.5859,5l-3.35,3.35A12.0812,12.0812,0,0,0,23.65,6.7637L27,3.4141,25.5859,2,21.9766,5.6094A11.9792,11.9792,0,0,0,5.6094,21.9766L2,25.5859,3.4141,27l3.35-3.35A12.0812,12.0812,0,0,0,8.35,25.2363L5,28.5859,6.4141,30l3.6093-3.6094A11.9792,11.9792,0,0,0,26.3906,10.0234ZM16,26A10,10,0,1,1,26,16,10.0114,10.0114,0,0,1,16,26Z"
  })), children);
});
var CostTotal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CostTotal16(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 13H22V15H10zM10 18H22V20H10z"
  })), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,6.4141,28.5859,5l-3.35,3.35A12.0812,12.0812,0,0,0,23.65,6.7637L27,3.4141,25.5859,2,21.9766,5.6094A11.9792,11.9792,0,0,0,5.6094,21.9766L2,25.5859,3.4141,27l3.35-3.35A12.0812,12.0812,0,0,0,8.35,25.2363L5,28.5859,6.4141,30l3.6093-3.6094A11.9792,11.9792,0,0,0,26.3906,10.0234ZM16,26A10,10,0,1,1,26,16,10.0114,10.0114,0,0,1,16,26Z"
  })), children);
});
var Cough32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cough32(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H24V27H20a5.0055,5.0055,0,0,1-5-5V20.7207l-2.3162-.772a1,1,0,0,1-.5412-1.4631L15,13.7229V11a9.01,9.01,0,0,1,9-9h5V4H24a7.0078,7.0078,0,0,0-7,7v3a.9991.9991,0,0,1-.1426.5144l-2.3586,3.9312,1.8174.6057A1,1,0,0,1,17,20v2a3.0033,3.0033,0,0,0,3,3h5a1,1,0,0,1,1,1Z"
  })), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "23",
    r: "1"
  })), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "20",
    r: "1"
  })), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "26",
    r: "1"
  })), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "17",
    r: "1"
  })), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "29",
    r: "1"
  })), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "23",
    r: "1"
  })), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 12H23V14H19z"
  })), children);
});
var Cough24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cough24(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H24V27H20a5.0055,5.0055,0,0,1-5-5V20.7207l-2.3162-.772a1,1,0,0,1-.5412-1.4631L15,13.7229V11a9.01,9.01,0,0,1,9-9h5V4H24a7.0078,7.0078,0,0,0-7,7v3a.9991.9991,0,0,1-.1426.5144l-2.3586,3.9312,1.8174.6057A1,1,0,0,1,17,20v2a3.0033,3.0033,0,0,0,3,3h5a1,1,0,0,1,1,1Z"
  })), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "23",
    r: "1"
  })), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "20",
    r: "1"
  })), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "26",
    r: "1"
  })), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "17",
    r: "1"
  })), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "29",
    r: "1"
  })), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "23",
    r: "1"
  })), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 12H23V14H19z"
  })), children);
});
var Cough20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cough20(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H24V27H20a5.0055,5.0055,0,0,1-5-5V20.7207l-2.3162-.772a1,1,0,0,1-.5412-1.4631L15,13.7229V11a9.01,9.01,0,0,1,9-9h5V4H24a7.0078,7.0078,0,0,0-7,7v3a.9991.9991,0,0,1-.1426.5144l-2.3586,3.9312,1.8174.6057A1,1,0,0,1,17,20v2a3.0033,3.0033,0,0,0,3,3h5a1,1,0,0,1,1,1Z"
  })), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "23",
    r: "1"
  })), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "20",
    r: "1"
  })), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "26",
    r: "1"
  })), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "17",
    r: "1"
  })), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "29",
    r: "1"
  })), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "23",
    r: "1"
  })), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 12H23V14H19z"
  })), children);
});
var Cough16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cough16(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H24V27H20a5.0055,5.0055,0,0,1-5-5V20.7207l-2.3162-.772a1,1,0,0,1-.5412-1.4631L15,13.7229V11a9.01,9.01,0,0,1,9-9h5V4H24a7.0078,7.0078,0,0,0-7,7v3a.9991.9991,0,0,1-.1426.5144l-2.3586,3.9312,1.8174.6057A1,1,0,0,1,17,20v2a3.0033,3.0033,0,0,0,3,3h5a1,1,0,0,1,1,1Z"
  })), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "23",
    r: "1"
  })), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "20",
    r: "1"
  })), _circle21 || (_circle21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "6",
    cy: "26",
    r: "1"
  })), _circle22 || (_circle22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "17",
    r: "1"
  })), _circle23 || (_circle23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "29",
    r: "1"
  })), _circle24 || (_circle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "3",
    cy: "23",
    r: "1"
  })), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 12H23V14H19z"
  })), children);
});
var Course32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Course32(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30H8a2.0023,2.0023,0,0,1-2-2V4A2.002,2.002,0,0,1,8,2H24a2.0023,2.0023,0,0,1,2,2V20.6182l-5-2.5-5,2.5V4H8V28H24V24h2v4A2.0027,2.0027,0,0,1,24,30ZM21,15.8818l3,1.5V4H18V17.3818Z"
  })), children);
});
var Course24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Course24(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30H8a2.0023,2.0023,0,0,1-2-2V4A2.002,2.002,0,0,1,8,2H24a2.0023,2.0023,0,0,1,2,2V20.6182l-5-2.5-5,2.5V4H8V28H24V24h2v4A2.0027,2.0027,0,0,1,24,30ZM21,15.8818l3,1.5V4H18V17.3818Z"
  })), children);
});
var Course20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Course20(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30H8a2.0023,2.0023,0,0,1-2-2V4A2.002,2.002,0,0,1,8,2H24a2.0023,2.0023,0,0,1,2,2V20.6182l-5-2.5-5,2.5V4H8V28H24V24h2v4A2.0027,2.0027,0,0,1,24,30ZM21,15.8818l3,1.5V4H18V17.3818Z"
  })), children);
});
var Course16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Course16(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,30H8a2.0023,2.0023,0,0,1-2-2V4A2.002,2.002,0,0,1,8,2H24a2.0023,2.0023,0,0,1,2,2V20.6182l-5-2.5-5,2.5V4H8V28H24V24h2v4A2.0027,2.0027,0,0,1,24,30ZM21,15.8818l3,1.5V4H18V17.3818Z"
  })), children);
});
var Covariate32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Covariate32(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle25 || (_circle25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "2"
  })), _circle26 || (_circle26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "8",
    r: "2"
  })), _circle27 || (_circle27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "12",
    r: "2"
  })), _circle28 || (_circle28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "18",
    r: "2"
  })), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4141,28.5859,2,4,26.5859V2H2V28a2,2,0,0,0,2,2H30V28H5.4141ZM4,28Z"
  })), children);
});
var Covariate24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Covariate24(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle29 || (_circle29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "2"
  })), _circle30 || (_circle30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "8",
    r: "2"
  })), _circle31 || (_circle31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "12",
    r: "2"
  })), _circle32 || (_circle32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "18",
    r: "2"
  })), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4141,28.5859,2,4,26.5859V2H2V28a2,2,0,0,0,2,2H30V28H5.4141ZM4,28Z"
  })), children);
});
var Covariate20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Covariate20(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle33 || (_circle33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "2"
  })), _circle34 || (_circle34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "8",
    r: "2"
  })), _circle35 || (_circle35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "12",
    r: "2"
  })), _circle36 || (_circle36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "18",
    r: "2"
  })), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4141,28.5859,2,4,26.5859V2H2V28a2,2,0,0,0,2,2H30V28H5.4141ZM4,28Z"
  })), children);
});
var Covariate16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Covariate16(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle37 || (_circle37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "2"
  })), _circle38 || (_circle38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "8",
    r: "2"
  })), _circle39 || (_circle39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "28",
    cy: "12",
    r: "2"
  })), _circle40 || (_circle40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "21",
    cy: "18",
    r: "2"
  })), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,3.4141,28.5859,2,4,26.5859V2H2V28a2,2,0,0,0,2,2H30V28H5.4141ZM4,28Z"
  })), children);
});
var Credentials32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Credentials32(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22a4 4 0 10-4-4A4 4 0 0016 22zm0-6a2 2 0 11-2 2A2 2 0 0116 16zM14 6H18V8H14z"
  })), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,2H8A2.002,2.002,0,0,0,6,4V28a2.0023,2.0023,0,0,0,2,2H24a2.0027,2.0027,0,0,0,2-2V4A2.0023,2.0023,0,0,0,24,2ZM20,28H12V26a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1Zm2,0V26a3,3,0,0,0-3-3H13a3,3,0,0,0-3,3v2H8V4H24V28Z"
  })), children);
});
var Credentials24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Credentials24(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22a4 4 0 10-4-4A4 4 0 0016 22zm0-6a2 2 0 11-2 2A2 2 0 0116 16zM14 6H18V8H14z"
  })), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,2H8A2.002,2.002,0,0,0,6,4V28a2.0023,2.0023,0,0,0,2,2H24a2.0027,2.0027,0,0,0,2-2V4A2.0023,2.0023,0,0,0,24,2ZM20,28H12V26a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1Zm2,0V26a3,3,0,0,0-3-3H13a3,3,0,0,0-3,3v2H8V4H24V28Z"
  })), children);
});
var Credentials20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Credentials20(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22a4 4 0 10-4-4A4 4 0 0016 22zm0-6a2 2 0 11-2 2A2 2 0 0116 16zM14 6H18V8H14z"
  })), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,2H8A2.002,2.002,0,0,0,6,4V28a2.0023,2.0023,0,0,0,2,2H24a2.0027,2.0027,0,0,0,2-2V4A2.0023,2.0023,0,0,0,24,2ZM20,28H12V26a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1Zm2,0V26a3,3,0,0,0-3-3H13a3,3,0,0,0-3,3v2H8V4H24V28Z"
  })), children);
});
var Credentials16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Credentials16(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 22a4 4 0 10-4-4A4 4 0 0016 22zm0-6a2 2 0 11-2 2A2 2 0 0116 16zM14 6H18V8H14z"
  })), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,2H8A2.002,2.002,0,0,0,6,4V28a2.0023,2.0023,0,0,0,2,2H24a2.0027,2.0027,0,0,0,2-2V4A2.0023,2.0023,0,0,0,24,2ZM20,28H12V26a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1Zm2,0V26a3,3,0,0,0-3-3H13a3,3,0,0,0-3,3v2H8V4H24V28Z"
  })), children);
});
var CriticalGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CriticalGlyph(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.887 11.4727a5.9936 5.9936 0 00-8.36-8.3594zM3.113 4.5273a5.9936 5.9936 0 008.36 8.3594z"
  })), children);
});
var CriticalSeverityGlyph = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CriticalSeverityGlyph(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 13L3 13 3 3 13 13z"
  })), children);
});
var Crop32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Crop32(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,20H23V9H12V7H23a2,2,0,0,1,2,2Z"
  })), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,23V2H7V7H2V9H7V23a2,2,0,0,0,2,2H23v5h2V25h5V23Z"
  })), children);
});
var Crop24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Crop24(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,20H23V9H12V7H23a2,2,0,0,1,2,2Z"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,23V2H7V7H2V9H7V23a2,2,0,0,0,2,2H23v5h2V25h5V23Z"
  })), children);
});
var Crop20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Crop20(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,20H23V9H12V7H23a2,2,0,0,1,2,2Z"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,23V2H7V7H2V9H7V23a2,2,0,0,0,2,2H23v5h2V25h5V23Z"
  })), children);
});
var Crop16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Crop16(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25,20H23V9H12V7H23a2,2,0,0,1,2,2Z"
  })), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,23V2H7V7H2V9H7V23a2,2,0,0,0,2,2H23v5h2V25h5V23Z"
  })), children);
});
var CropGrowth32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CropGrowth32(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,13a4.0045,4.0045,0,0,0,4-4V6H27a3.979,3.979,0,0,0-2.7468,1.1064A6.0041,6.0041,0,0,0,19,4H16V7a6.0066,6.0066,0,0,0,6,6h1V26H11V21h1a4.0045,4.0045,0,0,0,4-4V14H13a3.979,3.979,0,0,0-2.7468,1.1064A6.0041,6.0041,0,0,0,5,12H2v3a6.0066,6.0066,0,0,0,6,6H9v5H2v2H30V26H25V13Zm-1-3a2.002,2.002,0,0,1,2-2h1V9a2.002,2.002,0,0,1-2,2H25ZM11,18a2.002,2.002,0,0,1,2-2h1v1a2.002,2.002,0,0,1-2,2H11ZM9,19H8a4.0045,4.0045,0,0,1-4-4V14H5a4.0045,4.0045,0,0,1,4,4Zm14-8H22a4.0045,4.0045,0,0,1-4-4V6h1a4.0045,4.0045,0,0,1,4,4Z"
  })), children);
});
var CropGrowth24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CropGrowth24(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,13a4.0045,4.0045,0,0,0,4-4V6H27a3.979,3.979,0,0,0-2.7468,1.1064A6.0041,6.0041,0,0,0,19,4H16V7a6.0066,6.0066,0,0,0,6,6h1V26H11V21h1a4.0045,4.0045,0,0,0,4-4V14H13a3.979,3.979,0,0,0-2.7468,1.1064A6.0041,6.0041,0,0,0,5,12H2v3a6.0066,6.0066,0,0,0,6,6H9v5H2v2H30V26H25V13Zm-1-3a2.002,2.002,0,0,1,2-2h1V9a2.002,2.002,0,0,1-2,2H25ZM11,18a2.002,2.002,0,0,1,2-2h1v1a2.002,2.002,0,0,1-2,2H11ZM9,19H8a4.0045,4.0045,0,0,1-4-4V14H5a4.0045,4.0045,0,0,1,4,4Zm14-8H22a4.0045,4.0045,0,0,1-4-4V6h1a4.0045,4.0045,0,0,1,4,4Z"
  })), children);
});
var CropGrowth20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CropGrowth20(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,13a4.0045,4.0045,0,0,0,4-4V6H27a3.979,3.979,0,0,0-2.7468,1.1064A6.0041,6.0041,0,0,0,19,4H16V7a6.0066,6.0066,0,0,0,6,6h1V26H11V21h1a4.0045,4.0045,0,0,0,4-4V14H13a3.979,3.979,0,0,0-2.7468,1.1064A6.0041,6.0041,0,0,0,5,12H2v3a6.0066,6.0066,0,0,0,6,6H9v5H2v2H30V26H25V13Zm-1-3a2.002,2.002,0,0,1,2-2h1V9a2.002,2.002,0,0,1-2,2H25ZM11,18a2.002,2.002,0,0,1,2-2h1v1a2.002,2.002,0,0,1-2,2H11ZM9,19H8a4.0045,4.0045,0,0,1-4-4V14H5a4.0045,4.0045,0,0,1,4,4Zm14-8H22a4.0045,4.0045,0,0,1-4-4V6h1a4.0045,4.0045,0,0,1,4,4Z"
  })), children);
});
var CropGrowth16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CropGrowth16(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,13a4.0045,4.0045,0,0,0,4-4V6H27a3.979,3.979,0,0,0-2.7468,1.1064A6.0041,6.0041,0,0,0,19,4H16V7a6.0066,6.0066,0,0,0,6,6h1V26H11V21h1a4.0045,4.0045,0,0,0,4-4V14H13a3.979,3.979,0,0,0-2.7468,1.1064A6.0041,6.0041,0,0,0,5,12H2v3a6.0066,6.0066,0,0,0,6,6H9v5H2v2H30V26H25V13Zm-1-3a2.002,2.002,0,0,1,2-2h1V9a2.002,2.002,0,0,1-2,2H25ZM11,18a2.002,2.002,0,0,1,2-2h1v1a2.002,2.002,0,0,1-2,2H11ZM9,19H8a4.0045,4.0045,0,0,1-4-4V14H5a4.0045,4.0045,0,0,1,4,4Zm14-8H22a4.0045,4.0045,0,0,1-4-4V6h1a4.0045,4.0045,0,0,1,4,4Z"
  })), children);
});
var CropHealth32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CropHealth32(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H10V30H2zM17 29a1 1 0 01-.7808-.3752L12.52 24H2V22H13a1 1 0 01.7808.3752l3.146 3.9322 5.2412-7.8621A1 1 0 0123.8 18.4L26.5 22H30v2H26a.9991.9991 0 01-.8-.4l-2.1523-2.8694-5.2159 7.824a.9986.9986 0 01-.7885.4443zM11 16V11h1a4.0045 4.0045 0 004-4V4H13a3.9779 3.9779 0 00-2.7468 1.1067A6.0034 6.0034 0 005 2H2V5a6.0066 6.0066 0 006 6H9v5H2v2H16V16zM13 6h1V7a2.002 2.002 0 01-2 2H11V8A2.002 2.002 0 0113 6zM8 9A4.0045 4.0045 0 014 5V4H5A4.0045 4.0045 0 019 8V9z"
  })), children);
});
var CropHealth24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CropHealth24(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H10V30H2zM17 29a1 1 0 01-.7808-.3752L12.52 24H2V22H13a1 1 0 01.7808.3752l3.146 3.9322 5.2412-7.8621A1 1 0 0123.8 18.4L26.5 22H30v2H26a.9991.9991 0 01-.8-.4l-2.1523-2.8694-5.2159 7.824a.9986.9986 0 01-.7885.4443zM11 16V11h1a4.0045 4.0045 0 004-4V4H13a3.9779 3.9779 0 00-2.7468 1.1067A6.0034 6.0034 0 005 2H2V5a6.0066 6.0066 0 006 6H9v5H2v2H16V16zM13 6h1V7a2.002 2.002 0 01-2 2H11V8A2.002 2.002 0 0113 6zM8 9A4.0045 4.0045 0 014 5V4H5A4.0045 4.0045 0 019 8V9z"
  })), children);
});
var CropHealth20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CropHealth20(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H10V30H2zM17 29a1 1 0 01-.7808-.3752L12.52 24H2V22H13a1 1 0 01.7808.3752l3.146 3.9322 5.2412-7.8621A1 1 0 0123.8 18.4L26.5 22H30v2H26a.9991.9991 0 01-.8-.4l-2.1523-2.8694-5.2159 7.824a.9986.9986 0 01-.7885.4443zM11 16V11h1a4.0045 4.0045 0 004-4V4H13a3.9779 3.9779 0 00-2.7468 1.1067A6.0034 6.0034 0 005 2H2V5a6.0066 6.0066 0 006 6H9v5H2v2H16V16zM13 6h1V7a2.002 2.002 0 01-2 2H11V8A2.002 2.002 0 0113 6zM8 9A4.0045 4.0045 0 014 5V4H5A4.0045 4.0045 0 019 8V9z"
  })), children);
});
var CropHealth16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CropHealth16(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H10V30H2zM17 29a1 1 0 01-.7808-.3752L12.52 24H2V22H13a1 1 0 01.7808.3752l3.146 3.9322 5.2412-7.8621A1 1 0 0123.8 18.4L26.5 22H30v2H26a.9991.9991 0 01-.8-.4l-2.1523-2.8694-5.2159 7.824a.9986.9986 0 01-.7885.4443zM11 16V11h1a4.0045 4.0045 0 004-4V4H13a3.9779 3.9779 0 00-2.7468 1.1067A6.0034 6.0034 0 005 2H2V5a6.0066 6.0066 0 006 6H9v5H2v2H16V16zM13 6h1V7a2.002 2.002 0 01-2 2H11V8A2.002 2.002 0 0113 6zM8 9A4.0045 4.0045 0 014 5V4H5A4.0045 4.0045 0 019 8V9z"
  })), children);
});
var WatsonHealthCrossReference32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCrossReference32(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H15V26H11zM5 24H9V26H5zM23 24H27V26H23zM17 24H21V26H17zM9 22a4.92 4.92 0 014-2h6a5.22 5.22 0 014 2h2.3A6.87 6.87 0 0019 18H13a6.87 6.87 0 00-6.3 4zM24 28H26V30H24zM6 28H8V30H6zM16 16a7 7 0 117-7A7 7 0 0116 16zM16 4a5 5 0 00-5 5A5 5 0 0021 9 5 5 0 0016 4z"
  })), children);
});
var WatsonHealthCrossReference24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCrossReference24(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H15V26H11zM5 24H9V26H5zM23 24H27V26H23zM17 24H21V26H17zM9 22a4.92 4.92 0 014-2h6a5.22 5.22 0 014 2h2.3A6.87 6.87 0 0019 18H13a6.87 6.87 0 00-6.3 4zM24 28H26V30H24zM6 28H8V30H6zM16 16a7 7 0 117-7A7 7 0 0116 16zM16 4a5 5 0 00-5 5A5 5 0 0021 9 5 5 0 0016 4z"
  })), children);
});
var WatsonHealthCrossReference20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCrossReference20(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H15V26H11zM5 24H9V26H5zM23 24H27V26H23zM17 24H21V26H17zM9 22a4.92 4.92 0 014-2h6a5.22 5.22 0 014 2h2.3A6.87 6.87 0 0019 18H13a6.87 6.87 0 00-6.3 4zM24 28H26V30H24zM6 28H8V30H6zM16 16a7 7 0 117-7A7 7 0 0116 16zM16 4a5 5 0 00-5 5A5 5 0 0021 9 5 5 0 0016 4z"
  })), children);
});
var WatsonHealthCrossReference16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCrossReference16(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M11 24H15V26H11zM5 24H9V26H5zM23 24H27V26H23zM17 24H21V26H17zM9 22a4.92 4.92 0 014-2h6a5.22 5.22 0 014 2h2.3A6.87 6.87 0 0019 18H13a6.87 6.87 0 00-6.3 4zM24 28H26V30H24zM6 28H8V30H6zM16 16a7 7 0 117-7A7 7 0 0116 16zM16 4a5 5 0 00-5 5A5 5 0 0021 9 5 5 0 0016 4z"
  })), children);
});
var CrossTab32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CrossTab32(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H10A2.0023,2.0023,0,0,0,8,4V7H4A2.0023,2.0023,0,0,0,2,9V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2ZM10,4H28V7H10ZM28,14H20V9h8ZM10,21V16h8v5Zm8,2v5H10V23ZM8,21H4V16H8ZM18,9v5H10V9Zm2,7h8v5H20ZM8,9v5H4V9ZM4,23H8v5H4Zm16,5V23h8v5Z"
  })), children);
});
var CrossTab24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CrossTab24(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H10A2.0023,2.0023,0,0,0,8,4V7H4A2.0023,2.0023,0,0,0,2,9V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2ZM10,4H28V7H10ZM28,14H20V9h8ZM10,21V16h8v5Zm8,2v5H10V23ZM8,21H4V16H8ZM18,9v5H10V9Zm2,7h8v5H20ZM8,9v5H4V9ZM4,23H8v5H4Zm16,5V23h8v5Z"
  })), children);
});
var CrossTab20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CrossTab20(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H10A2.0023,2.0023,0,0,0,8,4V7H4A2.0023,2.0023,0,0,0,2,9V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2ZM10,4H28V7H10ZM28,14H20V9h8ZM10,21V16h8v5Zm8,2v5H10V23ZM8,21H4V16H8ZM18,9v5H10V9Zm2,7h8v5H20ZM8,9v5H4V9ZM4,23H8v5H4Zm16,5V23h8v5Z"
  })), children);
});
var CrossTab16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CrossTab16(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H10A2.0023,2.0023,0,0,0,8,4V7H4A2.0023,2.0023,0,0,0,2,9V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2ZM10,4H28V7H10ZM28,14H20V9h8ZM10,21V16h8v5Zm8,2v5H10V23ZM8,21H4V16H8ZM18,9v5H10V9Zm2,7h8v5H20ZM8,9v5H4V9ZM4,23H8v5H4Zm16,5V23h8v5Z"
  })), children);
});
var Crossroads32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Crossroads32(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5859,6.5859A1.9862,1.9862,0,0,0,25.1719,6H17V2H15V12H6.8281a1.9862,1.9862,0,0,0-1.414.5859L2,16l3.4141,3.4141A1.9862,1.9862,0,0,0,6.8281,20H15V30h2V14h8.1719a1.9862,1.9862,0,0,0,1.414-.5859L30,10ZM6.8281,18l-2-2,2-2H15v4Zm18.3438-6H17V8h8.1719l2,2Z"
  })), children);
});
var Crossroads24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Crossroads24(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5859,6.5859A1.9862,1.9862,0,0,0,25.1719,6H17V2H15V12H6.8281a1.9862,1.9862,0,0,0-1.414.5859L2,16l3.4141,3.4141A1.9862,1.9862,0,0,0,6.8281,20H15V30h2V14h8.1719a1.9862,1.9862,0,0,0,1.414-.5859L30,10ZM6.8281,18l-2-2,2-2H15v4Zm18.3438-6H17V8h8.1719l2,2Z"
  })), children);
});
var Crossroads20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Crossroads20(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5859,6.5859A1.9862,1.9862,0,0,0,25.1719,6H17V2H15V12H6.8281a1.9862,1.9862,0,0,0-1.414.5859L2,16l3.4141,3.4141A1.9862,1.9862,0,0,0,6.8281,20H15V30h2V14h8.1719a1.9862,1.9862,0,0,0,1.414-.5859L30,10ZM6.8281,18l-2-2,2-2H15v4Zm18.3438-6H17V8h8.1719l2,2Z"
  })), children);
});
var Crossroads16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Crossroads16(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5859,6.5859A1.9862,1.9862,0,0,0,25.1719,6H17V2H15V12H6.8281a1.9862,1.9862,0,0,0-1.414.5859L2,16l3.4141,3.4141A1.9862,1.9862,0,0,0,6.8281,20H15V30h2V14h8.1719a1.9862,1.9862,0,0,0,1.414-.5859L30,10ZM6.8281,18l-2-2,2-2H15v4Zm18.3438-6H17V8h8.1719l2,2Z"
  })), children);
});
var CrowdReport32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CrowdReport32(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.832,19.5547l-1.664-1.1094L17.4648,15H20V10H12v5h2v2H12a2.0021,2.0021,0,0,1-2-2V10a2.0021,2.0021,0,0,1,2-2h8a2.0021,2.0021,0,0,1,2,2v5a2.0021,2.0021,0,0,1-2,2H18.5352Z"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var CrowdReport24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CrowdReport24(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.832,19.5547l-1.664-1.1094L17.4648,15H20V10H12v5h2v2H12a2.0021,2.0021,0,0,1-2-2V10a2.0021,2.0021,0,0,1,2-2h8a2.0021,2.0021,0,0,1,2,2v5a2.0021,2.0021,0,0,1-2,2H18.5352Z"
  })), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var CrowdReport20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CrowdReport20(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.832,19.5547l-1.664-1.1094L17.4648,15H20V10H12v5h2v2H12a2.0021,2.0021,0,0,1-2-2V10a2.0021,2.0021,0,0,1,2-2h8a2.0021,2.0021,0,0,1,2,2v5a2.0021,2.0021,0,0,1-2,2H18.5352Z"
  })), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var CrowdReport16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CrowdReport16(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16.832,19.5547l-1.664-1.1094L17.4648,15H20V10H12v5h2v2H12a2.0021,2.0021,0,0,1-2-2V10a2.0021,2.0021,0,0,1,2-2h8a2.0021,2.0021,0,0,1,2,2v5a2.0021,2.0021,0,0,1-2,2H18.5352Z"
  })), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,30,7.5645,20.0513c-.0479-.0571-.3482-.4515-.3482-.4515A10.8888,10.8888,0,0,1,5,13a11,11,0,0,1,22,0,10.8844,10.8844,0,0,1-2.2148,6.5973l-.0015.0025s-.3.3944-.3447.4474ZM8.8125,18.395c.001.0007.2334.3082.2866.3744L16,26.9079l6.91-8.15c.0439-.0552.2783-.3649.2788-.3657A8.901,8.901,0,0,0,25,13,9,9,0,0,0,7,13a8.9054,8.9054,0,0,0,1.8125,5.395Z"
  })), children);
});
var CrowdReportFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CrowdReportFilled32(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16.832,19.5547l-1.664-1.1094L17.4648,15H20V10H12v5h2v2H12a2.0021,2.0021,0,0,1-2-2V10a2.0021,2.0021,0,0,1,2-2h8a2.0021,2.0021,0,0,1,2,2v5a2.0021,2.0021,0,0,1-2,2H18.5352Z"
  })), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm6,13a2.0023,2.0023,0,0,1-2,2H18.5352L16.832,19.5547l-1.664-1.1094L17.4648,15H20V10H12v5h2v2H12a2.0023,2.0023,0,0,1-2-2V10a2.0023,2.0023,0,0,1,2-2h8a2.0023,2.0023,0,0,1,2,2Z"
  })), children);
});
var CrowdReportFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CrowdReportFilled24(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16.832,19.5547l-1.664-1.1094L17.4648,15H20V10H12v5h2v2H12a2.0021,2.0021,0,0,1-2-2V10a2.0021,2.0021,0,0,1,2-2h8a2.0021,2.0021,0,0,1,2,2v5a2.0021,2.0021,0,0,1-2,2H18.5352Z"
  })), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm6,13a2.0023,2.0023,0,0,1-2,2H18.5352L16.832,19.5547l-1.664-1.1094L17.4648,15H20V10H12v5h2v2H12a2.0023,2.0023,0,0,1-2-2V10a2.0023,2.0023,0,0,1,2-2h8a2.0023,2.0023,0,0,1,2,2Z"
  })), children);
});
var CrowdReportFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CrowdReportFilled20(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16.832,19.5547l-1.664-1.1094L17.4648,15H20V10H12v5h2v2H12a2.0021,2.0021,0,0,1-2-2V10a2.0021,2.0021,0,0,1,2-2h8a2.0021,2.0021,0,0,1,2,2v5a2.0021,2.0021,0,0,1-2,2H18.5352Z"
  })), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm6,13a2.0023,2.0023,0,0,1-2,2H18.5352L16.832,19.5547l-1.664-1.1094L17.4648,15H20V10H12v5h2v2H12a2.0023,2.0023,0,0,1-2-2V10a2.0023,2.0023,0,0,1,2-2h8a2.0023,2.0023,0,0,1,2,2Z"
  })), children);
});
var CrowdReportFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CrowdReportFilled16(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16.832,19.5547l-1.664-1.1094L17.4648,15H20V10H12v5h2v2H12a2.0021,2.0021,0,0,1-2-2V10a2.0021,2.0021,0,0,1,2-2h8a2.0021,2.0021,0,0,1,2,2v5a2.0021,2.0021,0,0,1-2,2H18.5352Z"
  })), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,2A11.0134,11.0134,0,0,0,5,13a10.8885,10.8885,0,0,0,2.2163,6.6s.3.3945.3482.4517L16,30l8.439-9.9526c.0444-.0533.3447-.4478.3447-.4478l.0015-.0024A10.8846,10.8846,0,0,0,27,13,11.0134,11.0134,0,0,0,16,2Zm6,13a2.0023,2.0023,0,0,1-2,2H18.5352L16.832,19.5547l-1.664-1.1094L17.4648,15H20V10H12v5h2v2H12a2.0023,2.0023,0,0,1-2-2V10a2.0023,2.0023,0,0,1,2-2h8a2.0023,2.0023,0,0,1,2,2Z"
  })), children);
});
var Csv32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Csv32(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9L26 22 24 9 22 9 24.516 23 27.484 23 30 9 28 9zM18 23H12V21h6V17H14a2.002 2.002 0 01-2-2V11a2.002 2.002 0 012-2h6v2H14v4h4a2.002 2.002 0 012 2v4A2.002 2.002 0 0118 23zM10 23H4a2.0023 2.0023 0 01-2-2V11A2.002 2.002 0 014 9h6v2H4V21h6z"
  })), children);
});
var Csv24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Csv24(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9L26 22 24 9 22 9 24.516 23 27.484 23 30 9 28 9zM18 23H12V21h6V17H14a2.002 2.002 0 01-2-2V11a2.002 2.002 0 012-2h6v2H14v4h4a2.002 2.002 0 012 2v4A2.002 2.002 0 0118 23zM10 23H4a2.0023 2.0023 0 01-2-2V11A2.002 2.002 0 014 9h6v2H4V21h6z"
  })), children);
});
var Csv20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Csv20(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9L26 22 24 9 22 9 24.516 23 27.484 23 30 9 28 9zM18 23H12V21h6V17H14a2.002 2.002 0 01-2-2V11a2.002 2.002 0 012-2h6v2H14v4h4a2.002 2.002 0 012 2v4A2.002 2.002 0 0118 23zM10 23H4a2.0023 2.0023 0 01-2-2V11A2.002 2.002 0 014 9h6v2H4V21h6z"
  })), children);
});
var Csv16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Csv16(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 9L26 22 24 9 22 9 24.516 23 27.484 23 30 9 28 9zM18 23H12V21h6V17H14a2.002 2.002 0 01-2-2V11a2.002 2.002 0 012-2h6v2H14v4h4a2.002 2.002 0 012 2v4A2.002 2.002 0 0118 23zM10 23H4a2.0023 2.0023 0 01-2-2V11A2.002 2.002 0 014 9h6v2H4V21h6z"
  })), children);
});
var QCU132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCU132(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 23H5a2 2 0 01-2-2V15a2 2 0 012-2h5v2H5v6h5zM18 23H14a2 2 0 01-2-2V9h2V21h4V9h2V21A2 2 0 0118 23zM27 21L27 9.01 22 9.01 22 11.01 25 11.01 25 21 22 21 22 23 30 23 30 21 27 21z"
  })), children);
});
var QCU124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCU124(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 23H5a2 2 0 01-2-2V15a2 2 0 012-2h5v2H5v6h5zM18 23H14a2 2 0 01-2-2V9h2V21h4V9h2V21A2 2 0 0118 23zM27 21L27 9.01 22 9.01 22 11.01 25 11.01 25 21 22 21 22 23 30 23 30 21 27 21z"
  })), children);
});
var QCU120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCU120(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 23H5a2 2 0 01-2-2V15a2 2 0 012-2h5v2H5v6h5zM18 23H14a2 2 0 01-2-2V9h2V21h4V9h2V21A2 2 0 0118 23zM27 21L27 9.01 22 9.01 22 11.01 25 11.01 25 21 22 21 22 23 30 23 30 21 27 21z"
  })), children);
});
var QCU116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCU116(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 23H5a2 2 0 01-2-2V15a2 2 0 012-2h5v2H5v6h5zM18 23H14a2 2 0 01-2-2V9h2V21h4V9h2V21A2 2 0 0118 23zM27 21L27 9.01 22 9.01 22 11.01 25 11.01 25 21 22 21 22 23 30 23 30 21 27 21z"
  })), children);
});
var QCU332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCU332(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 23H5a2 2 0 01-2-2V15a2 2 0 012-2h5v2H5v6h5zM18 23H14a2 2 0 01-2-2V9h2V21h4V9h2V21A2 2 0 0118 23zM28 9H22v2h6v4H23v2h5v4H22v2h6a2 2 0 002-2V11A2 2 0 0028 9z"
  })), children);
});
var QCU324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCU324(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 23H5a2 2 0 01-2-2V15a2 2 0 012-2h5v2H5v6h5zM18 23H14a2 2 0 01-2-2V9h2V21h4V9h2V21A2 2 0 0118 23zM28 9H22v2h6v4H23v2h5v4H22v2h6a2 2 0 002-2V11A2 2 0 0028 9z"
  })), children);
});
var QCU320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCU320(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 23H5a2 2 0 01-2-2V15a2 2 0 012-2h5v2H5v6h5zM18 23H14a2 2 0 01-2-2V9h2V21h4V9h2V21A2 2 0 0118 23zM28 9H22v2h6v4H23v2h5v4H22v2h6a2 2 0 002-2V11A2 2 0 0028 9z"
  })), children);
});
var QCU316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCU316(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 23H5a2 2 0 01-2-2V15a2 2 0 012-2h5v2H5v6h5zM18 23H14a2 2 0 01-2-2V9h2V21h4V9h2V21A2 2 0 0118 23zM28 9H22v2h6v4H23v2h5v4H22v2h6a2 2 0 002-2V11A2 2 0 0028 9z"
  })), children);
});
var Cube32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cube32(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5039,8.1362l-12-7a1,1,0,0,0-1.0078,0l-12,7A1,1,0,0,0,3,9V23a1,1,0,0,0,.4961.8638l12,7a1,1,0,0,0,1.0078,0l12-7A1,1,0,0,0,29,23V9A1,1,0,0,0,28.5039,8.1362ZM16,3.1577,26.0156,9,16,14.8423,5.9844,9ZM5,10.7412l10,5.833V28.2588L5,22.4258ZM17,28.2588V16.5742l10-5.833V22.4258Z"
  })), children);
});
var Cube24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cube24(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5039,8.1362l-12-7a1,1,0,0,0-1.0078,0l-12,7A1,1,0,0,0,3,9V23a1,1,0,0,0,.4961.8638l12,7a1,1,0,0,0,1.0078,0l12-7A1,1,0,0,0,29,23V9A1,1,0,0,0,28.5039,8.1362ZM16,3.1577,26.0156,9,16,14.8423,5.9844,9ZM5,10.7412l10,5.833V28.2588L5,22.4258ZM17,28.2588V16.5742l10-5.833V22.4258Z"
  })), children);
});
var Cube20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cube20(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5039,8.1362l-12-7a1,1,0,0,0-1.0078,0l-12,7A1,1,0,0,0,3,9V23a1,1,0,0,0,.4961.8638l12,7a1,1,0,0,0,1.0078,0l12-7A1,1,0,0,0,29,23V9A1,1,0,0,0,28.5039,8.1362ZM16,3.1577,26.0156,9,16,14.8423,5.9844,9ZM5,10.7412l10,5.833V28.2588L5,22.4258ZM17,28.2588V16.5742l10-5.833V22.4258Z"
  })), children);
});
var Cube16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cube16(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5039,8.1362l-12-7a1,1,0,0,0-1.0078,0l-12,7A1,1,0,0,0,3,9V23a1,1,0,0,0,.4961.8638l12,7a1,1,0,0,0,1.0078,0l12-7A1,1,0,0,0,29,23V9A1,1,0,0,0,28.5039,8.1362ZM16,3.1577,26.0156,9,16,14.8423,5.9844,9ZM5,10.7412l10,5.833V28.2588L5,22.4258ZM17,28.2588V16.5742l10-5.833V22.4258Z"
  })), children);
});
var CubeView32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CubeView32(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle41 || (_circle41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.7769,15.4785A8.64,8.64,0,0,0,16,10a8.64,8.64,0,0,0-7.7769,5.4785L8,16l.2231.5215A8.64,8.64,0,0,0,16,22a8.64,8.64,0,0,0,7.7769-5.4785L24,16ZM16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Z"
  })), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5039,8.1362l-12-7a1,1,0,0,0-1.0078,0l-12,7A1,1,0,0,0,3,9V23a1,1,0,0,0,.4961.8638l12,7a1,1,0,0,0,1.0078,0l12-7A1,1,0,0,0,29,23V9A1,1,0,0,0,28.5039,8.1362ZM27,22.4258,16,28.8423,5,22.4258V9.5742L16,3.1577,27,9.5742Z"
  })), children);
});
var CubeView24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CubeView24(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle42 || (_circle42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.7769,15.4785A8.64,8.64,0,0,0,16,10a8.64,8.64,0,0,0-7.7769,5.4785L8,16l.2231.5215A8.64,8.64,0,0,0,16,22a8.64,8.64,0,0,0,7.7769-5.4785L24,16ZM16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Z"
  })), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5039,8.1362l-12-7a1,1,0,0,0-1.0078,0l-12,7A1,1,0,0,0,3,9V23a1,1,0,0,0,.4961.8638l12,7a1,1,0,0,0,1.0078,0l12-7A1,1,0,0,0,29,23V9A1,1,0,0,0,28.5039,8.1362ZM27,22.4258,16,28.8423,5,22.4258V9.5742L16,3.1577,27,9.5742Z"
  })), children);
});
var CubeView20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CubeView20(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle43 || (_circle43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.7769,15.4785A8.64,8.64,0,0,0,16,10a8.64,8.64,0,0,0-7.7769,5.4785L8,16l.2231.5215A8.64,8.64,0,0,0,16,22a8.64,8.64,0,0,0,7.7769-5.4785L24,16ZM16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Z"
  })), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5039,8.1362l-12-7a1,1,0,0,0-1.0078,0l-12,7A1,1,0,0,0,3,9V23a1,1,0,0,0,.4961.8638l12,7a1,1,0,0,0,1.0078,0l12-7A1,1,0,0,0,29,23V9A1,1,0,0,0,28.5039,8.1362ZM27,22.4258,16,28.8423,5,22.4258V9.5742L16,3.1577,27,9.5742Z"
  })), children);
});
var CubeView16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CubeView16(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle44 || (_circle44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.7769,15.4785A8.64,8.64,0,0,0,16,10a8.64,8.64,0,0,0-7.7769,5.4785L8,16l.2231.5215A8.64,8.64,0,0,0,16,22a8.64,8.64,0,0,0,7.7769-5.4785L24,16ZM16,20a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,20Z"
  })), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.5039,8.1362l-12-7a1,1,0,0,0-1.0078,0l-12,7A1,1,0,0,0,3,9V23a1,1,0,0,0,.4961.8638l12,7a1,1,0,0,0,1.0078,0l12-7A1,1,0,0,0,29,23V9A1,1,0,0,0,28.5039,8.1362ZM27,22.4258,16,28.8423,5,22.4258V9.5742L16,3.1577,27,9.5742Z"
  })), children);
});
var Currency32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Currency32(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,12V10H17V7H15v3H13a2.002,2.002,0,0,0-2,2v3a2.002,2.002,0,0,0,2,2h6v3H11v2h4v3h2V22h2a2.0023,2.0023,0,0,0,2-2V17a2.002,2.002,0,0,0-2-2H13V12Z"
  })), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12.0353,12.0353,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14.0412,14.0412,0,0,0,16,2Z"
  })), children);
});
var Currency24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Currency24(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,12V10H17V7H15v3H13a2.002,2.002,0,0,0-2,2v3a2.002,2.002,0,0,0,2,2h6v3H11v2h4v3h2V22h2a2.0023,2.0023,0,0,0,2-2V17a2.002,2.002,0,0,0-2-2H13V12Z"
  })), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12.0353,12.0353,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14.0412,14.0412,0,0,0,16,2Z"
  })), children);
});
var Currency20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Currency20(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,12V10H17V7H15v3H13a2.002,2.002,0,0,0-2,2v3a2.002,2.002,0,0,0,2,2h6v3H11v2h4v3h2V22h2a2.0023,2.0023,0,0,0,2-2V17a2.002,2.002,0,0,0-2-2H13V12Z"
  })), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12.0353,12.0353,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14.0412,14.0412,0,0,0,16,2Z"
  })), children);
});
var Currency16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Currency16(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,12V10H17V7H15v3H13a2.002,2.002,0,0,0-2,2v3a2.002,2.002,0,0,0,2,2h6v3H11v2h4v3h2V22h2a2.0023,2.0023,0,0,0,2-2V17a2.002,2.002,0,0,0-2-2H13V12Z"
  })), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,4A12,12,0,1,1,4,16,12.0353,12.0353,0,0,1,16,4m0-2A14,14,0,1,0,30,16,14.0412,14.0412,0,0,0,16,2Z"
  })), children);
});
var CurrencyBaht32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyBaht32(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4023,15.6426A4.9727,4.9727,0,0,0,23,12V11a5.0059,5.0059,0,0,0-5-5H17V3H15V6H10V26h5v3h2V26h2a5.0059,5.0059,0,0,0,5-5V20A4.9834,4.9834,0,0,0,21.4023,15.6426ZM12,8h6a3.0033,3.0033,0,0,1,3,3v1a3.0033,3.0033,0,0,1-3,3H12ZM22,21a3.0033,3.0033,0,0,1-3,3H12V17h7a3.0033,3.0033,0,0,1,3,3Z"
  })), children);
});
var CurrencyBaht24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyBaht24(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4023,15.6426A4.9727,4.9727,0,0,0,23,12V11a5.0059,5.0059,0,0,0-5-5H17V3H15V6H10V26h5v3h2V26h2a5.0059,5.0059,0,0,0,5-5V20A4.9834,4.9834,0,0,0,21.4023,15.6426ZM12,8h6a3.0033,3.0033,0,0,1,3,3v1a3.0033,3.0033,0,0,1-3,3H12ZM22,21a3.0033,3.0033,0,0,1-3,3H12V17h7a3.0033,3.0033,0,0,1,3,3Z"
  })), children);
});
var CurrencyBaht20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyBaht20(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4023,15.6426A4.9727,4.9727,0,0,0,23,12V11a5.0059,5.0059,0,0,0-5-5H17V3H15V6H10V26h5v3h2V26h2a5.0059,5.0059,0,0,0,5-5V20A4.9834,4.9834,0,0,0,21.4023,15.6426ZM12,8h6a3.0033,3.0033,0,0,1,3,3v1a3.0033,3.0033,0,0,1-3,3H12ZM22,21a3.0033,3.0033,0,0,1-3,3H12V17h7a3.0033,3.0033,0,0,1,3,3Z"
  })), children);
});
var CurrencyBaht16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyBaht16(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21.4023,15.6426A4.9727,4.9727,0,0,0,23,12V11a5.0059,5.0059,0,0,0-5-5H17V3H15V6H10V26h5v3h2V26h2a5.0059,5.0059,0,0,0,5-5V20A4.9834,4.9834,0,0,0,21.4023,15.6426ZM12,8h6a3.0033,3.0033,0,0,1,3,3v1a3.0033,3.0033,0,0,1-3,3H12ZM22,21a3.0033,3.0033,0,0,1-3,3H12V17h7a3.0033,3.0033,0,0,1,3,3Z"
  })), children);
});
var CurrencyDollar32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyDollar32(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,20.5151c0-4.6152-3.78-5.1411-6.8171-5.563-3.31-.4609-5.1829-.86-5.1829-3.71C11,8.8491,13.5071,8,15.6538,8a6.7538,6.7538,0,0,1,5.5681,2.6279l1.5562-1.2558A8.6508,8.6508,0,0,0,17,6.0962V3H15V6.022c-3.6152.2192-6,2.26-6,5.22,0,4.73,3.83,5.2627,6.9075,5.69C19.16,17.3848,21,17.7744,21,20.5151,21,23.5474,17.8674,24,16,24c-3.4294,0-4.8782-.9639-6.2219-2.6279L8.2219,22.6279A8.4382,8.4382,0,0,0,15,25.9648V29h2V25.9551C20.7256,25.6509,23,23.6279,23,20.5151Z"
  })), children);
});
var CurrencyDollar24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyDollar24(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,20.5151c0-4.6152-3.78-5.1411-6.8171-5.563-3.31-.4609-5.1829-.86-5.1829-3.71C11,8.8491,13.5071,8,15.6538,8a6.7538,6.7538,0,0,1,5.5681,2.6279l1.5562-1.2558A8.6508,8.6508,0,0,0,17,6.0962V3H15V6.022c-3.6152.2192-6,2.26-6,5.22,0,4.73,3.83,5.2627,6.9075,5.69C19.16,17.3848,21,17.7744,21,20.5151,21,23.5474,17.8674,24,16,24c-3.4294,0-4.8782-.9639-6.2219-2.6279L8.2219,22.6279A8.4382,8.4382,0,0,0,15,25.9648V29h2V25.9551C20.7256,25.6509,23,23.6279,23,20.5151Z"
  })), children);
});
var CurrencyDollar20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyDollar20(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,20.5151c0-4.6152-3.78-5.1411-6.8171-5.563-3.31-.4609-5.1829-.86-5.1829-3.71C11,8.8491,13.5071,8,15.6538,8a6.7538,6.7538,0,0,1,5.5681,2.6279l1.5562-1.2558A8.6508,8.6508,0,0,0,17,6.0962V3H15V6.022c-3.6152.2192-6,2.26-6,5.22,0,4.73,3.83,5.2627,6.9075,5.69C19.16,17.3848,21,17.7744,21,20.5151,21,23.5474,17.8674,24,16,24c-3.4294,0-4.8782-.9639-6.2219-2.6279L8.2219,22.6279A8.4382,8.4382,0,0,0,15,25.9648V29h2V25.9551C20.7256,25.6509,23,23.6279,23,20.5151Z"
  })), children);
});
var CurrencyDollar16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyDollar16(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,20.5151c0-4.6152-3.78-5.1411-6.8171-5.563-3.31-.4609-5.1829-.86-5.1829-3.71C11,8.8491,13.5071,8,15.6538,8a6.7538,6.7538,0,0,1,5.5681,2.6279l1.5562-1.2558A8.6508,8.6508,0,0,0,17,6.0962V3H15V6.022c-3.6152.2192-6,2.26-6,5.22,0,4.73,3.83,5.2627,6.9075,5.69C19.16,17.3848,21,17.7744,21,20.5151,21,23.5474,17.8674,24,16,24c-3.4294,0-4.8782-.9639-6.2219-2.6279L8.2219,22.6279A8.4382,8.4382,0,0,0,15,25.9648V29h2V25.9551C20.7256,25.6509,23,23.6279,23,20.5151Z"
  })), children);
});
var CurrencyEuro32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyEuro32(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,26c-3.6162,0-6.3328-2.2974-7.4456-6H19V18H9.1321A15.2782,15.2782,0,0,1,9,16c0-.33.01-.6641.0259-1H19V13H9.2371C9.8447,9.3525,11.81,6,17,6c3.8533,0,5.5315,1.6465,7.1282,4.4893l1.7436-.9786C24.2649,6.6484,22.0779,4,17,4,10.6448,4,7,8.374,7,16c0,7.0654,4.1121,12,10,12,5.0779,0,7.2649-2.6484,8.8718-5.5107l-1.7436-.9786C22.5315,24.3535,20.8533,26,17,26Z"
  })), children);
});
var CurrencyEuro24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyEuro24(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,26c-3.6162,0-6.3328-2.2974-7.4456-6H19V18H9.1321A15.2782,15.2782,0,0,1,9,16c0-.33.01-.6641.0259-1H19V13H9.2371C9.8447,9.3525,11.81,6,17,6c3.8533,0,5.5315,1.6465,7.1282,4.4893l1.7436-.9786C24.2649,6.6484,22.0779,4,17,4,10.6448,4,7,8.374,7,16c0,7.0654,4.1121,12,10,12,5.0779,0,7.2649-2.6484,8.8718-5.5107l-1.7436-.9786C22.5315,24.3535,20.8533,26,17,26Z"
  })), children);
});
var CurrencyEuro20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyEuro20(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,26c-3.6162,0-6.3328-2.2974-7.4456-6H19V18H9.1321A15.2782,15.2782,0,0,1,9,16c0-.33.01-.6641.0259-1H19V13H9.2371C9.8447,9.3525,11.81,6,17,6c3.8533,0,5.5315,1.6465,7.1282,4.4893l1.7436-.9786C24.2649,6.6484,22.0779,4,17,4,10.6448,4,7,8.374,7,16c0,7.0654,4.1121,12,10,12,5.0779,0,7.2649-2.6484,8.8718-5.5107l-1.7436-.9786C22.5315,24.3535,20.8533,26,17,26Z"
  })), children);
});
var CurrencyEuro16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyEuro16(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,26c-3.6162,0-6.3328-2.2974-7.4456-6H19V18H9.1321A15.2782,15.2782,0,0,1,9,16c0-.33.01-.6641.0259-1H19V13H9.2371C9.8447,9.3525,11.81,6,17,6c3.8533,0,5.5315,1.6465,7.1282,4.4893l1.7436-.9786C24.2649,6.6484,22.0779,4,17,4,10.6448,4,7,8.374,7,16c0,7.0654,4.1121,12,10,12,5.0779,0,7.2649-2.6484,8.8718-5.5107l-1.7436-.9786C22.5315,24.3535,20.8533,26,17,26Z"
  })), children);
});
var CurrencyLira32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyLira32(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,19a6.0066,6.0066,0,0,1-6,6H13V18.1079L21.2139,15V13L13,16.1079v-3L21.2139,10V8L13,11.1079V5H11v6.8647L8,13v2l3-1.1353v3L8,18v2l3-1.1353V27h6a8.0092,8.0092,0,0,0,8-8Z"
  })), children);
});
var CurrencyLira24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyLira24(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,19a6.0066,6.0066,0,0,1-6,6H13V18.1079L21.2139,15V13L13,16.1079v-3L21.2139,10V8L13,11.1079V5H11v6.8647L8,13v2l3-1.1353v3L8,18v2l3-1.1353V27h6a8.0092,8.0092,0,0,0,8-8Z"
  })), children);
});
var CurrencyLira20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyLira20(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,19a6.0066,6.0066,0,0,1-6,6H13V18.1079L21.2139,15V13L13,16.1079v-3L21.2139,10V8L13,11.1079V5H11v6.8647L8,13v2l3-1.1353v3L8,18v2l3-1.1353V27h6a8.0092,8.0092,0,0,0,8-8Z"
  })), children);
});
var CurrencyLira16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyLira16(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,19a6.0066,6.0066,0,0,1-6,6H13V18.1079L21.2139,15V13L13,16.1079v-3L21.2139,10V8L13,11.1079V5H11v6.8647L8,13v2l3-1.1353v3L8,18v2l3-1.1353V27h6a8.0092,8.0092,0,0,0,8-8Z"
  })), children);
});
var CurrencyPound32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyPound32(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.4531,25A8.7775,8.7775,0,0,0,14,20a10.6,10.6,0,0,0-.18-2H22V16H13.2175c-.0842-.2109-.17-.4194-.2556-.624A9.8586,9.8586,0,0,1,12,11a4.792,4.792,0,0,1,5-5,6.1234,6.1234,0,0,1,5.2222,2.6279l1.5556-1.2558A8.11,8.11,0,0,0,17,4a6.7781,6.7781,0,0,0-7,7,11.65,11.65,0,0,0,1.0559,5H8v2h3.7729A8.209,8.209,0,0,1,12,20c0,2.5234-1.4858,5-3,5v2H24V25Z"
  })), children);
});
var CurrencyPound24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyPound24(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.4531,25A8.7775,8.7775,0,0,0,14,20a10.6,10.6,0,0,0-.18-2H22V16H13.2175c-.0842-.2109-.17-.4194-.2556-.624A9.8586,9.8586,0,0,1,12,11a4.792,4.792,0,0,1,5-5,6.1234,6.1234,0,0,1,5.2222,2.6279l1.5556-1.2558A8.11,8.11,0,0,0,17,4a6.7781,6.7781,0,0,0-7,7,11.65,11.65,0,0,0,1.0559,5H8v2h3.7729A8.209,8.209,0,0,1,12,20c0,2.5234-1.4858,5-3,5v2H24V25Z"
  })), children);
});
var CurrencyPound20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyPound20(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.4531,25A8.7775,8.7775,0,0,0,14,20a10.6,10.6,0,0,0-.18-2H22V16H13.2175c-.0842-.2109-.17-.4194-.2556-.624A9.8586,9.8586,0,0,1,12,11a4.792,4.792,0,0,1,5-5,6.1234,6.1234,0,0,1,5.2222,2.6279l1.5556-1.2558A8.11,8.11,0,0,0,17,4a6.7781,6.7781,0,0,0-7,7,11.65,11.65,0,0,0,1.0559,5H8v2h3.7729A8.209,8.209,0,0,1,12,20c0,2.5234-1.4858,5-3,5v2H24V25Z"
  })), children);
});
var CurrencyPound16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyPound16(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12.4531,25A8.7775,8.7775,0,0,0,14,20a10.6,10.6,0,0,0-.18-2H22V16H13.2175c-.0842-.2109-.17-.4194-.2556-.624A9.8586,9.8586,0,0,1,12,11a4.792,4.792,0,0,1,5-5,6.1234,6.1234,0,0,1,5.2222,2.6279l1.5556-1.2558A8.11,8.11,0,0,0,17,4a6.7781,6.7781,0,0,0-7,7,11.65,11.65,0,0,0,1.0559,5H8v2h3.7729A8.209,8.209,0,0,1,12,20c0,2.5234-1.4858,5-3,5v2H24V25Z"
  })), children);
});
var CurrencyRuble32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyRuble32(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,4H10V15H7v2h3v3H7v2h3v6h2V22h9V20H12V17h7a6.0067,6.0067,0,0,0,6-6V10A6.0067,6.0067,0,0,0,19,4Zm4,7a4.0045,4.0045,0,0,1-4,4H12V6h7a4.0045,4.0045,0,0,1,4,4Z"
  })), children);
});
var CurrencyRuble24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyRuble24(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,4H10V15H7v2h3v3H7v2h3v6h2V22h9V20H12V17h7a6.0067,6.0067,0,0,0,6-6V10A6.0067,6.0067,0,0,0,19,4Zm4,7a4.0045,4.0045,0,0,1-4,4H12V6h7a4.0045,4.0045,0,0,1,4,4Z"
  })), children);
});
var CurrencyRuble20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyRuble20(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,4H10V15H7v2h3v3H7v2h3v6h2V22h9V20H12V17h7a6.0067,6.0067,0,0,0,6-6V10A6.0067,6.0067,0,0,0,19,4Zm4,7a4.0045,4.0045,0,0,1-4,4H12V6h7a4.0045,4.0045,0,0,1,4,4Z"
  })), children);
});
var CurrencyRuble16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyRuble16(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,4H10V15H7v2h3v3H7v2h3v6h2V22h9V20H12V17h7a6.0067,6.0067,0,0,0,6-6V10A6.0067,6.0067,0,0,0,19,4Zm4,7a4.0045,4.0045,0,0,1-4,4H12V6h7a4.0045,4.0045,0,0,1,4,4Z"
  })), children);
});
var CurrencyRupee32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyRupee32(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,7V5H8V7h5.5a4.4906,4.4906,0,0,1,4.45,4H8v2h9.95A4.4906,4.4906,0,0,1,13.5,17H8v2.3452L17.6169,28l1.3379-1.4863L10.606,19H13.5a6.5041,6.5041,0,0,0,6.4746-6H24V11H19.9746A6.4719,6.4719,0,0,0,18.18,7Z"
  })), children);
});
var CurrencyRupee24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyRupee24(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,7V5H8V7h5.5a4.4906,4.4906,0,0,1,4.45,4H8v2h9.95A4.4906,4.4906,0,0,1,13.5,17H8v2.3452L17.6169,28l1.3379-1.4863L10.606,19H13.5a6.5041,6.5041,0,0,0,6.4746-6H24V11H19.9746A6.4719,6.4719,0,0,0,18.18,7Z"
  })), children);
});
var CurrencyRupee20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyRupee20(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,7V5H8V7h5.5a4.4906,4.4906,0,0,1,4.45,4H8v2h9.95A4.4906,4.4906,0,0,1,13.5,17H8v2.3452L17.6169,28l1.3379-1.4863L10.606,19H13.5a6.5041,6.5041,0,0,0,6.4746-6H24V11H19.9746A6.4719,6.4719,0,0,0,18.18,7Z"
  })), children);
});
var CurrencyRupee16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyRupee16(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,7V5H8V7h5.5a4.4906,4.4906,0,0,1,4.45,4H8v2h9.95A4.4906,4.4906,0,0,1,13.5,17H8v2.3452L17.6169,28l1.3379-1.4863L10.606,19H13.5a6.5041,6.5041,0,0,0,6.4746-6H24V11H19.9746A6.4719,6.4719,0,0,0,18.18,7Z"
  })), children);
});
var CurrencyShekel32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyShekel32(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,27H7V5h8a5.0057,5.0057,0,0,1,5,5V22H18V10a3.0033,3.0033,0,0,0-3-3H9Z"
  })), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,27H12V10h2V25h6a3.0033,3.0033,0,0,0,3-3V5h2V22A5.0057,5.0057,0,0,1,20,27Z"
  })), children);
});
var CurrencyShekel24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyShekel24(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,27H7V5h8a5.0057,5.0057,0,0,1,5,5V22H18V10a3.0033,3.0033,0,0,0-3-3H9Z"
  })), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,27H12V10h2V25h6a3.0033,3.0033,0,0,0,3-3V5h2V22A5.0057,5.0057,0,0,1,20,27Z"
  })), children);
});
var CurrencyShekel20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyShekel20(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,27H7V5h8a5.0057,5.0057,0,0,1,5,5V22H18V10a3.0033,3.0033,0,0,0-3-3H9Z"
  })), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,27H12V10h2V25h6a3.0033,3.0033,0,0,0,3-3V5h2V22A5.0057,5.0057,0,0,1,20,27Z"
  })), children);
});
var CurrencyShekel16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyShekel16(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M9,27H7V5h8a5.0057,5.0057,0,0,1,5,5V22H18V10a3.0033,3.0033,0,0,0-3-3H9Z"
  })), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,27H12V10h2V25h6a3.0033,3.0033,0,0,0,3-3V5h2V22A5.0057,5.0057,0,0,1,20,27Z"
  })), children);
});
var CurrencyWon32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyWon32(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 14L28 12 23.045 12 24 5 22 5 20 23 17 8 15 8 12 23 10 5 8 5 8.955 12 4 12 4 14 9.227 14 9.636 17 4 17 4 19 9.909 19 11 27 13 27 16 12 19 27 21 27 22.091 19 28 19 28 17 22.364 17 22.773 14 28 14z"
  })), children);
});
var CurrencyWon24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyWon24(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 14L28 12 23.045 12 24 5 22 5 20 23 17 8 15 8 12 23 10 5 8 5 8.955 12 4 12 4 14 9.227 14 9.636 17 4 17 4 19 9.909 19 11 27 13 27 16 12 19 27 21 27 22.091 19 28 19 28 17 22.364 17 22.773 14 28 14z"
  })), children);
});
var CurrencyWon20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyWon20(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 14L28 12 23.045 12 24 5 22 5 20 23 17 8 15 8 12 23 10 5 8 5 8.955 12 4 12 4 14 9.227 14 9.636 17 4 17 4 19 9.909 19 11 27 13 27 16 12 19 27 21 27 22.091 19 28 19 28 17 22.364 17 22.773 14 28 14z"
  })), children);
});
var CurrencyWon16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyWon16(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 14L28 12 23.045 12 24 5 22 5 20 23 17 8 15 8 12 23 10 5 8 5 8.955 12 4 12 4 14 9.227 14 9.636 17 4 17 4 19 9.909 19 11 27 13 27 16 12 19 27 21 27 22.091 19 28 19 28 17 22.364 17 22.773 14 28 14z"
  })), children);
});
var CurrencyYen32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyYen32(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.271 5L22 5 16 16 10 5 7.729 5 13.794 16 8 16 8 18 15 18 15 21 8 21 8 23 15 23 15 27 17 27 17 23 24 23 24 21 17 21 17 18 24 18 24 16 18.206 16 24.271 5z"
  })), children);
});
var CurrencyYen24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyYen24(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.271 5L22 5 16 16 10 5 7.729 5 13.794 16 8 16 8 18 15 18 15 21 8 21 8 23 15 23 15 27 17 27 17 23 24 23 24 21 17 21 17 18 24 18 24 16 18.206 16 24.271 5z"
  })), children);
});
var CurrencyYen20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyYen20(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.271 5L22 5 16 16 10 5 7.729 5 13.794 16 8 16 8 18 15 18 15 21 8 21 8 23 15 23 15 27 17 27 17 23 24 23 24 21 17 21 17 18 24 18 24 16 18.206 16 24.271 5z"
  })), children);
});
var CurrencyYen16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CurrencyYen16(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.271 5L22 5 16 16 10 5 7.729 5 13.794 16 8 16 8 18 15 18 15 21 8 21 8 23 15 23 15 27 17 27 17 23 24 23 24 21 17 21 17 18 24 18 24 16 18.206 16 24.271 5z"
  })), children);
});
var Cursor_132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cursor_132(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,28a1,1,0,0,1-.71-.29l-6.13-6.14-3.33,5a1,1,0,0,1-1,.44,1,1,0,0,1-.81-.7l-6-20A1,1,0,0,1,6.29,5l20,6a1,1,0,0,1,.7.81,1,1,0,0,1-.44,1l-5,3.33,6.14,6.13a1,1,0,0,1,0,1.42l-4,4A1,1,0,0,1,23,28Zm0-2.41L25.59,23l-7.16-7.15,5.25-3.5L7.49,7.49l4.86,16.19,3.5-5.25Z"
  })), children);
});
var Cursor_124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cursor_124(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,28a1,1,0,0,1-.71-.29l-6.13-6.14-3.33,5a1,1,0,0,1-1,.44,1,1,0,0,1-.81-.7l-6-20A1,1,0,0,1,6.29,5l20,6a1,1,0,0,1,.7.81,1,1,0,0,1-.44,1l-5,3.33,6.14,6.13a1,1,0,0,1,0,1.42l-4,4A1,1,0,0,1,23,28Zm0-2.41L25.59,23l-7.16-7.15,5.25-3.5L7.49,7.49l4.86,16.19,3.5-5.25Z"
  })), children);
});
var Cursor_120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cursor_120(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,28a1,1,0,0,1-.71-.29l-6.13-6.14-3.33,5a1,1,0,0,1-1,.44,1,1,0,0,1-.81-.7l-6-20A1,1,0,0,1,6.29,5l20,6a1,1,0,0,1,.7.81,1,1,0,0,1-.44,1l-5,3.33,6.14,6.13a1,1,0,0,1,0,1.42l-4,4A1,1,0,0,1,23,28Zm0-2.41L25.59,23l-7.16-7.15,5.25-3.5L7.49,7.49l4.86,16.19,3.5-5.25Z"
  })), children);
});
var Cursor_116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cursor_116(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,28a1,1,0,0,1-.71-.29l-6.13-6.14-3.33,5a1,1,0,0,1-1,.44,1,1,0,0,1-.81-.7l-6-20A1,1,0,0,1,6.29,5l20,6a1,1,0,0,1,.7.81,1,1,0,0,1-.44,1l-5,3.33,6.14,6.13a1,1,0,0,1,0,1.42l-4,4A1,1,0,0,1,23,28Zm0-2.41L25.59,23l-7.16-7.15,5.25-3.5L7.49,7.49l4.86,16.19,3.5-5.25Z"
  })), children);
});
var Cursor_232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cursor_232(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.34,12.06l-22-8A1,1,0,0,0,4.06,5.34l8,22A1,1,0,0,0,13,28h0a1,1,0,0,0,.93-.63l3.84-9.6,9.6-3.84a1,1,0,0,0,0-1.87Zm-10.71,4h0l-.4.16-.16.4h0L13,24.2,6.67,6.67,24.2,13Z"
  })), children);
});
var Cursor_224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cursor_224(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.34,12.06l-22-8A1,1,0,0,0,4.06,5.34l8,22A1,1,0,0,0,13,28h0a1,1,0,0,0,.93-.63l3.84-9.6,9.6-3.84a1,1,0,0,0,0-1.87Zm-10.71,4h0l-.4.16-.16.4h0L13,24.2,6.67,6.67,24.2,13Z"
  })), children);
});
var Cursor_220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cursor_220(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.34,12.06l-22-8A1,1,0,0,0,4.06,5.34l8,22A1,1,0,0,0,13,28h0a1,1,0,0,0,.93-.63l3.84-9.6,9.6-3.84a1,1,0,0,0,0-1.87Zm-10.71,4h0l-.4.16-.16.4h0L13,24.2,6.67,6.67,24.2,13Z"
  })), children);
});
var Cursor_216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cursor_216(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.34,12.06l-22-8A1,1,0,0,0,4.06,5.34l8,22A1,1,0,0,0,13,28h0a1,1,0,0,0,.93-.63l3.84-9.6,9.6-3.84a1,1,0,0,0,0-1.87Zm-10.71,4h0l-.4.16-.16.4h0L13,24.2,6.67,6.67,24.2,13Z"
  })), children);
});
var Cut32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cut32(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5,19.63,20.24,16l6.26-3.63a5,5,0,0,0-1.21-9.2A5.19,5.19,0,0,0,24,3a5,5,0,0,0-4.33,7.53,5,5,0,0,0,2.39,2.1l-3.82,2.21L4,6.6,3,8.34,16.24,16,3,23.68l1,1.74,14.24-8.26,3.82,2.21a5,5,0,0,0-2.39,2.1A5,5,0,0,0,24,29a5.19,5.19,0,0,0,1.29-.17,5,5,0,0,0,1.21-9.2ZM21.4,9.53a3,3,0,0,1,1.1-4.12,3,3,0,0,1,4.1,1.11,3,3,0,0,1-1.1,4.11h0A3,3,0,0,1,21.4,9.53Zm5.2,16a3,3,0,0,1-4.1,1.11,3,3,0,0,1-1.1-4.12,3,3,0,0,1,4.1-1.1h0A3,3,0,0,1,26.6,25.48Z"
  })), children);
});
var Cut24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cut24(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5,19.63,20.24,16l6.26-3.63a5,5,0,0,0-1.21-9.2A5.19,5.19,0,0,0,24,3a5,5,0,0,0-4.33,7.53,5,5,0,0,0,2.39,2.1l-3.82,2.21L4,6.6,3,8.34,16.24,16,3,23.68l1,1.74,14.24-8.26,3.82,2.21a5,5,0,0,0-2.39,2.1A5,5,0,0,0,24,29a5.19,5.19,0,0,0,1.29-.17,5,5,0,0,0,1.21-9.2ZM21.4,9.53a3,3,0,0,1,1.1-4.12,3,3,0,0,1,4.1,1.11,3,3,0,0,1-1.1,4.11h0A3,3,0,0,1,21.4,9.53Zm5.2,16a3,3,0,0,1-4.1,1.11,3,3,0,0,1-1.1-4.12,3,3,0,0,1,4.1-1.1h0A3,3,0,0,1,26.6,25.48Z"
  })), children);
});
var Cut20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cut20(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5,19.63,20.24,16l6.26-3.63a5,5,0,0,0-1.21-9.2A5.19,5.19,0,0,0,24,3a5,5,0,0,0-4.33,7.53,5,5,0,0,0,2.39,2.1l-3.82,2.21L4,6.6,3,8.34,16.24,16,3,23.68l1,1.74,14.24-8.26,3.82,2.21a5,5,0,0,0-2.39,2.1A5,5,0,0,0,24,29a5.19,5.19,0,0,0,1.29-.17,5,5,0,0,0,1.21-9.2ZM21.4,9.53a3,3,0,0,1,1.1-4.12,3,3,0,0,1,4.1,1.11,3,3,0,0,1-1.1,4.11h0A3,3,0,0,1,21.4,9.53Zm5.2,16a3,3,0,0,1-4.1,1.11,3,3,0,0,1-1.1-4.12,3,3,0,0,1,4.1-1.1h0A3,3,0,0,1,26.6,25.48Z"
  })), children);
});
var Cut16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cut16(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5,19.63,20.24,16l6.26-3.63a5,5,0,0,0-1.21-9.2A5.19,5.19,0,0,0,24,3a5,5,0,0,0-4.33,7.53,5,5,0,0,0,2.39,2.1l-3.82,2.21L4,6.6,3,8.34,16.24,16,3,23.68l1,1.74,14.24-8.26,3.82,2.21a5,5,0,0,0-2.39,2.1A5,5,0,0,0,24,29a5.19,5.19,0,0,0,1.29-.17,5,5,0,0,0,1.21-9.2ZM21.4,9.53a3,3,0,0,1,1.1-4.12,3,3,0,0,1,4.1,1.11,3,3,0,0,1-1.1,4.11h0A3,3,0,0,1,21.4,9.53Zm5.2,16a3,3,0,0,1-4.1,1.11,3,3,0,0,1-1.1-4.12,3,3,0,0,1,4.1-1.1h0A3,3,0,0,1,26.6,25.48Z"
  })), children);
});
var WatsonHealthCutInHalf32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCutInHalf32(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2.0023,2.0023,0,0,0,2,6V26a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V6A2.0023,2.0023,0,0,0,28,4ZM4,6H16V26H4Z"
  })), children);
});
var WatsonHealthCutInHalf24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCutInHalf24(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2.0023,2.0023,0,0,0,2,6V26a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V6A2.0023,2.0023,0,0,0,28,4ZM4,6H16V26H4Z"
  })), children);
});
var WatsonHealthCutInHalf20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCutInHalf20(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2.0023,2.0023,0,0,0,2,6V26a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V6A2.0023,2.0023,0,0,0,28,4ZM4,6H16V26H4Z"
  })), children);
});
var WatsonHealthCutInHalf16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthCutInHalf16(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2.0023,2.0023,0,0,0,2,6V26a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V6A2.0023,2.0023,0,0,0,28,4ZM4,6H16V26H4Z"
  })), children);
});
var CutOut32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CutOut32(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.05 13.7326L18.05 12 7.928 17.8457 6.9312 17.27a2.9524 2.9524 0 00.6672-.769A3 3 0 103.5 17.5986l2.428 1.4019L3.5 20.4023a3.0342 3.0342 0 103.4407.3223l.987-.5693L14.5914 24l1-1.7294-5.6634-3.27zM4.0344 15.26a1 1 0 11.4658.6069A.9929.9929 0 014.0344 15.26zM4.9988 22a1 1 0 11-.8645 1.5A1 1 0 014.9988 22zM17 26H21V28H17zM10 26H14V28H10z"
  })), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,28H24V26h4V4H7V8H5V4A2.0023,2.0023,0,0,1,7,2H28a2.0023,2.0023,0,0,1,2,2V26A2.0023,2.0023,0,0,1,28,28Z"
  })), children);
});
var CutOut24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CutOut24(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.05 13.7326L18.05 12 7.928 17.8457 6.9312 17.27a2.9524 2.9524 0 00.6672-.769A3 3 0 103.5 17.5986l2.428 1.4019L3.5 20.4023a3.0342 3.0342 0 103.4407.3223l.987-.5693L14.5914 24l1-1.7294-5.6634-3.27zM4.0344 15.26a1 1 0 11.4658.6069A.9929.9929 0 014.0344 15.26zM4.9988 22a1 1 0 11-.8645 1.5A1 1 0 014.9988 22zM17 26H21V28H17zM10 26H14V28H10z"
  })), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,28H24V26h4V4H7V8H5V4A2.0023,2.0023,0,0,1,7,2H28a2.0023,2.0023,0,0,1,2,2V26A2.0023,2.0023,0,0,1,28,28Z"
  })), children);
});
var CutOut20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CutOut20(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.05 13.7326L18.05 12 7.928 17.8457 6.9312 17.27a2.9524 2.9524 0 00.6672-.769A3 3 0 103.5 17.5986l2.428 1.4019L3.5 20.4023a3.0342 3.0342 0 103.4407.3223l.987-.5693L14.5914 24l1-1.7294-5.6634-3.27zM4.0344 15.26a1 1 0 11.4658.6069A.9929.9929 0 014.0344 15.26zM4.9988 22a1 1 0 11-.8645 1.5A1 1 0 014.9988 22zM17 26H21V28H17zM10 26H14V28H10z"
  })), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,28H24V26h4V4H7V8H5V4A2.0023,2.0023,0,0,1,7,2H28a2.0023,2.0023,0,0,1,2,2V26A2.0023,2.0023,0,0,1,28,28Z"
  })), children);
});
var CutOut16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function CutOut16(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.05 13.7326L18.05 12 7.928 17.8457 6.9312 17.27a2.9524 2.9524 0 00.6672-.769A3 3 0 103.5 17.5986l2.428 1.4019L3.5 20.4023a3.0342 3.0342 0 103.4407.3223l.987-.5693L14.5914 24l1-1.7294-5.6634-3.27zM4.0344 15.26a1 1 0 11.4658.6069A.9929.9929 0 014.0344 15.26zM4.9988 22a1 1 0 11-.8645 1.5A1 1 0 014.9988 22zM17 26H21V28H17zM10 26H14V28H10z"
  })), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,28H24V26h4V4H7V8H5V4A2.0023,2.0023,0,0,1,7,2H28a2.0023,2.0023,0,0,1,2,2V26A2.0023,2.0023,0,0,1,28,28Z"
  })), children);
});
var QCY32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCY32(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 23H10a2 2 0 01-2-2V15a2 2 0 012-2h5v2H10v6h5zM24 9L22 9 20 16 18 9 16 9 19 18 19 23 21 23 21 18 24 9z"
  })), children);
});
var QCY24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCY24(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 23H10a2 2 0 01-2-2V15a2 2 0 012-2h5v2H10v6h5zM24 9L22 9 20 16 18 9 16 9 19 18 19 23 21 23 21 18 24 9z"
  })), children);
});
var QCY20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCY20(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 23H10a2 2 0 01-2-2V15a2 2 0 012-2h5v2H10v6h5zM24 9L22 9 20 16 18 9 16 9 19 18 19 23 21 23 21 18 24 9z"
  })), children);
});
var QCY16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCY16(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 23H10a2 2 0 01-2-2V15a2 2 0 012-2h5v2H10v6h5zM24 9L22 9 20 16 18 9 16 9 19 18 19 23 21 23 21 18 24 9z"
  })), children);
});
var Cyclist32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cyclist32(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 30a6 6 0 116-6A6.0069 6.0069 0 0125 30zm0-10a4 4 0 104 4A4.0045 4.0045 0 0025 20zM7 30a6 6 0 116-6A6.0069 6.0069 0 017 30zM7 20a4 4 0 104 4A4.0045 4.0045 0 007 20z"
  })), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 27H15V20.4139L9.5849 15a2.003 2.003 0 010-2.8292l4.5859-4.5859a2.0024 2.0024 0 012.8286 0L21.414 12H27v1.9993L20.5853 14l-5-5L11 13.5849l6 6zM21.5 8A3.5 3.5 0 1125 4.5 3.5042 3.5042 0 0121.5 8zm0-5A1.5 1.5 0 1023 4.5 1.5017 1.5017 0 0021.5 3z"
  })), children);
});
var Cyclist24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cyclist24(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 30a6 6 0 116-6A6.0069 6.0069 0 0125 30zm0-10a4 4 0 104 4A4.0045 4.0045 0 0025 20zM7 30a6 6 0 116-6A6.0069 6.0069 0 017 30zM7 20a4 4 0 104 4A4.0045 4.0045 0 007 20z"
  })), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 27H15V20.4139L9.5849 15a2.003 2.003 0 010-2.8292l4.5859-4.5859a2.0024 2.0024 0 012.8286 0L21.414 12H27v1.9993L20.5853 14l-5-5L11 13.5849l6 6zM21.5 8A3.5 3.5 0 1125 4.5 3.5042 3.5042 0 0121.5 8zm0-5A1.5 1.5 0 1023 4.5 1.5017 1.5017 0 0021.5 3z"
  })), children);
});
var Cyclist20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cyclist20(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 30a6 6 0 116-6A6.0069 6.0069 0 0125 30zm0-10a4 4 0 104 4A4.0045 4.0045 0 0025 20zM7 30a6 6 0 116-6A6.0069 6.0069 0 017 30zM7 20a4 4 0 104 4A4.0045 4.0045 0 007 20z"
  })), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 27H15V20.4139L9.5849 15a2.003 2.003 0 010-2.8292l4.5859-4.5859a2.0024 2.0024 0 012.8286 0L21.414 12H27v1.9993L20.5853 14l-5-5L11 13.5849l6 6zM21.5 8A3.5 3.5 0 1125 4.5 3.5042 3.5042 0 0121.5 8zm0-5A1.5 1.5 0 1023 4.5 1.5017 1.5017 0 0021.5 3z"
  })), children);
});
var Cyclist16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Cyclist16(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 30a6 6 0 116-6A6.0069 6.0069 0 0125 30zm0-10a4 4 0 104 4A4.0045 4.0045 0 0025 20zM7 30a6 6 0 116-6A6.0069 6.0069 0 017 30zM7 20a4 4 0 104 4A4.0045 4.0045 0 007 20z"
  })), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 27H15V20.4139L9.5849 15a2.003 2.003 0 010-2.8292l4.5859-4.5859a2.0024 2.0024 0 012.8286 0L21.414 12H27v1.9993L20.5853 14l-5-5L11 13.5849l6 6zM21.5 8A3.5 3.5 0 1125 4.5 3.5042 3.5042 0 0121.5 8zm0-5A1.5 1.5 0 1023 4.5 1.5017 1.5017 0 0021.5 3z"
  })), children);
});
var QCZ32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCZ32(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 23H9a2 2 0 01-2-2V15a2 2 0 012-2h5v2H9v6h5zM24 9L16 9 16 11 22 11 16 21 16 23 24 23 24 21 18 21 24 11 24 9z"
  })), children);
});
var QCZ24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCZ24(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 23H9a2 2 0 01-2-2V15a2 2 0 012-2h5v2H9v6h5zM24 9L16 9 16 11 22 11 16 21 16 23 24 23 24 21 18 21 24 11 24 9z"
  })), children);
});
var QCZ20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCZ20(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 23H9a2 2 0 01-2-2V15a2 2 0 012-2h5v2H9v6h5zM24 9L16 9 16 11 22 11 16 21 16 23 24 23 24 21 18 21 24 11 24 9z"
  })), children);
});
var QCZ16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function QCZ16(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 23H9a2 2 0 01-2-2V15a2 2 0 012-2h5v2H9v6h5zM24 9L16 9 16 11 22 11 16 21 16 23 24 23 24 21 18 21 24 11 24 9z"
  })), children);
});
var Dashboard32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Dashboard32(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21H26V26H24zM20 16H22V26H20zM11 26a5.0059 5.0059 0 01-5-5H8a3 3 0 103-3V16a5 5 0 010 10z"
  })), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2.002,2.002,0,0,0,2,4V28a2.0023,2.0023,0,0,0,2,2H28a2.0027,2.0027,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2Zm0,9H14V4H28ZM12,4v7H4V4ZM4,28V13H28.0007l.0013,15Z"
  })), children);
});
var Dashboard24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Dashboard24(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21H26V26H24zM20 16H22V26H20zM11 26a5.0059 5.0059 0 01-5-5H8a3 3 0 103-3V16a5 5 0 010 10z"
  })), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2.002,2.002,0,0,0,2,4V28a2.0023,2.0023,0,0,0,2,2H28a2.0027,2.0027,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2Zm0,9H14V4H28ZM12,4v7H4V4ZM4,28V13H28.0007l.0013,15Z"
  })), children);
});
var Dashboard20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Dashboard20(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21H26V26H24zM20 16H22V26H20zM11 26a5.0059 5.0059 0 01-5-5H8a3 3 0 103-3V16a5 5 0 010 10z"
  })), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2.002,2.002,0,0,0,2,4V28a2.0023,2.0023,0,0,0,2,2H28a2.0027,2.0027,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2Zm0,9H14V4H28ZM12,4v7H4V4ZM4,28V13H28.0007l.0013,15Z"
  })), children);
});
var Dashboard16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Dashboard16(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 21H26V26H24zM20 16H22V26H20zM11 26a5.0059 5.0059 0 01-5-5H8a3 3 0 103-3V16a5 5 0 010 10z"
  })), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2.002,2.002,0,0,0,2,4V28a2.0023,2.0023,0,0,0,2,2H28a2.0027,2.0027,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2Zm0,9H14V4H28ZM12,4v7H4V4ZM4,28V13H28.0007l.0013,15Z"
  })), children);
});
var DashboardReference32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DashboardReference32(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM24 21H26V26H24zM20 16H22V26H20zM16 18H18V26H16z"
  })), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2.002,2.002,0,0,0,2,4V16H4V13H28.001l.001,15H16v2H28a2.0027,2.0027,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2ZM12,11H4V4h8Zm2,0V4H28l.0007,7Z"
  })), children);
});
var DashboardReference24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DashboardReference24(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM24 21H26V26H24zM20 16H22V26H20zM16 18H18V26H16z"
  })), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2.002,2.002,0,0,0,2,4V16H4V13H28.001l.001,15H16v2H28a2.0027,2.0027,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2ZM12,11H4V4h8Zm2,0V4H28l.0007,7Z"
  })), children);
});
var DashboardReference20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DashboardReference20(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM24 21H26V26H24zM20 16H22V26H20zM16 18H18V26H16z"
  })), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2.002,2.002,0,0,0,2,4V16H4V13H28.001l.001,15H16v2H28a2.0027,2.0027,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2ZM12,11H4V4h8Zm2,0V4H28l.0007,7Z"
  })), children);
});
var DashboardReference16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DashboardReference16(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM24 21H26V26H24zM20 16H22V26H20zM16 18H18V26H16z"
  })), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2.002,2.002,0,0,0,2,4V16H4V13H28.001l.001,15H16v2H28a2.0027,2.0027,0,0,0,2-2V4A2.0023,2.0023,0,0,0,28,2ZM12,11H4V4h8Zm2,0V4H28l.0007,7Z"
  })), children);
});
var Data_132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Data_132(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 6H28V8H15zM15 24H28V26H15zM4 15H17V17H4zM7 11a4 4 0 114-4A4 4 0 017 11zM7 5A2 2 0 109 7 2 2 0 007 5zM7 29a4 4 0 114-4A4 4 0 017 29zm0-6a2 2 0 102 2A2 2 0 007 23zM25 20a4 4 0 114-4A4 4 0 0125 20zm0-6a2 2 0 102 2A2 2 0 0025 14z"
  })), children);
});
var Data_124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Data_124(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 6H28V8H15zM15 24H28V26H15zM4 15H17V17H4zM7 11a4 4 0 114-4A4 4 0 017 11zM7 5A2 2 0 109 7 2 2 0 007 5zM7 29a4 4 0 114-4A4 4 0 017 29zm0-6a2 2 0 102 2A2 2 0 007 23zM25 20a4 4 0 114-4A4 4 0 0125 20zm0-6a2 2 0 102 2A2 2 0 0025 14z"
  })), children);
});
var Data_120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Data_120(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 6H28V8H15zM15 24H28V26H15zM4 15H17V17H4zM7 11a4 4 0 114-4A4 4 0 017 11zM7 5A2 2 0 109 7 2 2 0 007 5zM7 29a4 4 0 114-4A4 4 0 017 29zm0-6a2 2 0 102 2A2 2 0 007 23zM25 20a4 4 0 114-4A4 4 0 0125 20zm0-6a2 2 0 102 2A2 2 0 0025 14z"
  })), children);
});
var Data_116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Data_116(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15 6H28V8H15zM15 24H28V26H15zM4 15H17V17H4zM7 11a4 4 0 114-4A4 4 0 017 11zM7 5A2 2 0 109 7 2 2 0 007 5zM7 29a4 4 0 114-4A4 4 0 017 29zm0-6a2 2 0 102 2A2 2 0 007 23zM25 20a4 4 0 114-4A4 4 0 0125 20zm0-6a2 2 0 102 2A2 2 0 0025 14z"
  })), children);
});
var Data_232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Data_232(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 6H15V8H4zM18 6H28V8H18zM21 12H28V14H21zM11 12H18V14H11zM4 12H8V14H4zM4 18H28V20H4zM4 24H21V26H4zM24 24H28V26H24z"
  })), children);
});
var Data_224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Data_224(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 6H15V8H4zM18 6H28V8H18zM21 12H28V14H21zM11 12H18V14H11zM4 12H8V14H4zM4 18H28V20H4zM4 24H21V26H4zM24 24H28V26H24z"
  })), children);
});
var Data_220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Data_220(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 6H15V8H4zM18 6H28V8H18zM21 12H28V14H21zM11 12H18V14H11zM4 12H8V14H4zM4 18H28V20H4zM4 24H21V26H4zM24 24H28V26H24z"
  })), children);
});
var Data_216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Data_216(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M4 6H15V8H4zM18 6H28V8H18zM21 12H28V14H21zM11 12H18V14H11zM4 12H8V14H4zM4 18H28V20H4zM4 24H21V26H4zM24 24H28V26H24z"
  })), children);
});
var DataBase32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBase32(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,3H8A2,2,0,0,0,6,5V27a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V5A2,2,0,0,0,24,3Zm0,2v6H8V5ZM8,19V13H24v6Zm0,8V21H24v6Z"
  })), _circle45 || (_circle45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "8",
    r: "1"
  })), _circle46 || (_circle46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "16",
    r: "1"
  })), _circle47 || (_circle47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "24",
    r: "1"
  })), children);
});
var DataBase24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBase24(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,3H8A2,2,0,0,0,6,5V27a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V5A2,2,0,0,0,24,3Zm0,2v6H8V5ZM8,19V13H24v6Zm0,8V21H24v6Z"
  })), _circle48 || (_circle48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "8",
    r: "1"
  })), _circle49 || (_circle49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "16",
    r: "1"
  })), _circle50 || (_circle50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "24",
    r: "1"
  })), children);
});
var DataBase20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBase20(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,3H8A2,2,0,0,0,6,5V27a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V5A2,2,0,0,0,24,3Zm0,2v6H8V5ZM8,19V13H24v6Zm0,8V21H24v6Z"
  })), _circle51 || (_circle51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "8",
    r: "1"
  })), _circle52 || (_circle52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "16",
    r: "1"
  })), _circle53 || (_circle53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "24",
    r: "1"
  })), children);
});
var DataBase16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBase16(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,3H8A2,2,0,0,0,6,5V27a2,2,0,0,0,2,2H24a2,2,0,0,0,2-2V5A2,2,0,0,0,24,3Zm0,2v6H8V5ZM8,19V13H24v6Zm0,8V21H24v6Z"
  })), _circle54 || (_circle54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "8",
    r: "1"
  })), _circle55 || (_circle55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "16",
    r: "1"
  })), _circle56 || (_circle56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "24",
    r: "1"
  })), children);
});
var DataBaseAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBaseAlt32(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 8H12V10H7zM7 12H12V14H7zM7 16H12V18H7zM20 8H25V10H20zM20 12H25V14H20zM20 16H25V18H20z"
  })), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2.0023,2.0023,0,0,0,2,6V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V6A2.0023,2.0023,0,0,0,28,4ZM4,6H15V28H4ZM17,28V6H28V28Z"
  })), children);
});
var DataBaseAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBaseAlt24(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 8H12V10H7zM7 12H12V14H7zM7 16H12V18H7zM20 8H25V10H20zM20 12H25V14H20zM20 16H25V18H20z"
  })), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2.0023,2.0023,0,0,0,2,6V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V6A2.0023,2.0023,0,0,0,28,4ZM4,6H15V28H4ZM17,28V6H28V28Z"
  })), children);
});
var DataBaseAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBaseAlt20(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 8H12V10H7zM7 12H12V14H7zM7 16H12V18H7zM20 8H25V10H20zM20 12H25V14H20zM20 16H25V18H20z"
  })), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2.0023,2.0023,0,0,0,2,6V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V6A2.0023,2.0023,0,0,0,28,4ZM4,6H15V28H4ZM17,28V6H28V28Z"
  })), children);
});
var DataBaseAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBaseAlt16(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M7 8H12V10H7zM7 12H12V14H7zM7 16H12V18H7zM20 8H25V10H20zM20 12H25V14H20zM20 16H25V18H20z"
  })), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,4H4A2.0023,2.0023,0,0,0,2,6V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V6A2.0023,2.0023,0,0,0,28,4ZM4,6H15V28H4ZM17,28V6H28V28Z"
  })), children);
});
var DataCenter32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataCenter32(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H23V6a2.0023,2.0023,0,0,0-2-2H11A2.0023,2.0023,0,0,0,9,6v4H4a2.0023,2.0023,0,0,0-2,2V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V12A2.0023,2.0023,0,0,0,28,10ZM4,28V12H9v2H7v2H9v2H7v2H9v2H7v2H9v4Zm17,0H11V6H21Zm7,0H23V24h2V22H23V20h2V18H23V16h2V14H23V12h5Z"
  })), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 8H18V10H14zM14 12H18V14H14zM14 16H18V18H14z"
  })), children);
});
var DataCenter24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataCenter24(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H23V6a2.0023,2.0023,0,0,0-2-2H11A2.0023,2.0023,0,0,0,9,6v4H4a2.0023,2.0023,0,0,0-2,2V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V12A2.0023,2.0023,0,0,0,28,10ZM4,28V12H9v2H7v2H9v2H7v2H9v2H7v2H9v4Zm17,0H11V6H21Zm7,0H23V24h2V22H23V20h2V18H23V16h2V14H23V12h5Z"
  })), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 8H18V10H14zM14 12H18V14H14zM14 16H18V18H14z"
  })), children);
});
var DataCenter20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataCenter20(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H23V6a2.0023,2.0023,0,0,0-2-2H11A2.0023,2.0023,0,0,0,9,6v4H4a2.0023,2.0023,0,0,0-2,2V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V12A2.0023,2.0023,0,0,0,28,10ZM4,28V12H9v2H7v2H9v2H7v2H9v2H7v2H9v4Zm17,0H11V6H21Zm7,0H23V24h2V22H23V20h2V18H23V16h2V14H23V12h5Z"
  })), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 8H18V10H14zM14 12H18V14H14zM14 16H18V18H14z"
  })), children);
});
var DataCenter16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataCenter16(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,10H23V6a2.0023,2.0023,0,0,0-2-2H11A2.0023,2.0023,0,0,0,9,6v4H4a2.0023,2.0023,0,0,0-2,2V28a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V12A2.0023,2.0023,0,0,0,28,10ZM4,28V12H9v2H7v2H9v2H7v2H9v2H7v2H9v4Zm17,0H11V6H21Zm7,0H23V24h2V22H23V20h2V18H23V16h2V14H23V12h5Z"
  })), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M14 8H18V10H14zM14 12H18V14H14zM14 16H18V18H14z"
  })), children);
});
var DataCheck32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataCheck32(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 27.18L20.41 24.59 19 26 23 30 30 23 28.59 21.59 23 27.18z"
  })), _circle57 || (_circle57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "8",
    r: "1"
  })), _circle58 || (_circle58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "16",
    r: "1"
  })), _circle59 || (_circle59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "24",
    r: "1"
  })), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,3H8A2,2,0,0,0,6,5V27a2,2,0,0,0,2,2h8V27H8V21H26V5A2,2,0,0,0,24,3Zm0,16H8V13H24Zm0-8H8V5H24Z"
  })), children);
});
var DataCheck24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataCheck24(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 27.18L20.41 24.59 19 26 23 30 30 23 28.59 21.59 23 27.18z"
  })), _circle60 || (_circle60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "8",
    r: "1"
  })), _circle61 || (_circle61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "16",
    r: "1"
  })), _circle62 || (_circle62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "24",
    r: "1"
  })), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,3H8A2,2,0,0,0,6,5V27a2,2,0,0,0,2,2h8V27H8V21H26V5A2,2,0,0,0,24,3Zm0,16H8V13H24Zm0-8H8V5H24Z"
  })), children);
});
var DataCheck20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataCheck20(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 27.18L20.41 24.59 19 26 23 30 30 23 28.59 21.59 23 27.18z"
  })), _circle63 || (_circle63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "8",
    r: "1"
  })), _circle64 || (_circle64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "16",
    r: "1"
  })), _circle65 || (_circle65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "24",
    r: "1"
  })), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,3H8A2,2,0,0,0,6,5V27a2,2,0,0,0,2,2h8V27H8V21H26V5A2,2,0,0,0,24,3Zm0,16H8V13H24Zm0-8H8V5H24Z"
  })), children);
});
var DataCheck16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataCheck16(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23 27.18L20.41 24.59 19 26 23 30 30 23 28.59 21.59 23 27.18z"
  })), _circle66 || (_circle66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "8",
    r: "1"
  })), _circle67 || (_circle67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "16",
    r: "1"
  })), _circle68 || (_circle68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "24",
    r: "1"
  })), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,3H8A2,2,0,0,0,6,5V27a2,2,0,0,0,2,2h8V27H8V21H26V5A2,2,0,0,0,24,3Zm0,16H8V13H24Zm0-8H8V5H24Z"
  })), children);
});
var DataConnected32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataConnected32(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30L24 30 24 28 28 28 28 4 24 4 24 2 30 2 30 30z"
  })), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.91,19.59a4.51,4.51,0,0,0-2.66-3.24,4.55,4.55,0,0,0-3.5,0,4.94,4.94,0,0,0-.64.35L15.3,13.89a4.53,4.53,0,1,0-1.41,1.41l2.81,2.81a4.48,4.48,0,0,0-.61,3.3,4.51,4.51,0,0,0,2.66,3.24,4.55,4.55,0,0,0,3.5,0,4.51,4.51,0,0,0,2.66-3.24,4.65,4.65,0,0,0,0-1.82ZM11.5,14A2.5,2.5,0,1,1,14,11.5,2.5,2.5,0,0,1,11.5,14Z"
  })), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30L2 30 2 2 8 2 8 4 4 4 4 28 8 28 8 30z"
  })), children);
});
var DataConnected24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataConnected24(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30L24 30 24 28 28 28 28 4 24 4 24 2 30 2 30 30z"
  })), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.91,19.59a4.51,4.51,0,0,0-2.66-3.24,4.55,4.55,0,0,0-3.5,0,4.94,4.94,0,0,0-.64.35L15.3,13.89a4.53,4.53,0,1,0-1.41,1.41l2.81,2.81a4.48,4.48,0,0,0-.61,3.3,4.51,4.51,0,0,0,2.66,3.24,4.55,4.55,0,0,0,3.5,0,4.51,4.51,0,0,0,2.66-3.24,4.65,4.65,0,0,0,0-1.82ZM11.5,14A2.5,2.5,0,1,1,14,11.5,2.5,2.5,0,0,1,11.5,14Z"
  })), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30L2 30 2 2 8 2 8 4 4 4 4 28 8 28 8 30z"
  })), children);
});
var DataConnected20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataConnected20(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30L24 30 24 28 28 28 28 4 24 4 24 2 30 2 30 30z"
  })), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.91,19.59a4.51,4.51,0,0,0-2.66-3.24,4.55,4.55,0,0,0-3.5,0,4.94,4.94,0,0,0-.64.35L15.3,13.89a4.53,4.53,0,1,0-1.41,1.41l2.81,2.81a4.48,4.48,0,0,0-.61,3.3,4.51,4.51,0,0,0,2.66,3.24,4.55,4.55,0,0,0,3.5,0,4.51,4.51,0,0,0,2.66-3.24,4.65,4.65,0,0,0,0-1.82ZM11.5,14A2.5,2.5,0,1,1,14,11.5,2.5,2.5,0,0,1,11.5,14Z"
  })), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30L2 30 2 2 8 2 8 4 4 4 4 28 8 28 8 30z"
  })), children);
});
var DataConnected16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataConnected16(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 30L24 30 24 28 28 28 28 4 24 4 24 2 30 2 30 30z"
  })), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24.91,19.59a4.51,4.51,0,0,0-2.66-3.24,4.55,4.55,0,0,0-3.5,0,4.94,4.94,0,0,0-.64.35L15.3,13.89a4.53,4.53,0,1,0-1.41,1.41l2.81,2.81a4.48,4.48,0,0,0-.61,3.3,4.51,4.51,0,0,0,2.66,3.24,4.55,4.55,0,0,0,3.5,0,4.51,4.51,0,0,0,2.66-3.24,4.65,4.65,0,0,0,0-1.82ZM11.5,14A2.5,2.5,0,1,1,14,11.5,2.5,2.5,0,0,1,11.5,14Z"
  })), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 30L2 30 2 2 8 2 8 4 4 4 4 28 8 28 8 30z"
  })), children);
});
var DataError32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataError32(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle69 || (_circle69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "8",
    r: "1"
  })), _circle70 || (_circle70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "16",
    r: "1"
  })), _circle71 || (_circle71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "24",
    r: "1"
  })), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,3H8A2,2,0,0,0,6,5V27a2,2,0,0,0,2,2H18V27H8V21H26V5A2,2,0,0,0,24,3Zm0,16H8V13H24Zm0-8H8V5H24Z"
  })), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 24.415L27.586 23 25 25.587 22.414 23 21 24.415 23.586 27 21 29.586 22.414 31 25 28.414 27.586 31 29 29.586 26.414 27 29 24.415z"
  })), children);
});
var DataError24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataError24(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle72 || (_circle72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "8",
    r: "1"
  })), _circle73 || (_circle73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "16",
    r: "1"
  })), _circle74 || (_circle74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "24",
    r: "1"
  })), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,3H8A2,2,0,0,0,6,5V27a2,2,0,0,0,2,2H18V27H8V21H26V5A2,2,0,0,0,24,3Zm0,16H8V13H24Zm0-8H8V5H24Z"
  })), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 24.415L27.586 23 25 25.587 22.414 23 21 24.415 23.586 27 21 29.586 22.414 31 25 28.414 27.586 31 29 29.586 26.414 27 29 24.415z"
  })), children);
});
var DataError20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataError20(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle75 || (_circle75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "8",
    r: "1"
  })), _circle76 || (_circle76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "16",
    r: "1"
  })), _circle77 || (_circle77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "24",
    r: "1"
  })), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,3H8A2,2,0,0,0,6,5V27a2,2,0,0,0,2,2H18V27H8V21H26V5A2,2,0,0,0,24,3Zm0,16H8V13H24Zm0-8H8V5H24Z"
  })), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 24.415L27.586 23 25 25.587 22.414 23 21 24.415 23.586 27 21 29.586 22.414 31 25 28.414 27.586 31 29 29.586 26.414 27 29 24.415z"
  })), children);
});
var DataError16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataError16(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle78 || (_circle78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "8",
    r: "1"
  })), _circle79 || (_circle79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "16",
    r: "1"
  })), _circle80 || (_circle80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "24",
    r: "1"
  })), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,3H8A2,2,0,0,0,6,5V27a2,2,0,0,0,2,2H18V27H8V21H26V5A2,2,0,0,0,24,3Zm0,16H8V13H24Zm0-8H8V5H24Z"
  })), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29 24.415L27.586 23 25 25.587 22.414 23 21 24.415 23.586 27 21 29.586 22.414 31 25 28.414 27.586 31 29 29.586 26.414 27 29 24.415z"
  })), children);
});
var DataFormat32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataFormat32(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 11H26V13H18zM6 19H14V21H6zM10 16a4 4 0 114-4A4.0045 4.0045 0 0110 16zm0-6a2 2 0 102 2A2.002 2.002 0 0010 10zM22 24a4 4 0 114-4A4.0045 4.0045 0 0122 24zm0-6a2 2 0 102 2A2.002 2.002 0 0022 18z"
  })), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var DataFormat24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataFormat24(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 11H26V13H18zM6 19H14V21H6zM10 16a4 4 0 114-4A4.0045 4.0045 0 0110 16zm0-6a2 2 0 102 2A2.002 2.002 0 0010 10zM22 24a4 4 0 114-4A4.0045 4.0045 0 0122 24zm0-6a2 2 0 102 2A2.002 2.002 0 0022 18z"
  })), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var DataFormat20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataFormat20(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 11H26V13H18zM6 19H14V21H6zM10 16a4 4 0 114-4A4.0045 4.0045 0 0110 16zm0-6a2 2 0 102 2A2.002 2.002 0 0010 10zM22 24a4 4 0 114-4A4.0045 4.0045 0 0122 24zm0-6a2 2 0 102 2A2.002 2.002 0 0022 18z"
  })), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var DataFormat16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataFormat16(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18 11H26V13H18zM6 19H14V21H6zM10 16a4 4 0 114-4A4.0045 4.0045 0 0110 16zm0-6a2 2 0 102 2A2.002 2.002 0 0010 10zM22 24a4 4 0 114-4A4.0045 4.0045 0 0122 24zm0-6a2 2 0 102 2A2.002 2.002 0 0022 18z"
  })), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), children);
});
var DataReference32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataReference32(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 13L25 4 23 4 23 6 20 6 20 8 23 8 23 13 20 13 20 15 28 15 28 13 25 13zM8.5 6A3.5 3.5 0 115 9.5 3.504 3.504 0 018.5 6m0-2A5.5 5.5 0 1014 9.5 5.5 5.5 0 008.5 4zM23.5 20A3.5 3.5 0 1120 23.5 3.504 3.504 0 0123.5 20m0-2A5.5 5.5 0 1029 23.5 5.5 5.5 0 0023.5 18zM6 19L6 21 9.586 21 4 26.586 5.414 28 11 22.414 11 26 13 26 13 19 6 19z"
  })), children);
});
var DataReference24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataReference24(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 13L25 4 23 4 23 6 20 6 20 8 23 8 23 13 20 13 20 15 28 15 28 13 25 13zM8.5 6A3.5 3.5 0 115 9.5 3.504 3.504 0 018.5 6m0-2A5.5 5.5 0 1014 9.5 5.5 5.5 0 008.5 4zM23.5 20A3.5 3.5 0 1120 23.5 3.504 3.504 0 0123.5 20m0-2A5.5 5.5 0 1029 23.5 5.5 5.5 0 0023.5 18zM6 19L6 21 9.586 21 4 26.586 5.414 28 11 22.414 11 26 13 26 13 19 6 19z"
  })), children);
});
var DataReference20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataReference20(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 13L25 4 23 4 23 6 20 6 20 8 23 8 23 13 20 13 20 15 28 15 28 13 25 13zM8.5 6A3.5 3.5 0 115 9.5 3.504 3.504 0 018.5 6m0-2A5.5 5.5 0 1014 9.5 5.5 5.5 0 008.5 4zM23.5 20A3.5 3.5 0 1120 23.5 3.504 3.504 0 0123.5 20m0-2A5.5 5.5 0 1029 23.5 5.5 5.5 0 0023.5 18zM6 19L6 21 9.586 21 4 26.586 5.414 28 11 22.414 11 26 13 26 13 19 6 19z"
  })), children);
});
var DataReference16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataReference16(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 13L25 4 23 4 23 6 20 6 20 8 23 8 23 13 20 13 20 15 28 15 28 13 25 13zM8.5 6A3.5 3.5 0 115 9.5 3.504 3.504 0 018.5 6m0-2A5.5 5.5 0 1014 9.5 5.5 5.5 0 008.5 4zM23.5 20A3.5 3.5 0 1120 23.5 3.504 3.504 0 0123.5 20m0-2A5.5 5.5 0 1029 23.5 5.5 5.5 0 0023.5 18zM6 19L6 21 9.586 21 4 26.586 5.414 28 11 22.414 11 26 13 26 13 19 6 19z"
  })), children);
});
var DataSet32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataSet32(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 13L25 4 23 4 23 6 20 6 20 8 23 8 23 13 20 13 20 15 28 15 28 13 25 13zM8.5 6A3.5 3.5 0 115 9.5 3.5 3.5 0 018.5 6m0-2A5.5 5.5 0 1014 9.5 5.5 5.5 0 008.5 4zM8.5 20A3.5 3.5 0 115 23.5 3.5 3.5 0 018.5 20m0-2A5.5 5.5 0 1014 23.5 5.5 5.5 0 008.5 18zM23.5 20A3.5 3.5 0 1120 23.5 3.5 3.5 0 0123.5 20m0-2A5.5 5.5 0 1029 23.5 5.5 5.5 0 0023.5 18z"
  })), children);
});
var DataSet24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataSet24(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 13L25 4 23 4 23 6 20 6 20 8 23 8 23 13 20 13 20 15 28 15 28 13 25 13zM8.5 6A3.5 3.5 0 115 9.5 3.5 3.5 0 018.5 6m0-2A5.5 5.5 0 1014 9.5 5.5 5.5 0 008.5 4zM8.5 20A3.5 3.5 0 115 23.5 3.5 3.5 0 018.5 20m0-2A5.5 5.5 0 1014 23.5 5.5 5.5 0 008.5 18zM23.5 20A3.5 3.5 0 1120 23.5 3.5 3.5 0 0123.5 20m0-2A5.5 5.5 0 1029 23.5 5.5 5.5 0 0023.5 18z"
  })), children);
});
var DataSet20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataSet20(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 13L25 4 23 4 23 6 20 6 20 8 23 8 23 13 20 13 20 15 28 15 28 13 25 13zM8.5 6A3.5 3.5 0 115 9.5 3.5 3.5 0 018.5 6m0-2A5.5 5.5 0 1014 9.5 5.5 5.5 0 008.5 4zM8.5 20A3.5 3.5 0 115 23.5 3.5 3.5 0 018.5 20m0-2A5.5 5.5 0 1014 23.5 5.5 5.5 0 008.5 18zM23.5 20A3.5 3.5 0 1120 23.5 3.5 3.5 0 0123.5 20m0-2A5.5 5.5 0 1029 23.5 5.5 5.5 0 0023.5 18z"
  })), children);
});
var DataSet16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataSet16(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25 13L25 4 23 4 23 6 20 6 20 8 23 8 23 13 20 13 20 15 28 15 28 13 25 13zM8.5 6A3.5 3.5 0 115 9.5 3.5 3.5 0 018.5 6m0-2A5.5 5.5 0 1014 9.5 5.5 5.5 0 008.5 4zM8.5 20A3.5 3.5 0 115 23.5 3.5 3.5 0 018.5 20m0-2A5.5 5.5 0 1014 23.5 5.5 5.5 0 008.5 18zM23.5 20A3.5 3.5 0 1120 23.5 3.5 3.5 0 0123.5 20m0-2A5.5 5.5 0 1029 23.5 5.5 5.5 0 0023.5 18z"
  })), children);
});
var DataStructured32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataStructured32(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle81 || (_circle81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "7",
    r: "1"
  })), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.14V18a2,2,0,0,0-2-2H17V12h9a2,2,0,0,0,2-2V4a2,2,0,0,0-2-2H6A2,2,0,0,0,4,4v6a2,2,0,0,0,2,2h9v4H7a2,2,0,0,0-2,2v4.14a4,4,0,1,0,2,0V18h8v4H12v8h8V22H17V18h8v4.14a4,4,0,1,0,2,0ZM8,26a2,2,0,1,1-2-2A2,2,0,0,1,8,26Zm10-2v4H14V24ZM6,10V4H26v6ZM26,28a2,2,0,1,1,2-2A2,2,0,0,1,26,28Z"
  })), children);
});
var DataStructured24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataStructured24(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle82 || (_circle82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "7",
    r: "1"
  })), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.14V18a2,2,0,0,0-2-2H17V12h9a2,2,0,0,0,2-2V4a2,2,0,0,0-2-2H6A2,2,0,0,0,4,4v6a2,2,0,0,0,2,2h9v4H7a2,2,0,0,0-2,2v4.14a4,4,0,1,0,2,0V18h8v4H12v8h8V22H17V18h8v4.14a4,4,0,1,0,2,0ZM8,26a2,2,0,1,1-2-2A2,2,0,0,1,8,26Zm10-2v4H14V24ZM6,10V4H26v6ZM26,28a2,2,0,1,1,2-2A2,2,0,0,1,26,28Z"
  })), children);
});
var DataStructured20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataStructured20(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle83 || (_circle83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "7",
    r: "1"
  })), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.14V18a2,2,0,0,0-2-2H17V12h9a2,2,0,0,0,2-2V4a2,2,0,0,0-2-2H6A2,2,0,0,0,4,4v6a2,2,0,0,0,2,2h9v4H7a2,2,0,0,0-2,2v4.14a4,4,0,1,0,2,0V18h8v4H12v8h8V22H17V18h8v4.14a4,4,0,1,0,2,0ZM8,26a2,2,0,1,1-2-2A2,2,0,0,1,8,26Zm10-2v4H14V24ZM6,10V4H26v6ZM26,28a2,2,0,1,1,2-2A2,2,0,0,1,26,28Z"
  })), children);
});
var DataStructured16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataStructured16(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle84 || (_circle84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "7",
    r: "1"
  })), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.14V18a2,2,0,0,0-2-2H17V12h9a2,2,0,0,0,2-2V4a2,2,0,0,0-2-2H6A2,2,0,0,0,4,4v6a2,2,0,0,0,2,2h9v4H7a2,2,0,0,0-2,2v4.14a4,4,0,1,0,2,0V18h8v4H12v8h8V22H17V18h8v4.14a4,4,0,1,0,2,0ZM8,26a2,2,0,1,1-2-2A2,2,0,0,1,8,26Zm10-2v4H14V24ZM6,10V4H26v6ZM26,28a2,2,0,1,1,2-2A2,2,0,0,1,26,28Z"
  })), children);
});
var DataUnstructured32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataUnstructured32(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 24a2 2 0 11-2 2 2 2 0 012-2m0-2a4 4 0 104 4A4 4 0 006 22zM16 4a2 2 0 11-2 2 2 2 0 012-2m0-2a4 4 0 104 4A4 4 0 0016 2zM26 4a2 2 0 11-2 2 2 2 0 012-2m0-2a4 4 0 104 4A4 4 0 0026 2zM18 24v4H14V24h4m2-2H12v8h8z"
  })), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.14V17a2,2,0,0,0-2-2H7V10h3V2H2v8H5v5a2,2,0,0,0,2,2H25v5.14a4,4,0,1,0,2,0ZM4,4H8V8H4ZM26,28a2,2,0,1,1,2-2A2,2,0,0,1,26,28Z"
  })), children);
});
var DataUnstructured24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataUnstructured24(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 24a2 2 0 11-2 2 2 2 0 012-2m0-2a4 4 0 104 4A4 4 0 006 22zM16 4a2 2 0 11-2 2 2 2 0 012-2m0-2a4 4 0 104 4A4 4 0 0016 2zM26 4a2 2 0 11-2 2 2 2 0 012-2m0-2a4 4 0 104 4A4 4 0 0026 2zM18 24v4H14V24h4m2-2H12v8h8z"
  })), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.14V17a2,2,0,0,0-2-2H7V10h3V2H2v8H5v5a2,2,0,0,0,2,2H25v5.14a4,4,0,1,0,2,0ZM4,4H8V8H4ZM26,28a2,2,0,1,1,2-2A2,2,0,0,1,26,28Z"
  })), children);
});
var DataUnstructured20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataUnstructured20(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 24a2 2 0 11-2 2 2 2 0 012-2m0-2a4 4 0 104 4A4 4 0 006 22zM16 4a2 2 0 11-2 2 2 2 0 012-2m0-2a4 4 0 104 4A4 4 0 0016 2zM26 4a2 2 0 11-2 2 2 2 0 012-2m0-2a4 4 0 104 4A4 4 0 0026 2zM18 24v4H14V24h4m2-2H12v8h8z"
  })), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.14V17a2,2,0,0,0-2-2H7V10h3V2H2v8H5v5a2,2,0,0,0,2,2H25v5.14a4,4,0,1,0,2,0ZM4,4H8V8H4ZM26,28a2,2,0,1,1,2-2A2,2,0,0,1,26,28Z"
  })), children);
});
var DataUnstructured16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataUnstructured16(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M6 24a2 2 0 11-2 2 2 2 0 012-2m0-2a4 4 0 104 4A4 4 0 006 22zM16 4a2 2 0 11-2 2 2 2 0 012-2m0-2a4 4 0 104 4A4 4 0 0016 2zM26 4a2 2 0 11-2 2 2 2 0 012-2m0-2a4 4 0 104 4A4 4 0 0026 2zM18 24v4H14V24h4m2-2H12v8h8z"
  })), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27,22.14V17a2,2,0,0,0-2-2H7V10h3V2H2v8H5v5a2,2,0,0,0,2,2H25v5.14a4,4,0,1,0,2,0ZM4,4H8V8H4ZM26,28a2,2,0,1,1,2-2A2,2,0,0,1,26,28Z"
  })), children);
});
var DataView32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataView32(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle85 || (_circle85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "24",
    r: "2"
  })), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769,23.4785A8.64,8.64,0,0,0,22,18a8.64,8.64,0,0,0-7.7769,5.4785L14,24l.2231.5215A8.64,8.64,0,0,0,22,30a8.64,8.64,0,0,0,7.7769-5.4785L30,24ZM22,28a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,22,28Z"
  })), _circle86 || (_circle86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "8",
    r: "1"
  })), _circle87 || (_circle87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "1"
  })), _circle88 || (_circle88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "24",
    r: "1"
  })), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5,21h7V19H5V13H21v3h2V5a2,2,0,0,0-2-2H5A2,2,0,0,0,3,5V27a2,2,0,0,0,2,2h7V27H5ZM5,5H21v6H5Z"
  })), children);
});
var DataView24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataView24(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle89 || (_circle89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "24",
    r: "2"
  })), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769,23.4785A8.64,8.64,0,0,0,22,18a8.64,8.64,0,0,0-7.7769,5.4785L14,24l.2231.5215A8.64,8.64,0,0,0,22,30a8.64,8.64,0,0,0,7.7769-5.4785L30,24ZM22,28a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,22,28Z"
  })), _circle90 || (_circle90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "8",
    r: "1"
  })), _circle91 || (_circle91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "1"
  })), _circle92 || (_circle92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "24",
    r: "1"
  })), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5,21h7V19H5V13H21v3h2V5a2,2,0,0,0-2-2H5A2,2,0,0,0,3,5V27a2,2,0,0,0,2,2h7V27H5ZM5,5H21v6H5Z"
  })), children);
});
var DataView20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataView20(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle93 || (_circle93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "24",
    r: "2"
  })), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769,23.4785A8.64,8.64,0,0,0,22,18a8.64,8.64,0,0,0-7.7769,5.4785L14,24l.2231.5215A8.64,8.64,0,0,0,22,30a8.64,8.64,0,0,0,7.7769-5.4785L30,24ZM22,28a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,22,28Z"
  })), _circle94 || (_circle94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "8",
    r: "1"
  })), _circle95 || (_circle95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "1"
  })), _circle96 || (_circle96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "24",
    r: "1"
  })), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5,21h7V19H5V13H21v3h2V5a2,2,0,0,0-2-2H5A2,2,0,0,0,3,5V27a2,2,0,0,0,2,2h7V27H5ZM5,5H21v6H5Z"
  })), children);
});
var DataView16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataView16(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle97 || (_circle97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "24",
    r: "2"
  })), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769,23.4785A8.64,8.64,0,0,0,22,18a8.64,8.64,0,0,0-7.7769,5.4785L14,24l.2231.5215A8.64,8.64,0,0,0,22,30a8.64,8.64,0,0,0,7.7769-5.4785L30,24ZM22,28a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,22,28Z"
  })), _circle98 || (_circle98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "8",
    r: "1"
  })), _circle99 || (_circle99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "16",
    r: "1"
  })), _circle100 || (_circle100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "8",
    cy: "24",
    r: "1"
  })), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M5,21h7V19H5V13H21v3h2V5a2,2,0,0,0-2-2H5A2,2,0,0,0,3,5V27a2,2,0,0,0,2,2h7V27H5ZM5,5H21v6H5Z"
  })), children);
});
var DataViewAlt32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataViewAlt32(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle101 || (_circle101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "24",
    r: "2"
  })), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769 23.4785A8.64 8.64 0 0022 18a8.64 8.64 0 00-7.7769 5.4785L14 24l.2231.5215A8.64 8.64 0 0022 30a8.64 8.64 0 007.7769-5.4785L30 24zM22 28a4 4 0 114-4A4.0045 4.0045 0 0122 28zM7 17H12V19H7zM7 12H19V14H7zM7 7H19V9H7z"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,2,4,2A2.0058,2.0058,0,0,0,2,4V28a2.0058,2.0058,0,0,0,2,2h8V28H4V4H22V15h2V4A2.0058,2.0058,0,0,0,22,2Z"
  })), children);
});
var DataViewAlt24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataViewAlt24(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle102 || (_circle102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "24",
    r: "2"
  })), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769 23.4785A8.64 8.64 0 0022 18a8.64 8.64 0 00-7.7769 5.4785L14 24l.2231.5215A8.64 8.64 0 0022 30a8.64 8.64 0 007.7769-5.4785L30 24zM22 28a4 4 0 114-4A4.0045 4.0045 0 0122 28zM7 17H12V19H7zM7 12H19V14H7zM7 7H19V9H7z"
  })), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,2,4,2A2.0058,2.0058,0,0,0,2,4V28a2.0058,2.0058,0,0,0,2,2h8V28H4V4H22V15h2V4A2.0058,2.0058,0,0,0,22,2Z"
  })), children);
});
var DataViewAlt20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataViewAlt20(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle103 || (_circle103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "24",
    r: "2"
  })), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769 23.4785A8.64 8.64 0 0022 18a8.64 8.64 0 00-7.7769 5.4785L14 24l.2231.5215A8.64 8.64 0 0022 30a8.64 8.64 0 007.7769-5.4785L30 24zM22 28a4 4 0 114-4A4.0045 4.0045 0 0122 28zM7 17H12V19H7zM7 12H19V14H7zM7 7H19V9H7z"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,2,4,2A2.0058,2.0058,0,0,0,2,4V28a2.0058,2.0058,0,0,0,2,2h8V28H4V4H22V15h2V4A2.0058,2.0058,0,0,0,22,2Z"
  })), children);
});
var DataViewAlt16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataViewAlt16(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle104 || (_circle104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "24",
    r: "2"
  })), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769 23.4785A8.64 8.64 0 0022 18a8.64 8.64 0 00-7.7769 5.4785L14 24l.2231.5215A8.64 8.64 0 0022 30a8.64 8.64 0 007.7769-5.4785L30 24zM22 28a4 4 0 114-4A4.0045 4.0045 0 0122 28zM7 17H12V19H7zM7 12H19V14H7zM7 7H19V9H7z"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,2,4,2A2.0058,2.0058,0,0,0,2,4V28a2.0058,2.0058,0,0,0,2,2h8V28H4V4H22V15h2V4A2.0058,2.0058,0,0,0,22,2Z"
  })), children);
});
var DataAccessor32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataAccessor32(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H6V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle105 || (_circle105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,13a2.9609,2.9609,0,0,0-1.2854.3008L17.4141,11l2.3-2.3008A2.9609,2.9609,0,0,0,21,9a3,3,0,1,0-3-3,2.9665,2.9665,0,0,0,.3,1.2852L16,9.5859,13.7,7.2852A2.9665,2.9665,0,0,0,14,6a3,3,0,1,0-3,3,2.9609,2.9609,0,0,0,1.2854-.3008L14.5859,11l-2.3005,2.3008A2.9609,2.9609,0,0,0,11,13a3,3,0,1,0,3,3,2.9665,2.9665,0,0,0-.3-1.2852L16,12.4141l2.3,2.3007A2.9665,2.9665,0,0,0,18,16a3,3,0,1,0,3-3Zm0-8a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,21,5ZM10,6a1,1,0,1,1,1,1A1.0009,1.0009,0,0,1,10,6Zm1,11a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,11,17Zm10,0a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,21,17Z"
  })), children);
});
var DataAccessor24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataAccessor24(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H6V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle106 || (_circle106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,13a2.9609,2.9609,0,0,0-1.2854.3008L17.4141,11l2.3-2.3008A2.9609,2.9609,0,0,0,21,9a3,3,0,1,0-3-3,2.9665,2.9665,0,0,0,.3,1.2852L16,9.5859,13.7,7.2852A2.9665,2.9665,0,0,0,14,6a3,3,0,1,0-3,3,2.9609,2.9609,0,0,0,1.2854-.3008L14.5859,11l-2.3005,2.3008A2.9609,2.9609,0,0,0,11,13a3,3,0,1,0,3,3,2.9665,2.9665,0,0,0-.3-1.2852L16,12.4141l2.3,2.3007A2.9665,2.9665,0,0,0,18,16a3,3,0,1,0,3-3Zm0-8a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,21,5ZM10,6a1,1,0,1,1,1,1A1.0009,1.0009,0,0,1,10,6Zm1,11a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,11,17Zm10,0a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,21,17Z"
  })), children);
});
var DataAccessor20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataAccessor20(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H6V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle107 || (_circle107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,13a2.9609,2.9609,0,0,0-1.2854.3008L17.4141,11l2.3-2.3008A2.9609,2.9609,0,0,0,21,9a3,3,0,1,0-3-3,2.9665,2.9665,0,0,0,.3,1.2852L16,9.5859,13.7,7.2852A2.9665,2.9665,0,0,0,14,6a3,3,0,1,0-3,3,2.9609,2.9609,0,0,0,1.2854-.3008L14.5859,11l-2.3005,2.3008A2.9609,2.9609,0,0,0,11,13a3,3,0,1,0,3,3,2.9665,2.9665,0,0,0-.3-1.2852L16,12.4141l2.3,2.3007A2.9665,2.9665,0,0,0,18,16a3,3,0,1,0,3-3Zm0-8a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,21,5ZM10,6a1,1,0,1,1,1,1A1.0009,1.0009,0,0,1,10,6Zm1,11a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,11,17Zm10,0a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,21,17Z"
  })), children);
});
var DataAccessor16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataAccessor16(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,20H26v2h2v6H4V22H6V20H4a2.0024,2.0024,0,0,0-2,2v6a2.0024,2.0024,0,0,0,2,2H28a2.0024,2.0024,0,0,0,2-2V22A2.0024,2.0024,0,0,0,28,20Z"
  })), _circle108 || (_circle108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "25",
    r: "1"
  })), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M21,13a2.9609,2.9609,0,0,0-1.2854.3008L17.4141,11l2.3-2.3008A2.9609,2.9609,0,0,0,21,9a3,3,0,1,0-3-3,2.9665,2.9665,0,0,0,.3,1.2852L16,9.5859,13.7,7.2852A2.9665,2.9665,0,0,0,14,6a3,3,0,1,0-3,3,2.9609,2.9609,0,0,0,1.2854-.3008L14.5859,11l-2.3005,2.3008A2.9609,2.9609,0,0,0,11,13a3,3,0,1,0,3,3,2.9665,2.9665,0,0,0-.3-1.2852L16,12.4141l2.3,2.3007A2.9665,2.9665,0,0,0,18,16a3,3,0,1,0,3-3Zm0-8a1,1,0,1,1-1,1A1.0009,1.0009,0,0,1,21,5ZM10,6a1,1,0,1,1,1,1A1.0009,1.0009,0,0,1,10,6Zm1,11a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,11,17Zm10,0a1,1,0,1,1,1-1A1.0009,1.0009,0,0,1,21,17Z"
  })), children);
});
var DataBackup32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBackup32(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle109 || (_circle109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "7",
    r: "1"
  })), _circle110 || (_circle110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "15",
    r: "1"
  })), _circle111 || (_circle111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "23",
    r: "1"
  })), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,26H4V20h8V18H4V12H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V26a2,2,0,0,0,2,2h8ZM4,4H20v6H4Z"
  })), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,17v2.4131A6.996,6.996,0,1,0,22,30V28a5,5,0,1,1,4.5762-7H24v2h6V17Z"
  })), children);
});
var DataBackup24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBackup24(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle112 || (_circle112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "7",
    r: "1"
  })), _circle113 || (_circle113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "15",
    r: "1"
  })), _circle114 || (_circle114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "23",
    r: "1"
  })), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,26H4V20h8V18H4V12H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V26a2,2,0,0,0,2,2h8ZM4,4H20v6H4Z"
  })), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,17v2.4131A6.996,6.996,0,1,0,22,30V28a5,5,0,1,1,4.5762-7H24v2h6V17Z"
  })), children);
});
var DataBackup20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBackup20(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle115 || (_circle115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "7",
    r: "1"
  })), _circle116 || (_circle116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "15",
    r: "1"
  })), _circle117 || (_circle117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "23",
    r: "1"
  })), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,26H4V20h8V18H4V12H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V26a2,2,0,0,0,2,2h8ZM4,4H20v6H4Z"
  })), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,17v2.4131A6.996,6.996,0,1,0,22,30V28a5,5,0,1,1,4.5762-7H24v2h6V17Z"
  })), children);
});
var DataBackup16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBackup16(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle118 || (_circle118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "7",
    r: "1"
  })), _circle119 || (_circle119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "15",
    r: "1"
  })), _circle120 || (_circle120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "7",
    cy: "23",
    r: "1"
  })), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,26H4V20h8V18H4V12H22V4a2,2,0,0,0-2-2H4A2,2,0,0,0,2,4V26a2,2,0,0,0,2,2h8ZM4,4H20v6H4Z"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,17v2.4131A6.996,6.996,0,1,0,22,30V28a5,5,0,1,1,4.5762-7H24v2h6V17Z"
  })), children);
});
var DataBin32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBin32(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 2H20a2.0023 2.0023 0 00-2 2V28a2.0023 2.0023 0 002 2h8a2.0023 2.0023 0 002-2V4A2.0023 2.0023 0 0028 2zm0 2v7H20V4zm0 9v6H20V13zM20 28V21h8v7zM12 15L10 15 10 13 8 13 8 15 6 15 6 17 8 17 8 19 10 19 10 17 12 17 12 15z"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6V4H10A2.0023,2.0023,0,0,0,8,6V9.08A6.99,6.99,0,0,0,8,22.92V26a2.0023,2.0023,0,0,0,2,2h6V26H10V22.92A6.99,6.99,0,0,0,10,9.08V6ZM14,16a5,5,0,1,1-5-5A5.0059,5.0059,0,0,1,14,16Z"
  })), children);
});
var DataBin24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBin24(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 2H20a2.0023 2.0023 0 00-2 2V28a2.0023 2.0023 0 002 2h8a2.0023 2.0023 0 002-2V4A2.0023 2.0023 0 0028 2zm0 2v7H20V4zm0 9v6H20V13zM20 28V21h8v7zM12 15L10 15 10 13 8 13 8 15 6 15 6 17 8 17 8 19 10 19 10 17 12 17 12 15z"
  })), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6V4H10A2.0023,2.0023,0,0,0,8,6V9.08A6.99,6.99,0,0,0,8,22.92V26a2.0023,2.0023,0,0,0,2,2h6V26H10V22.92A6.99,6.99,0,0,0,10,9.08V6ZM14,16a5,5,0,1,1-5-5A5.0059,5.0059,0,0,1,14,16Z"
  })), children);
});
var DataBin20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBin20(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 2H20a2.0023 2.0023 0 00-2 2V28a2.0023 2.0023 0 002 2h8a2.0023 2.0023 0 002-2V4A2.0023 2.0023 0 0028 2zm0 2v7H20V4zm0 9v6H20V13zM20 28V21h8v7zM12 15L10 15 10 13 8 13 8 15 6 15 6 17 8 17 8 19 10 19 10 17 12 17 12 15z"
  })), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6V4H10A2.0023,2.0023,0,0,0,8,6V9.08A6.99,6.99,0,0,0,8,22.92V26a2.0023,2.0023,0,0,0,2,2h6V26H10V22.92A6.99,6.99,0,0,0,10,9.08V6ZM14,16a5,5,0,1,1-5-5A5.0059,5.0059,0,0,1,14,16Z"
  })), children);
});
var DataBin16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBin16(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 2H20a2.0023 2.0023 0 00-2 2V28a2.0023 2.0023 0 002 2h8a2.0023 2.0023 0 002-2V4A2.0023 2.0023 0 0028 2zm0 2v7H20V4zm0 9v6H20V13zM20 28V21h8v7zM12 15L10 15 10 13 8 13 8 15 6 15 6 17 8 17 8 19 10 19 10 17 12 17 12 15z"
  })), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,6V4H10A2.0023,2.0023,0,0,0,8,6V9.08A6.99,6.99,0,0,0,8,22.92V26a2.0023,2.0023,0,0,0,2,2h6V26H10V22.92A6.99,6.99,0,0,0,10,9.08V6ZM14,16a5,5,0,1,1-5-5A5.0059,5.0059,0,0,1,14,16Z"
  })), children);
});
var DataBlob32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBlob32(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 7H15V14H13zM8 7H10V14H8zM22 14H20a2.0021 2.0021 0 01-2-2V9a2.0021 2.0021 0 012-2h2a2.0021 2.0021 0 012 2v3A2.0021 2.0021 0 0122 14zM20 9v3h2V9zM22 18H24V25H22zM8 18H10V25H8zM17 25H15a2.0021 2.0021 0 01-2-2V20a2.0021 2.0021 0 012-2h2a2.0021 2.0021 0 012 2v3A2.0021 2.0021 0 0117 25zm-2-5v3h2V20z"
  })), children);
});
var DataBlob24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBlob24(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 7H15V14H13zM8 7H10V14H8zM22 14H20a2.0021 2.0021 0 01-2-2V9a2.0021 2.0021 0 012-2h2a2.0021 2.0021 0 012 2v3A2.0021 2.0021 0 0122 14zM20 9v3h2V9zM22 18H24V25H22zM8 18H10V25H8zM17 25H15a2.0021 2.0021 0 01-2-2V20a2.0021 2.0021 0 012-2h2a2.0021 2.0021 0 012 2v3A2.0021 2.0021 0 0117 25zm-2-5v3h2V20z"
  })), children);
});
var DataBlob20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBlob20(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 7H15V14H13zM8 7H10V14H8zM22 14H20a2.0021 2.0021 0 01-2-2V9a2.0021 2.0021 0 012-2h2a2.0021 2.0021 0 012 2v3A2.0021 2.0021 0 0122 14zM20 9v3h2V9zM22 18H24V25H22zM8 18H10V25H8zM17 25H15a2.0021 2.0021 0 01-2-2V20a2.0021 2.0021 0 012-2h2a2.0021 2.0021 0 012 2v3A2.0021 2.0021 0 0117 25zm-2-5v3h2V20z"
  })), children);
});
var DataBlob16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataBlob16(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2V28A2.0021,2.0021,0,0,1,28,30ZM4,4V28H28V4Z"
  })), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 7H15V14H13zM8 7H10V14H8zM22 14H20a2.0021 2.0021 0 01-2-2V9a2.0021 2.0021 0 012-2h2a2.0021 2.0021 0 012 2v3A2.0021 2.0021 0 0122 14zM20 9v3h2V9zM22 18H24V25H22zM8 18H10V25H8zM17 25H15a2.0021 2.0021 0 01-2-2V20a2.0021 2.0021 0 012-2h2a2.0021 2.0021 0 012 2v3A2.0021 2.0021 0 0117 25zm-2-5v3h2V20z"
  })), children);
});
var DataClass32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataClass32(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,16a3.9612,3.9612,0,0,0-2.02.5657l-2.8586-2.8585,2.293-2.293a2,2,0,0,0,0-2.8284l-6-6a2,2,0,0,0-2.8284,0l-6,6a2,2,0,0,0,0,2.8284l2.293,2.293L8.02,16.5657A4.043,4.043,0,1,0,9.4343,17.98l2.8585-2.8586,2.293,2.293A1.9773,1.9773,0,0,0,15,17.7233V22H12v8h8V22H17V17.7233a1.9773,1.9773,0,0,0,.4142-.3091l2.293-2.293L22.5657,17.98A3.9885,3.9885,0,1,0,26,16ZM8,20a2,2,0,1,1-2-2A2.0023,2.0023,0,0,1,8,20Zm10,4v4H14V24h4Zm-2-8-6-6,6-6,6,6Zm10,6a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,26,22Z"
  })), children);
});
var DataClass24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataClass24(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,16a3.9612,3.9612,0,0,0-2.02.5657l-2.8586-2.8585,2.293-2.293a2,2,0,0,0,0-2.8284l-6-6a2,2,0,0,0-2.8284,0l-6,6a2,2,0,0,0,0,2.8284l2.293,2.293L8.02,16.5657A4.043,4.043,0,1,0,9.4343,17.98l2.8585-2.8586,2.293,2.293A1.9773,1.9773,0,0,0,15,17.7233V22H12v8h8V22H17V17.7233a1.9773,1.9773,0,0,0,.4142-.3091l2.293-2.293L22.5657,17.98A3.9885,3.9885,0,1,0,26,16ZM8,20a2,2,0,1,1-2-2A2.0023,2.0023,0,0,1,8,20Zm10,4v4H14V24h4Zm-2-8-6-6,6-6,6,6Zm10,6a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,26,22Z"
  })), children);
});
var DataClass20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataClass20(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,16a3.9612,3.9612,0,0,0-2.02.5657l-2.8586-2.8585,2.293-2.293a2,2,0,0,0,0-2.8284l-6-6a2,2,0,0,0-2.8284,0l-6,6a2,2,0,0,0,0,2.8284l2.293,2.293L8.02,16.5657A4.043,4.043,0,1,0,9.4343,17.98l2.8585-2.8586,2.293,2.293A1.9773,1.9773,0,0,0,15,17.7233V22H12v8h8V22H17V17.7233a1.9773,1.9773,0,0,0,.4142-.3091l2.293-2.293L22.5657,17.98A3.9885,3.9885,0,1,0,26,16ZM8,20a2,2,0,1,1-2-2A2.0023,2.0023,0,0,1,8,20Zm10,4v4H14V24h4Zm-2-8-6-6,6-6,6,6Zm10,6a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,26,22Z"
  })), children);
});
var DataClass16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataClass16(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,16a3.9612,3.9612,0,0,0-2.02.5657l-2.8586-2.8585,2.293-2.293a2,2,0,0,0,0-2.8284l-6-6a2,2,0,0,0-2.8284,0l-6,6a2,2,0,0,0,0,2.8284l2.293,2.293L8.02,16.5657A4.043,4.043,0,1,0,9.4343,17.98l2.8585-2.8586,2.293,2.293A1.9773,1.9773,0,0,0,15,17.7233V22H12v8h8V22H17V17.7233a1.9773,1.9773,0,0,0,.4142-.3091l2.293-2.293L22.5657,17.98A3.9885,3.9885,0,1,0,26,16ZM8,20a2,2,0,1,1-2-2A2.0023,2.0023,0,0,1,8,20Zm10,4v4H14V24h4Zm-2-8-6-6,6-6,6,6Zm10,6a2,2,0,1,1,2-2A2.0023,2.0023,0,0,1,26,22Z"
  })), children);
});
var DataCollection32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataCollection32(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle121 || (_circle121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 17L30 15 23.83 15 26.41 12.41 25 11 20 16 25 21 26.41 19.59 23.83 17 30 17zM15 23.83L15 30 17 30 17 23.83 19.59 26.41 21 25 16 20 11 25 12.41 26.41 15 23.83zM7 11L5.59 12.41 8.17 15 2 15 2 17 8.17 17 5.59 19.59 7 21 12 16 7 11zM17 8.17L17 2 15 2 15 8.17 12.41 5.59 11 7 16 12 21 7 19.59 5.59 17 8.17z"
  })), children);
});
var DataCollection24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataCollection24(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle122 || (_circle122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 17L30 15 23.83 15 26.41 12.41 25 11 20 16 25 21 26.41 19.59 23.83 17 30 17zM15 23.83L15 30 17 30 17 23.83 19.59 26.41 21 25 16 20 11 25 12.41 26.41 15 23.83zM7 11L5.59 12.41 8.17 15 2 15 2 17 8.17 17 5.59 19.59 7 21 12 16 7 11zM17 8.17L17 2 15 2 15 8.17 12.41 5.59 11 7 16 12 21 7 19.59 5.59 17 8.17z"
  })), children);
});
var DataCollection20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataCollection20(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle123 || (_circle123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 17L30 15 23.83 15 26.41 12.41 25 11 20 16 25 21 26.41 19.59 23.83 17 30 17zM15 23.83L15 30 17 30 17 23.83 19.59 26.41 21 25 16 20 11 25 12.41 26.41 15 23.83zM7 11L5.59 12.41 8.17 15 2 15 2 17 8.17 17 5.59 19.59 7 21 12 16 7 11zM17 8.17L17 2 15 2 15 8.17 12.41 5.59 11 7 16 12 21 7 19.59 5.59 17 8.17z"
  })), children);
});
var DataCollection16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataCollection16(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle124 || (_circle124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "2"
  })), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 17L30 15 23.83 15 26.41 12.41 25 11 20 16 25 21 26.41 19.59 23.83 17 30 17zM15 23.83L15 30 17 30 17 23.83 19.59 26.41 21 25 16 20 11 25 12.41 26.41 15 23.83zM7 11L5.59 12.41 8.17 15 2 15 2 17 8.17 17 5.59 19.59 7 21 12 16 7 11zM17 8.17L17 2 15 2 15 8.17 12.41 5.59 11 7 16 12 21 7 19.59 5.59 17 8.17z"
  })), children);
});
var DataDefinition32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataDefinition32(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle125 || (_circle125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "14",
    r: "2"
  })), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,30a.9967.9967,0,0,1-.707-.293L8.5859,19A2.0126,2.0126,0,0,1,8,17.5859V10a2.002,2.002,0,0,1,2-2h7.5859A1.9864,1.9864,0,0,1,19,8.5859L29.707,19.293a.9994.9994,0,0,1,0,1.414l-9,9A.9967.9967,0,0,1,20,30ZM10,10v7.5859l10,10L27.5859,20l-10-10Z"
  })), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2v8H28V4H4V28h8Z"
  })), children);
});
var DataDefinition24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataDefinition24(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle126 || (_circle126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "14",
    r: "2"
  })), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,30a.9967.9967,0,0,1-.707-.293L8.5859,19A2.0126,2.0126,0,0,1,8,17.5859V10a2.002,2.002,0,0,1,2-2h7.5859A1.9864,1.9864,0,0,1,19,8.5859L29.707,19.293a.9994.9994,0,0,1,0,1.414l-9,9A.9967.9967,0,0,1,20,30ZM10,10v7.5859l10,10L27.5859,20l-10-10Z"
  })), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2v8H28V4H4V28h8Z"
  })), children);
});
var DataDefinition20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataDefinition20(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle127 || (_circle127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "14",
    r: "2"
  })), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,30a.9967.9967,0,0,1-.707-.293L8.5859,19A2.0126,2.0126,0,0,1,8,17.5859V10a2.002,2.002,0,0,1,2-2h7.5859A1.9864,1.9864,0,0,1,19,8.5859L29.707,19.293a.9994.9994,0,0,1,0,1.414l-9,9A.9967.9967,0,0,1,20,30ZM10,10v7.5859l10,10L27.5859,20l-10-10Z"
  })), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2v8H28V4H4V28h8Z"
  })), children);
});
var DataDefinition16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataDefinition16(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle128 || (_circle128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "14",
    cy: "14",
    r: "2"
  })), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20,30a.9967.9967,0,0,1-.707-.293L8.5859,19A2.0126,2.0126,0,0,1,8,17.5859V10a2.002,2.002,0,0,1,2-2h7.5859A1.9864,1.9864,0,0,1,19,8.5859L29.707,19.293a.9994.9994,0,0,1,0,1.414l-9,9A.9967.9967,0,0,1,20,30ZM10,10v7.5859l10,10L27.5859,20l-10-10Z"
  })), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H4a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,4,2H28a2.0021,2.0021,0,0,1,2,2v8H28V4H4V28h8Z"
  })), children);
});
var DataDiode32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataDiode32(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H27V7H25v8H22V7H20v7.8262L7.5239,7.1484A1,1,0,0,0,6,8v7H2v2H6v7a1,1,0,0,0,1.5239.8516L20,17.1738V25h2V17h3v8h2V17h3ZM8,22.21V9.79L18.0918,16Z"
  })), children);
});
var DataDiode24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DataDiode24(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,15H27V7H25v8H22V7H20v7.8262L7.5239,7.1484A1,1,0,0,0,6,8v7H2v2H6v7a1,1,0,0,0,1.5239.8516L20,17.1738V25h2V17h3v8h2V17h3ZM8,22.21V9.79L18.0918,16Z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-9.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/@carbon/icons-react/es/__generated__/bucket-9.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "DirectionLoopRightFilled16": () => (/* binding */ DirectionLoopRightFilled16),
/* harmony export */   "DirectionLoopRightFilled20": () => (/* binding */ DirectionLoopRightFilled20),
/* harmony export */   "DirectionLoopRightFilled24": () => (/* binding */ DirectionLoopRightFilled24),
/* harmony export */   "DirectionLoopRightFilled32": () => (/* binding */ DirectionLoopRightFilled32),
/* harmony export */   "DirectionMerge16": () => (/* binding */ DirectionMerge16),
/* harmony export */   "DirectionMerge20": () => (/* binding */ DirectionMerge20),
/* harmony export */   "DirectionMerge24": () => (/* binding */ DirectionMerge24),
/* harmony export */   "DirectionMerge32": () => (/* binding */ DirectionMerge32),
/* harmony export */   "DirectionMergeFilled16": () => (/* binding */ DirectionMergeFilled16),
/* harmony export */   "DirectionMergeFilled20": () => (/* binding */ DirectionMergeFilled20),
/* harmony export */   "DirectionMergeFilled24": () => (/* binding */ DirectionMergeFilled24),
/* harmony export */   "DirectionMergeFilled32": () => (/* binding */ DirectionMergeFilled32),
/* harmony export */   "DirectionRight_0116": () => (/* binding */ DirectionRight_0116),
/* harmony export */   "DirectionRight_0120": () => (/* binding */ DirectionRight_0120),
/* harmony export */   "DirectionRight_0124": () => (/* binding */ DirectionRight_0124),
/* harmony export */   "DirectionRight_0132": () => (/* binding */ DirectionRight_0132),
/* harmony export */   "DirectionRight_01Filled16": () => (/* binding */ DirectionRight_01Filled16),
/* harmony export */   "DirectionRight_01Filled20": () => (/* binding */ DirectionRight_01Filled20),
/* harmony export */   "DirectionRight_01Filled24": () => (/* binding */ DirectionRight_01Filled24),
/* harmony export */   "DirectionRight_01Filled32": () => (/* binding */ DirectionRight_01Filled32),
/* harmony export */   "DirectionRight_0216": () => (/* binding */ DirectionRight_0216),
/* harmony export */   "DirectionRight_0220": () => (/* binding */ DirectionRight_0220),
/* harmony export */   "DirectionRight_0224": () => (/* binding */ DirectionRight_0224),
/* harmony export */   "DirectionRight_0232": () => (/* binding */ DirectionRight_0232),
/* harmony export */   "DirectionRight_02Filled16": () => (/* binding */ DirectionRight_02Filled16),
/* harmony export */   "DirectionRight_02Filled20": () => (/* binding */ DirectionRight_02Filled20),
/* harmony export */   "DirectionRight_02Filled24": () => (/* binding */ DirectionRight_02Filled24),
/* harmony export */   "DirectionRight_02Filled32": () => (/* binding */ DirectionRight_02Filled32),
/* harmony export */   "DirectionRotaryFirstRight16": () => (/* binding */ DirectionRotaryFirstRight16),
/* harmony export */   "DirectionRotaryFirstRight20": () => (/* binding */ DirectionRotaryFirstRight20),
/* harmony export */   "DirectionRotaryFirstRight24": () => (/* binding */ DirectionRotaryFirstRight24),
/* harmony export */   "DirectionRotaryFirstRight32": () => (/* binding */ DirectionRotaryFirstRight32),
/* harmony export */   "DirectionRotaryFirstRightFilled16": () => (/* binding */ DirectionRotaryFirstRightFilled16),
/* harmony export */   "DirectionRotaryFirstRightFilled20": () => (/* binding */ DirectionRotaryFirstRightFilled20),
/* harmony export */   "DirectionRotaryFirstRightFilled24": () => (/* binding */ DirectionRotaryFirstRightFilled24),
/* harmony export */   "DirectionRotaryFirstRightFilled32": () => (/* binding */ DirectionRotaryFirstRightFilled32),
/* harmony export */   "DirectionRotaryRight16": () => (/* binding */ DirectionRotaryRight16),
/* harmony export */   "DirectionRotaryRight20": () => (/* binding */ DirectionRotaryRight20),
/* harmony export */   "DirectionRotaryRight24": () => (/* binding */ DirectionRotaryRight24),
/* harmony export */   "DirectionRotaryRight32": () => (/* binding */ DirectionRotaryRight32),
/* harmony export */   "DirectionRotaryRightFilled16": () => (/* binding */ DirectionRotaryRightFilled16),
/* harmony export */   "DirectionRotaryRightFilled20": () => (/* binding */ DirectionRotaryRightFilled20),
/* harmony export */   "DirectionRotaryRightFilled24": () => (/* binding */ DirectionRotaryRightFilled24),
/* harmony export */   "DirectionRotaryRightFilled32": () => (/* binding */ DirectionRotaryRightFilled32),
/* harmony export */   "DirectionRotaryStraight16": () => (/* binding */ DirectionRotaryStraight16),
/* harmony export */   "DirectionRotaryStraight20": () => (/* binding */ DirectionRotaryStraight20),
/* harmony export */   "DirectionRotaryStraight24": () => (/* binding */ DirectionRotaryStraight24),
/* harmony export */   "DirectionRotaryStraight32": () => (/* binding */ DirectionRotaryStraight32),
/* harmony export */   "DirectionRotaryStraightFilled16": () => (/* binding */ DirectionRotaryStraightFilled16),
/* harmony export */   "DirectionRotaryStraightFilled20": () => (/* binding */ DirectionRotaryStraightFilled20),
/* harmony export */   "DirectionRotaryStraightFilled24": () => (/* binding */ DirectionRotaryStraightFilled24),
/* harmony export */   "DirectionRotaryStraightFilled32": () => (/* binding */ DirectionRotaryStraightFilled32),
/* harmony export */   "DirectionSharpTurn16": () => (/* binding */ DirectionSharpTurn16),
/* harmony export */   "DirectionSharpTurn20": () => (/* binding */ DirectionSharpTurn20),
/* harmony export */   "DirectionSharpTurn24": () => (/* binding */ DirectionSharpTurn24),
/* harmony export */   "DirectionSharpTurn32": () => (/* binding */ DirectionSharpTurn32),
/* harmony export */   "DirectionSharpTurnFilled16": () => (/* binding */ DirectionSharpTurnFilled16),
/* harmony export */   "DirectionSharpTurnFilled20": () => (/* binding */ DirectionSharpTurnFilled20),
/* harmony export */   "DirectionSharpTurnFilled24": () => (/* binding */ DirectionSharpTurnFilled24),
/* harmony export */   "DirectionSharpTurnFilled32": () => (/* binding */ DirectionSharpTurnFilled32),
/* harmony export */   "DirectionStraight16": () => (/* binding */ DirectionStraight16),
/* harmony export */   "DirectionStraight20": () => (/* binding */ DirectionStraight20),
/* harmony export */   "DirectionStraight24": () => (/* binding */ DirectionStraight24),
/* harmony export */   "DirectionStraight32": () => (/* binding */ DirectionStraight32),
/* harmony export */   "DirectionStraightFilled16": () => (/* binding */ DirectionStraightFilled16),
/* harmony export */   "DirectionStraightFilled20": () => (/* binding */ DirectionStraightFilled20),
/* harmony export */   "DirectionStraightFilled24": () => (/* binding */ DirectionStraightFilled24),
/* harmony export */   "DirectionStraightFilled32": () => (/* binding */ DirectionStraightFilled32),
/* harmony export */   "DirectionStraightRight16": () => (/* binding */ DirectionStraightRight16),
/* harmony export */   "DirectionStraightRight20": () => (/* binding */ DirectionStraightRight20),
/* harmony export */   "DirectionStraightRight24": () => (/* binding */ DirectionStraightRight24),
/* harmony export */   "DirectionStraightRight32": () => (/* binding */ DirectionStraightRight32),
/* harmony export */   "DirectionStraightRightFilled16": () => (/* binding */ DirectionStraightRightFilled16),
/* harmony export */   "DirectionStraightRightFilled20": () => (/* binding */ DirectionStraightRightFilled20),
/* harmony export */   "DirectionStraightRightFilled24": () => (/* binding */ DirectionStraightRightFilled24),
/* harmony export */   "DirectionStraightRightFilled32": () => (/* binding */ DirectionStraightRightFilled32),
/* harmony export */   "DirectionUTurn16": () => (/* binding */ DirectionUTurn16),
/* harmony export */   "DirectionUTurn20": () => (/* binding */ DirectionUTurn20),
/* harmony export */   "DirectionUTurn24": () => (/* binding */ DirectionUTurn24),
/* harmony export */   "DirectionUTurn32": () => (/* binding */ DirectionUTurn32),
/* harmony export */   "DirectionUTurnFilled16": () => (/* binding */ DirectionUTurnFilled16),
/* harmony export */   "DirectionUTurnFilled20": () => (/* binding */ DirectionUTurnFilled20),
/* harmony export */   "DirectionUTurnFilled24": () => (/* binding */ DirectionUTurnFilled24),
/* harmony export */   "DirectionUTurnFilled32": () => (/* binding */ DirectionUTurnFilled32),
/* harmony export */   "DirectoryDomain16": () => (/* binding */ DirectoryDomain16),
/* harmony export */   "DirectoryDomain20": () => (/* binding */ DirectoryDomain20),
/* harmony export */   "DirectoryDomain24": () => (/* binding */ DirectoryDomain24),
/* harmony export */   "DirectoryDomain32": () => (/* binding */ DirectoryDomain32),
/* harmony export */   "DistributeHorizontalCenter16": () => (/* binding */ DistributeHorizontalCenter16),
/* harmony export */   "DistributeHorizontalCenter20": () => (/* binding */ DistributeHorizontalCenter20),
/* harmony export */   "DistributeHorizontalCenter24": () => (/* binding */ DistributeHorizontalCenter24),
/* harmony export */   "DistributeHorizontalCenter32": () => (/* binding */ DistributeHorizontalCenter32),
/* harmony export */   "DistributeHorizontalLeft16": () => (/* binding */ DistributeHorizontalLeft16),
/* harmony export */   "DistributeHorizontalLeft20": () => (/* binding */ DistributeHorizontalLeft20),
/* harmony export */   "DistributeHorizontalLeft24": () => (/* binding */ DistributeHorizontalLeft24),
/* harmony export */   "DistributeHorizontalLeft32": () => (/* binding */ DistributeHorizontalLeft32),
/* harmony export */   "DistributeHorizontalRight16": () => (/* binding */ DistributeHorizontalRight16),
/* harmony export */   "DistributeHorizontalRight20": () => (/* binding */ DistributeHorizontalRight20),
/* harmony export */   "DistributeHorizontalRight24": () => (/* binding */ DistributeHorizontalRight24),
/* harmony export */   "DistributeHorizontalRight32": () => (/* binding */ DistributeHorizontalRight32),
/* harmony export */   "DistributeVerticalBottom16": () => (/* binding */ DistributeVerticalBottom16),
/* harmony export */   "DistributeVerticalBottom20": () => (/* binding */ DistributeVerticalBottom20),
/* harmony export */   "DistributeVerticalBottom24": () => (/* binding */ DistributeVerticalBottom24),
/* harmony export */   "DistributeVerticalBottom32": () => (/* binding */ DistributeVerticalBottom32),
/* harmony export */   "DistributeVerticalCenter16": () => (/* binding */ DistributeVerticalCenter16),
/* harmony export */   "DistributeVerticalCenter20": () => (/* binding */ DistributeVerticalCenter20),
/* harmony export */   "DistributeVerticalCenter24": () => (/* binding */ DistributeVerticalCenter24),
/* harmony export */   "DistributeVerticalCenter32": () => (/* binding */ DistributeVerticalCenter32),
/* harmony export */   "DistributeVerticalTop16": () => (/* binding */ DistributeVerticalTop16),
/* harmony export */   "DistributeVerticalTop20": () => (/* binding */ DistributeVerticalTop20),
/* harmony export */   "DistributeVerticalTop24": () => (/* binding */ DistributeVerticalTop24),
/* harmony export */   "DistributeVerticalTop32": () => (/* binding */ DistributeVerticalTop32),
/* harmony export */   "DnsServices16": () => (/* binding */ DnsServices16),
/* harmony export */   "DnsServices20": () => (/* binding */ DnsServices20),
/* harmony export */   "DnsServices24": () => (/* binding */ DnsServices24),
/* harmony export */   "DnsServices32": () => (/* binding */ DnsServices32),
/* harmony export */   "Doc16": () => (/* binding */ Doc16),
/* harmony export */   "Doc20": () => (/* binding */ Doc20),
/* harmony export */   "Doc24": () => (/* binding */ Doc24),
/* harmony export */   "Doc32": () => (/* binding */ Doc32),
/* harmony export */   "Document16": () => (/* binding */ Document16),
/* harmony export */   "Document20": () => (/* binding */ Document20),
/* harmony export */   "Document24": () => (/* binding */ Document24),
/* harmony export */   "Document32": () => (/* binding */ Document32),
/* harmony export */   "DocumentAdd16": () => (/* binding */ DocumentAdd16),
/* harmony export */   "DocumentAdd20": () => (/* binding */ DocumentAdd20),
/* harmony export */   "DocumentAdd24": () => (/* binding */ DocumentAdd24),
/* harmony export */   "DocumentAdd32": () => (/* binding */ DocumentAdd32),
/* harmony export */   "DocumentAttachment16": () => (/* binding */ DocumentAttachment16),
/* harmony export */   "DocumentAttachment20": () => (/* binding */ DocumentAttachment20),
/* harmony export */   "DocumentAttachment24": () => (/* binding */ DocumentAttachment24),
/* harmony export */   "DocumentAttachment32": () => (/* binding */ DocumentAttachment32),
/* harmony export */   "DocumentAudio16": () => (/* binding */ DocumentAudio16),
/* harmony export */   "DocumentAudio20": () => (/* binding */ DocumentAudio20),
/* harmony export */   "DocumentAudio24": () => (/* binding */ DocumentAudio24),
/* harmony export */   "DocumentAudio32": () => (/* binding */ DocumentAudio32),
/* harmony export */   "DocumentBlank16": () => (/* binding */ DocumentBlank16),
/* harmony export */   "DocumentBlank20": () => (/* binding */ DocumentBlank20),
/* harmony export */   "DocumentBlank24": () => (/* binding */ DocumentBlank24),
/* harmony export */   "DocumentBlank32": () => (/* binding */ DocumentBlank32),
/* harmony export */   "DocumentDownload16": () => (/* binding */ DocumentDownload16),
/* harmony export */   "DocumentDownload20": () => (/* binding */ DocumentDownload20),
/* harmony export */   "DocumentDownload24": () => (/* binding */ DocumentDownload24),
/* harmony export */   "DocumentDownload32": () => (/* binding */ DocumentDownload32),
/* harmony export */   "DocumentEpdf16": () => (/* binding */ DocumentEpdf16),
/* harmony export */   "DocumentEpdf20": () => (/* binding */ DocumentEpdf20),
/* harmony export */   "DocumentEpdf24": () => (/* binding */ DocumentEpdf24),
/* harmony export */   "DocumentEpdf32": () => (/* binding */ DocumentEpdf32),
/* harmony export */   "DocumentExport16": () => (/* binding */ DocumentExport16),
/* harmony export */   "DocumentExport20": () => (/* binding */ DocumentExport20),
/* harmony export */   "DocumentExport24": () => (/* binding */ DocumentExport24),
/* harmony export */   "DocumentExport32": () => (/* binding */ DocumentExport32),
/* harmony export */   "DocumentHorizontal16": () => (/* binding */ DocumentHorizontal16),
/* harmony export */   "DocumentHorizontal20": () => (/* binding */ DocumentHorizontal20),
/* harmony export */   "DocumentHorizontal24": () => (/* binding */ DocumentHorizontal24),
/* harmony export */   "DocumentHorizontal32": () => (/* binding */ DocumentHorizontal32),
/* harmony export */   "DocumentImport16": () => (/* binding */ DocumentImport16),
/* harmony export */   "DocumentImport20": () => (/* binding */ DocumentImport20),
/* harmony export */   "DocumentImport24": () => (/* binding */ DocumentImport24),
/* harmony export */   "DocumentImport32": () => (/* binding */ DocumentImport32),
/* harmony export */   "DocumentPdf16": () => (/* binding */ DocumentPdf16),
/* harmony export */   "DocumentPdf20": () => (/* binding */ DocumentPdf20),
/* harmony export */   "DocumentPdf24": () => (/* binding */ DocumentPdf24),
/* harmony export */   "DocumentPdf32": () => (/* binding */ DocumentPdf32),
/* harmony export */   "DocumentPreliminary16": () => (/* binding */ DocumentPreliminary16),
/* harmony export */   "DocumentPreliminary20": () => (/* binding */ DocumentPreliminary20),
/* harmony export */   "DocumentPreliminary24": () => (/* binding */ DocumentPreliminary24),
/* harmony export */   "DocumentPreliminary32": () => (/* binding */ DocumentPreliminary32),
/* harmony export */   "DocumentProtected16": () => (/* binding */ DocumentProtected16),
/* harmony export */   "DocumentProtected20": () => (/* binding */ DocumentProtected20),
/* harmony export */   "DocumentProtected24": () => (/* binding */ DocumentProtected24),
/* harmony export */   "DocumentProtected32": () => (/* binding */ DocumentProtected32),
/* harmony export */   "DocumentSecurity16": () => (/* binding */ DocumentSecurity16),
/* harmony export */   "DocumentSecurity20": () => (/* binding */ DocumentSecurity20),
/* harmony export */   "DocumentSecurity24": () => (/* binding */ DocumentSecurity24),
/* harmony export */   "DocumentSecurity32": () => (/* binding */ DocumentSecurity32),
/* harmony export */   "DocumentSentiment16": () => (/* binding */ DocumentSentiment16),
/* harmony export */   "DocumentSentiment20": () => (/* binding */ DocumentSentiment20),
/* harmony export */   "DocumentSentiment24": () => (/* binding */ DocumentSentiment24),
/* harmony export */   "DocumentSentiment32": () => (/* binding */ DocumentSentiment32),
/* harmony export */   "DocumentSigned16": () => (/* binding */ DocumentSigned16),
/* harmony export */   "DocumentSigned20": () => (/* binding */ DocumentSigned20),
/* harmony export */   "DocumentSigned24": () => (/* binding */ DocumentSigned24),
/* harmony export */   "DocumentSigned32": () => (/* binding */ DocumentSigned32),
/* harmony export */   "DocumentSketch16": () => (/* binding */ DocumentSketch16),
/* harmony export */   "DocumentSketch20": () => (/* binding */ DocumentSketch20),
/* harmony export */   "DocumentSketch24": () => (/* binding */ DocumentSketch24),
/* harmony export */   "DocumentSketch32": () => (/* binding */ DocumentSketch32),
/* harmony export */   "DocumentSubtract16": () => (/* binding */ DocumentSubtract16),
/* harmony export */   "DocumentSubtract20": () => (/* binding */ DocumentSubtract20),
/* harmony export */   "DocumentSubtract24": () => (/* binding */ DocumentSubtract24),
/* harmony export */   "DocumentSubtract32": () => (/* binding */ DocumentSubtract32),
/* harmony export */   "DocumentTasks16": () => (/* binding */ DocumentTasks16),
/* harmony export */   "DocumentTasks20": () => (/* binding */ DocumentTasks20),
/* harmony export */   "DocumentTasks24": () => (/* binding */ DocumentTasks24),
/* harmony export */   "DocumentTasks32": () => (/* binding */ DocumentTasks32),
/* harmony export */   "DocumentUnknown16": () => (/* binding */ DocumentUnknown16),
/* harmony export */   "DocumentUnknown20": () => (/* binding */ DocumentUnknown20),
/* harmony export */   "DocumentUnknown24": () => (/* binding */ DocumentUnknown24),
/* harmony export */   "DocumentUnknown32": () => (/* binding */ DocumentUnknown32),
/* harmony export */   "DocumentUnprotected16": () => (/* binding */ DocumentUnprotected16),
/* harmony export */   "DocumentUnprotected20": () => (/* binding */ DocumentUnprotected20),
/* harmony export */   "DocumentUnprotected24": () => (/* binding */ DocumentUnprotected24),
/* harmony export */   "DocumentUnprotected32": () => (/* binding */ DocumentUnprotected32),
/* harmony export */   "DocumentVertical16": () => (/* binding */ DocumentVertical16),
/* harmony export */   "DocumentVertical20": () => (/* binding */ DocumentVertical20),
/* harmony export */   "DocumentVertical24": () => (/* binding */ DocumentVertical24),
/* harmony export */   "DocumentVertical32": () => (/* binding */ DocumentVertical32),
/* harmony export */   "DocumentVideo16": () => (/* binding */ DocumentVideo16),
/* harmony export */   "DocumentVideo20": () => (/* binding */ DocumentVideo20),
/* harmony export */   "DocumentVideo24": () => (/* binding */ DocumentVideo24),
/* harmony export */   "DocumentVideo32": () => (/* binding */ DocumentVideo32),
/* harmony export */   "DocumentView16": () => (/* binding */ DocumentView16),
/* harmony export */   "DocumentView20": () => (/* binding */ DocumentView20),
/* harmony export */   "DocumentView24": () => (/* binding */ DocumentView24),
/* harmony export */   "DocumentView32": () => (/* binding */ DocumentView32),
/* harmony export */   "DocumentWordProcessor16": () => (/* binding */ DocumentWordProcessor16),
/* harmony export */   "DocumentWordProcessor20": () => (/* binding */ DocumentWordProcessor20),
/* harmony export */   "DocumentWordProcessor24": () => (/* binding */ DocumentWordProcessor24),
/* harmony export */   "DocumentWordProcessor32": () => (/* binding */ DocumentWordProcessor32),
/* harmony export */   "DocumentWordProcessorReference16": () => (/* binding */ DocumentWordProcessorReference16),
/* harmony export */   "DocumentWordProcessorReference20": () => (/* binding */ DocumentWordProcessorReference20),
/* harmony export */   "DocumentWordProcessorReference24": () => (/* binding */ DocumentWordProcessorReference24),
/* harmony export */   "DocumentWordProcessorReference32": () => (/* binding */ DocumentWordProcessorReference32),
/* harmony export */   "DogWalker16": () => (/* binding */ DogWalker16),
/* harmony export */   "DogWalker20": () => (/* binding */ DogWalker20),
/* harmony export */   "DogWalker24": () => (/* binding */ DogWalker24),
/* harmony export */   "DogWalker32": () => (/* binding */ DogWalker32),
/* harmony export */   "DotMark16": () => (/* binding */ DotMark16),
/* harmony export */   "DotMark20": () => (/* binding */ DotMark20),
/* harmony export */   "DotMark24": () => (/* binding */ DotMark24),
/* harmony export */   "DotMark32": () => (/* binding */ DotMark32),
/* harmony export */   "DoubleInteger16": () => (/* binding */ DoubleInteger16),
/* harmony export */   "DoubleInteger20": () => (/* binding */ DoubleInteger20),
/* harmony export */   "DoubleInteger24": () => (/* binding */ DoubleInteger24),
/* harmony export */   "DoubleInteger32": () => (/* binding */ DoubleInteger32),
/* harmony export */   "DownToBottom16": () => (/* binding */ DownToBottom16),
/* harmony export */   "DownToBottom20": () => (/* binding */ DownToBottom20),
/* harmony export */   "DownToBottom24": () => (/* binding */ DownToBottom24),
/* harmony export */   "DownToBottom32": () => (/* binding */ DownToBottom32),
/* harmony export */   "Download16": () => (/* binding */ Download16),
/* harmony export */   "Download20": () => (/* binding */ Download20),
/* harmony export */   "Download24": () => (/* binding */ Download24),
/* harmony export */   "Download32": () => (/* binding */ Download32),
/* harmony export */   "WatsonHealthDna16": () => (/* binding */ WatsonHealthDna16),
/* harmony export */   "WatsonHealthDna20": () => (/* binding */ WatsonHealthDna20),
/* harmony export */   "WatsonHealthDna24": () => (/* binding */ WatsonHealthDna24),
/* harmony export */   "WatsonHealthDna32": () => (/* binding */ WatsonHealthDna32),
/* harmony export */   "WatsonHealthDownloadStudy24": () => (/* binding */ WatsonHealthDownloadStudy24),
/* harmony export */   "WatsonHealthDownloadStudy32": () => (/* binding */ WatsonHealthDownloadStudy32)
/* harmony export */ });
/* harmony import */ var _Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Icon-9ecdf98c.js */ "../../node_modules/@carbon/icons-react/es/Icon-9ecdf98c.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2019, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Code generated by @carbon/icon-build-helpers. DO NOT EDIT.
 */





var _path, _path2, _path3, _path4, _path5, _path6, _path7, _path8, _path9, _path10, _path11, _path12, _path13, _path14, _path15, _path16, _path17, _path18, _path19, _path20, _path21, _path22, _path23, _path24, _path25, _path26, _path27, _path28, _path29, _path30, _path31, _path32, _path33, _path34, _path35, _path36, _path37, _path38, _path39, _path40, _path41, _path42, _path43, _path44, _path45, _path46, _path47, _path48, _circle, _path49, _path50, _circle2, _path51, _path52, _circle3, _path53, _path54, _circle4, _path55, _path56, _path57, _path58, _path59, _path60, _circle5, _path61, _path62, _circle6, _path63, _path64, _circle7, _path65, _path66, _circle8, _path67, _path68, _path69, _path70, _path71, _path72, _circle9, _path73, _path74, _circle10, _path75, _path76, _circle11, _path77, _path78, _circle12, _path79, _path80, _path81, _path82, _path83, _path84, _path85, _path86, _path87, _path88, _path89, _path90, _path91, _path92, _path93, _path94, _path95, _path96, _path97, _path98, _path99, _path100, _path101, _path102, _path103, _path104, _path105, _path106, _path107, _path108, _path109, _path110, _path111, _path112, _path113, _path114, _path115, _path116, _path117, _path118, _path119, _path120, _path121, _path122, _path123, _path124, _path125, _path126, _path127, _path128, _path129, _path130, _path131, _path132, _path133, _path134, _path135, _path136, _path137, _path138, _path139, _path140, _path141, _path142, _path143, _path144, _path145, _path146, _path147, _path148, _path149, _path150, _path151, _path152, _path153, _path154, _path155, _path156, _path157, _path158, _path159, _path160, _path161, _path162, _path163, _path164, _path165, _path166, _path167, _path168, _path169, _path170, _path171, _path172, _path173, _path174, _path175, _path176, _path177, _path178, _path179, _path180, _path181, _path182, _path183, _path184, _path185, _path186, _path187, _path188, _path189, _path190, _path191, _path192, _path193, _path194, _path195, _path196, _path197, _path198, _path199, _path200, _path201, _path202, _path203, _path204, _path205, _path206, _path207, _path208, _path209, _path210, _path211, _path212, _path213, _path214, _path215, _path216, _path217, _path218, _path219, _path220, _path221, _path222, _path223, _path224, _path225, _path226, _path227, _path228, _path229, _path230, _path231, _path232, _path233, _path234, _path235, _path236, _path237, _path238, _path239, _path240, _path241, _path242, _path243, _path244, _path245, _path246, _path247, _path248, _path249, _path250, _path251, _path252, _path253, _path254, _path255, _path256, _path257, _path258, _path259, _path260, _path261, _path262, _path263, _path264, _path265, _path266, _path267, _path268, _path269, _path270, _path271, _path272, _path273, _path274, _path275, _path276, _path277, _path278, _path279, _path280, _path281, _circle13, _path282, _path283, _path284, _circle14, _path285, _path286, _path287, _circle15, _path288, _path289, _path290, _circle16, _path291, _path292, _path293, _path294, _path295, _path296, _path297, _path298, _path299, _path300, _path301, _path302, _path303, _path304, _path305, _path306, _path307, _path308, _path309, _path310, _path311, _path312, _path313, _path314, _path315, _path316, _circle17, _path317, _path318, _circle18, _path319, _path320, _circle19, _path321, _path322, _circle20, _path323, _path324, _path325, _path326, _path327, _path328, _path329, _path330, _path331, _path332, _path333, _path334, _path335, _path336, _path337, _path338, _path339, _path340, _path341, _path342, _path343, _path344, _path345, _path346, _path347, _path348, _circle21, _path349, _path350, _path351, _circle22, _path352, _path353, _path354, _circle23, _path355, _path356, _path357, _circle24, _path358, _path359, _path360, _path361, _path362, _path363, _path364, _path365, _path366, _path367, _path368, _path369, _path370, _path371, _path372, _path373, _path374, _path375, _path376, _path377, _path378, _path379, _path380, _path381, _path382, _path383, _path384, _path385, _path386, _path387, _path388, _circle25, _circle26, _circle27, _circle28, _path389, _path390, _path391, _path392, _path393, _path394, _path395, _path396, _path397, _path398, _path399, _path400, _path401, _path402, _path403, _path404;

var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["children"],
    _excluded6 = ["children"],
    _excluded7 = ["children"],
    _excluded8 = ["children"],
    _excluded9 = ["children"],
    _excluded10 = ["children"],
    _excluded11 = ["children"],
    _excluded12 = ["children"],
    _excluded13 = ["children"],
    _excluded14 = ["children"],
    _excluded15 = ["children"],
    _excluded16 = ["children"],
    _excluded17 = ["children"],
    _excluded18 = ["children"],
    _excluded19 = ["children"],
    _excluded20 = ["children"],
    _excluded21 = ["children"],
    _excluded22 = ["children"],
    _excluded23 = ["children"],
    _excluded24 = ["children"],
    _excluded25 = ["children"],
    _excluded26 = ["children"],
    _excluded27 = ["children"],
    _excluded28 = ["children"],
    _excluded29 = ["children"],
    _excluded30 = ["children"],
    _excluded31 = ["children"],
    _excluded32 = ["children"],
    _excluded33 = ["children"],
    _excluded34 = ["children"],
    _excluded35 = ["children"],
    _excluded36 = ["children"],
    _excluded37 = ["children"],
    _excluded38 = ["children"],
    _excluded39 = ["children"],
    _excluded40 = ["children"],
    _excluded41 = ["children"],
    _excluded42 = ["children"],
    _excluded43 = ["children"],
    _excluded44 = ["children"],
    _excluded45 = ["children"],
    _excluded46 = ["children"],
    _excluded47 = ["children"],
    _excluded48 = ["children"],
    _excluded49 = ["children"],
    _excluded50 = ["children"],
    _excluded51 = ["children"],
    _excluded52 = ["children"],
    _excluded53 = ["children"],
    _excluded54 = ["children"],
    _excluded55 = ["children"],
    _excluded56 = ["children"],
    _excluded57 = ["children"],
    _excluded58 = ["children"],
    _excluded59 = ["children"],
    _excluded60 = ["children"],
    _excluded61 = ["children"],
    _excluded62 = ["children"],
    _excluded63 = ["children"],
    _excluded64 = ["children"],
    _excluded65 = ["children"],
    _excluded66 = ["children"],
    _excluded67 = ["children"],
    _excluded68 = ["children"],
    _excluded69 = ["children"],
    _excluded70 = ["children"],
    _excluded71 = ["children"],
    _excluded72 = ["children"],
    _excluded73 = ["children"],
    _excluded74 = ["children"],
    _excluded75 = ["children"],
    _excluded76 = ["children"],
    _excluded77 = ["children"],
    _excluded78 = ["children"],
    _excluded79 = ["children"],
    _excluded80 = ["children"],
    _excluded81 = ["children"],
    _excluded82 = ["children"],
    _excluded83 = ["children"],
    _excluded84 = ["children"],
    _excluded85 = ["children"],
    _excluded86 = ["children"],
    _excluded87 = ["children"],
    _excluded88 = ["children"],
    _excluded89 = ["children"],
    _excluded90 = ["children"],
    _excluded91 = ["children"],
    _excluded92 = ["children"],
    _excluded93 = ["children"],
    _excluded94 = ["children"],
    _excluded95 = ["children"],
    _excluded96 = ["children"],
    _excluded97 = ["children"],
    _excluded98 = ["children"],
    _excluded99 = ["children"],
    _excluded100 = ["children"],
    _excluded101 = ["children"],
    _excluded102 = ["children"],
    _excluded103 = ["children"],
    _excluded104 = ["children"],
    _excluded105 = ["children"],
    _excluded106 = ["children"],
    _excluded107 = ["children"],
    _excluded108 = ["children"],
    _excluded109 = ["children"],
    _excluded110 = ["children"],
    _excluded111 = ["children"],
    _excluded112 = ["children"],
    _excluded113 = ["children"],
    _excluded114 = ["children"],
    _excluded115 = ["children"],
    _excluded116 = ["children"],
    _excluded117 = ["children"],
    _excluded118 = ["children"],
    _excluded119 = ["children"],
    _excluded120 = ["children"],
    _excluded121 = ["children"],
    _excluded122 = ["children"],
    _excluded123 = ["children"],
    _excluded124 = ["children"],
    _excluded125 = ["children"],
    _excluded126 = ["children"],
    _excluded127 = ["children"],
    _excluded128 = ["children"],
    _excluded129 = ["children"],
    _excluded130 = ["children"],
    _excluded131 = ["children"],
    _excluded132 = ["children"],
    _excluded133 = ["children"],
    _excluded134 = ["children"],
    _excluded135 = ["children"],
    _excluded136 = ["children"],
    _excluded137 = ["children"],
    _excluded138 = ["children"],
    _excluded139 = ["children"],
    _excluded140 = ["children"],
    _excluded141 = ["children"],
    _excluded142 = ["children"],
    _excluded143 = ["children"],
    _excluded144 = ["children"],
    _excluded145 = ["children"],
    _excluded146 = ["children"],
    _excluded147 = ["children"],
    _excluded148 = ["children"],
    _excluded149 = ["children"],
    _excluded150 = ["children"],
    _excluded151 = ["children"],
    _excluded152 = ["children"],
    _excluded153 = ["children"],
    _excluded154 = ["children"],
    _excluded155 = ["children"],
    _excluded156 = ["children"],
    _excluded157 = ["children"],
    _excluded158 = ["children"],
    _excluded159 = ["children"],
    _excluded160 = ["children"],
    _excluded161 = ["children"],
    _excluded162 = ["children"],
    _excluded163 = ["children"],
    _excluded164 = ["children"],
    _excluded165 = ["children"],
    _excluded166 = ["children"],
    _excluded167 = ["children"],
    _excluded168 = ["children"],
    _excluded169 = ["children"],
    _excluded170 = ["children"],
    _excluded171 = ["children"],
    _excluded172 = ["children"],
    _excluded173 = ["children"],
    _excluded174 = ["children"],
    _excluded175 = ["children"],
    _excluded176 = ["children"],
    _excluded177 = ["children"],
    _excluded178 = ["children"],
    _excluded179 = ["children"],
    _excluded180 = ["children"],
    _excluded181 = ["children"],
    _excluded182 = ["children"],
    _excluded183 = ["children"],
    _excluded184 = ["children"],
    _excluded185 = ["children"],
    _excluded186 = ["children"],
    _excluded187 = ["children"],
    _excluded188 = ["children"],
    _excluded189 = ["children"],
    _excluded190 = ["children"],
    _excluded191 = ["children"],
    _excluded192 = ["children"],
    _excluded193 = ["children"],
    _excluded194 = ["children"],
    _excluded195 = ["children"],
    _excluded196 = ["children"],
    _excluded197 = ["children"],
    _excluded198 = ["children"],
    _excluded199 = ["children"],
    _excluded200 = ["children"],
    _excluded201 = ["children"],
    _excluded202 = ["children"],
    _excluded203 = ["children"],
    _excluded204 = ["children"],
    _excluded205 = ["children"],
    _excluded206 = ["children"],
    _excluded207 = ["children"],
    _excluded208 = ["children"],
    _excluded209 = ["children"],
    _excluded210 = ["children"],
    _excluded211 = ["children"],
    _excluded212 = ["children"],
    _excluded213 = ["children"],
    _excluded214 = ["children"],
    _excluded215 = ["children"],
    _excluded216 = ["children"],
    _excluded217 = ["children"],
    _excluded218 = ["children"],
    _excluded219 = ["children"],
    _excluded220 = ["children"],
    _excluded221 = ["children"],
    _excluded222 = ["children"],
    _excluded223 = ["children"],
    _excluded224 = ["children"],
    _excluded225 = ["children"],
    _excluded226 = ["children"],
    _excluded227 = ["children"],
    _excluded228 = ["children"],
    _excluded229 = ["children"],
    _excluded230 = ["children"],
    _excluded231 = ["children"],
    _excluded232 = ["children"],
    _excluded233 = ["children"],
    _excluded234 = ["children"],
    _excluded235 = ["children"],
    _excluded236 = ["children"],
    _excluded237 = ["children"],
    _excluded238 = ["children"],
    _excluded239 = ["children"],
    _excluded240 = ["children"],
    _excluded241 = ["children"],
    _excluded242 = ["children"],
    _excluded243 = ["children"],
    _excluded244 = ["children"],
    _excluded245 = ["children"],
    _excluded246 = ["children"],
    _excluded247 = ["children"],
    _excluded248 = ["children"],
    _excluded249 = ["children"],
    _excluded250 = ["children"];
var DirectionLoopRightFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionLoopRightFilled32(_ref, ref) {
  var children = _ref.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref, _excluded);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path || (_path = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,26H14V18h2ZM21,8,19.5859,9.4141,24.1719,14H11a3,3,0,1,1,3-3v1h2V11a5,5,0,1,0-5,5H24.1719l-4.586,4.5859L21,22l7-7Z",
    "data-icon-path": "inner-path"
  })), _path2 || (_path2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM16,26H14V18h2Zm5-4-1.4141-1.4141L24.1719,16H11a5,5,0,1,1,5-5v1H14V11a3,3,0,1,0-3,3H24.1719l-4.586-4.5859L21,8l7,7Z"
  })), children);
});
var DirectionLoopRightFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionLoopRightFilled24(_ref2, ref) {
  var children = _ref2.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref2, _excluded2);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path3 || (_path3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,26H14V18h2ZM21,8,19.5859,9.4141,24.1719,14H11a3,3,0,1,1,3-3v1h2V11a5,5,0,1,0-5,5H24.1719l-4.586,4.5859L21,22l7-7Z",
    "data-icon-path": "inner-path"
  })), _path4 || (_path4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM16,26H14V18h2Zm5-4-1.4141-1.4141L24.1719,16H11a5,5,0,1,1,5-5v1H14V11a3,3,0,1,0-3,3H24.1719l-4.586-4.5859L21,8l7,7Z"
  })), children);
});
var DirectionLoopRightFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionLoopRightFilled20(_ref3, ref) {
  var children = _ref3.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref3, _excluded3);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path5 || (_path5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,26H14V18h2ZM21,8,19.5859,9.4141,24.1719,14H11a3,3,0,1,1,3-3v1h2V11a5,5,0,1,0-5,5H24.1719l-4.586,4.5859L21,22l7-7Z",
    "data-icon-path": "inner-path"
  })), _path6 || (_path6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM16,26H14V18h2Zm5-4-1.4141-1.4141L24.1719,16H11a5,5,0,1,1,5-5v1H14V11a3,3,0,1,0-3,3H24.1719l-4.586-4.5859L21,8l7,7Z"
  })), children);
});
var DirectionLoopRightFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionLoopRightFilled16(_ref4, ref) {
  var children = _ref4.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref4, _excluded4);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path7 || (_path7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M16,26H14V18h2ZM21,8,19.5859,9.4141,24.1719,14H11a3,3,0,1,1,3-3v1h2V11a5,5,0,1,0-5,5H24.1719l-4.586,4.5859L21,22l7-7Z",
    "data-icon-path": "inner-path"
  })), _path8 || (_path8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM16,26H14V18h2Zm5-4-1.4141-1.4141L24.1719,16H11a5,5,0,1,1,5-5v1H14V11a3,3,0,1,0-3,3H24.1719l-4.586-4.5859L21,8l7,7Z"
  })), children);
});
var DirectionMerge32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionMerge32(_ref5, ref) {
  var children = _ref5.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref5, _excluded5);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path9 || (_path9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.8784,15.4648A2.9821,2.9821,0,0,1,17,13.3433V7.8281l4.5859,4.586L23,11,16,4,9,11l1.4141,1.4141L15,7.8281v5.5152a2.9805,2.9805,0,0,1-.8784,2.1211l-2.6572,2.6567A4.9682,4.9682,0,0,0,10,21.6567V28h2V21.6567a2.9805,2.9805,0,0,1,.8784-2.1211l2.6572-2.6567A5.0021,5.0021,0,0,0,16,16.3135a5.0021,5.0021,0,0,0,.4644.5654l2.6572,2.6563A2.9821,2.9821,0,0,1,20,21.6567V28h2V21.6567a4.9682,4.9682,0,0,0-1.4644-3.5356Z"
  })), children);
});
var DirectionMerge24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionMerge24(_ref6, ref) {
  var children = _ref6.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref6, _excluded6);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path10 || (_path10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.8784,15.4648A2.9821,2.9821,0,0,1,17,13.3433V7.8281l4.5859,4.586L23,11,16,4,9,11l1.4141,1.4141L15,7.8281v5.5152a2.9805,2.9805,0,0,1-.8784,2.1211l-2.6572,2.6567A4.9682,4.9682,0,0,0,10,21.6567V28h2V21.6567a2.9805,2.9805,0,0,1,.8784-2.1211l2.6572-2.6567A5.0021,5.0021,0,0,0,16,16.3135a5.0021,5.0021,0,0,0,.4644.5654l2.6572,2.6563A2.9821,2.9821,0,0,1,20,21.6567V28h2V21.6567a4.9682,4.9682,0,0,0-1.4644-3.5356Z"
  })), children);
});
var DirectionMerge20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionMerge20(_ref7, ref) {
  var children = _ref7.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref7, _excluded7);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path11 || (_path11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.8784,15.4648A2.9821,2.9821,0,0,1,17,13.3433V7.8281l4.5859,4.586L23,11,16,4,9,11l1.4141,1.4141L15,7.8281v5.5152a2.9805,2.9805,0,0,1-.8784,2.1211l-2.6572,2.6567A4.9682,4.9682,0,0,0,10,21.6567V28h2V21.6567a2.9805,2.9805,0,0,1,.8784-2.1211l2.6572-2.6567A5.0021,5.0021,0,0,0,16,16.3135a5.0021,5.0021,0,0,0,.4644.5654l2.6572,2.6563A2.9821,2.9821,0,0,1,20,21.6567V28h2V21.6567a4.9682,4.9682,0,0,0-1.4644-3.5356Z"
  })), children);
});
var DirectionMerge16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionMerge16(_ref8, ref) {
  var children = _ref8.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref8, _excluded8);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path12 || (_path12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17.8784,15.4648A2.9821,2.9821,0,0,1,17,13.3433V7.8281l4.5859,4.586L23,11,16,4,9,11l1.4141,1.4141L15,7.8281v5.5152a2.9805,2.9805,0,0,1-.8784,2.1211l-2.6572,2.6567A4.9682,4.9682,0,0,0,10,21.6567V28h2V21.6567a2.9805,2.9805,0,0,1,.8784-2.1211l2.6572-2.6567A5.0021,5.0021,0,0,0,16,16.3135a5.0021,5.0021,0,0,0,.4644.5654l2.6572,2.6563A2.9821,2.9821,0,0,1,20,21.6567V28h2V21.6567a4.9682,4.9682,0,0,0-1.4644-3.5356Z"
  })), children);
});
var DirectionMergeFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionMergeFilled32(_ref9, ref) {
  var children = _ref9.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref9, _excluded9);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path13 || (_path13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM17.8784,15.4648l2.6572,2.6563A4.9682,4.9682,0,0,1,22,21.6567V26H20V21.6567a2.9821,2.9821,0,0,0-.8784-2.1215l-2.6572-2.6563A5.0021,5.0021,0,0,1,16,16.3135a5.0021,5.0021,0,0,1-.4644.5654l-2.6572,2.6567A2.9805,2.9805,0,0,0,12,21.6567V26H10V21.6567a4.9682,4.9682,0,0,1,1.4644-3.5356l2.6572-2.6567A2.9805,2.9805,0,0,0,15,13.3433V8.8281l-4.5859,4.586L9,12l7-7,7,7-1.4141,1.4141L17,8.8281v4.5152A2.9821,2.9821,0,0,0,17.8784,15.4648Z"
  })), _path14 || (_path14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M17.8784,15.4648l2.6572,2.6563A4.9682,4.9682,0,0,1,22,21.6567V26H20V21.6567a2.9821,2.9821,0,0,0-.8784-2.1215l-2.6572-2.6563A5.0021,5.0021,0,0,1,16,16.3135a5.0021,5.0021,0,0,1-.4644.5654l-2.6572,2.6567A2.9805,2.9805,0,0,0,12,21.6567V26H10V21.6567a4.9682,4.9682,0,0,1,1.4644-3.5356l2.6572-2.6567A2.9805,2.9805,0,0,0,15,13.3433V8.8281l-4.5859,4.586L9,12l7-7,7,7-1.4141,1.4141L17,8.8281v4.5152A2.9821,2.9821,0,0,0,17.8784,15.4648Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionMergeFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionMergeFilled24(_ref10, ref) {
  var children = _ref10.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref10, _excluded10);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path15 || (_path15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM17.8784,15.4648l2.6572,2.6563A4.9682,4.9682,0,0,1,22,21.6567V26H20V21.6567a2.9821,2.9821,0,0,0-.8784-2.1215l-2.6572-2.6563A5.0021,5.0021,0,0,1,16,16.3135a5.0021,5.0021,0,0,1-.4644.5654l-2.6572,2.6567A2.9805,2.9805,0,0,0,12,21.6567V26H10V21.6567a4.9682,4.9682,0,0,1,1.4644-3.5356l2.6572-2.6567A2.9805,2.9805,0,0,0,15,13.3433V8.8281l-4.5859,4.586L9,12l7-7,7,7-1.4141,1.4141L17,8.8281v4.5152A2.9821,2.9821,0,0,0,17.8784,15.4648Z"
  })), _path16 || (_path16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M17.8784,15.4648l2.6572,2.6563A4.9682,4.9682,0,0,1,22,21.6567V26H20V21.6567a2.9821,2.9821,0,0,0-.8784-2.1215l-2.6572-2.6563A5.0021,5.0021,0,0,1,16,16.3135a5.0021,5.0021,0,0,1-.4644.5654l-2.6572,2.6567A2.9805,2.9805,0,0,0,12,21.6567V26H10V21.6567a4.9682,4.9682,0,0,1,1.4644-3.5356l2.6572-2.6567A2.9805,2.9805,0,0,0,15,13.3433V8.8281l-4.5859,4.586L9,12l7-7,7,7-1.4141,1.4141L17,8.8281v4.5152A2.9821,2.9821,0,0,0,17.8784,15.4648Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionMergeFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionMergeFilled20(_ref11, ref) {
  var children = _ref11.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref11, _excluded11);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path17 || (_path17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM17.8784,15.4648l2.6572,2.6563A4.9682,4.9682,0,0,1,22,21.6567V26H20V21.6567a2.9821,2.9821,0,0,0-.8784-2.1215l-2.6572-2.6563A5.0021,5.0021,0,0,1,16,16.3135a5.0021,5.0021,0,0,1-.4644.5654l-2.6572,2.6567A2.9805,2.9805,0,0,0,12,21.6567V26H10V21.6567a4.9682,4.9682,0,0,1,1.4644-3.5356l2.6572-2.6567A2.9805,2.9805,0,0,0,15,13.3433V8.8281l-4.5859,4.586L9,12l7-7,7,7-1.4141,1.4141L17,8.8281v4.5152A2.9821,2.9821,0,0,0,17.8784,15.4648Z"
  })), _path18 || (_path18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M17.8784,15.4648l2.6572,2.6563A4.9682,4.9682,0,0,1,22,21.6567V26H20V21.6567a2.9821,2.9821,0,0,0-.8784-2.1215l-2.6572-2.6563A5.0021,5.0021,0,0,1,16,16.3135a5.0021,5.0021,0,0,1-.4644.5654l-2.6572,2.6567A2.9805,2.9805,0,0,0,12,21.6567V26H10V21.6567a4.9682,4.9682,0,0,1,1.4644-3.5356l2.6572-2.6567A2.9805,2.9805,0,0,0,15,13.3433V8.8281l-4.5859,4.586L9,12l7-7,7,7-1.4141,1.4141L17,8.8281v4.5152A2.9821,2.9821,0,0,0,17.8784,15.4648Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionMergeFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionMergeFilled16(_ref12, ref) {
  var children = _ref12.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref12, _excluded12);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path19 || (_path19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM17.8784,15.4648l2.6572,2.6563A4.9682,4.9682,0,0,1,22,21.6567V26H20V21.6567a2.9821,2.9821,0,0,0-.8784-2.1215l-2.6572-2.6563A5.0021,5.0021,0,0,1,16,16.3135a5.0021,5.0021,0,0,1-.4644.5654l-2.6572,2.6567A2.9805,2.9805,0,0,0,12,21.6567V26H10V21.6567a4.9682,4.9682,0,0,1,1.4644-3.5356l2.6572-2.6567A2.9805,2.9805,0,0,0,15,13.3433V8.8281l-4.5859,4.586L9,12l7-7,7,7-1.4141,1.4141L17,8.8281v4.5152A2.9821,2.9821,0,0,0,17.8784,15.4648Z"
  })), _path20 || (_path20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M17.8784,15.4648l2.6572,2.6563A4.9682,4.9682,0,0,1,22,21.6567V26H20V21.6567a2.9821,2.9821,0,0,0-.8784-2.1215l-2.6572-2.6563A5.0021,5.0021,0,0,1,16,16.3135a5.0021,5.0021,0,0,1-.4644.5654l-2.6572,2.6567A2.9805,2.9805,0,0,0,12,21.6567V26H10V21.6567a4.9682,4.9682,0,0,1,1.4644-3.5356l2.6572-2.6567A2.9805,2.9805,0,0,0,15,13.3433V8.8281l-4.5859,4.586L9,12l7-7,7,7-1.4141,1.4141L17,8.8281v4.5152A2.9821,2.9821,0,0,0,17.8784,15.4648Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRight_0132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRight_0132(_ref13, ref) {
  var children = _ref13.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref13, _excluded13);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path21 || (_path21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,4,17.5859,5.4141,22.1719,10H10a2,2,0,0,0-2,2V28h2V12H22.1719l-4.586,4.5859L19,18l7-7Z"
  })), children);
});
var DirectionRight_0124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRight_0124(_ref14, ref) {
  var children = _ref14.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref14, _excluded14);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path22 || (_path22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,4,17.5859,5.4141,22.1719,10H10a2,2,0,0,0-2,2V28h2V12H22.1719l-4.586,4.5859L19,18l7-7Z"
  })), children);
});
var DirectionRight_0120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRight_0120(_ref15, ref) {
  var children = _ref15.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref15, _excluded15);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path23 || (_path23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,4,17.5859,5.4141,22.1719,10H10a2,2,0,0,0-2,2V28h2V12H22.1719l-4.586,4.5859L19,18l7-7Z"
  })), children);
});
var DirectionRight_0116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRight_0116(_ref16, ref) {
  var children = _ref16.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref16, _excluded16);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path24 || (_path24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19,4,17.5859,5.4141,22.1719,10H10a2,2,0,0,0-2,2V28h2V12H22.1719l-4.586,4.5859L19,18l7-7Z"
  })), children);
});
var DirectionRight_01Filled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRight_01Filled32(_ref17, ref) {
  var children = _ref17.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref17, _excluded17);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path25 || (_path25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM19,18l-1.4141-1.4141L22.1719,12H10V26H8V12a2,2,0,0,1,2-2H22.1719l-4.586-4.5859L19,4l7,7Z"
  })), _path26 || (_path26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M19,18l-1.4141-1.4141L22.1719,12H10V26H8V12a2,2,0,0,1,2-2H22.1719l-4.586-4.5859L19,4l7,7Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRight_01Filled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRight_01Filled24(_ref18, ref) {
  var children = _ref18.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref18, _excluded18);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path27 || (_path27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM19,18l-1.4141-1.4141L22.1719,12H10V26H8V12a2,2,0,0,1,2-2H22.1719l-4.586-4.5859L19,4l7,7Z"
  })), _path28 || (_path28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M19,18l-1.4141-1.4141L22.1719,12H10V26H8V12a2,2,0,0,1,2-2H22.1719l-4.586-4.5859L19,4l7,7Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRight_01Filled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRight_01Filled20(_ref19, ref) {
  var children = _ref19.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref19, _excluded19);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path29 || (_path29 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM19,18l-1.4141-1.4141L22.1719,12H10V26H8V12a2,2,0,0,1,2-2H22.1719l-4.586-4.5859L19,4l7,7Z"
  })), _path30 || (_path30 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M19,18l-1.4141-1.4141L22.1719,12H10V26H8V12a2,2,0,0,1,2-2H22.1719l-4.586-4.5859L19,4l7,7Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRight_01Filled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRight_01Filled16(_ref20, ref) {
  var children = _ref20.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref20, _excluded20);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path31 || (_path31 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM19,18l-1.4141-1.4141L22.1719,12H10V26H8V12a2,2,0,0,1,2-2H22.1719l-4.586-4.5859L19,4l7,7Z"
  })), _path32 || (_path32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M19,18l-1.4141-1.4141L22.1719,12H10V26H8V12a2,2,0,0,1,2-2H22.1719l-4.586-4.5859L19,4l7,7Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRight_0232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRight_0232(_ref21, ref) {
  var children = _ref21.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref21, _excluded21);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path33 || (_path33 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 8L17.5859 9.4141 22.1719 14H10a2 2 0 00-2 2V28h2V16H22.1719l-4.586 4.5859L19 22l7-7zM8 4H10V12H8z"
  })), children);
});
var DirectionRight_0224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRight_0224(_ref22, ref) {
  var children = _ref22.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref22, _excluded22);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path34 || (_path34 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 8L17.5859 9.4141 22.1719 14H10a2 2 0 00-2 2V28h2V16H22.1719l-4.586 4.5859L19 22l7-7zM8 4H10V12H8z"
  })), children);
});
var DirectionRight_0220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRight_0220(_ref23, ref) {
  var children = _ref23.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref23, _excluded23);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path35 || (_path35 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 8L17.5859 9.4141 22.1719 14H10a2 2 0 00-2 2V28h2V16H22.1719l-4.586 4.5859L19 22l7-7zM8 4H10V12H8z"
  })), children);
});
var DirectionRight_0216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRight_0216(_ref24, ref) {
  var children = _ref24.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref24, _excluded24);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path36 || (_path36 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19 8L17.5859 9.4141 22.1719 14H10a2 2 0 00-2 2V28h2V16H22.1719l-4.586 4.5859L19 22l7-7zM8 4H10V12H8z"
  })), children);
});
var DirectionRight_02Filled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRight_02Filled32(_ref25, ref) {
  var children = _ref25.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref25, _excluded25);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path37 || (_path37 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM8,6h2v8H8ZM19,24l-1.4141-1.4141L22.1719,18H10v8H8V18a2,2,0,0,1,2-2H22.1719l-4.586-4.5859L19,10l7,7Z"
  })), _path38 || (_path38 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M8,6h2v8H8ZM19,24l-1.4141-1.4141L22.1719,18H10v8H8V18a2,2,0,0,1,2-2H22.1719l-4.586-4.5859L19,10l7,7Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRight_02Filled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRight_02Filled24(_ref26, ref) {
  var children = _ref26.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref26, _excluded26);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path39 || (_path39 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM8,6h2v8H8ZM19,24l-1.4141-1.4141L22.1719,18H10v8H8V18a2,2,0,0,1,2-2H22.1719l-4.586-4.5859L19,10l7,7Z"
  })), _path40 || (_path40 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M8,6h2v8H8ZM19,24l-1.4141-1.4141L22.1719,18H10v8H8V18a2,2,0,0,1,2-2H22.1719l-4.586-4.5859L19,10l7,7Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRight_02Filled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRight_02Filled20(_ref27, ref) {
  var children = _ref27.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref27, _excluded27);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path41 || (_path41 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM8,6h2v8H8ZM19,24l-1.4141-1.4141L22.1719,18H10v8H8V18a2,2,0,0,1,2-2H22.1719l-4.586-4.5859L19,10l7,7Z"
  })), _path42 || (_path42 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M8,6h2v8H8ZM19,24l-1.4141-1.4141L22.1719,18H10v8H8V18a2,2,0,0,1,2-2H22.1719l-4.586-4.5859L19,10l7,7Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRight_02Filled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRight_02Filled16(_ref28, ref) {
  var children = _ref28.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref28, _excluded28);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path43 || (_path43 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM8,6h2v8H8ZM19,24l-1.4141-1.4141L22.1719,18H10v8H8V18a2,2,0,0,1,2-2H22.1719l-4.586-4.5859L19,10l7,7Z"
  })), _path44 || (_path44 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M8,6h2v8H8ZM19,24l-1.4141-1.4141L22.1719,18H10v8H8V18a2,2,0,0,1,2-2H22.1719l-4.586-4.5859L19,10l7,7Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRotaryFirstRight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryFirstRight32(_ref29, ref) {
  var children = _ref29.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref29, _excluded29);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path45 || (_path45 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,18v6.5859L15.8712,14.457A5.9242,5.9242,0,0,0,17,11a6,6,0,1,0-7,5.91V28h2V16.91a5.9566,5.9566,0,0,0,2.4554-1.04L24.5859,26H18v2H28V18ZM11,15a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,11,15Z"
  })), children);
});
var DirectionRotaryFirstRight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryFirstRight24(_ref30, ref) {
  var children = _ref30.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref30, _excluded30);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path46 || (_path46 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,18v6.5859L15.8712,14.457A5.9242,5.9242,0,0,0,17,11a6,6,0,1,0-7,5.91V28h2V16.91a5.9566,5.9566,0,0,0,2.4554-1.04L24.5859,26H18v2H28V18ZM11,15a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,11,15Z"
  })), children);
});
var DirectionRotaryFirstRight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryFirstRight20(_ref31, ref) {
  var children = _ref31.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref31, _excluded31);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path47 || (_path47 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,18v6.5859L15.8712,14.457A5.9242,5.9242,0,0,0,17,11a6,6,0,1,0-7,5.91V28h2V16.91a5.9566,5.9566,0,0,0,2.4554-1.04L24.5859,26H18v2H28V18ZM11,15a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,11,15Z"
  })), children);
});
var DirectionRotaryFirstRight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryFirstRight16(_ref32, ref) {
  var children = _ref32.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref32, _excluded32);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path48 || (_path48 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,18v6.5859L15.8712,14.457A5.9242,5.9242,0,0,0,17,11a6,6,0,1,0-7,5.91V28h2V16.91a5.9566,5.9566,0,0,0,2.4554-1.04L24.5859,26H18v2H28V18ZM11,15a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,11,15Z"
  })), children);
});
var DirectionRotaryFirstRightFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryFirstRightFilled32(_ref33, ref) {
  var children = _ref33.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref33, _excluded33);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle || (_circle = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "11",
    r: "3"
  })), _path49 || (_path49 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM26,26H16V24h6.5859l-8.833-8.833A4.9678,4.9678,0,0,1,12,15.8989V26H10V15.8989a5.0113,5.0113,0,1,1,5.167-2.146L24,22.5859V16h2Z"
  })), _path50 || (_path50 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11,14a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,11,14Zm13,2v6.5859l-8.833-8.833A4.9959,4.9959,0,1,0,10,15.8989V26h2V15.8989a4.9678,4.9678,0,0,0,1.7529-.7319L22.5859,24H16v2H26V16Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRotaryFirstRightFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryFirstRightFilled24(_ref34, ref) {
  var children = _ref34.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref34, _excluded34);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle2 || (_circle2 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "11",
    r: "3"
  })), _path51 || (_path51 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM26,26H16V24h6.5859l-8.833-8.833A4.9678,4.9678,0,0,1,12,15.8989V26H10V15.8989a5.0113,5.0113,0,1,1,5.167-2.146L24,22.5859V16h2Z"
  })), _path52 || (_path52 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11,14a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,11,14Zm13,2v6.5859l-8.833-8.833A4.9959,4.9959,0,1,0,10,15.8989V26h2V15.8989a4.9678,4.9678,0,0,0,1.7529-.7319L22.5859,24H16v2H26V16Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRotaryFirstRightFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryFirstRightFilled20(_ref35, ref) {
  var children = _ref35.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref35, _excluded35);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle3 || (_circle3 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "11",
    r: "3"
  })), _path53 || (_path53 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM26,26H16V24h6.5859l-8.833-8.833A4.9678,4.9678,0,0,1,12,15.8989V26H10V15.8989a5.0113,5.0113,0,1,1,5.167-2.146L24,22.5859V16h2Z"
  })), _path54 || (_path54 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11,14a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,11,14Zm13,2v6.5859l-8.833-8.833A4.9959,4.9959,0,1,0,10,15.8989V26h2V15.8989a4.9678,4.9678,0,0,0,1.7529-.7319L22.5859,24H16v2H26V16Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRotaryFirstRightFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryFirstRightFilled16(_ref36, ref) {
  var children = _ref36.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref36, _excluded36);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle4 || (_circle4 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "11",
    r: "3"
  })), _path55 || (_path55 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM26,26H16V24h6.5859l-8.833-8.833A4.9678,4.9678,0,0,1,12,15.8989V26H10V15.8989a5.0113,5.0113,0,1,1,5.167-2.146L24,22.5859V16h2Z"
  })), _path56 || (_path56 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M11,14a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,11,14Zm13,2v6.5859l-8.833-8.833A4.9959,4.9959,0,1,0,10,15.8989V26h2V15.8989a4.9678,4.9678,0,0,0,1.7529-.7319L22.5859,24H16v2H26V16Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRotaryRight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryRight32(_ref37, ref) {
  var children = _ref37.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref37, _excluded37);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path57 || (_path57 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,4,20.5859,5.4141,25.1719,10H16.91A5.9965,5.9965,0,1,0,10,16.91V28h2V16.91A6.0061,6.0061,0,0,0,16.91,12h8.2622l-4.586,4.5859L22,18l7-7ZM11,15a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,11,15Z"
  })), children);
});
var DirectionRotaryRight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryRight24(_ref38, ref) {
  var children = _ref38.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref38, _excluded38);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path58 || (_path58 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,4,20.5859,5.4141,25.1719,10H16.91A5.9965,5.9965,0,1,0,10,16.91V28h2V16.91A6.0061,6.0061,0,0,0,16.91,12h8.2622l-4.586,4.5859L22,18l7-7ZM11,15a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,11,15Z"
  })), children);
});
var DirectionRotaryRight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryRight20(_ref39, ref) {
  var children = _ref39.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref39, _excluded39);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path59 || (_path59 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,4,20.5859,5.4141,25.1719,10H16.91A5.9965,5.9965,0,1,0,10,16.91V28h2V16.91A6.0061,6.0061,0,0,0,16.91,12h8.2622l-4.586,4.5859L22,18l7-7ZM11,15a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,11,15Z"
  })), children);
});
var DirectionRotaryRight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryRight16(_ref40, ref) {
  var children = _ref40.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref40, _excluded40);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path60 || (_path60 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,4,20.5859,5.4141,25.1719,10H16.91A5.9965,5.9965,0,1,0,10,16.91V28h2V16.91A6.0061,6.0061,0,0,0,16.91,12h8.2622l-4.586,4.5859L22,18l7-7ZM11,15a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,11,15Z"
  })), children);
});
var DirectionRotaryRightFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryRightFilled32(_ref41, ref) {
  var children = _ref41.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref41, _excluded41);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle5 || (_circle5 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "11",
    r: "3"
  })), _path61 || (_path61 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM20,18l-1.4141-1.4141L23.1719,12h-7.273A5.0145,5.0145,0,0,1,12,15.8989V26H10V15.8989A5,5,0,1,1,15.8989,10h7.273l-4.586-4.5859L20,4l7,7Z"
  })), _path62 || (_path62 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M20,4,18.5859,5.4141,23.1719,10h-7.273A5,5,0,1,0,10,15.8989V26h2V15.8989A5.0145,5.0145,0,0,0,15.8989,12h7.273l-4.586,4.5859L20,18l7-7ZM11,14a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,11,14Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRotaryRightFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryRightFilled24(_ref42, ref) {
  var children = _ref42.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref42, _excluded42);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle6 || (_circle6 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "11",
    r: "3"
  })), _path63 || (_path63 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM20,18l-1.4141-1.4141L23.1719,12h-7.273A5.0145,5.0145,0,0,1,12,15.8989V26H10V15.8989A5,5,0,1,1,15.8989,10h7.273l-4.586-4.5859L20,4l7,7Z"
  })), _path64 || (_path64 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M20,4,18.5859,5.4141,23.1719,10h-7.273A5,5,0,1,0,10,15.8989V26h2V15.8989A5.0145,5.0145,0,0,0,15.8989,12h7.273l-4.586,4.5859L20,18l7-7ZM11,14a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,11,14Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRotaryRightFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryRightFilled20(_ref43, ref) {
  var children = _ref43.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref43, _excluded43);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle7 || (_circle7 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "11",
    r: "3"
  })), _path65 || (_path65 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM20,18l-1.4141-1.4141L23.1719,12h-7.273A5.0145,5.0145,0,0,1,12,15.8989V26H10V15.8989A5,5,0,1,1,15.8989,10h7.273l-4.586-4.5859L20,4l7,7Z"
  })), _path66 || (_path66 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M20,4,18.5859,5.4141,23.1719,10h-7.273A5,5,0,1,0,10,15.8989V26h2V15.8989A5.0145,5.0145,0,0,0,15.8989,12h7.273l-4.586,4.5859L20,18l7-7ZM11,14a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,11,14Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRotaryRightFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryRightFilled16(_ref44, ref) {
  var children = _ref44.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref44, _excluded44);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle8 || (_circle8 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "11",
    cy: "11",
    r: "3"
  })), _path67 || (_path67 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM20,18l-1.4141-1.4141L23.1719,12h-7.273A5.0145,5.0145,0,0,1,12,15.8989V26H10V15.8989A5,5,0,1,1,15.8989,10h7.273l-4.586-4.5859L20,4l7,7Z"
  })), _path68 || (_path68 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M20,4,18.5859,5.4141,23.1719,10h-7.273A5,5,0,1,0,10,15.8989V26h2V15.8989A5.0145,5.0145,0,0,0,15.8989,12h7.273l-4.586,4.5859L20,18l7-7ZM11,14a3,3,0,1,1,3-3A3.0033,3.0033,0,0,1,11,14Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRotaryStraight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryStraight32(_ref45, ref) {
  var children = _ref45.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref45, _excluded45);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path69 || (_path69 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,12.09V5.8281l4.5859,4.586L23,9,16,2,9,9l1.4141,1.4141L15,5.8281V12.09A5.9925,5.9925,0,0,0,15,23.91V28h2V23.91A5.9925,5.9925,0,0,0,17,12.09ZM16,22a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,22Z"
  })), children);
});
var DirectionRotaryStraight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryStraight24(_ref46, ref) {
  var children = _ref46.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref46, _excluded46);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path70 || (_path70 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,12.09V5.8281l4.5859,4.586L23,9,16,2,9,9l1.4141,1.4141L15,5.8281V12.09A5.9925,5.9925,0,0,0,15,23.91V28h2V23.91A5.9925,5.9925,0,0,0,17,12.09ZM16,22a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,22Z"
  })), children);
});
var DirectionRotaryStraight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryStraight20(_ref47, ref) {
  var children = _ref47.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref47, _excluded47);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path71 || (_path71 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,12.09V5.8281l4.5859,4.586L23,9,16,2,9,9l1.4141,1.4141L15,5.8281V12.09A5.9925,5.9925,0,0,0,15,23.91V28h2V23.91A5.9925,5.9925,0,0,0,17,12.09ZM16,22a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,22Z"
  })), children);
});
var DirectionRotaryStraight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryStraight16(_ref48, ref) {
  var children = _ref48.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref48, _excluded48);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path72 || (_path72 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17,12.09V5.8281l4.5859,4.586L23,9,16,2,9,9l1.4141,1.4141L15,5.8281V12.09A5.9925,5.9925,0,0,0,15,23.91V28h2V23.91A5.9925,5.9925,0,0,0,17,12.09ZM16,22a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,16,22Z"
  })), children);
});
var DirectionRotaryStraightFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryStraightFilled32(_ref49, ref) {
  var children = _ref49.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref49, _excluded49);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle9 || (_circle9 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "19",
    r: "3"
  })), _path73 || (_path73 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM21.5859,12.4141,17,7.8281v6.273a5,5,0,0,1,0,9.7978V28H15V23.8989a5,5,0,0,1,0-9.7978V7.8281l-4.5859,4.586L9,11l7-7,7,7Z"
  })), _path74 || (_path74 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M21.5859,12.4141,23,11,16,4,9,11l1.4141,1.4141L15,7.8281v6.273a5,5,0,0,0,0,9.7978V28h2V23.8989a5,5,0,0,0,0-9.7978V7.8281ZM19,19a3,3,0,1,1-3-3A3.0033,3.0033,0,0,1,19,19Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRotaryStraightFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryStraightFilled24(_ref50, ref) {
  var children = _ref50.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref50, _excluded50);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle10 || (_circle10 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "19",
    r: "3"
  })), _path75 || (_path75 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM21.5859,12.4141,17,7.8281v6.273a5,5,0,0,1,0,9.7978V28H15V23.8989a5,5,0,0,1,0-9.7978V7.8281l-4.5859,4.586L9,11l7-7,7,7Z"
  })), _path76 || (_path76 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M21.5859,12.4141,23,11,16,4,9,11l1.4141,1.4141L15,7.8281v6.273a5,5,0,0,0,0,9.7978V28h2V23.8989a5,5,0,0,0,0-9.7978V7.8281ZM19,19a3,3,0,1,1-3-3A3.0033,3.0033,0,0,1,19,19Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRotaryStraightFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryStraightFilled20(_ref51, ref) {
  var children = _ref51.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref51, _excluded51);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle11 || (_circle11 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "19",
    r: "3"
  })), _path77 || (_path77 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM21.5859,12.4141,17,7.8281v6.273a5,5,0,0,1,0,9.7978V28H15V23.8989a5,5,0,0,1,0-9.7978V7.8281l-4.5859,4.586L9,11l7-7,7,7Z"
  })), _path78 || (_path78 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M21.5859,12.4141,23,11,16,4,9,11l1.4141,1.4141L15,7.8281v6.273a5,5,0,0,0,0,9.7978V28h2V23.8989a5,5,0,0,0,0-9.7978V7.8281ZM19,19a3,3,0,1,1-3-3A3.0033,3.0033,0,0,1,19,19Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionRotaryStraightFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionRotaryStraightFilled16(_ref52, ref) {
  var children = _ref52.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref52, _excluded52);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle12 || (_circle12 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "19",
    r: "3"
  })), _path79 || (_path79 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM21.5859,12.4141,17,7.8281v6.273a5,5,0,0,1,0,9.7978V28H15V23.8989a5,5,0,0,1,0-9.7978V7.8281l-4.5859,4.586L9,11l7-7,7,7Z"
  })), _path80 || (_path80 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M21.5859,12.4141,23,11,16,4,9,11l1.4141,1.4141L15,7.8281v6.273a5,5,0,0,0,0,9.7978V28h2V23.8989a5,5,0,0,0,0-9.7978V7.8281ZM19,19a3,3,0,1,1-3-3A3.0033,3.0033,0,0,1,19,19Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionSharpTurn32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionSharpTurn32(_ref53, ref) {
  var children = _ref53.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref53, _excluded53);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path81 || (_path81 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,18v6.5859L7.707,6.293A1,1,0,0,0,6,7V28H8V9.4141L24.5859,26H18v2H28V18Z"
  })), children);
});
var DirectionSharpTurn24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionSharpTurn24(_ref54, ref) {
  var children = _ref54.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref54, _excluded54);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path82 || (_path82 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,18v6.5859L7.707,6.293A1,1,0,0,0,6,7V28H8V9.4141L24.5859,26H18v2H28V18Z"
  })), children);
});
var DirectionSharpTurn20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionSharpTurn20(_ref55, ref) {
  var children = _ref55.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref55, _excluded55);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path83 || (_path83 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,18v6.5859L7.707,6.293A1,1,0,0,0,6,7V28H8V9.4141L24.5859,26H18v2H28V18Z"
  })), children);
});
var DirectionSharpTurn16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionSharpTurn16(_ref56, ref) {
  var children = _ref56.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref56, _excluded56);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path84 || (_path84 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,18v6.5859L7.707,6.293A1,1,0,0,0,6,7V28H8V9.4141L24.5859,26H18v2H28V18Z"
  })), children);
});
var DirectionSharpTurnFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionSharpTurnFilled32(_ref57, ref) {
  var children = _ref57.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref57, _excluded57);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path85 || (_path85 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM26,26H16V24h6.5859L8,9.4141V26H6V7a1,1,0,0,1,1.707-.707L24,22.5859V16h2Z"
  })), _path86 || (_path86 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M26,26H16V24h6.5859L8,9.4141V26H6V7a1,1,0,0,1,1.707-.707L24,22.5859V16h2Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionSharpTurnFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionSharpTurnFilled24(_ref58, ref) {
  var children = _ref58.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref58, _excluded58);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path87 || (_path87 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM26,26H16V24h6.5859L8,9.4141V26H6V7a1,1,0,0,1,1.707-.707L24,22.5859V16h2Z"
  })), _path88 || (_path88 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M26,26H16V24h6.5859L8,9.4141V26H6V7a1,1,0,0,1,1.707-.707L24,22.5859V16h2Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionSharpTurnFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionSharpTurnFilled20(_ref59, ref) {
  var children = _ref59.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref59, _excluded59);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path89 || (_path89 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM26,26H16V24h6.5859L8,9.4141V26H6V7a1,1,0,0,1,1.707-.707L24,22.5859V16h2Z"
  })), _path90 || (_path90 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M26,26H16V24h6.5859L8,9.4141V26H6V7a1,1,0,0,1,1.707-.707L24,22.5859V16h2Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionSharpTurnFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionSharpTurnFilled16(_ref60, ref) {
  var children = _ref60.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref60, _excluded60);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path91 || (_path91 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM26,26H16V24h6.5859L8,9.4141V26H6V7a1,1,0,0,1,1.707-.707L24,22.5859V16h2Z"
  })), _path92 || (_path92 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M26,26H16V24h6.5859L8,9.4141V26H6V7a1,1,0,0,1,1.707-.707L24,22.5859V16h2Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionStraight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionStraight32(_ref61, ref) {
  var children = _ref61.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref61, _excluded61);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path93 || (_path93 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 4L9 11 10.414 12.414 15 7.828 15 28 17 28 17 7.828 21.586 12.414 23 11 16 4z"
  })), children);
});
var DirectionStraight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionStraight24(_ref62, ref) {
  var children = _ref62.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref62, _excluded62);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path94 || (_path94 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 4L9 11 10.414 12.414 15 7.828 15 28 17 28 17 7.828 21.586 12.414 23 11 16 4z"
  })), children);
});
var DirectionStraight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionStraight20(_ref63, ref) {
  var children = _ref63.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref63, _excluded63);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path95 || (_path95 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 4L9 11 10.414 12.414 15 7.828 15 28 17 28 17 7.828 21.586 12.414 23 11 16 4z"
  })), children);
});
var DirectionStraight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionStraight16(_ref64, ref) {
  var children = _ref64.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref64, _excluded64);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path96 || (_path96 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 4L9 11 10.414 12.414 15 7.828 15 28 17 28 17 7.828 21.586 12.414 23 11 16 4z"
  })), children);
});
var DirectionStraightFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionStraightFilled32(_ref65, ref) {
  var children = _ref65.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref65, _excluded65);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path97 || (_path97 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM21.5859,13.4141,17,8.8281V26H15V8.8281l-4.5859,4.586L9,12l7-7,7,7Z"
  })), _path98 || (_path98 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M21.5859,13.4141,17,8.8281V26H15V8.8281l-4.5859,4.586L9,12l7-7,7,7Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionStraightFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionStraightFilled24(_ref66, ref) {
  var children = _ref66.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref66, _excluded66);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path99 || (_path99 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM21.5859,13.4141,17,8.8281V26H15V8.8281l-4.5859,4.586L9,12l7-7,7,7Z"
  })), _path100 || (_path100 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M21.5859,13.4141,17,8.8281V26H15V8.8281l-4.5859,4.586L9,12l7-7,7,7Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionStraightFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionStraightFilled20(_ref67, ref) {
  var children = _ref67.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref67, _excluded67);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path101 || (_path101 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM21.5859,13.4141,17,8.8281V26H15V8.8281l-4.5859,4.586L9,12l7-7,7,7Z"
  })), _path102 || (_path102 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M21.5859,13.4141,17,8.8281V26H15V8.8281l-4.5859,4.586L9,12l7-7,7,7Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionStraightFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionStraightFilled16(_ref68, ref) {
  var children = _ref68.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref68, _excluded68);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path103 || (_path103 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM21.5859,13.4141,17,8.8281V26H15V8.8281l-4.5859,4.586L9,12l7-7,7,7Z"
  })), _path104 || (_path104 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M21.5859,13.4141,17,8.8281V26H15V8.8281l-4.5859,4.586L9,12l7-7,7,7Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionStraightRight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionStraightRight32(_ref69, ref) {
  var children = _ref69.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref69, _excluded69);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path105 || (_path105 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 16L21 9 19.586 10.414 24.172 15 4 15 4 17 24.172 17 19.586 21.586 21 23 28 16z"
  })), children);
});
var DirectionStraightRight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionStraightRight24(_ref70, ref) {
  var children = _ref70.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref70, _excluded70);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path106 || (_path106 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 16L21 9 19.586 10.414 24.172 15 4 15 4 17 24.172 17 19.586 21.586 21 23 28 16z"
  })), children);
});
var DirectionStraightRight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionStraightRight20(_ref71, ref) {
  var children = _ref71.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref71, _excluded71);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path107 || (_path107 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 16L21 9 19.586 10.414 24.172 15 4 15 4 17 24.172 17 19.586 21.586 21 23 28 16z"
  })), children);
});
var DirectionStraightRight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionStraightRight16(_ref72, ref) {
  var children = _ref72.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref72, _excluded72);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path108 || (_path108 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 16L21 9 19.586 10.414 24.172 15 4 15 4 17 24.172 17 19.586 21.586 21 23 28 16z"
  })), children);
});
var DirectionStraightRightFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionStraightRightFilled32(_ref73, ref) {
  var children = _ref73.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref73, _excluded73);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path109 || (_path109 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM20,23l-1.4141-1.4141L23.1719,17H6V15H23.1719l-4.586-4.5859L20,9l7,7Z"
  })), _path110 || (_path110 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M20,23l-1.4141-1.4141L23.1719,17H6V15H23.1719l-4.586-4.5859L20,9l7,7Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionStraightRightFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionStraightRightFilled24(_ref74, ref) {
  var children = _ref74.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref74, _excluded74);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path111 || (_path111 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM20,23l-1.4141-1.4141L23.1719,17H6V15H23.1719l-4.586-4.5859L20,9l7,7Z"
  })), _path112 || (_path112 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M20,23l-1.4141-1.4141L23.1719,17H6V15H23.1719l-4.586-4.5859L20,9l7,7Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionStraightRightFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionStraightRightFilled20(_ref75, ref) {
  var children = _ref75.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref75, _excluded75);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path113 || (_path113 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM20,23l-1.4141-1.4141L23.1719,17H6V15H23.1719l-4.586-4.5859L20,9l7,7Z"
  })), _path114 || (_path114 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M20,23l-1.4141-1.4141L23.1719,17H6V15H23.1719l-4.586-4.5859L20,9l7,7Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionStraightRightFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionStraightRightFilled16(_ref76, ref) {
  var children = _ref76.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref76, _excluded76);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path115 || (_path115 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM20,23l-1.4141-1.4141L23.1719,17H6V15H23.1719l-4.586-4.5859L20,9l7,7Z"
  })), _path116 || (_path116 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M20,23l-1.4141-1.4141L23.1719,17H6V15H23.1719l-4.586-4.5859L20,9l7,7Z",
    "data-icon-path": "inner-path"
  })), children);
});
var DirectionUTurn32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionUTurn32(_ref77, ref) {
  var children = _ref77.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref77, _excluded77);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path117 || (_path117 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5859,19.5859,22,24.1719V12A8,8,0,0,0,6,12V28H8V12a6,6,0,0,1,12,0V24.1719l-4.5859-4.586L14,21l7,7,7-7Z"
  })), children);
});
var DirectionUTurn24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionUTurn24(_ref78, ref) {
  var children = _ref78.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref78, _excluded78);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path118 || (_path118 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5859,19.5859,22,24.1719V12A8,8,0,0,0,6,12V28H8V12a6,6,0,0,1,12,0V24.1719l-4.5859-4.586L14,21l7,7,7-7Z"
  })), children);
});
var DirectionUTurn20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionUTurn20(_ref79, ref) {
  var children = _ref79.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref79, _excluded79);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path119 || (_path119 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5859,19.5859,22,24.1719V12A8,8,0,0,0,6,12V28H8V12a6,6,0,0,1,12,0V24.1719l-4.5859-4.586L14,21l7,7,7-7Z"
  })), children);
});
var DirectionUTurn16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionUTurn16(_ref80, ref) {
  var children = _ref80.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref80, _excluded80);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path120 || (_path120 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26.5859,19.5859,22,24.1719V12A8,8,0,0,0,6,12V28H8V12a6,6,0,0,1,12,0V24.1719l-4.5859-4.586L14,21l7,7,7-7Z"
  })), children);
});
var DirectionUTurnFilled32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionUTurnFilled32(_ref81, ref) {
  var children = _ref81.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref81, _excluded81);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path121 || (_path121 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M26.5859,17.5859,22,22.1719V14A8,8,0,0,0,6,14V26H8V14a6,6,0,0,1,12,0v8.1719l-4.5859-4.586L14,19l7,7,7-7Z",
    "data-icon-path": "inner-path"
  })), _path122 || (_path122 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM21,26l-7-7,1.4141-1.4141L20,22.1719V14A6,6,0,0,0,8,14V26H6V14a8,8,0,0,1,16,0v8.1719l4.5859-4.586L28,19Z"
  })), children);
});
var DirectionUTurnFilled24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionUTurnFilled24(_ref82, ref) {
  var children = _ref82.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref82, _excluded82);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path123 || (_path123 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M26.5859,17.5859,22,22.1719V14A8,8,0,0,0,6,14V26H8V14a6,6,0,0,1,12,0v8.1719l-4.5859-4.586L14,19l7,7,7-7Z",
    "data-icon-path": "inner-path"
  })), _path124 || (_path124 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM21,26l-7-7,1.4141-1.4141L20,22.1719V14A6,6,0,0,0,8,14V26H6V14a8,8,0,0,1,16,0v8.1719l4.5859-4.586L28,19Z"
  })), children);
});
var DirectionUTurnFilled20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionUTurnFilled20(_ref83, ref) {
  var children = _ref83.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref83, _excluded83);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path125 || (_path125 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M26.5859,17.5859,22,22.1719V14A8,8,0,0,0,6,14V26H8V14a6,6,0,0,1,12,0v8.1719l-4.5859-4.586L14,19l7,7,7-7Z",
    "data-icon-path": "inner-path"
  })), _path126 || (_path126 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM21,26l-7-7,1.4141-1.4141L20,22.1719V14A6,6,0,0,0,8,14V26H6V14a8,8,0,0,1,16,0v8.1719l4.5859-4.586L28,19Z"
  })), children);
});
var DirectionUTurnFilled16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectionUTurnFilled16(_ref84, ref) {
  var children = _ref84.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref84, _excluded84);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path127 || (_path127 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M26.5859,17.5859,22,22.1719V14A8,8,0,0,0,6,14V26H8V14a6,6,0,0,1,12,0v8.1719l-4.5859-4.586L14,19l7,7,7-7Z",
    "data-icon-path": "inner-path"
  })), _path128 || (_path128 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H28a2,2,0,0,0,2-2V4A2,2,0,0,0,28,2ZM21,26l-7-7,1.4141-1.4141L20,22.1719V14A6,6,0,0,0,8,14V26H6V14a8,8,0,0,1,16,0v8.1719l4.5859-4.586L28,19Z"
  })), children);
});
var DirectoryDomain32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectoryDomain32(_ref85, ref) {
  var children = _ref85.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref85, _excluded85);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path129 || (_path129 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H18.8157A2.9959,2.9959,0,0,0,17,24.1841V19h7a2.0025,2.0025,0,0,0,2-2V4a2.0025,2.0025,0,0,0-2-2H8A2.0025,2.0025,0,0,0,6,4V17a2.0025,2.0025,0,0,0,2,2h7v5.1841A2.9959,2.9959,0,0,0,13.1843,26H4v2h9.1843a2.982,2.982,0,0,0,5.6314,0H28ZM24,12H8V9H24Zm0-8V7H8V4ZM8,14H24v3H8Zm8,14a1,1,0,1,1,1-1A1.0008,1.0008,0,0,1,16,28Z"
  })), children);
});
var DirectoryDomain24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectoryDomain24(_ref86, ref) {
  var children = _ref86.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref86, _excluded86);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path130 || (_path130 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H18.8157A2.9959,2.9959,0,0,0,17,24.1841V19h7a2.0025,2.0025,0,0,0,2-2V4a2.0025,2.0025,0,0,0-2-2H8A2.0025,2.0025,0,0,0,6,4V17a2.0025,2.0025,0,0,0,2,2h7v5.1841A2.9959,2.9959,0,0,0,13.1843,26H4v2h9.1843a2.982,2.982,0,0,0,5.6314,0H28ZM24,12H8V9H24Zm0-8V7H8V4ZM8,14H24v3H8Zm8,14a1,1,0,1,1,1-1A1.0008,1.0008,0,0,1,16,28Z"
  })), children);
});
var DirectoryDomain20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectoryDomain20(_ref87, ref) {
  var children = _ref87.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref87, _excluded87);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path131 || (_path131 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H18.8157A2.9959,2.9959,0,0,0,17,24.1841V19h7a2.0025,2.0025,0,0,0,2-2V4a2.0025,2.0025,0,0,0-2-2H8A2.0025,2.0025,0,0,0,6,4V17a2.0025,2.0025,0,0,0,2,2h7v5.1841A2.9959,2.9959,0,0,0,13.1843,26H4v2h9.1843a2.982,2.982,0,0,0,5.6314,0H28ZM24,12H8V9H24Zm0-8V7H8V4ZM8,14H24v3H8Zm8,14a1,1,0,1,1,1-1A1.0008,1.0008,0,0,1,16,28Z"
  })), children);
});
var DirectoryDomain16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DirectoryDomain16(_ref88, ref) {
  var children = _ref88.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref88, _excluded88);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path132 || (_path132 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26H18.8157A2.9959,2.9959,0,0,0,17,24.1841V19h7a2.0025,2.0025,0,0,0,2-2V4a2.0025,2.0025,0,0,0-2-2H8A2.0025,2.0025,0,0,0,6,4V17a2.0025,2.0025,0,0,0,2,2h7v5.1841A2.9959,2.9959,0,0,0,13.1843,26H4v2h9.1843a2.982,2.982,0,0,0,5.6314,0H28ZM24,12H8V9H24Zm0-8V7H8V4ZM8,14H24v3H8Zm8,14a1,1,0,1,1,1-1A1.0008,1.0008,0,0,1,16,28Z"
  })), children);
});
var DistributeHorizontalCenter32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeHorizontalCenter32(_ref89, ref) {
  var children = _ref89.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref89, _excluded89);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path133 || (_path133 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 10H23V2H21v8H20a2.0023 2.0023 0 00-2 2v8a2.0023 2.0023 0 002 2h1v8h2V22h1a2.0023 2.0023 0 002-2V12A2.0023 2.0023 0 0024 10zm0 10H20V12h4zM12 6H11V2H9V6H8A2.0023 2.0023 0 006 8V24a2.0023 2.0023 0 002 2H9v4h2V26h1a2.0023 2.0023 0 002-2V8A2.0023 2.0023 0 0012 6zm0 18H8V8h4z"
  })), children);
});
var DistributeHorizontalCenter24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeHorizontalCenter24(_ref90, ref) {
  var children = _ref90.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref90, _excluded90);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path134 || (_path134 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 10H23V2H21v8H20a2.0023 2.0023 0 00-2 2v8a2.0023 2.0023 0 002 2h1v8h2V22h1a2.0023 2.0023 0 002-2V12A2.0023 2.0023 0 0024 10zm0 10H20V12h4zM12 6H11V2H9V6H8A2.0023 2.0023 0 006 8V24a2.0023 2.0023 0 002 2H9v4h2V26h1a2.0023 2.0023 0 002-2V8A2.0023 2.0023 0 0012 6zm0 18H8V8h4z"
  })), children);
});
var DistributeHorizontalCenter20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeHorizontalCenter20(_ref91, ref) {
  var children = _ref91.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref91, _excluded91);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path135 || (_path135 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 10H23V2H21v8H20a2.0023 2.0023 0 00-2 2v8a2.0023 2.0023 0 002 2h1v8h2V22h1a2.0023 2.0023 0 002-2V12A2.0023 2.0023 0 0024 10zm0 10H20V12h4zM12 6H11V2H9V6H8A2.0023 2.0023 0 006 8V24a2.0023 2.0023 0 002 2H9v4h2V26h1a2.0023 2.0023 0 002-2V8A2.0023 2.0023 0 0012 6zm0 18H8V8h4z"
  })), children);
});
var DistributeHorizontalCenter16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeHorizontalCenter16(_ref92, ref) {
  var children = _ref92.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref92, _excluded92);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path136 || (_path136 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 10H23V2H21v8H20a2.0023 2.0023 0 00-2 2v8a2.0023 2.0023 0 002 2h1v8h2V22h1a2.0023 2.0023 0 002-2V12A2.0023 2.0023 0 0024 10zm0 10H20V12h4zM12 6H11V2H9V6H8A2.0023 2.0023 0 006 8V24a2.0023 2.0023 0 002 2H9v4h2V26h1a2.0023 2.0023 0 002-2V8A2.0023 2.0023 0 0012 6zm0 18H8V8h4z"
  })), children);
});
var DistributeHorizontalLeft32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeHorizontalLeft32(_ref93, ref) {
  var children = _ref93.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref93, _excluded93);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path137 || (_path137 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 22H24a2.0021 2.0021 0 01-2-2V12a2.0021 2.0021 0 012-2h4a2.0021 2.0021 0 012 2v8A2.0021 2.0021 0 0128 22zM24 12v8h4V12zM18 2H20V30H18zM12 26H8a2.0021 2.0021 0 01-2-2V8A2.0021 2.0021 0 018 6h4a2.0021 2.0021 0 012 2V24A2.0021 2.0021 0 0112 26zM8 8V24h4V8zM2 2H4V30H2z"
  })), children);
});
var DistributeHorizontalLeft24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeHorizontalLeft24(_ref94, ref) {
  var children = _ref94.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref94, _excluded94);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path138 || (_path138 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 22H24a2.0021 2.0021 0 01-2-2V12a2.0021 2.0021 0 012-2h4a2.0021 2.0021 0 012 2v8A2.0021 2.0021 0 0128 22zM24 12v8h4V12zM18 2H20V30H18zM12 26H8a2.0021 2.0021 0 01-2-2V8A2.0021 2.0021 0 018 6h4a2.0021 2.0021 0 012 2V24A2.0021 2.0021 0 0112 26zM8 8V24h4V8zM2 2H4V30H2z"
  })), children);
});
var DistributeHorizontalLeft20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeHorizontalLeft20(_ref95, ref) {
  var children = _ref95.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref95, _excluded95);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path139 || (_path139 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 22H24a2.0021 2.0021 0 01-2-2V12a2.0021 2.0021 0 012-2h4a2.0021 2.0021 0 012 2v8A2.0021 2.0021 0 0128 22zM24 12v8h4V12zM18 2H20V30H18zM12 26H8a2.0021 2.0021 0 01-2-2V8A2.0021 2.0021 0 018 6h4a2.0021 2.0021 0 012 2V24A2.0021 2.0021 0 0112 26zM8 8V24h4V8zM2 2H4V30H2z"
  })), children);
});
var DistributeHorizontalLeft16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeHorizontalLeft16(_ref96, ref) {
  var children = _ref96.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref96, _excluded96);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path140 || (_path140 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 22H24a2.0021 2.0021 0 01-2-2V12a2.0021 2.0021 0 012-2h4a2.0021 2.0021 0 012 2v8A2.0021 2.0021 0 0128 22zM24 12v8h4V12zM18 2H20V30H18zM12 26H8a2.0021 2.0021 0 01-2-2V8A2.0021 2.0021 0 018 6h4a2.0021 2.0021 0 012 2V24A2.0021 2.0021 0 0112 26zM8 8V24h4V8zM2 2H4V30H2z"
  })), children);
});
var DistributeHorizontalRight32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeHorizontalRight32(_ref97, ref) {
  var children = _ref97.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref97, _excluded97);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path141 || (_path141 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 2H30V30H28zM24 22H20a2.0021 2.0021 0 01-2-2V12a2.0021 2.0021 0 012-2h4a2.0021 2.0021 0 012 2v8A2.0021 2.0021 0 0124 22zM20 12h-.0015L20 20h4V12zM12 2H14V30H12zM8 26H4a2.0021 2.0021 0 01-2-2V8A2.0021 2.0021 0 014 6H8a2.0021 2.0021 0 012 2V24A2.0021 2.0021 0 018 26zM4 8H3.9985L4 24H8V8z"
  })), children);
});
var DistributeHorizontalRight24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeHorizontalRight24(_ref98, ref) {
  var children = _ref98.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref98, _excluded98);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path142 || (_path142 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 2H30V30H28zM24 22H20a2.0021 2.0021 0 01-2-2V12a2.0021 2.0021 0 012-2h4a2.0021 2.0021 0 012 2v8A2.0021 2.0021 0 0124 22zM20 12h-.0015L20 20h4V12zM12 2H14V30H12zM8 26H4a2.0021 2.0021 0 01-2-2V8A2.0021 2.0021 0 014 6H8a2.0021 2.0021 0 012 2V24A2.0021 2.0021 0 018 26zM4 8H3.9985L4 24H8V8z"
  })), children);
});
var DistributeHorizontalRight20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeHorizontalRight20(_ref99, ref) {
  var children = _ref99.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref99, _excluded99);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path143 || (_path143 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 2H30V30H28zM24 22H20a2.0021 2.0021 0 01-2-2V12a2.0021 2.0021 0 012-2h4a2.0021 2.0021 0 012 2v8A2.0021 2.0021 0 0124 22zM20 12h-.0015L20 20h4V12zM12 2H14V30H12zM8 26H4a2.0021 2.0021 0 01-2-2V8A2.0021 2.0021 0 014 6H8a2.0021 2.0021 0 012 2V24A2.0021 2.0021 0 018 26zM4 8H3.9985L4 24H8V8z"
  })), children);
});
var DistributeHorizontalRight16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeHorizontalRight16(_ref100, ref) {
  var children = _ref100.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref100, _excluded100);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path144 || (_path144 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 2H30V30H28zM24 22H20a2.0021 2.0021 0 01-2-2V12a2.0021 2.0021 0 012-2h4a2.0021 2.0021 0 012 2v8A2.0021 2.0021 0 0124 22zM20 12h-.0015L20 20h4V12zM12 2H14V30H12zM8 26H4a2.0021 2.0021 0 01-2-2V8A2.0021 2.0021 0 014 6H8a2.0021 2.0021 0 012 2V24A2.0021 2.0021 0 018 26zM4 8H3.9985L4 24H8V8z"
  })), children);
});
var DistributeVerticalBottom32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeVerticalBottom32(_ref101, ref) {
  var children = _ref101.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref101, _excluded101);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path145 || (_path145 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM24 26H8a2.0021 2.0021 0 01-2-2V20a2.0021 2.0021 0 012-2H24a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0124 26zm0-6.0012L8 20v4H24zM2 12H30V14H2zM20 10H12a2.0021 2.0021 0 01-2-2V4a2.0021 2.0021 0 012-2h8a2.0021 2.0021 0 012 2V8A2.0021 2.0021 0 0120 10zm0-6.0012L12 4V8h8z"
  })), children);
});
var DistributeVerticalBottom24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeVerticalBottom24(_ref102, ref) {
  var children = _ref102.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref102, _excluded102);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path146 || (_path146 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM24 26H8a2.0021 2.0021 0 01-2-2V20a2.0021 2.0021 0 012-2H24a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0124 26zm0-6.0012L8 20v4H24zM2 12H30V14H2zM20 10H12a2.0021 2.0021 0 01-2-2V4a2.0021 2.0021 0 012-2h8a2.0021 2.0021 0 012 2V8A2.0021 2.0021 0 0120 10zm0-6.0012L12 4V8h8z"
  })), children);
});
var DistributeVerticalBottom20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeVerticalBottom20(_ref103, ref) {
  var children = _ref103.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref103, _excluded103);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path147 || (_path147 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM24 26H8a2.0021 2.0021 0 01-2-2V20a2.0021 2.0021 0 012-2H24a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0124 26zm0-6.0012L8 20v4H24zM2 12H30V14H2zM20 10H12a2.0021 2.0021 0 01-2-2V4a2.0021 2.0021 0 012-2h8a2.0021 2.0021 0 012 2V8A2.0021 2.0021 0 0120 10zm0-6.0012L12 4V8h8z"
  })), children);
});
var DistributeVerticalBottom16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeVerticalBottom16(_ref104, ref) {
  var children = _ref104.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref104, _excluded104);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path148 || (_path148 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M2 28H30V30H2zM24 26H8a2.0021 2.0021 0 01-2-2V20a2.0021 2.0021 0 012-2H24a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0124 26zm0-6.0012L8 20v4H24zM2 12H30V14H2zM20 10H12a2.0021 2.0021 0 01-2-2V4a2.0021 2.0021 0 012-2h8a2.0021 2.0021 0 012 2V8A2.0021 2.0021 0 0120 10zm0-6.0012L12 4V8h8z"
  })), children);
});
var DistributeVerticalCenter32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeVerticalCenter32(_ref105, ref) {
  var children = _ref105.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref105, _excluded105);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path149 || (_path149 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 21H26V20a2.0023 2.0023 0 00-2-2H8a2.0023 2.0023 0 00-2 2v1H2v2H6v1a2.0023 2.0023 0 002 2H24a2.0023 2.0023 0 002-2V23h4zm-6 3H8V20l16-.001zM30 9H22V8a2.0023 2.0023 0 00-2-2H12a2.0023 2.0023 0 00-2 2V9H2v2h8v1a2.0023 2.0023 0 002 2h8a2.0023 2.0023 0 002-2V11h8zM20 12H12V8l8-.001z"
  })), children);
});
var DistributeVerticalCenter24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeVerticalCenter24(_ref106, ref) {
  var children = _ref106.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref106, _excluded106);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path150 || (_path150 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 21H26V20a2.0023 2.0023 0 00-2-2H8a2.0023 2.0023 0 00-2 2v1H2v2H6v1a2.0023 2.0023 0 002 2H24a2.0023 2.0023 0 002-2V23h4zm-6 3H8V20l16-.001zM30 9H22V8a2.0023 2.0023 0 00-2-2H12a2.0023 2.0023 0 00-2 2V9H2v2h8v1a2.0023 2.0023 0 002 2h8a2.0023 2.0023 0 002-2V11h8zM20 12H12V8l8-.001z"
  })), children);
});
var DistributeVerticalCenter20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeVerticalCenter20(_ref107, ref) {
  var children = _ref107.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref107, _excluded107);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path151 || (_path151 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 21H26V20a2.0023 2.0023 0 00-2-2H8a2.0023 2.0023 0 00-2 2v1H2v2H6v1a2.0023 2.0023 0 002 2H24a2.0023 2.0023 0 002-2V23h4zm-6 3H8V20l16-.001zM30 9H22V8a2.0023 2.0023 0 00-2-2H12a2.0023 2.0023 0 00-2 2V9H2v2h8v1a2.0023 2.0023 0 002 2h8a2.0023 2.0023 0 002-2V11h8zM20 12H12V8l8-.001z"
  })), children);
});
var DistributeVerticalCenter16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeVerticalCenter16(_ref108, ref) {
  var children = _ref108.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref108, _excluded108);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path152 || (_path152 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 21H26V20a2.0023 2.0023 0 00-2-2H8a2.0023 2.0023 0 00-2 2v1H2v2H6v1a2.0023 2.0023 0 002 2H24a2.0023 2.0023 0 002-2V23h4zm-6 3H8V20l16-.001zM30 9H22V8a2.0023 2.0023 0 00-2-2H12a2.0023 2.0023 0 00-2 2V9H2v2h8v1a2.0023 2.0023 0 002 2h8a2.0023 2.0023 0 002-2V11h8zM20 12H12V8l8-.001z"
  })), children);
});
var DistributeVerticalTop32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeVerticalTop32(_ref109, ref) {
  var children = _ref109.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref109, _excluded109);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path153 || (_path153 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30H8a2.0021 2.0021 0 01-2-2V24a2.0021 2.0021 0 012-2H24a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0124 30zM8 24v4H24V24zM2 18H30V20H2zM20 14H12a2.0021 2.0021 0 01-2-2V8a2.0021 2.0021 0 012-2h8a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0120 14zM12 8v4h8V8zM2 2H30V4H2z"
  })), children);
});
var DistributeVerticalTop24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeVerticalTop24(_ref110, ref) {
  var children = _ref110.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref110, _excluded110);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path154 || (_path154 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30H8a2.0021 2.0021 0 01-2-2V24a2.0021 2.0021 0 012-2H24a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0124 30zM8 24v4H24V24zM2 18H30V20H2zM20 14H12a2.0021 2.0021 0 01-2-2V8a2.0021 2.0021 0 012-2h8a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0120 14zM12 8v4h8V8zM2 2H30V4H2z"
  })), children);
});
var DistributeVerticalTop20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeVerticalTop20(_ref111, ref) {
  var children = _ref111.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref111, _excluded111);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path155 || (_path155 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30H8a2.0021 2.0021 0 01-2-2V24a2.0021 2.0021 0 012-2H24a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0124 30zM8 24v4H24V24zM2 18H30V20H2zM20 14H12a2.0021 2.0021 0 01-2-2V8a2.0021 2.0021 0 012-2h8a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0120 14zM12 8v4h8V8zM2 2H30V4H2z"
  })), children);
});
var DistributeVerticalTop16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DistributeVerticalTop16(_ref112, ref) {
  var children = _ref112.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref112, _excluded112);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path156 || (_path156 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30H8a2.0021 2.0021 0 01-2-2V24a2.0021 2.0021 0 012-2H24a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0124 30zM8 24v4H24V24zM2 18H30V20H2zM20 14H12a2.0021 2.0021 0 01-2-2V8a2.0021 2.0021 0 012-2h8a2.0021 2.0021 0 012 2v4A2.0021 2.0021 0 0120 14zM12 8v4h8V8zM2 2H30V4H2z"
  })), children);
});
var WatsonHealthDna32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthDna32(_ref113, ref) {
  var children = _ref113.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref113, _excluded113);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path157 || (_path157 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,2V1H20V2a7.04,7.04,0,0,1-.08,1H12.08A7.04,7.04,0,0,1,12,2V1H10V2c0,3.7549,1.9707,5.6035,4.1008,7C11.9707,10.3965,10,12.2451,10,16s1.9707,5.6035,4.1008,7C11.9707,24.3965,10,26.2451,10,30v1h2V30a7.04,7.04,0,0,1,.08-1H19.92A7.04,7.04,0,0,1,20,30v1h2V30c0-3.7549-1.9707-5.6035-4.1008-7C20.0293,21.6035,22,19.7549,22,16s-1.9707-5.6035-4.1008-7C20.0293,7.6035,22,5.7549,22,2ZM20,16a7.04,7.04,0,0,1-.08,1H12.08a6.3212,6.3212,0,0,1,0-2H19.92A7.04,7.04,0,0,1,20,16Zm-.7559,11H12.7559A8.9078,8.9078,0,0,1,16,24.17,8.9078,8.9078,0,0,1,19.2441,27ZM16,21.83A8.9078,8.9078,0,0,1,12.7559,19h6.4882A8.9078,8.9078,0,0,1,16,21.83ZM19.2441,13H12.7559A8.9078,8.9078,0,0,1,16,10.17,8.9078,8.9078,0,0,1,19.2441,13ZM16,7.83A8.9078,8.9078,0,0,1,12.7559,5h6.4882A8.9078,8.9078,0,0,1,16,7.83Z"
  })), children);
});
var WatsonHealthDna24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthDna24(_ref114, ref) {
  var children = _ref114.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref114, _excluded114);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path158 || (_path158 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,2V1H20V2a7.04,7.04,0,0,1-.08,1H12.08A7.04,7.04,0,0,1,12,2V1H10V2c0,3.7549,1.9707,5.6035,4.1008,7C11.9707,10.3965,10,12.2451,10,16s1.9707,5.6035,4.1008,7C11.9707,24.3965,10,26.2451,10,30v1h2V30a7.04,7.04,0,0,1,.08-1H19.92A7.04,7.04,0,0,1,20,30v1h2V30c0-3.7549-1.9707-5.6035-4.1008-7C20.0293,21.6035,22,19.7549,22,16s-1.9707-5.6035-4.1008-7C20.0293,7.6035,22,5.7549,22,2ZM20,16a7.04,7.04,0,0,1-.08,1H12.08a6.3212,6.3212,0,0,1,0-2H19.92A7.04,7.04,0,0,1,20,16Zm-.7559,11H12.7559A8.9078,8.9078,0,0,1,16,24.17,8.9078,8.9078,0,0,1,19.2441,27ZM16,21.83A8.9078,8.9078,0,0,1,12.7559,19h6.4882A8.9078,8.9078,0,0,1,16,21.83ZM19.2441,13H12.7559A8.9078,8.9078,0,0,1,16,10.17,8.9078,8.9078,0,0,1,19.2441,13ZM16,7.83A8.9078,8.9078,0,0,1,12.7559,5h6.4882A8.9078,8.9078,0,0,1,16,7.83Z"
  })), children);
});
var WatsonHealthDna20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthDna20(_ref115, ref) {
  var children = _ref115.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref115, _excluded115);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path159 || (_path159 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,2V1H20V2a7.04,7.04,0,0,1-.08,1H12.08A7.04,7.04,0,0,1,12,2V1H10V2c0,3.7549,1.9707,5.6035,4.1008,7C11.9707,10.3965,10,12.2451,10,16s1.9707,5.6035,4.1008,7C11.9707,24.3965,10,26.2451,10,30v1h2V30a7.04,7.04,0,0,1,.08-1H19.92A7.04,7.04,0,0,1,20,30v1h2V30c0-3.7549-1.9707-5.6035-4.1008-7C20.0293,21.6035,22,19.7549,22,16s-1.9707-5.6035-4.1008-7C20.0293,7.6035,22,5.7549,22,2ZM20,16a7.04,7.04,0,0,1-.08,1H12.08a6.3212,6.3212,0,0,1,0-2H19.92A7.04,7.04,0,0,1,20,16Zm-.7559,11H12.7559A8.9078,8.9078,0,0,1,16,24.17,8.9078,8.9078,0,0,1,19.2441,27ZM16,21.83A8.9078,8.9078,0,0,1,12.7559,19h6.4882A8.9078,8.9078,0,0,1,16,21.83ZM19.2441,13H12.7559A8.9078,8.9078,0,0,1,16,10.17,8.9078,8.9078,0,0,1,19.2441,13ZM16,7.83A8.9078,8.9078,0,0,1,12.7559,5h6.4882A8.9078,8.9078,0,0,1,16,7.83Z"
  })), children);
});
var WatsonHealthDna16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthDna16(_ref116, ref) {
  var children = _ref116.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref116, _excluded116);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path160 || (_path160 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,2V1H20V2a7.04,7.04,0,0,1-.08,1H12.08A7.04,7.04,0,0,1,12,2V1H10V2c0,3.7549,1.9707,5.6035,4.1008,7C11.9707,10.3965,10,12.2451,10,16s1.9707,5.6035,4.1008,7C11.9707,24.3965,10,26.2451,10,30v1h2V30a7.04,7.04,0,0,1,.08-1H19.92A7.04,7.04,0,0,1,20,30v1h2V30c0-3.7549-1.9707-5.6035-4.1008-7C20.0293,21.6035,22,19.7549,22,16s-1.9707-5.6035-4.1008-7C20.0293,7.6035,22,5.7549,22,2ZM20,16a7.04,7.04,0,0,1-.08,1H12.08a6.3212,6.3212,0,0,1,0-2H19.92A7.04,7.04,0,0,1,20,16Zm-.7559,11H12.7559A8.9078,8.9078,0,0,1,16,24.17,8.9078,8.9078,0,0,1,19.2441,27ZM16,21.83A8.9078,8.9078,0,0,1,12.7559,19h6.4882A8.9078,8.9078,0,0,1,16,21.83ZM19.2441,13H12.7559A8.9078,8.9078,0,0,1,16,10.17,8.9078,8.9078,0,0,1,19.2441,13ZM16,7.83A8.9078,8.9078,0,0,1,12.7559,5h6.4882A8.9078,8.9078,0,0,1,16,7.83Z"
  })), children);
});
var DnsServices32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DnsServices32(_ref117, ref) {
  var children = _ref117.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref117, _excluded117);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path161 || (_path161 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20H30V22H20zM20 24H26V26H20z"
  })), _path162 || (_path162 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,17V16A13.9871,13.9871,0,1,0,19.23,29.625l-.46-1.9463A12.0419,12.0419,0,0,1,16,28c-.19,0-.375-.0186-.563-.0273A20.3044,20.3044,0,0,1,12.0259,17Zm-2.0415-2H21.9751A24.2838,24.2838,0,0,0,19.2014,4.4414,12.0228,12.0228,0,0,1,27.9585,15ZM16.563,4.0273A20.3044,20.3044,0,0,1,19.9741,15H12.0259A20.3044,20.3044,0,0,1,15.437,4.0273C15.625,4.0186,15.81,4,16,4S16.375,4.0186,16.563,4.0273Zm-3.7644.4141A24.2838,24.2838,0,0,0,10.0249,15H4.0415A12.0228,12.0228,0,0,1,12.7986,4.4414Zm0,23.1172A12.0228,12.0228,0,0,1,4.0415,17h5.9834A24.2838,24.2838,0,0,0,12.7986,27.5586Z"
  })), children);
});
var DnsServices24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DnsServices24(_ref118, ref) {
  var children = _ref118.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref118, _excluded118);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path163 || (_path163 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20H30V22H20zM20 24H26V26H20z"
  })), _path164 || (_path164 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,17V16A13.9871,13.9871,0,1,0,19.23,29.625l-.46-1.9463A12.0419,12.0419,0,0,1,16,28c-.19,0-.375-.0186-.563-.0273A20.3044,20.3044,0,0,1,12.0259,17Zm-2.0415-2H21.9751A24.2838,24.2838,0,0,0,19.2014,4.4414,12.0228,12.0228,0,0,1,27.9585,15ZM16.563,4.0273A20.3044,20.3044,0,0,1,19.9741,15H12.0259A20.3044,20.3044,0,0,1,15.437,4.0273C15.625,4.0186,15.81,4,16,4S16.375,4.0186,16.563,4.0273Zm-3.7644.4141A24.2838,24.2838,0,0,0,10.0249,15H4.0415A12.0228,12.0228,0,0,1,12.7986,4.4414Zm0,23.1172A12.0228,12.0228,0,0,1,4.0415,17h5.9834A24.2838,24.2838,0,0,0,12.7986,27.5586Z"
  })), children);
});
var DnsServices20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DnsServices20(_ref119, ref) {
  var children = _ref119.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref119, _excluded119);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path165 || (_path165 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20H30V22H20zM20 24H26V26H20z"
  })), _path166 || (_path166 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,17V16A13.9871,13.9871,0,1,0,19.23,29.625l-.46-1.9463A12.0419,12.0419,0,0,1,16,28c-.19,0-.375-.0186-.563-.0273A20.3044,20.3044,0,0,1,12.0259,17Zm-2.0415-2H21.9751A24.2838,24.2838,0,0,0,19.2014,4.4414,12.0228,12.0228,0,0,1,27.9585,15ZM16.563,4.0273A20.3044,20.3044,0,0,1,19.9741,15H12.0259A20.3044,20.3044,0,0,1,15.437,4.0273C15.625,4.0186,15.81,4,16,4S16.375,4.0186,16.563,4.0273Zm-3.7644.4141A24.2838,24.2838,0,0,0,10.0249,15H4.0415A12.0228,12.0228,0,0,1,12.7986,4.4414Zm0,23.1172A12.0228,12.0228,0,0,1,4.0415,17h5.9834A24.2838,24.2838,0,0,0,12.7986,27.5586Z"
  })), children);
});
var DnsServices16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DnsServices16(_ref120, ref) {
  var children = _ref120.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref120, _excluded120);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path167 || (_path167 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20H30V22H20zM20 24H26V26H20z"
  })), _path168 || (_path168 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,17V16A13.9871,13.9871,0,1,0,19.23,29.625l-.46-1.9463A12.0419,12.0419,0,0,1,16,28c-.19,0-.375-.0186-.563-.0273A20.3044,20.3044,0,0,1,12.0259,17Zm-2.0415-2H21.9751A24.2838,24.2838,0,0,0,19.2014,4.4414,12.0228,12.0228,0,0,1,27.9585,15ZM16.563,4.0273A20.3044,20.3044,0,0,1,19.9741,15H12.0259A20.3044,20.3044,0,0,1,15.437,4.0273C15.625,4.0186,15.81,4,16,4S16.375,4.0186,16.563,4.0273Zm-3.7644.4141A24.2838,24.2838,0,0,0,10.0249,15H4.0415A12.0228,12.0228,0,0,1,12.7986,4.4414Zm0,23.1172A12.0228,12.0228,0,0,1,4.0415,17h5.9834A24.2838,24.2838,0,0,0,12.7986,27.5586Z"
  })), children);
});
var Doc32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Doc32(_ref121, ref) {
  var children = _ref121.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref121, _excluded121);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path169 || (_path169 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h6v2H24V21h6zM18 23H14a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h4a2.002 2.002 0 012 2V21A2.0023 2.0023 0 0118 23zM14 11V21h4V11zM6 23H2V9H6a4.0045 4.0045 0 014 4v6A4.0045 4.0045 0 016 23zM4 21H6a2.002 2.002 0 002-2V13a2.002 2.002 0 00-2-2H4z"
  })), children);
});
var Doc24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Doc24(_ref122, ref) {
  var children = _ref122.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref122, _excluded122);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path170 || (_path170 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h6v2H24V21h6zM18 23H14a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h4a2.002 2.002 0 012 2V21A2.0023 2.0023 0 0118 23zM14 11V21h4V11zM6 23H2V9H6a4.0045 4.0045 0 014 4v6A4.0045 4.0045 0 016 23zM4 21H6a2.002 2.002 0 002-2V13a2.002 2.002 0 00-2-2H4z"
  })), children);
});
var Doc20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Doc20(_ref123, ref) {
  var children = _ref123.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref123, _excluded123);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path171 || (_path171 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h6v2H24V21h6zM18 23H14a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h4a2.002 2.002 0 012 2V21A2.0023 2.0023 0 0118 23zM14 11V21h4V11zM6 23H2V9H6a4.0045 4.0045 0 014 4v6A4.0045 4.0045 0 016 23zM4 21H6a2.002 2.002 0 002-2V13a2.002 2.002 0 00-2-2H4z"
  })), children);
});
var Doc16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Doc16(_ref124, ref) {
  var children = _ref124.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref124, _excluded124);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path172 || (_path172 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 23H24a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h6v2H24V21h6zM18 23H14a2.0023 2.0023 0 01-2-2V11a2.002 2.002 0 012-2h4a2.002 2.002 0 012 2V21A2.0023 2.0023 0 0118 23zM14 11V21h4V11zM6 23H2V9H6a4.0045 4.0045 0 014 4v6A4.0045 4.0045 0 016 23zM4 21H6a2.002 2.002 0 002-2V13a2.002 2.002 0 00-2-2H4z"
  })), children);
});
var Document32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Document32(_ref125, ref) {
  var children = _ref125.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref125, _excluded125);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path173 || (_path173 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.7,9.3l-7-7C18.5,2.1,18.3,2,18,2H8C6.9,2,6,2.9,6,4v24c0,1.1,0.9,2,2,2h16c1.1,0,2-0.9,2-2V10C26,9.7,25.9,9.5,25.7,9.3\tz M18,4.4l5.6,5.6H18V4.4z M24,28H8V4h8v6c0,1.1,0.9,2,2,2h6V28z"
  })), _path174 || (_path174 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 22H22V24H10zM10 16H22V18H10z"
  })), children);
});
var Document24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Document24(_ref126, ref) {
  var children = _ref126.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref126, _excluded126);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path175 || (_path175 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.7,9.3l-7-7C18.5,2.1,18.3,2,18,2H8C6.9,2,6,2.9,6,4v24c0,1.1,0.9,2,2,2h16c1.1,0,2-0.9,2-2V10C26,9.7,25.9,9.5,25.7,9.3\tz M18,4.4l5.6,5.6H18V4.4z M24,28H8V4h8v6c0,1.1,0.9,2,2,2h6V28z"
  })), _path176 || (_path176 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 22H22V24H10zM10 16H22V18H10z"
  })), children);
});
var Document20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Document20(_ref127, ref) {
  var children = _ref127.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref127, _excluded127);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path177 || (_path177 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.7,9.3l-7-7C18.5,2.1,18.3,2,18,2H8C6.9,2,6,2.9,6,4v24c0,1.1,0.9,2,2,2h16c1.1,0,2-0.9,2-2V10C26,9.7,25.9,9.5,25.7,9.3\tz M18,4.4l5.6,5.6H18V4.4z M24,28H8V4h8v6c0,1.1,0.9,2,2,2h6V28z"
  })), _path178 || (_path178 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 22H22V24H10zM10 16H22V18H10z"
  })), children);
});
var Document16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Document16(_ref128, ref) {
  var children = _ref128.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref128, _excluded128);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path179 || (_path179 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.7,9.3l-7-7C18.5,2.1,18.3,2,18,2H8C6.9,2,6,2.9,6,4v24c0,1.1,0.9,2,2,2h16c1.1,0,2-0.9,2-2V10C26,9.7,25.9,9.5,25.7,9.3\tz M18,4.4l5.6,5.6H18V4.4z M24,28H8V4h8v6c0,1.1,0.9,2,2,2h6V28z"
  })), _path180 || (_path180 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10 22H22V24H10zM10 16H22V18H10z"
  })), children);
});
var DocumentAdd32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentAdd32(_ref129, ref) {
  var children = _ref129.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref129, _excluded129);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path181 || (_path181 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 24L26 24 26 20 24 20 24 24 20 24 20 26 24 26 24 30 26 30 26 26 30 26 30 24z"
  })), _path182 || (_path182 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v4h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentAdd24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentAdd24(_ref130, ref) {
  var children = _ref130.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref130, _excluded130);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path183 || (_path183 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 24L26 24 26 20 24 20 24 24 20 24 20 26 24 26 24 30 26 30 26 26 30 26 30 24z"
  })), _path184 || (_path184 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v4h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentAdd20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentAdd20(_ref131, ref) {
  var children = _ref131.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref131, _excluded131);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path185 || (_path185 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 24L26 24 26 20 24 20 24 24 20 24 20 26 24 26 24 30 26 30 26 26 30 26 30 24z"
  })), _path186 || (_path186 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v4h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentAdd16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentAdd16(_ref132, ref) {
  var children = _ref132.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref132, _excluded132);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path187 || (_path187 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 24L26 24 26 20 24 20 24 24 20 24 20 26 24 26 24 30 26 30 26 26 30 26 30 24z"
  })), _path188 || (_path188 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v4h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentAttachment32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentAttachment32(_ref133, ref) {
  var children = _ref133.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref133, _excluded133);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path189 || (_path189 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H11a2.0023,2.0023,0,0,1-2-2V22h2v6H26V6H17V4h9a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30Z"
  })), _path190 || (_path190 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 10H24V12H17zM16 15H24V17H16zM15 20H24V22H15zM9 19a5.0055 5.0055 0 01-5-5V3H6V14a3 3 0 006 0V5a1 1 0 00-2 0V15H8V5a3 3 0 016 0v9A5.0055 5.0055 0 019 19z"
  })), children);
});
var DocumentAttachment24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentAttachment24(_ref134, ref) {
  var children = _ref134.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref134, _excluded134);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path191 || (_path191 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H11a2.0023,2.0023,0,0,1-2-2V22h2v6H26V6H17V4h9a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30Z"
  })), _path192 || (_path192 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 10H24V12H17zM16 15H24V17H16zM15 20H24V22H15zM9 19a5.0055 5.0055 0 01-5-5V3H6V14a3 3 0 006 0V5a1 1 0 00-2 0V15H8V5a3 3 0 016 0v9A5.0055 5.0055 0 019 19z"
  })), children);
});
var DocumentAttachment20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentAttachment20(_ref135, ref) {
  var children = _ref135.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref135, _excluded135);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path193 || (_path193 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H11a2.0023,2.0023,0,0,1-2-2V22h2v6H26V6H17V4h9a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30Z"
  })), _path194 || (_path194 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 10H24V12H17zM16 15H24V17H16zM15 20H24V22H15zM9 19a5.0055 5.0055 0 01-5-5V3H6V14a3 3 0 006 0V5a1 1 0 00-2 0V15H8V5a3 3 0 016 0v9A5.0055 5.0055 0 019 19z"
  })), children);
});
var DocumentAttachment16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentAttachment16(_ref136, ref) {
  var children = _ref136.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref136, _excluded136);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path195 || (_path195 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,30H11a2.0023,2.0023,0,0,1-2-2V22h2v6H26V6H17V4h9a2.0023,2.0023,0,0,1,2,2V28A2.0023,2.0023,0,0,1,26,30Z"
  })), _path196 || (_path196 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 10H24V12H17zM16 15H24V17H16zM15 20H24V22H15zM9 19a5.0055 5.0055 0 01-5-5V3H6V14a3 3 0 006 0V5a1 1 0 00-2 0V15H8V5a3 3 0 016 0v9A5.0055 5.0055 0 019 19z"
  })), children);
});
var DocumentAudio32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentAudio32(_ref137, ref) {
  var children = _ref137.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref137, _excluded137);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path197 || (_path197 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,31a.9987.9987,0,0,1-.6245-.2192L23.6494,27H20a1,1,0,0,1-1-1V21a1,1,0,0,1,1-1h3.6494l4.7261-3.7808A1,1,0,0,1,30,17V30a1,1,0,0,1-1,1Zm-8-6h3a1,1,0,0,1,.6245.2192L28,27.9194V19.0806l-3.3755,2.7A1,1,0,0,1,24,22H21Z"
  })), _path198 || (_path198 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3l2,0V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentAudio24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentAudio24(_ref138, ref) {
  var children = _ref138.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref138, _excluded138);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path199 || (_path199 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,31a.9987.9987,0,0,1-.6245-.2192L23.6494,27H20a1,1,0,0,1-1-1V21a1,1,0,0,1,1-1h3.6494l4.7261-3.7808A1,1,0,0,1,30,17V30a1,1,0,0,1-1,1Zm-8-6h3a1,1,0,0,1,.6245.2192L28,27.9194V19.0806l-3.3755,2.7A1,1,0,0,1,24,22H21Z"
  })), _path200 || (_path200 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3l2,0V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentAudio20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentAudio20(_ref139, ref) {
  var children = _ref139.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref139, _excluded139);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path201 || (_path201 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,31a.9987.9987,0,0,1-.6245-.2192L23.6494,27H20a1,1,0,0,1-1-1V21a1,1,0,0,1,1-1h3.6494l4.7261-3.7808A1,1,0,0,1,30,17V30a1,1,0,0,1-1,1Zm-8-6h3a1,1,0,0,1,.6245.2192L28,27.9194V19.0806l-3.3755,2.7A1,1,0,0,1,24,22H21Z"
  })), _path202 || (_path202 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3l2,0V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentAudio16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentAudio16(_ref140, ref) {
  var children = _ref140.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref140, _excluded140);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path203 || (_path203 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29,31a.9987.9987,0,0,1-.6245-.2192L23.6494,27H20a1,1,0,0,1-1-1V21a1,1,0,0,1,1-1h3.6494l4.7261-3.7808A1,1,0,0,1,30,17V30a1,1,0,0,1-1,1Zm-8-6h3a1,1,0,0,1,.6245.2192L28,27.9194V19.0806l-3.3755,2.7A1,1,0,0,1,24,22H21Z"
  })), _path204 || (_path204 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3l2,0V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentBlank32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentBlank32(_ref141, ref) {
  var children = _ref141.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref141, _excluded141);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path205 || (_path205 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.7,9.3l-7-7A.9078.9078,0,0,0,18,2H8A2.0059,2.0059,0,0,0,6,4V28a2.0059,2.0059,0,0,0,2,2H24a2.0059,2.0059,0,0,0,2-2V10A.9078.9078,0,0,0,25.7,9.3ZM18,4.4,23.6,10H18ZM24,28H8V4h8v6a2.0059,2.0059,0,0,0,2,2h6Z"
  })), children);
});
var DocumentBlank24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentBlank24(_ref142, ref) {
  var children = _ref142.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref142, _excluded142);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path206 || (_path206 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.7,9.3l-7-7A.9078.9078,0,0,0,18,2H8A2.0059,2.0059,0,0,0,6,4V28a2.0059,2.0059,0,0,0,2,2H24a2.0059,2.0059,0,0,0,2-2V10A.9078.9078,0,0,0,25.7,9.3ZM18,4.4,23.6,10H18ZM24,28H8V4h8v6a2.0059,2.0059,0,0,0,2,2h6Z"
  })), children);
});
var DocumentBlank20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentBlank20(_ref143, ref) {
  var children = _ref143.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref143, _excluded143);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path207 || (_path207 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.7,9.3l-7-7A.9078.9078,0,0,0,18,2H8A2.0059,2.0059,0,0,0,6,4V28a2.0059,2.0059,0,0,0,2,2H24a2.0059,2.0059,0,0,0,2-2V10A.9078.9078,0,0,0,25.7,9.3ZM18,4.4,23.6,10H18ZM24,28H8V4h8v6a2.0059,2.0059,0,0,0,2,2h6Z"
  })), children);
});
var DocumentBlank16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentBlank16(_ref144, ref) {
  var children = _ref144.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref144, _excluded144);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path208 || (_path208 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.7,9.3l-7-7A.9078.9078,0,0,0,18,2H8A2.0059,2.0059,0,0,0,6,4V28a2.0059,2.0059,0,0,0,2,2H24a2.0059,2.0059,0,0,0,2-2V10A.9078.9078,0,0,0,25.7,9.3ZM18,4.4,23.6,10H18ZM24,28H8V4h8v6a2.0059,2.0059,0,0,0,2,2h6Z"
  })), children);
});
var DocumentDownload32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentDownload32(_ref145, ref) {
  var children = _ref145.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref145, _excluded145);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path209 || (_path209 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 25L28.586 23.586 26 26.172 26 18 24 18 24 26.172 21.414 23.586 20 25 25 30 30 25z"
  })), _path210 || (_path210 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3l2,0V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2H18ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentDownload24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentDownload24(_ref146, ref) {
  var children = _ref146.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref146, _excluded146);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path211 || (_path211 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 25L28.586 23.586 26 26.172 26 18 24 18 24 26.172 21.414 23.586 20 25 25 30 30 25z"
  })), _path212 || (_path212 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3l2,0V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2H18ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentDownload20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentDownload20(_ref147, ref) {
  var children = _ref147.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref147, _excluded147);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path213 || (_path213 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 25L28.586 23.586 26 26.172 26 18 24 18 24 26.172 21.414 23.586 20 25 25 30 30 25z"
  })), _path214 || (_path214 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3l2,0V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2H18ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentDownload16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentDownload16(_ref148, ref) {
  var children = _ref148.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref148, _excluded148);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path215 || (_path215 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 25L28.586 23.586 26 26.172 26 18 24 18 24 26.172 21.414 23.586 20 25 25 30 30 25z"
  })), _path216 || (_path216 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3l2,0V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2H18ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentEpdf32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentEpdf32(_ref149, ref) {
  var children = _ref149.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref149, _excluded149);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path217 || (_path217 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26V22a2.0023,2.0023,0,0,0-2-2H22a2.0023,2.0023,0,0,0-2,2v6a2.0077,2.0077,0,0,0,2,2h5V28H22V26Zm-6-4h4v2H22Z"
  })), _path218 || (_path218 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.707,9.293l-7-7A1,1,0,0,0,18,2H8A2.002,2.002,0,0,0,6,4V28a2.0023,2.0023,0,0,0,2,2h8V28H8V4h8v6a2.002,2.002,0,0,0,2,2h6v4h2V10A1,1,0,0,0,25.707,9.293ZM18,4.4141,23.5859,10H18Z"
  })), children);
});
var DocumentEpdf24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentEpdf24(_ref150, ref) {
  var children = _ref150.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref150, _excluded150);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path219 || (_path219 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26V22a2.0023,2.0023,0,0,0-2-2H22a2.0023,2.0023,0,0,0-2,2v6a2.0077,2.0077,0,0,0,2,2h5V28H22V26Zm-6-4h4v2H22Z"
  })), _path220 || (_path220 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.707,9.293l-7-7A1,1,0,0,0,18,2H8A2.002,2.002,0,0,0,6,4V28a2.0023,2.0023,0,0,0,2,2h8V28H8V4h8v6a2.002,2.002,0,0,0,2,2h6v4h2V10A1,1,0,0,0,25.707,9.293ZM18,4.4141,23.5859,10H18Z"
  })), children);
});
var DocumentEpdf20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentEpdf20(_ref151, ref) {
  var children = _ref151.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref151, _excluded151);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path221 || (_path221 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26V22a2.0023,2.0023,0,0,0-2-2H22a2.0023,2.0023,0,0,0-2,2v6a2.0077,2.0077,0,0,0,2,2h5V28H22V26Zm-6-4h4v2H22Z"
  })), _path222 || (_path222 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.707,9.293l-7-7A1,1,0,0,0,18,2H8A2.002,2.002,0,0,0,6,4V28a2.0023,2.0023,0,0,0,2,2h8V28H8V4h8v6a2.002,2.002,0,0,0,2,2h6v4h2V10A1,1,0,0,0,25.707,9.293ZM18,4.4141,23.5859,10H18Z"
  })), children);
});
var DocumentEpdf16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentEpdf16(_ref152, ref) {
  var children = _ref152.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref152, _excluded152);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path223 || (_path223 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,26V22a2.0023,2.0023,0,0,0-2-2H22a2.0023,2.0023,0,0,0-2,2v6a2.0077,2.0077,0,0,0,2,2h5V28H22V26Zm-6-4h4v2H22Z"
  })), _path224 || (_path224 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.707,9.293l-7-7A1,1,0,0,0,18,2H8A2.002,2.002,0,0,0,6,4V28a2.0023,2.0023,0,0,0,2,2h8V28H8V4h8v6a2.002,2.002,0,0,0,2,2h6v4h2V10A1,1,0,0,0,25.707,9.293ZM18,4.4141,23.5859,10H18Z"
  })), children);
});
var DocumentExport32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentExport32(_ref153, ref) {
  var children = _ref153.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref153, _excluded153);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path225 || (_path225 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 21L26.17 21 23.59 23.59 25 25 30 20 25 15 23.59 16.41 26.17 19 13 19 13 21z"
  })), _path226 || (_path226 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14V10a1,1,0,0,0-.29-.71l-7-7A1,1,0,0,0,14,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V26H20v2H4V4h8v6a2,2,0,0,0,2,2h6v2Zm-8-4V4.41L19.59,10Z"
  })), children);
});
var DocumentExport24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentExport24(_ref154, ref) {
  var children = _ref154.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref154, _excluded154);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path227 || (_path227 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 21L26.17 21 23.59 23.59 25 25 30 20 25 15 23.59 16.41 26.17 19 13 19 13 21z"
  })), _path228 || (_path228 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14V10a1,1,0,0,0-.29-.71l-7-7A1,1,0,0,0,14,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V26H20v2H4V4h8v6a2,2,0,0,0,2,2h6v2Zm-8-4V4.41L19.59,10Z"
  })), children);
});
var DocumentExport20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentExport20(_ref155, ref) {
  var children = _ref155.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref155, _excluded155);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path229 || (_path229 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 21L26.17 21 23.59 23.59 25 25 30 20 25 15 23.59 16.41 26.17 19 13 19 13 21z"
  })), _path230 || (_path230 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14V10a1,1,0,0,0-.29-.71l-7-7A1,1,0,0,0,14,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V26H20v2H4V4h8v6a2,2,0,0,0,2,2h6v2Zm-8-4V4.41L19.59,10Z"
  })), children);
});
var DocumentExport16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentExport16(_ref156, ref) {
  var children = _ref156.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref156, _excluded156);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path231 || (_path231 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 21L26.17 21 23.59 23.59 25 25 30 20 25 15 23.59 16.41 26.17 19 13 19 13 21z"
  })), _path232 || (_path232 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14V10a1,1,0,0,0-.29-.71l-7-7A1,1,0,0,0,14,2H4A2,2,0,0,0,2,4V28a2,2,0,0,0,2,2H20a2,2,0,0,0,2-2V26H20v2H4V4h8v6a2,2,0,0,0,2,2h6v2Zm-8-4V4.41L19.59,10Z"
  })), children);
});
var DocumentHorizontal32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentHorizontal32(_ref157, ref) {
  var children = _ref157.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref157, _excluded157);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path233 || (_path233 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2.0023,2.0023,0,0,0,2,8V24a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V8A2.0023,2.0023,0,0,0,28,6ZM20,24H12V22a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1Zm8,0H22V22a3,3,0,0,0-3-3H13a3,3,0,0,0-3,3v2H4V8H28Z"
  })), _path234 || (_path234 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,18a4,4,0,1,0-4-4A4,4,0,0,0,16,18Zm0-6a2,2,0,1,1-2,2A2,2,0,0,1,16,12Z"
  })), children);
});
var DocumentHorizontal24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentHorizontal24(_ref158, ref) {
  var children = _ref158.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref158, _excluded158);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path235 || (_path235 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2.0023,2.0023,0,0,0,2,8V24a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V8A2.0023,2.0023,0,0,0,28,6ZM20,24H12V22a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1Zm8,0H22V22a3,3,0,0,0-3-3H13a3,3,0,0,0-3,3v2H4V8H28Z"
  })), _path236 || (_path236 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,18a4,4,0,1,0-4-4A4,4,0,0,0,16,18Zm0-6a2,2,0,1,1-2,2A2,2,0,0,1,16,12Z"
  })), children);
});
var DocumentHorizontal20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentHorizontal20(_ref159, ref) {
  var children = _ref159.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref159, _excluded159);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path237 || (_path237 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2.0023,2.0023,0,0,0,2,8V24a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V8A2.0023,2.0023,0,0,0,28,6ZM20,24H12V22a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1Zm8,0H22V22a3,3,0,0,0-3-3H13a3,3,0,0,0-3,3v2H4V8H28Z"
  })), _path238 || (_path238 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,18a4,4,0,1,0-4-4A4,4,0,0,0,16,18Zm0-6a2,2,0,1,1-2,2A2,2,0,0,1,16,12Z"
  })), children);
});
var DocumentHorizontal16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentHorizontal16(_ref160, ref) {
  var children = _ref160.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref160, _excluded160);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path239 || (_path239 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,6H4A2.0023,2.0023,0,0,0,2,8V24a2.0023,2.0023,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V8A2.0023,2.0023,0,0,0,28,6ZM20,24H12V22a1,1,0,0,1,1-1h6a1,1,0,0,1,1,1Zm8,0H22V22a3,3,0,0,0-3-3H13a3,3,0,0,0-3,3v2H4V8H28Z"
  })), _path240 || (_path240 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,18a4,4,0,1,0-4-4A4,4,0,0,0,16,18Zm0-6a2,2,0,1,1-2,2A2,2,0,0,1,16,12Z"
  })), children);
});
var DocumentImport32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentImport32(_ref161, ref) {
  var children = _ref161.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref161, _excluded161);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path241 || (_path241 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 19L14.83 19 17.41 16.41 16 15 11 20 16 25 17.41 23.59 14.83 21 28 21 28 19z"
  })), _path242 || (_path242 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,14V10a1,1,0,0,0-.29-.71l-7-7A1,1,0,0,0,16,2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H22a2,2,0,0,0,2-2V26H22v2H6V4h8v6a2,2,0,0,0,2,2h6v2Zm-8-4V4.41L21.59,10Z"
  })), children);
});
var DocumentImport24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentImport24(_ref162, ref) {
  var children = _ref162.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref162, _excluded162);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path243 || (_path243 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 19L14.83 19 17.41 16.41 16 15 11 20 16 25 17.41 23.59 14.83 21 28 21 28 19z"
  })), _path244 || (_path244 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,14V10a1,1,0,0,0-.29-.71l-7-7A1,1,0,0,0,16,2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H22a2,2,0,0,0,2-2V26H22v2H6V4h8v6a2,2,0,0,0,2,2h6v2Zm-8-4V4.41L21.59,10Z"
  })), children);
});
var DocumentImport20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentImport20(_ref163, ref) {
  var children = _ref163.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref163, _excluded163);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path245 || (_path245 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 19L14.83 19 17.41 16.41 16 15 11 20 16 25 17.41 23.59 14.83 21 28 21 28 19z"
  })), _path246 || (_path246 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,14V10a1,1,0,0,0-.29-.71l-7-7A1,1,0,0,0,16,2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H22a2,2,0,0,0,2-2V26H22v2H6V4h8v6a2,2,0,0,0,2,2h6v2Zm-8-4V4.41L21.59,10Z"
  })), children);
});
var DocumentImport16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentImport16(_ref164, ref) {
  var children = _ref164.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref164, _excluded164);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path247 || (_path247 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28 19L14.83 19 17.41 16.41 16 15 11 20 16 25 17.41 23.59 14.83 21 28 21 28 19z"
  })), _path248 || (_path248 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,14V10a1,1,0,0,0-.29-.71l-7-7A1,1,0,0,0,16,2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H22a2,2,0,0,0,2-2V26H22v2H6V4h8v6a2,2,0,0,0,2,2h6v2Zm-8-4V4.41L21.59,10Z"
  })), children);
});
var DocumentPdf32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentPdf32(_ref165, ref) {
  var children = _ref165.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref165, _excluded165);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path249 || (_path249 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 18L30 16 24 16 24 26 26 26 26 22 29 22 29 20 26 20 26 18 30 18zM19 26H15V16h4a3.0033 3.0033 0 013 3v4A3.0033 3.0033 0 0119 26zm-2-2h2a1.0011 1.0011 0 001-1V19a1.0011 1.0011 0 00-1-1H17zM11 16H6V26H8V23h3a2.0027 2.0027 0 002-2V18A2.0023 2.0023 0 0011 16zM8 21V18h3l.001 3z"
  })), _path250 || (_path250 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,14,2H4A2.0059,2.0059,0,0,0,2,4V28a2,2,0,0,0,2,2H20V28H4V4h8v6a2.0059,2.0059,0,0,0,2,2h6v2Zm-8-4V4.4L19.6,10Z"
  })), children);
});
var DocumentPdf24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentPdf24(_ref166, ref) {
  var children = _ref166.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref166, _excluded166);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path251 || (_path251 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 18L30 16 24 16 24 26 26 26 26 22 29 22 29 20 26 20 26 18 30 18zM19 26H15V16h4a3.0033 3.0033 0 013 3v4A3.0033 3.0033 0 0119 26zm-2-2h2a1.0011 1.0011 0 001-1V19a1.0011 1.0011 0 00-1-1H17zM11 16H6V26H8V23h3a2.0027 2.0027 0 002-2V18A2.0023 2.0023 0 0011 16zM8 21V18h3l.001 3z"
  })), _path252 || (_path252 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,14,2H4A2.0059,2.0059,0,0,0,2,4V28a2,2,0,0,0,2,2H20V28H4V4h8v6a2.0059,2.0059,0,0,0,2,2h6v2Zm-8-4V4.4L19.6,10Z"
  })), children);
});
var DocumentPdf20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentPdf20(_ref167, ref) {
  var children = _ref167.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref167, _excluded167);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path253 || (_path253 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 18L30 16 24 16 24 26 26 26 26 22 29 22 29 20 26 20 26 18 30 18zM19 26H15V16h4a3.0033 3.0033 0 013 3v4A3.0033 3.0033 0 0119 26zm-2-2h2a1.0011 1.0011 0 001-1V19a1.0011 1.0011 0 00-1-1H17zM11 16H6V26H8V23h3a2.0027 2.0027 0 002-2V18A2.0023 2.0023 0 0011 16zM8 21V18h3l.001 3z"
  })), _path254 || (_path254 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,14,2H4A2.0059,2.0059,0,0,0,2,4V28a2,2,0,0,0,2,2H20V28H4V4h8v6a2.0059,2.0059,0,0,0,2,2h6v2Zm-8-4V4.4L19.6,10Z"
  })), children);
});
var DocumentPdf16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentPdf16(_ref168, ref) {
  var children = _ref168.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref168, _excluded168);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path255 || (_path255 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 18L30 16 24 16 24 26 26 26 26 22 29 22 29 20 26 20 26 18 30 18zM19 26H15V16h4a3.0033 3.0033 0 013 3v4A3.0033 3.0033 0 0119 26zm-2-2h2a1.0011 1.0011 0 001-1V19a1.0011 1.0011 0 00-1-1H17zM11 16H6V26H8V23h3a2.0027 2.0027 0 002-2V18A2.0023 2.0023 0 0011 16zM8 21V18h3l.001 3z"
  })), _path256 || (_path256 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22,14V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,14,2H4A2.0059,2.0059,0,0,0,2,4V28a2,2,0,0,0,2,2H20V28H4V4h8v6a2.0059,2.0059,0,0,0,2,2h6v2Zm-8-4V4.4L19.6,10Z"
  })), children);
});
var DocumentPreliminary32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentPreliminary32(_ref169, ref) {
  var children = _ref169.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref169, _excluded169);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path257 || (_path257 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30a6 6 0 116-6A6.0067 6.0067 0 0124 30zm0-10a4 4 0 104 4A4.0045 4.0045 0 0024 20zM8 22H16V24H8zM8 16H18V18H8z"
  })), _path258 || (_path258 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H6V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,16,2H6A2.0058,2.0058,0,0,0,4,4V28a2.0058,2.0058,0,0,0,2,2H16ZM16,4.4,21.6,10H16Z"
  })), children);
});
var DocumentPreliminary24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentPreliminary24(_ref170, ref) {
  var children = _ref170.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref170, _excluded170);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path259 || (_path259 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30a6 6 0 116-6A6.0067 6.0067 0 0124 30zm0-10a4 4 0 104 4A4.0045 4.0045 0 0024 20zM8 22H16V24H8zM8 16H18V18H8z"
  })), _path260 || (_path260 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H6V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,16,2H6A2.0058,2.0058,0,0,0,4,4V28a2.0058,2.0058,0,0,0,2,2H16ZM16,4.4,21.6,10H16Z"
  })), children);
});
var DocumentPreliminary20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentPreliminary20(_ref171, ref) {
  var children = _ref171.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref171, _excluded171);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path261 || (_path261 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30a6 6 0 116-6A6.0067 6.0067 0 0124 30zm0-10a4 4 0 104 4A4.0045 4.0045 0 0024 20zM8 22H16V24H8zM8 16H18V18H8z"
  })), _path262 || (_path262 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H6V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,16,2H6A2.0058,2.0058,0,0,0,4,4V28a2.0058,2.0058,0,0,0,2,2H16ZM16,4.4,21.6,10H16Z"
  })), children);
});
var DocumentPreliminary16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentPreliminary16(_ref172, ref) {
  var children = _ref172.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref172, _excluded172);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path263 || (_path263 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24 30a6 6 0 116-6A6.0067 6.0067 0 0124 30zm0-10a4 4 0 104 4A4.0045 4.0045 0 0024 20zM8 22H16V24H8zM8 16H18V18H8z"
  })), _path264 || (_path264 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H6V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,16,2H6A2.0058,2.0058,0,0,0,4,4V28a2.0058,2.0058,0,0,0,2,2H16ZM16,4.4,21.6,10H16Z"
  })), children);
});
var DocumentProtected32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentProtected32(_ref173, ref) {
  var children = _ref173.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref173, _excluded173);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path265 || (_path265 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,21V18a4,4,0,0,0-8,0v3a2.0025,2.0025,0,0,0-2,2v5a2.0025,2.0025,0,0,0,2,2h8a2.0025,2.0025,0,0,0,2-2V23A2.0025,2.0025,0,0,0,28,21Zm-6-3a2,2,0,0,1,4,0v3H22ZM20,28V23h8v5Z"
  })), _path266 || (_path266 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.499,9.085,16.707,2.293A1,1,0,0,0,16,2H6A2.0058,2.0058,0,0,0,4,4V28a2.0058,2.0058,0,0,0,2,2h8V28H6V4h8v6a2.0023,2.0023,0,0,0,2,2h6.292a1.7075,1.7075,0,0,0,1.207-2.915ZM16,10V4.4141L21.5854,10Z"
  })), children);
});
var DocumentProtected24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentProtected24(_ref174, ref) {
  var children = _ref174.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref174, _excluded174);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path267 || (_path267 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,21V18a4,4,0,0,0-8,0v3a2.0025,2.0025,0,0,0-2,2v5a2.0025,2.0025,0,0,0,2,2h8a2.0025,2.0025,0,0,0,2-2V23A2.0025,2.0025,0,0,0,28,21Zm-6-3a2,2,0,0,1,4,0v3H22ZM20,28V23h8v5Z"
  })), _path268 || (_path268 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.499,9.085,16.707,2.293A1,1,0,0,0,16,2H6A2.0058,2.0058,0,0,0,4,4V28a2.0058,2.0058,0,0,0,2,2h8V28H6V4h8v6a2.0023,2.0023,0,0,0,2,2h6.292a1.7075,1.7075,0,0,0,1.207-2.915ZM16,10V4.4141L21.5854,10Z"
  })), children);
});
var DocumentProtected20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentProtected20(_ref175, ref) {
  var children = _ref175.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref175, _excluded175);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path269 || (_path269 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,21V18a4,4,0,0,0-8,0v3a2.0025,2.0025,0,0,0-2,2v5a2.0025,2.0025,0,0,0,2,2h8a2.0025,2.0025,0,0,0,2-2V23A2.0025,2.0025,0,0,0,28,21Zm-6-3a2,2,0,0,1,4,0v3H22ZM20,28V23h8v5Z"
  })), _path270 || (_path270 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.499,9.085,16.707,2.293A1,1,0,0,0,16,2H6A2.0058,2.0058,0,0,0,4,4V28a2.0058,2.0058,0,0,0,2,2h8V28H6V4h8v6a2.0023,2.0023,0,0,0,2,2h6.292a1.7075,1.7075,0,0,0,1.207-2.915ZM16,10V4.4141L21.5854,10Z"
  })), children);
});
var DocumentProtected16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentProtected16(_ref176, ref) {
  var children = _ref176.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref176, _excluded176);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path271 || (_path271 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,21V18a4,4,0,0,0-8,0v3a2.0025,2.0025,0,0,0-2,2v5a2.0025,2.0025,0,0,0,2,2h8a2.0025,2.0025,0,0,0,2-2V23A2.0025,2.0025,0,0,0,28,21Zm-6-3a2,2,0,0,1,4,0v3H22ZM20,28V23h8v5Z"
  })), _path272 || (_path272 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.499,9.085,16.707,2.293A1,1,0,0,0,16,2H6A2.0058,2.0058,0,0,0,4,4V28a2.0058,2.0058,0,0,0,2,2h8V28H6V4h8v6a2.0023,2.0023,0,0,0,2,2h6.292a1.7075,1.7075,0,0,0,1.207-2.915ZM16,10V4.4141L21.5854,10Z"
  })), children);
});
var DocumentSecurity32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSecurity32(_ref177, ref) {
  var children = _ref177.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref177, _excluded177);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path273 || (_path273 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,30l-2.1387-1.0127A5.0216,5.0216,0,0,1,18,24.4678V18H28v6.4678a5.0216,5.0216,0,0,1-2.8613,4.52ZM20,20v4.4678a3.012,3.012,0,0,0,1.7168,2.7109L23,27.7861l1.2832-.6074A3.012,3.012,0,0,0,26,24.4678V20Z"
  })), _path274 || (_path274 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H6V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,16,2H6A2.0058,2.0058,0,0,0,4,4V28a2.0058,2.0058,0,0,0,2,2H16ZM16,4.4,21.6,10H16Z"
  })), children);
});
var DocumentSecurity24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSecurity24(_ref178, ref) {
  var children = _ref178.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref178, _excluded178);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path275 || (_path275 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,30l-2.1387-1.0127A5.0216,5.0216,0,0,1,18,24.4678V18H28v6.4678a5.0216,5.0216,0,0,1-2.8613,4.52ZM20,20v4.4678a3.012,3.012,0,0,0,1.7168,2.7109L23,27.7861l1.2832-.6074A3.012,3.012,0,0,0,26,24.4678V20Z"
  })), _path276 || (_path276 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H6V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,16,2H6A2.0058,2.0058,0,0,0,4,4V28a2.0058,2.0058,0,0,0,2,2H16ZM16,4.4,21.6,10H16Z"
  })), children);
});
var DocumentSecurity20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSecurity20(_ref179, ref) {
  var children = _ref179.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref179, _excluded179);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path277 || (_path277 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,30l-2.1387-1.0127A5.0216,5.0216,0,0,1,18,24.4678V18H28v6.4678a5.0216,5.0216,0,0,1-2.8613,4.52ZM20,20v4.4678a3.012,3.012,0,0,0,1.7168,2.7109L23,27.7861l1.2832-.6074A3.012,3.012,0,0,0,26,24.4678V20Z"
  })), _path278 || (_path278 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H6V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,16,2H6A2.0058,2.0058,0,0,0,4,4V28a2.0058,2.0058,0,0,0,2,2H16ZM16,4.4,21.6,10H16Z"
  })), children);
});
var DocumentSecurity16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSecurity16(_ref180, ref) {
  var children = _ref180.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref180, _excluded180);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path279 || (_path279 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23,30l-2.1387-1.0127A5.0216,5.0216,0,0,1,18,24.4678V18H28v6.4678a5.0216,5.0216,0,0,1-2.8613,4.52ZM20,20v4.4678a3.012,3.012,0,0,0,1.7168,2.7109L23,27.7861l1.2832-.6074A3.012,3.012,0,0,0,26,24.4678V20Z"
  })), _path280 || (_path280 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H6V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,16,2H6A2.0058,2.0058,0,0,0,4,4V28a2.0058,2.0058,0,0,0,2,2H16ZM16,4.4,21.6,10H16Z"
  })), children);
});
var DocumentSigned32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSigned32(_ref181, ref) {
  var children = _ref181.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref181, _excluded181);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path281 || (_path281 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.4141,30H15V25.5857l5.0337-5.0337A4.6069,4.6069,0,0,1,20,20a5,5,0,1,1,4.4478,4.9663ZM17,28h1.5859l5.2061-5.2063.5395.1238a3.0351,3.0351,0,1,0-2.249-2.2488l.1236.5393L17,26.4143Z"
  })), _circle13 || (_circle13 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "20",
    r: "1"
  })), _path282 || (_path282 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 6H20V8H8zM8 10H20V12H8zM8 14H14V16H8zM8 24H12V26H8z"
  })), _path283 || (_path283 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2v9H22V4H6V28h6Z"
  })), children);
});
var DocumentSigned24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSigned24(_ref182, ref) {
  var children = _ref182.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref182, _excluded182);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path284 || (_path284 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.4141,30H15V25.5857l5.0337-5.0337A4.6069,4.6069,0,0,1,20,20a5,5,0,1,1,4.4478,4.9663ZM17,28h1.5859l5.2061-5.2063.5395.1238a3.0351,3.0351,0,1,0-2.249-2.2488l.1236.5393L17,26.4143Z"
  })), _circle14 || (_circle14 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "20",
    r: "1"
  })), _path285 || (_path285 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 6H20V8H8zM8 10H20V12H8zM8 14H14V16H8zM8 24H12V26H8z"
  })), _path286 || (_path286 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2v9H22V4H6V28h6Z"
  })), children);
});
var DocumentSigned20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSigned20(_ref183, ref) {
  var children = _ref183.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref183, _excluded183);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path287 || (_path287 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.4141,30H15V25.5857l5.0337-5.0337A4.6069,4.6069,0,0,1,20,20a5,5,0,1,1,4.4478,4.9663ZM17,28h1.5859l5.2061-5.2063.5395.1238a3.0351,3.0351,0,1,0-2.249-2.2488l.1236.5393L17,26.4143Z"
  })), _circle15 || (_circle15 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "20",
    r: "1"
  })), _path288 || (_path288 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 6H20V8H8zM8 10H20V12H8zM8 14H14V16H8zM8 24H12V26H8z"
  })), _path289 || (_path289 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2v9H22V4H6V28h6Z"
  })), children);
});
var DocumentSigned16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSigned16(_ref184, ref) {
  var children = _ref184.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref184, _excluded184);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path290 || (_path290 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M19.4141,30H15V25.5857l5.0337-5.0337A4.6069,4.6069,0,0,1,20,20a5,5,0,1,1,4.4478,4.9663ZM17,28h1.5859l5.2061-5.2063.5395.1238a3.0351,3.0351,0,1,0-2.249-2.2488l.1236.5393L17,26.4143Z"
  })), _circle16 || (_circle16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "25",
    cy: "20",
    r: "1"
  })), _path291 || (_path291 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M8 6H20V8H8zM8 10H20V12H8zM8 14H14V16H8zM8 24H12V26H8z"
  })), _path292 || (_path292 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,30H6a2.0021,2.0021,0,0,1-2-2V4A2.0021,2.0021,0,0,1,6,2H22a2.0021,2.0021,0,0,1,2,2v9H22V4H6V28h6Z"
  })), children);
});
var DocumentSketch32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSketch32(_ref185, ref) {
  var children = _ref185.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref185, _excluded185);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path293 || (_path293 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20l1.4272,1.9028L23,26.9629l-4.4272-5.06L20,20h6m1-2H19l-3,4,7,8,7-8-3-4Z"
  })), _path294 || (_path294 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3l2,0V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentSketch24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSketch24(_ref186, ref) {
  var children = _ref186.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref186, _excluded186);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path295 || (_path295 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20l1.4272,1.9028L23,26.9629l-4.4272-5.06L20,20h6m1-2H19l-3,4,7,8,7-8-3-4Z"
  })), _path296 || (_path296 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3l2,0V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentSketch20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSketch20(_ref187, ref) {
  var children = _ref187.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref187, _excluded187);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path297 || (_path297 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20l1.4272,1.9028L23,26.9629l-4.4272-5.06L20,20h6m1-2H19l-3,4,7,8,7-8-3-4Z"
  })), _path298 || (_path298 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3l2,0V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentSketch16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSketch16(_ref188, ref) {
  var children = _ref188.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref188, _excluded188);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path299 || (_path299 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26,20l1.4272,1.9028L23,26.9629l-4.4272-5.06L20,20h6m1-2H19l-3,4,7,8,7-8-3-4Z"
  })), _path300 || (_path300 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3l2,0V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentSubtract32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSubtract32(_ref189, ref) {
  var children = _ref189.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref189, _excluded189);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path301 || (_path301 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 24H30V26H20z"
  })), _path302 || (_path302 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v8h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentSubtract24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSubtract24(_ref190, ref) {
  var children = _ref190.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref190, _excluded190);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path303 || (_path303 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 24H30V26H20z"
  })), _path304 || (_path304 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v8h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentSubtract20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSubtract20(_ref191, ref) {
  var children = _ref191.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref191, _excluded191);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path305 || (_path305 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 24H30V26H20z"
  })), _path306 || (_path306 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v8h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentSubtract16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSubtract16(_ref192, ref) {
  var children = _ref192.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref192, _excluded192);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path307 || (_path307 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 24H30V26H20z"
  })), _path308 || (_path308 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v8h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h8ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentTasks32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentTasks32(_ref193, ref) {
  var children = _ref193.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref193, _excluded193);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path309 || (_path309 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 27.18L19.41 24.59 18 26 22 30 30 22 28.59 20.59 22 27.18z"
  })), _path310 || (_path310 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v6h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h7ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentTasks24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentTasks24(_ref194, ref) {
  var children = _ref194.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref194, _excluded194);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path311 || (_path311 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 27.18L19.41 24.59 18 26 22 30 30 22 28.59 20.59 22 27.18z"
  })), _path312 || (_path312 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v6h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h7ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentTasks20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentTasks20(_ref195, ref) {
  var children = _ref195.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref195, _excluded195);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path313 || (_path313 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 27.18L19.41 24.59 18 26 22 30 30 22 28.59 20.59 22 27.18z"
  })), _path314 || (_path314 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v6h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h7ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentTasks16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentTasks16(_ref196, ref) {
  var children = _ref196.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref196, _excluded196);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path315 || (_path315 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M22 27.18L19.41 24.59 18 26 22 30 30 22 28.59 20.59 22 27.18z"
  })), _path316 || (_path316 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M15,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v6h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h7ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentUnknown32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentUnknown32(_ref197, ref) {
  var children = _ref197.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref197, _excluded197);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle17 || (_circle17 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "28.5",
    r: "1.5"
  })), _path317 || (_path317 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,25H8V21h2a2,2,0,0,0,0-4H8a2.0023,2.0023,0,0,0-2,2v.5H4V19a4.0045,4.0045,0,0,1,4-4h2a4,4,0,0,1,0,8Z"
  })), _path318 || (_path318 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.7,9.3l-7-7A.9085.9085,0,0,0,20,2H10A2.0058,2.0058,0,0,0,8,4v8h2V4h8v6a2.0058,2.0058,0,0,0,2,2h6V28H14v2H26a2.0058,2.0058,0,0,0,2-2V10A.9092.9092,0,0,0,27.7,9.3ZM20,10V4.4L25.6,10Z"
  })), children);
});
var DocumentUnknown24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentUnknown24(_ref198, ref) {
  var children = _ref198.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref198, _excluded198);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle18 || (_circle18 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "28.5",
    r: "1.5"
  })), _path319 || (_path319 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,25H8V21h2a2,2,0,0,0,0-4H8a2.0023,2.0023,0,0,0-2,2v.5H4V19a4.0045,4.0045,0,0,1,4-4h2a4,4,0,0,1,0,8Z"
  })), _path320 || (_path320 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.7,9.3l-7-7A.9085.9085,0,0,0,20,2H10A2.0058,2.0058,0,0,0,8,4v8h2V4h8v6a2.0058,2.0058,0,0,0,2,2h6V28H14v2H26a2.0058,2.0058,0,0,0,2-2V10A.9092.9092,0,0,0,27.7,9.3ZM20,10V4.4L25.6,10Z"
  })), children);
});
var DocumentUnknown20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentUnknown20(_ref199, ref) {
  var children = _ref199.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref199, _excluded199);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle19 || (_circle19 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "28.5",
    r: "1.5"
  })), _path321 || (_path321 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,25H8V21h2a2,2,0,0,0,0-4H8a2.0023,2.0023,0,0,0-2,2v.5H4V19a4.0045,4.0045,0,0,1,4-4h2a4,4,0,0,1,0,8Z"
  })), _path322 || (_path322 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.7,9.3l-7-7A.9085.9085,0,0,0,20,2H10A2.0058,2.0058,0,0,0,8,4v8h2V4h8v6a2.0058,2.0058,0,0,0,2,2h6V28H14v2H26a2.0058,2.0058,0,0,0,2-2V10A.9092.9092,0,0,0,27.7,9.3ZM20,10V4.4L25.6,10Z"
  })), children);
});
var DocumentUnknown16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentUnknown16(_ref200, ref) {
  var children = _ref200.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref200, _excluded200);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle20 || (_circle20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "9",
    cy: "28.5",
    r: "1.5"
  })), _path323 || (_path323 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M10,25H8V21h2a2,2,0,0,0,0-4H8a2.0023,2.0023,0,0,0-2,2v.5H4V19a4.0045,4.0045,0,0,1,4-4h2a4,4,0,0,1,0,8Z"
  })), _path324 || (_path324 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M27.7,9.3l-7-7A.9085.9085,0,0,0,20,2H10A2.0058,2.0058,0,0,0,8,4v8h2V4h8v6a2.0058,2.0058,0,0,0,2,2h6V28H14v2H26a2.0058,2.0058,0,0,0,2-2V10A.9092.9092,0,0,0,27.7,9.3ZM20,10V4.4L25.6,10Z"
  })), children);
});
var DocumentUnprotected32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentUnprotected32(_ref201, ref) {
  var children = _ref201.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref201, _excluded201);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path325 || (_path325 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.499,9.085,16.707,2.293A1,1,0,0,0,16,2H6A2.0058,2.0058,0,0,0,4,4V28a2.0058,2.0058,0,0,0,2,2h8V28H6V4h8v6a2.0023,2.0023,0,0,0,2,2h6.292a1.7075,1.7075,0,0,0,1.207-2.915ZM16,10V4.4141L21.5854,10Z"
  })), _path326 || (_path326 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,21H22V18a2,2,0,0,1,4,0h2a4,4,0,0,0-8,0v3a2.0025,2.0025,0,0,0-2,2v5a2.0025,2.0025,0,0,0,2,2h8a2.0025,2.0025,0,0,0,2-2V23A2.0025,2.0025,0,0,0,28,21Zm-8,7V23h8v5Z"
  })), children);
});
var DocumentUnprotected24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentUnprotected24(_ref202, ref) {
  var children = _ref202.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref202, _excluded202);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path327 || (_path327 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.499,9.085,16.707,2.293A1,1,0,0,0,16,2H6A2.0058,2.0058,0,0,0,4,4V28a2.0058,2.0058,0,0,0,2,2h8V28H6V4h8v6a2.0023,2.0023,0,0,0,2,2h6.292a1.7075,1.7075,0,0,0,1.207-2.915ZM16,10V4.4141L21.5854,10Z"
  })), _path328 || (_path328 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,21H22V18a2,2,0,0,1,4,0h2a4,4,0,0,0-8,0v3a2.0025,2.0025,0,0,0-2,2v5a2.0025,2.0025,0,0,0,2,2h8a2.0025,2.0025,0,0,0,2-2V23A2.0025,2.0025,0,0,0,28,21Zm-8,7V23h8v5Z"
  })), children);
});
var DocumentUnprotected20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentUnprotected20(_ref203, ref) {
  var children = _ref203.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref203, _excluded203);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path329 || (_path329 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.499,9.085,16.707,2.293A1,1,0,0,0,16,2H6A2.0058,2.0058,0,0,0,4,4V28a2.0058,2.0058,0,0,0,2,2h8V28H6V4h8v6a2.0023,2.0023,0,0,0,2,2h6.292a1.7075,1.7075,0,0,0,1.207-2.915ZM16,10V4.4141L21.5854,10Z"
  })), _path330 || (_path330 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,21H22V18a2,2,0,0,1,4,0h2a4,4,0,0,0-8,0v3a2.0025,2.0025,0,0,0-2,2v5a2.0025,2.0025,0,0,0,2,2h8a2.0025,2.0025,0,0,0,2-2V23A2.0025,2.0025,0,0,0,28,21Zm-8,7V23h8v5Z"
  })), children);
});
var DocumentUnprotected16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentUnprotected16(_ref204, ref) {
  var children = _ref204.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref204, _excluded204);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path331 || (_path331 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M23.499,9.085,16.707,2.293A1,1,0,0,0,16,2H6A2.0058,2.0058,0,0,0,4,4V28a2.0058,2.0058,0,0,0,2,2h8V28H6V4h8v6a2.0023,2.0023,0,0,0,2,2h6.292a1.7075,1.7075,0,0,0,1.207-2.915ZM16,10V4.4141L21.5854,10Z"
  })), _path332 || (_path332 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28,21H22V18a2,2,0,0,1,4,0h2a4,4,0,0,0-8,0v3a2.0025,2.0025,0,0,0-2,2v5a2.0025,2.0025,0,0,0,2,2h8a2.0025,2.0025,0,0,0,2-2V23A2.0025,2.0025,0,0,0,28,21Zm-8,7V23h8v5Z"
  })), children);
});
var DocumentVertical32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentVertical32(_ref205, ref) {
  var children = _ref205.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref205, _excluded205);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path333 || (_path333 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,14a4,4,0,1,1,4-4h0A4.0118,4.0118,0,0,1,16,14Zm0-6a2,2,0,1,0,2,2h0a2.0059,2.0059,0,0,0-2-2Z"
  })), _path334 || (_path334 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,2H8A2.0023,2.0023,0,0,0,6,4V28a2.0023,2.0023,0,0,0,2,2H24a2.0023,2.0023,0,0,0,2-2V4A2.0023,2.0023,0,0,0,24,2ZM12,24V18a.9447.9447,0,0,1,1-1h6a.9447.9447,0,0,1,1,1v6H18v4H14V24Zm8,4V26a2.0058,2.0058,0,0,0,2-2V18a2.9463,2.9463,0,0,0-3-3H13a2.9463,2.9463,0,0,0-3,3v6a2.0058,2.0058,0,0,0,2,2v2H8V4H24V28Z"
  })), children);
});
var DocumentVertical24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentVertical24(_ref206, ref) {
  var children = _ref206.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref206, _excluded206);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path335 || (_path335 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,14a4,4,0,1,1,4-4h0A4.0118,4.0118,0,0,1,16,14Zm0-6a2,2,0,1,0,2,2h0a2.0059,2.0059,0,0,0-2-2Z"
  })), _path336 || (_path336 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,2H8A2.0023,2.0023,0,0,0,6,4V28a2.0023,2.0023,0,0,0,2,2H24a2.0023,2.0023,0,0,0,2-2V4A2.0023,2.0023,0,0,0,24,2ZM12,24V18a.9447.9447,0,0,1,1-1h6a.9447.9447,0,0,1,1,1v6H18v4H14V24Zm8,4V26a2.0058,2.0058,0,0,0,2-2V18a2.9463,2.9463,0,0,0-3-3H13a2.9463,2.9463,0,0,0-3,3v6a2.0058,2.0058,0,0,0,2,2v2H8V4H24V28Z"
  })), children);
});
var DocumentVertical20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentVertical20(_ref207, ref) {
  var children = _ref207.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref207, _excluded207);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path337 || (_path337 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,14a4,4,0,1,1,4-4h0A4.0118,4.0118,0,0,1,16,14Zm0-6a2,2,0,1,0,2,2h0a2.0059,2.0059,0,0,0-2-2Z"
  })), _path338 || (_path338 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,2H8A2.0023,2.0023,0,0,0,6,4V28a2.0023,2.0023,0,0,0,2,2H24a2.0023,2.0023,0,0,0,2-2V4A2.0023,2.0023,0,0,0,24,2ZM12,24V18a.9447.9447,0,0,1,1-1h6a.9447.9447,0,0,1,1,1v6H18v4H14V24Zm8,4V26a2.0058,2.0058,0,0,0,2-2V18a2.9463,2.9463,0,0,0-3-3H13a2.9463,2.9463,0,0,0-3,3v6a2.0058,2.0058,0,0,0,2,2v2H8V4H24V28Z"
  })), children);
});
var DocumentVertical16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentVertical16(_ref208, ref) {
  var children = _ref208.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref208, _excluded208);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path339 || (_path339 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16,14a4,4,0,1,1,4-4h0A4.0118,4.0118,0,0,1,16,14Zm0-6a2,2,0,1,0,2,2h0a2.0059,2.0059,0,0,0-2-2Z"
  })), _path340 || (_path340 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M24,2H8A2.0023,2.0023,0,0,0,6,4V28a2.0023,2.0023,0,0,0,2,2H24a2.0023,2.0023,0,0,0,2-2V4A2.0023,2.0023,0,0,0,24,2ZM12,24V18a.9447.9447,0,0,1,1-1h6a.9447.9447,0,0,1,1,1v6H18v4H14V24Zm8,4V26a2.0058,2.0058,0,0,0,2-2V18a2.9463,2.9463,0,0,0-3-3H13a2.9463,2.9463,0,0,0-3,3v6a2.0058,2.0058,0,0,0,2,2v2H8V4H24V28Z"
  })), children);
});
var DocumentVideo32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentVideo32(_ref209, ref) {
  var children = _ref209.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref209, _excluded209);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path341 || (_path341 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,19l-4,3.2V20a2.0023,2.0023,0,0,0-2-2H16a2.0023,2.0023,0,0,0-2,2v6a2.0023,2.0023,0,0,0,2,2h8a2.0023,2.0023,0,0,0,2-2V23.8L30,27ZM16,26V20h8l.0015,6Z"
  })), _path342 || (_path342 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3l2,0V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h4ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentVideo24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentVideo24(_ref210, ref) {
  var children = _ref210.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref210, _excluded210);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path343 || (_path343 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,19l-4,3.2V20a2.0023,2.0023,0,0,0-2-2H16a2.0023,2.0023,0,0,0-2,2v6a2.0023,2.0023,0,0,0,2,2h8a2.0023,2.0023,0,0,0,2-2V23.8L30,27ZM16,26V20h8l.0015,6Z"
  })), _path344 || (_path344 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3l2,0V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h4ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentVideo20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentVideo20(_ref211, ref) {
  var children = _ref211.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref211, _excluded211);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path345 || (_path345 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,19l-4,3.2V20a2.0023,2.0023,0,0,0-2-2H16a2.0023,2.0023,0,0,0-2,2v6a2.0023,2.0023,0,0,0,2,2h8a2.0023,2.0023,0,0,0,2-2V23.8L30,27ZM16,26V20h8l.0015,6Z"
  })), _path346 || (_path346 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3l2,0V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h4ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentVideo16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentVideo16(_ref212, ref) {
  var children = _ref212.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref212, _excluded212);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path347 || (_path347 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30,19l-4,3.2V20a2.0023,2.0023,0,0,0-2-2H16a2.0023,2.0023,0,0,0-2,2v6a2.0023,2.0023,0,0,0,2,2h8a2.0023,2.0023,0,0,0,2-2V23.8L30,27ZM16,26V20h8l.0015,6Z"
  })), _path348 || (_path348 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v3l2,0V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h4ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentView32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentView32(_ref213, ref) {
  var children = _ref213.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref213, _excluded213);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle21 || (_circle21 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "24",
    r: "2"
  })), _path349 || (_path349 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M22,28a4,4,0,1,1,4-4A4.0039,4.0039,0,0,1,22,28Zm0-6a2,2,0,1,0,2,2A2.0027,2.0027,0,0,0,22,22Z"
  })), _path350 || (_path350 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769,23.4785A8.64,8.64,0,0,0,22,18a8.64,8.64,0,0,0-7.7769,5.4785L14,24l.2231.5215A8.64,8.64,0,0,0,22,30a8.64,8.64,0,0,0,7.7769-5.4785L30,24ZM22,28a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,22,28Z"
  })), _path351 || (_path351 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v4h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h4ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentView24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentView24(_ref214, ref) {
  var children = _ref214.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref214, _excluded214);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle22 || (_circle22 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "24",
    r: "2"
  })), _path352 || (_path352 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M22,28a4,4,0,1,1,4-4A4.0039,4.0039,0,0,1,22,28Zm0-6a2,2,0,1,0,2,2A2.0027,2.0027,0,0,0,22,22Z"
  })), _path353 || (_path353 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769,23.4785A8.64,8.64,0,0,0,22,18a8.64,8.64,0,0,0-7.7769,5.4785L14,24l.2231.5215A8.64,8.64,0,0,0,22,30a8.64,8.64,0,0,0,7.7769-5.4785L30,24ZM22,28a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,22,28Z"
  })), _path354 || (_path354 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v4h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h4ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentView20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentView20(_ref215, ref) {
  var children = _ref215.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref215, _excluded215);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle23 || (_circle23 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "24",
    r: "2"
  })), _path355 || (_path355 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M22,28a4,4,0,1,1,4-4A4.0039,4.0039,0,0,1,22,28Zm0-6a2,2,0,1,0,2,2A2.0027,2.0027,0,0,0,22,22Z"
  })), _path356 || (_path356 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769,23.4785A8.64,8.64,0,0,0,22,18a8.64,8.64,0,0,0-7.7769,5.4785L14,24l.2231.5215A8.64,8.64,0,0,0,22,30a8.64,8.64,0,0,0,7.7769-5.4785L30,24ZM22,28a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,22,28Z"
  })), _path357 || (_path357 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v4h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h4ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentView16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentView16(_ref216, ref) {
  var children = _ref216.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref216, _excluded216);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle24 || (_circle24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "22",
    cy: "24",
    r: "2"
  })), _path358 || (_path358 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    fill: "none",
    d: "M22,28a4,4,0,1,1,4-4A4.0039,4.0039,0,0,1,22,28Zm0-6a2,2,0,1,0,2,2A2.0027,2.0027,0,0,0,22,22Z"
  })), _path359 || (_path359 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M29.7769,23.4785A8.64,8.64,0,0,0,22,18a8.64,8.64,0,0,0-7.7769,5.4785L14,24l.2231.5215A8.64,8.64,0,0,0,22,30a8.64,8.64,0,0,0,7.7769-5.4785L30,24ZM22,28a4,4,0,1,1,4-4A4.0045,4.0045,0,0,1,22,28Z"
  })), _path360 || (_path360 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M12,28H8V4h8v6a2.0058,2.0058,0,0,0,2,2h6v4h2V10a.9092.9092,0,0,0-.3-.7l-7-7A.9087.9087,0,0,0,18,2H8A2.0058,2.0058,0,0,0,6,4V28a2.0058,2.0058,0,0,0,2,2h4ZM18,4.4,23.6,10H18Z"
  })), children);
});
var DocumentWordProcessor32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentWordProcessor32(_ref217, ref) {
  var children = _ref217.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref217, _excluded217);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path361 || (_path361 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.3 20L27.391 28.611 26 20 24 20 22.609 28.611 21.7 20 20 20 21.36 30 23.64 30 25 21.626 26.36 30 28.64 30 30 20 28.3 20z"
  })), _path362 || (_path362 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.707,9.293l-7-7A1,1,0,0,0,18,2H8A2.002,2.002,0,0,0,6,4V28a2.0023,2.0023,0,0,0,2,2h8V28H8V4h8v6a2.002,2.002,0,0,0,2,2h6v4h2V10A1,1,0,0,0,25.707,9.293ZM18,4.4141,23.5859,10H18Z"
  })), children);
});
var DocumentWordProcessor24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentWordProcessor24(_ref218, ref) {
  var children = _ref218.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref218, _excluded218);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path363 || (_path363 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.3 20L27.391 28.611 26 20 24 20 22.609 28.611 21.7 20 20 20 21.36 30 23.64 30 25 21.626 26.36 30 28.64 30 30 20 28.3 20z"
  })), _path364 || (_path364 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.707,9.293l-7-7A1,1,0,0,0,18,2H8A2.002,2.002,0,0,0,6,4V28a2.0023,2.0023,0,0,0,2,2h8V28H8V4h8v6a2.002,2.002,0,0,0,2,2h6v4h2V10A1,1,0,0,0,25.707,9.293ZM18,4.4141,23.5859,10H18Z"
  })), children);
});
var DocumentWordProcessor20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentWordProcessor20(_ref219, ref) {
  var children = _ref219.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref219, _excluded219);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path365 || (_path365 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.3 20L27.391 28.611 26 20 24 20 22.609 28.611 21.7 20 20 20 21.36 30 23.64 30 25 21.626 26.36 30 28.64 30 30 20 28.3 20z"
  })), _path366 || (_path366 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.707,9.293l-7-7A1,1,0,0,0,18,2H8A2.002,2.002,0,0,0,6,4V28a2.0023,2.0023,0,0,0,2,2h8V28H8V4h8v6a2.002,2.002,0,0,0,2,2h6v4h2V10A1,1,0,0,0,25.707,9.293ZM18,4.4141,23.5859,10H18Z"
  })), children);
});
var DocumentWordProcessor16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentWordProcessor16(_ref220, ref) {
  var children = _ref220.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref220, _excluded220);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path367 || (_path367 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.3 20L27.391 28.611 26 20 24 20 22.609 28.611 21.7 20 20 20 21.36 30 23.64 30 25 21.626 26.36 30 28.64 30 30 20 28.3 20z"
  })), _path368 || (_path368 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.707,9.293l-7-7A1,1,0,0,0,18,2H8A2.002,2.002,0,0,0,6,4V28a2.0023,2.0023,0,0,0,2,2h8V28H8V4h8v6a2.002,2.002,0,0,0,2,2h6v4h2V10A1,1,0,0,0,25.707,9.293ZM18,4.4141,23.5859,10H18Z"
  })), children);
});
var DocumentWordProcessorReference32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentWordProcessorReference32(_ref221, ref) {
  var children = _ref221.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref221, _excluded221);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path369 || (_path369 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.3 20L27.391 28.611 26 20 24 20 22.609 28.611 21.7 20 20 20 21.36 30 23.64 30 25 21.626 26.36 30 28.64 30 30 20 28.3 20zM4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM25.707 9.293l-7-7A1 1 0 0018 2H8A2.002 2.002 0 006 4V16H8V4h8v6a2.002 2.002 0 002 2h6v4h2V10A1 1 0 0025.707 9.293zM18 10V4.4141L23.5859 10z"
  })), children);
});
var DocumentWordProcessorReference24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentWordProcessorReference24(_ref222, ref) {
  var children = _ref222.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref222, _excluded222);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path370 || (_path370 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.3 20L27.391 28.611 26 20 24 20 22.609 28.611 21.7 20 20 20 21.36 30 23.64 30 25 21.626 26.36 30 28.64 30 30 20 28.3 20zM4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM25.707 9.293l-7-7A1 1 0 0018 2H8A2.002 2.002 0 006 4V16H8V4h8v6a2.002 2.002 0 002 2h6v4h2V10A1 1 0 0025.707 9.293zM18 10V4.4141L23.5859 10z"
  })), children);
});
var DocumentWordProcessorReference20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentWordProcessorReference20(_ref223, ref) {
  var children = _ref223.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref223, _excluded223);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path371 || (_path371 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.3 20L27.391 28.611 26 20 24 20 22.609 28.611 21.7 20 20 20 21.36 30 23.64 30 25 21.626 26.36 30 28.64 30 30 20 28.3 20zM4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM25.707 9.293l-7-7A1 1 0 0018 2H8A2.002 2.002 0 006 4V16H8V4h8v6a2.002 2.002 0 002 2h6v4h2V10A1 1 0 0025.707 9.293zM18 10V4.4141L23.5859 10z"
  })), children);
});
var DocumentWordProcessorReference16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentWordProcessorReference16(_ref224, ref) {
  var children = _ref224.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref224, _excluded224);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path372 || (_path372 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M28.3 20L27.391 28.611 26 20 24 20 22.609 28.611 21.7 20 20 20 21.36 30 23.64 30 25 21.626 26.36 30 28.64 30 30 20 28.3 20zM4 20L4 22 8.586 22 2 28.586 3.414 30 10 23.414 10 28 12 28 12 20 4 20zM25.707 9.293l-7-7A1 1 0 0018 2H8A2.002 2.002 0 006 4V16H8V4h8v6a2.002 2.002 0 002 2h6v4h2V10A1 1 0 0025.707 9.293zM18 10V4.4141L23.5859 10z"
  })), children);
});
var DocumentSentiment32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSentiment32(_ref225, ref) {
  var children = _ref225.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref225, _excluded225);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path373 || (_path373 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.303,16a2.6616,2.6616,0,0,0-1.9079.8058l-.3932.4054-.397-.4054a2.6615,2.6615,0,0,0-3.8157,0,2.7992,2.7992,0,0,0,0,3.8964L16.0019,25l4.2089-4.2978a2.7992,2.7992,0,0,0,0-3.8964A2.6616,2.6616,0,0,0,18.303,16Z"
  })), _path374 || (_path374 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.7,9.3l-7-7A.9078.9078,0,0,0,18,2H8A2.0059,2.0059,0,0,0,6,4V28a2.0059,2.0059,0,0,0,2,2H24a2.0059,2.0059,0,0,0,2-2V10A.9078.9078,0,0,0,25.7,9.3ZM18,4.4,23.6,10H18ZM24,28H8V4h8v6a2.0059,2.0059,0,0,0,2,2h6Z"
  })), children);
});
var DocumentSentiment24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSentiment24(_ref226, ref) {
  var children = _ref226.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref226, _excluded226);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path375 || (_path375 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.303,16a2.6616,2.6616,0,0,0-1.9079.8058l-.3932.4054-.397-.4054a2.6615,2.6615,0,0,0-3.8157,0,2.7992,2.7992,0,0,0,0,3.8964L16.0019,25l4.2089-4.2978a2.7992,2.7992,0,0,0,0-3.8964A2.6616,2.6616,0,0,0,18.303,16Z"
  })), _path376 || (_path376 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.7,9.3l-7-7A.9078.9078,0,0,0,18,2H8A2.0059,2.0059,0,0,0,6,4V28a2.0059,2.0059,0,0,0,2,2H24a2.0059,2.0059,0,0,0,2-2V10A.9078.9078,0,0,0,25.7,9.3ZM18,4.4,23.6,10H18ZM24,28H8V4h8v6a2.0059,2.0059,0,0,0,2,2h6Z"
  })), children);
});
var DocumentSentiment20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSentiment20(_ref227, ref) {
  var children = _ref227.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref227, _excluded227);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path377 || (_path377 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.303,16a2.6616,2.6616,0,0,0-1.9079.8058l-.3932.4054-.397-.4054a2.6615,2.6615,0,0,0-3.8157,0,2.7992,2.7992,0,0,0,0,3.8964L16.0019,25l4.2089-4.2978a2.7992,2.7992,0,0,0,0-3.8964A2.6616,2.6616,0,0,0,18.303,16Z"
  })), _path378 || (_path378 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.7,9.3l-7-7A.9078.9078,0,0,0,18,2H8A2.0059,2.0059,0,0,0,6,4V28a2.0059,2.0059,0,0,0,2,2H24a2.0059,2.0059,0,0,0,2-2V10A.9078.9078,0,0,0,25.7,9.3ZM18,4.4,23.6,10H18ZM24,28H8V4h8v6a2.0059,2.0059,0,0,0,2,2h6Z"
  })), children);
});
var DocumentSentiment16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DocumentSentiment16(_ref228, ref) {
  var children = _ref228.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref228, _excluded228);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path379 || (_path379 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18.303,16a2.6616,2.6616,0,0,0-1.9079.8058l-.3932.4054-.397-.4054a2.6615,2.6615,0,0,0-3.8157,0,2.7992,2.7992,0,0,0,0,3.8964L16.0019,25l4.2089-4.2978a2.7992,2.7992,0,0,0,0-3.8964A2.6616,2.6616,0,0,0,18.303,16Z"
  })), _path380 || (_path380 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M25.7,9.3l-7-7A.9078.9078,0,0,0,18,2H8A2.0059,2.0059,0,0,0,6,4V28a2.0059,2.0059,0,0,0,2,2H24a2.0059,2.0059,0,0,0,2-2V10A.9078.9078,0,0,0,25.7,9.3ZM18,4.4,23.6,10H18ZM24,28H8V4h8v6a2.0059,2.0059,0,0,0,2,2h6Z"
  })), children);
});
var DogWalker32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DogWalker32(_ref229, ref) {
  var children = _ref229.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref229, _excluded229);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path381 || (_path381 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20H22V30H20zM4 23H6V30H4z"
  })), _path382 || (_path382 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30H14V26a1.0011 1.0011 0 00-1-1H11v5H9V23h4a3.0033 3.0033 0 013 3zM7.5 22A3.5041 3.5041 0 014 18.5V17H2V15H6v3.5a1.5 1.5 0 003 0V15h4v2H11v1.5A3.5041 3.5041 0 017.5 22zM27 10H21.354a2.9861 2.9861 0 00-2.7856 1.8857l-1.4419 3.6055-3.6079 4.51 1.562 1.249 3.7-4.625 1.645-3.9961A.9949.9949 0 0121.354 12H27a1.0009 1.0009 0 011 1v7H25V30h2V22h1a2.0023 2.0023 0 002-2V13A3.0033 3.0033 0 0027 10zM24 9a4 4 0 114-4A4.0045 4.0045 0 0124 9zm0-6a2 2 0 102 2A2.0021 2.0021 0 0024 3z"
  })), children);
});
var DogWalker24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DogWalker24(_ref230, ref) {
  var children = _ref230.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref230, _excluded230);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path383 || (_path383 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20H22V30H20zM4 23H6V30H4z"
  })), _path384 || (_path384 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30H14V26a1.0011 1.0011 0 00-1-1H11v5H9V23h4a3.0033 3.0033 0 013 3zM7.5 22A3.5041 3.5041 0 014 18.5V17H2V15H6v3.5a1.5 1.5 0 003 0V15h4v2H11v1.5A3.5041 3.5041 0 017.5 22zM27 10H21.354a2.9861 2.9861 0 00-2.7856 1.8857l-1.4419 3.6055-3.6079 4.51 1.562 1.249 3.7-4.625 1.645-3.9961A.9949.9949 0 0121.354 12H27a1.0009 1.0009 0 011 1v7H25V30h2V22h1a2.0023 2.0023 0 002-2V13A3.0033 3.0033 0 0027 10zM24 9a4 4 0 114-4A4.0045 4.0045 0 0124 9zm0-6a2 2 0 102 2A2.0021 2.0021 0 0024 3z"
  })), children);
});
var DogWalker20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DogWalker20(_ref231, ref) {
  var children = _ref231.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref231, _excluded231);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path385 || (_path385 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20H22V30H20zM4 23H6V30H4z"
  })), _path386 || (_path386 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30H14V26a1.0011 1.0011 0 00-1-1H11v5H9V23h4a3.0033 3.0033 0 013 3zM7.5 22A3.5041 3.5041 0 014 18.5V17H2V15H6v3.5a1.5 1.5 0 003 0V15h4v2H11v1.5A3.5041 3.5041 0 017.5 22zM27 10H21.354a2.9861 2.9861 0 00-2.7856 1.8857l-1.4419 3.6055-3.6079 4.51 1.562 1.249 3.7-4.625 1.645-3.9961A.9949.9949 0 0121.354 12H27a1.0009 1.0009 0 011 1v7H25V30h2V22h1a2.0023 2.0023 0 002-2V13A3.0033 3.0033 0 0027 10zM24 9a4 4 0 114-4A4.0045 4.0045 0 0124 9zm0-6a2 2 0 102 2A2.0021 2.0021 0 0024 3z"
  })), children);
});
var DogWalker16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DogWalker16(_ref232, ref) {
  var children = _ref232.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref232, _excluded232);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path387 || (_path387 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M20 20H22V30H20zM4 23H6V30H4z"
  })), _path388 || (_path388 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 30H14V26a1.0011 1.0011 0 00-1-1H11v5H9V23h4a3.0033 3.0033 0 013 3zM7.5 22A3.5041 3.5041 0 014 18.5V17H2V15H6v3.5a1.5 1.5 0 003 0V15h4v2H11v1.5A3.5041 3.5041 0 017.5 22zM27 10H21.354a2.9861 2.9861 0 00-2.7856 1.8857l-1.4419 3.6055-3.6079 4.51 1.562 1.249 3.7-4.625 1.645-3.9961A.9949.9949 0 0121.354 12H27a1.0009 1.0009 0 011 1v7H25V30h2V22h1a2.0023 2.0023 0 002-2V13A3.0033 3.0033 0 0027 10zM24 9a4 4 0 114-4A4.0045 4.0045 0 0124 9zm0-6a2 2 0 102 2A2.0021 2.0021 0 0024 3z"
  })), children);
});
var DotMark32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DotMark32(_ref233, ref) {
  var children = _ref233.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref233, _excluded233);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle25 || (_circle25 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "8"
  })), children);
});
var DotMark24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DotMark24(_ref234, ref) {
  var children = _ref234.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref234, _excluded234);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle26 || (_circle26 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "8"
  })), children);
});
var DotMark20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DotMark20(_ref235, ref) {
  var children = _ref235.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref235, _excluded235);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle27 || (_circle27 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "8"
  })), children);
});
var DotMark16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DotMark16(_ref236, ref) {
  var children = _ref236.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref236, _excluded236);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _circle28 || (_circle28 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("circle", {
    cx: "16",
    cy: "16",
    r: "8"
  })), children);
});
var DoubleInteger32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DoubleInteger32(_ref237, ref) {
  var children = _ref237.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref237, _excluded237);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path389 || (_path389 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 8V6H13V2H11V6H8V2H6V6H2V8H6v3H2v2H6v4H8V13h3v4h2V13h4V11H13V8zm-6 3H8V8h3zM30 21V19H26V15H24v4H21V15H19v4H15v2h4v3H15v2h4v4h2V26h3v4h2V26h4V24H26V21zm-6 3H21V21h3z"
  })), children);
});
var DoubleInteger24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DoubleInteger24(_ref238, ref) {
  var children = _ref238.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref238, _excluded238);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path390 || (_path390 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 8V6H13V2H11V6H8V2H6V6H2V8H6v3H2v2H6v4H8V13h3v4h2V13h4V11H13V8zm-6 3H8V8h3zM30 21V19H26V15H24v4H21V15H19v4H15v2h4v3H15v2h4v4h2V26h3v4h2V26h4V24H26V21zm-6 3H21V21h3z"
  })), children);
});
var DoubleInteger20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DoubleInteger20(_ref239, ref) {
  var children = _ref239.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref239, _excluded239);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path391 || (_path391 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 8V6H13V2H11V6H8V2H6V6H2V8H6v3H2v2H6v4H8V13h3v4h2V13h4V11H13V8zm-6 3H8V8h3zM30 21V19H26V15H24v4H21V15H19v4H15v2h4v3H15v2h4v4h2V26h3v4h2V26h4V24H26V21zm-6 3H21V21h3z"
  })), children);
});
var DoubleInteger16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DoubleInteger16(_ref240, ref) {
  var children = _ref240.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref240, _excluded240);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path392 || (_path392 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M17 8V6H13V2H11V6H8V2H6V6H2V8H6v3H2v2H6v4H8V13h3v4h2V13h4V11H13V8zm-6 3H8V8h3zM30 21V19H26V15H24v4H21V15H19v4H15v2h4v3H15v2h4v4h2V26h3v4h2V26h4V24H26V21zm-6 3H21V21h3z"
  })), children);
});
var DownToBottom32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DownToBottom32(_ref241, ref) {
  var children = _ref241.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref241, _excluded241);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path393 || (_path393 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 18L6 8 7.4 6.6 16 15.2 24.6 6.6 26 8zM4 22H28V24H4z"
  })), children);
});
var DownToBottom24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DownToBottom24(_ref242, ref) {
  var children = _ref242.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref242, _excluded242);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path394 || (_path394 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 18L6 8 7.4 6.6 16 15.2 24.6 6.6 26 8zM4 22H28V24H4z"
  })), children);
});
var DownToBottom20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DownToBottom20(_ref243, ref) {
  var children = _ref243.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref243, _excluded243);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path395 || (_path395 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 18L6 8 7.4 6.6 16 15.2 24.6 6.6 26 8zM4 22H28V24H4z"
  })), children);
});
var DownToBottom16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function DownToBottom16(_ref244, ref) {
  var children = _ref244.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref244, _excluded244);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path396 || (_path396 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M16 18L6 8 7.4 6.6 16 15.2 24.6 6.6 26 8zM4 22H28V24H4z"
  })), children);
});
var Download32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Download32(_ref245, ref) {
  var children = _ref245.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref245, _excluded245);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path397 || (_path397 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 24v4H6V24H4v4H4a2 2 0 002 2H26a2 2 0 002-2h0V24zM26 14L24.59 12.59 17 20.17 17 2 15 2 15 20.17 7.41 12.59 6 14 16 24 26 14z"
  })), children);
});
var Download24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Download24(_ref246, ref) {
  var children = _ref246.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref246, _excluded246);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path398 || (_path398 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 24v4H6V24H4v4H4a2 2 0 002 2H26a2 2 0 002-2h0V24zM26 14L24.59 12.59 17 20.17 17 2 15 2 15 20.17 7.41 12.59 6 14 16 24 26 14z"
  })), children);
});
var Download20 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Download20(_ref247, ref) {
  var children = _ref247.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref247, _excluded247);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 20,
    height: 20,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path399 || (_path399 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M26 24v4H6V24H4v4H4a2 2 0 002 2H26a2 2 0 002-2h0V24zM26 14L24.59 12.59 17 20.17 17 2 15 2 15 20.17 7.41 12.59 6 14 16 24 26 14z"
  })), children);
});
var Download16 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function Download16(_ref248, ref) {
  var children = _ref248.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref248, _excluded248);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path400 || (_path400 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M13 7L12.3 6.3 8.5 10.1 8.5 1 7.5 1 7.5 10.1 3.7 6.3 3 7 8 12zM13 12v2H3v-2H2v2l0 0c0 .6.4 1 1 1h10c.6 0 1-.4 1-1l0 0v-2H13z"
  })), children);
});
var WatsonHealthDownloadStudy32 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthDownloadStudy32(_ref249, ref) {
  var children = _ref249.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref249, _excluded249);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 32,
    height: 32,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path401 || (_path401 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 25L28.586 23.586 26 26.172 26 18 24 18 24 26.172 21.414 23.586 20 25 25 30 30 25zM19 14H23V16H19zM19 10H26V12H19zM9 18h6a3 3 0 013 3v2H16V21a1 1 0 00-1-1H9a1 1 0 00-1 1v2H6V21A3 3 0 019 18zM16 13a4 4 0 10-4 4A4 4 0 0016 13zm-2 0a2 2 0 11-2-2A2 2 0 0114 13z"
  })), _path402 || (_path402 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,26H4V6H28V16h2V6a2,2,0,0,0-2-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H18Z"
  })), children);
});
var WatsonHealthDownloadStudy24 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef(function WatsonHealthDownloadStudy24(_ref250, ref) {
  var children = _ref250.children,
      rest = (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__._)(_ref250, _excluded250);

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.I, (0,_Icon_9ecdf98c_js__WEBPACK_IMPORTED_MODULE_1__.a)({
    width: 24,
    height: 24,
    viewBox: "0 0 32 32",
    xmlns: "http://www.w3.org/2000/svg",
    fill: "currentColor",
    ref: ref
  }, rest), _path403 || (_path403 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M30 25L28.586 23.586 26 26.172 26 18 24 18 24 26.172 21.414 23.586 20 25 25 30 30 25zM19 14H23V16H19zM19 10H26V12H19zM9 18h6a3 3 0 013 3v2H16V21a1 1 0 00-1-1H9a1 1 0 00-1 1v2H6V21A3 3 0 019 18zM16 13a4 4 0 10-4 4A4 4 0 0016 13zm-2 0a2 2 0 11-2-2A2 2 0 0114 13z"
  })), _path404 || (_path404 = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("path", {
    d: "M18,26H4V6H28V16h2V6a2,2,0,0,0-2-2H4A2,2,0,0,0,2,6V26a2,2,0,0,0,2,2H18Z"
  })), children);
});




/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/_baseForOwn-d38b560e.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/_baseForOwn-d38b560e.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "_": () => (/* binding */ e)
/* harmony export */ });
/* harmony import */ var _isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./isArrayLikeObject-a9c7973b.js */ "../../node_modules/@elyra/canvas/dist/isArrayLikeObject-a9c7973b.js");
var s=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.a2,t=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.p;var e=function(r,a){return r&&s(r,a,t)};
//# sourceMappingURL=_baseForOwn-d38b560e.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/canvas-constants-3c09c7f6.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/canvas-constants-3c09c7f6.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "$": () => (/* binding */ h),
/* harmony export */   "A": () => (/* binding */ R),
/* harmony export */   "B": () => (/* binding */ b),
/* harmony export */   "C": () => (/* binding */ Sa),
/* harmony export */   "D": () => (/* binding */ e),
/* harmony export */   "E": () => (/* binding */ C),
/* harmony export */   "F": () => (/* binding */ s),
/* harmony export */   "G": () => (/* binding */ Ka),
/* harmony export */   "H": () => (/* binding */ X),
/* harmony export */   "I": () => (/* binding */ S),
/* harmony export */   "J": () => (/* binding */ l),
/* harmony export */   "K": () => (/* binding */ F),
/* harmony export */   "L": () => (/* binding */ n),
/* harmony export */   "M": () => (/* binding */ L),
/* harmony export */   "N": () => (/* binding */ $a),
/* harmony export */   "O": () => (/* binding */ Y),
/* harmony export */   "P": () => (/* binding */ y),
/* harmony export */   "Q": () => (/* binding */ r),
/* harmony export */   "R": () => (/* binding */ Ra),
/* harmony export */   "S": () => (/* binding */ _),
/* harmony export */   "T": () => (/* binding */ Fa),
/* harmony export */   "U": () => (/* binding */ La),
/* harmony export */   "V": () => (/* binding */ ba),
/* harmony export */   "W": () => (/* binding */ D),
/* harmony export */   "X": () => (/* binding */ Ta),
/* harmony export */   "Y": () => (/* binding */ ka),
/* harmony export */   "Z": () => (/* binding */ g),
/* harmony export */   "_": () => (/* binding */ a),
/* harmony export */   "a": () => (/* binding */ Da),
/* harmony export */   "a0": () => (/* binding */ H),
/* harmony export */   "a1": () => (/* binding */ O),
/* harmony export */   "a2": () => (/* binding */ j),
/* harmony export */   "a3": () => (/* binding */ Z),
/* harmony export */   "a4": () => (/* binding */ W),
/* harmony export */   "a5": () => (/* binding */ x),
/* harmony export */   "a6": () => (/* binding */ u),
/* harmony export */   "a7": () => (/* binding */ w),
/* harmony export */   "a8": () => (/* binding */ Ca),
/* harmony export */   "a9": () => (/* binding */ c),
/* harmony export */   "aA": () => (/* binding */ ta),
/* harmony export */   "aB": () => (/* binding */ na),
/* harmony export */   "aC": () => (/* binding */ ia),
/* harmony export */   "aD": () => (/* binding */ T),
/* harmony export */   "aE": () => (/* binding */ pa),
/* harmony export */   "aF": () => (/* binding */ ra),
/* harmony export */   "aG": () => (/* binding */ ea),
/* harmony export */   "aH": () => (/* binding */ oa),
/* harmony export */   "aI": () => (/* binding */ ca),
/* harmony export */   "aJ": () => (/* binding */ la),
/* harmony export */   "aK": () => (/* binding */ k),
/* harmony export */   "aL": () => (/* binding */ da),
/* harmony export */   "aM": () => (/* binding */ ha),
/* harmony export */   "aN": () => (/* binding */ ga),
/* harmony export */   "aO": () => (/* binding */ m),
/* harmony export */   "aP": () => (/* binding */ I),
/* harmony export */   "aQ": () => (/* binding */ va),
/* harmony export */   "aR": () => (/* binding */ ma),
/* harmony export */   "aS": () => (/* binding */ wa),
/* harmony export */   "aT": () => (/* binding */ ua),
/* harmony export */   "aa": () => (/* binding */ as),
/* harmony export */   "ab": () => (/* binding */ i),
/* harmony export */   "ac": () => (/* binding */ d),
/* harmony export */   "ad": () => (/* binding */ E),
/* harmony export */   "ae": () => (/* binding */ A),
/* harmony export */   "af": () => (/* binding */ Ua),
/* harmony export */   "ag": () => (/* binding */ Qa),
/* harmony export */   "ah": () => (/* binding */ qa),
/* harmony export */   "ai": () => (/* binding */ fa),
/* harmony export */   "aj": () => (/* binding */ B),
/* harmony export */   "ak": () => (/* binding */ v),
/* harmony export */   "al": () => (/* binding */ p),
/* harmony export */   "am": () => (/* binding */ z),
/* harmony export */   "an": () => (/* binding */ f),
/* harmony export */   "ao": () => (/* binding */ o),
/* harmony export */   "ap": () => (/* binding */ t),
/* harmony export */   "aq": () => (/* binding */ N),
/* harmony export */   "ar": () => (/* binding */ za),
/* harmony export */   "as": () => (/* binding */ ss),
/* harmony export */   "at": () => (/* binding */ ya),
/* harmony export */   "au": () => (/* binding */ Ma),
/* harmony export */   "av": () => (/* binding */ xa),
/* harmony export */   "aw": () => (/* binding */ sa),
/* harmony export */   "ax": () => (/* binding */ P),
/* harmony export */   "ay": () => (/* binding */ G),
/* harmony export */   "az": () => (/* binding */ V),
/* harmony export */   "b": () => (/* binding */ Ja),
/* harmony export */   "c": () => (/* binding */ Ya),
/* harmony export */   "d": () => (/* binding */ Xa),
/* harmony export */   "e": () => (/* binding */ Ga),
/* harmony export */   "f": () => (/* binding */ Va),
/* harmony export */   "g": () => (/* binding */ Wa),
/* harmony export */   "h": () => (/* binding */ Ea),
/* harmony export */   "i": () => (/* binding */ ja),
/* harmony export */   "j": () => (/* binding */ Za),
/* harmony export */   "k": () => (/* binding */ Oa),
/* harmony export */   "l": () => (/* binding */ Ha),
/* harmony export */   "m": () => (/* binding */ Ba),
/* harmony export */   "n": () => (/* binding */ Aa),
/* harmony export */   "o": () => (/* binding */ Pa),
/* harmony export */   "p": () => (/* binding */ Ia),
/* harmony export */   "q": () => (/* binding */ _a),
/* harmony export */   "r": () => (/* binding */ K),
/* harmony export */   "s": () => (/* binding */ Na),
/* harmony export */   "t": () => (/* binding */ $),
/* harmony export */   "u": () => (/* binding */ M),
/* harmony export */   "v": () => (/* binding */ aa),
/* harmony export */   "w": () => (/* binding */ q),
/* harmony export */   "x": () => (/* binding */ Q),
/* harmony export */   "y": () => (/* binding */ U),
/* harmony export */   "z": () => (/* binding */ J)
/* harmony export */ });
function a(a,s,e){return s in a?Object.defineProperty(a,s,{value:e,enumerable:!0,configurable:!0,writable:!0}):a[s]=e,a}var s=4,e="text",t="Notifications",o="notificationCounterIcon",i="Mouse",c="Trackpad",n="Curve",l="Elbow",r="Straight",p="LeftRight",g="TopBottom",h="BottomTop",d="None",v="Handles",w="Detachable",m="None",u="After",x="During",f="None",y="Flyout",M="Modal",z="Top",L="RightSideCurve",N="Straight",R="Locked",b="ReadOnly",T="Pipelineflow",k="LocalStorage",C="error",D="warning",S="info",_="success",I="horizonal",P="vertical",A="image",B="circle",H="curveRight",O="curveLeft",Z="doubleBackRight",j="doubleBackLeft",E="node",W="link",V="LR",G="TB",X="nodeLink",F="associationLink",Y="commentLink",J="tipTypeNode",U="tipTypePort",Q="tipTypeDec",q="tipTypeLink",K="tipTypePaletteItem",$="tipTypePaletteCategory",aa="tipTypeStateTag",sa="create_node",ea="clone_node",ta="create_comment",oa="clone_comment",ia="create_node_link",ca="clone_node_link",na="create_comment_link",la="clone_comment_link",ra="create_pipeline",pa="clone_pipeline",ga="branch",ha="upstream",da="downstream",va="#bad8ff",wa="#a0c8fe",ma="#152935",ua="3px",xa="binding",fa="super_node",ya="model_node",Ma="execution_node",za="savedNodes",La="useDefaultIcon",Na="useDefaultExtIcon",Ra="n",ba="s",Ta="e",ka="w",Ca=2,Da={CHEVRONARROWS:{UP:"chevron-up",DOWN:"chevron-down"},SEARCH:"search",WARNING_UNFILLED:"warning16"},Sa={CHEVRONARROWS:{RIGHT:"chevron-right"}},_a="stop",Ia="run",Pa="undo",Aa="redo",Ba="cut",Ha="copy",Oa="paste",Za="createAutoComment",ja="deleteSelectedObjects",Ea="zoomIn",Wa="zoomOut",Va="zoomToFit",Ga="arrangeHorizontally",Xa="arrangeVertically",Fa="toggleNotificationPanel",Ya="paletteOpen",Ja="paletteClose",Ua='<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 32 32"><rect x="2" y="26" width="28" height="2"/><path d="M25.4,9c0.8-0.8,0.8-2,0-2.8c0,0,0,0,0,0l-3.6-3.6c-0.8-0.8-2-0.8-2.8,0c0,0,0,0,0,0l-15,15V24h6.4L25.4,9z M20.4,4L24,7.6l-3,3L17.4,7L20.4,4z M6,22v-3.6l10-10l3.6,3.6l-10,10H6z"/></svg>',Qa='<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 4 16"><circle cx="2" cy="4" r="1.1"/><circle cx="2" cy="9" r="1.1"/><circle cx="2" cy="14" r="1.1"/></svg>',qa='<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16" enable-background="new 0 0 16 16"><g><path d="m14.9 9.1h-1.5c-.1 0-.1 0-.1.1v5.2h-11.6v-11.6h5.2c.1 0 .1 0 .1-.1v-1.5c0-.1 0-.1-.1-.1h-5.4c-.8 0-1.5.7-1.5 1.4v12c0 .8.7 1.5 1.5 1.5h12.1c.8 0 1.5-.7 1.5-1.4v-5.4c-.1-.1-.2-.1-.2-.1"/><path d="m10.4 0v1.4h3.2l-5.1 5v.1l1.1 1 4.9-5.1v3.3h1.5v-5.7z"/></g></svg>',Ka='<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16"><path d="M8 1C4.1 1 1 4.1 1 8s3.1 7 7 7 7-3.1 7-7-3.1-7-7-7zm2.7 10.5L4.5 5.3l.8-.8 6.2 6.2-.8.8z"></path><path style="fill: #ffffff;" d="M10.7 11.5L4.5 5.3l.8-.8 6.2 6.2-.8.8z"></path></svg>',$a='<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16"><path d="M8 1C4.2 1 1 4.2 1 8s3.2 7 7 7 7-3.1 7-7-3.1-7-7-7zm-.5 3h1v5h-1V4zm.5 8.2c-.4 0-.8-.4-.8-.8s.3-.8.8-.8c.4 0 .8.4.8.8s-.4.8-.8.8z"></path><path style="stroke-width: 0; fill: #161616; opacity: 1;" d="M7.5 4h1v5h-1V4zm.5 8.2c-.4 0-.8-.4-.8-.8s.3-.8.8-.8c.4 0 .8.4.8.8s-.4.8-.8.8z"></path></svg>',as='<svg focusable="false" preserveAspectRatio="xMidYMid meet" xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 32 32" aria-hidden="true" style="will-change: transform;"><path d="M13 26L14.41 24.59 6.83 17 29 17 29 15 6.83 15 14.41 7.41 13 6 3 16 13 26z"></path><title>Arrow left</title></svg>',ss="data:image/svg+xml;base64,PHN2ZyBpZD0iTGF5ZXJfMSIgZGF0YS1uYW1lPSJMYXllciAxIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAyNCAyMCI+PGRlZnM+PHN0eWxlPi5jbHMtMXtmaWxsOiM5NDkzOTQ7fTwvc3R5bGU+PC9kZWZzPjx0aXRsZT5zb3VyY2VzX29wZW48L3RpdGxlPjxwYXRoIGNsYXNzPSJjbHMtMSIgZD0iTTEwLDMuNDRWMkgyVjE4SDIyVjMuNDRabTEwLjE3LDEzSDMuNzdWNS4xN0gyMC4xNFoiLz48L3N2Zz4=";
//# sourceMappingURL=canvas-constants-3c09c7f6.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/canvas-controller-e023521c.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/canvas-controller-e023521c.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "C": () => (/* binding */ qi),
/* harmony export */   "_": () => (/* binding */ Ye),
/* harmony export */   "a": () => (/* binding */ $e),
/* harmony export */   "b": () => (/* binding */ ot),
/* harmony export */   "d": () => (/* binding */ Ge)
/* harmony export */ });
/* harmony import */ var _createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./createClass-32a0cf0f.js */ "../../node_modules/@elyra/canvas/dist/createClass-32a0cf0f.js");
/* harmony import */ var _isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./isArrayLikeObject-a9c7973b.js */ "../../node_modules/@elyra/canvas/dist/isArrayLikeObject-a9c7973b.js");
/* harmony import */ var _getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./getPrototypeOf-97272efe.js */ "../../node_modules/@elyra/canvas/dist/getPrototypeOf-97272efe.js");
/* harmony import */ var _datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./datarecord-metadata-v3-schema-81228a9a.js */ "../../node_modules/@elyra/canvas/dist/datarecord-metadata-v3-schema-81228a9a.js");
/* harmony import */ var _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./canvas-constants-3c09c7f6.js */ "../../node_modules/@elyra/canvas/dist/canvas-constants-3c09c7f6.js");
/* harmony import */ var _lib_command_stack_es_js__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./lib/command-stack.es.js */ "../../node_modules/@elyra/canvas/dist/lib/command-stack.es.js");
/* harmony import */ var _en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./en-8647c347.js */ "../../node_modules/@elyra/canvas/dist/en-8647c347.js");
/* harmony import */ var _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./canvas-logger-815781bb.js */ "../../node_modules/@elyra/canvas/dist/canvas-logger-815781bb.js");
/* harmony import */ var uuid__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! uuid */ "webpack/sharing/consume/default/uuid/uuid");
/* harmony import */ var uuid__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(uuid__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var redux__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! redux */ "../../node_modules/redux/es/redux.js");
/* harmony import */ var jsonschema__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! jsonschema */ "../../node_modules/jsonschema/lib/index.js");
/* harmony import */ var _elyra_pipeline_schemas__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @elyra/pipeline-schemas */ "../../node_modules/@elyra/pipeline-schemas/common-pipeline/pipeline-flow/upgrade/upgrade-flow.js");
/* harmony import */ var _elyra_pipeline_schemas__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_elyra_pipeline_schemas__WEBPACK_IMPORTED_MODULE_2__);
var Ge={"menu.highlightBranch":"Highlight branch","menu.highlightUpstream":"Highlight upstream","menu.highlightDownstream":"Highlight downstream","menu.unhighlight":"Unhighlight","menu.highlight":"Highlight","edit.cutSelection":"Cut","edit.copySelection":"Copy","edit.pasteSelection":"Paste","canvas.label":"Canvas","canvas.addComment":"New comment","canvas.selectAll":"Select all","canvas.undo":"Undo","canvas.redo":"Redo","canvas.undoCommand":"Undo: {undo_command}","canvas.redoCommand":"Redo: {redo_command}","canvas.deleteObject":"Delete","canvas.flowIsEmpty":"Your flow is empty.","canvas.addNodeToStart":"Get started by adding a node.","canvas.stateTagLocked":"Locked","canvas.stateTagReadOnly":"Read-only","canvas.stateTagTipLocked":"This flow is locked and cannot be edited.","canvas.stateTagTipReadOnly":"This flow cannot be edited.","comment.colorBackground":"Color background","node.createSupernode":"Create supernode","node.createSupernodeExternal":"Create external supernode","node.expandSupernode":"Expand supernode","node.displaySupernodeFullPage":"Display full page","node.collapseSupernodeInPlace":"Collapse supernode","node.deconstructSupernode":"Deconstruct supernode","node.convertSupernodeExternalToLocal":"Convert external to local","node.convertSupernodeLocalToExternal":"Convert local to external","canvas.validateFlow":"Validate Flow","node.editNode":"Open","node.editMenu":"Edit","node.disconnectNode":"Disconnect","node.saveToPalette":"Save to palette","link.deleteLink":"Delete"};function ze(e,t){var n="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!n){if(Array.isArray(e)||(n=function(e,t){if(!e)return;if("string"==typeof e)return Ve(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);"Object"===n&&e.constructor&&(n=e.constructor.name);if("Map"===n||"Set"===n)return Array.from(e);if("Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return Ve(e,t)}(e))||t&&e&&"number"==typeof e.length){n&&(e=n);var i=0,o=function(){};return{s:o,n:function(){return i>=e.length?{done:!0}:{done:!1,value:e[i++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var a,r=!0,s=!1;return{s:function(){n=n.call(e)},n:function(){var e=n.next();return r=e.done,e},e:function(e){s=!0,a=e},f:function(){try{r||null==n.return||n.return()}finally{if(s)throw a}}}}function Ve(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,i=new Array(t);n<t;n++)i[n]=e[n];return i}var $e=function(){function i(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,i)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(i,null,[{key:"getObjectPositions",value:function(e){var t=[];return e.forEach((function(e){t[e.id]={x_pos:e.x_pos,y_pos:e.y_pos}})),t}},{key:"getLinkPositions",value:function(e){var t=[];return e.forEach((function(e){e.srcPos&&((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.s)(t[e.id],"srcPos.x_pos",e.srcPos.x_pos),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.s)(t[e.id],"srcPos.y_pos",e.srcPos.y_pos)),e.trgPos&&(t[e.id]||(t[e.id]={}),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.s)(t[e.id],"trgPos.x_pos",e.trgPos.x_pos),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.s)(t[e.id],"trgPos.y_pos",e.trgPos.y_pos))})),t}},{key:"moveSurroundingObjects",value:function(e,t,n,i,o,a){var r=this,s=[],d=i-e.width,c=o-e.height,l=e.x_pos+e.width/2,u=e.y_pos+e.height/2;return t.forEach((function(t){if(t.id!==e.id){var i=r.getMoveDeltas(t.x_pos+t.width/2,t.y_pos+t.height/2,n,l,u,d,c);0===i.xDelta&&0===i.yDelta||(s[t.id]={id:t.id,x_pos:t.x_pos+i.xDelta,y_pos:t.y_pos+i.yDelta,width:t.width,height:t.height},a&&(t.x_pos+=i.xDelta,t.y_pos+=i.yDelta))}})),s}},{key:"moveSurroundingDetachedLinks",value:function(e,t,n,i,o,a){var r=this,s=[],d=i-e.width,c=o-e.height,l=e.x_pos+e.width/2,u=e.y_pos+e.height/2;return t.forEach((function(e){if(e.srcPos){var t=r.getMoveDeltas(e.srcPos.x_pos,e.srcPos.y_pos,n,l,u,d,c);0===t.xDelta&&0===t.yDelta||(s[e.id]||(s[e.id]={id:e.id}),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.s)(s[e.id],"srcPos.x_pos",e.srcPos.x_pos+t.xDelta),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.s)(s[e.id],"srcPos.y_pos",e.srcPos.y_pos+t.yDelta),a&&(e.srcPos.x_pos+=t.xDelta,e.srcPos.y_pos+=t.yDelta))}if(e.trgPos){var i=r.getMoveDeltas(e.trgPos.x_pos,e.trgPos.y_pos,n,l,u,d,c);0===i.xDelta&&0===i.yDelta||(s[e.id]||(s[e.id]={id:e.id}),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.s)(s[e.id],"trgPos.x_pos",e.trgPos.x_pos+i.xDelta),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.s)(s[e.id],"trgPos.y_pos",e.trgPos.y_pos+i.yDelta)),a&&(e.trgPos.x_pos+=i.xDelta,e.trgPos.y_pos+=i.yDelta)}})),s}},{key:"getMoveDeltas",value:function(e,t,n,i,o,a,r){var s=0,d=0;return n.indexOf("n")>-1&&t<o-20?d=-r:n.indexOf("s")>-1&&t>o+20&&(d=r),n.indexOf("w")>-1&&e<i-20?s=-a:n.indexOf("e")>-1&&e>i+20&&(s=a),{xDelta:s,yDelta:d}}},{key:"getSupernodeExpandedWidth",value:function(e,t){return e.expanded_width?e.expanded_width:Math.max(t.supernodeDefaultWidth,e.width)}},{key:"getSupernodeExpandedHeight",value:function(e,t){return e.expanded_height?e.expanded_height:Math.max(t.supernodeDefaultHeight,e.height)}},{key:"getNodePaddingToTargetNodes",value:function(e,t,n,i){var o=0;if("Elbow"===i){var a=this.getCountOfLinksToTargetNodes(e,t,n)*e.layout.minInitialLineIncrement;o=e.layout.minInitialLine+e.layout.minFinalLine+a}else o=2*e.layout.minInitialLine;return o}},{key:"getCountOfLinksToTargetNodes",value:function(e,t,n){var i=this,o=0;return e.outputs&&e.outputs.length>0&&e.outputs.forEach((function(a){i.isNodeOutputLinkedToTargetNodes(e,a,t,n)&&o++})),o}},{key:"isNodeOutputLinkedToTargetNodes",value:function(e,t,n,i){var o=this,a=!1;return i.forEach((function(i){i.srcNodeId===e.id&&i.srcNodePortId===t.id&&o.isTargetNode(i.trgNodeId,n)&&(a=!0)})),a}},{key:"isTargetNode",value:function(e,t){return t.findIndex((function(t){return t.id===e}))>-1}},{key:"getCombinedDecorations",value:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:[],n=e.map((function(e){var n=t.find((function(t){return t.id===e.id}));return n?Object.assign({},e,n):e}));return t&&t.forEach((function(t){-1===e.findIndex((function(e){return e.id===t.id}))&&n.push(t)})),n}},{key:"isCmndCtrlPressed",value:function(e){return this.isMacintosh()?e.metaKey:e.ctrlKey}},{key:"isMacintosh",value:function(){return navigator.platform.indexOf("Mac")>-1}},{key:"stopPropagationAndPreventDefault",value:function(e){e.stopPropagation(),e.preventDefault()}},{key:"snapToGrid",value:function(e,t){var n=e/t,i=Math.trunc(n);return n-i>.5&&i++,i*t}},{key:"getOuterCoord",value:function(e,t,n,i,o,a,r,s,d){var c,l,u=t-o,p=e-o,f=e+n+o,h=t+i+o,g=r-u,y=a-p,m=h-r,v=a-s,b=r-d;if(0===v)c=a,l=d<r?u:h;else if(s>a){var _=b/v;_<g/(a-f)?(c=a-g/_,l=u):_>(r-h)/(a-f)?(c=a+m/_,l=h):(c=f,l=r+(f-a)*_)}else{var k=b/v;k>g/y?(c=a-g/k,l=u):k<(r-h)/y?(c=a+m/k,l=h):(c=p,l=r-y*k)}return{x:c,y:l}}},{key:"getDir",value:function(e,t,n,i,o,a,r,s){var d=t+i,c=a-t,l=o-e,u=o-r,p=a-s,f="";if(0===u)f=s<a?_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.R:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.V;else if(r>o){var h=e+n,g=p/u;f=g<c/(o-h)?_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.R:g>(a-d)/(o-h)?_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.V:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.X}else{var y=p/u;f=y>c/l?_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.R:y<(a-d)/l?_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.V:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Y}return f}},{key:"lineIntersectRectangle",value:function(e,t,n,i,o,a,r,s){var d=this.lineInside(e,t,n,i,o,a,r,s),c=this.linesIntersect(e,t,n,i,o,a,r,a),l=this.linesIntersect(e,t,n,i,o,a,o,s),u=this.linesIntersect(e,t,n,i,r,a,r,s),p=this.linesIntersect(e,t,n,i,o,s,r,s);return d||c||l||u||p}},{key:"lineInside",value:function(e,t,n,i,o,a,r,s){return e>=o&&e<=r&&t>=a&&t<=s&&n>=o&&n<=r&&i>=a&&i<=s}},{key:"linesIntersect",value:function(e,t,n,i,o,a,r,s){var d=((r-o)*(t-a)-(s-a)*(e-o))/((s-a)*(n-e)-(r-o)*(i-t)),c=((n-e)*(t-a)-(i-t)*(e-o))/((s-a)*(n-e)-(r-o)*(i-t));return d>=0&&d<=1&&c>=0&&c<=1?{x:e+d*(n-e),y:t+d*(i-t)}:null}},{key:"isConnectionAllowed",value:function(e,t,n,i,o,a){return a===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K?this.isAssocConnectionAllowed(n,i,o):this.isDataConnectionAllowed(e,t,n,i,o)}},{key:"isConnectionAllowedWithDetachedLinks",value:function(e,t,n,i,o){return(!n||!i||n.id!==i.id)&&!(n&&i&&this.linkAlreadyExists(e,t,n,i,o))}},{key:"isSrcConnectionAllowedWithDetachedLinks",value:function(e,t,n){return!(t&&!this.doesNodeHaveOutputPorts(t))&&(!t||!this.isSrcCardinalityAtMax(e,t,n))}},{key:"isTrgConnectionAllowedWithDetachedLinks",value:function(e,t,n){return!(t&&!this.doesNodeHaveInputPorts(t))&&(!t||!this.isTrgCardinalityAtMax(e,t,n))}},{key:"doesNodeHaveInputPorts",value:function(e){return e.inputs&&e.inputs.length>0}},{key:"doesNodeHaveOutputPorts",value:function(e){return e.outputs&&e.outputs.length>0}},{key:"isDataLinkReplacementAllowed",value:function(e,t,n,i,o){return!!this.isDataConnectionAllowedNoCardinality(e,t,n,i,o)&&(1===this.getMaxCardinality(t,i.inputs)&&!!this.isTrgCardinalityAtMax(t,i,o))}},{key:"isDataConnectionAllowed",value:function(e,t,n,i,o){return!!this.isDataConnectionAllowedNoCardinality(e,t,n,i,o)&&!this.isCardinalityAtMax(e,t,n,i,o)}},{key:"isDataConnectionAllowedNoCardinality",value:function(e,t,n,i,o){return!(!n||!i)&&(n.id!==i.id&&(!!this.doesNodeHaveInputPorts(i)&&!this.linkAlreadyExists(e,t,n,i,o)))}},{key:"isAssocConnectionAllowed",value:function(e,t,n){return!(!e||!t)&&e.id!==t.id}},{key:"isSrcNodeAvailable",value:function(e,t,n,i){return!(!t||t.id!==e.id)||!!this.doesNodeHaveOutputPorts(e)&&!this.areAllSrcNodePortsCardinalityAtMax(e,i)}},{key:"isTrgNodeAvailable",value:function(e,t,n,i){return!(!t||t.id!==e.id)||!!this.doesNodeHaveInputPorts(e)&&!this.areAllTrgNodePortsCardinalityAtMax(e,i)}},{key:"linkAlreadyExists",value:function(e,t,n,i,o){var a=!1;return o.forEach((function(o){o.srcNodeId!==n.id||o.srcNodePortId&&o.srcNodePortId!==e||o.trgNodeId!==i.id||o.trgNodePortId&&o.trgNodePortId!==t||(a=!0)})),a}},{key:"areAllSrcNodePortsCardinalityAtMax",value:function(e,t){var n=this;return!(!e||!e.outputs)&&-1===e.outputs.findIndex((function(i){return!n.isSrcCardinalityAtMax(i.id,e,t)}))}},{key:"areAllTrgNodePortsCardinalityAtMax",value:function(e,t){var n=this;return!(!e||!e.inputs)&&-1===e.inputs.findIndex((function(i){return!n.isTrgCardinalityAtMax(i.id,e,t)}))}},{key:"hasInputAndOutputPorts",value:function(e){return this.isNode(e)&&e.inputs&&e.inputs.length>0&&e.outputs&&e.outputs.length>0}},{key:"isNodeDefaultPortsCardinalityAtMax",value:function(e,t){return this.isCardinalityAtMax(null,null,e,e,t)}},{key:"isCardinalityAtMax",value:function(e,t,n,i,o){return this.isSrcCardinalityAtMax(e,n,o)||this.isTrgCardinalityAtMax(t,i,o)}},{key:"isSrcCardinalityAtMax",value:function(e,t,n){var i=this,o=e||this.getDefaultOutputPortId(t),a=0;n.forEach((function(e){e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H&&e.srcNodeId===t.id&&o&&(e.srcNodePortId===o||!e.srcNodePortId&&i.isFirstPort(t.outputs,o))&&a++}));var r=this.getMaxCardinality(o,t.outputs);return null!==r&&-1!==r&&a>=r}},{key:"isTrgCardinalityAtMax",value:function(e,t,n){var i=this,o=e||this.getDefaultInputPortId(t),a=0;n.forEach((function(e){e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H&&e.trgNodeId===t.id&&o&&(e.trgNodePortId===o||!e.trgNodePortId&&i.isFirstPort(t.inputs,o))&&a++}));var r=this.getMaxCardinality(o,t.inputs);return null!==r&&-1!==r&&a>=r}},{key:"isFirstPort",value:function(e,t){return 0===e.findIndex((function(e){return e.id===t}))}},{key:"getPort",value:function(e,t){if(t&&t.length>0){var n=t.findIndex((function(t){return t.id===e}));if(n>-1)return t[n]}return null}},{key:"getMaxCardinality",value:function(e,t){var n=this.getPort(e,t);return n&&n.cardinality?Number(n.cardinality.max):null}},{key:"isCommentLinkConnectionAllowed",value:function(e,t,n){return!this.commentLinkAlreadyExists(e,t,n)}},{key:"commentLinkAlreadyExists",value:function(e,t,n){var i=!1;return n.forEach((function(n){n.srcNodeId===e&&n.trgNodeId===t&&(i=!0)})),i}},{key:"getDetachedLinksToUpdate",value:function(e,t,n){var i=this,o=[],a=[];return t.forEach((function(t){if(t.nodeOverSrcPos&&t.srcPos&&e.outputs&&e.outputs.length>0){var r=!1;e.outputs.forEach((function(s){if(!1===r&&i.isSrcConnectionAllowedWithDetachedLinks(s.id,e,i.getReplacedLinks(n,o))){var d=Object.assign({},t,{srcNodeId:e.id,srcNodePortId:s.id});delete d.srcPos,o.push(d),a.push(t),r=!0}}))}else if(t.nodeOverTrgPos&&t.trgPos&&e.inputs&&e.inputs.length>0){var s=!1;e.inputs.forEach((function(r){if(!1===s&&i.isTrgConnectionAllowedWithDetachedLinks(r.id,e,i.getReplacedLinks(n,o))){var d=Object.assign({},t,{trgNodeId:e.id,trgNodePortId:r.id});delete d.trgPos,o.push(d),a.push(t),s=!0}}))}})),{newLinks:o,oldLinks:a}}},{key:"getReplacedLinks",value:function(e,t){return e.map((function(e){var n=t.findIndex((function(t){return t.id===e.id}));return n>-1?t[n]:e}))}},{key:"selectInRegion",value:function(e,t,n,i,o){var a,r=[],s=ze(t.nodes);try{for(s.s();!(a=s.n()).done;){var d=a.value;!this.isSuperBindingNode(d)&&e.x1<d.x_pos+d.width&&e.x2>d.x_pos&&e.y1<d.y_pos+d.height&&e.y2>d.y_pos&&r.push(d.id)}}catch(e){s.e(e)}finally{s.f()}var c,l=ze(t.comments);try{for(l.s();!(c=l.n()).done;){var u=c.value;e.x1<u.x_pos+u.width&&e.x2>u.x_pos&&e.y1<u.y_pos+u.height&&e.y2>u.y_pos&&r.push(u.id)}}catch(e){l.e(e)}finally{l.f()}if(n){var p,f=ze(t.links);try{for(f.s();!(p=f.n()).done;){var h=p.value;h.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H&&i===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Q||h.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O||h.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K&&o===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aq?this.lineIntersectRectangle(h.x1,h.y1,h.x2,h.y2,e.x1,e.y1,e.x2,e.y2)&&r.push(h.id):(this.isPosInArea({x_pos:h.x1,y_pos:h.y1},e,0)||this.isPosInArea({x_pos:h.x2,y_pos:h.y2},e,0))&&r.push(h.id)}}catch(e){f.e(e)}finally{f.f()}}return r}},{key:"isSelected",value:function(e,t){return-1!==t.findIndex((function(t){return t===e}))}},{key:"isPosInArea",value:function(e,t,n){return e.x_pos>t.x1-n&&e.x_pos<t.x2+n&&e.y_pos>t.y1-n&&e.y_pos<t.y2+n}},{key:"isNode",value:function(e){return e.type}},{key:"isSupernode",value:function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai}},{key:"isExpanded",value:function(e){return!0===e.is_expanded}},{key:"isExpandedSupernode",value:function(e){return this.isSupernode(e)&&this.isExpanded(e)}},{key:"isCollapsedSupernode",value:function(e){return this.isSupernode(e)&&!this.isExpanded(e)}},{key:"isSuperBindingNode",value:function(e){return e.isSupernodeInputBinding||e.isSupernodeOutputBinding}},{key:"getCanvasDimensions",value:function(e,t,n,i,o){var a=this,r=1/0,s=1/0,d=-1/0,c=-1/0;return e&&e.forEach((function(e){if(!a.isSuperBindingNode(e)){var t=0===o?0:e.layout.nodeHighlightGap;r=Math.min(r,e.x_pos-t),s=Math.min(s,e.y_pos-t),d=Math.max(d,e.x_pos+e.width+t),c=Math.max(c,e.y_pos+e.height+t)}})),t&&t.forEach((function(e){r=Math.min(r,e.x_pos-i),s=Math.min(s,e.y_pos-i),d=Math.max(d,e.x_pos+e.width+i),c=Math.max(c,e.y_pos+e.height+i)})),n&&n.forEach((function(e){e.srcPos&&(r=Math.min(r,e.srcPos.x_pos),s=Math.min(s,e.srcPos.y_pos),d=Math.max(d,e.srcPos.x_pos),c=Math.max(c,e.srcPos.y_pos)),e.trgPos&&(r=Math.min(r,e.trgPos.x_pos),s=Math.min(s,e.trgPos.y_pos),d=Math.max(d,e.trgPos.x_pos),c=Math.max(c,e.trgPos.y_pos))})),r===1/0||s===1/0||d===-1/0||c===-1/0?{left:0,top:0,right:0,bottom:0,width:0,height:0}:{left:r,top:s,right:d,bottom:c,width:d-r,height:c-s}}},{key:"getDataLinksConnectedTo",value:function(e,t,n){var i=this.getDefaultInputPortId(t);return n.filter((function(n){if(n.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H){var o=n.trgNodePortId||i;return n.trgNodeId===t.id&&o===e}return!1}))}},{key:"getDefaultInputPortId",value:function(e){return e.inputs&&e.inputs.length>0?e.inputs[0].id:null}},{key:"getDefaultOutputPortId",value:function(e){return e.outputs&&e.outputs.length>0?e.outputs[0].id:null}},{key:"getObjectStyle",value:function(e,t,n){if(!e.style&&!e.style_temp)return null;var i=null;return"hover"===n?i=this.getStyleValue(e,t,"default")+";"+this.getStyleValue(e,t,"hover"):"default"===n&&(i=this.getStyleValue(e,t,"default")),i}},{key:"getStyleValue",value:function(e,t,i){var o=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.k)(e,"style_temp.".concat(t,".").concat(i),null);return null!==o?o:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.k)(e,"style.".concat(t,".").concat(i),null)}},{key:"filterSupernodes",value:function(e){return e.filter((function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai}))}},{key:"getSrcPos",value:function(e,t){var n,i;if(e.trgNodeId){var o=t.getNode(e.trgNodeId);n=o.x_pos+o.width/2,i=o.y_pos+o.height/2}else n=e.trgPos.x_pos,i=e.trgPos.y_pos;var a,r,s=t.getNode(e.srcNodeId);s.layout&&"image_center"===s.layout.drawNodeLinkLineFromTo?(a=s.x_pos+s.layout.imagePosX+s.layout.imageWidth/2,r=s.y_pos+s.layout.imagePosY+s.layout.imageHeight/2):(a=s.x_pos+s.width/2,r=s.y_pos+s.height/2);var d=this.getOuterCoord(s.x_pos,s.y_pos,s.width,s.height,0,a,r,n,i);return{x_pos:d.x,y_pos:d.y}}},{key:"getTrgPos",value:function(e,t){var n,i;if(e.srcNodeId){var o=t.getNode(e.srcNodeId);n=o.x_pos+o.width/2,i=o.y_pos+o.height/2}else n=e.srcPos.x_pos,i=e.srcPos.y_pos;var a,r,s=t.getNode(e.trgNodeId);s.layout&&"image_center"===s.layout.drawNodeLinkLineFromTo?(a=s.x_pos+s.layout.imagePosX+s.layout.imageWidth/2,r=s.y_pos+s.layout.imagePosY+s.layout.imageHeight/2):(a=s.x_pos+s.width/2,r=s.y_pos+s.height/2);var d=this.getOuterCoord(s.x_pos,s.y_pos,s.width,s.height,0,a,r,n,i);return{x_pos:d.x,y_pos:d.y}}},{key:"concatUniqueBasedOnId",value:function(e,t){var n=t;return e.forEach((function(e){t.some((function(t){return t.id===e.id}))||n.push(e)})),n}},{key:"getBkgColorClass",value:function(e){return"bkg-col-white-0"===e||"bkg-col-yellow-20"===e||"bkg-col-gray-20"===e||"bkg-col-green-20"===e||"bkg-col-teal-20"===e||"bkg-col-cyan-20"===e||"bkg-col-red-50"===e||"bkg-col-orange-40"===e||"bkg-col-gray-50"===e||"bkg-col-green-50"===e||"bkg-col-teal-50"===e||"bkg-col-cyan-50"===e?e:null}}]),i}(),We=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.G;var Ye=function(e){return"function"==typeof e?e:We},Xe=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.B,Ke=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.C;var Je=function(e,t,n){return n="function"==typeof n?n:void 0,Xe(e,t,Ke(t),n)},Ze=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.B,Qe=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.C;var et=function(e,t){return e===t||Ze(e,t,Qe(t))},tt={nodeLayout:{defaultNodeWidth:160,defaultNodeHeight:40,nodeShape:"port-arcs",bodyPath:null,selectionPath:null,imageDisplay:!0,imageWidth:26,imageHeight:26,imagePosition:"topLeft",imagePosX:6,imagePosY:7,labelWidth:112,labelHeight:19,labelPosition:"topLeft",labelPosX:36,labelPosY:12,labelEditable:!1,labelAlign:"left",labelSingleLine:!0,labelOutline:!1,labelMaxCharacters:null,labelAllowReturnKey:!1,decorations:[],decoratorTopY:2,decoratorMiddleY:-8,decoratorBottomY:-18,decoratorLeftX:2,decoratorCenterX:-8,decoratorRightX:-30,decoratorWidth:16,decoratorHeight:16,decoratorPadding:2,decoratorLabelWidth:80,decoratorLabelHeight:15,dropShadow:!0,nodeHighlightGap:1,nodeSizingArea:10,errorPosition:"topLeft",errorXPos:24,errorYPos:5,errorWidth:10.5,errorHeight:10.5,nodeCornerResizeArea:10,drawNodeLinkLineFromTo:"node_center",drawCommentLinkLineTo:"node_center",minInitialLine:30,minInitialLineIncrement:8,minFinalLine:30,inputPortDisplay:!0,inputPortObject:"circle",inputPortImage:"",inputPortWidth:12,inputPortHeight:12,inputPortLeftPosX:0,inputPortLeftPosY:20,inputPortTopPosX:80,inputPortTopPosY:0,inputPortBottomPosX:80,inputPortBottomPosY:0,inputPortGuideObject:"circle",inputPortGuideImage:"",outputPortDisplay:!0,outputPortObject:"circle",outputPortImage:"",outputPortWidth:12,outputPortHeight:12,outputPortRightPosX:0,outputPortRightPosY:20,outputPortTopPosX:80,outputPortTopPosY:0,outputPortBottomPosX:80,outputPortBottomPosY:0,outputPortGuideObject:"circle",outputPortGuideImage:"",portRadius:3,portArcOffset:3,portArcRadius:6,portArcSpacing:3,ellipsisDisplay:!0,ellipsisPosition:"topLeft",ellipsisWidth:10,ellipsisHeight:22,ellipsisPosX:145,ellipsisPosY:9,ellipsisHoverAreaPadding:2},canvasLayout:{supernodeLabelPosX:30,supernodeLabelPosY:4,supernodeLabelWidth:50,supernodeLabelHeight:20,supernodeImageWidth:18,supernodeImageHeight:18,supernodeImagePosX:5,supernodeImagePosY:4,supernodeEllipsisPosX:-34,supernodeEllipsisPosY:2,supernodeEllipsisWidth:10,supernodeEllipsisHeight:20,supernodeExpansionIconPosX:-21,supernodeExpansionIconPosY:4,supernodeExpansionIconHeight:18,supernodeExpansionIconWidth:18,supernodeExpansionIconHoverAreaPadding:2,supernodeErrorPosX:-50,supernodeErrorPosY:5,supernodeErrorWidth:14,supernodeErrorHeight:14,supernodeDefaultWidth:300,supernodeDefaultHeight:200,supernodeMinWidth:100,supernodeMinHeight:80,supernodeTopAreaHeight:25,supernodeSVGAreaPadding:3,supernodeBindingPortRadius:6,linkDirection:"LeftRight",displayLinkOnOverlap:!0,linkGap:7,linkDecoratorHeight:20,linkDecoratorWidth:20,linkDecoratorPadding:2,linkDecoratorLabelWidth:80,linkDecoratorLabelHeight:15,elbowSize:10,wrapAroundSpacing:20,wrapAroundNodePadding:10,linkType:"Curve",commentLinkArrowHead:!1,dataLinkArrowHead:!1,linkStartHandleObject:"circle",linkStartHandleImage:"",linkStartHandleWidth:12,linkStartHandleHeight:12,linkStartHandleRadius:5,linkEndHandleObject:"circle",linkEndHandleImage:"",linkEndHandleWidth:12,linkEndHandleHeight:12,linkEndHandleRadius:5,commentCornerResizeArea:10,commentHighlightGap:1,commentSizingArea:10,addCommentOffset:30,commentPortRadius:5,alwaysDisplayBackToParentFlow:!1,zoomToFitPadding:10,snapToGridType:"None",snapToGridX:"20%",snapToGridY:"33.33%",nodeProximity:20,ghostAreaPadding:10,initialPanX:null,initialPanY:null,autoLayoutInitialMarginX:50,autoLayoutInitialMarginY:50,autoLayoutVerticalSpacing:80,autoLayoutHorizontalSpacing:80}},nt={nodeLayout:{defaultNodeWidth:70,defaultNodeHeight:75,nodeShape:"rectangle",bodyPath:null,selectionPath:null,imageDisplay:!0,imageWidth:48,imageHeight:48,imagePosition:"topLeft",imagePosX:11,imagePosY:6,labelWidth:72,labelHeight:19,labelPosition:"topLeft",labelPosX:35,labelPosY:55,labelEditable:!1,labelAlign:"center",labelSingleLine:!0,labelOutline:!1,labelMaxCharacters:null,labelAllowReturnKey:!1,decorations:[],decoratorTopY:5,decoratorMiddleY:-8,decoratorBottomY:-34,decoratorLeftX:10,decoratorCenterX:-8,decoratorRightX:-24,decoratorWidth:16,decoratorHeight:16,decoratorPadding:2,decoratorLabelWidth:80,decoratorLabelHeight:15,dropShadow:!1,nodeHighlightGap:4,nodeSizingArea:10,errorPosition:"topLeft",errorXPos:45,errorYPos:5,errorWidth:14,errorHeight:14,nodeCornerResizeArea:10,drawNodeLinkLineFromTo:"node_center",drawCommentLinkLineTo:"node_center",minInitialLine:30,minInitialLineIncrement:8,minFinalLine:30,inputPortDisplay:!0,inputPortObject:"circle",inputPortImage:"",inputPortWidth:12,inputPortHeight:12,inputPortLeftPosX:0,inputPortLeftPosY:29,inputPortTopPosX:35,inputPortTopPosY:0,inputPortBottomPosX:35,inputPortBottomPosY:0,inputPortGuideObject:"circle",inputPortGuideImage:"",outputPortDisplay:!0,outputPortObject:"circle",outputPortImage:"",outputPortWidth:12,outputPortHeight:12,outputPortRightPosX:0,outputPortRightPosY:29,outputPortTopPosX:35,outputPortTopPosY:0,outputPortBottomPosX:35,outputPortBottomPosY:0,outputPortGuideObject:"circle",outputPortGuideImage:"",portRadius:6,portArcOffset:0,portArcRadius:10,portArcSpacing:0,ellipsisDisplay:!0,ellipsisPosition:"topLeft",ellipsisWidth:11,ellipsisHeight:21,ellipsisPosX:57,ellipsisPosY:4,ellipsisHoverAreaPadding:2},canvasLayout:{supernodeLabelPosX:30,supernodeLabelPosY:4,supernodeLabelWidth:50,supernodeLabelHeight:20,supernodeImageWidth:18,supernodeImageHeight:18,supernodeImagePosX:5,supernodeImagePosY:4,supernodeEllipsisPosX:-34,supernodeEllipsisPosY:2,supernodeEllipsisWidth:10,supernodeEllipsisHeight:20,supernodeExpansionIconPosX:-21,supernodeExpansionIconPosY:4,supernodeExpansionIconHeight:18,supernodeExpansionIconWidth:18,supernodeExpansionIconHoverAreaPadding:2,supernodeErrorPosX:-50,supernodeErrorPosY:5,supernodeErrorWidth:14,supernodeErrorHeight:14,supernodeDefaultWidth:200,supernodeDefaultHeight:200,supernodeMinWidth:100,supernodeMinHeight:80,supernodeTopAreaHeight:25,supernodeSVGAreaPadding:3,supernodeBindingPortRadius:10,linkDirection:"LeftRight",displayLinkOnOverlap:!0,linkGap:7,linkDecoratorHeight:20,linkDecoratorWidth:20,linkDecoratorPadding:2,linkDecoratorLabelWidth:80,linkDecoratorLabelHeight:15,elbowSize:10,wrapAroundSpacing:20,wrapAroundNodePadding:10,linkType:"Curve",commentLinkArrowHead:!1,dataLinkArrowHead:!1,linkStartHandleObject:"circle",linkStartHandleImage:"",linkStartHandleWidth:12,linkStartHandleHeight:12,linkStartHandleRadius:6,linkEndHandleObject:"circle",linkEndHandleImage:"",linkEndHandleWidth:12,linkEndHandleHeight:12,linkEndHandleRadius:6,commentCornerResizeArea:10,commentHighlightGap:4,commentSizingArea:10,addCommentOffset:30,commentPortRadius:5,alwaysDisplayBackToParentFlow:!1,zoomToFitPadding:10,snapToGridType:"None",snapToGridX:"25%",snapToGridY:"20%",nodeProximity:20,ghostAreaPadding:10,initialPanX:null,initialPanY:null,autoLayoutInitialMarginX:50,autoLayoutInitialMarginY:50,autoLayoutVerticalSpacing:80,autoLayoutHorizontalSpacing:80}},it=function(){function n(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,n)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(n,null,[{key:"getLayout",value:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},n=this.getDefaultLayout(e);return e&&(n=this.overrideNodeLayout(n,t),n=this.overrideCanvasLayout(n,e,t),n=this.overrideLinkType(n,e),n=this.overrideSnapToGrid(n,e),n=this.overrideAutoLayout(n,e)),n}},{key:"getDefaultLayout",value:function(e){var t;return t=e&&"Vertical"===e.enableNodeFormatType?nt:tt,Object.assign({},t)}},{key:"overrideNodeLayout",value:function(e,t){return e.nodeLayout=Object.assign({},e.nodeLayout,t.nodeLayout||{}),e}},{key:"overrideCanvasLayout",value:function(e,t,n){return e.canvasLayout=Object.assign({},e.canvasLayout,{linkDirection:t.enableLinkDirection},n.canvasLayout||{}),e}},{key:"overrideLinkType",value:function(e,t){return e.canvasLayout.linkType=t.enableLinkType||e.canvasLayout.linkType||"Curve",e}},{key:"overrideSnapToGrid",value:function(e,t){return t.enableSnapToGridType&&(e.canvasLayout.snapToGridType=t.enableSnapToGridType),e.canvasLayout.snapToGridX=t.enableSnapToGridX||e.canvasLayout.snapToGridX||"25%",e.canvasLayout.snapToGridY=t.enableSnapToGridY||e.canvasLayout.snapToGridY||"20%",e.canvasLayout.snapToGridXPx=this.getSnapToGridSize(e.canvasLayout.snapToGridX,e.nodeLayout.defaultNodeWidth),e.canvasLayout.snapToGridYPx=this.getSnapToGridSize(e.canvasLayout.snapToGridY,e.nodeLayout.defaultNodeHeight),e}},{key:"overrideAutoLayout",value:function(e,t){return e.canvasLayout.autoLayoutVerticalSpacing=this.getAutoLayoutSpacing(t.enableAutoLayoutVerticalSpacing,e.canvasLayout.autoLayoutVerticalSpacing),e.canvasLayout.autoLayoutHorizontalSpacing=this.getAutoLayoutSpacing(t.enableAutoLayoutHorizontalSpacing,e.canvasLayout.autoLayoutHorizontalSpacing),e}},{key:"getAutoLayoutSpacing",value:function(e,t){var n=80;return null!=e?n=e:null!=t&&(n=t),n}},{key:"getSnapToGridSize",value:function(e,t){return e.endsWith("%")?Number.parseInt(e,10)/100*t:Number.parseInt(e,10)}}]),n}(),ot=function(){function n(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,n)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(n,null,[{key:"mergeCanvasConfigs",value:function(e,t){var n=Object.assign({},e,t||{});if(t){var i=it.getLayout(n,{nodeLayout:t.enableNodeLayout,canvasLayout:t.enableCanvasLayout}),o=Object.assign({},e.tipConfig,t.tipConfig);n=Object.assign({},n,{enableNodeLayout:i.nodeLayout,enableCanvasLayout:i.canvasLayout,tipConfig:o})}return n}},{key:"getDefaultCanvasConfig",value:function(){var e={enableInteractionType:"Mouse",enableNodeFormatType:"Horizontal",enableLinkType:"Curve",enableLinkDirection:"LeftRight",enableLinkSelection:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ac,enableLinkReplaceOnNewConnection:!1,enableAssocLinkCreation:!1,enableAssocLinkType:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aq,enableDragWithoutSelect:!1,enableInternalObjectModel:!0,enablePaletteLayout:"Flyout",enableToolbarLayout:"Top",enableResizableNodes:!1,enableInsertNodeDroppedOnLink:!1,enableHighlightNodeOnNewLinkDrag:!1,enableHighlightUnavailableNodes:!1,enableMoveNodesOnSupernodeResize:!0,enableExternalPipelineFlows:!0,enableEditingActions:!0,enableDisplayFullLabelOnHover:!1,enableDropZoneOnExternalDrag:!1,enableRightFlyoutUnderToolbar:!1,enablePanIntoViewOnOpen:!1,enableZoomIntoSubFlows:!1,enableBrowserEditMenu:!0,enableAutoLinkOnlyFromSelNodes:!1,enableSaveZoom:"None",enableSnapToGridType:"None",enableSnapToGridX:null,enableSnapToGridY:null,enableAutoLayoutVerticalSpacing:null,enableAutoLayoutHorizontalSpacing:null,enableSingleOutputPortDisplay:!1,enableNarrowPalette:!0,schemaValidation:!1,enableBoundingRectangles:!1,enableCanvasUnderlay:"None",enableParentClass:"",enablePositionNodeOnRightFlyoutOpen:!1,emptyCanvasContent:null,dropZoneCanvasContent:null,enableNodeLayout:{},enableCanvasLayout:{},tipConfig:{palette:!0,nodes:!0,ports:!0,decorations:!0,links:!0,stateTag:!0}},t=it.getLayout(e);return e.enableNodeLayout=t.nodeLayout,e.enableCanvasLayout=t.canvasLayout,e}},{key:"compareCanvasConfigs",value:function(e,t){var n=this,i=!1;return Object.keys(e).length===Object.keys(t).length&&(i=Je(e,t,(function(e,t,i){switch(i){case"enablePositionNodeOnRightFlyoutOpen":return n.enableNodeRightFlyoutOpenExactlyMatches(e,t);case"enableCanvasLayout":return n.enableCanvasLayoutExactlyMatches(e,t);case"enableNodeLayout":return n.enableNodeLayoutExactlyMatches(e,t);case"tipConfig":return n.enableTipConfigExactlyMatches(e,t);default:return e===t}}))),i}},{key:"enableNodeRightFlyoutOpenExactlyMatches",value:function(e,t){return"boolean"==typeof e&&"boolean"==typeof t?e===t:"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.d)(e)&&"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.d)(t)&&e.x===t.x&&e.y===t.y}},{key:"enableCanvasLayoutExactlyMatches",value:function(e,t){return!e&&!t||!(!this.compareFieldCount(e,t)||!et(e,t))}},{key:"enableNodeLayoutExactlyMatches",value:function(e,t){return!e&&!t||!!(this.compareFieldCount(e,t)&&et(e,t)&&this.decorationsArraysExactlyMatches(e.decorations,t.decorations))}},{key:"decorationsArraysExactlyMatches",value:function(e,t){if(!e&&!t)return!0;if(!e||!t)return!1;var n=!0;return e.forEach((function(e,i){var o=t[i];o&&et(e,o)&&et(o,e)||(n=!1)})),n}},{key:"enableTipConfigExactlyMatches",value:function(e,t){return!e&&!t||!(!e||!t)&&(this.compareFieldCount(e,t)&&et(e,t))}},{key:"compareFieldCount",value:function(e,t){return Object.keys(e).length===Object.keys(t).length}}]),n}();function at(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var rt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=at(o);function o(e,n,a,r){var s;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(s=i.call(this,r)).data=e,s.objectModel=n,s.labelUtil=a,s.layoutDirection=r,s.apiPipeline=s.objectModel.getAPIPipeline(),s.existingNodes=s.apiPipeline.getNodes().map((function(e){return Object.assign({},e)})),s}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.apiPipeline.autoLayout(this.layoutDirection)}},{key:"undo",value:function(){this.apiPipeline.replaceNodes(this.existingNodes)}},{key:"redo",value:function(){this.apiPipeline.autoLayout(this.layoutDirection)}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.arrangeLayout")}}]),o}();function st(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var dt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=st(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.node=e.node,r.linksToUpdateInfo=$e.getDetachedLinksToUpdate(r.node,r.data.detachedLinks,r.apiPipeline.getNodeDataLinks()),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"getData",value:function(){return this.data.linksToUpdateInfo=this.linksToUpdateInfo,this.data}},{key:"do",value:function(){this.apiPipeline.moveObjects({nodes:[this.node.id],offsetX:this.data.offsetX,offsetY:this.data.offsetY}),this.apiPipeline.updateLinks(this.linksToUpdateInfo.newLinks)}},{key:"undo",value:function(){this.apiPipeline.updateLinks(this.linksToUpdateInfo.oldLinks),this.apiPipeline.moveObjects({nodes:[this.node.id],offsetX:-this.data.offsetX,offsetY:-this.data.offsetY})}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.attachNodeToLinks",{node_label:this.node.label})}}]),o}();function ct(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var lt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=ct(o);function o(e,n,a){var r;(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.pipelineFlowLoaded=r.objectModel.ensurePipelineIsLoaded(r.data),r.oldSupernode=r.apiPipeline.getNode(r.data.targetObject.id),r.oldPipelines=r.objectModel.getDescPipelinesToDelete([r.oldSupernode],r.data.pipelineId),r.oldPipelines=r.oldPipelines.filter((function(e){return e.parentUrl===r.data.externalUrl})),r.oldExtPipelineFlows=r.objectModel.getExternalPipelineFlowsForPipelines(r.oldPipelines),r.newSupernode=Object.assign({},r.oldSupernode,{subflow_ref:Object.assign({},r.oldSupernode.subflow_ref)}),r.newSupernode.image=r.newSupernode.image===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.s?_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.U:r.newSupernode.image,delete r.newSupernode.subflow_ref.url;var s=r.objectModel.getDescendantPipelinesForSupernode(r.newSupernode).filter((function(e){return e.parentUrl===r.data.externalUrl}));return r.newPipelines=r.objectModel.cloneSupernodeContents(r.newSupernode,s),r.newPipelines=r.newPipelines.map((function(e){return delete e.parentUrl,e})),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.objectModel.replaceSupernodeAndPipelines({pipelineId:this.data.pipelineId,topSupernode:this.newSupernode,pipelinesToAdd:this.newPipelines,pipelinesToRemove:this.oldPipelines,extPipelineFlowsToAdd:[],extPipelineFlowsToDelete:this.oldExtPipelineFlows})}},{key:"undo",value:function(){this.objectModel.replaceSupernodeAndPipelines({pipelineId:this.data.pipelineId,topSupernode:this.oldSupernode,pipelinesToAdd:this.oldPipelines,pipelinesToRemove:this.newPipelines,extPipelineFlowsToAdd:this.oldExtPipelineFlows,extPipelineFlowsToDelete:[]})}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.convertSuperNodeExternalToLocal",{node_label:this.oldSupernode.label})}}]),o}();function ut(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var pt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=ut(o);function o(e,n,a){var r;(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.oldSupernode=r.apiPipeline.getNode(r.data.targetObject.id),r.newSupernode=Object.assign({},r.oldSupernode,{subflow_ref:Object.assign({},r.oldSupernode.subflow_ref)}),r.newSupernode.image=r.newSupernode.image===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.U?_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.s:r.newSupernode.image,r.newSupernode.subflow_ref.url=r.data.externalUrl;var s=r.objectModel.getDescendantPipelinesForSupernode(r.oldSupernode);return r.oldPipelines=s.filter((function(e){return!e.parentUrl})),r.newPipelines=r.objectModel.cloneSupernodeContents(r.newSupernode,r.oldPipelines),r.newPipelines=r.newPipelines.map((function(e){return e.parentUrl=r.data.externalUrl,e})),r.newPipelineFlow=r.objectModel.createExternalPipelineFlowTemplate(r.data.pipelineFlowId,r.newSupernode.subflow_ref.pipeline_id_ref),r.newPipelineFlow.pipelines=[],r.newPipelineFlow.url=r.data.externalUrl,r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.objectModel.replaceSupernodeAndPipelines({pipelineId:this.data.pipelineId,topSupernode:this.newSupernode,pipelinesToAdd:this.newPipelines,pipelinesToRemove:this.oldPipelines,extPipelineFlowsToAdd:[this.newPipelineFlow],extPipelineFlowsToDelete:[]})}},{key:"undo",value:function(){this.objectModel.replaceSupernodeAndPipelines({pipelineId:this.data.pipelineId,topSupernode:this.oldSupernode,pipelinesToAdd:this.oldPipelines,pipelinesToRemove:this.newPipelines,extPipelineFlowsToAdd:[],extPipelineFlowsToDelete:[this.newPipelineFlow]})}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.convertSuperNodeLocalToExternal",{node_label:this.oldSupernode.label})}}]),o}();function ft(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var ht=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=ft(o);function o(e,n,a,r){var s;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(s=i.call(this,e)).data=e,s.labelUtil=a,s.objectModel=n,s.apiPipeline=s.objectModel.getAPIPipeline(e.pipelineId),s.srcNode=s.apiPipeline.getAutoSourceNode(r),s.newNode=s.apiPipeline.createAutoNode(e,s.srcNode),s.newLink=null,s.apiPipeline.isLinkNeededWithAutoNode(s.newNode,s.srcNode)&&(s.newLink=s.apiPipeline.createLink(s.newNode,s.srcNode)),s}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"getData",value:function(){return this.data.sourceNode=this.srcNode,this.data.newNode=this.newNode,this.data.newLink=this.newLink,this.data.subPipeline=this.subPipelines,this.data}},{key:"do",value:function(){this.apiPipeline.addNode(this.newNode),this.newLink&&this.apiPipeline.addLink(this.newLink),this.objectModel.setSelections([this.newNode.id],this.data.pipelineId)}},{key:"undo",value:function(){this.apiPipeline.deleteNodes([this.newNode])}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.createNode",{node_label:this.newNode.label})}}]),o}();function gt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var yt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=gt(o);function o(e,n,a,r){var s;if((0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(s=i.call(this,e)).data=e,s.objectModel=n,s.labelUtil=a,s.apiPipeline=s.objectModel.getAPIPipeline(e.pipelineId),r){var d=s.apiPipeline.getNewCommentPosition(r);s.data.mousePos={x:d.x_pos,y:d.y_pos}}return s.comment=s.apiPipeline.createComment(e),s}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"getData",value:function(){return this.data.commentId=this.comment.id,this.data}},{key:"do",value:function(){this.apiPipeline.addComment(this.comment)}},{key:"undo",value:function(){this.apiPipeline.deleteComment(this.comment.id)}},{key:"redo",value:function(){this.apiPipeline.addComment(this.comment)}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.createComment")}}]),o}();function mt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var vt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=mt(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.linkCommentList=r.apiPipeline.createCommentLinks(e),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"getData",value:function(){return this.data.linkIds=this.linkCommentList.map((function(e){return e.id})),this.data.linkType="comment",this.data}},{key:"do",value:function(){this.apiPipeline.addLinks(this.linkCommentList)}},{key:"undo",value:function(){var e=this;this.linkCommentList.forEach((function(t){e.apiPipeline.deleteLink(t)}))}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.createCommentLink")}}]),o}();function bt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var _t=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=bt(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.newNode=r.apiPipeline.createNode(e),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"getData",value:function(){return this.data.newNode=this.newNode,this.data.subPipelines=this.subPipelines,this.data}},{key:"do",value:function(){this.apiPipeline.addNode(this.newNode)}},{key:"undo",value:function(){this.apiPipeline.deleteNodes([this.newNode])}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.createNode",{node_label:this.newNode.label})}}]),o}();function kt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var Pt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=kt(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.actionLabel=r.createActionLabel(),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"getData",value:function(){return this.data.linkIds=this.linkNodeList.map((function(e){return e.id})),this.data.linkType="data",this.data}},{key:"do",value:function(){this.data.replaceLink&&this.apiPipeline.deleteLink(this.data.replaceLink),this.linkNodeList=this.apiPipeline.createNodeLinks(this.data),this.apiPipeline.addLinks(this.linkNodeList)}},{key:"undo",value:function(){var e=this;this.linkNodeList.forEach((function(t){e.apiPipeline.deleteLink(t)})),this.data.replaceLink&&this.apiPipeline.addLinks([this.data.replaceLink])}},{key:"redo",value:function(){this.data.replaceLink&&this.apiPipeline.deleteLink(this.data.replaceLink),this.apiPipeline.addLinks(this.linkNodeList)}},{key:"getLabel",value:function(){return this.actionLabel}},{key:"createActionLabel",value:function(){var e=this.getTargetNodeLabel();return this.data.replaceLink?this.labelUtil.getActionLabel(this,"action.replaceNodeLink",{node_label:e}):this.labelUtil.getActionLabel(this,"action.createNodeLink",{node_label:e})}},{key:"getTargetNodeLabel",value:function(){return(this.data.targetNodes&&this.data.targetNodes.length>0?this.apiPipeline.getNode(this.data.targetNodes[0].id):{}).label}}]),o}();function It(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var Nt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=It(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.detachedLink=r.apiPipeline.createNodeLinkDetached(e),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"getData",value:function(){return this.data}},{key:"do",value:function(){this.apiPipeline.addLinks([this.detachedLink])}},{key:"undo",value:function(){this.apiPipeline.deleteLink(this.detachedLink)}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.createNodeLinkDetached")}}]),o}();function St(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var Et=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=St(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.newNode=r.apiPipeline.createNode(e),r.firstLinkSrcInfo={id:e.link.srcNodeId,portId:e.link.srcNodePortId},r.firstLinkTrgInfo={id:r.newNode.id},r.secondLinkSrcInfo={id:r.newNode.id},r.secondLinkTrgInfo={id:e.link.trgNodeId,portId:e.link.trgNodePortId},r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"getData",value:function(){return this.data.newNode=this.newNode,this.data.newFirstLink=this.firstLink,this.data.newSecondLink=this.secondLink,this.data}},{key:"do",value:function(){this.apiPipeline.deleteLink({id:this.data.link.id}),this.apiPipeline.addNode(this.newNode),this.firstLink=this.apiPipeline.createNodeLink(this.firstLinkSrcInfo,this.firstLinkTrgInfo,{type:"nodeLink"}),this.secondLink=this.apiPipeline.createNodeLink(this.secondLinkSrcInfo,this.secondLinkTrgInfo,{type:"nodeLink"}),this.apiPipeline.addLinks([this.firstLink,this.secondLink])}},{key:"undo",value:function(){this.apiPipeline.deleteLink({id:this.firstLink.id}),this.apiPipeline.deleteLink({id:this.secondLink.id}),this.apiPipeline.deleteNodes([this.newNode]),this.apiPipeline.addLinks([this.data.link])}},{key:"redo",value:function(){this.apiPipeline.deleteLink({id:this.data.link.id}),this.apiPipeline.addNode(this.newNode),this.apiPipeline.addLinks([this.firstLink,this.secondLink])}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.createNodeOnLink",{node_label:this.newNode.label})}}]),o}();function jt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var wt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=jt(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.newNode=r.apiPipeline.createNode(e),r.linksToUpdateInfo=$e.getDetachedLinksToUpdate(r.newNode,r.data.detachedLinks,r.apiPipeline.getNodeDataLinks()),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"getData",value:function(){return this.data.newNode=this.newNode,this.data.linksToUpdateInfo=this.linksToUpdateInfo,this.data}},{key:"do",value:function(){this.apiPipeline.addNode(this.newNode),this.apiPipeline.updateLinks(this.linksToUpdateInfo.newLinks)}},{key:"undo",value:function(){this.apiPipeline.updateLinks(this.linksToUpdateInfo.oldLinks),this.apiPipeline.deleteNodes([this.newNode])}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.createNodeAttachLinks",{node_label:this.newNode.label})}}]),o}();function Ot(e,t){var n="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!n){if(Array.isArray(e)||(n=function(e,t){if(!e)return;if("string"==typeof e)return Tt(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);"Object"===n&&e.constructor&&(n=e.constructor.name);if("Map"===n||"Set"===n)return Array.from(e);if("Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return Tt(e,t)}(e))||t&&e&&"number"==typeof e.length){n&&(e=n);var i=0,o=function(){};return{s:o,n:function(){return i>=e.length?{done:!0}:{done:!1,value:e[i++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var a,r=!0,s=!1;return{s:function(){n=n.call(e)},n:function(){var e=n.next();return r=e.done,e},e:function(e){s=!0,a=e},f:function(){try{r||null==n.return||n.return()}finally{if(s)throw a}}}}function Tt(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,i=new Array(t);n<t;n++)i[n]=e[n];return i}function Lt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var xt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=Lt(o);function o(e,n,a){var r;(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).labelUtil=a,r.data=e,r.objectModel=n,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.subflowNodes=r.objectModel.getSelectedNodes(),r.subflowComments=r.objectModel.getSelectedComments(),r.subflowRect=r.apiPipeline.getBoundingRectForNodes(r.subflowNodes),r.subflowLinks=[],r.linksToDelete=[],r.commentLinks=[],r.data.selectedObjectIds.forEach((function(e){r.apiPipeline.getLinksContainingId(e).forEach((function(e){r.subflowLinks.find((function(t){return t.id===e.id}))||(e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H||e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K?r.subflowLinks.push(e):r.commentLinks.find((function(t){return t.id===e.id}))||e.type!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O||r.commentLinks.push(e))}))})),r.commentLinks.forEach((function(e){var t=r.apiPipeline.getComment(e.srcNodeId);r.apiPipeline.isObjectIdInObjects(t.id,r.subflowComments)?r.subflowLinks.push(e):r.apiPipeline.isCommentLinkedToNonSelectedNodes(t.id)?(r.linksToDelete.push(e),r.subflowLinks=r.subflowLinks.filter((function(t){return t.id!==e.id}))):(r.subflowLinks.push(e),r.subflowComments.push(t))})),r.commentsToUnlinkFromUnselectedNodes=[];var s,d=Ot(r.subflowComments);try{for(d.s();!(s=d.n()).done;){var c=s.value;r.apiPipeline.isCommentLinkedToNonSelectedNodes(c.id)&&r.commentsToUnlinkFromUnselectedNodes.push(c)}}catch(e){d.e(e)}finally{d.f()}r.commentsToUnlinkFromUnselectedNodes.forEach((function(e){r.apiPipeline.getLinksContainingId(e.id).forEach((function(e){r.apiPipeline.isObjectIdInObjects(e.trgNodeId,r.subflowNodes)||r.apiPipeline.isObjectIdInObjects(e.id,r.linksToDelete)||r.removeLinkFromSubflow(e,!0)}))})),r.supernodeInputLinks=[],r.supernodeOutputLinks=[],r.apiPipeline.getNodeLinks(r.subflowNodes).forEach((function(e){r.apiPipeline.isObjectIdInObjects(e.srcNodeId,r.subflowNodes)||r.supernodeInputLinks.find((function(t){return t.id===e.trgNodeId}))||(e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K?r.removeLinkFromSubflow(e,!0):r.supernodeInputLinks.push(e)),r.apiPipeline.isObjectIdInObjects(e.trgNodeId,r.subflowNodes)||r.supernodeOutputLinks.find((function(t){return t.id===e.srcNodeId}))||(e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K?r.removeLinkFromSubflow(e,!0):r.supernodeOutputLinks.push(e))})),r.supernodeInputLinksModified=r.reorderSupernodeLinks(r.supernodeInputLinks,"input"),r.supernodeOutputLinksModified=r.reorderSupernodeLinks(r.supernodeOutputLinks,"output"),r.supernodeInputLinksModified.forEach((function(e){r.removeLinkFromSubflow(e,!1)})),r.supernodeOutputLinksModified.forEach((function(e){r.removeLinkFromSubflow(e,!1)})),r.subPipeline=r.objectModel.createPipeline(r.subflowNodes,r.subflowComments,r.subflowLinks),r.subAPIPipeline=r.objectModel.getAPIPipeline(r.subPipeline.id),r.createBindingNodeData=[],r.supernode=r.createSupernode(),r.linkSrcDefs=[],r.linkTrgDefs=[],r.supernodeInputLinksModified.forEach((function(e){r.apiPipeline.isObjectIdInObjects(e.srcNodeId,r.subflowNodes)||(r.linkSrcDefs.push({id:e.srcNodeId,portId:e.srcNodePortId}),r.linkTrgDefs.push({id:r.supernode.id,portId:e.trgNodePortId?e.trgNodeId+"_"+e.trgNodePortId:e.trgNodePortId}))})),r.supernodeOutputLinksModified.forEach((function(e){r.apiPipeline.isObjectIdInObjects(e.trgNodeId,r.subflowNodes)||(r.linkSrcDefs.push({id:r.supernode.id,portId:e.srcNodePortId?e.srcNodeId+"_"+e.srcNodePortId:e.srcNodePortId}),r.linkTrgDefs.push({id:e.trgNodeId,portId:e.trgNodePortId}))})),r.supernodeBindingNodesMappedToParentFlowData=[],r.supernodeEntryBindingNodes=[],r.supernodeExitBindingNodes=[];var l=80,u=r.subflowRect.y-l,p=r.subflowRect.y-l;if(r.createBindingNodeData.forEach((function(e){var t=Object.assign({},e.port);if("entry"===e.type){var n={x:r.subflowRect.x-160,y:u+=l};t.id=t.id?"output_"+t.id:t.id;var i=r.createBindingNode(e.link,{outputs:[t]},n);r.supernodeBindingNodesMappedToParentFlowData[i.id]={portId:e.port.id,link:e.link},i.isSupernodeInputBinding=!0,r.supernodeEntryBindingNodes.push(i)}else{var o={x:r.subflowRect.x+r.subflowRect.width+l,y:p+=l};t.id=t.id?"input_"+t.id:t.id;var a=r.createBindingNode(e.link,{inputs:[t]},o);r.supernodeBindingNodesMappedToParentFlowData[a.id]={portId:e.port.id,link:e.link},a.isSupernodeOutputBinding=!0,r.supernodeExitBindingNodes.push(a)}})),r.bindingNodeLinkSrcDefs=[],r.bindingNodeLinkTrgDefs=[],r.supernodeEntryBindingNodes.forEach((function(e){var t=r.supernodeBindingNodesMappedToParentFlowData[e.id].link;r.bindingNodeLinkSrcDefs.push({id:e.id,portId:t.trgNodePortId?"output_"+t.trgNodeId+"_"+t.trgNodePortId:t.trgNodePortId}),r.bindingNodeLinkTrgDefs.push({id:t.trgNodeId,portId:t.trgNodePortId})})),r.supernodeExitBindingNodes.forEach((function(e){var t=r.supernodeBindingNodesMappedToParentFlowData[e.id].link;r.bindingNodeLinkSrcDefs.push({id:t.srcNodeId,portId:t.srcNodePortId}),r.bindingNodeLinkTrgDefs.push({id:e.id,portId:t.srcNodePortId?"input_"+t.srcNodeId+"_"+t.srcNodePortId:t.srcNodePortId})})),r.data.externalUrl){var f=$e.filterSupernodes(r.subflowNodes),h=r.objectModel.getDescendantPipelinesForSupernodes(f);r.descPipelines=h.filter((function(e){return!e.parentUrl})),r.newPipelineFlow=r.objectModel.createExternalPipelineFlowTemplate(r.data.externalPipelineFlowId,r.supernode.subflow_ref.pipeline_id_ref)}return r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"createSupernode",value:function(){var e=this,t=[];this.supernodeInputLinksModified.forEach((function(n){var i=e.apiPipeline.getNode(n.trgNodeId);e.createSupernodePorts(i,n,t,"entry")}));var n=[];this.supernodeOutputLinksModified.forEach((function(t){var i=e.apiPipeline.getNode(t.srcNodeId);e.createSupernodePorts(i,t,n,"exit")}));var i={label:this.labelUtil.getLabel("supernode.template.label"),description:this.labelUtil.getLabel("supernode.template.description"),image:this.data.externalUrl?_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.s:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.U,inputs:t,outputs:n,type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai,subflow_ref:{pipeline_id_ref:this.subPipeline.id}};this.data.externalUrl&&(i.subflow_ref.url=this.data.externalUrl);var o=this.getTopLeftNode(this.subflowNodes),a={nodeTemplate:i,offsetX:o.x_pos,offsetY:o.y_pos};return this.apiPipeline.createNode(a)}},{key:"reorderSupernodeLinks",value:function(e,t){var n=this;if(e.length>1){var i=(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e),o="input"===t?"inputs":"outputs",a="input"===t?"trgNodeId":"srcNodeId",r="input"===t?"trgNodePortId":"srcNodePortId",s=[];i.forEach((function(e){s.find((function(t){return t.id===e[a]}))||s.push(n.apiPipeline.getNode(e[a]))})),s.sort((function(e,t){return e.y_pos<t.y_pos?-1:e.y_pos>t.y_pos?1:0}));var d=[];return s.forEach((function(e){var t=e[o],n=t[0];t.forEach((function(t){var o=i.filter((function(n){return(n[r]===t.id||void 0===n[r]||null===n[r])&&n[a]===e.id}));(o=o.map((function(e){var t=Object.assign({},e);return t[r]=t[r]?t[r]:n.id,t}))).forEach((function(e){d.find((function(t){return t.id===e.id}))||(d=d.concat(e))}))}))})),d}return e}},{key:"getTopLeftNode",value:function(e){var t=this,n=e[0],i=this.getDistanceFromPosition(this.subflowRect.x,this.subflowRect.y,e[0]);return e.forEach((function(e){var o=t.getDistanceFromPosition(t.subflowRect.x,t.subflowRect.y,e);o<i&&(i=o,n=e)})),n}},{key:"getDistanceFromPosition",value:function(e,t,n){var i=n.x_pos-e,o=n.y_pos-t;return Math.sqrt(Math.pow(i,2)+Math.pow(o,2))}},{key:"createSupernodePorts",value:function(e,t,n,i){var o=this,a="entry"===i?"inputs":"outputs",r="entry"===i?"trgNodePortId":"srcNodePortId";if(void 0!==t[r]&&null!==t[r])e[a].forEach((function(a){if(t[r]===a.id){var s=Object.assign({},a);s.id=a.id?e.id+"_"+a.id:a.id,s.label=o.labelUtil.getLabel("supernode.new.port.label"),o.addToCreateBindingNodeData(e.id,s,t,n,i)}}));else{var s=Object.assign({},e[a][0]);s.id=s.id?e.id+"_"+s.id:s.id,s.label=this.labelUtil.getLabel("supernode.new.port.label"),this.addToCreateBindingNodeData(e.id,s,t,n,i)}}},{key:"addToCreateBindingNodeData",value:function(e,t,n,i,o){i.find((function(e){return e.id===t.id}))||(i.push(t),this.createBindingNodeData.push({bindindNodeForNodeId:e,type:o,link:n,port:t}))}},{key:"createBindingNode",value:function(e,t,n){var i={description:this.labelUtil.getLabel("supernode.binding.node.description"),label:this.labelUtil.getLabel("supernode.binding.node.label"),type:"binding"},o={editType:"createNode",nodeTemplate:Object.assign(i,t),offsetX:n.x,offsetY:n.y};return this.subAPIPipeline.createNode(o)}},{key:"removeLinkFromSubflow",value:function(e,t){this.subflowLinks=this.subflowLinks.filter((function(t){return t.id!==e.id})),t&&this.linksToDelete.push(e)}},{key:"getData",value:function(){return this.data.newNode=this.supernode,this.data.newLinks=this.newLinks,this.data.subPipelineId=this.subPipeline.id,this.data}},{key:"do",value:function(){var e=this;this.apiPipeline.deleteNodes(this.subflowNodes,!1),this.apiPipeline.deleteComments(this.subflowComments),this.apiPipeline.deleteLinks(this.linksToDelete),this.apiPipeline.addSupernode(this.supernode,[this.subPipeline]),this.supernodeEntryBindingNodes.forEach((function(t){var n=e.supernodeBindingNodesMappedToParentFlowData[t.id].portId;e.apiPipeline.setInputPortSubflowNodeRef(e.supernode.id,n,t.id)})),this.supernodeExitBindingNodes.forEach((function(t){var n=e.supernodeBindingNodesMappedToParentFlowData[t.id].portId;e.apiPipeline.setOutputPortSubflowNodeRef(e.supernode.id,n,t.id)})),this.newLinks=[];for(var t=0;t<this.linkSrcDefs.length;t++){var n=this.apiPipeline.createNodeLink(this.linkSrcDefs[t],this.linkTrgDefs[t],{type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H});n&&this.newLinks.push(n)}this.apiPipeline.addLinks(this.newLinks),this.supernodeEntryBindingNodes.forEach((function(t){e.subAPIPipeline.addNode(t)})),this.supernodeExitBindingNodes.forEach((function(t){e.subAPIPipeline.addNode(t)})),this.supernodeNewLinks=[];for(var i=0;i<this.bindingNodeLinkSrcDefs.length;i++)this.supernodeNewLinks.push(this.subAPIPipeline.createNodeLink(this.bindingNodeLinkSrcDefs[i],this.bindingNodeLinkTrgDefs[i],{type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H}));if(this.subAPIPipeline.addLinks(this.supernodeNewLinks),this.data.externalUrl){this.objectModel.addExternalPipelineFlow(this.newPipelineFlow,this.data.externalUrl,null,!1);var o=[this.subPipeline].concat(this.descPipelines);this.objectModel.setParentUrl(o,this.data.externalUrl)}}},{key:"undo",value:function(){var e=this;this.data.externalUrl&&(this.objectModel.setParentUrl(this.descPipelines),this.objectModel.removeExternalPipelineFlow(this.data.externalUrl)),this.apiPipeline.deleteSupernodes([this.supernode],[this.subPipeline],[]),this.subflowNodes.forEach((function(t){e.apiPipeline.addNode(t)})),this.subflowComments.forEach((function(t){e.apiPipeline.addComment(t)})),this.apiPipeline.addLinks(this.subflowLinks),this.apiPipeline.addLinks(this.supernodeInputLinks),this.apiPipeline.addLinks(this.supernodeOutputLinks),this.apiPipeline.addLinks(this.linksToDelete)}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.createSuperNode",{node_label:this.supernode.label})}}]),o}();function Ct(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var At=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=Ct(o);function o(e,n,a,r){var s;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(s=i.call(this,e)).data=e,s.objectModel=n,s.labelUtil=a,s.apiPipeline=s.objectModel.getAPIPipeline(e.pipelineId),s.oldObjectPositions=[],s.newObjectPositions=[],s.oldLinkPositions=[],s.newLinkPositions=[],s.enableMoveNodesOnSupernodeResize=r,s.apiPipeline=s.objectModel.getAPIPipeline(e.pipelineId),s.enableMoveNodesOnSupernodeResize&&(s.supernode=s.apiPipeline.getNode(s.data.id),s.oldObjectPositions=$e.getObjectPositions(s.apiPipeline.getObjects()),s.oldLinkPositions=$e.getLinkPositions(s.apiPipeline.getLinks()),s.newObjectPositions=$e.moveSurroundingObjects(s.supernode,s.apiPipeline.getObjects(),"se",s.supernode.layout.defaultNodeWidth,s.supernode.layout.defaultNodeHeight,!1),s.newLinkPositions=$e.moveSurroundingDetachedLinks(s.supernode,s.apiPipeline.getLinks(),"se",s.supernode.layout.defaultNodeWidth,s.supernode.layout.defaultNodeHeight,!1)),s}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.apiPipeline.collapseSuperNodeInPlace(this.data.id,this.newObjectPositions,this.newLinkPositions)}},{key:"undo",value:function(){this.apiPipeline.expandSuperNodeInPlace(this.data.id,this.oldObjectPositions,this.oldLinkPositions)}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.collapseSuperNodeInPlace")}}]),o}();function Dt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var Mt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=Dt(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.oldIds=r.data.selectedObjects.map((function(e){return e.id})),r.oldColors=r.getOldColors(),r.actionLabel=r.createActionLabel(),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.apiPipeline.setObjectsColorClassName(this.oldIds,this.data.editParam.color)}},{key:"undo",value:function(){this.apiPipeline.setObjectsColorClassName(this.oldIds,this.oldColors)}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.actionLabel}},{key:"createActionLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.colorComments",{comments_count:this.data.selectedObjectIds.length})}},{key:"getOldColors",value:function(){var e=this,t=[];return this.data.selectedObjects.forEach((function(n){t.push(e.getObjectColorClass(n))})),t}},{key:"getObjectColorClass",value:function(e){if(e.class_name){var t=e.class_name.split(" ");if(t)return t.find((function(e){return $e.getBkgColorClass(e)}))}return""}}]),o}();function Rt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var Ut=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=Rt(o);function o(e,n,a,r){var s;(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(s=i.call(this,e)).data=e,s.objectModel=n,s.labelUtil=a,s.apiPipeline=s.objectModel.getAPIPipeline(e.pipelineId),s.enableMoveNodesOnSupernodeResize=r,s.supernode=s.data.targetObject,s.oldObjectPositions=[],s.newObjectPositions=[],s.oldLinkPositions=[],s.newLinkPositions=[],s.objectModel.ensurePipelineIsLoaded(s.data),s.targetApiPipeline=s.objectModel.getAPIPipeline(s.supernode.subflow_ref.pipeline_id_ref),s.targetPipeline=s.targetApiPipeline.getPipeline(),s.extPipelineFlowToDelete=s.targetPipeline.parentUrl?s.objectModel.getExternalPipelineFlow(s.targetPipeline.parentUrl):[];var d=s.getLinksToRemove(),c=s.getBindingNodes(),l=s.getNonBindingNodes(c),u=s.getCommentsToAdd(),p=s.getLinksToAdd(c,d),f={left:0,top:0};return s.enableMoveNodesOnSupernodeResize&&(s.oldObjectPositions=$e.getObjectPositions(s.apiPipeline.getObjects()),s.oldLinkPositions=$e.getLinkPositions(s.apiPipeline.getLinks()),f=$e.getCanvasDimensions(l,u,p,0,0),s.newObjectPositions=$e.moveSurroundingObjects(s.data.targetObject,s.apiPipeline.getObjects(),"se",f.width,f.height,!1),s.newLinkPositions=$e.moveSurroundingDetachedLinks(s.data.targetObject,s.apiPipeline.getLinks(),"se",f.width,f.height,!1)),l.forEach((function(e){s.newObjectPositions[e.id]={x_pos:s.supernode.x_pos+e.x_pos-f.left,y_pos:s.supernode.y_pos+e.y_pos-f.top}})),u.forEach((function(e){s.newObjectPositions[e.id]={x_pos:s.supernode.x_pos+e.x_pos-f.left,y_pos:s.supernode.y_pos+e.y_pos-f.top}})),s.info={pipelineId:s.data.pipelineId,supernodeToDelete:s.supernode,nodesToAdd:l,linksToAdd:p,linksToRemove:d,commentsToAdd:u,oldObjectPositions:s.oldObjectPositions,newObjectPositions:s.newObjectPositions,oldLinkPositions:s.oldLinkPositions,newLinkPositions:s.newLinkPositions,pipelineToDelete:s.targetPipeline,extPipelineFlowToDelete:s.extPipelineFlowToDelete},s}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"getNonBindingNodes",value:function(e){return this.targetApiPipeline.getNodes().filter((function(t){return!e.some((function(e){return e.id===t.id}))}))}},{key:"getBindingNodes",value:function(){var e=this,t=[];return this.data.targetObject.inputs&&this.data.targetObject.inputs.forEach((function(n){var i=e.targetApiPipeline.getNode(n.subflow_node_ref);i&&t.push(i)})),this.data.targetObject.outputs&&this.data.targetObject.outputs.forEach((function(n){var i=e.targetApiPipeline.getNode(n.subflow_node_ref);i&&t.push(i)})),t}},{key:"getLinksToFromBindingNodes",value:function(e){return this.targetApiPipeline.getLinksContainingIds(e.map((function(e){return e.id})))}},{key:"getLinksNotToFromBindingNodes",value:function(e){var t=this.getLinksToFromBindingNodes(e);return this.targetApiPipeline.getLinks().filter((function(e){return!t.some((function(t){return t.id===e.id}))}))}},{key:"getCommentsToAdd",value:function(){return this.targetApiPipeline.getComments()}},{key:"getLinksToRemove",value:function(){return this.apiPipeline.getLinksContainingId(this.supernode.id)}},{key:"getLinksToAdd",value:function(e,t){var n=this.getLinksNotToFromBindingNodes(e),i=this.getNewLinks(t);return n.concat(i)}},{key:"getNewLinks",value:function(e){var t=this,n=[],i=e.filter((function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H}));return this.supernode.inputs&&this.supernode.inputs.forEach((function(e){n=n.concat(t.getNewLinksForInput(e,i))})),this.supernode.outputs&&this.supernode.outputs.forEach((function(e){n=n.concat(t.getNewLinksForOutput(e,i))})),n}},{key:"getNewLinksForInput",value:function(e,t){var n=this,i=[],o=this.getSupernodeInputLinks(this.supernode,e.id,t),a=this.getInputBindingNode(e);if(a){var r=this.getInputBindingLinks(a);o.forEach((function(e){r.forEach((function(t){var o={};e.srcPos?o.srcPos=e.srcPos:(o.srcNodeId=e.srcNodeId,o.srcNodePortId=e.srcNodePortId),t.trgPos?o.trgPos=t.trgPos:(o.trgNodeId=t.trgNodeId,o.trgNodePortId=t.trgNodePortId);var a=n.apiPipeline.createLinkFromInfo(o);i.push(a)}))}))}return i}},{key:"getNewLinksForOutput",value:function(e,t){var n=this,i=[],o=this.getSupernodeOutputLinks(this.supernode,e.id,t),a=this.getOutputBindingNode(e);if(a){var r=this.getOutputBindingLinks(a);o.forEach((function(e){r.forEach((function(t){var o={};t.srcPos?o.srcPos=t.srcPos:(o.srcNodeId=t.srcNodeId,o.srcNodePortId=t.srcNodePortId),e.trgPos?o.trgPos=e.trgPos:(o.trgNodeId=e.trgNodeId,o.trgNodePortId=e.trgNodePortId);var a=n.apiPipeline.createLinkFromInfo(o);i.push(a)}))}))}return i}},{key:"getSupernodeInputLinks",value:function(e,t,n){return n.filter((function(n){var i=n.trgNodePortId||$e.getDefaultInputPortId(e);return n.trgNodeId===e.id&&i===t}))}},{key:"getInputBindingNode",value:function(e){return this.targetApiPipeline.getNodes().find((function(t){return t.id===e.subflow_node_ref}))}},{key:"getInputBindingLinks",value:function(e){return this.targetApiPipeline.getLinksContainingSourceId(e.id).filter((function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H}))}},{key:"getSupernodeOutputLinks",value:function(e,t,n){return n.filter((function(n){var i=n.srcNodePortId||$e.getDefaultOutputPortId(e);return n.srcNodeId===e.id&&i===t}))}},{key:"getOutputBindingNode",value:function(e){return this.targetApiPipeline.getNodes().find((function(t){return t.id===e.subflow_node_ref}))}},{key:"getOutputBindingLinks",value:function(e){return this.targetApiPipeline.getLinksContainingTargetId(e.id).filter((function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H}))}},{key:"do",value:function(){this.apiPipeline.deconstructSupernode(this.info)}},{key:"undo",value:function(){this.apiPipeline.reconstructSupernode(this.info)}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.deconstructSuperNode",{node_label:this.supernode.label})}}]),o}();function Ft(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var Bt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=Ft(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.linkInfo=[],r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.linkInfo=this.apiPipeline.getLink(this.data.id),this.apiPipeline.deleteLink(this.data)}},{key:"undo",value:function(){this.apiPipeline.addLinks([this.linkInfo])}},{key:"redo",value:function(){this.apiPipeline.deleteLink(this.data)}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.deleteLink")}}]),o}();function Ht(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var qt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=Ht(o);function o(e,n,a,r){var s;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(s=i.call(this,e)).data=e,s.objectModel=n,s.labelUtil=a,s.areDetachableLinksSupported=r,s.objectsInfo=[],s.apiPipeline=s.objectModel.getAPIPipeline(e.pipelineId),s.nodesToDelete=s.objectModel.getSelectedNodes(),s.commentsToDelete=s.objectModel.getSelectedComments(),s.linksToDelete=s.objectModel.getSelectedLinks(),s.linksToUpdateInfo={},s.supernodesToDelete=[],s.nodeAndCommentsToDelete=s.nodesToDelete.concat(s.commentsToDelete),r?(s.linksToDelete=s.getConnectedLinksToDelete(s.linksToDelete,"nodeLink"),s.linksToUpdateInfo=s.getLinksToUpdateInfo()):s.linksToDelete=s.getConnectedLinksToDelete(s.linksToDelete),s.supernodesToDelete=$e.filterSupernodes(s.nodesToDelete),s.pipelinesToDelete=s.objectModel.getDescPipelinesToDelete(s.supernodesToDelete,s.data.pipelineId),s.extPipelineFlowsToDelete=s.objectModel.getExternalPipelineFlowsForPipelines(s.pipelinesToDelete),s.nodesToDelete=s.nodesToDelete.filter((function(e){return!s.isSupernodeToBeDeleted(e)})),s.actionLabel=s.createActionLabel(),s}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"getConnectedLinksToDelete",value:function(e,t){var n=this;return this.nodeAndCommentsToDelete.forEach((function(i){n.apiPipeline.getLinksContainingId(i.id).forEach((function(i){n.isLinkToBeDeleted(i,e)||i.type===t||e.push(i)}))})),e}},{key:"getLinksToUpdateInfo",value:function(){var e=this,t=[],n=[];return this.apiPipeline.getLinks().forEach((function(i){if(!e.isLinkToBeDeleted(i,e.linksToDelete)){var o=e.isSourceToBeDeleted(i),a=e.isTargetToBeDeleted(i);if(o||a){var r=Object.assign({},i);o&&(delete r.srcNodeId,delete r.srcNodePortId,r.srcPos=$e.getSrcPos(i,e.apiPipeline)),a&&(delete r.trgNodeId,delete r.trgNodePortId,r.trgPos=$e.getTrgPos(i,e.apiPipeline)),t.push(r),n.push(i)}}})),{newLinks:t,oldLinks:n}}},{key:"isLinkToBeDeleted",value:function(e,t){return-1!==t.findIndex((function(t){return t.id===e.id}))}},{key:"isSupernodeToBeDeleted",value:function(e){return-1!==this.supernodesToDelete.findIndex((function(t){return e.id===t.id}))}},{key:"isSourceToBeDeleted",value:function(e){return-1!==this.nodeAndCommentsToDelete.findIndex((function(t){return t.id===e.srcNodeId}))}},{key:"isTargetToBeDeleted",value:function(e){return-1!==this.nodesToDelete.findIndex((function(t){return t.id===e.trgNodeId}))}},{key:"do",value:function(){this.apiPipeline.deleteAndUpdateObjects({linksToUpdate:this.linksToUpdateInfo.newLinks,linksToDelete:this.linksToDelete,supernodesToDelete:this.supernodesToDelete,pipelinesToDelete:this.pipelinesToDelete,extPipelineFlowsToDelete:this.extPipelineFlowsToDelete,nodesToDelete:this.nodesToDelete,commentsToDelete:this.commentsToDelete})}},{key:"undo",value:function(){this.apiPipeline.addAndUpdateObjects({linksToUpdate:this.linksToUpdateInfo.oldLinks,linksToAdd:this.linksToDelete,supernodesToAdd:this.supernodesToDelete,pipelinesToAdd:this.pipelinesToDelete,extPipelineFlowsToAdd:this.extPipelineFlowsToDelete,nodesToAdd:this.nodesToDelete,commentsToAdd:this.commentsToDelete})}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.actionLabel}},{key:"createActionLabel",value:function(){var e="action.delete"+[{label:"Nodes",val:this.nodesToDelete.length+this.supernodesToDelete.length},{label:"Comments",val:this.commentsToDelete.length},{label:"Links",val:this.linksToDelete.length}].filter((function(e){return e.val})).map((function(e){return e.label})).join("");return this.labelUtil.getActionLabel(this,e,{nodes_count:this.nodesToDelete.length+this.supernodesToDelete.length,comments_count:this.commentsToDelete.length,links_count:this.linksToDelete.length})}}]),o}();function Gt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var zt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=Gt(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.links=[],r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.links=this.apiPipeline.disconnectObjects(this.data.selectedObjectIds)}},{key:"undo",value:function(){this.apiPipeline.addLinks(this.links)}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.disconnectObjects")}}]),o}();function Vt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var $t=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=Vt(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.oldBreadcrumbs=r.objectModel.getBreadcrumbs(),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.objectModel.setPreviousBreadcrumb()}},{key:"undo",value:function(){this.objectModel.setBreadcrumbs(this.oldBreadcrumbs)}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.displayPreviousPipeline")}}]),o}();function Wt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var Yt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=Wt(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.oldBreadcrumbs=r.objectModel.getBreadcrumbs(),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.data.addBreadcrumbs?(this.objectModel.ensurePipelineIsLoaded(this.data),this.objectModel.addBreadcrumbs(this.data)):0===this.data.breadcrumbIndex?this.objectModel.setIndexedBreadcrumb(this.data):this.data.breadcrumbIndex&&(this.objectModel.ensurePipelineIsLoaded(this.data),this.objectModel.setIndexedBreadcrumb(this.data))}},{key:"undo",value:function(){this.objectModel.setBreadcrumbs(this.oldBreadcrumbs)}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.displaySubPipeline")}}]),o}();function Xt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var Kt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=Xt(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.previousComment=r.apiPipeline.getComment(r.data.id),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.apiPipeline.editComment(this.data)}},{key:"undo",value:function(){this.apiPipeline.editComment(this.previousComment)}},{key:"redo",value:function(){this.apiPipeline.editComment(this.data)}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.editComment")}}]),o}();function Jt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var Zt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=Jt(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(r.data.pipelineId),r.data.objType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a4?r.previousDecorations=r.apiPipeline.getLinkDecorations(r.data.objId)||[]:r.data.objType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ad&&(r.previousDecorations=r.apiPipeline.getNodeDecorations(r.data.objId)||[]),r.newDecorations=r.previousDecorations.map((function(e){return e.id===r.data.decId?Object.assign({},e,{label:r.data.label}):e})),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.data.objType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a4?this.apiPipeline.setLinkDecorations(this.data.objId,this.newDecorations):this.data.objType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ad&&this.apiPipeline.setNodeDecorations(this.data.objId,this.newDecorations)}},{key:"undo",value:function(){this.data.objType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a4?this.apiPipeline.setLinkDecorations(this.data.objId,this.previousDecorations):this.data.objType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ad&&this.apiPipeline.setNodeDecorations(this.data.objId,this.previousDecorations)}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.data.objType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a4?this.labelUtil.getActionLabel(this,"action.editLinkDecorationLabel"):this.labelUtil.getActionLabel(this,"action.editNodeDecorationLabel")}}]),o}();function Qt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var en=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=Qt(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.previousLabel=r.apiPipeline.getNode(e.nodeId).label,r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.apiPipeline.setNodeLabel(this.data.nodeId,this.data.label)}},{key:"undo",value:function(){this.apiPipeline.setNodeLabel(this.data.nodeId,this.previousLabel)}},{key:"redo",value:function(){this.apiPipeline.setNodeLabel(this.data.nodeId,this.data.label)}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.setNodeLabel")}}]),o}();function tn(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var nn=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=tn(o);function o(e,n,a,r){var s;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(s=i.call(this,e)).data=e,s.objectModel=n,s.labelUtil=a,s.oldObjectPositions=[],s.newObjectPositions=[],s.oldLinkPositions=[],s.newLinkPositions=[],s.enableMoveNodesOnSupernodeResize=r,s.apiPipeline=s.objectModel.getAPIPipeline(e.pipelineId),s.supernode=s.apiPipeline.getNode(s.data.id),s.enableMoveNodesOnSupernodeResize&&(s.oldObjectPositions=$e.getObjectPositions(s.apiPipeline.getObjects()),s.oldLinkPositions=$e.getLinkPositions(s.apiPipeline.getLinks()),s.newObjectPositions=$e.moveSurroundingObjects(s.supernode,s.apiPipeline.getObjects(),"se",$e.getSupernodeExpandedWidth(s.supernode,s.objectModel.getCanvasLayout()),$e.getSupernodeExpandedHeight(s.supernode,s.objectModel.getCanvasLayout()),!1),s.newLinkPositions=$e.moveSurroundingDetachedLinks(s.supernode,s.apiPipeline.getLinks(),"se",$e.getSupernodeExpandedWidth(s.supernode,s.objectModel.getCanvasLayout()),$e.getSupernodeExpandedHeight(s.supernode,s.objectModel.getCanvasLayout()),!1)),s}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.objectModel.ensurePipelineIsLoaded(this.data),this.apiPipeline.expandSuperNodeInPlace(this.data.id,this.newObjectPositions,this.newLinkPositions)}},{key:"undo",value:function(){this.apiPipeline.collapseSuperNodeInPlace(this.data.id,this.oldObjectPositions,this.oldLinkPositions)}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.expandSuperNodeInPlace",{node_label:this.supernode.label})}}]),o}();function on(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var an=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=on(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.node=e.node,r.firstLinkSrcInfo={id:e.link.srcNodeId,portId:e.link.srcNodePortId},r.firstLinkTrgInfo={id:r.node.id},r.secondLinkSrcInfo={id:r.node.id},r.secondLinkTrgInfo={id:e.link.trgNodeId,portId:e.link.trgNodePortId},r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"getData",value:function(){return this.data.newFirstLink=this.firstLink,this.data.newSecondLink=this.secondLink,this.data}},{key:"do",value:function(){this.apiPipeline.deleteLink({id:this.data.link.id}),this.apiPipeline.moveObjects({nodes:[this.node.id],offsetX:this.data.offsetX,offsetY:this.data.offsetY}),this.firstLink=this.apiPipeline.createNodeLink(this.firstLinkSrcInfo,this.firstLinkTrgInfo,{type:"nodeLink"}),this.secondLink=this.apiPipeline.createNodeLink(this.secondLinkSrcInfo,this.secondLinkTrgInfo,{type:"nodeLink"}),this.apiPipeline.addLinks([this.firstLink,this.secondLink])}},{key:"undo",value:function(){this.apiPipeline.deleteLink({id:this.firstLink.id}),this.apiPipeline.deleteLink({id:this.secondLink.id}),this.apiPipeline.moveObjects({nodes:[this.node.id],offsetX:-this.data.offsetX,offsetY:-this.data.offsetY}),this.apiPipeline.addLinks([this.data.link])}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.insertNodeIntoLink",{node_label:this.node.label})}}]),o}();function rn(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var sn=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=rn(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.apiPipeline.moveObjects(this.data)}},{key:"undo",value:function(){this.data.offsetX=-this.data.offsetX,this.data.offsetY=-this.data.offsetY,this.apiPipeline.moveObjects(this.data)}},{key:"redo",value:function(){this.data.offsetX=-this.data.offsetX,this.data.offsetY=-this.data.offsetY,this.apiPipeline.moveObjects(this.data)}},{key:"getLabel",value:function(){return 1===this.data.nodes.length?this.labelUtil.getActionLabel(this,"action.moveObject"):this.labelUtil.getActionLabel(this,"action.moveObjects")}}]),o}();function dn(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var cn=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=dn(o);function o(e,n,a,r,s,d){var c;(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(c=i.call(this,e)).data=e,c.objectModel=n,c.labelUtil=a,c.viewportDimensions=r,c.areDetachableLinksInUse=s,c.isSnapToGridInUse=d,c.apiPipeline=c.objectModel.getAPIPipeline(e.pipelineId),c.adjustObjectsPositions(),c.clones=c.objectModel.cloneObjectsToPaste(e.objects.nodes,e.objects.comments,e.objects.links);var l=c.objectModel.extractAddDataPipelines(c.clones.clonedNodes),u=l.nodes,p=l.pipelines;return c.clones.clonedNodes=u,c.pipelines=p,c.selectionIds=c.getSelectionIds(c.clones),c}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"adjustObjectsPositions",value:function(){var e=this.data.objects,t=$e.getCanvasDimensions(e.nodes,e.comments,e.links,0,0);if(t)if(this.data.mousePos&&this.data.mousePos.x&&this.data.mousePos.y){var n=this.data.mousePos.x-t.left,i=this.data.mousePos.y-t.top;this.moveObjectsPositions(e,n,i)}else{var o=this.viewportDimensions;if(o.x<t.left&&o.y<t.top&&o.x+o.width>t.left&&o.y+o.height>t.top)this.ensureNoOverlap(e);else{var a=o.x+o.width/2-t.width/2-t.left,r=o.y+o.height/2-t.height/2-t.top;this.moveObjectsPositions(e,a,r),this.ensureNoOverlap(e)}}}},{key:"ensureNoOverlap",value:function(e){var t=10,n=10;if(this.isSnapToGridInUse){var i=this.objectModel.getCanvasLayout();t=i.snapToGridXPx,n=i.snapToGridYPx}for(;this.apiPipeline.exactlyOverlaps(e.nodes,e.comments,e.links);)this.moveObjectsPositions(e,t,n)}},{key:"moveObjectsPositions",value:function(e,t,n){e.nodes&&e.nodes.forEach((function(e){e.x_pos+=t,e.y_pos+=n})),e.comments&&e.comments.forEach((function(e){e.x_pos+=t,e.y_pos+=n,e.selectedObjectIds=[]})),e.links&&e.links.forEach((function(e){e.srcPos&&(e.srcPos.x_pos+=t,e.srcPos.y_pos+=n),e.trgPos&&(e.trgPos.x_pos+=t,e.trgPos.y_pos+=n)}))}},{key:"getSelectionIds",value:function(e){var t=[];return e.clonedNodes.forEach((function(e){t.push(e.id)})),e.clonedComments.forEach((function(e){t.push(e.id)})),this.areDetachableLinksInUse&&e.clonedLinks.forEach((function(e){return t.push(e.id)})),t}},{key:"getData",value:function(){return this.data.clonedNodes=this.clones.clonedNodes,this.data.clonedComments=this.clones.clonedComments,this.data.clonedLinks=this.clones.clonedLinks,this.data}},{key:"do",value:function(){this.apiPipeline.addPastedObjects({nodesToAdd:this.clones.clonedNodes,commentsToAdd:this.clones.clonedComments,linksToAdd:this.clones.clonedLinks,pipelinesToAdd:this.pipelines,selections:this.selectionIds})}},{key:"undo",value:function(){var e=$e.filterSupernodes(this.clones.clonedNodes),t=this.objectModel.getDescPipelinesToDelete(e,this.data.pipelineId),n=this.objectModel.getExternalPipelineFlowsForPipelines(t);this.apiPipeline.deletePastedObjects({nodesToDelete:this.clones.clonedNodes,commentsToDelete:this.clones.clonedComments,linksToDelete:this.clones.clonedLinks,pipelinesToDelete:t,extPipelineFlowsToDelete:n})}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.pasteObjects")}}]),o}();function ln(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var un=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=ln(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.data.addedNodeTypes=r.apiPipeline.createNodesForPalette(r.data.selectedObjectIds),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.objectModel.addNodeTypesToPalette(this.data.addedNodeTypes,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ar,this.labelUtil.getLabel("palette.saved.nodes.label"),this.labelUtil.getLabel("palette.saved.nodes.description"),_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.as)}},{key:"undo",value:function(){var e=this.data.addedNodeTypes.map((function(e){return e.id}));this.objectModel.removeNodesFromPalette(e,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ar)}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.saveToPalette")}}]),o}(),pn=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.a2,fn=Ye,hn=_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.k;var gn=function(e,t){return null==e?e:pn(e,fn(t),hn)};function yn(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var mn=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=yn(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.oldPipelineObjStyles=[],gn(r.data.pipelineObjectIds,(function(e,t){var n=r.objectModel.getAPIPipeline(t);r.oldPipelineObjStyles=[],e.forEach((function(e){r.oldPipelineObjStyles.push({pipelineId:t,objId:e,style:n.getObjectStyle(e,r.data.temporary)})}))})),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.objectModel.setObjectsStyle(this.data.pipelineObjectIds,this.data.style,this.data.temporary)}},{key:"undo",value:function(){this.objectModel.setObjectsMultiStyle(this.oldPipelineObjStyles,this.data.temporary)}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.setObjectsStyle")}}]),o}();function vn(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var bn=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=vn(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.oldPipelineLinkStyles=[],gn(r.data.pipelineLinkIds,(function(e,t){var n=r.objectModel.getAPIPipeline(t);r.oldPipelineLinkStyles=[],e.forEach((function(e){r.oldPipelineLinkStyles.push({pipelineId:t,objId:e,style:n.getLinkStyle(e,r.data.temporary)})}))})),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.objectModel.setLinksStyle(this.data.pipelineLinkIds,this.data.style,this.data.temporary)}},{key:"undo",value:function(){this.objectModel.setLinksMultiStyle(this.oldPipelineLinkStyles,this.data.temporary)}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.setLinksStyle")}}]),o}();function _n(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var kn=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=_n(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.oldLink=r.apiPipeline.getLink(e.newLink.id),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.apiPipeline.updateLink(this.data.newLink)}},{key:"undo",value:function(){this.apiPipeline.updateLink(this.oldLink)}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.updateLink")}}]),o}();function Pn(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var i=Object.getOwnPropertySymbols(e);t&&(i=i.filter((function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable}))),n.push.apply(n,i)}return n}function In(e){for(var t=1;t<arguments.length;t++){var n=null!=arguments[t]?arguments[t]:{};t%2?Pn(Object(n),!0).forEach((function(t){(0,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__._)(e,t,n[t])})):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):Pn(Object(n)).forEach((function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t))}))}return e}var Nn=function(){function n(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,n),this.intl=null,this.actionLabelHandler=null,this.defaultMessages=In(In({},Ge),_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.f)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(n,[{key:"setIntl",value:function(e){this.intl=e}},{key:"setActionLabelHandler",value:function(e){this.actionLabelHandler=e}},{key:"getActionLabel",value:function(e,t,n){if(this.actionLabelHandler){var i=this.actionLabelHandler(e,n);if(i)return i}return this.getLabel(t,n)}},{key:"getLabel",value:function(e,t){return void 0!==this.intl&&null!==this.intl?this.intl.formatMessage({id:e,defaultMessage:this.defaultMessages[e]},t):this.defaultMessages[e]}}]),n}(),Sn=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.I,En=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.b,jn=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.q,wn=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.l,On=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.m)((function(e,t){var n=wn(t);return jn(n)&&(n=void 0),jn(e)?Sn(e,En(t,1,jn,!0),void 0,n):[]})),Tn=function(){function n(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,n)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(n,null,[{key:"convertCanvasToCanvasInfo",value:function(e){var t={id:e.diagram.id,nodes:this.getNodes(e.diagram.nodes),comments:this.getComments(e.diagram.comments),links:this.getLinks(e.diagram.links,e.diagram.nodes,e.diagram.comments),runtime_ref:""};return e.zoom&&"number"==typeof e.zoom&&100!==e.zoom&&(t.zoom={k:e.zoom/100,x:0,y:0}),{doc_type:"pipeline",version:"3.0",json_schema:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v3-schema.json",id:e.id,primary_pipeline:e.diagram.id,pipelines:[t]}}},{key:"getNodes",value:function(e){var t=this;return e.map((function(e){var n=t.getType(e),i={id:e.id,image:e.image,x_pos:void 0!==e.x_pos?e.x_pos:e.xPos,y_pos:void 0!==e.y_pos?e.y_pos:e.yPos,class_name:e.className,label:e.objectData.label,type:n};return e.objectData&&e.objectData.description&&(i.description=e.objectData.description),e.inputPorts&&(i.inputs=t.getInputPorts(e.inputPorts,1)),e.outputPorts&&(i.outputs=t.getOutputPorts(e.outputPorts,-1)),e.decorations&&(i.decorations=t.getDecorations(e.decorations)),n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai&&(i.subflow_ref={pipeline_id_ref:e.subDiagramId,url:"app_defined"},i.open_with_tool="canvas",i.is_expanded=!1,i.expanded_width=200,i.expanded_height=200),n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.at&&(i.model_ref=""),n!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.au&&n!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.av&&n!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.at||(e.userData&&e.userData.typeId?i.op=e.userData.typeId:i.op=""),i}))}},{key:"getType",value:function(e){return e.userData&&!0===e.userData.containsModel?_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.at:e.inputPorts&&e.inputPorts.length>0&&e.outputPorts&&e.outputPorts.length>0?e.subDiagramId?_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.au:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.av}},{key:"getInputPorts",value:function(e,t){var n=this;return e.map((function(e){return{id:e.name,label:e.label,cardinality:{min:n.getMinCard(e.cardinality),max:n.getMaxCard(e.cardinality,t)}}}))}},{key:"getOutputPorts",value:function(e,t){var n=this;return e.map((function(e){return{id:e.name,label:e.label,cardinality:{min:n.getMinCard(e.cardinality),max:n.getMaxCard(e.cardinality,t)}}}))}},{key:"getMinCard",value:function(e){return e?Number(e.split(":")[0]):0}},{key:"getMaxCard",value:function(e,t){return e?Number(e.split(":")[1]):t}},{key:"getDecorations",value:function(e){return e.map((function(e){return{position:e.position,class_name:e.className,hotspot:e.hotspot,id:e.id,image:e.image,outline:e.outline,x_pos:e.x_pos,y_pos:e.y_pos,width:e.width,height:e.height}}))}},{key:"getComments",value:function(e){return e.map((function(e){return{id:e.id,class_name:e.className,content:e.content,x_pos:void 0!==e.x_pos?e.x_pos:e.xPos,y_pos:void 0!==e.y_pos?e.y_pos:e.yPos,height:e.height,width:e.width}}))}},{key:"getLinks",value:function(e,t,n){var i=this,o=[];return e.forEach((function(e){if(i.isValidLink(e,t,n)){var a={id:e.id,class_name:e.className,srcNodeId:e.source,trgNodeId:e.target,type:i.getLinkType(e)};e.sourcePort&&(a.srcNodePortId=e.sourcePort),e.targetPort&&(a.trgNodePortId=e.targetPort),o.push(a)}})),o}},{key:"isValidLink",value:function(e,t,n){var i=!1;return("nodeLink"===this.getLinkType(e)||"associationLink"===this.getLinkType(e))&&t.findIndex((function(t){return t.id===e.source}))>-1&&t.findIndex((function(t){return t.id===e.target}))>-1&&(i=!0),"commentLink"===this.getLinkType(e)&&n.findIndex((function(t){return t.id===e.source}))>-1&&t.findIndex((function(t){return t.id===e.target}))>-1&&(i=!0),i}},{key:"getLinkType",value:function(e){if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"userData.linkType"))switch(e.userData.linkType){case"comment":return"commentLink";case"object":return"associationLink";default:return"nodeLink"}return"nodeLink"}},{key:"convertPaletteToPipelineFlowPalette",value:function(e){return{version:"1.0",categories:this.getCategories(e.categories)}}},{key:"getCategories",value:function(e){var t=this;return e.map((function(e){return{category:e.category,label:e.label,description:e.description,image:e.image,nodetypes:t.convertNodeTypes(e.nodetypes)}}))}},{key:"convertNodeTypes",value:function(e){var t=this;return e.map((function(e){var n={type:t.getType(e),label:e.label,description:e.description,operator_id_ref:e.typeId,image:e.image};return e.inputPorts&&(n.input_ports=t.convertPalettePorts(e.inputPorts,1)),e.outputPorts&&(n.output_ports=t.convertPalettePorts(e.outputPorts,-1)),n}))}},{key:"convertPalettePorts",value:function(e,t){var n=this;return e.map((function(e){return{id:e.name,label:e.label,cardinality:n.convertPaletteCardinality(e.cardinality,t)}}))}},{key:"convertPaletteCardinality",value:function(e,t){return{min:this.getMinCard(e),max:this.getMaxCard(e,t)}}},{key:"isVersion0Palette",value:function(e){for(var t=!1,n=0;n<e.categories.length;n++)if(this.isVersion0Category(e.categories[n])){t=!0;break}return t}},{key:"isVersion0Category",value:function(e){var t=!1;if(e.nodetypes)for(var n=0;n<e.nodetypes.length;n++)if(e.nodetypes[n].typeId){t=!0;break}return t}}]),n}(),Ln=function(){function n(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,n)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(n,null,[{key:"getCanvasBasedOnCanvasInfo",value:function(e,t){return Object.assign({},e,{diagram:this.getDiagram(e,t.pipelines[0])})}},{key:"getDiagram",value:function(e,t){return{id:t.id,nodes:this.getCanvasNodes(t.nodes,e),comments:this.getCanvasComments(t.comments),links:this.getCanvasLinks(t.links)}}},{key:"getCanvasNodes",value:function(e,t){var n=this;return e.map((function(e){var i={id:e.id};e.inputs&&(i.inputPorts=n.getCanvasPorts(e.inputs)),e.outputs&&(i.outputPorts=n.getCanvasPorts(e.outputs)),i.image=e.image,i.x_pos=e.x_pos,i.y_pos=e.y_pos,i.className=e.class_name,i.objectData={label:e.label,description:e.description||""},i.userData={typeId:e.op},e.decorations&&(i.decorations=n.getCanvasDecorations(e.decorations));var o=n.getOldNode(e.id,t);return o&&o.userData&&(i.userData=o.userData),i}))}},{key:"getCanvasPorts",value:function(e){return e.map((function(e){var t={name:e.id,label:e.label};return e.cardinality&&(t.cardinality=e.cardinality.min+":"+e.cardinality.max),t}))}},{key:"getCanvasDecorations",value:function(e){return e.map((function(e){var t={};return e.position&&(t.position=e.position),e.class_name&&(t.className=e.class_name),e.image&&(t.image=e.image),e.hotspot&&(t.hotspot=e.hotspot),e.id&&(t.id=e.id),t}))}},{key:"getOldNode",value:function(e,t){if(t&&t.diagram&&t.diagram.nodes){var n=t.diagram.nodes.findIndex((function(t){return t.id===e}));if(n>-1)return t.diagram.nodes[n]}return null}},{key:"getCanvasComments",value:function(e){return e.map((function(e){return{id:e.id,className:e.class_name,content:e.content,height:e.height,width:e.width,x_pos:e.x_pos,y_pos:e.y_pos}}))}},{key:"getCanvasLinks",value:function(e){return e.map((function(e){var t={id:e.id,className:e.class_name,source:e.srcNodeId};e.srcNodePortId&&(t.sourcePort=e.srcNodePortId),t.target=e.trgNodeId,e.trgNodePortId&&(t.targetPort=e.trgNodePortId);var n="";switch(e.type){case"commentLink":n="comment";break;case"associationLink":n="object";break;default:n="data"}return t.userData={linkType:n},t}))}}]),n}(),xn=function(){function n(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,n)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(n,null,[{key:"convertPipelineFlowToCanvasInfo",value:function(e,t){var n=this.convertPipelinesToCanvasInfoPipelines(e.pipelines,t);return Object.assign({},e,{pipelines:n})}},{key:"convertPipelinesToCanvasInfoPipelines",value:function(e,t){var n=this,i=[];return e&&(i=e.map((function(e){return n.convertPipelineToCanvasInfoPipeline(e,t)}))),i}},{key:"convertPipelineToCanvasInfoPipeline",value:function(e,t){var n=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"nodes")?e.nodes:[],i=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.comments")?e.app_data.ui_data.comments:[],o=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.detached_links")?e.app_data.ui_data.detached_links:[],a={id:e.id,name:e.name,nodes:this.convertNodes(n,t),comments:this.convertComments(i),links:this.convertLinks(n,i,o),runtime_ref:e.runtime_ref,app_data:e.app_data,parameters:e.parameters};return (0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.zoom")&&("number"==typeof e.app_data.ui_data.zoom?a.zoom={x:0,y:0,k:e.app_data.ui_data.zoom/100}:a.zoom=e.app_data.ui_data.zoom),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(a,"app_data.ui_data.comments")&&delete a.app_data.ui_data.comments,(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(a,"app_data.ui_data.detached_links")&&delete a.app_data.ui_data.detached_links,a}},{key:"convertNodes",value:function(e,t){var n=this;return e.map((function(e){return n.convertNode(e,t)}))}},{key:"convertNode",value:function(e,t){var n={id:e.id,type:e.type,outputs:this.convertOutputs(e),inputs:this.convertInputs(e),label:this.convertLabel(e),x_pos:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.x_pos")?e.app_data.ui_data.x_pos:10,y_pos:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.y_pos")?e.app_data.ui_data.y_pos:10,decorations:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.decorations")?this.convertDecorations(e.app_data.ui_data.decorations):[],parameters:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"parameters")?e.parameters:[],messages:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.messages")?e.app_data.ui_data.messages:[],ui_parameters:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.ui_parameters")?e.app_data.ui_data.ui_parameters:[],app_data:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data")?this.removeUiDataFromAppData(e.app_data):[]};return e.type!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.au&&e.type!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.av&&e.type!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.at||(n.op=e.op),e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai&&((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"open_with_tool")&&(n.open_with_tool=e.open_with_tool),n.subflow_ref=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"subflow_ref")?this.convertSubFlowRef(e.subflow_ref):{},n.is_expanded=!!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.is_expanded")&&e.app_data.ui_data.is_expanded,n.expanded_width=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.expanded_width")?e.app_data.ui_data.expanded_width:t.supernodeDefaultWidth,n.expanded_height=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.expanded_height")?e.app_data.ui_data.expanded_height:t.supernodeDefaultHeight),e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.at&&(n.model_ref=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"model_ref")?e.model_ref:""),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.is_resized")&&(n.isResized=e.app_data.ui_data.is_resized,n.resizeHeight=e.app_data.ui_data.resize_height,n.resizeWidth=e.app_data.ui_data.resize_width),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.description")&&(n.description=e.app_data.ui_data.description),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.image")&&(n.image=e.app_data.ui_data.image),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.class_name")&&(n.class_name=e.app_data.ui_data.class_name),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.style")&&(n.style=e.app_data.ui_data.style),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"isSupernodeInputBinding")&&(n.isSupernodeInputBinding=!0),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"isSupernodeOutputBinding")&&(n.isSupernodeOutputBinding=!0),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"connection")&&(n.connection=e.connection),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"data_asset")&&(n.data_asset=e.data_asset),n}},{key:"convertSubFlowRef",value:function(e){var t={pipeline_id_ref:e.pipeline_id_ref};return e.url&&(t.url=e.url),t}},{key:"convertLabel",value:function(e){var t=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.label")?e.app_data.ui_data.label:"";return (0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.M)(t)&&t.default?t.default:t}},{key:"convertOutputs",value:function(e){var t=this;return e.outputs?e.outputs.map((function(e){return t.convertPortObject(e)})):e.outputs}},{key:"convertInputs",value:function(e){var t=this;return e.inputs?e.inputs.map((function(e){return t.convertPortObject(e)})):e.inputs}},{key:"convertPortObject",value:function(e){var t={id:e.id,label:this.convertLabel(e)};return (0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"subflow_node_ref")&&(t.subflow_node_ref=e.subflow_node_ref),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"schema_ref")&&(t.schema_ref=e.schema_ref),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.cardinality")&&(t.cardinality={min:e.app_data.ui_data.cardinality.min,max:e.app_data.ui_data.cardinality.max}),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.class_name")&&(t.class_name=e.app_data.ui_data.class_name),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"parameters")&&(t.parameters=e.parameters),e.app_data&&(t.app_data=this.removeUiDataFromAppData(e.app_data)),t}},{key:"convertDecorations",value:function(e){var t=this,n=[];return e&&e.forEach((function(e){var i=Object.assign({},e,{id:e.id||t.getUUID()});n.push(i)})),n}},{key:"convertComments",value:function(e){return e.map((function(e){var t={id:e.id,content:e.content,height:e.height,width:e.width,x_pos:e.x_pos,y_pos:e.y_pos};return (0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"class_name")&&(t.class_name=e.class_name),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"style")&&(t.style=e.style),t}))}},{key:"convertLinks",value:function(e,t,n){var i=this,o=[];return e.forEach((function(t){t.inputs&&t.inputs.forEach((function(n){n.links&&n.links.forEach((function(a){if(i.isNode(e,a.node_id_ref)){var r=i.createDataLink(a,a.node_id_ref,a.port_id_ref,t.id,n.id);o.push(r)}}))})),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(t,"app_data.ui_data.associations")&&!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(t.app_data.ui_data.associations)&&t.app_data.ui_data.associations.forEach((function(n){if(i.isNode(e,n.node_ref)){var a={id:n.id?n.id:i.getUUID(),srcNodeId:t.id,trgNodeId:n.node_ref,type:"associationLink",decorations:n.decorations};(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(n,"class_name")&&(a.class_name=n.class_name),o.push(a)}}))})),t.forEach((function(t){t.associated_id_refs&&t.associated_id_refs.forEach((function(n){if(i.isNode(e,n.node_ref)){var a={id:n.id?n.id:i.getUUID(),srcNodeId:t.id,trgNodeId:n.node_ref,type:"commentLink"};(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(n,"class_name")&&(a.class_name=n.class_name),n.style&&(a.style=n.style),o.push(a)}}))})),n.forEach((function(e){var t=i.createDataLink(e,e.src_node_id,e.src_node_port_id,e.trg_node_id,e.trg_node_port_id);e.src_pos&&(t.srcPos=e.src_pos),e.trg_pos&&(t.trgPos=e.trg_pos),o.push(t)})),o}},{key:"isNode",value:function(e,t){return-1!==e.findIndex((function(e){return e.id===t}))}},{key:"getUUID",value:function(){return (0,uuid__WEBPACK_IMPORTED_MODULE_0__.v4)()}},{key:"createDataLink",value:function(e,t,n,i,o){var a={id:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"id")?e.id:this.getUUID(),srcNodeId:t,trgNodeId:i,trgNodePortId:o,type:"nodeLink"};return (0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.class_name")&&(a.class_name=e.app_data.ui_data.class_name),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.style")&&(a.style=e.app_data.ui_data.style),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.decorations")&&(a.decorations=e.app_data.ui_data.decorations),e.app_data&&(a.app_data=this.removeUiDataFromAppData(e.app_data)),n&&(a.srcNodePortId=n),e.link_name&&(a.linkName=e.link_name),e.type_attr&&(a.typeAttr=e.type_attr),e.description&&(a.description=e.description),a}},{key:"removeUiDataFromAppData",value:function(e){var t;return e&&delete(t=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(e)).ui_data,t}}]),n}(),Cn=function(){function n(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,n)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(n,null,[{key:"createPipelineFlow",value:function(e){var t=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(e);return delete t.subdueStyle,Object.assign({},t,{pipelines:this.createPipelinesFromCanvasInfo(t)})}},{key:"createPipelinesFromCanvasInfo",value:function(e){var t=this;return e?this.filterOutExternalPipelines(e.pipelines).map((function(e){return t.createPipeline(e)})):{}}},{key:"filterOutExternalPipelines",value:function(e){return e.filter((function(e){return!e.parentUrl}))}},{key:"createPipeline",value:function(e){var t={id:e.id};return e.name&&(t.name=e.name),t.nodes=this.createNodes(e),t.app_data=this.createPipelineAppData(e),t.runtime_ref=e.runtime_ref,e.parameters&&(t.parameters=e.parameters),t}},{key:"createNodes",value:function(e){var t=this;return e.nodes.map((function(n){return t.createSchemaNode(n,e.links)}))}},{key:"createSchemaNode",value:function(e,t){var n={id:e.id,type:e.type};e.type!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.au&&e.type!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.av&&e.type!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.at||(e.op||""===e.op)&&(n.op=e.op),e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai&&(e.open_with_tool&&(n.open_with_tool=e.open_with_tool),n.subflow_ref=e.subflow_ref),e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.at&&(n.model_ref=e.model_ref),n.app_data=Object.assign({},e.app_data,{ui_data:this.createNodeUiData(e)}),e.inputs&&(n.inputs=this.createInputs(e,t)),e.outputs&&(n.outputs=this.createOutputs(e)),e.parameters&&!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(e.parameters)&&(n.parameters=e.parameters),e.connection&&(n.connection=e.connection),e.data_asset&&(n.data_asset=e.data_asset);var i=this.createAssociationLinks(e,t);return (0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(i)||(n.app_data.ui_data.associations=i),n}},{key:"createNodeUiData",value:function(e){var t={label:e.label,image:e.image,x_pos:e.x_pos,y_pos:e.y_pos};if(e.class_name&&(t.class_name=e.class_name),e.style&&(t.style=e.style),e.description&&(t.description=e.description),e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai?(t.is_expanded=e.is_expanded,t.expanded_width=e.expanded_width,t.expanded_height=e.expanded_height):e.isResized&&(t.is_resized=e.isResized,t.resize_width=e.width,t.resize_height=e.height),e.messages&&!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(e.messages)&&(t.messages=e.messages),e.ui_parameters&&!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(e.ui_parameters)&&(t.ui_parameters=e.ui_parameters),e.decorations){var n=this.createDecorations(e.decorations);n.length>0&&(t.decorations=n)}return t}},{key:"createDecorations",value:function(e){var t=[];return e&&e.forEach((function(e){if(!e.temporary){var n=Object.assign({},e);t.push(n)}})),t}},{key:"createInputs",value:function(e,t){var n=this,i=[];return e.inputs.forEach((function(o,a){var r={id:o.id};e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai&&o.subflow_node_ref&&(r.subflow_node_ref=o.subflow_node_ref),o.schema_ref&&(r.schema_ref=o.schema_ref),r.app_data=Object.assign({},o.app_data,{ui_data:n.createPortUiData(o)});var s=n.createLinks(t,e.id,o.id,a);s.length>0&&(r.links=s),o.parameters&&(r.parameters=o.parameters),i.push(r)})),i}},{key:"createOutputs",value:function(e){var t=this,n=[];return e.outputs.forEach((function(i){var o={id:i.id};e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai&&i.subflow_node_ref&&(o.subflow_node_ref=i.subflow_node_ref),i.schema_ref&&(o.schema_ref=i.schema_ref),o.app_data=Object.assign({},i.app_data,{ui_data:t.createPortUiData(i)}),i.parameters&&(o.parameters=i.parameters),n.push(o)})),n}},{key:"createPortUiData",value:function(e){var t={};return e.cardinality&&(t.cardinality=e.cardinality),e.class_name&&(t.class_name=e.class_name),t.label=e.label,t}},{key:"createLinks",value:function(e,t,n,i){var o=this,a=[];e&&this.getFilteredCanvasLinks(e,t,n,i).forEach((function(e){if(void 0!==e.srcNodeId){var t={id:e.id,node_id_ref:e.srcNodeId};e.srcNodePortId&&(t.port_id_ref=e.srcNodePortId),t=o.addNodeLinkCommonAttrs(t,e),a.push(t)}}));return a}},{key:"getFilteredCanvasLinks",value:function(e,t,n,i){return e.filter((function(e){if("nodeLink"===e.type&&e.trgNodeId===t)if(e.trgNodePortId){if(e.trgNodePortId===n)return!0}else if(0===i)return!0;return!1}))}},{key:"createPipelineAppData",value:function(e){return e.app_data?Object.assign({},e.app_data,{ui_data:this.createPipelineUiData(e)}):{ui_data:this.createPipelineUiData(e)}}},{key:"createPipelineUiData",value:function(e){var t=null;t=e.app_data&&e.app_data.ui_data?Object.assign({},e.app_data.ui_data,{comments:this.createComments(e.comments,e.links)}):{comments:this.createComments(e.comments,e.links)};var n=this.createDetachedLinks(e.links);return n.length>0&&(t.detached_links=n),e.zoom&&(t.zoom=e.zoom),t}},{key:"createComments",value:function(e,t){var n=this;return e.map((function(e){var i={id:e.id,x_pos:e.x_pos,y_pos:e.y_pos,width:e.width,height:e.height};return e.class_name&&(i.class_name=e.class_name),i.content=e.content,i.associated_id_refs=n.createCommentLinks(t,e.id),e.style&&(i.style=e.style),i}))}},{key:"createCommentLinks",value:function(e,t){var n=[];return e.forEach((function(e){if("commentLink"===e.type&&e.srcNodeId===t){var i={node_ref:e.trgNodeId};e.class_name&&(i.class_name=e.class_name),e.style&&(i.style=e.style),n.push(i)}})),n}},{key:"createAssociationLinks",value:function(e,t){var n=this,i=[];return t.forEach((function(t){if("associationLink"===t.type&&t.srcNodeId===e.id){var o={id:t.id,node_ref:t.trgNodeId};if(t.class_name&&(o.class_name=t.class_name),t.style&&(o.style=t.style),t.decorations){var a=n.createDecorations(t.decorations);a.length>0&&(o.decorations=a)}i.push(o)}})),i}},{key:"createDetachedLinks",value:function(e){var t=this,n=[];return e.forEach((function(e){if(!e.srcNodeId||!e.trgNodeId){var i={id:e.id};e.srcNodeId?(i.src_node_id=e.srcNodeId,e.srcNodePortId&&(i.src_node_port_id=e.srcNodePortId)):e.srcPos&&(i.src_pos=e.srcPos),e.trgNodeId?(i.trg_node_id=e.trgNodeId,e.trgNodePortId&&(i.trg_node_port_id=e.trgNodePortId)):e.trgPos&&(i.trg_pos=e.trgPos),i=t.addNodeLinkCommonAttrs(i,e),n.push(i)}})),n}},{key:"addNodeLinkCommonAttrs",value:function(e,t){if(t.app_data&&(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.s)(e,"app_data",t.app_data),t.class_name&&(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.s)(e,"app_data.ui_data.class_name",t.class_name),t.style&&(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.s)(e,"app_data.ui_data.style",t.style),t.decorations){var n=this.createDecorations(t.decorations);n.length>0&&(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.s)(e,"app_data.ui_data.decorations",n)}return t.linkName&&(e.link_name=t.linkName),t.typeAttr&&(e.type_attr=t.typeAttr),t.description&&(e.description=t.description),e}}]),n}(),An=function(){function n(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,n)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(n,null,[{key:"set",value:function(e,t){try{window.electronUtil&&window.electronUtil.wsdStorage&&window.electronUtil.wsdStorage.setItem?window.electronUtil.wsdStorage.setItem(e,t):window.localStorage&&(window.localStorage[e]=t)}catch(e){n.logger.warn("Local storage is not accessible: "+e)}}},{key:"get",value:function(e){try{if(window.electronUtil&&window.electronUtil.wsdStorage&&window.electronUtil.wsdStorage.getItem)return window.electronUtil.wsdStorage.getItem(e);if(window.localStorage)return window.localStorage[e]}catch(e){n.logger.warn("Local storage is not accessible: "+e)}return null}},{key:"delete",value:function(e){try{window.electronUtil&&window.electronUtil.wsdStorage&&window.electronUtil.wsdStorage.removeItem?window.electronUtil.wsdStorage.removeItem(e):window.localStorage&&delete window.localStorage[e]}catch(e){n.logger.warn("Local storage is not accessible: "+e)}}}]),n}();An.logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_9__.L(["LocalStorage"]);var Dn={exports:{}},Mn=Dn.exports=function(){function e(t,n,i){function o(r,s){if(!n[r]){if(!t[r]){var d="function"==typeof _isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.a5&&_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.a5;if(!s&&d)return d(r,!0);if(a)return a(r,!0);var c=new Error("Cannot find module '"+r+"'");throw c.code="MODULE_NOT_FOUND",c}var l=n[r]={exports:{}};t[r][0].call(l.exports,(function(e){return o(t[r][1][e]||e)}),l,l.exports,e,t,n,i)}return n[r].exports}for(var a="function"==typeof _isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.a5&&_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.a5,r=0;r<i.length;r++)o(i[r]);return o}return e}()({1:[function(e,t,n){t.exports={graphlib:e("./lib/graphlib"),layout:e("./lib/layout"),debug:e("./lib/debug"),util:{time:e("./lib/util").time,notime:e("./lib/util").notime},version:e("./lib/version")}},{"./lib/debug":6,"./lib/graphlib":7,"./lib/layout":9,"./lib/util":29,"./lib/version":30}],2:[function(e,t,n){var i=e("./lodash"),o=e("./greedy-fas");function a(e){var t="greedy"===e.graph().acyclicer?o(e,n(e)):r(e);function n(e){return function(t){return e.edge(t).weight}}i.forEach(t,(function(t){var n=e.edge(t);e.removeEdge(t),n.forwardName=t.name,n.reversed=!0,e.setEdge(t.w,t.v,n,i.uniqueId("rev"))}))}function r(e){var t=[],n={},o={};function a(r){i.has(o,r)||(o[r]=!0,n[r]=!0,i.forEach(e.outEdges(r),(function(e){i.has(n,e.w)?t.push(e):a(e.w)})),delete n[r])}return i.forEach(e.nodes(),a),t}function s(e){i.forEach(e.edges(),(function(t){var n=e.edge(t);if(n.reversed){e.removeEdge(t);var i=n.forwardName;delete n.reversed,delete n.forwardName,e.setEdge(t.w,t.v,n,i)}}))}t.exports={run:a,undo:s}},{"./greedy-fas":8,"./lodash":10}],3:[function(e,t,n){var i=e("./lodash"),o=e("./util");function a(e){function t(n){var o=e.children(n),a=e.node(n);if(o.length&&i.forEach(o,t),i.has(a,"minRank")){a.borderLeft=[],a.borderRight=[];for(var s=a.minRank,d=a.maxRank+1;s<d;++s)r(e,"borderLeft","_bl",n,a,s),r(e,"borderRight","_br",n,a,s)}}i.forEach(e.children(),t)}function r(e,t,n,i,a,r){var s={width:0,height:0,rank:r,borderType:t},d=a[t][r-1],c=o.addDummyNode(e,"border",s,n);a[t][r]=c,e.setParent(c,i),d&&e.setEdge(d,c,{weight:1})}t.exports=a},{"./lodash":10,"./util":29}],4:[function(e,t,n){var i=e("./lodash");function o(e){var t=e.graph().rankdir.toLowerCase();"lr"!==t&&"rl"!==t||r(e)}function a(e){var t=e.graph().rankdir.toLowerCase();"bt"!==t&&"rl"!==t||d(e),"lr"!==t&&"rl"!==t||(l(e),r(e))}function r(e){i.forEach(e.nodes(),(function(t){s(e.node(t))})),i.forEach(e.edges(),(function(t){s(e.edge(t))}))}function s(e){var t=e.width;e.width=e.height,e.height=t}function d(e){i.forEach(e.nodes(),(function(t){c(e.node(t))})),i.forEach(e.edges(),(function(t){var n=e.edge(t);i.forEach(n.points,c),i.has(n,"y")&&c(n)}))}function c(e){e.y=-e.y}function l(e){i.forEach(e.nodes(),(function(t){u(e.node(t))})),i.forEach(e.edges(),(function(t){var n=e.edge(t);i.forEach(n.points,u),i.has(n,"x")&&u(n)}))}function u(e){var t=e.x;e.x=e.y,e.y=t}t.exports={adjust:o,undo:a}},{"./lodash":10}],5:[function(e,t,n){function i(){var e={};e._next=e._prev=e,this._sentinel=e}function o(e){e._prev._next=e._next,e._next._prev=e._prev,delete e._next,delete e._prev}function a(e,t){if("_next"!==e&&"_prev"!==e)return t}t.exports=i,i.prototype.dequeue=function(){var e=this._sentinel,t=e._prev;if(t!==e)return o(t),t},i.prototype.enqueue=function(e){var t=this._sentinel;e._prev&&e._next&&o(e),e._next=t._next,t._next._prev=e,t._next=e,e._prev=t},i.prototype.toString=function(){for(var e=[],t=this._sentinel,n=t._prev;n!==t;)e.push(JSON.stringify(n,a)),n=n._prev;return"["+e.join(", ")+"]"}},{}],6:[function(e,t,n){var i=e("./lodash"),o=e("./util"),a=e("./graphlib").Graph;function r(e){var t=o.buildLayerMatrix(e),n=new a({compound:!0,multigraph:!0}).setGraph({});return i.forEach(e.nodes(),(function(t){n.setNode(t,{label:t}),n.setParent(t,"layer"+e.node(t).rank)})),i.forEach(e.edges(),(function(e){n.setEdge(e.v,e.w,{},e.name)})),i.forEach(t,(function(e,t){var o="layer"+t;n.setNode(o,{rank:"same"}),i.reduce(e,(function(e,t){return n.setEdge(e,t,{style:"invis"}),t}))})),n}t.exports={debugOrdering:r}},{"./graphlib":7,"./lodash":10,"./util":29}],7:[function(e,t,n){var i;if("function"==typeof e)try{i=e("graphlib")}catch(e){}i||(i=window.graphlib),t.exports=i},{graphlib:31}],8:[function(e,t,n){var i=e("./lodash"),o=e("./graphlib").Graph,a=e("./data/list");t.exports=s;var r=i.constant(1);function s(e,t){if(e.nodeCount()<=1)return[];var n=l(e,t||r),o=d(n.graph,n.buckets,n.zeroIdx);return i.flatten(i.map(o,(function(t){return e.outEdges(t.v,t.w)})),!0)}function d(e,t,n){for(var i,o=[],a=t[t.length-1],r=t[0];e.nodeCount();){for(;i=r.dequeue();)c(e,t,n,i);for(;i=a.dequeue();)c(e,t,n,i);if(e.nodeCount())for(var s=t.length-2;s>0;--s)if(i=t[s].dequeue()){o=o.concat(c(e,t,n,i,!0));break}}return o}function c(e,t,n,o,a){var r=a?[]:void 0;return i.forEach(e.inEdges(o.v),(function(i){var o=e.edge(i),s=e.node(i.v);a&&r.push({v:i.v,w:i.w}),s.out-=o,u(t,n,s)})),i.forEach(e.outEdges(o.v),(function(i){var o=e.edge(i),a=i.w,r=e.node(a);r.in-=o,u(t,n,r)})),e.removeNode(o.v),r}function l(e,t){var n=new o,r=0,s=0;i.forEach(e.nodes(),(function(e){n.setNode(e,{v:e,in:0,out:0})})),i.forEach(e.edges(),(function(e){var i=n.edge(e.v,e.w)||0,o=t(e),a=i+o;n.setEdge(e.v,e.w,a),s=Math.max(s,n.node(e.v).out+=o),r=Math.max(r,n.node(e.w).in+=o)}));var d=i.range(s+r+3).map((function(){return new a})),c=r+1;return i.forEach(n.nodes(),(function(e){u(d,c,n.node(e))})),{graph:n,buckets:d,zeroIdx:c}}function u(e,t,n){n.out?n.in?e[n.out-n.in+t].enqueue(n):e[e.length-1].enqueue(n):e[0].enqueue(n)}},{"./data/list":5,"./graphlib":7,"./lodash":10}],9:[function(e,t,n){var i=e("./lodash"),o=e("./acyclic"),a=e("./normalize"),r=e("./rank"),s=e("./util").normalizeRanks,d=e("./parent-dummy-chains"),c=e("./util").removeEmptyRanks,l=e("./nesting-graph"),u=e("./add-border-segments"),p=e("./coordinate-system"),f=e("./order"),h=e("./position"),g=e("./util"),y=e("./graphlib").Graph;function m(e,t){var n=t&&t.debugTiming?g.time:g.notime;n("layout",(function(){var t=n("  buildLayoutGraph",(function(){return w(e)}));n("  runLayout",(function(){v(t,n)})),n("  updateInputGraph",(function(){b(e,t)}))}))}function v(e,t){t("    makeSpaceForEdgeLabels",(function(){O(e)})),t("    removeSelfEdges",(function(){U(e)})),t("    acyclic",(function(){o.run(e)})),t("    nestingGraph.run",(function(){l.run(e)})),t("    rank",(function(){r(g.asNonCompoundGraph(e))})),t("    injectEdgeLabelProxies",(function(){T(e)})),t("    removeEmptyRanks",(function(){c(e)})),t("    nestingGraph.cleanup",(function(){l.cleanup(e)})),t("    normalizeRanks",(function(){s(e)})),t("    assignRankMinMax",(function(){L(e)})),t("    removeEdgeLabelProxies",(function(){x(e)})),t("    normalize.run",(function(){a.run(e)})),t("    parentDummyChains",(function(){d(e)})),t("    addBorderSegments",(function(){u(e)})),t("    order",(function(){f(e)})),t("    insertSelfEdges",(function(){F(e)})),t("    adjustCoordinateSystem",(function(){p.adjust(e)})),t("    position",(function(){h(e)})),t("    positionSelfEdges",(function(){B(e)})),t("    removeBorderNodes",(function(){R(e)})),t("    normalize.undo",(function(){a.undo(e)})),t("    fixupEdgeLabelCoords",(function(){D(e)})),t("    undoCoordinateSystem",(function(){p.undo(e)})),t("    translateGraph",(function(){C(e)})),t("    assignNodeIntersects",(function(){A(e)})),t("    reversePoints",(function(){M(e)})),t("    acyclic.undo",(function(){o.undo(e)}))}function b(e,t){i.forEach(e.nodes(),(function(n){var i=e.node(n),o=t.node(n);i&&(i.x=o.x,i.y=o.y,t.children(n).length&&(i.width=o.width,i.height=o.height))})),i.forEach(e.edges(),(function(n){var o=e.edge(n),a=t.edge(n);o.points=a.points,i.has(a,"x")&&(o.x=a.x,o.y=a.y)})),e.graph().width=t.graph().width,e.graph().height=t.graph().height}t.exports=m;var _=["nodesep","edgesep","ranksep","marginx","marginy"],k={ranksep:50,edgesep:20,nodesep:50,rankdir:"tb"},P=["acyclicer","ranker","rankdir","align"],I=["width","height"],N={width:0,height:0},S=["minlen","weight","width","height","labeloffset"],E={minlen:1,weight:1,width:0,height:0,labeloffset:10,labelpos:"r"},j=["labelpos"];function w(e){var t=new y({multigraph:!0,compound:!0}),n=q(e.graph());return t.setGraph(i.merge({},k,H(n,_),i.pick(n,P))),i.forEach(e.nodes(),(function(n){var o=q(e.node(n));t.setNode(n,i.defaults(H(o,I),N)),t.setParent(n,e.parent(n))})),i.forEach(e.edges(),(function(n){var o=q(e.edge(n));t.setEdge(n,i.merge({},E,H(o,S),i.pick(o,j)))})),t}function O(e){var t=e.graph();t.ranksep/=2,i.forEach(e.edges(),(function(n){var i=e.edge(n);i.minlen*=2,"c"!==i.labelpos.toLowerCase()&&("TB"===t.rankdir||"BT"===t.rankdir?i.width+=i.labeloffset:i.height+=i.labeloffset)}))}function T(e){i.forEach(e.edges(),(function(t){var n=e.edge(t);if(n.width&&n.height){var i=e.node(t.v),o={rank:(e.node(t.w).rank-i.rank)/2+i.rank,e:t};g.addDummyNode(e,"edge-proxy",o,"_ep")}}))}function L(e){var t=0;i.forEach(e.nodes(),(function(n){var o=e.node(n);o.borderTop&&(o.minRank=e.node(o.borderTop).rank,o.maxRank=e.node(o.borderBottom).rank,t=i.max(t,o.maxRank))})),e.graph().maxRank=t}function x(e){i.forEach(e.nodes(),(function(t){var n=e.node(t);"edge-proxy"===n.dummy&&(e.edge(n.e).labelRank=n.rank,e.removeNode(t))}))}function C(e){var t=Number.POSITIVE_INFINITY,n=0,o=Number.POSITIVE_INFINITY,a=0,r=e.graph(),s=r.marginx||0,d=r.marginy||0;function c(e){var i=e.x,r=e.y,s=e.width,d=e.height;t=Math.min(t,i-s/2),n=Math.max(n,i+s/2),o=Math.min(o,r-d/2),a=Math.max(a,r+d/2)}i.forEach(e.nodes(),(function(t){c(e.node(t))})),i.forEach(e.edges(),(function(t){var n=e.edge(t);i.has(n,"x")&&c(n)})),t-=s,o-=d,i.forEach(e.nodes(),(function(n){var i=e.node(n);i.x-=t,i.y-=o})),i.forEach(e.edges(),(function(n){var a=e.edge(n);i.forEach(a.points,(function(e){e.x-=t,e.y-=o})),i.has(a,"x")&&(a.x-=t),i.has(a,"y")&&(a.y-=o)})),r.width=n-t+s,r.height=a-o+d}function A(e){i.forEach(e.edges(),(function(t){var n,i,o=e.edge(t),a=e.node(t.v),r=e.node(t.w);o.points?(n=o.points[0],i=o.points[o.points.length-1]):(o.points=[],n=r,i=a),o.points.unshift(g.intersectRect(a,n)),o.points.push(g.intersectRect(r,i))}))}function D(e){i.forEach(e.edges(),(function(t){var n=e.edge(t);if(i.has(n,"x"))switch("l"!==n.labelpos&&"r"!==n.labelpos||(n.width-=n.labeloffset),n.labelpos){case"l":n.x-=n.width/2+n.labeloffset;break;case"r":n.x+=n.width/2+n.labeloffset}}))}function M(e){i.forEach(e.edges(),(function(t){var n=e.edge(t);n.reversed&&n.points.reverse()}))}function R(e){i.forEach(e.nodes(),(function(t){if(e.children(t).length){var n=e.node(t),o=e.node(n.borderTop),a=e.node(n.borderBottom),r=e.node(i.last(n.borderLeft)),s=e.node(i.last(n.borderRight));n.width=Math.abs(s.x-r.x),n.height=Math.abs(a.y-o.y),n.x=r.x+n.width/2,n.y=o.y+n.height/2}})),i.forEach(e.nodes(),(function(t){"border"===e.node(t).dummy&&e.removeNode(t)}))}function U(e){i.forEach(e.edges(),(function(t){if(t.v===t.w){var n=e.node(t.v);n.selfEdges||(n.selfEdges=[]),n.selfEdges.push({e:t,label:e.edge(t)}),e.removeEdge(t)}}))}function F(e){var t=g.buildLayerMatrix(e);i.forEach(t,(function(t){var n=0;i.forEach(t,(function(t,o){var a=e.node(t);a.order=o+n,i.forEach(a.selfEdges,(function(t){g.addDummyNode(e,"selfedge",{width:t.label.width,height:t.label.height,rank:a.rank,order:o+ ++n,e:t.e,label:t.label},"_se")})),delete a.selfEdges}))}))}function B(e){i.forEach(e.nodes(),(function(t){var n=e.node(t);if("selfedge"===n.dummy){var i=e.node(n.e.v),o=i.x+i.width/2,a=i.y,r=n.x-o,s=i.height/2;e.setEdge(n.e,n.label),e.removeNode(t),n.label.points=[{x:o+2*r/3,y:a-s},{x:o+5*r/6,y:a-s},{x:o+r,y:a},{x:o+5*r/6,y:a+s},{x:o+2*r/3,y:a+s}],n.label.x=n.x,n.label.y=n.y}}))}function H(e,t){return i.mapValues(i.pick(e,t),Number)}function q(e){var t={};return i.forEach(e,(function(e,n){t[n.toLowerCase()]=e})),t}},{"./acyclic":2,"./add-border-segments":3,"./coordinate-system":4,"./graphlib":7,"./lodash":10,"./nesting-graph":11,"./normalize":12,"./order":17,"./parent-dummy-chains":22,"./position":24,"./rank":26,"./util":29}],10:[function(e,t,n){var i;if("function"==typeof e)try{i={cloneDeep:e("lodash/cloneDeep"),constant:e("lodash/constant"),defaults:e("lodash/defaults"),each:e("lodash/each"),filter:e("lodash/filter"),find:e("lodash/find"),flatten:e("lodash/flatten"),forEach:e("lodash/forEach"),forIn:e("lodash/forIn"),has:e("lodash/has"),isUndefined:e("lodash/isUndefined"),last:e("lodash/last"),map:e("lodash/map"),mapValues:e("lodash/mapValues"),max:e("lodash/max"),merge:e("lodash/merge"),min:e("lodash/min"),minBy:e("lodash/minBy"),now:e("lodash/now"),pick:e("lodash/pick"),range:e("lodash/range"),reduce:e("lodash/reduce"),sortBy:e("lodash/sortBy"),uniqueId:e("lodash/uniqueId"),values:e("lodash/values"),zipObject:e("lodash/zipObject")}}catch(e){}i||(i=window._),t.exports=i},{"lodash/cloneDeep":227,"lodash/constant":228,"lodash/defaults":229,"lodash/each":230,"lodash/filter":232,"lodash/find":233,"lodash/flatten":235,"lodash/forEach":236,"lodash/forIn":237,"lodash/has":239,"lodash/isUndefined":258,"lodash/last":261,"lodash/map":262,"lodash/mapValues":263,"lodash/max":264,"lodash/merge":266,"lodash/min":267,"lodash/minBy":268,"lodash/now":270,"lodash/pick":271,"lodash/range":273,"lodash/reduce":274,"lodash/sortBy":276,"lodash/uniqueId":286,"lodash/values":287,"lodash/zipObject":288}],11:[function(e,t,n){var i=e("./lodash"),o=e("./util");function a(e){var t=o.addDummyNode(e,"root",{},"_root"),n=s(e),a=i.max(i.values(n))-1,c=2*a+1;e.graph().nestingRoot=t,i.forEach(e.edges(),(function(t){e.edge(t).minlen*=c}));var l=d(e)+1;i.forEach(e.children(),(function(i){r(e,t,c,l,a,n,i)})),e.graph().nodeRankFactor=c}function r(e,t,n,a,s,d,c){var l=e.children(c);if(l.length){var u=o.addBorderNode(e,"_bt"),p=o.addBorderNode(e,"_bb"),f=e.node(c);e.setParent(u,c),f.borderTop=u,e.setParent(p,c),f.borderBottom=p,i.forEach(l,(function(i){r(e,t,n,a,s,d,i);var o=e.node(i),l=o.borderTop?o.borderTop:i,f=o.borderBottom?o.borderBottom:i,h=o.borderTop?a:2*a,g=l!==f?1:s-d[c]+1;e.setEdge(u,l,{weight:h,minlen:g,nestingEdge:!0}),e.setEdge(f,p,{weight:h,minlen:g,nestingEdge:!0})})),e.parent(c)||e.setEdge(t,u,{weight:0,minlen:s+d[c]})}else c!==t&&e.setEdge(t,c,{weight:0,minlen:n})}function s(e){var t={};function n(o,a){var r=e.children(o);r&&r.length&&i.forEach(r,(function(e){n(e,a+1)})),t[o]=a}return i.forEach(e.children(),(function(e){n(e,1)})),t}function d(e){return i.reduce(e.edges(),(function(t,n){return t+e.edge(n).weight}),0)}function c(e){var t=e.graph();e.removeNode(t.nestingRoot),delete t.nestingRoot,i.forEach(e.edges(),(function(t){e.edge(t).nestingEdge&&e.removeEdge(t)}))}t.exports={run:a,cleanup:c}},{"./lodash":10,"./util":29}],12:[function(e,t,n){var i=e("./lodash"),o=e("./util");function a(e){e.graph().dummyChains=[],i.forEach(e.edges(),(function(t){r(e,t)}))}function r(e,t){var n=t.v,i=e.node(n).rank,a=t.w,r=e.node(a).rank,s=t.name,d=e.edge(t),c=d.labelRank;if(r!==i+1){var l,u,p;for(e.removeEdge(t),p=0,++i;i<r;++p,++i)d.points=[],u={width:0,height:0,edgeLabel:d,edgeObj:t,rank:i},l=o.addDummyNode(e,"edge",u,"_d"),i===c&&(u.width=d.width,u.height=d.height,u.dummy="edge-label",u.labelpos=d.labelpos),e.setEdge(n,l,{weight:d.weight},s),0===p&&e.graph().dummyChains.push(l),n=l;e.setEdge(n,a,{weight:d.weight},s)}}function s(e){i.forEach(e.graph().dummyChains,(function(t){var n,i=e.node(t),o=i.edgeLabel;for(e.setEdge(i.edgeObj,o);i.dummy;)n=e.successors(t)[0],e.removeNode(t),o.points.push({x:i.x,y:i.y}),"edge-label"===i.dummy&&(o.x=i.x,o.y=i.y,o.width=i.width,o.height=i.height),t=n,i=e.node(t)}))}t.exports={run:a,undo:s}},{"./lodash":10,"./util":29}],13:[function(e,t,n){var i=e("../lodash");function o(e,t,n){var o,a={};i.forEach(n,(function(n){for(var i,r,s=e.parent(n);s;){if((i=e.parent(s))?(r=a[i],a[i]=s):(r=o,o=s),r&&r!==s)return void t.setEdge(r,s);s=i}}))}t.exports=o},{"../lodash":10}],14:[function(e,t,n){var i=e("../lodash");function o(e,t){return i.map(t,(function(t){var n=e.inEdges(t);if(n.length){var o=i.reduce(n,(function(t,n){var i=e.edge(n),o=e.node(n.v);return{sum:t.sum+i.weight*o.order,weight:t.weight+i.weight}}),{sum:0,weight:0});return{v:t,barycenter:o.sum/o.weight,weight:o.weight}}return{v:t}}))}t.exports=o},{"../lodash":10}],15:[function(e,t,n){var i=e("../lodash"),o=e("../graphlib").Graph;function a(e,t,n){var a=r(e),s=new o({compound:!0}).setGraph({root:a}).setDefaultNodeLabel((function(t){return e.node(t)}));return i.forEach(e.nodes(),(function(o){var r=e.node(o),d=e.parent(o);(r.rank===t||r.minRank<=t&&t<=r.maxRank)&&(s.setNode(o),s.setParent(o,d||a),i.forEach(e[n](o),(function(t){var n=t.v===o?t.w:t.v,a=s.edge(n,o),r=i.isUndefined(a)?0:a.weight;s.setEdge(n,o,{weight:e.edge(t).weight+r})})),i.has(r,"minRank")&&s.setNode(o,{borderLeft:r.borderLeft[t],borderRight:r.borderRight[t]}))})),s}function r(e){for(var t;e.hasNode(t=i.uniqueId("_root")););return t}t.exports=a},{"../graphlib":7,"../lodash":10}],16:[function(e,t,n){var i=e("../lodash");function o(e,t){for(var n=0,i=1;i<t.length;++i)n+=a(e,t[i-1],t[i]);return n}function a(e,t,n){for(var o=i.zipObject(n,i.map(n,(function(e,t){return t}))),a=i.flatten(i.map(t,(function(t){return i.sortBy(i.map(e.outEdges(t),(function(t){return{pos:o[t.w],weight:e.edge(t).weight}})),"pos")})),!0),r=1;r<n.length;)r<<=1;var s=2*r-1;r-=1;var d=i.map(new Array(s),(function(){return 0})),c=0;return i.forEach(a.forEach((function(e){var t=e.pos+r;d[t]+=e.weight;for(var n=0;t>0;)t%2&&(n+=d[t+1]),d[t=t-1>>1]+=e.weight;c+=e.weight*n}))),c}t.exports=o},{"../lodash":10}],17:[function(e,t,n){var i=e("../lodash"),o=e("./init-order"),a=e("./cross-count"),r=e("./sort-subgraph"),s=e("./build-layer-graph"),d=e("./add-subgraph-constraints"),c=e("../graphlib").Graph,l=e("../util");function u(e){var t=l.maxRank(e),n=p(e,i.range(1,t+1),"inEdges"),r=p(e,i.range(t-1,-1,-1),"outEdges"),s=o(e);h(e,s);for(var d,c=Number.POSITIVE_INFINITY,u=0,g=0;g<4;++u,++g){f(u%2?n:r,u%4>=2),s=l.buildLayerMatrix(e);var y=a(e,s);y<c&&(g=0,d=i.cloneDeep(s),c=y)}h(e,d)}function p(e,t,n){return i.map(t,(function(t){return s(e,t,n)}))}function f(e,t){var n=new c;i.forEach(e,(function(e){var o=e.graph().root,a=r(e,o,n,t);i.forEach(a.vs,(function(t,n){e.node(t).order=n})),d(e,n,a.vs)}))}function h(e,t){i.forEach(t,(function(t){i.forEach(t,(function(t,n){e.node(t).order=n}))}))}t.exports=u},{"../graphlib":7,"../lodash":10,"../util":29,"./add-subgraph-constraints":13,"./build-layer-graph":15,"./cross-count":16,"./init-order":18,"./sort-subgraph":20}],18:[function(e,t,n){var i=e("../lodash");function o(e){var t={},n=i.filter(e.nodes(),(function(t){return!e.children(t).length})),o=i.max(i.map(n,(function(t){return e.node(t).rank}))),a=i.map(i.range(o+1),(function(){return[]}));function r(n){if(!i.has(t,n)){t[n]=!0;var o=e.node(n);a[o.rank].push(n),i.forEach(e.successors(n),r)}}var s=i.sortBy(n,(function(t){return e.node(t).rank}));return i.forEach(s,r),a}t.exports=o},{"../lodash":10}],19:[function(e,t,n){var i=e("../lodash");function o(e,t){var n={};return i.forEach(e,(function(e,t){var o=n[e.v]={indegree:0,in:[],out:[],vs:[e.v],i:t};i.isUndefined(e.barycenter)||(o.barycenter=e.barycenter,o.weight=e.weight)})),i.forEach(t.edges(),(function(e){var t=n[e.v],o=n[e.w];i.isUndefined(t)||i.isUndefined(o)||(o.indegree++,t.out.push(n[e.w]))})),a(i.filter(n,(function(e){return!e.indegree})))}function a(e){var t=[];function n(e){return function(t){t.merged||(i.isUndefined(t.barycenter)||i.isUndefined(e.barycenter)||t.barycenter>=e.barycenter)&&r(e,t)}}function o(t){return function(n){n.in.push(t),0==--n.indegree&&e.push(n)}}for(;e.length;){var a=e.pop();t.push(a),i.forEach(a.in.reverse(),n(a)),i.forEach(a.out,o(a))}return i.map(i.filter(t,(function(e){return!e.merged})),(function(e){return i.pick(e,["vs","i","barycenter","weight"])}))}function r(e,t){var n=0,i=0;e.weight&&(n+=e.barycenter*e.weight,i+=e.weight),t.weight&&(n+=t.barycenter*t.weight,i+=t.weight),e.vs=t.vs.concat(e.vs),e.barycenter=n/i,e.weight=i,e.i=Math.min(t.i,e.i),t.merged=!0}t.exports=o},{"../lodash":10}],20:[function(e,t,n){var i=e("../lodash"),o=e("./barycenter"),a=e("./resolve-conflicts"),r=e("./sort");function s(e,t,n,l){var u=e.children(t),p=e.node(t),f=p?p.borderLeft:void 0,h=p?p.borderRight:void 0,g={};f&&(u=i.filter(u,(function(e){return e!==f&&e!==h})));var y=o(e,u);i.forEach(y,(function(t){if(e.children(t.v).length){var o=s(e,t.v,n,l);g[t.v]=o,i.has(o,"barycenter")&&c(t,o)}}));var m=a(y,n);d(m,g);var v=r(m,l);if(f&&(v.vs=i.flatten([f,v.vs,h],!0),e.predecessors(f).length)){var b=e.node(e.predecessors(f)[0]),_=e.node(e.predecessors(h)[0]);i.has(v,"barycenter")||(v.barycenter=0,v.weight=0),v.barycenter=(v.barycenter*v.weight+b.order+_.order)/(v.weight+2),v.weight+=2}return v}function d(e,t){i.forEach(e,(function(e){e.vs=i.flatten(e.vs.map((function(e){return t[e]?t[e].vs:e})),!0)}))}function c(e,t){i.isUndefined(e.barycenter)?(e.barycenter=t.barycenter,e.weight=t.weight):(e.barycenter=(e.barycenter*e.weight+t.barycenter*t.weight)/(e.weight+t.weight),e.weight+=t.weight)}t.exports=s},{"../lodash":10,"./barycenter":14,"./resolve-conflicts":19,"./sort":21}],21:[function(e,t,n){var i=e("../lodash"),o=e("../util");function a(e,t){var n=o.partition(e,(function(e){return i.has(e,"barycenter")})),a=n.lhs,d=i.sortBy(n.rhs,(function(e){return-e.i})),c=[],l=0,u=0,p=0;a.sort(s(!!t)),p=r(c,d,p),i.forEach(a,(function(e){p+=e.vs.length,c.push(e.vs),l+=e.barycenter*e.weight,u+=e.weight,p=r(c,d,p)}));var f={vs:i.flatten(c,!0)};return u&&(f.barycenter=l/u,f.weight=u),f}function r(e,t,n){for(var o;t.length&&(o=i.last(t)).i<=n;)t.pop(),e.push(o.vs),n++;return n}function s(e){return function(t,n){return t.barycenter<n.barycenter?-1:t.barycenter>n.barycenter?1:e?n.i-t.i:t.i-n.i}}t.exports=a},{"../lodash":10,"../util":29}],22:[function(e,t,n){var i=e("./lodash");function o(e){var t=r(e);i.forEach(e.graph().dummyChains,(function(n){for(var i=e.node(n),o=i.edgeObj,r=a(e,t,o.v,o.w),s=r.path,d=r.lca,c=0,l=s[c],u=!0;n!==o.w;){if(i=e.node(n),u){for(;(l=s[c])!==d&&e.node(l).maxRank<i.rank;)c++;l===d&&(u=!1)}if(!u){for(;c<s.length-1&&e.node(l=s[c+1]).minRank<=i.rank;)c++;l=s[c]}e.setParent(n,l),n=e.successors(n)[0]}}))}function a(e,t,n,i){var o,a,r=[],s=[],d=Math.min(t[n].low,t[i].low),c=Math.max(t[n].lim,t[i].lim);o=n;do{o=e.parent(o),r.push(o)}while(o&&(t[o].low>d||c>t[o].lim));for(a=o,o=i;(o=e.parent(o))!==a;)s.push(o);return{path:r.concat(s.reverse()),lca:a}}function r(e){var t={},n=0;function o(a){var r=n;i.forEach(e.children(a),o),t[a]={low:r,lim:n++}}return i.forEach(e.children(),o),t}t.exports=o},{"./lodash":10}],23:[function(e,t,n){var i=e("../lodash"),o=e("../graphlib").Graph,a=e("../util");function r(e,t){var n={};function o(t,o){var a=0,r=0,s=t.length,l=i.last(o);return i.forEach(o,(function(t,u){var p=d(e,t),f=p?e.node(p).order:s;(p||t===l)&&(i.forEach(o.slice(r,u+1),(function(t){i.forEach(e.predecessors(t),(function(i){var o=e.node(i),r=o.order;!(r<a||f<r)||o.dummy&&e.node(t).dummy||c(n,i,t)}))})),r=u+1,a=f)})),o}return i.reduce(t,o),n}function s(e,t){var n={};function o(t,o,a,r,s){var d;i.forEach(i.range(o,a),(function(o){d=t[o],e.node(d).dummy&&i.forEach(e.predecessors(d),(function(t){var i=e.node(t);i.dummy&&(i.order<r||i.order>s)&&c(n,t,d)}))}))}function a(t,n){var a,r=-1,s=0;return i.forEach(n,(function(i,d){if("border"===e.node(i).dummy){var c=e.predecessors(i);c.length&&(a=e.node(c[0]).order,o(n,s,d,r,a),s=d,r=a)}o(n,s,n.length,a,t.length)})),n}return i.reduce(t,a),n}function d(e,t){if(e.node(t).dummy)return i.find(e.predecessors(t),(function(t){return e.node(t).dummy}))}function c(e,t,n){if(t>n){var i=t;t=n,n=i}var o=e[t];o||(e[t]=o={}),o[n]=!0}function l(e,t,n){if(t>n){var o=t;t=n,n=o}return i.has(e[t],n)}function u(e,t,n,o){var a={},r={},s={};return i.forEach(t,(function(e){i.forEach(e,(function(e,t){a[e]=e,r[e]=e,s[e]=t}))})),i.forEach(t,(function(e){var t=-1;i.forEach(e,(function(e){var d=o(e);if(d.length){d=i.sortBy(d,(function(e){return s[e]}));for(var c=(d.length-1)/2,u=Math.floor(c),p=Math.ceil(c);u<=p;++u){var f=d[u];r[e]===e&&t<s[f]&&!l(n,e,f)&&(r[f]=e,r[e]=a[e]=a[f],t=s[f])}}}))})),{root:a,align:r}}function p(e,t,n,o,a){var r={},s=f(e,t,n,a),d=a?"borderLeft":"borderRight";function c(e,t){for(var n=s.nodes(),i=n.pop(),o={};i;)o[i]?e(i):(o[i]=!0,n.push(i),n=n.concat(t(i))),i=n.pop()}function l(e){r[e]=s.inEdges(e).reduce((function(e,t){return Math.max(e,r[t.v]+s.edge(t))}),0)}function u(t){var n=s.outEdges(t).reduce((function(e,t){return Math.min(e,r[t.w]-s.edge(t))}),Number.POSITIVE_INFINITY),i=e.node(t);n!==Number.POSITIVE_INFINITY&&i.borderType!==d&&(r[t]=Math.max(r[t],n))}return c(l,s.predecessors.bind(s)),c(u,s.successors.bind(s)),i.forEach(o,(function(e){r[e]=r[n[e]]})),r}function f(e,t,n,a){var r=new o,s=e.graph(),d=v(s.nodesep,s.edgesep,a);return i.forEach(t,(function(t){var o;i.forEach(t,(function(t){var i=n[t];if(r.setNode(i),o){var a=n[o],s=r.edge(a,i);r.setEdge(a,i,Math.max(d(e,t,o),s||0))}o=t}))})),r}function h(e,t){return i.minBy(i.values(t),(function(t){var n=Number.NEGATIVE_INFINITY,o=Number.POSITIVE_INFINITY;return i.forIn(t,(function(t,i){var a=b(e,i)/2;n=Math.max(t+a,n),o=Math.min(t-a,o)})),n-o}))}function g(e,t){var n=i.values(t),o=i.min(n),a=i.max(n);i.forEach(["u","d"],(function(n){i.forEach(["l","r"],(function(r){var s,d=n+r,c=e[d];if(c!==t){var l=i.values(c);(s="l"===r?o-i.min(l):a-i.max(l))&&(e[d]=i.mapValues(c,(function(e){return e+s})))}}))}))}function y(e,t){return i.mapValues(e.ul,(function(n,o){if(t)return e[t.toLowerCase()][o];var a=i.sortBy(i.map(e,o));return(a[1]+a[2])/2}))}function m(e){var t,n=a.buildLayerMatrix(e),o=i.merge(r(e,n),s(e,n)),d={};i.forEach(["u","d"],(function(a){t="u"===a?n:i.values(n).reverse(),i.forEach(["l","r"],(function(n){"r"===n&&(t=i.map(t,(function(e){return i.values(e).reverse()})));var r=("u"===a?e.predecessors:e.successors).bind(e),s=u(e,t,o,r),c=p(e,t,s.root,s.align,"r"===n);"r"===n&&(c=i.mapValues(c,(function(e){return-e}))),d[a+n]=c}))}));var c=h(e,d);return g(d,c),y(d,e.graph().align)}function v(e,t,n){return function(o,a,r){var s,d=o.node(a),c=o.node(r),l=0;if(l+=d.width/2,i.has(d,"labelpos"))switch(d.labelpos.toLowerCase()){case"l":s=-d.width/2;break;case"r":s=d.width/2}if(s&&(l+=n?s:-s),s=0,l+=(d.dummy?t:e)/2,l+=(c.dummy?t:e)/2,l+=c.width/2,i.has(c,"labelpos"))switch(c.labelpos.toLowerCase()){case"l":s=c.width/2;break;case"r":s=-c.width/2}return s&&(l+=n?s:-s),s=0,l}}function b(e,t){return e.node(t).width}t.exports={positionX:m,findType1Conflicts:r,findType2Conflicts:s,addConflict:c,hasConflict:l,verticalAlignment:u,horizontalCompaction:p,alignCoordinates:g,findSmallestWidthAlignment:h,balance:y}},{"../graphlib":7,"../lodash":10,"../util":29}],24:[function(e,t,n){var i=e("../lodash"),o=e("../util"),a=e("./bk").positionX;function r(e){s(e=o.asNonCompoundGraph(e)),i.forEach(a(e),(function(t,n){e.node(n).x=t}))}function s(e){var t=o.buildLayerMatrix(e),n=e.graph().ranksep,a=0;i.forEach(t,(function(t){var o=i.max(i.map(t,(function(t){return e.node(t).height})));i.forEach(t,(function(t){e.node(t).y=a+o/2})),a+=o+n}))}t.exports=r},{"../lodash":10,"../util":29,"./bk":23}],25:[function(e,t,n){var i=e("../lodash"),o=e("../graphlib").Graph,a=e("./util").slack;function r(e){var t,n,i=new o({directed:!1}),r=e.nodes()[0],l=e.nodeCount();for(i.setNode(r,{});s(i,e)<l;)t=d(i,e),n=i.hasNode(t.v)?a(e,t):-a(e,t),c(i,e,n);return i}function s(e,t){function n(o){i.forEach(t.nodeEdges(o),(function(i){var r=i.v,s=o===r?i.w:r;e.hasNode(s)||a(t,i)||(e.setNode(s,{}),e.setEdge(o,s,{}),n(s))}))}return i.forEach(e.nodes(),n),e.nodeCount()}function d(e,t){return i.minBy(t.edges(),(function(n){if(e.hasNode(n.v)!==e.hasNode(n.w))return a(t,n)}))}function c(e,t,n){i.forEach(e.nodes(),(function(e){t.node(e).rank+=n}))}t.exports=r},{"../graphlib":7,"../lodash":10,"./util":28}],26:[function(e,t,n){var i=e("./util").longestPath,o=e("./feasible-tree"),a=e("./network-simplex");function r(e){switch(e.graph().ranker){case"network-simplex":default:c(e);break;case"tight-tree":d(e);break;case"longest-path":s(e)}}t.exports=r;var s=i;function d(e){i(e),o(e)}function c(e){a(e)}},{"./feasible-tree":25,"./network-simplex":27,"./util":28}],27:[function(e,t,n){var i=e("../lodash"),o=e("./feasible-tree"),a=e("./util").slack,r=e("./util").longestPath,s=e("../graphlib").alg.preorder,d=e("../graphlib").alg.postorder,c=e("../util").simplify;function l(e){e=c(e),r(e);var t,n=o(e);for(h(n),u(n,e);t=y(n);)v(n,e,t,m(n,e,t))}function u(e,t){var n=d(e,e.nodes());n=n.slice(0,n.length-1),i.forEach(n,(function(n){p(e,t,n)}))}function p(e,t,n){var i=e.node(n).parent;e.edge(n,i).cutvalue=f(e,t,n)}function f(e,t,n){var o=e.node(n).parent,a=!0,r=t.edge(n,o),s=0;return r||(a=!1,r=t.edge(o,n)),s=r.weight,i.forEach(t.nodeEdges(n),(function(i){var r=i.v===n,d=r?i.w:i.v;if(d!==o){var c=r===a,l=t.edge(i).weight;if(s+=c?l:-l,_(e,n,d)){var u=e.edge(n,d).cutvalue;s+=c?-u:u}}})),s}function h(e,t){arguments.length<2&&(t=e.nodes()[0]),g(e,{},1,t)}function g(e,t,n,o,a){var r=n,s=e.node(o);return t[o]=!0,i.forEach(e.neighbors(o),(function(a){i.has(t,a)||(n=g(e,t,n,a,o))})),s.low=r,s.lim=n++,a?s.parent=a:delete s.parent,n}function y(e){return i.find(e.edges(),(function(t){return e.edge(t).cutvalue<0}))}function m(e,t,n){var o=n.v,r=n.w;t.hasEdge(o,r)||(o=n.w,r=n.v);var s=e.node(o),d=e.node(r),c=s,l=!1;s.lim>d.lim&&(c=d,l=!0);var u=i.filter(t.edges(),(function(t){return l===k(e,e.node(t.v),c)&&l!==k(e,e.node(t.w),c)}));return i.minBy(u,(function(e){return a(t,e)}))}function v(e,t,n,i){var o=n.v,a=n.w;e.removeEdge(o,a),e.setEdge(i.v,i.w,{}),h(e),u(e,t),b(e,t)}function b(e,t){var n=i.find(e.nodes(),(function(e){return!t.node(e).parent})),o=s(e,n);o=o.slice(1),i.forEach(o,(function(n){var i=e.node(n).parent,o=t.edge(n,i),a=!1;o||(o=t.edge(i,n),a=!0),t.node(n).rank=t.node(i).rank+(a?o.minlen:-o.minlen)}))}function _(e,t,n){return e.hasEdge(t,n)}function k(e,t,n){return n.low<=t.lim&&t.lim<=n.lim}t.exports=l,l.initLowLimValues=h,l.initCutValues=u,l.calcCutValue=f,l.leaveEdge=y,l.enterEdge=m,l.exchangeEdges=v},{"../graphlib":7,"../lodash":10,"../util":29,"./feasible-tree":25,"./util":28}],28:[function(e,t,n){var i=e("../lodash");function o(e){var t={};function n(o){var a=e.node(o);if(i.has(t,o))return a.rank;t[o]=!0;var r=i.min(i.map(e.outEdges(o),(function(t){return n(t.w)-e.edge(t).minlen})));return r!==Number.POSITIVE_INFINITY&&null!=r||(r=0),a.rank=r}i.forEach(e.sources(),n)}function a(e,t){return e.node(t.w).rank-e.node(t.v).rank-e.edge(t).minlen}t.exports={longestPath:o,slack:a}},{"../lodash":10}],29:[function(e,t,n){var i=e("./lodash"),o=e("./graphlib").Graph;function a(e,t,n,o){var a;do{a=i.uniqueId(o)}while(e.hasNode(a));return n.dummy=t,e.setNode(a,n),a}function r(e){var t=(new o).setGraph(e.graph());return i.forEach(e.nodes(),(function(n){t.setNode(n,e.node(n))})),i.forEach(e.edges(),(function(n){var i=t.edge(n.v,n.w)||{weight:0,minlen:1},o=e.edge(n);t.setEdge(n.v,n.w,{weight:i.weight+o.weight,minlen:Math.max(i.minlen,o.minlen)})})),t}function s(e){var t=new o({multigraph:e.isMultigraph()}).setGraph(e.graph());return i.forEach(e.nodes(),(function(n){e.children(n).length||t.setNode(n,e.node(n))})),i.forEach(e.edges(),(function(n){t.setEdge(n,e.edge(n))})),t}function d(e){var t=i.map(e.nodes(),(function(t){var n={};return i.forEach(e.outEdges(t),(function(t){n[t.w]=(n[t.w]||0)+e.edge(t).weight})),n}));return i.zipObject(e.nodes(),t)}function c(e){var t=i.map(e.nodes(),(function(t){var n={};return i.forEach(e.inEdges(t),(function(t){n[t.v]=(n[t.v]||0)+e.edge(t).weight})),n}));return i.zipObject(e.nodes(),t)}function l(e,t){var n,i,o=e.x,a=e.y,r=t.x-o,s=t.y-a,d=e.width/2,c=e.height/2;if(!r&&!s)throw new Error("Not possible to find intersection inside of the rectangle");return Math.abs(s)*d>Math.abs(r)*c?(s<0&&(c=-c),n=c*r/s,i=c):(r<0&&(d=-d),n=d,i=d*s/r),{x:o+n,y:a+i}}function u(e){var t=i.map(i.range(g(e)+1),(function(){return[]}));return i.forEach(e.nodes(),(function(n){var o=e.node(n),a=o.rank;i.isUndefined(a)||(t[a][o.order]=n)})),t}function p(e){var t=i.min(i.map(e.nodes(),(function(t){return e.node(t).rank})));i.forEach(e.nodes(),(function(n){var o=e.node(n);i.has(o,"rank")&&(o.rank-=t)}))}function f(e){var t=i.min(i.map(e.nodes(),(function(t){return e.node(t).rank}))),n=[];i.forEach(e.nodes(),(function(i){var o=e.node(i).rank-t;n[o]||(n[o]=[]),n[o].push(i)}));var o=0,a=e.graph().nodeRankFactor;i.forEach(n,(function(t,n){i.isUndefined(t)&&n%a!=0?--o:o&&i.forEach(t,(function(t){e.node(t).rank+=o}))}))}function h(e,t,n,i){var o={width:0,height:0};return arguments.length>=4&&(o.rank=n,o.order=i),a(e,"border",o,t)}function g(e){return i.max(i.map(e.nodes(),(function(t){var n=e.node(t).rank;if(!i.isUndefined(n))return n})))}function y(e,t){var n={lhs:[],rhs:[]};return i.forEach(e,(function(e){t(e)?n.lhs.push(e):n.rhs.push(e)})),n}function m(e,t){var n=i.now();try{return t()}finally{console.log(e+" time: "+(i.now()-n)+"ms")}}function v(e,t){return t()}t.exports={addDummyNode:a,simplify:r,asNonCompoundGraph:s,successorWeights:d,predecessorWeights:c,intersectRect:l,buildLayerMatrix:u,normalizeRanks:p,removeEmptyRanks:f,addBorderNode:h,maxRank:g,partition:y,time:m,notime:v}},{"./graphlib":7,"./lodash":10}],30:[function(e,t,n){t.exports="0.8.5"},{}],31:[function(e,t,n){var i=e("./lib");t.exports={Graph:i.Graph,json:e("./lib/json"),alg:e("./lib/alg"),version:i.version}},{"./lib":47,"./lib/alg":38,"./lib/json":48}],32:[function(e,t,n){var i=e("../lodash");function o(e){var t,n={},o=[];function a(o){i.has(n,o)||(n[o]=!0,t.push(o),i.each(e.successors(o),a),i.each(e.predecessors(o),a))}return i.each(e.nodes(),(function(e){t=[],a(e),t.length&&o.push(t)})),o}t.exports=o},{"../lodash":49}],33:[function(e,t,n){var i=e("../lodash");function o(e,t,n){i.isArray(t)||(t=[t]);var o=(e.isDirected()?e.successors:e.neighbors).bind(e),r=[],s={};return i.each(t,(function(t){if(!e.hasNode(t))throw new Error("Graph does not have node: "+t);a(e,t,"post"===n,s,o,r)})),r}function a(e,t,n,o,r,s){i.has(o,t)||(o[t]=!0,n||s.push(t),i.each(r(t),(function(t){a(e,t,n,o,r,s)})),n&&s.push(t))}t.exports=o},{"../lodash":49}],34:[function(e,t,n){var i=e("./dijkstra"),o=e("../lodash");function a(e,t,n){return o.transform(e.nodes(),(function(o,a){o[a]=i(e,a,t,n)}),{})}t.exports=a},{"../lodash":49,"./dijkstra":35}],35:[function(e,t,n){var i=e("../lodash"),o=e("../data/priority-queue");t.exports=r;var a=i.constant(1);function r(e,t,n,i){return s(e,String(t),n||a,i||function(t){return e.outEdges(t)})}function s(e,t,n,i){var a,r,s={},d=new o,c=function(e){var t=e.v!==a?e.v:e.w,i=s[t],o=n(e),c=r.distance+o;if(o<0)throw new Error("dijkstra does not allow negative edge weights. Bad edge: "+e+" Weight: "+o);c<i.distance&&(i.distance=c,i.predecessor=a,d.decrease(t,c))};for(e.nodes().forEach((function(e){var n=e===t?0:Number.POSITIVE_INFINITY;s[e]={distance:n},d.add(e,n)}));d.size()>0&&(a=d.removeMin(),(r=s[a]).distance!==Number.POSITIVE_INFINITY);)i(a).forEach(c);return s}},{"../data/priority-queue":45,"../lodash":49}],36:[function(e,t,n){var i=e("../lodash"),o=e("./tarjan");function a(e){return i.filter(o(e),(function(t){return t.length>1||1===t.length&&e.hasEdge(t[0],t[0])}))}t.exports=a},{"../lodash":49,"./tarjan":43}],37:[function(e,t,n){var i=e("../lodash");t.exports=a;var o=i.constant(1);function a(e,t,n){return r(e,t||o,n||function(t){return e.outEdges(t)})}function r(e,t,n){var i={},o=e.nodes();return o.forEach((function(e){i[e]={},i[e][e]={distance:0},o.forEach((function(t){e!==t&&(i[e][t]={distance:Number.POSITIVE_INFINITY})})),n(e).forEach((function(n){var o=n.v===e?n.w:n.v,a=t(n);i[e][o]={distance:a,predecessor:e}}))})),o.forEach((function(e){var t=i[e];o.forEach((function(n){var a=i[n];o.forEach((function(n){var i=a[e],o=t[n],r=a[n],s=i.distance+o.distance;s<r.distance&&(r.distance=s,r.predecessor=o.predecessor)}))}))})),i}},{"../lodash":49}],38:[function(e,t,n){t.exports={components:e("./components"),dijkstra:e("./dijkstra"),dijkstraAll:e("./dijkstra-all"),findCycles:e("./find-cycles"),floydWarshall:e("./floyd-warshall"),isAcyclic:e("./is-acyclic"),postorder:e("./postorder"),preorder:e("./preorder"),prim:e("./prim"),tarjan:e("./tarjan"),topsort:e("./topsort")}},{"./components":32,"./dijkstra":35,"./dijkstra-all":34,"./find-cycles":36,"./floyd-warshall":37,"./is-acyclic":39,"./postorder":40,"./preorder":41,"./prim":42,"./tarjan":43,"./topsort":44}],39:[function(e,t,n){var i=e("./topsort");function o(e){try{i(e)}catch(e){if(e instanceof i.CycleException)return!1;throw e}return!0}t.exports=o},{"./topsort":44}],40:[function(e,t,n){var i=e("./dfs");function o(e,t){return i(e,t,"post")}t.exports=o},{"./dfs":33}],41:[function(e,t,n){var i=e("./dfs");function o(e,t){return i(e,t,"pre")}t.exports=o},{"./dfs":33}],42:[function(e,t,n){var i=e("../lodash"),o=e("../graph"),a=e("../data/priority-queue");function r(e,t){var n,r=new o,s={},d=new a;function c(e){var i=e.v===n?e.w:e.v,o=d.priority(i);if(void 0!==o){var a=t(e);a<o&&(s[i]=n,d.decrease(i,a))}}if(0===e.nodeCount())return r;i.each(e.nodes(),(function(e){d.add(e,Number.POSITIVE_INFINITY),r.setNode(e)})),d.decrease(e.nodes()[0],0);for(var l=!1;d.size()>0;){if(n=d.removeMin(),i.has(s,n))r.setEdge(n,s[n]);else{if(l)throw new Error("Input graph is not connected: "+e);l=!0}e.nodeEdges(n).forEach(c)}return r}t.exports=r},{"../data/priority-queue":45,"../graph":46,"../lodash":49}],43:[function(e,t,n){var i=e("../lodash");function o(e){var t=0,n=[],o={},a=[];function r(s){var d=o[s]={onStack:!0,lowlink:t,index:t++};if(n.push(s),e.successors(s).forEach((function(e){i.has(o,e)?o[e].onStack&&(d.lowlink=Math.min(d.lowlink,o[e].index)):(r(e),d.lowlink=Math.min(d.lowlink,o[e].lowlink))})),d.lowlink===d.index){var c,l=[];do{c=n.pop(),o[c].onStack=!1,l.push(c)}while(s!==c);a.push(l)}}return e.nodes().forEach((function(e){i.has(o,e)||r(e)})),a}t.exports=o},{"../lodash":49}],44:[function(e,t,n){var i=e("../lodash");function o(e){var t={},n={},o=[];function r(s){if(i.has(n,s))throw new a;i.has(t,s)||(n[s]=!0,t[s]=!0,i.each(e.predecessors(s),r),delete n[s],o.push(s))}if(i.each(e.sinks(),r),i.size(t)!==e.nodeCount())throw new a;return o}function a(){}t.exports=o,o.CycleException=a,a.prototype=new Error},{"../lodash":49}],45:[function(e,t,n){var i=e("../lodash");function o(){this._arr=[],this._keyIndices={}}t.exports=o,o.prototype.size=function(){return this._arr.length},o.prototype.keys=function(){return this._arr.map((function(e){return e.key}))},o.prototype.has=function(e){return i.has(this._keyIndices,e)},o.prototype.priority=function(e){var t=this._keyIndices[e];if(void 0!==t)return this._arr[t].priority},o.prototype.min=function(){if(0===this.size())throw new Error("Queue underflow");return this._arr[0].key},o.prototype.add=function(e,t){var n=this._keyIndices;if(e=String(e),!i.has(n,e)){var o=this._arr,a=o.length;return n[e]=a,o.push({key:e,priority:t}),this._decrease(a),!0}return!1},o.prototype.removeMin=function(){this._swap(0,this._arr.length-1);var e=this._arr.pop();return delete this._keyIndices[e.key],this._heapify(0),e.key},o.prototype.decrease=function(e,t){var n=this._keyIndices[e];if(t>this._arr[n].priority)throw new Error("New priority is greater than current priority. Key: "+e+" Old: "+this._arr[n].priority+" New: "+t);this._arr[n].priority=t,this._decrease(n)},o.prototype._heapify=function(e){var t=this._arr,n=2*e,i=n+1,o=e;n<t.length&&(o=t[n].priority<t[o].priority?n:o,i<t.length&&(o=t[i].priority<t[o].priority?i:o),o!==e&&(this._swap(e,o),this._heapify(o)))},o.prototype._decrease=function(e){for(var t,n=this._arr,i=n[e].priority;0!==e&&!(n[t=e>>1].priority<i);)this._swap(e,t),e=t},o.prototype._swap=function(e,t){var n=this._arr,i=this._keyIndices,o=n[e],a=n[t];n[e]=a,n[t]=o,i[a.key]=e,i[o.key]=t}},{"../lodash":49}],46:[function(e,t,n){var i=e("./lodash");t.exports=s;var o="\0",a="\0",r="";function s(e){this._isDirected=!i.has(e,"directed")||e.directed,this._isMultigraph=!!i.has(e,"multigraph")&&e.multigraph,this._isCompound=!!i.has(e,"compound")&&e.compound,this._label=void 0,this._defaultNodeLabelFn=i.constant(void 0),this._defaultEdgeLabelFn=i.constant(void 0),this._nodes={},this._isCompound&&(this._parent={},this._children={},this._children[a]={}),this._in={},this._preds={},this._out={},this._sucs={},this._edgeObjs={},this._edgeLabels={}}function d(e,t){e[t]?e[t]++:e[t]=1}function c(e,t){--e[t]||delete e[t]}function l(e,t,n,a){var s=""+t,d=""+n;if(!e&&s>d){var c=s;s=d,d=c}return s+r+d+r+(i.isUndefined(a)?o:a)}function u(e,t,n,i){var o=""+t,a=""+n;if(!e&&o>a){var r=o;o=a,a=r}var s={v:o,w:a};return i&&(s.name=i),s}function p(e,t){return l(e,t.v,t.w,t.name)}s.prototype._nodeCount=0,s.prototype._edgeCount=0,s.prototype.isDirected=function(){return this._isDirected},s.prototype.isMultigraph=function(){return this._isMultigraph},s.prototype.isCompound=function(){return this._isCompound},s.prototype.setGraph=function(e){return this._label=e,this},s.prototype.graph=function(){return this._label},s.prototype.setDefaultNodeLabel=function(e){return i.isFunction(e)||(e=i.constant(e)),this._defaultNodeLabelFn=e,this},s.prototype.nodeCount=function(){return this._nodeCount},s.prototype.nodes=function(){return i.keys(this._nodes)},s.prototype.sources=function(){var e=this;return i.filter(this.nodes(),(function(t){return i.isEmpty(e._in[t])}))},s.prototype.sinks=function(){var e=this;return i.filter(this.nodes(),(function(t){return i.isEmpty(e._out[t])}))},s.prototype.setNodes=function(e,t){var n=arguments,o=this;return i.each(e,(function(e){n.length>1?o.setNode(e,t):o.setNode(e)})),this},s.prototype.setNode=function(e,t){return i.has(this._nodes,e)?(arguments.length>1&&(this._nodes[e]=t),this):(this._nodes[e]=arguments.length>1?t:this._defaultNodeLabelFn(e),this._isCompound&&(this._parent[e]=a,this._children[e]={},this._children[a][e]=!0),this._in[e]={},this._preds[e]={},this._out[e]={},this._sucs[e]={},++this._nodeCount,this)},s.prototype.node=function(e){return this._nodes[e]},s.prototype.hasNode=function(e){return i.has(this._nodes,e)},s.prototype.removeNode=function(e){var t=this;if(i.has(this._nodes,e)){var n=function(e){t.removeEdge(t._edgeObjs[e])};delete this._nodes[e],this._isCompound&&(this._removeFromParentsChildList(e),delete this._parent[e],i.each(this.children(e),(function(e){t.setParent(e)})),delete this._children[e]),i.each(i.keys(this._in[e]),n),delete this._in[e],delete this._preds[e],i.each(i.keys(this._out[e]),n),delete this._out[e],delete this._sucs[e],--this._nodeCount}return this},s.prototype.setParent=function(e,t){if(!this._isCompound)throw new Error("Cannot set parent in a non-compound graph");if(i.isUndefined(t))t=a;else{for(var n=t+="";!i.isUndefined(n);n=this.parent(n))if(n===e)throw new Error("Setting "+t+" as parent of "+e+" would create a cycle");this.setNode(t)}return this.setNode(e),this._removeFromParentsChildList(e),this._parent[e]=t,this._children[t][e]=!0,this},s.prototype._removeFromParentsChildList=function(e){delete this._children[this._parent[e]][e]},s.prototype.parent=function(e){if(this._isCompound){var t=this._parent[e];if(t!==a)return t}},s.prototype.children=function(e){if(i.isUndefined(e)&&(e=a),this._isCompound){var t=this._children[e];if(t)return i.keys(t)}else{if(e===a)return this.nodes();if(this.hasNode(e))return[]}},s.prototype.predecessors=function(e){var t=this._preds[e];if(t)return i.keys(t)},s.prototype.successors=function(e){var t=this._sucs[e];if(t)return i.keys(t)},s.prototype.neighbors=function(e){var t=this.predecessors(e);if(t)return i.union(t,this.successors(e))},s.prototype.isLeaf=function(e){return 0===(this.isDirected()?this.successors(e):this.neighbors(e)).length},s.prototype.filterNodes=function(e){var t=new this.constructor({directed:this._isDirected,multigraph:this._isMultigraph,compound:this._isCompound});t.setGraph(this.graph());var n=this;i.each(this._nodes,(function(n,i){e(i)&&t.setNode(i,n)})),i.each(this._edgeObjs,(function(e){t.hasNode(e.v)&&t.hasNode(e.w)&&t.setEdge(e,n.edge(e))}));var o={};function a(e){var i=n.parent(e);return void 0===i||t.hasNode(i)?(o[e]=i,i):i in o?o[i]:a(i)}return this._isCompound&&i.each(t.nodes(),(function(e){t.setParent(e,a(e))})),t},s.prototype.setDefaultEdgeLabel=function(e){return i.isFunction(e)||(e=i.constant(e)),this._defaultEdgeLabelFn=e,this},s.prototype.edgeCount=function(){return this._edgeCount},s.prototype.edges=function(){return i.values(this._edgeObjs)},s.prototype.setPath=function(e,t){var n=this,o=arguments;return i.reduce(e,(function(e,i){return o.length>1?n.setEdge(e,i,t):n.setEdge(e,i),i})),this},s.prototype.setEdge=function(){var e,t,n,o,a=!1,r=arguments[0];"object"==typeof r&&null!==r&&"v"in r?(e=r.v,t=r.w,n=r.name,2===arguments.length&&(o=arguments[1],a=!0)):(e=r,t=arguments[1],n=arguments[3],arguments.length>2&&(o=arguments[2],a=!0)),e=""+e,t=""+t,i.isUndefined(n)||(n=""+n);var s=l(this._isDirected,e,t,n);if(i.has(this._edgeLabels,s))return a&&(this._edgeLabels[s]=o),this;if(!i.isUndefined(n)&&!this._isMultigraph)throw new Error("Cannot set a named edge when isMultigraph = false");this.setNode(e),this.setNode(t),this._edgeLabels[s]=a?o:this._defaultEdgeLabelFn(e,t,n);var c=u(this._isDirected,e,t,n);return e=c.v,t=c.w,Object.freeze(c),this._edgeObjs[s]=c,d(this._preds[t],e),d(this._sucs[e],t),this._in[t][s]=c,this._out[e][s]=c,this._edgeCount++,this},s.prototype.edge=function(e,t,n){var i=1===arguments.length?p(this._isDirected,arguments[0]):l(this._isDirected,e,t,n);return this._edgeLabels[i]},s.prototype.hasEdge=function(e,t,n){var o=1===arguments.length?p(this._isDirected,arguments[0]):l(this._isDirected,e,t,n);return i.has(this._edgeLabels,o)},s.prototype.removeEdge=function(e,t,n){var i=1===arguments.length?p(this._isDirected,arguments[0]):l(this._isDirected,e,t,n),o=this._edgeObjs[i];return o&&(e=o.v,t=o.w,delete this._edgeLabels[i],delete this._edgeObjs[i],c(this._preds[t],e),c(this._sucs[e],t),delete this._in[t][i],delete this._out[e][i],this._edgeCount--),this},s.prototype.inEdges=function(e,t){var n=this._in[e];if(n){var o=i.values(n);return t?i.filter(o,(function(e){return e.v===t})):o}},s.prototype.outEdges=function(e,t){var n=this._out[e];if(n){var o=i.values(n);return t?i.filter(o,(function(e){return e.w===t})):o}},s.prototype.nodeEdges=function(e,t){var n=this.inEdges(e,t);if(n)return n.concat(this.outEdges(e,t))}},{"./lodash":49}],47:[function(e,t,n){t.exports={Graph:e("./graph"),version:e("./version")}},{"./graph":46,"./version":50}],48:[function(e,t,n){var i=e("./lodash"),o=e("./graph");function a(e){var t={options:{directed:e.isDirected(),multigraph:e.isMultigraph(),compound:e.isCompound()},nodes:r(e),edges:s(e)};return i.isUndefined(e.graph())||(t.value=i.clone(e.graph())),t}function r(e){return i.map(e.nodes(),(function(t){var n=e.node(t),o=e.parent(t),a={v:t};return i.isUndefined(n)||(a.value=n),i.isUndefined(o)||(a.parent=o),a}))}function s(e){return i.map(e.edges(),(function(t){var n=e.edge(t),o={v:t.v,w:t.w};return i.isUndefined(t.name)||(o.name=t.name),i.isUndefined(n)||(o.value=n),o}))}function d(e){var t=new o(e.options).setGraph(e.value);return i.each(e.nodes,(function(e){t.setNode(e.v,e.value),e.parent&&t.setParent(e.v,e.parent)})),i.each(e.edges,(function(e){t.setEdge({v:e.v,w:e.w,name:e.name},e.value)})),t}t.exports={write:a,read:d}},{"./graph":46,"./lodash":49}],49:[function(e,t,n){var i;if("function"==typeof e)try{i={clone:e("lodash/clone"),constant:e("lodash/constant"),each:e("lodash/each"),filter:e("lodash/filter"),has:e("lodash/has"),isArray:e("lodash/isArray"),isEmpty:e("lodash/isEmpty"),isFunction:e("lodash/isFunction"),isUndefined:e("lodash/isUndefined"),keys:e("lodash/keys"),map:e("lodash/map"),reduce:e("lodash/reduce"),size:e("lodash/size"),transform:e("lodash/transform"),union:e("lodash/union"),values:e("lodash/values")}}catch(e){}i||(i=window._),t.exports=i},{"lodash/clone":226,"lodash/constant":228,"lodash/each":230,"lodash/filter":232,"lodash/has":239,"lodash/isArray":243,"lodash/isEmpty":247,"lodash/isFunction":248,"lodash/isUndefined":258,"lodash/keys":259,"lodash/map":262,"lodash/reduce":274,"lodash/size":275,"lodash/transform":284,"lodash/union":285,"lodash/values":287}],50:[function(e,t,n){t.exports="2.1.8"},{}],51:[function(e,t,n){var i=e("./_getNative")(e("./_root"),"DataView");t.exports=i},{"./_getNative":163,"./_root":208}],52:[function(e,t,n){var i=e("./_hashClear"),o=e("./_hashDelete"),a=e("./_hashGet"),r=e("./_hashHas"),s=e("./_hashSet");function d(e){var t=-1,n=null==e?0:e.length;for(this.clear();++t<n;){var i=e[t];this.set(i[0],i[1])}}d.prototype.clear=i,d.prototype.delete=o,d.prototype.get=a,d.prototype.has=r,d.prototype.set=s,t.exports=d},{"./_hashClear":172,"./_hashDelete":173,"./_hashGet":174,"./_hashHas":175,"./_hashSet":176}],53:[function(e,t,n){var i=e("./_listCacheClear"),o=e("./_listCacheDelete"),a=e("./_listCacheGet"),r=e("./_listCacheHas"),s=e("./_listCacheSet");function d(e){var t=-1,n=null==e?0:e.length;for(this.clear();++t<n;){var i=e[t];this.set(i[0],i[1])}}d.prototype.clear=i,d.prototype.delete=o,d.prototype.get=a,d.prototype.has=r,d.prototype.set=s,t.exports=d},{"./_listCacheClear":188,"./_listCacheDelete":189,"./_listCacheGet":190,"./_listCacheHas":191,"./_listCacheSet":192}],54:[function(e,t,n){var i=e("./_getNative")(e("./_root"),"Map");t.exports=i},{"./_getNative":163,"./_root":208}],55:[function(e,t,n){var i=e("./_mapCacheClear"),o=e("./_mapCacheDelete"),a=e("./_mapCacheGet"),r=e("./_mapCacheHas"),s=e("./_mapCacheSet");function d(e){var t=-1,n=null==e?0:e.length;for(this.clear();++t<n;){var i=e[t];this.set(i[0],i[1])}}d.prototype.clear=i,d.prototype.delete=o,d.prototype.get=a,d.prototype.has=r,d.prototype.set=s,t.exports=d},{"./_mapCacheClear":193,"./_mapCacheDelete":194,"./_mapCacheGet":195,"./_mapCacheHas":196,"./_mapCacheSet":197}],56:[function(e,t,n){var i=e("./_getNative")(e("./_root"),"Promise");t.exports=i},{"./_getNative":163,"./_root":208}],57:[function(e,t,n){var i=e("./_getNative")(e("./_root"),"Set");t.exports=i},{"./_getNative":163,"./_root":208}],58:[function(e,t,n){var i=e("./_MapCache"),o=e("./_setCacheAdd"),a=e("./_setCacheHas");function r(e){var t=-1,n=null==e?0:e.length;for(this.__data__=new i;++t<n;)this.add(e[t])}r.prototype.add=r.prototype.push=o,r.prototype.has=a,t.exports=r},{"./_MapCache":55,"./_setCacheAdd":210,"./_setCacheHas":211}],59:[function(e,t,n){var i=e("./_ListCache"),o=e("./_stackClear"),a=e("./_stackDelete"),r=e("./_stackGet"),s=e("./_stackHas"),d=e("./_stackSet");function c(e){var t=this.__data__=new i(e);this.size=t.size}c.prototype.clear=o,c.prototype.delete=a,c.prototype.get=r,c.prototype.has=s,c.prototype.set=d,t.exports=c},{"./_ListCache":53,"./_stackClear":215,"./_stackDelete":216,"./_stackGet":217,"./_stackHas":218,"./_stackSet":219}],60:[function(e,t,n){var i=e("./_root").Symbol;t.exports=i},{"./_root":208}],61:[function(e,t,n){var i=e("./_root").Uint8Array;t.exports=i},{"./_root":208}],62:[function(e,t,n){var i=e("./_getNative")(e("./_root"),"WeakMap");t.exports=i},{"./_getNative":163,"./_root":208}],63:[function(e,t,n){function i(e,t,n){switch(n.length){case 0:return e.call(t);case 1:return e.call(t,n[0]);case 2:return e.call(t,n[0],n[1]);case 3:return e.call(t,n[0],n[1],n[2])}return e.apply(t,n)}t.exports=i},{}],64:[function(e,t,n){function i(e,t){for(var n=-1,i=null==e?0:e.length;++n<i&&!1!==t(e[n],n,e););return e}t.exports=i},{}],65:[function(e,t,n){function i(e,t){for(var n=-1,i=null==e?0:e.length,o=0,a=[];++n<i;){var r=e[n];t(r,n,e)&&(a[o++]=r)}return a}t.exports=i},{}],66:[function(e,t,n){var i=e("./_baseIndexOf");function o(e,t){return!(null==e||!e.length)&&i(e,t,0)>-1}t.exports=o},{"./_baseIndexOf":95}],67:[function(e,t,n){function i(e,t,n){for(var i=-1,o=null==e?0:e.length;++i<o;)if(n(t,e[i]))return!0;return!1}t.exports=i},{}],68:[function(e,t,n){var i=e("./_baseTimes"),o=e("./isArguments"),a=e("./isArray"),r=e("./isBuffer"),s=e("./_isIndex"),d=e("./isTypedArray"),c=Object.prototype.hasOwnProperty;function l(e,t){var n=a(e),l=!n&&o(e),u=!n&&!l&&r(e),p=!n&&!l&&!u&&d(e),f=n||l||u||p,h=f?i(e.length,String):[],g=h.length;for(var y in e)!t&&!c.call(e,y)||f&&("length"==y||u&&("offset"==y||"parent"==y)||p&&("buffer"==y||"byteLength"==y||"byteOffset"==y)||s(y,g))||h.push(y);return h}t.exports=l},{"./_baseTimes":125,"./_isIndex":181,"./isArguments":242,"./isArray":243,"./isBuffer":246,"./isTypedArray":257}],69:[function(e,t,n){function i(e,t){for(var n=-1,i=null==e?0:e.length,o=Array(i);++n<i;)o[n]=t(e[n],n,e);return o}t.exports=i},{}],70:[function(e,t,n){function i(e,t){for(var n=-1,i=t.length,o=e.length;++n<i;)e[o+n]=t[n];return e}t.exports=i},{}],71:[function(e,t,n){function i(e,t,n,i){var o=-1,a=null==e?0:e.length;for(i&&a&&(n=e[++o]);++o<a;)n=t(n,e[o],o,e);return n}t.exports=i},{}],72:[function(e,t,n){function i(e,t){for(var n=-1,i=null==e?0:e.length;++n<i;)if(t(e[n],n,e))return!0;return!1}t.exports=i},{}],73:[function(e,t,n){var i=e("./_baseProperty")("length");t.exports=i},{"./_baseProperty":117}],74:[function(e,t,n){var i=e("./_baseAssignValue"),o=e("./eq");function a(e,t,n){(void 0!==n&&!o(e[t],n)||void 0===n&&!(t in e))&&i(e,t,n)}t.exports=a},{"./_baseAssignValue":79,"./eq":231}],75:[function(e,t,n){var i=e("./_baseAssignValue"),o=e("./eq"),a=Object.prototype.hasOwnProperty;function r(e,t,n){var r=e[t];a.call(e,t)&&o(r,n)&&(void 0!==n||t in e)||i(e,t,n)}t.exports=r},{"./_baseAssignValue":79,"./eq":231}],76:[function(e,t,n){var i=e("./eq");function o(e,t){for(var n=e.length;n--;)if(i(e[n][0],t))return n;return-1}t.exports=o},{"./eq":231}],77:[function(e,t,n){var i=e("./_copyObject"),o=e("./keys");function a(e,t){return e&&i(t,o(t),e)}t.exports=a},{"./_copyObject":143,"./keys":259}],78:[function(e,t,n){var i=e("./_copyObject"),o=e("./keysIn");function a(e,t){return e&&i(t,o(t),e)}t.exports=a},{"./_copyObject":143,"./keysIn":260}],79:[function(e,t,n){var i=e("./_defineProperty");function o(e,t,n){"__proto__"==t&&i?i(e,t,{configurable:!0,enumerable:!0,value:n,writable:!0}):e[t]=n}t.exports=o},{"./_defineProperty":153}],80:[function(e,t,n){var i=e("./_Stack"),o=e("./_arrayEach"),a=e("./_assignValue"),r=e("./_baseAssign"),s=e("./_baseAssignIn"),d=e("./_cloneBuffer"),c=e("./_copyArray"),l=e("./_copySymbols"),u=e("./_copySymbolsIn"),p=e("./_getAllKeys"),f=e("./_getAllKeysIn"),h=e("./_getTag"),g=e("./_initCloneArray"),y=e("./_initCloneByTag"),m=e("./_initCloneObject"),v=e("./isArray"),b=e("./isBuffer"),_=e("./isMap"),k=e("./isObject"),P=e("./isSet"),I=e("./keys"),N=1,S=2,E=4,j="[object Arguments]",w="[object Array]",O="[object Boolean]",T="[object Date]",L="[object Error]",x="[object Function]",C="[object GeneratorFunction]",A="[object Map]",D="[object Number]",M="[object Object]",R="[object RegExp]",U="[object Set]",F="[object String]",B="[object Symbol]",H="[object WeakMap]",q="[object ArrayBuffer]",G="[object DataView]",z="[object Float32Array]",V="[object Float64Array]",$="[object Int8Array]",W="[object Int16Array]",Y="[object Int32Array]",X="[object Uint8Array]",K="[object Uint8ClampedArray]",J="[object Uint16Array]",Z="[object Uint32Array]",Q={};function ee(e,t,n,w,O,T){var L,A=t&N,D=t&S,R=t&E;if(n&&(L=O?n(e,w,O,T):n(e)),void 0!==L)return L;if(!k(e))return e;var U=v(e);if(U){if(L=g(e),!A)return c(e,L)}else{var F=h(e),B=F==x||F==C;if(b(e))return d(e,A);if(F==M||F==j||B&&!O){if(L=D||B?{}:m(e),!A)return D?u(e,s(L,e)):l(e,r(L,e))}else{if(!Q[F])return O?e:{};L=y(e,F,A)}}T||(T=new i);var H=T.get(e);if(H)return H;T.set(e,L),P(e)?e.forEach((function(i){L.add(ee(i,t,n,i,e,T))})):_(e)&&e.forEach((function(i,o){L.set(o,ee(i,t,n,o,e,T))}));var q=R?D?f:p:D?keysIn:I,G=U?void 0:q(e);return o(G||e,(function(i,o){G&&(i=e[o=i]),a(L,o,ee(i,t,n,o,e,T))})),L}Q[j]=Q[w]=Q[q]=Q[G]=Q[O]=Q[T]=Q[z]=Q[V]=Q[$]=Q[W]=Q[Y]=Q[A]=Q[D]=Q[M]=Q[R]=Q[U]=Q[F]=Q[B]=Q[X]=Q[K]=Q[J]=Q[Z]=!0,Q[L]=Q[x]=Q[H]=!1,t.exports=ee},{"./_Stack":59,"./_arrayEach":64,"./_assignValue":75,"./_baseAssign":77,"./_baseAssignIn":78,"./_cloneBuffer":135,"./_copyArray":142,"./_copySymbols":144,"./_copySymbolsIn":145,"./_getAllKeys":159,"./_getAllKeysIn":160,"./_getTag":168,"./_initCloneArray":177,"./_initCloneByTag":178,"./_initCloneObject":179,"./isArray":243,"./isBuffer":246,"./isMap":250,"./isObject":251,"./isSet":254,"./keys":259}],81:[function(e,t,n){var i=e("./isObject"),o=Object.create,a=function(){function e(){}return function(t){if(!i(t))return{};if(o)return o(t);e.prototype=t;var n=new e;return e.prototype=void 0,n}}();t.exports=a},{"./isObject":251}],82:[function(e,t,n){var i=e("./_baseForOwn"),o=e("./_createBaseEach")(i);t.exports=o},{"./_baseForOwn":88,"./_createBaseEach":148}],83:[function(e,t,n){var i=e("./isSymbol");function o(e,t,n){for(var o=-1,a=e.length;++o<a;){var r=e[o],s=t(r);if(null!=s&&(void 0===d?s==s&&!i(s):n(s,d)))var d=s,c=r}return c}t.exports=o},{"./isSymbol":256}],84:[function(e,t,n){var i=e("./_baseEach");function o(e,t){var n=[];return i(e,(function(e,i,o){t(e,i,o)&&n.push(e)})),n}t.exports=o},{"./_baseEach":82}],85:[function(e,t,n){function i(e,t,n,i){for(var o=e.length,a=n+(i?1:-1);i?a--:++a<o;)if(t(e[a],a,e))return a;return-1}t.exports=i},{}],86:[function(e,t,n){var i=e("./_arrayPush"),o=e("./_isFlattenable");function a(e,t,n,r,s){var d=-1,c=e.length;for(n||(n=o),s||(s=[]);++d<c;){var l=e[d];t>0&&n(l)?t>1?a(l,t-1,n,r,s):i(s,l):r||(s[s.length]=l)}return s}t.exports=a},{"./_arrayPush":70,"./_isFlattenable":180}],87:[function(e,t,n){var i=e("./_createBaseFor")();t.exports=i},{"./_createBaseFor":149}],88:[function(e,t,n){var i=e("./_baseFor"),o=e("./keys");function a(e,t){return e&&i(e,t,o)}t.exports=a},{"./_baseFor":87,"./keys":259}],89:[function(e,t,n){var i=e("./_castPath"),o=e("./_toKey");function a(e,t){for(var n=0,a=(t=i(t,e)).length;null!=e&&n<a;)e=e[o(t[n++])];return n&&n==a?e:void 0}t.exports=a},{"./_castPath":133,"./_toKey":223}],90:[function(e,t,n){var i=e("./_arrayPush"),o=e("./isArray");function a(e,t,n){var a=t(e);return o(e)?a:i(a,n(e))}t.exports=a},{"./_arrayPush":70,"./isArray":243}],91:[function(e,t,n){var i=e("./_Symbol"),o=e("./_getRawTag"),a=e("./_objectToString"),r="[object Null]",s="[object Undefined]",d=i?i.toStringTag:void 0;function c(e){return null==e?void 0===e?s:r:d&&d in Object(e)?o(e):a(e)}t.exports=c},{"./_Symbol":60,"./_getRawTag":165,"./_objectToString":205}],92:[function(e,t,n){function i(e,t){return e>t}t.exports=i},{}],93:[function(e,t,n){var i=Object.prototype.hasOwnProperty;function o(e,t){return null!=e&&i.call(e,t)}t.exports=o},{}],94:[function(e,t,n){function i(e,t){return null!=e&&t in Object(e)}t.exports=i},{}],95:[function(e,t,n){var i=e("./_baseFindIndex"),o=e("./_baseIsNaN"),a=e("./_strictIndexOf");function r(e,t,n){return t==t?a(e,t,n):i(e,o,n)}t.exports=r},{"./_baseFindIndex":85,"./_baseIsNaN":101,"./_strictIndexOf":220}],96:[function(e,t,n){var i=e("./_baseGetTag"),o=e("./isObjectLike"),a="[object Arguments]";function r(e){return o(e)&&i(e)==a}t.exports=r},{"./_baseGetTag":91,"./isObjectLike":252}],97:[function(e,t,n){var i=e("./_baseIsEqualDeep"),o=e("./isObjectLike");function a(e,t,n,r,s){return e===t||(null==e||null==t||!o(e)&&!o(t)?e!=e&&t!=t:i(e,t,n,r,a,s))}t.exports=a},{"./_baseIsEqualDeep":98,"./isObjectLike":252}],98:[function(e,t,n){var i=e("./_Stack"),o=e("./_equalArrays"),a=e("./_equalByTag"),r=e("./_equalObjects"),s=e("./_getTag"),d=e("./isArray"),c=e("./isBuffer"),l=e("./isTypedArray"),u=1,p="[object Arguments]",f="[object Array]",h="[object Object]",g=Object.prototype.hasOwnProperty;function y(e,t,n,y,m,v){var b=d(e),_=d(t),k=b?f:s(e),P=_?f:s(t),I=(k=k==p?h:k)==h,N=(P=P==p?h:P)==h,S=k==P;if(S&&c(e)){if(!c(t))return!1;b=!0,I=!1}if(S&&!I)return v||(v=new i),b||l(e)?o(e,t,n,y,m,v):a(e,t,k,n,y,m,v);if(!(n&u)){var E=I&&g.call(e,"__wrapped__"),j=N&&g.call(t,"__wrapped__");if(E||j){var w=E?e.value():e,O=j?t.value():t;return v||(v=new i),m(w,O,n,y,v)}}return!!S&&(v||(v=new i),r(e,t,n,y,m,v))}t.exports=y},{"./_Stack":59,"./_equalArrays":154,"./_equalByTag":155,"./_equalObjects":156,"./_getTag":168,"./isArray":243,"./isBuffer":246,"./isTypedArray":257}],99:[function(e,t,n){var i=e("./_getTag"),o=e("./isObjectLike"),a="[object Map]";function r(e){return o(e)&&i(e)==a}t.exports=r},{"./_getTag":168,"./isObjectLike":252}],100:[function(e,t,n){var i=e("./_Stack"),o=e("./_baseIsEqual"),a=1,r=2;function s(e,t,n,s){var d=n.length,c=d,l=!s;if(null==e)return!c;for(e=Object(e);d--;){var u=n[d];if(l&&u[2]?u[1]!==e[u[0]]:!(u[0]in e))return!1}for(;++d<c;){var p=(u=n[d])[0],f=e[p],h=u[1];if(l&&u[2]){if(void 0===f&&!(p in e))return!1}else{var g=new i;if(s)var y=s(f,h,p,e,t,g);if(!(void 0===y?o(h,f,a|r,s,g):y))return!1}}return!0}t.exports=s},{"./_Stack":59,"./_baseIsEqual":97}],101:[function(e,t,n){function i(e){return e!=e}t.exports=i},{}],102:[function(e,t,n){var i=e("./isFunction"),o=e("./_isMasked"),a=e("./isObject"),r=e("./_toSource"),s=/[\\^$.*+?()[\]{}|]/g,d=/^\[object .+?Constructor\]$/,c=Function.prototype,l=Object.prototype,u=c.toString,p=l.hasOwnProperty,f=RegExp("^"+u.call(p).replace(s,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$");function h(e){return!(!a(e)||o(e))&&(i(e)?f:d).test(r(e))}t.exports=h},{"./_isMasked":185,"./_toSource":224,"./isFunction":248,"./isObject":251}],103:[function(e,t,n){var i=e("./_getTag"),o=e("./isObjectLike"),a="[object Set]";function r(e){return o(e)&&i(e)==a}t.exports=r},{"./_getTag":168,"./isObjectLike":252}],104:[function(e,t,n){var i=e("./_baseGetTag"),o=e("./isLength"),a=e("./isObjectLike"),r="[object Arguments]",s="[object Array]",d="[object Boolean]",c="[object Date]",l="[object Error]",u="[object Function]",p="[object Map]",f="[object Number]",h="[object Object]",g="[object RegExp]",y="[object Set]",m="[object String]",v="[object WeakMap]",b="[object ArrayBuffer]",_="[object DataView]",k="[object Float64Array]",P="[object Int8Array]",I="[object Int16Array]",N="[object Int32Array]",S="[object Uint8Array]",E="[object Uint8ClampedArray]",j="[object Uint16Array]",w="[object Uint32Array]",O={};function T(e){return a(e)&&o(e.length)&&!!O[i(e)]}O["[object Float32Array]"]=O[k]=O[P]=O[I]=O[N]=O[S]=O[E]=O[j]=O[w]=!0,O[r]=O[s]=O[b]=O[d]=O[_]=O[c]=O[l]=O[u]=O[p]=O[f]=O[h]=O[g]=O[y]=O[m]=O[v]=!1,t.exports=T},{"./_baseGetTag":91,"./isLength":249,"./isObjectLike":252}],105:[function(e,t,n){var i=e("./_baseMatches"),o=e("./_baseMatchesProperty"),a=e("./identity"),r=e("./isArray"),s=e("./property");function d(e){return"function"==typeof e?e:null==e?a:"object"==typeof e?r(e)?o(e[0],e[1]):i(e):s(e)}t.exports=d},{"./_baseMatches":110,"./_baseMatchesProperty":111,"./identity":241,"./isArray":243,"./property":272}],106:[function(e,t,n){var i=e("./_isPrototype"),o=e("./_nativeKeys"),a=Object.prototype.hasOwnProperty;function r(e){if(!i(e))return o(e);var t=[];for(var n in Object(e))a.call(e,n)&&"constructor"!=n&&t.push(n);return t}t.exports=r},{"./_isPrototype":186,"./_nativeKeys":202}],107:[function(e,t,n){var i=e("./isObject"),o=e("./_isPrototype"),a=e("./_nativeKeysIn"),r=Object.prototype.hasOwnProperty;function s(e){if(!i(e))return a(e);var t=o(e),n=[];for(var s in e)("constructor"!=s||!t&&r.call(e,s))&&n.push(s);return n}t.exports=s},{"./_isPrototype":186,"./_nativeKeysIn":203,"./isObject":251}],108:[function(e,t,n){function i(e,t){return e<t}t.exports=i},{}],109:[function(e,t,n){var i=e("./_baseEach"),o=e("./isArrayLike");function a(e,t){var n=-1,a=o(e)?Array(e.length):[];return i(e,(function(e,i,o){a[++n]=t(e,i,o)})),a}t.exports=a},{"./_baseEach":82,"./isArrayLike":244}],110:[function(e,t,n){var i=e("./_baseIsMatch"),o=e("./_getMatchData"),a=e("./_matchesStrictComparable");function r(e){var t=o(e);return 1==t.length&&t[0][2]?a(t[0][0],t[0][1]):function(n){return n===e||i(n,e,t)}}t.exports=r},{"./_baseIsMatch":100,"./_getMatchData":162,"./_matchesStrictComparable":199}],111:[function(e,t,n){var i=e("./_baseIsEqual"),o=e("./get"),a=e("./hasIn"),r=e("./_isKey"),s=e("./_isStrictComparable"),d=e("./_matchesStrictComparable"),c=e("./_toKey"),l=1,u=2;function p(e,t){return r(e)&&s(t)?d(c(e),t):function(n){var r=o(n,e);return void 0===r&&r===t?a(n,e):i(t,r,l|u)}}t.exports=p},{"./_baseIsEqual":97,"./_isKey":183,"./_isStrictComparable":187,"./_matchesStrictComparable":199,"./_toKey":223,"./get":238,"./hasIn":240}],112:[function(e,t,n){var i=e("./_Stack"),o=e("./_assignMergeValue"),a=e("./_baseFor"),r=e("./_baseMergeDeep"),s=e("./isObject"),d=e("./keysIn"),c=e("./_safeGet");function l(e,t,n,u,p){e!==t&&a(t,(function(a,d){if(p||(p=new i),s(a))r(e,t,d,n,l,u,p);else{var f=u?u(c(e,d),a,d+"",e,t,p):void 0;void 0===f&&(f=a),o(e,d,f)}}),d)}t.exports=l},{"./_Stack":59,"./_assignMergeValue":74,"./_baseFor":87,"./_baseMergeDeep":113,"./_safeGet":209,"./isObject":251,"./keysIn":260}],113:[function(e,t,n){var i=e("./_assignMergeValue"),o=e("./_cloneBuffer"),a=e("./_cloneTypedArray"),r=e("./_copyArray"),s=e("./_initCloneObject"),d=e("./isArguments"),c=e("./isArray"),l=e("./isArrayLikeObject"),u=e("./isBuffer"),p=e("./isFunction"),f=e("./isObject"),h=e("./isPlainObject"),g=e("./isTypedArray"),y=e("./_safeGet"),m=e("./toPlainObject");function v(e,t,n,v,b,_,k){var P=y(e,n),I=y(t,n),N=k.get(I);if(N)i(e,n,N);else{var S=_?_(P,I,n+"",e,t,k):void 0,E=void 0===S;if(E){var j=c(I),w=!j&&u(I),O=!j&&!w&&g(I);S=I,j||w||O?c(P)?S=P:l(P)?S=r(P):w?(E=!1,S=o(I,!0)):O?(E=!1,S=a(I,!0)):S=[]:h(I)||d(I)?(S=P,d(P)?S=m(P):f(P)&&!p(P)||(S=s(I))):E=!1}E&&(k.set(I,S),b(S,I,v,_,k),k.delete(I)),i(e,n,S)}}t.exports=v},{"./_assignMergeValue":74,"./_cloneBuffer":135,"./_cloneTypedArray":139,"./_copyArray":142,"./_initCloneObject":179,"./_safeGet":209,"./isArguments":242,"./isArray":243,"./isArrayLikeObject":245,"./isBuffer":246,"./isFunction":248,"./isObject":251,"./isPlainObject":253,"./isTypedArray":257,"./toPlainObject":282}],114:[function(e,t,n){var i=e("./_arrayMap"),o=e("./_baseIteratee"),a=e("./_baseMap"),r=e("./_baseSortBy"),s=e("./_baseUnary"),d=e("./_compareMultiple"),c=e("./identity");function l(e,t,n){var l=-1;t=i(t.length?t:[c],s(o));var u=a(e,(function(e,n,o){return{criteria:i(t,(function(t){return t(e)})),index:++l,value:e}}));return r(u,(function(e,t){return d(e,t,n)}))}t.exports=l},{"./_arrayMap":69,"./_baseIteratee":105,"./_baseMap":109,"./_baseSortBy":124,"./_baseUnary":127,"./_compareMultiple":141,"./identity":241}],115:[function(e,t,n){var i=e("./_basePickBy"),o=e("./hasIn");function a(e,t){return i(e,t,(function(t,n){return o(e,n)}))}t.exports=a},{"./_basePickBy":116,"./hasIn":240}],116:[function(e,t,n){var i=e("./_baseGet"),o=e("./_baseSet"),a=e("./_castPath");function r(e,t,n){for(var r=-1,s=t.length,d={};++r<s;){var c=t[r],l=i(e,c);n(l,c)&&o(d,a(c,e),l)}return d}t.exports=r},{"./_baseGet":89,"./_baseSet":122,"./_castPath":133}],117:[function(e,t,n){function i(e){return function(t){return null==t?void 0:t[e]}}t.exports=i},{}],118:[function(e,t,n){var i=e("./_baseGet");function o(e){return function(t){return i(t,e)}}t.exports=o},{"./_baseGet":89}],119:[function(e,t,n){var i=Math.ceil,o=Math.max;function a(e,t,n,a){for(var r=-1,s=o(i((t-e)/(n||1)),0),d=Array(s);s--;)d[a?s:++r]=e,e+=n;return d}t.exports=a},{}],120:[function(e,t,n){function i(e,t,n,i,o){return o(e,(function(e,o,a){n=i?(i=!1,e):t(n,e,o,a)})),n}t.exports=i},{}],121:[function(e,t,n){var i=e("./identity"),o=e("./_overRest"),a=e("./_setToString");function r(e,t){return a(o(e,t,i),e+"")}t.exports=r},{"./_overRest":207,"./_setToString":213,"./identity":241}],122:[function(e,t,n){var i=e("./_assignValue"),o=e("./_castPath"),a=e("./_isIndex"),r=e("./isObject"),s=e("./_toKey");function d(e,t,n,d){if(!r(e))return e;for(var c=-1,l=(t=o(t,e)).length,u=l-1,p=e;null!=p&&++c<l;){var f=s(t[c]),h=n;if(c!=u){var g=p[f];void 0===(h=d?d(g,f,p):void 0)&&(h=r(g)?g:a(t[c+1])?[]:{})}i(p,f,h),p=p[f]}return e}t.exports=d},{"./_assignValue":75,"./_castPath":133,"./_isIndex":181,"./_toKey":223,"./isObject":251}],123:[function(e,t,n){var i=e("./constant"),o=e("./_defineProperty"),a=e("./identity"),r=o?function(e,t){return o(e,"toString",{configurable:!0,enumerable:!1,value:i(t),writable:!0})}:a;t.exports=r},{"./_defineProperty":153,"./constant":228,"./identity":241}],124:[function(e,t,n){function i(e,t){var n=e.length;for(e.sort(t);n--;)e[n]=e[n].value;return e}t.exports=i},{}],125:[function(e,t,n){function i(e,t){for(var n=-1,i=Array(e);++n<e;)i[n]=t(n);return i}t.exports=i},{}],126:[function(e,t,n){var i=e("./_Symbol"),o=e("./_arrayMap"),a=e("./isArray"),r=e("./isSymbol"),s=1/0,d=i?i.prototype:void 0,c=d?d.toString:void 0;function l(e){if("string"==typeof e)return e;if(a(e))return o(e,l)+"";if(r(e))return c?c.call(e):"";var t=e+"";return"0"==t&&1/e==-s?"-0":t}t.exports=l},{"./_Symbol":60,"./_arrayMap":69,"./isArray":243,"./isSymbol":256}],127:[function(e,t,n){function i(e){return function(t){return e(t)}}t.exports=i},{}],128:[function(e,t,n){var i=e("./_SetCache"),o=e("./_arrayIncludes"),a=e("./_arrayIncludesWith"),r=e("./_cacheHas"),s=e("./_createSet"),d=e("./_setToArray"),c=200;function l(e,t,n){var l=-1,u=o,p=e.length,f=!0,h=[],g=h;if(n)f=!1,u=a;else if(p>=c){var y=t?null:s(e);if(y)return d(y);f=!1,u=r,g=new i}else g=t?[]:h;e:for(;++l<p;){var m=e[l],v=t?t(m):m;if(m=n||0!==m?m:0,f&&v==v){for(var b=g.length;b--;)if(g[b]===v)continue e;t&&g.push(v),h.push(m)}else u(g,v,n)||(g!==h&&g.push(v),h.push(m))}return h}t.exports=l},{"./_SetCache":58,"./_arrayIncludes":66,"./_arrayIncludesWith":67,"./_cacheHas":131,"./_createSet":152,"./_setToArray":212}],129:[function(e,t,n){var i=e("./_arrayMap");function o(e,t){return i(t,(function(t){return e[t]}))}t.exports=o},{"./_arrayMap":69}],130:[function(e,t,n){function i(e,t,n){for(var i=-1,o=e.length,a=t.length,r={};++i<o;){var s=i<a?t[i]:void 0;n(r,e[i],s)}return r}t.exports=i},{}],131:[function(e,t,n){function i(e,t){return e.has(t)}t.exports=i},{}],132:[function(e,t,n){var i=e("./identity");function o(e){return"function"==typeof e?e:i}t.exports=o},{"./identity":241}],133:[function(e,t,n){var i=e("./isArray"),o=e("./_isKey"),a=e("./_stringToPath"),r=e("./toString");function s(e,t){return i(e)?e:o(e,t)?[e]:a(r(e))}t.exports=s},{"./_isKey":183,"./_stringToPath":222,"./isArray":243,"./toString":283}],134:[function(e,t,n){var i=e("./_Uint8Array");function o(e){var t=new e.constructor(e.byteLength);return new i(t).set(new i(e)),t}t.exports=o},{"./_Uint8Array":61}],135:[function(e,t,n){var i=e("./_root"),o="object"==typeof n&&n&&!n.nodeType&&n,a=o&&"object"==typeof t&&t&&!t.nodeType&&t,r=a&&a.exports===o?i.Buffer:void 0,s=r?r.allocUnsafe:void 0;function d(e,t){if(t)return e.slice();var n=e.length,i=s?s(n):new e.constructor(n);return e.copy(i),i}t.exports=d},{"./_root":208}],136:[function(e,t,n){var i=e("./_cloneArrayBuffer");function o(e,t){var n=t?i(e.buffer):e.buffer;return new e.constructor(n,e.byteOffset,e.byteLength)}t.exports=o},{"./_cloneArrayBuffer":134}],137:[function(e,t,n){var i=/\w*$/;function o(e){var t=new e.constructor(e.source,i.exec(e));return t.lastIndex=e.lastIndex,t}t.exports=o},{}],138:[function(e,t,n){var i=e("./_Symbol"),o=i?i.prototype:void 0,a=o?o.valueOf:void 0;function r(e){return a?Object(a.call(e)):{}}t.exports=r},{"./_Symbol":60}],139:[function(e,t,n){var i=e("./_cloneArrayBuffer");function o(e,t){var n=t?i(e.buffer):e.buffer;return new e.constructor(n,e.byteOffset,e.length)}t.exports=o},{"./_cloneArrayBuffer":134}],140:[function(e,t,n){var i=e("./isSymbol");function o(e,t){if(e!==t){var n=void 0!==e,o=null===e,a=e==e,r=i(e),s=void 0!==t,d=null===t,c=t==t,l=i(t);if(!d&&!l&&!r&&e>t||r&&s&&c&&!d&&!l||o&&s&&c||!n&&c||!a)return 1;if(!o&&!r&&!l&&e<t||l&&n&&a&&!o&&!r||d&&n&&a||!s&&a||!c)return-1}return 0}t.exports=o},{"./isSymbol":256}],141:[function(e,t,n){var i=e("./_compareAscending");function o(e,t,n){for(var o=-1,a=e.criteria,r=t.criteria,s=a.length,d=n.length;++o<s;){var c=i(a[o],r[o]);if(c)return o>=d?c:c*("desc"==n[o]?-1:1)}return e.index-t.index}t.exports=o},{"./_compareAscending":140}],142:[function(e,t,n){function i(e,t){var n=-1,i=e.length;for(t||(t=Array(i));++n<i;)t[n]=e[n];return t}t.exports=i},{}],143:[function(e,t,n){var i=e("./_assignValue"),o=e("./_baseAssignValue");function a(e,t,n,a){var r=!n;n||(n={});for(var s=-1,d=t.length;++s<d;){var c=t[s],l=a?a(n[c],e[c],c,n,e):void 0;void 0===l&&(l=e[c]),r?o(n,c,l):i(n,c,l)}return n}t.exports=a},{"./_assignValue":75,"./_baseAssignValue":79}],144:[function(e,t,n){var i=e("./_copyObject"),o=e("./_getSymbols");function a(e,t){return i(e,o(e),t)}t.exports=a},{"./_copyObject":143,"./_getSymbols":166}],145:[function(e,t,n){var i=e("./_copyObject"),o=e("./_getSymbolsIn");function a(e,t){return i(e,o(e),t)}t.exports=a},{"./_copyObject":143,"./_getSymbolsIn":167}],146:[function(e,t,n){var i=e("./_root")["__core-js_shared__"];t.exports=i},{"./_root":208}],147:[function(e,t,n){var i=e("./_baseRest"),o=e("./_isIterateeCall");function a(e){return i((function(t,n){var i=-1,a=n.length,r=a>1?n[a-1]:void 0,s=a>2?n[2]:void 0;for(r=e.length>3&&"function"==typeof r?(a--,r):void 0,s&&o(n[0],n[1],s)&&(r=a<3?void 0:r,a=1),t=Object(t);++i<a;){var d=n[i];d&&e(t,d,i,r)}return t}))}t.exports=a},{"./_baseRest":121,"./_isIterateeCall":182}],148:[function(e,t,n){var i=e("./isArrayLike");function o(e,t){return function(n,o){if(null==n)return n;if(!i(n))return e(n,o);for(var a=n.length,r=t?a:-1,s=Object(n);(t?r--:++r<a)&&!1!==o(s[r],r,s););return n}}t.exports=o},{"./isArrayLike":244}],149:[function(e,t,n){function i(e){return function(t,n,i){for(var o=-1,a=Object(t),r=i(t),s=r.length;s--;){var d=r[e?s:++o];if(!1===n(a[d],d,a))break}return t}}t.exports=i},{}],150:[function(e,t,n){var i=e("./_baseIteratee"),o=e("./isArrayLike"),a=e("./keys");function r(e){return function(t,n,r){var s=Object(t);if(!o(t)){var d=i(n,3);t=a(t),n=function(e){return d(s[e],e,s)}}var c=e(t,n,r);return c>-1?s[d?t[c]:c]:void 0}}t.exports=r},{"./_baseIteratee":105,"./isArrayLike":244,"./keys":259}],151:[function(e,t,n){var i=e("./_baseRange"),o=e("./_isIterateeCall"),a=e("./toFinite");function r(e){return function(t,n,r){return r&&"number"!=typeof r&&o(t,n,r)&&(n=r=void 0),t=a(t),void 0===n?(n=t,t=0):n=a(n),r=void 0===r?t<n?1:-1:a(r),i(t,n,r,e)}}t.exports=r},{"./_baseRange":119,"./_isIterateeCall":182,"./toFinite":279}],152:[function(e,t,n){var i=e("./_Set"),o=e("./noop"),a=e("./_setToArray"),r=1/0,s=i&&1/a(new i([,-0]))[1]==r?function(e){return new i(e)}:o;t.exports=s},{"./_Set":57,"./_setToArray":212,"./noop":269}],153:[function(e,t,n){var i=e("./_getNative"),o=function(){try{var e=i(Object,"defineProperty");return e({},"",{}),e}catch(e){}}();t.exports=o},{"./_getNative":163}],154:[function(e,t,n){var i=e("./_SetCache"),o=e("./_arraySome"),a=e("./_cacheHas"),r=1,s=2;function d(e,t,n,d,c,l){var u=n&r,p=e.length,f=t.length;if(p!=f&&!(u&&f>p))return!1;var h=l.get(e);if(h&&l.get(t))return h==t;var g=-1,y=!0,m=n&s?new i:void 0;for(l.set(e,t),l.set(t,e);++g<p;){var v=e[g],b=t[g];if(d)var _=u?d(b,v,g,t,e,l):d(v,b,g,e,t,l);if(void 0!==_){if(_)continue;y=!1;break}if(m){if(!o(t,(function(e,t){if(!a(m,t)&&(v===e||c(v,e,n,d,l)))return m.push(t)}))){y=!1;break}}else if(v!==b&&!c(v,b,n,d,l)){y=!1;break}}return l.delete(e),l.delete(t),y}t.exports=d},{"./_SetCache":58,"./_arraySome":72,"./_cacheHas":131}],155:[function(e,t,n){var i=e("./_Symbol"),o=e("./_Uint8Array"),a=e("./eq"),r=e("./_equalArrays"),s=e("./_mapToArray"),d=e("./_setToArray"),c=1,l=2,u="[object Boolean]",p="[object Date]",f="[object Error]",h="[object Map]",g="[object Number]",y="[object RegExp]",m="[object Set]",v="[object String]",b="[object Symbol]",_="[object ArrayBuffer]",k="[object DataView]",P=i?i.prototype:void 0,I=P?P.valueOf:void 0;function N(e,t,n,i,P,N,S){switch(n){case k:if(e.byteLength!=t.byteLength||e.byteOffset!=t.byteOffset)return!1;e=e.buffer,t=t.buffer;case _:return!(e.byteLength!=t.byteLength||!N(new o(e),new o(t)));case u:case p:case g:return a(+e,+t);case f:return e.name==t.name&&e.message==t.message;case y:case v:return e==t+"";case h:var E=s;case m:var j=i&c;if(E||(E=d),e.size!=t.size&&!j)return!1;var w=S.get(e);if(w)return w==t;i|=l,S.set(e,t);var O=r(E(e),E(t),i,P,N,S);return S.delete(e),O;case b:if(I)return I.call(e)==I.call(t)}return!1}t.exports=N},{"./_Symbol":60,"./_Uint8Array":61,"./_equalArrays":154,"./_mapToArray":198,"./_setToArray":212,"./eq":231}],156:[function(e,t,n){var i=e("./_getAllKeys"),o=1,a=Object.prototype.hasOwnProperty;function r(e,t,n,r,s,d){var c=n&o,l=i(e),u=l.length;if(u!=i(t).length&&!c)return!1;for(var p=u;p--;){var f=l[p];if(!(c?f in t:a.call(t,f)))return!1}var h=d.get(e);if(h&&d.get(t))return h==t;var g=!0;d.set(e,t),d.set(t,e);for(var y=c;++p<u;){var m=e[f=l[p]],v=t[f];if(r)var b=c?r(v,m,f,t,e,d):r(m,v,f,e,t,d);if(!(void 0===b?m===v||s(m,v,n,r,d):b)){g=!1;break}y||(y="constructor"==f)}if(g&&!y){var _=e.constructor,k=t.constructor;_==k||!("constructor"in e)||!("constructor"in t)||"function"==typeof _&&_ instanceof _&&"function"==typeof k&&k instanceof k||(g=!1)}return d.delete(e),d.delete(t),g}t.exports=r},{"./_getAllKeys":159}],157:[function(e,t,n){var i=e("./flatten"),o=e("./_overRest"),a=e("./_setToString");function r(e){return a(o(e,void 0,i),e+"")}t.exports=r},{"./_overRest":207,"./_setToString":213,"./flatten":235}],158:[function(e,t,n){(function(e){var n="object"==typeof e&&e&&e.Object===Object&&e;t.exports=n}).call(this,void 0!==_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.a4?_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.a4:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{}],159:[function(e,t,n){var i=e("./_baseGetAllKeys"),o=e("./_getSymbols"),a=e("./keys");function r(e){return i(e,a,o)}t.exports=r},{"./_baseGetAllKeys":90,"./_getSymbols":166,"./keys":259}],160:[function(e,t,n){var i=e("./_baseGetAllKeys"),o=e("./_getSymbolsIn"),a=e("./keysIn");function r(e){return i(e,a,o)}t.exports=r},{"./_baseGetAllKeys":90,"./_getSymbolsIn":167,"./keysIn":260}],161:[function(e,t,n){var i=e("./_isKeyable");function o(e,t){var n=e.__data__;return i(t)?n["string"==typeof t?"string":"hash"]:n.map}t.exports=o},{"./_isKeyable":184}],162:[function(e,t,n){var i=e("./_isStrictComparable"),o=e("./keys");function a(e){for(var t=o(e),n=t.length;n--;){var a=t[n],r=e[a];t[n]=[a,r,i(r)]}return t}t.exports=a},{"./_isStrictComparable":187,"./keys":259}],163:[function(e,t,n){var i=e("./_baseIsNative"),o=e("./_getValue");function a(e,t){var n=o(e,t);return i(n)?n:void 0}t.exports=a},{"./_baseIsNative":102,"./_getValue":169}],164:[function(e,t,n){var i=e("./_overArg")(Object.getPrototypeOf,Object);t.exports=i},{"./_overArg":206}],165:[function(e,t,n){var i=e("./_Symbol"),o=Object.prototype,a=o.hasOwnProperty,r=o.toString,s=i?i.toStringTag:void 0;function d(e){var t=a.call(e,s),n=e[s];try{e[s]=void 0;var i=!0}catch(e){}var o=r.call(e);return i&&(t?e[s]=n:delete e[s]),o}t.exports=d},{"./_Symbol":60}],166:[function(e,t,n){var i=e("./_arrayFilter"),o=e("./stubArray"),a=Object.prototype.propertyIsEnumerable,r=Object.getOwnPropertySymbols,s=r?function(e){return null==e?[]:(e=Object(e),i(r(e),(function(t){return a.call(e,t)})))}:o;t.exports=s},{"./_arrayFilter":65,"./stubArray":277}],167:[function(e,t,n){var i=e("./_arrayPush"),o=e("./_getPrototype"),a=e("./_getSymbols"),r=e("./stubArray"),s=Object.getOwnPropertySymbols?function(e){for(var t=[];e;)i(t,a(e)),e=o(e);return t}:r;t.exports=s},{"./_arrayPush":70,"./_getPrototype":164,"./_getSymbols":166,"./stubArray":277}],168:[function(e,t,n){var i=e("./_DataView"),o=e("./_Map"),a=e("./_Promise"),r=e("./_Set"),s=e("./_WeakMap"),d=e("./_baseGetTag"),c=e("./_toSource"),l="[object Map]",u="[object Object]",p="[object Promise]",f="[object Set]",h="[object WeakMap]",g="[object DataView]",y=c(i),m=c(o),v=c(a),b=c(r),_=c(s),k=d;(i&&k(new i(new ArrayBuffer(1)))!=g||o&&k(new o)!=l||a&&k(a.resolve())!=p||r&&k(new r)!=f||s&&k(new s)!=h)&&(k=function(e){var t=d(e),n=t==u?e.constructor:void 0,i=n?c(n):"";if(i)switch(i){case y:return g;case m:return l;case v:return p;case b:return f;case _:return h}return t}),t.exports=k},{"./_DataView":51,"./_Map":54,"./_Promise":56,"./_Set":57,"./_WeakMap":62,"./_baseGetTag":91,"./_toSource":224}],169:[function(e,t,n){function i(e,t){return null==e?void 0:e[t]}t.exports=i},{}],170:[function(e,t,n){var i=e("./_castPath"),o=e("./isArguments"),a=e("./isArray"),r=e("./_isIndex"),s=e("./isLength"),d=e("./_toKey");function c(e,t,n){for(var c=-1,l=(t=i(t,e)).length,u=!1;++c<l;){var p=d(t[c]);if(!(u=null!=e&&n(e,p)))break;e=e[p]}return u||++c!=l?u:!!(l=null==e?0:e.length)&&s(l)&&r(p,l)&&(a(e)||o(e))}t.exports=c},{"./_castPath":133,"./_isIndex":181,"./_toKey":223,"./isArguments":242,"./isArray":243,"./isLength":249}],171:[function(e,t,n){var i=RegExp("[\\u200d\\ud800-\\udfff\\u0300-\\u036f\\ufe20-\\ufe2f\\u20d0-\\u20ff\\ufe0e\\ufe0f]");function o(e){return i.test(e)}t.exports=o},{}],172:[function(e,t,n){var i=e("./_nativeCreate");function o(){this.__data__=i?i(null):{},this.size=0}t.exports=o},{"./_nativeCreate":201}],173:[function(e,t,n){function i(e){var t=this.has(e)&&delete this.__data__[e];return this.size-=t?1:0,t}t.exports=i},{}],174:[function(e,t,n){var i=e("./_nativeCreate"),o="__lodash_hash_undefined__",a=Object.prototype.hasOwnProperty;function r(e){var t=this.__data__;if(i){var n=t[e];return n===o?void 0:n}return a.call(t,e)?t[e]:void 0}t.exports=r},{"./_nativeCreate":201}],175:[function(e,t,n){var i=e("./_nativeCreate"),o=Object.prototype.hasOwnProperty;function a(e){var t=this.__data__;return i?void 0!==t[e]:o.call(t,e)}t.exports=a},{"./_nativeCreate":201}],176:[function(e,t,n){var i=e("./_nativeCreate"),o="__lodash_hash_undefined__";function a(e,t){var n=this.__data__;return this.size+=this.has(e)?0:1,n[e]=i&&void 0===t?o:t,this}t.exports=a},{"./_nativeCreate":201}],177:[function(e,t,n){var i=Object.prototype.hasOwnProperty;function o(e){var t=e.length,n=new e.constructor(t);return t&&"string"==typeof e[0]&&i.call(e,"index")&&(n.index=e.index,n.input=e.input),n}t.exports=o},{}],178:[function(e,t,n){var i=e("./_cloneArrayBuffer"),o=e("./_cloneDataView"),a=e("./_cloneRegExp"),r=e("./_cloneSymbol"),s=e("./_cloneTypedArray"),d="[object Boolean]",c="[object Date]",l="[object Map]",u="[object Number]",p="[object RegExp]",f="[object Set]",h="[object String]",g="[object Symbol]",y="[object ArrayBuffer]",m="[object DataView]",v="[object Float32Array]",b="[object Float64Array]",_="[object Int8Array]",k="[object Int16Array]",P="[object Int32Array]",I="[object Uint8Array]",N="[object Uint8ClampedArray]",S="[object Uint16Array]",E="[object Uint32Array]";function j(e,t,n){var j=e.constructor;switch(t){case y:return i(e);case d:case c:return new j(+e);case m:return o(e,n);case v:case b:case _:case k:case P:case I:case N:case S:case E:return s(e,n);case l:return new j;case u:case h:return new j(e);case p:return a(e);case f:return new j;case g:return r(e)}}t.exports=j},{"./_cloneArrayBuffer":134,"./_cloneDataView":136,"./_cloneRegExp":137,"./_cloneSymbol":138,"./_cloneTypedArray":139}],179:[function(e,t,n){var i=e("./_baseCreate"),o=e("./_getPrototype"),a=e("./_isPrototype");function r(e){return"function"!=typeof e.constructor||a(e)?{}:i(o(e))}t.exports=r},{"./_baseCreate":81,"./_getPrototype":164,"./_isPrototype":186}],180:[function(e,t,n){var i=e("./_Symbol"),o=e("./isArguments"),a=e("./isArray"),r=i?i.isConcatSpreadable:void 0;function s(e){return a(e)||o(e)||!!(r&&e&&e[r])}t.exports=s},{"./_Symbol":60,"./isArguments":242,"./isArray":243}],181:[function(e,t,n){var i=9007199254740991,o=/^(?:0|[1-9]\d*)$/;function a(e,t){var n=typeof e;return!!(t=null==t?i:t)&&("number"==n||"symbol"!=n&&o.test(e))&&e>-1&&e%1==0&&e<t}t.exports=a},{}],182:[function(e,t,n){var i=e("./eq"),o=e("./isArrayLike"),a=e("./_isIndex"),r=e("./isObject");function s(e,t,n){if(!r(n))return!1;var s=typeof t;return!!("number"==s?o(n)&&a(t,n.length):"string"==s&&t in n)&&i(n[t],e)}t.exports=s},{"./_isIndex":181,"./eq":231,"./isArrayLike":244,"./isObject":251}],183:[function(e,t,n){var i=e("./isArray"),o=e("./isSymbol"),a=/\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,r=/^\w*$/;function s(e,t){if(i(e))return!1;var n=typeof e;return!("number"!=n&&"symbol"!=n&&"boolean"!=n&&null!=e&&!o(e))||r.test(e)||!a.test(e)||null!=t&&e in Object(t)}t.exports=s},{"./isArray":243,"./isSymbol":256}],184:[function(e,t,n){function i(e){var t=typeof e;return"string"==t||"number"==t||"symbol"==t||"boolean"==t?"__proto__"!==e:null===e}t.exports=i},{}],185:[function(e,t,n){var i,o=e("./_coreJsData"),a=(i=/[^.]+$/.exec(o&&o.keys&&o.keys.IE_PROTO||""))?"Symbol(src)_1."+i:"";function r(e){return!!a&&a in e}t.exports=r},{"./_coreJsData":146}],186:[function(e,t,n){var i=Object.prototype;function o(e){var t=e&&e.constructor;return e===("function"==typeof t&&t.prototype||i)}t.exports=o},{}],187:[function(e,t,n){var i=e("./isObject");function o(e){return e==e&&!i(e)}t.exports=o},{"./isObject":251}],188:[function(e,t,n){function i(){this.__data__=[],this.size=0}t.exports=i},{}],189:[function(e,t,n){var i=e("./_assocIndexOf"),o=Array.prototype.splice;function a(e){var t=this.__data__,n=i(t,e);return!(n<0||(n==t.length-1?t.pop():o.call(t,n,1),--this.size,0))}t.exports=a},{"./_assocIndexOf":76}],190:[function(e,t,n){var i=e("./_assocIndexOf");function o(e){var t=this.__data__,n=i(t,e);return n<0?void 0:t[n][1]}t.exports=o},{"./_assocIndexOf":76}],191:[function(e,t,n){var i=e("./_assocIndexOf");function o(e){return i(this.__data__,e)>-1}t.exports=o},{"./_assocIndexOf":76}],192:[function(e,t,n){var i=e("./_assocIndexOf");function o(e,t){var n=this.__data__,o=i(n,e);return o<0?(++this.size,n.push([e,t])):n[o][1]=t,this}t.exports=o},{"./_assocIndexOf":76}],193:[function(e,t,n){var i=e("./_Hash"),o=e("./_ListCache"),a=e("./_Map");function r(){this.size=0,this.__data__={hash:new i,map:new(a||o),string:new i}}t.exports=r},{"./_Hash":52,"./_ListCache":53,"./_Map":54}],194:[function(e,t,n){var i=e("./_getMapData");function o(e){var t=i(this,e).delete(e);return this.size-=t?1:0,t}t.exports=o},{"./_getMapData":161}],195:[function(e,t,n){var i=e("./_getMapData");function o(e){return i(this,e).get(e)}t.exports=o},{"./_getMapData":161}],196:[function(e,t,n){var i=e("./_getMapData");function o(e){return i(this,e).has(e)}t.exports=o},{"./_getMapData":161}],197:[function(e,t,n){var i=e("./_getMapData");function o(e,t){var n=i(this,e),o=n.size;return n.set(e,t),this.size+=n.size==o?0:1,this}t.exports=o},{"./_getMapData":161}],198:[function(e,t,n){function i(e){var t=-1,n=Array(e.size);return e.forEach((function(e,i){n[++t]=[i,e]})),n}t.exports=i},{}],199:[function(e,t,n){function i(e,t){return function(n){return null!=n&&n[e]===t&&(void 0!==t||e in Object(n))}}t.exports=i},{}],200:[function(e,t,n){var i=e("./memoize"),o=500;function a(e){var t=i(e,(function(e){return n.size===o&&n.clear(),e})),n=t.cache;return t}t.exports=a},{"./memoize":265}],201:[function(e,t,n){var i=e("./_getNative")(Object,"create");t.exports=i},{"./_getNative":163}],202:[function(e,t,n){var i=e("./_overArg")(Object.keys,Object);t.exports=i},{"./_overArg":206}],203:[function(e,t,n){function i(e){var t=[];if(null!=e)for(var n in Object(e))t.push(n);return t}t.exports=i},{}],204:[function(e,t,n){var i=e("./_freeGlobal"),o="object"==typeof n&&n&&!n.nodeType&&n,a=o&&"object"==typeof t&&t&&!t.nodeType&&t,r=a&&a.exports===o&&i.process,s=function(){try{var e=a&&a.require&&a.require("util").types;return e||r&&r.binding&&r.binding("util")}catch(e){}}();t.exports=s},{"./_freeGlobal":158}],205:[function(e,t,n){var i=Object.prototype.toString;function o(e){return i.call(e)}t.exports=o},{}],206:[function(e,t,n){function i(e,t){return function(n){return e(t(n))}}t.exports=i},{}],207:[function(e,t,n){var i=e("./_apply"),o=Math.max;function a(e,t,n){return t=o(void 0===t?e.length-1:t,0),function(){for(var a=arguments,r=-1,s=o(a.length-t,0),d=Array(s);++r<s;)d[r]=a[t+r];r=-1;for(var c=Array(t+1);++r<t;)c[r]=a[r];return c[t]=n(d),i(e,this,c)}}t.exports=a},{"./_apply":63}],208:[function(e,t,n){var i=e("./_freeGlobal"),o="object"==typeof self&&self&&self.Object===Object&&self,a=i||o||Function("return this")();t.exports=a},{"./_freeGlobal":158}],209:[function(e,t,n){function i(e,t){if(("constructor"!==t||"function"!=typeof e[t])&&"__proto__"!=t)return e[t]}t.exports=i},{}],210:[function(e,t,n){var i="__lodash_hash_undefined__";function o(e){return this.__data__.set(e,i),this}t.exports=o},{}],211:[function(e,t,n){function i(e){return this.__data__.has(e)}t.exports=i},{}],212:[function(e,t,n){function i(e){var t=-1,n=Array(e.size);return e.forEach((function(e){n[++t]=e})),n}t.exports=i},{}],213:[function(e,t,n){var i=e("./_baseSetToString"),o=e("./_shortOut")(i);t.exports=o},{"./_baseSetToString":123,"./_shortOut":214}],214:[function(e,t,n){var i=800,o=16,a=Date.now;function r(e){var t=0,n=0;return function(){var r=a(),s=o-(r-n);if(n=r,s>0){if(++t>=i)return arguments[0]}else t=0;return e.apply(void 0,arguments)}}t.exports=r},{}],215:[function(e,t,n){var i=e("./_ListCache");function o(){this.__data__=new i,this.size=0}t.exports=o},{"./_ListCache":53}],216:[function(e,t,n){function i(e){var t=this.__data__,n=t.delete(e);return this.size=t.size,n}t.exports=i},{}],217:[function(e,t,n){function i(e){return this.__data__.get(e)}t.exports=i},{}],218:[function(e,t,n){function i(e){return this.__data__.has(e)}t.exports=i},{}],219:[function(e,t,n){var i=e("./_ListCache"),o=e("./_Map"),a=e("./_MapCache"),r=200;function s(e,t){var n=this.__data__;if(n instanceof i){var s=n.__data__;if(!o||s.length<r-1)return s.push([e,t]),this.size=++n.size,this;n=this.__data__=new a(s)}return n.set(e,t),this.size=n.size,this}t.exports=s},{"./_ListCache":53,"./_Map":54,"./_MapCache":55}],220:[function(e,t,n){function i(e,t,n){for(var i=n-1,o=e.length;++i<o;)if(e[i]===t)return i;return-1}t.exports=i},{}],221:[function(e,t,n){var i=e("./_asciiSize"),o=e("./_hasUnicode"),a=e("./_unicodeSize");function r(e){return o(e)?a(e):i(e)}t.exports=r},{"./_asciiSize":73,"./_hasUnicode":171,"./_unicodeSize":225}],222:[function(e,t,n){var i=e("./_memoizeCapped"),o=/[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g,a=/\\(\\)?/g,r=i((function(e){var t=[];return 46===e.charCodeAt(0)&&t.push(""),e.replace(o,(function(e,n,i,o){t.push(i?o.replace(a,"$1"):n||e)})),t}));t.exports=r},{"./_memoizeCapped":200}],223:[function(e,t,n){var i=e("./isSymbol"),o=1/0;function a(e){if("string"==typeof e||i(e))return e;var t=e+"";return"0"==t&&1/e==-o?"-0":t}t.exports=a},{"./isSymbol":256}],224:[function(e,t,n){var i=Function.prototype.toString;function o(e){if(null!=e){try{return i.call(e)}catch(e){}try{return e+""}catch(e){}}return""}t.exports=o},{}],225:[function(e,t,n){var i="\\ud800-\\udfff",o="["+i+"]",a="[\\u0300-\\u036f\\ufe20-\\ufe2f\\u20d0-\\u20ff]",r="\\ud83c[\\udffb-\\udfff]",s="[^"+i+"]",d="(?:\\ud83c[\\udde6-\\uddff]){2}",c="[\\ud800-\\udbff][\\udc00-\\udfff]",l="(?:"+a+"|"+r+")?",u="[\\ufe0e\\ufe0f]?",p=u+l+"(?:\\u200d(?:"+[s,d,c].join("|")+")"+u+l+")*",f="(?:"+[s+a+"?",a,d,c,o].join("|")+")",h=RegExp(r+"(?="+r+")|"+f+p,"g");function g(e){for(var t=h.lastIndex=0;h.test(e);)++t;return t}t.exports=g},{}],226:[function(e,t,n){var i=e("./_baseClone"),o=4;function a(e){return i(e,o)}t.exports=a},{"./_baseClone":80}],227:[function(e,t,n){var i=e("./_baseClone"),o=1,a=4;function r(e){return i(e,o|a)}t.exports=r},{"./_baseClone":80}],228:[function(e,t,n){function i(e){return function(){return e}}t.exports=i},{}],229:[function(e,t,n){var i=e("./_baseRest"),o=e("./eq"),a=e("./_isIterateeCall"),r=e("./keysIn"),s=Object.prototype,d=s.hasOwnProperty,c=i((function(e,t){e=Object(e);var n=-1,i=t.length,c=i>2?t[2]:void 0;for(c&&a(t[0],t[1],c)&&(i=1);++n<i;)for(var l=t[n],u=r(l),p=-1,f=u.length;++p<f;){var h=u[p],g=e[h];(void 0===g||o(g,s[h])&&!d.call(e,h))&&(e[h]=l[h])}return e}));t.exports=c},{"./_baseRest":121,"./_isIterateeCall":182,"./eq":231,"./keysIn":260}],230:[function(e,t,n){t.exports=e("./forEach")},{"./forEach":236}],231:[function(e,t,n){function i(e,t){return e===t||e!=e&&t!=t}t.exports=i},{}],232:[function(e,t,n){var i=e("./_arrayFilter"),o=e("./_baseFilter"),a=e("./_baseIteratee"),r=e("./isArray");function s(e,t){return(r(e)?i:o)(e,a(t,3))}t.exports=s},{"./_arrayFilter":65,"./_baseFilter":84,"./_baseIteratee":105,"./isArray":243}],233:[function(e,t,n){var i=e("./_createFind")(e("./findIndex"));t.exports=i},{"./_createFind":150,"./findIndex":234}],234:[function(e,t,n){var i=e("./_baseFindIndex"),o=e("./_baseIteratee"),a=e("./toInteger"),r=Math.max;function s(e,t,n){var s=null==e?0:e.length;if(!s)return-1;var d=null==n?0:a(n);return d<0&&(d=r(s+d,0)),i(e,o(t,3),d)}t.exports=s},{"./_baseFindIndex":85,"./_baseIteratee":105,"./toInteger":280}],235:[function(e,t,n){var i=e("./_baseFlatten");function o(e){return null!=e&&e.length?i(e,1):[]}t.exports=o},{"./_baseFlatten":86}],236:[function(e,t,n){var i=e("./_arrayEach"),o=e("./_baseEach"),a=e("./_castFunction"),r=e("./isArray");function s(e,t){return(r(e)?i:o)(e,a(t))}t.exports=s},{"./_arrayEach":64,"./_baseEach":82,"./_castFunction":132,"./isArray":243}],237:[function(e,t,n){var i=e("./_baseFor"),o=e("./_castFunction"),a=e("./keysIn");function r(e,t){return null==e?e:i(e,o(t),a)}t.exports=r},{"./_baseFor":87,"./_castFunction":132,"./keysIn":260}],238:[function(e,t,n){var i=e("./_baseGet");function o(e,t,n){var o=null==e?void 0:i(e,t);return void 0===o?n:o}t.exports=o},{"./_baseGet":89}],239:[function(e,t,n){var i=e("./_baseHas"),o=e("./_hasPath");function a(e,t){return null!=e&&o(e,t,i)}t.exports=a},{"./_baseHas":93,"./_hasPath":170}],240:[function(e,t,n){var i=e("./_baseHasIn"),o=e("./_hasPath");function a(e,t){return null!=e&&o(e,t,i)}t.exports=a},{"./_baseHasIn":94,"./_hasPath":170}],241:[function(e,t,n){function i(e){return e}t.exports=i},{}],242:[function(e,t,n){var i=e("./_baseIsArguments"),o=e("./isObjectLike"),a=Object.prototype,r=a.hasOwnProperty,s=a.propertyIsEnumerable,d=i(function(){return arguments}())?i:function(e){return o(e)&&r.call(e,"callee")&&!s.call(e,"callee")};t.exports=d},{"./_baseIsArguments":96,"./isObjectLike":252}],243:[function(e,t,n){var i=Array.isArray;t.exports=i},{}],244:[function(e,t,n){var i=e("./isFunction"),o=e("./isLength");function a(e){return null!=e&&o(e.length)&&!i(e)}t.exports=a},{"./isFunction":248,"./isLength":249}],245:[function(e,t,n){var i=e("./isArrayLike"),o=e("./isObjectLike");function a(e){return o(e)&&i(e)}t.exports=a},{"./isArrayLike":244,"./isObjectLike":252}],246:[function(e,t,n){var i=e("./_root"),o=e("./stubFalse"),a="object"==typeof n&&n&&!n.nodeType&&n,r=a&&"object"==typeof t&&t&&!t.nodeType&&t,s=r&&r.exports===a?i.Buffer:void 0,d=(s?s.isBuffer:void 0)||o;t.exports=d},{"./_root":208,"./stubFalse":278}],247:[function(e,t,n){var i=e("./_baseKeys"),o=e("./_getTag"),a=e("./isArguments"),r=e("./isArray"),s=e("./isArrayLike"),d=e("./isBuffer"),c=e("./_isPrototype"),l=e("./isTypedArray"),u="[object Map]",p="[object Set]",f=Object.prototype.hasOwnProperty;function h(e){if(null==e)return!0;if(s(e)&&(r(e)||"string"==typeof e||"function"==typeof e.splice||d(e)||l(e)||a(e)))return!e.length;var t=o(e);if(t==u||t==p)return!e.size;if(c(e))return!i(e).length;for(var n in e)if(f.call(e,n))return!1;return!0}t.exports=h},{"./_baseKeys":106,"./_getTag":168,"./_isPrototype":186,"./isArguments":242,"./isArray":243,"./isArrayLike":244,"./isBuffer":246,"./isTypedArray":257}],248:[function(e,t,n){var i=e("./_baseGetTag"),o=e("./isObject"),a="[object AsyncFunction]",r="[object Function]",s="[object GeneratorFunction]",d="[object Proxy]";function c(e){if(!o(e))return!1;var t=i(e);return t==r||t==s||t==a||t==d}t.exports=c},{"./_baseGetTag":91,"./isObject":251}],249:[function(e,t,n){var i=9007199254740991;function o(e){return"number"==typeof e&&e>-1&&e%1==0&&e<=i}t.exports=o},{}],250:[function(e,t,n){var i=e("./_baseIsMap"),o=e("./_baseUnary"),a=e("./_nodeUtil"),r=a&&a.isMap,s=r?o(r):i;t.exports=s},{"./_baseIsMap":99,"./_baseUnary":127,"./_nodeUtil":204}],251:[function(e,t,n){function i(e){var t=typeof e;return null!=e&&("object"==t||"function"==t)}t.exports=i},{}],252:[function(e,t,n){function i(e){return null!=e&&"object"==typeof e}t.exports=i},{}],253:[function(e,t,n){var i=e("./_baseGetTag"),o=e("./_getPrototype"),a=e("./isObjectLike"),r="[object Object]",s=Function.prototype,d=Object.prototype,c=s.toString,l=d.hasOwnProperty,u=c.call(Object);function p(e){if(!a(e)||i(e)!=r)return!1;var t=o(e);if(null===t)return!0;var n=l.call(t,"constructor")&&t.constructor;return"function"==typeof n&&n instanceof n&&c.call(n)==u}t.exports=p},{"./_baseGetTag":91,"./_getPrototype":164,"./isObjectLike":252}],254:[function(e,t,n){var i=e("./_baseIsSet"),o=e("./_baseUnary"),a=e("./_nodeUtil"),r=a&&a.isSet,s=r?o(r):i;t.exports=s},{"./_baseIsSet":103,"./_baseUnary":127,"./_nodeUtil":204}],255:[function(e,t,n){var i=e("./_baseGetTag"),o=e("./isArray"),a=e("./isObjectLike"),r="[object String]";function s(e){return"string"==typeof e||!o(e)&&a(e)&&i(e)==r}t.exports=s},{"./_baseGetTag":91,"./isArray":243,"./isObjectLike":252}],256:[function(e,t,n){var i=e("./_baseGetTag"),o=e("./isObjectLike"),a="[object Symbol]";function r(e){return"symbol"==typeof e||o(e)&&i(e)==a}t.exports=r},{"./_baseGetTag":91,"./isObjectLike":252}],257:[function(e,t,n){var i=e("./_baseIsTypedArray"),o=e("./_baseUnary"),a=e("./_nodeUtil"),r=a&&a.isTypedArray,s=r?o(r):i;t.exports=s},{"./_baseIsTypedArray":104,"./_baseUnary":127,"./_nodeUtil":204}],258:[function(e,t,n){function i(e){return void 0===e}t.exports=i},{}],259:[function(e,t,n){var i=e("./_arrayLikeKeys"),o=e("./_baseKeys"),a=e("./isArrayLike");function r(e){return a(e)?i(e):o(e)}t.exports=r},{"./_arrayLikeKeys":68,"./_baseKeys":106,"./isArrayLike":244}],260:[function(e,t,n){var i=e("./_arrayLikeKeys"),o=e("./_baseKeysIn"),a=e("./isArrayLike");function r(e){return a(e)?i(e,!0):o(e)}t.exports=r},{"./_arrayLikeKeys":68,"./_baseKeysIn":107,"./isArrayLike":244}],261:[function(e,t,n){function i(e){var t=null==e?0:e.length;return t?e[t-1]:void 0}t.exports=i},{}],262:[function(e,t,n){var i=e("./_arrayMap"),o=e("./_baseIteratee"),a=e("./_baseMap"),r=e("./isArray");function s(e,t){return(r(e)?i:a)(e,o(t,3))}t.exports=s},{"./_arrayMap":69,"./_baseIteratee":105,"./_baseMap":109,"./isArray":243}],263:[function(e,t,n){var i=e("./_baseAssignValue"),o=e("./_baseForOwn"),a=e("./_baseIteratee");function r(e,t){var n={};return t=a(t,3),o(e,(function(e,o,a){i(n,o,t(e,o,a))})),n}t.exports=r},{"./_baseAssignValue":79,"./_baseForOwn":88,"./_baseIteratee":105}],264:[function(e,t,n){var i=e("./_baseExtremum"),o=e("./_baseGt"),a=e("./identity");function r(e){return e&&e.length?i(e,a,o):void 0}t.exports=r},{"./_baseExtremum":83,"./_baseGt":92,"./identity":241}],265:[function(e,t,n){var i=e("./_MapCache"),o="Expected a function";function a(e,t){if("function"!=typeof e||null!=t&&"function"!=typeof t)throw new TypeError(o);var n=function(){var i=arguments,o=t?t.apply(this,i):i[0],a=n.cache;if(a.has(o))return a.get(o);var r=e.apply(this,i);return n.cache=a.set(o,r)||a,r};return n.cache=new(a.Cache||i),n}a.Cache=i,t.exports=a},{"./_MapCache":55}],266:[function(e,t,n){var i=e("./_baseMerge"),o=e("./_createAssigner")((function(e,t,n){i(e,t,n)}));t.exports=o},{"./_baseMerge":112,"./_createAssigner":147}],267:[function(e,t,n){var i=e("./_baseExtremum"),o=e("./_baseLt"),a=e("./identity");function r(e){return e&&e.length?i(e,a,o):void 0}t.exports=r},{"./_baseExtremum":83,"./_baseLt":108,"./identity":241}],268:[function(e,t,n){var i=e("./_baseExtremum"),o=e("./_baseIteratee"),a=e("./_baseLt");function r(e,t){return e&&e.length?i(e,o(t,2),a):void 0}t.exports=r},{"./_baseExtremum":83,"./_baseIteratee":105,"./_baseLt":108}],269:[function(e,t,n){function i(){}t.exports=i},{}],270:[function(e,t,n){var i=e("./_root"),o=function(){return i.Date.now()};t.exports=o},{"./_root":208}],271:[function(e,t,n){var i=e("./_basePick"),o=e("./_flatRest")((function(e,t){return null==e?{}:i(e,t)}));t.exports=o},{"./_basePick":115,"./_flatRest":157}],272:[function(e,t,n){var i=e("./_baseProperty"),o=e("./_basePropertyDeep"),a=e("./_isKey"),r=e("./_toKey");function s(e){return a(e)?i(r(e)):o(e)}t.exports=s},{"./_baseProperty":117,"./_basePropertyDeep":118,"./_isKey":183,"./_toKey":223}],273:[function(e,t,n){var i=e("./_createRange")();t.exports=i},{"./_createRange":151}],274:[function(e,t,n){var i=e("./_arrayReduce"),o=e("./_baseEach"),a=e("./_baseIteratee"),r=e("./_baseReduce"),s=e("./isArray");function d(e,t,n){var d=s(e)?i:r,c=arguments.length<3;return d(e,a(t,4),n,c,o)}t.exports=d},{"./_arrayReduce":71,"./_baseEach":82,"./_baseIteratee":105,"./_baseReduce":120,"./isArray":243}],275:[function(e,t,n){var i=e("./_baseKeys"),o=e("./_getTag"),a=e("./isArrayLike"),r=e("./isString"),s=e("./_stringSize"),d="[object Map]",c="[object Set]";function l(e){if(null==e)return 0;if(a(e))return r(e)?s(e):e.length;var t=o(e);return t==d||t==c?e.size:i(e).length}t.exports=l},{"./_baseKeys":106,"./_getTag":168,"./_stringSize":221,"./isArrayLike":244,"./isString":255}],276:[function(e,t,n){var i=e("./_baseFlatten"),o=e("./_baseOrderBy"),a=e("./_baseRest"),r=e("./_isIterateeCall"),s=a((function(e,t){if(null==e)return[];var n=t.length;return n>1&&r(e,t[0],t[1])?t=[]:n>2&&r(t[0],t[1],t[2])&&(t=[t[0]]),o(e,i(t,1),[])}));t.exports=s},{"./_baseFlatten":86,"./_baseOrderBy":114,"./_baseRest":121,"./_isIterateeCall":182}],277:[function(e,t,n){function i(){return[]}t.exports=i},{}],278:[function(e,t,n){function i(){return!1}t.exports=i},{}],279:[function(e,t,n){var i=e("./toNumber"),o=1/0,a=17976931348623157e292;function r(e){return e?(e=i(e))===o||e===-o?(e<0?-1:1)*a:e==e?e:0:0===e?e:0}t.exports=r},{"./toNumber":281}],280:[function(e,t,n){var i=e("./toFinite");function o(e){var t=i(e),n=t%1;return t==t?n?t-n:t:0}t.exports=o},{"./toFinite":279}],281:[function(e,t,n){var i=e("./isObject"),o=e("./isSymbol"),a=NaN,r=/^\s+|\s+$/g,s=/^[-+]0x[0-9a-f]+$/i,d=/^0b[01]+$/i,c=/^0o[0-7]+$/i,l=parseInt;function u(e){if("number"==typeof e)return e;if(o(e))return a;if(i(e)){var t="function"==typeof e.valueOf?e.valueOf():e;e=i(t)?t+"":t}if("string"!=typeof e)return 0===e?e:+e;e=e.replace(r,"");var n=d.test(e);return n||c.test(e)?l(e.slice(2),n?2:8):s.test(e)?a:+e}t.exports=u},{"./isObject":251,"./isSymbol":256}],282:[function(e,t,n){var i=e("./_copyObject"),o=e("./keysIn");function a(e){return i(e,o(e))}t.exports=a},{"./_copyObject":143,"./keysIn":260}],283:[function(e,t,n){var i=e("./_baseToString");function o(e){return null==e?"":i(e)}t.exports=o},{"./_baseToString":126}],284:[function(e,t,n){var i=e("./_arrayEach"),o=e("./_baseCreate"),a=e("./_baseForOwn"),r=e("./_baseIteratee"),s=e("./_getPrototype"),d=e("./isArray"),c=e("./isBuffer"),l=e("./isFunction"),u=e("./isObject"),p=e("./isTypedArray");function f(e,t,n){var f=d(e),h=f||c(e)||p(e);if(t=r(t,4),null==n){var g=e&&e.constructor;n=h?f?new g:[]:u(e)&&l(g)?o(s(e)):{}}return(h?i:a)(e,(function(e,i,o){return t(n,e,i,o)})),n}t.exports=f},{"./_arrayEach":64,"./_baseCreate":81,"./_baseForOwn":88,"./_baseIteratee":105,"./_getPrototype":164,"./isArray":243,"./isBuffer":246,"./isFunction":248,"./isObject":251,"./isTypedArray":257}],285:[function(e,t,n){var i=e("./_baseFlatten"),o=e("./_baseRest"),a=e("./_baseUniq"),r=e("./isArrayLikeObject"),s=o((function(e){return a(i(e,1,r,!0))}));t.exports=s},{"./_baseFlatten":86,"./_baseRest":121,"./_baseUniq":128,"./isArrayLikeObject":245}],286:[function(e,t,n){var i=e("./toString"),o=0;function a(e){var t=++o;return i(e)+t}t.exports=a},{"./toString":283}],287:[function(e,t,n){var i=e("./_baseValues"),o=e("./keys");function a(e){return null==e?[]:i(e,o(e))}t.exports=a},{"./_baseValues":129,"./keys":259}],288:[function(e,t,n){var i=e("./_assignValue"),o=e("./_baseZipObject");function a(e,t){return o(e||[],t||[],i)}t.exports=a},{"./_assignValue":75,"./_baseZipObject":130}]},{},[1])(1);function Rn(e,t){var n="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!n){if(Array.isArray(e)||(n=function(e,t){if(!e)return;if("string"==typeof e)return Un(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);"Object"===n&&e.constructor&&(n=e.constructor.name);if("Map"===n||"Set"===n)return Array.from(e);if("Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return Un(e,t)}(e))||t&&e&&"number"==typeof e.length){n&&(e=n);var i=0,o=function(){};return{s:o,n:function(){return i>=e.length?{done:!0}:{done:!1,value:e[i++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var a,r=!0,s=!1;return{s:function(){n=n.call(e)},n:function(){var e=n.next();return r=e.done,e},e:function(e){s=!0,a=e},f:function(){try{r||null==n.return||n.return()}finally{if(s)throw a}}}}function Un(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,i=new Array(t);n<t;n++)i[n]=e[n];return i}var Fn=function(){function i(e,n){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,i),this.pipelineId=e,this.objectModel=n,this.store=n.store}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(i,[{key:"getPipeline",value:function(){return this.objectModel.getCanvasInfoPipeline(this.pipelineId)}},{key:"isPipelineExternal",value:function(){return this.objectModel.getCanvasInfoPipeline(this.pipelineId).parentUrl}},{key:"getObjects",value:function(){var e=this.objectModel.getCanvasInfoPipeline(this.pipelineId);return e?e.nodes.concat(e.comments):[]}},{key:"moveObjects",value:function(e){this.store.dispatch({type:"MOVE_OBJECTS",data:e,pipelineId:this.pipelineId})}},{key:"deleteObject",value:function(e){this.deleteObjects([e])}},{key:"deleteObjects",value:function(e){var t=this;this.objectModel.executeWithSelectionChange((function(e){var n=t.filterNodesAndComments(e),i=n.nodes,o=n.comments;t.deleteNodesInternal(i),t.deleteCommentsInternal(o)}),e)}},{key:"addAndUpdateObjects",value:function(e){var t=this;this.objectModel.executeWithSelectionChange((function(e){t.store.dispatch({type:"ADD_AND_UPDATE_OBJECTS",data:e,pipelineId:t.pipelineId})}),e)}},{key:"deleteAndUpdateObjects",value:function(e){var t=this;this.objectModel.executeWithSelectionChange((function(e){t.store.dispatch({type:"DELETE_AND_UPDATE_OBJECTS",data:e,pipelineId:t.pipelineId})}),e)}},{key:"addPastedObjects",value:function(e){var t=this;this.objectModel.executeWithSelectionChange((function(e){t.store.dispatch({type:"ADD_PASTED_OBJECTS",data:e,pipelineId:t.pipelineId})}),e)}},{key:"deletePastedObjects",value:function(e){var t=this;this.objectModel.executeWithSelectionChange((function(e){t.store.dispatch({type:"DELETE_PASTED_OBJECTS",data:e,pipelineId:t.pipelineId})}),e)}},{key:"filterNodesAndComments",value:function(e){var t=this,n=[],i=[];return e.forEach((function(e){var o=t.getComment(e);o?i.push(o):n.push(t.getNode(e))})),{nodes:n,comments:i}}},{key:"getObjectStyle",value:function(e,t){var n=this.getObject(e);return t?n&&n.style_temp?n.style_temp:null:n&&n.style?n.style:null}},{key:"setObjectsClassName",value:function(e,t){this.store.dispatch({type:"SET_OBJECTS_CLASS_NAME",data:{objIds:e,newClassName:t},pipelineId:this.pipelineId})}},{key:"setObjectsColorClassName",value:function(e,t){this.store.dispatch({type:"SET_OBJECTS_COLOR_CLASS_NAME",data:{objIds:e,newColorClass:t},pipelineId:this.pipelineId})}},{key:"disconnectObjects",value:function(e){var t=this,n=[];return e.forEach((function(e){t.getLinksContainingId(e).forEach((function(e){n=t.pushUniqueLinks(e,n)}))})),this.store.dispatch({type:"DELETE_LINKS",data:{linksToDelete:n},pipelineId:this.pipelineId}),n}},{key:"isEmpty",value:function(){return!!(this.getNodes()&&0===this.getNodes().length&&this.getComments()&&0===this.getComments().length&&this.getLinks()&&0===this.getLinks().length)}},{key:"getObject",value:function(e){var t=this.getNode(e);if(t)return t;var n=this.getComment(e);return n||null}},{key:"exactlyOverlaps",value:function(e,t,n){var i=this,o=!1;e&&e.length>0&&(e.findIndex((function(e){return i.exactlyOverlapsNodes(e)}))>-1&&(o=!0));!1===o&&t&&t.length>0&&(t.findIndex((function(e){return i.exactlyOverlapsComments(e)}))>-1&&(o=!0));!1===o&&n&&n.length>0&&(n.findIndex((function(e){return i.exactlyOverlapsLinks(e)}))>-1&&(o=!0));return o}},{key:"exactlyOverlapsNodes",value:function(e){var t=!1;return this.getNodes().forEach((function(n){n.x_pos===e.x_pos&&n.y_pos===e.y_pos&&(t=!0)})),t}},{key:"overlapsNodes",value:function(e,t){var n=!1;return(t||this.getNodes()).forEach((function(t){var i=t.x_pos+t.width,o=t.y_pos+t.height;e.id!==t.id&&(e.x_pos===t.x_pos&&e.y_pos===t.y_pos||e.x_pos>=t.x_pos&&e.x_pos<=i&&e.y_pos>=t.y_pos&&e.y_pos<=o||e.x_pos+e.width>t.x_pos&&e.x_pos+e.width<i&&e.y_pos>t.y_pos&&e.y_pos<o||e.x_pos>t.x_pos&&e.x_pos<i&&e.y_pos+e.height>t.y_pos&&e.y_pos+e.height<o||e.x_pos+e.width>t.x_pos&&e.x_pos+e.width<i&&e.y_pos+e.height>t.y_pos&&e.y_pos+e.height<o)&&(n=!0)})),n}},{key:"exactlyOverlapsComments",value:function(e){var t=!1;return this.getComments().forEach((function(n){n.x_pos===e.x_pos&&n.y_pos===e.y_pos&&(t=!0)})),t}},{key:"exactlyOverlapsLinks",value:function(e){var t=!1;return this.getLinks().forEach((function(n){n.srcPos&&e.srcPos&&n.srcPos.x_pos===e.srcPos.x_pos&&n.srcPos.y_pos===e.srcPos.y_pos&&(t=!0),n.trgPos&&e.trgPos&&n.trgPos.x_pos===e.trgPos.x_pos&&n.trgPos.y_pos===e.trgPos.y_pos&&(t=!0)})),t}},{key:"isObjectIdInObjects",value:function(e,t){return!!t&&t.findIndex((function(t){return t.id===e}))>-1}},{key:"createNode",value:function(e){var t=e.nodeTemplate;(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e.nodeTemplate,"app_data.ui_data")&&(t=this.objectModel.convertNodeTemplate(t));var n={};return null!==t&&(n=Object.assign({},t,{id:this.objectModel.getUniqueId(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aw,{nodeType:t,pipelineId:this.pipelineId}),x_pos:e.offsetX,y_pos:e.offsetY}),n=this.objectModel.setNodeAttributes(n)),n}},{key:"getAutoSourceNode",value:function(e){var t=null,n=this.objectModel.getSelectedNodes();if(1===n.length&&this.isViableAutoSourceNode(n[0]))t=n[0];else if(!e){var i=this.getNodes();if(i.length>0){var o=i[i.length-1];if(o.outputs)t=o;else if(i.length>1){var a=i[i.length-2];a.outputs&&(t=a)}}}return t}},{key:"isViableAutoSourceNode",value:function(e){return e.outputs&&e.outputs.length>0&&!$e.isSrcCardinalityAtMax(e.outputs[0].id,e,this.getLinks())}},{key:"createAutoNode",value:function(e,t){var n=this.objectModel.getCanvasLayout().autoLayoutInitialMarginX,i=this.objectModel.getCanvasLayout().autoLayoutInitialMarginY,o=this.objectModel.getCanvasLayout().autoLayoutHorizontalSpacing,a=this.objectModel.getCanvasLayout().autoLayoutVerticalSpacing,r=0,s=0;null===t?(r=n,s=i):(r=t.x_pos+t.width+o,s=t.y_pos),e.offsetX=r,e.offsetY=s;var d=this.createNode(e);this.getNodes().length>0&&this.isEntryBindingNode(d)&&(d.x_pos=n,d.y_pos+=d.height+a);for(var c=!0;c;)(c=this.isNodeOverlappingOthers(d))&&(d.y_pos+=d.height+a);return d}},{key:"createNodesForPalette",value:function(e){var t=this,n=[];return e.forEach((function(e){var i=t.getNode(e);i&&((i=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(i)).id=t.objectModel.getUUID(),i.x_pos=0,i.y_pos=0,(i=Cn.createSchemaNode(i,[])).type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai&&(i.app_data||(i.app_data={}),i.app_data.pipeline_data=t.objectModel.getSchemaPipelinesForSupernode(i)),n.push(i))})),n}},{key:"replaceNodes",value:function(e){this.store.dispatch({type:"REPLACE_NODES",data:e,pipelineId:this.pipelineId})}},{key:"isLinkNeededWithAutoNode",value:function(e,t){var n=!1;return e&&t&&e.inputs&&t.outputs&&1===e.inputs.length&&1===t.outputs.length&&!$e.isCardinalityAtMax(t.outputs[0].id,e.inputs[0].id,t,e,this.getLinks())&&(n=!0),n}},{key:"isEntryBindingNode",value:function(e){return!(e.type!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.av||e.inputs&&0!==e.inputs.length)}},{key:"isExitBindingNode",value:function(e){return!!(e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.av&&e.inputs&&e.inputs.length>0)}},{key:"isNodeOverlappingOthers",value:function(e){var t=this;return-1!==this.getNodes().findIndex((function(n){return t.isSourceOverlappingTarget(n,e)}))}},{key:"isSourceOverlappingTarget",value:function(e,t){var n=e.layout.nodeHighlightGap,i=t.layout.nodeHighlightGap;return e.x_pos+e.width+n>=t.x_pos-i&&t.x_pos+t.width+i>=e.x_pos-n&&e.y_pos+e.height+n>=t.y_pos-i&&t.y_pos+t.height+i>=e.y_pos-n}},{key:"addNode",value:function(e){e&&(e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai?this.addSupernode(e,(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.k)(e,"app_data.pipeline_data")):this.store.dispatch({type:"ADD_NODE",data:{newNode:e},pipelineId:this.pipelineId}))}},{key:"addSupernodes",value:function(e,t,n){this.store.dispatch({type:"ADD_SUPERNODES",data:{supernodesToAdd:e,pipelinesToAdd:t,extPipelineFlowsToAdd:n,pipelineId:this.pipelineId}})}},{key:"addSupernode",value:function(e,t){var n=this,i=this.objectModel.getCanvasInfo(),o=this.objectModel.getCanvasInfo().pipelines.concat(t||[]);o=o.map((function(t){if(t.id===n.pipelineId){var i=[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(t.nodes),[n.cloneSupernodeRemovePipelineData(e)]);return Object.assign({},t,{nodes:i})}return t}));var a=Object.assign({},i,{pipelines:o});this.objectModel.setCanvasInfo(a)}},{key:"cloneSupernodeRemovePipelineData",value:function(e){var t=Object.assign({},e);return t.app_data&&(t.app_data=Object.assign({},t.app_data),delete t.app_data.pipeline_data),t}},{key:"deleteNode",value:function(e){var t=this.getNode(e);t&&this.deleteNodes([t])}},{key:"deleteNodes",value:function(e){var t=this,n=!(arguments.length>1&&void 0!==arguments[1])||arguments[1];e&&e.length>0&&this.objectModel.executeWithSelectionChange((function(e){t.deleteNodesInternal(e.nodes,e.removePipelines)}),{nodes:e,removePipelines:n})}},{key:"deleteNodesInternal",value:function(e,t){var n=this;e.filter((function(e){return e.type!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai})).forEach((function(e){n.store.dispatch({type:"DELETE_OBJECT",data:{id:e.id},pipelineId:n.pipelineId})}));var i=e.filter((function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai}));t?this.deleteSupernodesAndDescPipelines(i):this.deleteSupernodes(i,[],[])}},{key:"deleteSupernodesAndDescPipelines",value:function(e){var t=this.objectModel.getDescPipelinesToDelete(e,this.pipelineId),n=this.objectModel.getExternalPipelineFlowsForPipelines(t);this.deleteSupernodes(e,t,n)}},{key:"deleteSupernodes",value:function(e,t,n){this.store.dispatch({type:"DELETE_SUPERNODES",data:{supernodesToDelete:e,pipelinesToDelete:t,extPipelineFlowsToDelete:n,pipelineId:this.pipelineId}})}},{key:"deconstructSupernode",value:function(e){this.store.dispatch({type:"DECONSTRUCT_SUPERNODE",data:e})}},{key:"reconstructSupernode",value:function(e){this.store.dispatch({type:"RECONSTRUCT_SUPERNODE",data:e})}},{key:"getNodes",value:function(){return this.store.getNodes(this.pipelineId)}},{key:"getNodeIds",value:function(){return this.getNodes().map((function(e){return e.id}))}},{key:"getNode",value:function(e){return this.store.getNode(e,this.pipelineId)}},{key:"getSupernodes",value:function(){return $e.filterSupernodes(this.getNodes())}},{key:"isDataNode",value:function(e){return this.getNode(e)}},{key:"sizeAndPositionObjects",value:function(e,t){this.store.dispatch({type:"SIZE_AND_POSITION_OBJECTS",data:{objectsInfo:e,linksInfo:t},pipelineId:this.pipelineId})}},{key:"filterDataNodes",value:function(e){var t=this;return e.filter((function(e){return t.isDataNode(e)}))}},{key:"expandSuperNodeInPlace",value:function(e,t,n){var i=Object.assign({},this.getNode(e),{is_expanded:!0});i=this.objectModel.setNodeAttributes(i),this.store.dispatch({type:"SET_SUPERNODE_EXPAND_STATE",data:{node:i,objectPositions:t,linkPositions:n},pipelineId:this.pipelineId})}},{key:"collapseSuperNodeInPlace",value:function(e,t,n){var i=Object.assign({},this.getNode(e),{is_expanded:!1});i=this.objectModel.setNodeAttributes(i),this.store.dispatch({type:"SET_SUPERNODE_EXPAND_STATE",data:{node:i,objectPositions:t,linkPositions:n},pipelineId:this.pipelineId})}},{key:"isSuperNodeExpandedInPlace",value:function(e){return!0===this.getNode(e).is_expanded}},{key:"isSupernode",value:function(e){return this.getNode(e).type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai}},{key:"getNodeParameters",value:function(e){var t=this.getNode(e);return t?t.parameters:null}},{key:"getNodeUiParameters",value:function(e){var t=this.getNode(e);return t?t.ui_parameters:null}},{key:"setNodeLabel",value:function(e,t){this.store.dispatch({type:"SET_NODE_LABEL",data:{nodeId:e,label:t},pipelineId:this.pipelineId})}},{key:"setNodeDecorations",value:function(e,t){this.store.dispatch({type:"SET_NODE_DECORATIONS",data:{nodeId:e,decorations:this.ensureDecorationsHaveIds(t)},pipelineId:this.pipelineId})}},{key:"setInputPortLabel",value:function(e,t,n){this.store.dispatch({type:"SET_INPUT_PORT_LABEL",data:{nodeId:e,portId:t,label:n},pipelineId:this.pipelineId})}},{key:"setOutputPortLabel",value:function(e,t,n){this.store.dispatch({type:"SET_OUTPUT_PORT_LABEL",data:{nodeId:e,portId:t,label:n},pipelineId:this.pipelineId})}},{key:"setInputPortSubflowNodeRef",value:function(e,t,n){this.store.dispatch({type:"SET_INPUT_PORT_SUBFLOW_NODE_REF",data:{nodeId:e,portId:t,subflowNodeRef:n},pipelineId:this.pipelineId})}},{key:"setOutputPortSubflowNodeRef",value:function(e,t,n){this.store.dispatch({type:"SET_OUTPUT_PORT_SUBFLOW_NODE_REF",data:{nodeId:e,portId:t,subflowNodeRef:n},pipelineId:this.pipelineId})}},{key:"setNodeProperties",value:function(e,t){this.store.dispatch({type:"SET_NODE_PROPERTIES",data:{nodeId:e,properties:t},pipelineId:this.pipelineId})}},{key:"setNodeMessage",value:function(e,t){this.store.dispatch({type:"SET_NODE_MESSAGE",data:{nodeId:e,message:t},pipelineId:this.pipelineId})}},{key:"setNodeMessages",value:function(e,t){this.store.dispatch({type:"SET_NODE_MESSAGES",data:{nodeId:e,messages:t},pipelineId:this.pipelineId})}},{key:"setNodeUiParameters",value:function(e,t){this.store.dispatch({type:"SET_NODE_UI_PARAMETERS",data:{nodeId:e,ui_parameters:t},pipelineId:this.pipelineId})}},{key:"setNodeParameters",value:function(e,t){this.store.dispatch({type:"SET_NODE_PARAMETERS",data:{nodeId:e,parameters:t},pipelineId:this.pipelineId})}},{key:"setNodeInputPorts",value:function(e,t){var n=this.getNode(e);n.inputs=t;var i=this.objectModel.setNodeAttributes(n);this.store.dispatch({type:"REPLACE_NODE",data:{node:i},pipelineId:this.pipelineId})}},{key:"setNodeOutputPorts",value:function(e,t){var n=this.getNode(e);n.outputs=t;var i=this.objectModel.setNodeAttributes(n);this.store.dispatch({type:"REPLACE_NODE",data:{node:i},pipelineId:this.pipelineId})}},{key:"addCustomAttrToNodes",value:function(e,t,n){this.store.dispatch({type:"ADD_NODE_ATTR",data:{objIds:e,attrName:t,attrValue:n},pipelineId:this.pipelineId})}},{key:"removeCustomAttrFromNodes",value:function(e,t,n){this.store.dispatch({type:"REMOVE_NODE_ATTR",data:{objIds:e,attrName:t},pipelineId:this.pipelineId})}},{key:"getNodeDecorations",value:function(e){var t=this.getNode(e);return t?t.decorations:null}},{key:"getNodeMessages",value:function(e){var t=this.getNode(e);return t?t.messages:null}},{key:"getNodeMessage",value:function(e,t){var n=this.getNodeMessages(e);if(n){var i,o=Rn(n);try{for(o.s();!(i=o.n()).done;){var a=i.value;if(a.id_ref===t)return a}}catch(e){o.e(e)}finally{o.f()}}return null}},{key:"getNodeInputPorts",value:function(e){var t=this.getNode(e);return t?t.inputs:null}},{key:"getNodeOutputPorts",value:function(e){var t=this.getNode(e);return t?t.outputs:null}},{key:"getNodeClassName",value:function(e){var t=this.getNode(e);return t?t.class_name:null}},{key:"getNodeStyle",value:function(e,t){var n=this.getNode(e);return t?n?n.style_temp:null:n?n.style:null}},{key:"hasErrorMessage",value:function(e){var t=this.getNode(e);return this.objectModel.hasErrorMessage(t)}},{key:"hasWarningMessage",value:function(e){var t=this.getNode(e);return this.objectModel.hasWarningMessage(t)}},{key:"isFlowValid",value:function(e){var t,n=!0,i=Rn(this.getNodes());try{for(i.s();!(t=i.n()).done;){var o=t.value;n&&(n=this.isNodeValid(o,e))}}catch(e){i.e(e)}finally{i.f()}return n}},{key:"isNodeValid",value:function(e,t){var n=!0;if(t&&Array.isArray(t)&&t.length>0){var i,o=Rn(e.messages);try{for(o.s();!(i=o.n()).done;){var a=i.value;-1!==t.indexOf(a.type)&&(n=!1)}}catch(e){o.e(e)}finally{o.f()}}else e.messages&&e.messages.length>0&&(n=!1);return n}},{key:"getFlowMessages",value:function(){var e=this.getNodes(),t={};return e.forEach((function(e){e.messages&&e.messages.length>0&&(t[e.id]=e.messages)})),t}},{key:"autoLayout",value:function(e){var t=this.objectModel.getCanvasInfoPipeline(this.pipelineId),n={};n=e===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ax?this.dagreAutolayout(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ay,t):this.dagreAutolayout(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.az,t),this.sizeAndPositionObjects(n)}},{key:"dagreAutolayout",value:function(e,t){var n=this,i=this.objectModel.getCanvasLayout(),o=t.links.filter((function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H||e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K})).map((function(e){return{v:e.srcNodeId,w:e.trgNodeId,value:{points:[]}}})),a=t.nodes.map((function(o){var a=o.width;return e===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.az&&(a=o.width+Math.max(n.getPaddingForNode(o,i,t),i.autoLayoutHorizontalSpacing)),{v:o.id,value:{width:a,height:o.height}}})),r={};["TB","BT","LR","RL"].indexOf(e)>=0&&(r={rankDir:e});var s={nodes:a,edges:o,value:r},d=i.autoLayoutInitialMarginX,c=i.autoLayoutInitialMarginY,l=i.autoLayoutVerticalSpacing,u=i.autoLayoutHorizontalSpacing;e===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.az&&(u=0);var p=Mn.graphlib.json.read(s);p.graph().marginx=d,p.graph().marginy=c,"TB"===e?(p.graph().nodesep=u,p.graph().ranksep=l):(p.graph().nodesep=l,p.graph().ranksep=u),Mn.layout(p);var f=Mn.graphlib.json.write(p);return this.convertGraphToMovedNodes(f,t.nodes)}},{key:"convertGraphToMovedNodes",value:function(e,t){for(var n=[],i={},o=0,a=e.nodes.length;o<a;o++)i[e.nodes[o].v]=e.nodes[o];return t.forEach((function(e){n[e.id]={id:e.id,x_pos:i[e.id].value.x-i[e.id].value.width/2,y_pos:i[e.id].value.y-i[e.id].value.height/2,width:e.width,height:e.height}})),n}},{key:"getPaddingForNode",value:function(e,t,n){return $e.getNodePaddingToTargetNodes(e,n.nodes,n.links,t.linkType)}},{key:"getBoundingRectForNodes",value:function(e){var t=e[0].x_pos,n=e[0].y_pos,i=e[0].width+t,o=e[0].height+n;return e.forEach((function(e){t=Math.min(t,e.x_pos),n=Math.min(n,e.y_pos),i=Math.max(i,e.x_pos+e.width),o=Math.max(o,e.y_pos+e.height)})),{x:t,y:n,width:i-t,height:o-n}}},{key:"ensureDecorationsHaveIds",value:function(e){var t=this;return e?e.map((function(e){return Object.assign({},e,{id:e.id||t.objectModel.getUUID()})})):e}},{key:"createComment",value:function(e){var t=this,n={id:this.objectModel.getUniqueId(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aA),content:"",height:42,width:175,x_pos:e.mousePos.x,y_pos:e.mousePos.y,linkIds:[],selectedObjectIds:[]};return n=this.objectModel.setCommentAttributes(n),e.selectedObjectIds.forEach((function(e){t.isDataNode(e)&&(n.selectedObjectIds.push(e),n.linkIds.push(t.objectModel.getUniqueId(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aB,{comment:n,targetNode:t.getNode(e)})))})),n}},{key:"addComment",value:function(e){this.store.dispatch({type:"ADD_COMMENT",data:e,pipelineId:this.pipelineId})}},{key:"getNewCommentPosition",value:function(e){for(var t={x_pos:e.x_pos,y_pos:e.y_pos};this.exactlyOverlaps(null,[t],null);)t.x_pos+=10,t.y_pos+=10;return t}},{key:"deleteComment",value:function(e){var t=this.getComment(e);t&&this.deleteComments([t])}},{key:"deleteComments",value:function(e){var t=this;e&&e.length>0&&this.objectModel.executeWithSelectionChange((function(e){t.deleteCommentsInternal(e)}),e)}},{key:"deleteCommentsInternal",value:function(e){var t=this;e.forEach((function(e){t.store.dispatch({type:"DELETE_OBJECT",data:{id:e.id},pipelineId:t.pipelineId})}))}},{key:"getComments",value:function(){return this.store.getComments(this.pipelineId)}},{key:"getComment",value:function(e){return this.store.getComment(e,this.pipelineId)}},{key:"editComment",value:function(e){this.store.dispatch({type:"EDIT_COMMENT",data:e,pipelineId:this.pipelineId})}},{key:"addCustomAttrToComments",value:function(e,t,n){this.store.dispatch({type:"ADD_COMMENT_ATTR",data:{objIds:e,attrName:t,attrValue:n},pipelineId:this.pipelineId})}},{key:"removeCustomAttrFromComments",value:function(e,t){this.store.dispatch({type:"REMOVE_COMMENT_ATTR",data:{objIds:e,attrName:t},pipelineId:this.pipelineId})}},{key:"getCommentClassName",value:function(e){var t=this.getComment(e);return t?t.class_name:null}},{key:"getCommentStyle",value:function(e,t){var n=this.getComment(e);return t?n?n.style_temp:null:n?n.style:null}},{key:"createLink",value:function(e,t){var n={id:this.objectModel.getUniqueId(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aC,{sourceNode:t,targetNode:e}),srcNodeId:t.id,trgNodeId:e.id,type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H};return t.outputs&&t.outputs.length>0&&(n=Object.assign(n,{srcNodePortId:t.outputs[0].id})),e.inputs&&e.inputs.length>0&&(n=Object.assign(n,{trgNodePortId:e.inputs[0].id})),n}},{key:"createLinkFromInfo",value:function(e){var t=this.objectModel.getUniqueId(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aC,{sourceNodeId:e.srcNodeId,targetNodeId:e.trgNodeId});return Object.assign({id:t,type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H},e)}},{key:"deleteLink",value:function(e){this.store.dispatch({type:"DELETE_LINK",data:e,pipelineId:this.pipelineId})}},{key:"deleteLinks",value:function(e){this.store.dispatch({type:"DELETE_LINKS",data:{linksToDelete:e},pipelineId:this.pipelineId})}},{key:"updateLinks",value:function(e){this.store.dispatch({type:"UPDATE_LINKS",data:{linksToUpdate:e},pipelineId:this.pipelineId})}},{key:"updateLink",value:function(e){this.updateLinks([e])}},{key:"createNodeLinks",value:function(e){var t=this,n=[];return e.nodes.forEach((function(i){e.targetNodes.forEach((function(o){var a=t.createNodeLink(i,o,e);a&&n.push(a)}))})),n}},{key:"createNodeLink",value:function(e,t,n){var i=this.getNode(e.id),o=this.getNode(t.id),a=this.getLinks();if($e.isConnectionAllowed(e.portId,t.portId,i,o,a,n.type)){var r={};return r.id=n.id?n.id:this.objectModel.getUniqueId(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aC,{sourceNode:this.getNode(e.id),targetNode:this.getNode(t.id)}),r.type=n.type,r.srcNodeId=e.id,r.srcNodePortId=e.portId,r.trgNodeId=t.id,r.trgNodePortId=t.portId,n.class_name&&(r.class_name=n.class_name),n.linkName&&(r.linkName=n.linkName),r}return null}},{key:"createNodeLinkDetached",value:function(e){var t={};return t.id=e.id?e.id:this.objectModel.getUniqueId(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aC,{sourceNode:this.getNode(e.srcNodeId)}),t.type=e.type,t.srcNodeId=e.srcNodeId,t.srcNodePortId=e.srcNodePortId,t.trgPos={x_pos:e.trgPos.x,y_pos:e.trgPos.y},e.class_name&&(t.class_name=e.class_name),e.linkName&&(t.linkName=e.linkName),e.typeAttr&&(t.typeAttr=e.typeAttr),e.description&&(t.description=e.description),t}},{key:"createCommentLinks",value:function(e){var t=this,n=[];return e.nodes.forEach((function(i){e.targetNodes.forEach((function(o){if($e.isCommentLinkConnectionAllowed(i,o,t.getLinks())){var a={};a.id=t.objectModel.getUniqueId(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aB,{comment:t.getComment(i),targetNode:t.getNode(o)}),a.type=e.type,a.srcNodeId=i,a.trgNodeId=o,n.push(a)}}))})),n}},{key:"addLinks",value:function(e){var t=this;e.forEach((function(e){t.addLink(e)}))}},{key:"addLink",value:function(e){this.store.dispatch({type:"ADD_LINK",data:e,pipelineId:this.pipelineId})}},{key:"getLinks",value:function(){return this.store.getLinks(this.pipelineId)}},{key:"getLinkIds",value:function(){return this.getLinks().map((function(e){return e.id}))}},{key:"getLinksBetween",value:function(e,t){var n=this;return this.getLinks().filter((function(i){return!(!n.isObjectIdInObjects(i.trgNodeId,e)||!n.isObjectIdInObjects(i.srcNodeId,e)&&!n.isObjectIdInObjects(i.srcNodeId,t))}))}},{key:"getLinksContainingId",value:function(e){return this.getLinks().filter((function(t){return t.srcNodeId===e||t.trgNodeId===e})).map((function(e){return Object.assign({},e)}))}},{key:"getLinksContainingIds",value:function(e){var t=this,n=[];return e.forEach((function(e){var i=t.getLinksContainingId(e);i.length>0&&(n=$e.concatUniqueBasedOnId(i,n))})),n}},{key:"getNodeDataLinksContainingIds",value:function(e){return this.getLinksContainingIds(e).filter((function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H}))}},{key:"getLinksContainingSourceId",value:function(e){return this.getLinks().filter((function(t){return t.srcNodeId===e}))}},{key:"getLinksContainingTargetId",value:function(e){return this.getLinks().filter((function(t){return t.trgNodeId===e}))}},{key:"getAttachedLinksContainingSourceId",value:function(e){return this.getLinks().filter((function(t){return t.srcNodeId===e&&t.trgNodeId}))}},{key:"getAttachedLinksContainingTargetId",value:function(e){return this.getLinks().filter((function(t){return t.trgNodeId===e&&t.srcNodeId}))}},{key:"getNodeLinks",value:function(e){var t=this,n=[];return e.forEach((function(e){t.getLinksContainingId(e.id).forEach((function(e){e.type!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H&&e.type!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K||n.push(e)}))})),n}},{key:"getNodeDataLinks",value:function(){return this.getLinks().filter((function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H}))}},{key:"getNodeDataLinkFromInfo",value:function(e,t,n,i){var o=this,a=this.getDefaultSrcPortId(e,t),r=this.getDefaultTrgPortId(n,i);return a&&r?this.getLinks().find((function(t){if(t.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H){var i=o.getDefaultSrcPortId(t.srcNodeId,t.srcNodePortId),s=o.getDefaultTrgPortId(t.trgNodeId,t.trgNodePortId);return t.srcNodeId===e&&i===a&&t.trgNodeId===n&&s===r}return!1})):null}},{key:"getCommentLinkFromInfo",value:function(e,t){return this.getLinks().find((function(n){return n.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O&&(n.srcNodeId===e&&n.trgNodeId===t||n.srcNodeId===t&&n.trgNodeId===e)}))}},{key:"setCommentProperties",value:function(e,t){this.store.dispatch({type:"SET_COMMENT_PROPERTIES",data:{commentId:e,commentProperties:t},pipelineId:this.pipelineId})}},{key:"getNodeAssocLinkFromInfo",value:function(e,t){return this.getLinks().find((function(n){return n.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K&&(n.srcNodeId===e&&n.trgNodeId===t||n.srcNodeId===t&&n.trgNodeId===e)}))}},{key:"getDefaultSrcPortId",value:function(e,t){if(!t){var n=this.getNode(e);if(n&&n.outputs&&n.outputs.length>0)return n.outputs[0].id}return t}},{key:"getDefaultTrgPortId",value:function(e,t){if(!t){var n=this.getNode(e);if(n&&n.inputs&&n.inputs.length>0)return n.inputs[0].id}return t}},{key:"getLink",value:function(e){return this.store.getLink(e,this.pipelineId)}},{key:"setLinkProperties",value:function(e,t){this.store.dispatch({type:"SET_LINK_PROPERTIES",data:{linkId:e,linkProperties:t},pipelineId:this.pipelineId})}},{key:"setNodeDataLinkSrcInfo",value:function(e,t,n){this.store.dispatch({type:"SET_LINK_SRC_INFO",data:{linkId:e,srcNodeId:t,srcNodePortId:n},pipelineId:this.pipelineId})}},{key:"setNodeDataLinkTrgInfo",value:function(e,t,n){this.store.dispatch({type:"SET_LINK_TRG_INFO",data:{linkId:e,trgNodeId:t,trgNodePortId:n},pipelineId:this.pipelineId})}},{key:"getLinkClassName",value:function(e){var t=this.getLink(e);return t&&t.class_name?t.class_name:null}},{key:"getLinkStyle",value:function(e,t){var n=this.getLink(e);return t?n&&n.style_temp?n.style_temp:null:n&&n.style?n.style:null}},{key:"setLinksClassName",value:function(e,t){this.store.dispatch({type:"SET_LINKS_CLASS_NAME",data:{linkIds:e,newClassName:t},pipelineId:this.pipelineId})}},{key:"setLinkDecorations",value:function(e,t){this.store.dispatch({type:"SET_LINK_DECORATIONS",data:{linkId:e,decorations:this.ensureDecorationsHaveIds(t)},pipelineId:this.pipelineId})}},{key:"getLinkDecorations",value:function(e){var t=this.getLink(e);return t?t.decorations:null}},{key:"isCommentLinkedToNonSelectedNodes",value:function(e){var t,n=this.getLinksContainingId(e),i=this.objectModel.getSelectedObjectIds(),o=!1,a=Rn(n);try{for(a.s();!(t=a.n()).done;){var r=t.value;if(o=!i.includes(r.trgNodeId))return o}}catch(e){a.e(e)}finally{a.f()}return o}},{key:"pushUniqueLinks",value:function(e,t){return-1===t.findIndex((function(t){return t.id===e.id}))&&t.push(e),t}}]),i}(),Bn=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0;return"SET_TOOLTIP_DEF"===t.type&&t.data.tooltipDef?t.data.tooltipDef:e},Hn=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"ADD_NODE_TYPES_TO_PALETTE":return t.data.nodeTypes?[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(t.data.nodeTypes)):e;case"REMOVE_NODE_TYPES_FROM_PALETTE":return e.filter((function(e){return-1===t.data.selObjectIds.findIndex((function(t){return t===e.id}))}));default:return e}},qn=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"ADD_NODE_TYPES_TO_PALETTE":var n=e.find((function(e){return e.id===t.data.categoryId}));return n?e.map((function(e){return t.data.categoryId===e.id?Object.assign({},e,{node_types:Hn(e.node_types,t)}):e})):(n={id:t.data.categoryId,label:t.data.categoryLabel?t.data.categoryLabel:t.data.categoryId},t.data.categoryDescription&&(n.description=t.data.categoryDescription),t.data.categoryImage&&(n.image=t.data.categoryImage),n.node_types=[],[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e),[Object.assign({},n,{node_types:Hn(n.node_types,t)})]));case"REMOVE_NODE_TYPES_FROM_PALETTE":return e.map((function(e){return e.id===t.data.categoryId?Object.assign({},e,{node_types:Hn(e.node_types,t)}):e}));case"SET_CATEGORY_LOADING_TEXT":return e.map((function(e){return e.id===t.data.categoryId?Object.assign({},e,{loading_text:t.data.loadingText}):e}));case"SET_CATEGORY_EMPTY_TEXT":return e.map((function(e){return e.id===t.data.categoryId?Object.assign({},e,{empty_text:t.data.emptyText}):e}));default:return e}},Gn=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"CLEAR_PALETTE_DATA":return{content:{}};case"SET_PALETTE_DATA":var n=Object.assign({},t.data.content);return Object.assign({},e,{content:n});case"ADD_NODE_TYPES_TO_PALETTE":case"REMOVE_NODE_TYPES_FROM_PALETTE":case"SET_CATEGORY_LOADING_TEXT":case"SET_CATEGORY_EMPTY_TEXT":var i=Object.assign({},e.content,{categories:qn(e.content.categories,t)});return Object.assign({},e,{content:i,version:"3.0"});case"SET_PALETTE_OPEN_STATE":return Object.assign({},e,{isOpen:t.data.isOpen});default:return e}},zn=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"SET_INPUT_PORT_LABEL":case"SET_OUTPUT_PORT_LABEL":return e.map((function(e,n){if(t.data.portId===e.id){var i=Object.assign({},e);return i.label=t.data.label,i}return e}));case"SET_INPUT_PORT_SUBFLOW_NODE_REF":case"SET_OUTPUT_PORT_SUBFLOW_NODE_REF":return e.map((function(e,n){if(t.data.portId===e.id){var i=Object.assign({},e);return i.subflow_node_ref=t.data.subflowNodeRef,i}return e}));default:return e}},Vn=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"ADD_NODE":return[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e),[Object.assign({},t.data.newNode)]);case"ADD_NODES":return[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(t.data.nodesToAdd));case"REPLACE_NODES":return t.data;case"REPLACE_NODE":return e.map((function(e,n){return t.data.node.id===e.id?t.data.node:e}));case"MOVE_OBJECTS":return t.data.nodes?e.map((function(e,n){if(t.data.nodes.indexOf(e.id)>-1){var i=e.x_pos+t.data.offsetX,o=e.y_pos+t.data.offsetY;return Object.assign({},e,{x_pos:i,y_pos:o})}return e})):e;case"SIZE_AND_POSITION_OBJECTS":return e.map((function(e,n){var i=t.data.objectsInfo[e.id];if(void 0!==i){var o=Object.assign({},e,{height:i.height,width:i.width,x_pos:i.x_pos,y_pos:i.y_pos});return o.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai&&o.is_expanded?(o.expanded_width=i.width,o.expanded_height=i.height):i.isResized?(o.isResized=i.isResized,o.resizeWidth=i.resizeWidth,o.resizeHeight=i.resizeHeight):(delete o.isResized,delete o.resizeWidth,delete o.resizeHeight),o}return e}));case"SET_NODE_POSITIONS":return e.map((function(e,n){if(t.data.nodePositions&&void 0!==t.data.nodePositions[e.id]){var i=t.data.nodePositions[e.id];return Object.assign({},e,{x_pos:i.x_pos,y_pos:i.y_pos})}return e}));case"ADD_SUPERNODES":return[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(t.data.supernodesToAdd));case"DELETE_SUPERNODES":return e.filter((function(e){return!t.data.supernodesToDelete.some((function(t){return t.id===e.id}))}));case"DELETE_OBJECT":return e.filter((function(e){return e.id!==t.data.id}));case"DELETE_NODES":return e.filter((function(e){return!t.data.nodesToDelete.some((function(t){return t.id===e.id}))}));case"SET_NODE_PROPERTIES":return e.map((function(e,n){return t.data.nodeId===e.id?Object.assign({},e,t.data.properties):e}));case"SET_NODE_PARAMETERS":return e.map((function(e,n){if(t.data.nodeId===e.id){var i=Object.assign({},e);return i.parameters=t.data.parameters,i}return e}));case"SET_NODE_UI_PARAMETERS":return e.map((function(e,n){if(t.data.nodeId===e.id){var i=Object.assign({},e);return i.ui_parameters=t.data.ui_parameters,i}return e}));case"SET_NODE_MESSAGE":return e.map((function(e,n){if(t.data.nodeId===e.id){var i=Object.assign({},e);if(i.messages){var o=i.messages.findIndex((function(e){return e.id_ref===t.data.message.id_ref}));o>-1?i.messages[o]=t.data.message:i.messages.push(t.data.message)}else i.messages=[t.data.message];return i}return e}));case"SET_NODE_MESSAGES":return e.map((function(e,n){if(t.data.nodeId===e.id){var i=Object.assign({},e);return i.messages=t.data.messages,i}return e}));case"ADD_NODE_ATTR":return e.map((function(e,n){if(t.data.objIds.indexOf(e.id)>-1){var i=Object.assign({},e);return i.customAttrs=i.customAttrs||[],i.customAttrs.push(t.data.attrName),i}return e}));case"REMOVE_NODE_ATTR":return e.map((function(e,n){if(t.data.objIds.indexOf(e.id)>-1){var i=Object.assign({},e);return i.customAttrs&&(i.customAttrs=i.customAttrs.filter((function(e){return e!==t.data.attrName}))),i}return e}));case"SET_NODE_LABEL":return e.map((function(e,n){if(t.data.nodeId===e.id){var i=Object.assign({},e);return i.label=t.data.label,i}return e}));case"SET_NODE_DECORATIONS":return e.map((function(e,n){if(t.data.nodeId===e.id){var i=Object.assign({},e);return i.decorations=t.data.decorations,i}return e}));case"SET_NODES_MULTI_DECORATIONS":return e.map((function(e){var n=t.data.pipelineNodeDecorations.find((function(n){return n.pipelineId===t.data.pipelineId&&n.nodeId===e.id}));return n?Object.assign({},e,{decorations:n.decorations}):e}));case"SET_OBJECTS_CLASS_NAME":return e.map((function(e){var n=t.data.objIds.indexOf(e.id);if(n>-1){var i=Object.assign({},e);return i.class_name=Array.isArray(t.data.newClassName)?t.data.newClassName[n]||null:t.data.newClassName,i}return e}));case"SET_OBJECTS_STYLE":return e.map((function(e){if(t.data.objIds.indexOf(e.id)>-1){var n=Object.assign({},e);return t.data.temporary?n.style_temp=t.data.newStyle:n.style=t.data.newStyle,n}return e}));case"SET_OBJECTS_MULTI_STYLE":return e.map((function(e){var n=t.data.pipelineObjStyles.find((function(n){return n.pipelineId===t.data.pipelineId&&n.objId===e.id}));if(n){var i=Object.assign({},e),o=n&&n.style?n.style:null;return t.data.temporary?i.style_temp=o:i.style=o,i}return e}));case"REMOVE_ALL_STYLES":return e.map((function(e){if(t.data.temporary&&e.style_temp){var n=Object.assign({},e);return delete n.style_temp,n}if(!t.data.temporary&&e.style){var i=Object.assign({},e);return delete i.style,i}return e}));case"SET_INPUT_PORT_LABEL":case"SET_INPUT_PORT_SUBFLOW_NODE_REF":return e.map((function(e,n){return t.data.nodeId===e.id?Object.assign({},e,{inputs:zn(e.inputs,t)}):e}));case"SET_OUTPUT_PORT_LABEL":case"SET_OUTPUT_PORT_SUBFLOW_NODE_REF":return e.map((function(e,n){return t.data.nodeId===e.id?Object.assign({},e,{outputs:zn(e.outputs,t)}):e}));case"SET_SUPERNODE_EXPAND_STATE":return e.map((function(e){return t.data.node.id===e.id?t.data.node:e}));case"REPLACE_SN_AND_PIPELINES":return e.map((function(e,n){return e.id===t.data.topSupernode.id?Object.assign({},t.data.topSupernode):e}));default:return e}},$n=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"MOVE_OBJECTS":return t.data.nodes?e.map((function(e,n){if(t.data.nodes.indexOf(e.id)>-1){var i=e.x_pos+t.data.offsetX,o=e.y_pos+t.data.offsetY;return Object.assign({},e,{x_pos:i,y_pos:o})}return e})):e;case"SET_COMMENT_POSITIONS":return e.map((function(e,n){if(t.data.commentPositions&&void 0!==t.data.commentPositions[e.id]){var i=t.data.commentPositions[e.id];return Object.assign({},e,{x_pos:i.x_pos,y_pos:i.y_pos})}return e}));case"DELETE_OBJECT":return e.filter((function(e){return e.id!==t.data.id}));case"DELETE_COMMENTS":return e.filter((function(e){return!t.data.commentsToDelete.some((function(t){return t.id===e.id}))}));case"ADD_COMMENT":var n=Yn(t.data);return[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e),[n]);case"ADD_COMMENTS":var i=t.data.commentsToAdd.map((function(e){return Yn(e)}));return[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(i));case"EDIT_COMMENT":return e.map((function(e,n){return t.data.id===e.id?Object.assign({},e,{content:t.data.content,height:t.data.height,width:t.data.width,x_pos:t.data.x_pos?t.data.x_pos:e.x_pos,y_pos:t.data.y_pos?t.data.y_pos:e.y_pos}):e}));case"SET_COMMENT_PROPERTIES":return e.map((function(e){return e.id===t.data.commentId?Object.assign({},e,t.data.commentProperties):e}));case"SIZE_AND_POSITION_OBJECTS":return e.map((function(e,n){var i=t.data.objectsInfo[e.id];return void 0!==i?Object.assign({},e,{height:i.height,width:i.width,x_pos:i.x_pos,y_pos:i.y_pos}):e}));case"ADD_COMMENT_ATTR":return e.map((function(e,n){if(t.data.objIds.indexOf(e.id)>-1){var i=Object.assign({},e);return i.customAttrs=i.customAttrs||[],i.customAttrs.push(t.data.attrName),i}return e}));case"REMOVE_COMMENT_ATTR":return e.map((function(e,n){if(t.data.objIds.indexOf(e.id)>-1){var i=Object.assign({},e);return i.customAttrs&&(i.customAttrs=i.customAttrs.filter((function(e){return e!==t.data.attrName}))),i}return e}));case"SET_OBJECTS_COLOR_CLASS_NAME":return e.map((function(e){var n=t.data.objIds.indexOf(e.id);if(n>-1){var i=Array.isArray(t.data.newColorClass)?t.data.newColorClass[n]||null:t.data.newColorClass,o=Wn(e.class_name,i);return Object.assign({},e,{class_name:o})}return e}));case"SET_OBJECTS_CLASS_NAME":return e.map((function(e){var n=t.data.objIds.indexOf(e.id);if(n>-1){var i=Object.assign({},e);return i.class_name=Array.isArray(t.data.newClassName)?t.data.newClassName[n]||null:t.data.newClassName,i}return e}));case"SET_OBJECTS_STYLE":return e.map((function(e){if(t.data.objIds.indexOf(e.id)>-1){var n=Object.assign({},e);return t.data.temporary?n.style_temp=t.data.newStyle:n.style=t.data.newStyle,n}return e}));case"SET_OBJECTS_MULTI_STYLE":return e.map((function(e){var n=t.data.pipelineObjStyles.find((function(n){return n.pipelineId===t.data.pipelineId&&n.objId===e.id}));if(n){var i=Object.assign({},e),o=n&&n.style?n.style:null;return t.data.temporary?i.style_temp=o:i.style=o,i}return e}));case"REMOVE_ALL_STYLES":return e.map((function(e){if(t.data.temporary&&e.style_temp){var n=Object.assign({},e);return delete n.style_temp,n}if(!t.data.temporary&&e.style){var i=Object.assign({},e);return delete i.style,i}return e}));default:return e}};function Wn(e,t){var n="";return e?(n=function(e){return e.split(" ").filter((function(e){return!$e.getBkgColorClass(e)})).join(" ")}(e),n=function(e,t){return e?e+" "+t:t}(n,t)):n=t,n}function Yn(e){var t={id:e.id,content:e.content,height:e.height,width:e.width,x_pos:e.x_pos,y_pos:e.y_pos};return void 0!==e.class_name&&(t.class_name=e.class_name),t}var Xn=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"DELETE_SUPERNODES":return e.filter((function(e){return!t.data.supernodesToDelete.some((function(t){return e.srcNodeId===t.id||e.trgNodeId===t.id}))}));case"DELETE_OBJECT":return e.filter((function(e){return e.srcNodeId!==t.data.id&&e.trgNodeId!==t.data.id}));case"REMOVE_LINKS":return e.filter((function(e){return!t.data.linksToDelete.some((function(t){return t.id===e.id}))}));case"ADD_LINK":var n={id:t.data.id};return Kn(n,"type",t.data.type),Kn(n,"class_name",t.data.class_name),Kn(n,"srcPos",t.data.srcPos),Kn(n,"srcNodeId",t.data.srcNodeId),Kn(n,"srcNodePortId",t.data.srcNodePortId),Kn(n,"trgPos",t.data.trgPos),Kn(n,"trgNodeId",t.data.trgNodeId),Kn(n,"trgNodePortId",t.data.trgNodePortId),Kn(n,"decorations",t.data.decorations),Kn(n,"style",t.data.style),Kn(n,"style_temp",t.data.style_temp),Kn(n,"linkName",t.data.linkName),Kn(n,"typeAttr",t.data.typeAttr),Kn(n,"description",t.data.description),Kn(n,"app_data",t.data.app_data),[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e),[n]);case"ADD_LINKS":return[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(t.data.linksToAdd));case"MOVE_OBJECTS":return e.map((function(e){if(t.data.links&&t.data.links.findIndex((function(t){return t.id===e.id}))>-1){var n=Object.assign({},e);n.srcPos&&(n.srcPos.x_pos+=t.data.offsetX,n.srcPos.y_pos+=t.data.offsetY),n.trgPos&&(n.trgPos.x_pos+=t.data.offsetX,n.trgPos.y_pos+=t.data.offsetY)}return e}));case"SET_LINK_POSITIONS":return e.map((function(e,n){if(t.data.linkPositions&&void 0!==t.data.linkPositions[e.id]){var i=Object.assign({},e);return t.data.linkPositions[e.id].srcPos&&(i=Object.assign(i,{srcPos:t.data.linkPositions[e.id].srcPos})),t.data.linkPositions[e.id].trgPos&&(i=Object.assign(i,{trgPos:t.data.linkPositions[e.id].trgPos})),i}return e}));case"SIZE_AND_POSITION_OBJECTS":return e.map((function(e,n){if(t.data.linksInfo&&void 0!==t.data.linksInfo[e.id]){var i=Object.assign({},e);return t.data.linksInfo[e.id].srcPos&&(i=Object.assign(i,{srcPos:t.data.linksInfo[e.id].srcPos})),t.data.linksInfo[e.id].trgPos&&(i=Object.assign(i,{trgPos:t.data.linksInfo[e.id].trgPos})),i}return e}));case"SET_LINK_PROPERTIES":return e.map((function(e){return e.id===t.data.linkId?Object.assign({},e,t.data.linkProperties):e}));case"SET_LINK_SRC_INFO":return e.map((function(e){if(e.id===t.data.linkId){var n=Object.assign({},e);return delete n.srcNodeId,delete n.srcNodePortId,delete n.srcPos,n.srcNodeId=t.data.srcNodeId,t.data.srcNodePortId&&(n.srcNodePortId=t.data.srcNodePortId),n}return e}));case"SET_LINK_TRG_INFO":return e.map((function(e){if(e.id===t.data.linkId){var n=Object.assign({},e);return delete n.trgNodeId,delete n.trgNodePortId,delete n.trgPos,n.trgNodeId=t.data.trgNodeId,t.data.trgNodePortId&&(n.trgNodePortId=t.data.trgNodePortId),n}return e}));case"DELETE_LINK":return e.filter((function(e){return e.id!==t.data.id}));case"DELETE_LINKS":return e.filter((function(e){return-1===t.data.linksToDelete.findIndex((function(t){return e.id===t.id}))}));case"UPDATE_LINKS":return t.data.linksToUpdate?e.map((function(e){var n=t.data.linksToUpdate.find((function(t){return t.id===e.id}));if(n){var i=Object.assign({},e,n);return n.srcPos?(delete i.srcNodeId,delete i.srcNodePortId):n.srcNodeId&&delete i.srcPos,n.trgPos?(delete i.trgNodeId,delete i.trgNodePortId):n.trgNodeId&&delete i.trgPos,i}return e})):e;case"SET_LINKS_CLASS_NAME":return e.map((function(e){var n=t.data.linkIds.indexOf(e.id);if(n>-1){var i=Object.assign({},e);return i.class_name=Array.isArray(t.data.newClassName)?t.data.newClassName[n]:t.data.newClassName,i}return e}));case"SET_LINKS_STYLE":return e.map((function(e){if(t.data.objIds.indexOf(e.id)>-1){var n=Object.assign({},e);return t.data.temporary?n.style_temp=t.data.newStyle:n.style=t.data.newStyle,n}return e}));case"SET_LINKS_MULTI_STYLE":return e.map((function(e){var n=t.data.pipelineObjStyles.find((function(n){return n.pipelineId===t.data.pipelineId&&n.objId===e.id}));if(n){var i=Object.assign({},e),o=n&&n.style?n.style:null;return t.data.temporary?i.style_temp=o:i.style=o,i}return e}));case"SET_LINK_DECORATIONS":return e.map((function(e,n){if(t.data.linkId===e.id){var i=Object.assign({},e);return i.decorations=t.data.decorations,i}return e}));case"SET_LINKS_MULTI_DECORATIONS":return e.map((function(e){var n=t.data.pipelineLinkDecorations.find((function(n){return n.pipelineId===t.data.pipelineId&&n.linkId===e.id}));return n?Object.assign({},e,{decorations:n.decorations}):e}));case"REMOVE_ALL_STYLES":return e.map((function(e){if(t.data.temporary&&e.style_temp){var n=Object.assign({},e);return delete n.style_temp,n}if(!t.data.temporary&&e.style){var i=Object.assign({},e);return delete i.style,i}return e}));case"ADD_COMMENT":var i=[];return t.data.selectedObjectIds&&t.data.selectedObjectIds.forEach((function(e,n){i.push({id:t.data.linkIds[n],srcNodeId:t.data.id,trgNodeId:t.data.selectedObjectIds[n],type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O})})),[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e),i);default:return e}};function Kn(e,t,n){void 0!==n&&(e[t]=n)}var Jn=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"SET_CANVAS_INFO":return t.canvasInfo?Object.assign({},t.canvasInfo):e;case"SET_CANVAS_CONFIG_INFO":case"REPLACE_PIPELINES":return Object.assign({},e,{pipelines:t.data.pipelines});case"ADD_EXTERNAL_PIPELINE_FLOW":var n=t.newPipelines.map((function(e){return Object.assign({},e)})),i=e.pipelines.concat(n);return Object.assign({},e,{pipelines:i});case"REMOVE_EXTERNAL_PIPELINE_FLOW":var o=e.pipelines.filter((function(e){return!e.parentUrl||e.parentUrl!==t.externalUrl}));return Object.assign({},e,{pipelines:o});case"REPLACE_SN_AND_PIPELINES":var a=e.pipelines.filter((function(e){return!t.data.pipelinesToRemove.some((function(t){return t.id===e.id}))}));return a=(a=a.map((function(e){return e.id===t.data.pipelineId?Object.assign({},e,{nodes:Vn(e.nodes,t)}):e}))).concat(t.data.pipelinesToAdd),Object.assign({},e,{pipelines:a});case"SET_PIPELINE_PARENT_URL":var r=e.pipelines.map((function(e){if(t.data.pipelines.some((function(t){return t.id===e.id}))){var n=Object.assign({},e);return t.data.url?n.parentUrl=t.data.url:delete n.parentUrl,n}return e}));return Object.assign({},e,{pipelines:r});case"DELETE_PIPELINE":var s=e.pipelines.filter((function(e){return e.id!==t.data.id}));return Object.assign({},e,{pipelines:s});case"SET_ZOOM":if(t.data.enableSaveZoom===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aD){var d=e.pipelines.map((function(e){return e.id===t.pipelineId?Object.assign({},e,{zoom:{k:t.data.zoom.k,x:t.data.zoom.x,y:t.data.zoom.y}}):e}));return Object.assign({},e,{pipelines:d})}return e;case"ADD_SUPERNODES":var c=[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e.pipelines),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(t.data.pipelinesToAdd));return c=c.map((function(e){return e.id===t.data.pipelineId?Object.assign({},e,{nodes:Vn(e.nodes,t)}):e})),Object.assign({},e,{pipelines:c});case"DELETE_SUPERNODES":var l=e.pipelines.filter((function(e){return!t.data.pipelinesToDelete.some((function(t){return t.id===e.id}))}));return l=l.map((function(e){return e.id===t.data.pipelineId?Object.assign({},e,{nodes:Vn(e.nodes,t),links:Xn(e.links,t)}):e})),Object.assign({},e,{pipelines:l});case"SET_SUBDUE_STYLE":return Object.assign({},e,{subdueStyle:t.data.subdueStyle});case"ADD_NODE":case"REPLACE_NODES":case"REPLACE_NODE":case"SIZE_AND_POSITION_OBJECTS":case"SET_NODE_PROPERTIES":case"SET_NODE_PARAMETERS":case"SET_NODE_UI_PARAMETERS":case"SET_NODE_MESSAGE":case"SET_NODE_MESSAGES":case"SET_NODE_DECORATIONS":case"SET_LINK_DECORATIONS":case"ADD_NODE_ATTR":case"REMOVE_NODE_ATTR":case"SET_NODE_LABEL":case"SET_OBJECTS_CLASS_NAME":case"SET_OBJECTS_COLOR_CLASS_NAME":case"SET_INPUT_PORT_LABEL":case"SET_OUTPUT_PORT_LABEL":case"SET_INPUT_PORT_SUBFLOW_NODE_REF":case"SET_OUTPUT_PORT_SUBFLOW_NODE_REF":case"MOVE_OBJECTS":case"DELETE_OBJECT":case"ADD_LINK":case"SET_LINK_PROPERTIES":case"SET_LINK_SRC_INFO":case"SET_LINK_TRG_INFO":case"SET_LINKS_CLASS_NAME":case"DELETE_LINK":case"DELETE_LINKS":case"UPDATE_LINKS":case"ADD_COMMENT":case"EDIT_COMMENT":case"SET_COMMENT_PROPERTIES":case"ADD_COMMENT_ATTR":case"REMOVE_COMMENT_ATTR":var u=e.pipelines.map((function(e){return e.id===t.pipelineId?Object.assign({},e,{nodes:Vn(e.nodes,t),comments:$n(e.comments,t),links:Xn(e.links,t)}):e}));return Object.assign({},e,{pipelines:u});case"DELETE_AND_UPDATE_OBJECTS":var p=e.pipelines.map((function(e){if(e.id===t.pipelineId){var n=Xn(e.links,{type:"UPDATE_LINKS",data:{linksToUpdate:t.data.linksToUpdate||[]}});n=Xn(n,{type:"DELETE_LINKS",data:{linksToDelete:t.data.linksToDelete||[]}});var i=Vn(e.nodes,{type:"DELETE_SUPERNODES",data:{supernodesToDelete:t.data.supernodesToDelete||[]}});n=Xn(n,{type:"DELETE_SUPERNODES",data:{supernodesToDelete:t.data.supernodesToDelete||[]}}),i=Vn(i,{type:"DELETE_NODES",data:{nodesToDelete:t.data.nodesToDelete||[]}});var o=$n(e.comments,{type:"DELETE_COMMENTS",data:{commentsToDelete:t.data.commentsToDelete||[]}});return Object.assign({},e,{nodes:i,comments:o,links:n})}return e}));return p=p.filter((function(e){return!t.data.pipelinesToDelete.some((function(t){return t.id===e.id}))})),Object.assign({},e,{pipelines:p});case"ADD_PASTED_OBJECTS":case"ADD_AND_UPDATE_OBJECTS":var f=e.pipelines.map((function(e){if(e.id===t.pipelineId){var n=Vn(e.nodes,{type:"ADD_SUPERNODES",data:{supernodesToAdd:t.data.supernodesToAdd||[]}});n=Vn(n,{type:"ADD_NODES",data:{nodesToAdd:t.data.nodesToAdd||[]}});var i=$n(e.comments,{type:"ADD_COMMENTS",data:{commentsToAdd:t.data.commentsToAdd||[]}}),o=Xn(e.links,{type:"ADD_LINKS",data:{linksToAdd:t.data.linksToAdd||[]}});return o=Xn(o,{type:"UPDATE_LINKS",data:{linksToUpdate:t.data.linksToUpdate||[]}}),Object.assign({},e,{nodes:n,comments:i,links:o})}return e}));return f=[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(f),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(t.data.pipelinesToAdd)),Object.assign({},e,{pipelines:f});case"DELETE_PASTED_OBJECTS":var h=e.pipelines.filter((function(e){return!Zn(e,t.data.pipelinesToDelete)})).map((function(e){if(e.id===t.pipelineId){var n=Vn(e.nodes,{type:"DELETE_NODES",data:t.data}),i=$n(e.comments,{type:"DELETE_COMMENTS",data:t.data}),o=Xn(e.links,{type:"REMOVE_LINKS",data:t.data});return Object.assign({},e,{nodes:n,comments:i,links:o})}return e}));return Object.assign({},e,{pipelines:h});case"SET_SUPERNODE_EXPAND_STATE":var g=e.pipelines.map((function(e){if(e.id===t.pipelineId){var n=Vn(e.nodes,{type:"SET_SUPERNODE_EXPAND_STATE",data:t.data});n=Vn(n,{type:"SET_NODE_POSITIONS",data:{nodePositions:t.data.objectPositions}});var i=$n(e.comments,{type:"SET_COMMENT_POSITIONS",data:{commentPositions:t.data.objectPositions}}),o=Xn(e.links,{type:"SET_LINK_POSITIONS",data:t.data});return Object.assign({},e,{nodes:n,comments:i,links:o})}return e}));return Object.assign({},e,{pipelines:g});case"DECONSTRUCT_SUPERNODE":var y=e.pipelines.filter((function(e){return e.id!==t.data.pipelineToDelete.id})).map((function(e){if(e.id===t.data.pipelineId){var n=Vn(e.nodes,{type:"ADD_NODES",data:t.data}),i=$n(e.comments,{type:"ADD_COMMENTS",data:t.data}),o=Xn(e.links,{type:"ADD_LINKS",data:t.data});return n=Vn(n,{type:"DELETE_SUPERNODES",data:{supernodesToDelete:[t.data.supernodeToDelete]}}),o=Xn(o,{type:"DELETE_SUPERNODES",data:{supernodesToDelete:[t.data.supernodeToDelete]}}),n=Vn(n,{type:"SET_NODE_POSITIONS",data:{nodePositions:t.data.newObjectPositions}}),i=$n(i,{type:"SET_COMMENT_POSITIONS",data:{commentPositions:t.data.newObjectPositions}}),o=Xn(o,{type:"SET_LINK_POSITIONS",data:{linkPositions:t.data.newLinkPositions}}),Object.assign({},e,{nodes:n,comments:i,links:o})}return e}));return Object.assign({},e,{pipelines:y});case"RECONSTRUCT_SUPERNODE":var m=[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e.pipelines),[t.data.pipelineToDelete]);return m=m.map((function(e){if(e.id===t.data.pipelineId){var n=Vn(e.nodes,{type:"DELETE_NODES",data:{nodesToDelete:t.data.nodesToAdd}}),i=$n(e.comments,{type:"DELETE_COMMENTS",data:{commentsToDelete:t.data.commentsToAdd}}),o=Xn(e.links,{type:"REMOVE_LINKS",data:{linksToDelete:t.data.linksToAdd}});return n=Vn(n,{type:"ADD_SUPERNODES",data:{supernodesToAdd:[t.data.supernodeToDelete]}}),o=Xn(o,{type:"ADD_LINKS",data:{linksToAdd:t.data.linksToRemove}}),n=Vn(n,{type:"SET_NODE_POSITIONS",data:{nodePositions:t.data.oldObjectPositions}}),i=$n(i,{type:"SET_COMMENT_POSITIONS",data:{commentPositions:t.data.oldObjectPositions}}),o=Xn(o,{type:"SET_LINK_POSITIONS",data:{linkPositions:t.data.oldLinkPositions}}),Object.assign({},e,{nodes:n,comments:i,links:o})}return e})),Object.assign({},e,{pipelines:m});case"SET_OBJECTS_STYLE":case"SET_LINKS_STYLE":var v=Object.keys(t.data.pipelineObjIds),b=e.pipelines.map((function(e){return v.indexOf(e.id)>-1?(t.data.objIds=t.data.pipelineObjIds[e.id],t.data.pipelineId=e.id,Object.assign({},e,{nodes:Vn(e.nodes,t),comments:$n(e.comments,t),links:Xn(e.links,t)})):e}));return Object.assign({},e,{pipelines:b});case"SET_OBJECTS_MULTI_STYLE":case"SET_LINKS_MULTI_STYLE":var _=e.pipelines.map((function(e){return t.data.pipelineObjStyles.findIndex((function(t){return t.pipelineId===e.id}))>-1?(t.data.pipelineId=e.id,Object.assign({},e,{nodes:Vn(e.nodes,t),comments:$n(e.comments,t),links:Xn(e.links,t)})):e}));return Object.assign({},e,{pipelines:_});case"SET_NODES_MULTI_DECORATIONS":var k=e.pipelines.map((function(e){return t.data.pipelineNodeDecorations.findIndex((function(t){return t.pipelineId===e.id}))>-1?(t.data.pipelineId=e.id,Object.assign({},e,{nodes:Vn(e.nodes,t),comments:e.comments,links:e.links})):e}));return Object.assign({},e,{pipelines:k});case"SET_LINKS_MULTI_DECORATIONS":var P=e.pipelines.map((function(e){return t.data.pipelineLinkDecorations.findIndex((function(t){return t.pipelineId===e.id}))>-1?(t.data.pipelineId=e.id,Object.assign({},e,{nodes:e.nodes,comments:e.comments,links:Xn(e.links,t)})):e}));return Object.assign({},e,{pipelines:P});case"REMOVE_ALL_STYLES":var N=e.pipelines.map((function(e){return Object.assign({},e,{nodes:Vn(e.nodes,t),comments:$n(e.comments,t),links:Xn(e.links,t)})}));return Object.assign({},e,{pipelines:N});default:return e}};function Zn(e,t){return t.some((function(t){return t.id===e.id}))}var Qn=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0;if("SET_CONTEXT_MENU_DEF"===t.type){var n=t.data.menuDef.map((function(e){return Object.assign({},e)}));return Object.assign({},e,{menuDef:n})}return e},ei=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0;return"SET_RIGHT_FLYOUT_CONFIG"===t.type&&t.data.config?{content:t.data.config.content,isOpen:t.data.config.isOpen}:e},ti=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0;return"SET_BOTTOM_PANEL_CONFIG"===t.type&&t.data.config?{content:t.data.config.content,isOpen:t.data.config.isOpen}:e},ni=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"SET_CANVAS_INFO":return t.canvasInfoIdChanged||!ii(e,t.canvasInfo)?[{pipelineId:t.canvasInfo.primary_pipeline,pipelineFlowId:t.canvasInfo.id}]:e;case"SET_BREADCRUMBS":return t.data.breadcrumbs.map((function(e){return Object.assign({},e)}));case"ADD_BREADCRUMB":return[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e),[{pipelineId:t.data.pipelineId,supernodeId:t.data.supernodeId,supernodeParentPipelineId:t.data.supernodeParentPipelineId,externalUrl:t.data.externalUrl,label:t.data.label}]);case"ADD_BREADCRUMBS":return[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(t.data.addBreadcrumbs));case"SET_TO_INDEXED_BREADCRUMB":return t.data.breadcrumbIndex>=0&&t.data.breadcrumbIndex<e.length?e.slice(0,t.data.breadcrumbIndex+1):e;case"SET_TO_PREVIOUS_BREADCRUMB":return e.length>1?e.slice(0,e.length-1):e;case"RESET_BREADCRUMB":return[{pipelineId:t.data.pipelineId}];default:return e}},ii=function(e,t){if(t&&t.pipelines&&Array.isArray(e)&&e.length>0&&e[e.length-1].pipelineId){var n=e[e.length-1].pipelineId;return t.pipelines.findIndex((function(e){return e.id===n}))>-1}return!1},oi=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=arguments.length>1?arguments[1]:void 0;return"SET_CANVAS_CONFIG_INFO"===t.type?t.data.canvasConfig:e},ai=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"SET_ZOOM":case"SET_TOOLBAR_CONFIG":return Object.assign({},e,{config:t.data.toolbarConfig});default:return e}},ri=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"CLEAR_NOTIFICATION_MESSAGES":return[];case"SET_NOTIFICATION_MESSAGES":return t.data.messages.forEach((function(e){return si(e)})),t.data.messages;case"DELETE_NOTIFICATION_MESSAGES":var n=Array.isArray(t.data.ids)?t.data.ids:[t.data.ids],i=e.filter((function(e){return!n.includes(e.id)}));return i;default:return e}};function si(e){return null!==e.type&&""!==e.type&&void 0!==e.type||(e.type="unspecified"),e}var di=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"SET_CANVAS_INFO":return t.canvasInfoIdChanged?{}:e;case"CLEAR_SELECTIONS":case"SET_BREADCRUMBS":case"ADD_BREADCRUMB":case"ADD_BREADCRUMBS":case"SET_TO_INDEXED_BREADCRUMB":case"SET_TO_PREVIOUS_BREADCRUMB":case"RESET_BREADCRUMB":return{};case"ADD_PASTED_OBJECTS":case"SET_SELECTIONS":return{pipelineId:t.pipelineId,selections:(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(t.data.selections)};case"DELETE_OBJECT":if(e.selections){var n=e.selections.filter((function(e){return t.data.id!==e}));return{pipelineId:e.pipelineId,selections:n}}return e;case"DELETE_AND_UPDATE_OBJECTS":if(e.selections){var i=[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(t.data.linksToDelete),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(t.data.supernodesToDelete),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(t.data.nodesToDelete),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(t.data.commentsToDelete)),o=e.selections.filter((function(e){return!i.some((function(t){return t.id===e}))}));return{pipelineId:e.pipelineId,selections:o}}return e;default:return e}},ci=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"SET_NOTIFICATION_PANEL_CONFIG":return Object.assign({},e,{config:t.data.notificationPanelConfig});case"SET_NOTIFICATION_PANEL_OPEN_STATE":return Object.assign({},e,{isOpen:t.data.isOpen});default:return e}},li=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"ADD_EXTERNAL_PIPELINE_FLOW":var n=Object.assign({},t.newPipelineFlow);return[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e),[n]);case"REMOVE_EXTERNAL_PIPELINE_FLOW":return e.filter((function(e){return e.url!==t.externalUrl}));case"REPLACE_SN_AND_PIPELINES":var i=e.filter((function(e){return!t.data.extPipelineFlowsToDelete.some((function(t){return t.url===e.url}))})),o=[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(i),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(t.data.extPipelineFlowsToAdd));return o;case"ADD_OBJECTS_AND_UPDATE":case"ADD_SUPERNODES":return[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(t.data.extPipelineFlowsToAdd));case"DELETE_PASTED_OBJECTS":case"DELETE_OBJECTS_AND_UPDATE":case"DELETE_SUPERNODES":return e.filter((function(e){return!t.data.extPipelineFlowsToDelete.some((function(t){return e.url===t.url}))}));case"DECONSTRUCT_SUPERNODE":return e.filter((function(e){return e.id!==t.data.extPipelineFlowToDelete.id}));case"RECONSTRUCT_SUPERNODE":return[].concat((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(e),[t.data.extPipelineFlowToDelete]);case"SET_CANVAS_INFO":return t.canvasInfoIdChanged?[]:e;default:return e}},ui=function(){function n(e){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,n);var i=(0,redux__WEBPACK_IMPORTED_MODULE_10__.combineReducers)({selectioninfo:di,canvasconfig:oi,canvasinfo:Jn,breadcrumbs:ni,palette:Gn,notifications:ri,notificationpanel:ci,externalpipelineflows:li,tooltip:Bn,canvastoolbar:ai,contextmenu:Qn,rightflyout:ei,bottompanel:ti}),o={selectioninfo:{},canvasinfo:e,canvasconfig:ot.getDefaultCanvasConfig(),breadcrumbs:[{pipelineId:e.primary_pipeline,pipelineFlowId:e.id}],palette:{content:{}},notifications:[],notificationpanel:{isOpen:!1,config:{}},externalpipelineflows:[],tooltip:{},canvastoolbar:{},contextmenu:{menuDef:[]},rightflyout:{},bottompanel:{}},a=!1;"undefined"!=typeof window&&(a=window.__REDUX_DEVTOOLS_EXTENSION__&&window.__REDUX_DEVTOOLS_EXTENSION__()),this.store=(0,redux__WEBPACK_IMPORTED_MODULE_10__.createStore)(i,o,a),this.dispatch=this.dispatch.bind(this)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(n,[{key:"dispatch",value:function(e){this.store.dispatch(e)}},{key:"subscribe",value:function(e){return this.store.subscribe(e)}},{key:"getStore",value:function(){return this.store}},{key:"getPalette",value:function(){return (0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(this.store.getState().palette)}},{key:"getPaletteData",value:function(){return (0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(this.store.getState().palette.content)}},{key:"getCanvasInfo",value:function(){return (0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(this.store.getState().canvasinfo)}},{key:"getPipelineFlowId",value:function(){return this.store.getState().canvasinfo.id}},{key:"getPrimaryPipelineId",value:function(){return this.store.getState().canvasinfo.primary_pipeline}},{key:"getZoom",value:function(e){var t=this.getNonClonedPipeline(e);return t?(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(t.zoom):null}},{key:"getNonClonedPipeline",value:function(e){return this.store.getState().canvasinfo.pipelines.find((function(t){return t.id===e}))}},{key:"getNodes",value:function(e){var t=this.getNonClonedPipeline(e);return t&&t.nodes?(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(t.nodes):[]}},{key:"getNode",value:function(e,t){var n=this.getNonClonedPipeline(t),i=null;if(n&&n.nodes){var o=n.nodes.find((function(t){return t.id===e}));o&&(i=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(o))}return i}},{key:"getComments",value:function(e){var t=this.getNonClonedPipeline(e);return t&&t.comments?(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(t.comments):[]}},{key:"getComment",value:function(e,t){var n=this.getNonClonedPipeline(t),i=null;if(n&&n.comments){var o=n.comments.find((function(t){return t.id===e}));o&&(i=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(o))}return i}},{key:"getLinks",value:function(e){var t=this.getNonClonedPipeline(e);return t&&t.links?(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(t.links):[]}},{key:"getLink",value:function(e,t){var n=this.getNonClonedPipeline(t),i=null;if(n&&n.links){var o=n.links.find((function(t){return t.id===e}));o&&(i=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(o))}return i}},{key:"getBreadcrumbs",value:function(){return (0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(this.store.getState().breadcrumbs)}},{key:"getCanvasConfig",value:function(){return Object.assign({},this.store.getState().canvasconfig)}},{key:"getNodeLayout",value:function(){return this.cloneData(this.store.getState().canvasconfig.enableNodeLayout)}},{key:"getCanvasLayout",value:function(){return this.cloneData(this.store.getState().canvasconfig.enableCanvasLayout)}},{key:"isTooltipOpen",value:function(){return!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(this.store.getState().tooltip)}},{key:"getTooltip",value:function(){return this.cloneData(this.store.getState().tooltip)}},{key:"isRightFlyoutOpen",value:function(){return this.store.getState().rightflyout.isOpen}},{key:"isBottomPanelOpen",value:function(){return this.store.getState().bottompanel.isOpen}},{key:"getNotificationPanel",value:function(){return this.cloneData(this.store.getState().notificationpanel)}},{key:"getNotifications",value:function(){return this.store.getState().notifications.map((function(e,t){return Object.assign({},e)}))}},{key:"isNotificationPanelOpen",value:function(){return this.getNotificationPanel().isOpen}},{key:"getContextMenu",value:function(){return this.cloneData(this.store.getState().contextmenu)}},{key:"isContextMenuDisplayed",value:function(){return!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(this.store.getState().contextmenu.menuDef)}},{key:"getSelectionInfo",value:function(){return this.cloneData(this.store.getState().selectioninfo)}},{key:"getExternalPipelineFlows",value:function(){return this.cloneData(this.store.getState().externalpipelineflows)}},{key:"getExternalPipelineFlow",value:function(e){var t=this.store.getState().externalpipelineflows.find((function(t){return t.url===e}));return t?this.cloneData(t):null}},{key:"cloneData",value:function(e){return (0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(e)}}]),n}(),pi={$schema:"https://json-schema.org/draft-04/schema#",description:"WDP Pipeline Flow Schema",type:"object",id:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v1-schema.json",properties:{doc_type:{description:"Document type",type:"string"},version:{description:"Pipeline-flow schema version",enum:["1.0"]},json_schema:{description:"Refers to the JSON schema used to validate documents of this type",enum:["https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v1-schema.json"]},open_with_tool:{description:"Preferred authoring application",type:"string"},id:{description:"Document identifier, GUID recommended",type:"string"},primary_pipeline:{description:"Reference to the primary (main) pipeline flow within the document",type:"string"},pipelines:{description:"Array of pipelines",type:"array",minItems:1,items:{$ref:"#/definitions/pipeline_def"},uniqueItems:!0},schemas:{description:"Array of data record schemas used in the document",type:"array",minItems:0,items:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/datarecord-metadata/datarecord-metadata-v1-schema.json#/definitions/record_schema"},uniqueItems:!0},app_data:{$ref:"#/definitions/app_data_def"}},required:["doc_type","version","primary_pipeline","pipelines"],additionalProperties:!1,definitions:{pipeline_def:{description:"Definition of a single pipeline flow",type:"object",properties:{id:{description:"Unique identifier",type:"string"},runtime:{description:"Runtime associated with the operations in the current pipeline",type:"string"},nodes:{description:"Array of pipeline nodes",type:"array",minItems:0,items:{oneOf:[{$ref:"#/definitions/node_def"},{$ref:"#/definitions/supernode_def"},{$ref:"#/definitions/binding_entry_node_def"},{$ref:"#/definitions/binding_exit_node_def"},{$ref:"#/definitions/model_node_def"}]},uniqueItems:!0},app_data:{$ref:"#/definitions/app_data_def"}},required:["id","runtime","nodes"],additionalProperties:!1},node_def:{description:"Definition of a single pipeline node",type:"object",properties:{id:{description:"Unique identifier for node within the current pipeline",type:"string"},type:{description:"Node type - always 'execution_node' for non-model pipeline elements",enum:["execution_node"]},op:{description:"Operator type identifier",type:"string"},inputs:{$ref:"#/definitions/ports_def"},outputs:{$ref:"#/definitions/ports_def"},parameters:{description:"Input parameters for the operator",type:"object",properties:{},additionalProperties:!0},app_data:{$ref:"#/definitions/app_data_def"}},required:["id","type","op"],additionalProperties:!1},supernode_def:{description:"Definition of a supernode which serves as the entry point for a sub-pipeline",type:"object",properties:{id:{description:"Unique identifier for the supernode within the current pipeline",type:"string"},type:{description:"Node type - always 'super_node' for supernode elements",enum:["super_node"]},subflow_ref:{description:"Refers to the sub-flow associated with this supernode",type:"object",properties:{url:{description:"Reference to an external sub-flow. When not present the sub-flow is assumed to be in the current document. A value of 'app_defined' indicates a sub-flow identifier is present, but the controlling application will serve up the sub-pipeline in the form of a new pipeline-flow document (no sub-flow is present in the document).",type:"string"},pipeline_id_ref:{description:"Sub-flow identifier reference",type:"string"}},required:["pipeline_id_ref"]},inputs:{$ref:"#/definitions/bound_ports_def"},outputs:{$ref:"#/definitions/bound_ports_def"},app_data:{$ref:"#/definitions/app_data_def"}},required:["id","type","subflow_ref","inputs"],additionalProperties:!1},binding_entry_node_def:{description:"Defines an entry point (source) for a pipeline. Bindings can be concrete: the concrete_binding element is present on the port; or bindings can be abstract: bindings are performed externally via configuration or a wrapper document.",type:"object",properties:{id:{description:"Unique identifier for the binding within the current pipeline",type:"string"},type:{description:"Node type - always 'binding' for binding elements",enum:["binding"]},output:{$ref:"#/definitions/port_binding_def"},app_data:{$ref:"#/definitions/app_data_def"},connection:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-connection/pipeline-connection-v1-schema.json#/definitions/common_pipeline_connection_def"},data_asset:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-connection/pipeline-connection-v1-schema.json#/definitions/common_pipeline_data_asset_def"}},required:["id","type"],additionalProperties:!1},binding_exit_node_def:{description:"Defines an exit point (sink) for a pipeline. Bindings can be concrete: the concrete_binding element is present on the port; or bindings can be abstract: bindings are performed externally via configuration or a wrapper document.",type:"object",properties:{id:{description:"Unique identifier for the binding",type:"string"},type:{description:"Node type - always 'binding' for binding elements",enum:["binding"]},input:{$ref:"#/definitions/port_binding_def"},app_data:{$ref:"#/definitions/app_data_def"},connection:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-connection/pipeline-connection-v1-schema.json#/definitions/common_pipeline_connection_def"},data_asset:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-connection/pipeline-connection-v1-schema.json#/definitions/common_pipeline_data_asset_def"}},required:["id","type"],additionalProperties:!1},model_node_def:{description:"Definition of a single predictive model node",type:"object",properties:{id:{description:"Unique identifier for the model within the current pipeline",type:"string"},type:{description:"Node type - always 'model_node' for model pipeline elements",enum:["model_node"]},model_ref:{description:"Reference to the binary model",type:"string"},inputs:{$ref:"#/definitions/ports_def"},outputs:{$ref:"#/definitions/ports_def"},parameters:{description:"Input parameters for the operator",type:"object",properties:{},additionalProperties:!0},app_data:{$ref:"#/definitions/app_data_def"}},required:["id","type","inputs"],additionalProperties:!1},port_def:{description:"Port definition (input/output) on a node",type:"object",properties:{id:{description:"Unique identifier",type:"string"},schema_ref:{description:"Optional data record schema reference associated with the port",type:"string"},links:{description:"Array of links going into the node. Applies to input ports and exit bindings only.",type:"array",minItems:0,items:{$ref:"#/definitions/link_def"},uniqueItems:!0},app_data:{$ref:"#/definitions/app_data_def"}},required:["id"],additionalProperties:!1},port_binding_def:{description:"Definition (input/output) of a binding port on a node (bound or unbound). If no binding is present the port is bound at runtime via a configuration object or wrapper document.",type:"object",properties:{id:{description:"Unique identifier",type:"string"},schema_ref:{description:"Optional data record schema associated with the port",type:"string"},link:{$ref:"#/definitions/link_def"},app_data:{$ref:"#/definitions/app_data_def"}},required:["id"],additionalProperties:!1},ports_def:{type:"array",minItems:1,items:{$ref:"#/definitions/port_def"},uniqueItems:!0},bound_ports_def:{type:"array",minItems:1,items:{$ref:"#/definitions/bound_port_def"},uniqueItems:!0},bound_port_def:{description:"Port definition (input/output) on a node with optional pipeline port binding for supernodes",type:"object",properties:{id:{description:"Unique identifier",type:"string"},schema_ref:{description:"Optional data record schema associated with the port",type:"string"},links:{description:"Array of links going into the node. Applies to input ports and exit bindings only.",type:"array",minItems:1,items:{$ref:"#/definitions/link_def"},uniqueItems:!0},subflow_node_ref:{description:"Optional node id binding within the current document.",type:"string"},app_data:{$ref:"#/definitions/app_data_def"}},required:["id"],additionalProperties:!1},link_def:{description:"Node link definition",type:"object",properties:{pipeline_id_ref:{description:"id of the pipeline this link connects to",type:"string"},node_id_ref:{description:"id of a node this link connects to",type:"string"},port_id_ref:{description:"optional port id of a node this link connects to",type:"string"},app_data:{$ref:"#/definitions/app_data_def"}},required:["node_id_ref"],additionalProperties:!1},app_data_def:{description:"Object containing app-specific data",type:"object",properties:{ui_data:{anyOf:[{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v1-schema.json#/definitions/pipeline_overview_def"},{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v1-schema.json#/definitions/pipeline_def"},{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v1-schema.json#/definitions/port_info_def"},{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v1-schema.json#/definitions/node_info_def"}]}},additionalProperties:!0}}},fi={$schema:"https://json-schema.org/draft-04/schema#",description:"WDP Pipeline Flow UI Schema. Defines UI-only constructs for pipeline flow documents.",type:"object",id:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v1-schema.json#",properties:{},additionalProperties:!0,definitions:{pipeline_overview_def:{description:"Top level UI information",type:"object",properties:{name:{description:"User-defined name",type:"string"},description:{description:"User-defined description",type:"string"},class_name:{description:"CSS class name",type:"string"}},additionalProperties:!0},pipeline_def:{description:"Pipeline level UI information",type:"object",properties:{zoom:{description:"Zoom factor",type:"integer"},comments:{description:"Array of Comments, optionally associated with nodes",type:"array",minItems:0,items:{$ref:"#/definitions/comment_def"},uniqueItems:!0}},additionalProperties:!0},port_info_def:{description:"Additional UI info for ports",type:"object",properties:{cardinality:{description:"Property to capture how many data assets are allowed for this port, e.g., min: 1, max:1 implies you must supply 1 and only 1; min:0, max:1 implies it is optional and a max of one, min:0, max:-1 means it is optional and you can may have any number of data assets. The default value is 1:1 for inputs and 1:-1 for outputs.",type:"object",properties:{min:{description:"Minimum data sets that are required for this port",type:"integer",default:1},max:{description:"Maximum data sets that are allowed on this port. A negative value indicates unlimited. The default value is 1 for inputs and -1 for outputs.",type:"integer"}},additionalProperties:!1},class_name:{description:"CSS class name",type:"string"},label:{description:"Port name",type:"string"}},additionalProperties:!0},node_info_def:{description:"object with app-specific UI-information",type:"object",properties:{label:{description:"User-defined label",type:"string"},description:{description:"User-defined description",type:"string"},class_name:{description:"CSS class name",type:"string"},image:{description:"Image name (do not embed images inline!)",type:"string"},x_pos:{description:"x-position",type:"integer"},y_pos:{description:"y-position",type:"integer"},attributes:{description:"additional attributes",type:"string"},associations:{description:"Array of non-data node linkage",type:"array",minItems:0,items:{$ref:"#/definitions/association_def"}},messages:{descriptions:"An array of messages for the node",type:"array",minItems:0,items:{$ref:"#/definitions/message_def"},uniqueItems:!0},decorations:{description:"Array of decorations used to decorate nodes",type:"array",minItems:0,items:{$ref:"#/definitions/decoration_def"},uniqueItems:!0}},additionalProperties:!0},association_def:{description:"Non-data link",type:"object",properties:{id:{description:"Association identifier",type:"string"},node_ref:{description:"Target node id",type:"string"},class_name:{description:"CSS class name for link styling",type:"string"}},required:["id","node_ref"],additionalProperties:!1},decoration_def:{description:"Decoration used to decorate a node",type:"object",properties:{id:{description:"An identifier used as a token when a hotspot is used",type:"string"},hotspot:{description:"Indicates whether teh decorator is a hotspot or not. ie does it send an event to consuming app. when clicked",type:"boolean"},class_name:{description:"CSS class name for decoration styling",type:"string"},positions:{description:"Shows where the decoration is displayed with respect to the node",enum:["topLeft","topRight","bottomLeft","bottomRight"]},image:{description:"Image displayed at the decoration position",type:"string"}}},message_def:{description:"Node message definition",type:"object",properties:{id_ref:{description:"Name of the parameter that has the message",type:"string"},validation_id:{description:"Validation identifier from the fail_message validation section.",type:"string"},type:{description:"Type of message",enum:["info","error","warning"]},text:{description:"Message string",type:"string"}}},comment_def:{type:"object",properties:{id:{description:"Comment identifier. Must be unique.",type:"string"},x_pos:{description:"Horizontal comment position",type:"integer",minimum:0},y_pos:{description:"Vertical comment position",type:"integer",minimum:0},width:{description:"Comment width",type:"integer",minimum:10},height:{description:"Comment height",type:"integer",minimum:10},class_name:{description:"CSS class(es) to apply to the comment",type:"string"},attributes:{description:"Optional attributes to be added to this element. For example: \"attributes\": \"attr1='value1'; attr2='value2'\"",type:"string"},content:{description:"Comment content",type:"string"},associated_id_refs:{description:"Optional array of associated node id references",type:"array",minItems:0,items:{$ref:"#/definitions/comment_link_def"},uniqueItems:!0}},required:["id","x_pos","y_pos","width","height"],additionalProperties:!0},comment_link_def:{description:"Comment link definition",type:"object",properties:{node_ref:{description:"Node reference",type:"string"},class_name:{description:"CSS class name for link styling",type:"string"}},required:["node_ref"],additionalProperties:!0}}},hi={$schema:"https://json-schema.org/draft-04/schema#",id:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-connection/pipeline-connection-v1-schema.json#",title:"Watson Data Platform Pipeline Connection Schema",description:"Connection schema for pipelines in the Watson Data Platform",definitions:{common_pipeline_connection_def:{description:"Details of the connection to use for a pipeline binding node.",properties:{app_data:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v1-schema.json#/definitions/app_data_def"},ref:{description:"A reference to a connection by ID.",type:"string"},catalog_ref:{description:"If ref is set, this refers to the ID of the catalog which contains the connection. If neither this attribute nor project_ref are specified, the connection will be assumed to exist in the project or catalog which contains the pipeline.",type:"string"},project_ref:{description:"If ref is set, this refers to the ID of the project which contains the connection. If neither this attribute nor catalog_ref are specified, the connection will be assumed to exist in the project or catalog which contains the pipeline.",type:"string"},properties:{description:"The properties for the connection. The specific properties allowed depend on the type of connection referenced.",additionalProperties:{type:"object"},type:"object"}},required:["ref"],type:"object"},common_pipeline_data_asset_def:{description:"Details of the data asset contained in a catalog or project to use for a pipeline binding node.",properties:{app_data:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v1-schema.json#/definitions/app_data_def"},ref:{description:"A reference to a data asset by ID.",type:"string"},catalog_ref:{description:"If ref is set, this refers to the ID of the catalog which contains the data asset. If neither this attribute nor project_ref are specified, the data asset will be assumed to exist in the project or catalog which contains the pipeline.",type:"string"},project_ref:{description:"If ref is set, this refers to the ID of the project which contains the data asset. If neither this attribute nor catalog_ref are specified, the data asset will be assumed to exist in the project or catalog which contains the pipeline.",type:"string"},properties:{description:"Properties controlling how the data asset is used.",type:"object",additionalProperties:{type:"object"},properties:{attachment_ref:{description:"The ID of the data asset attachment to use. If not specified and used as a source, the first suitable attachment found will be used. If not specified and used as a target, a new attachment will be created.",type:"string"},name:{description:"Specifies the name of the data asset to read, create or update if ref is unset.",type:"string",default:!1},no_write_schema:{description:"When used as a target, whether to update the data asset with the schema when a run completes or not (will be automatically updated if not supplied by caller).",type:"boolean",default:!1},no_write_status:{description:"When used as a target, whether to update the data asset with the status when a run completes or not (will be automatically updated if not supplied by caller).",type:"boolean",default:!1}}}},type:"object"}}},gi={$schema:"https://json-schema.org/draft-04/schema#",id:"https://api.dataplatform.ibm.com/schemas/common-pipeline/datarecord-metadata/datarecord-metadata-v1-schema.json#",title:"Watson Data Platform Datarecord Metadata Schema",description:"Metadata schema for datarecords in the Watson Data Platform",definitions:{record_schema:{description:"Description of a datarecord including column types and metadata",type:"object",properties:{id:{description:"Unique identifier",type:"string"},name:{description:"Name of datarecord",type:"string"},json_schema:{description:"Refers to the JSON schema used to validate documents of this type",enum:["https://api.dataplatform.ibm.com/schemas/common-pipeline/datarecord-metadata/datarecord-metadata-v1-schema.json"],type:"string"},type:{description:"Always 'struct' for datarecord schema",type:"string"},fields:{description:"Array of field definitions",type:"array",minItems:0,items:{$ref:"#/definitions/field"},uniqueItems:!0}},required:["fields"]},field:{description:"Definition of a datarecord field",type:"object",properties:{name:{description:"Field name. Must be unique within the datarecord",type:"string"},type:{description:"Field type. Can be a primitive type (string, integer, double, date, time, timestamp, binary, boolean, or other)",type:"string"},nullable:{description:"Whether or not one can place null values into the field",type:"boolean",default:!1},metadata:{$ref:"#/definitions/metadata"}},required:["name","type"]},metadata:{description:"Additional field metadata",type:"object",properties:{description:{description:"Field description",type:"string"},measure:{description:"Field measurement level",enum:["range","discrete","flag","set","ordered-set","typeless","collection","geospatial","default"]},modeling_role:{description:"Field role for modeling",enum:["input","target","both","none","partition","split","frequency","record-id"]},max_length:{description:"Maximum length for fields. Length is unlimited when not present",type:"number"},decimal_precision:{description:"Precision for decimal types",type:"number"},decimal_scale:{description:"Scale for decimal types",type:"number"},values:{description:"Array of unique categorical values for the column",type:"array",minItems:0,items:{description:"A value discovered in the data",type:"string"},uniqueItems:!0},range:{description:"Minimum and maximum discovered values for scalar data",type:"object",properties:{min:{description:"Lowest value discovered in the data",type:"number"},max:{description:"Highest value discovered in the data",type:"number"}},required:["min","max"]}},required:[]}}},yi={$schema:"http://json-schema.org/draft-04/schema#",type:"object",description:"Abstract Canvas diagram schema",id:"http://api.dataplatform.ibm.com/schemas/common-canvas/palette/palette-v1-schema.json",properties:{categories:{description:"Array of palette categories",type:"array",minItems:0,items:{type:"object",properties:{category:{description:"The palette category that the items belong within",type:"string"},label:{description:"Category label",type:"string"},image:{description:"Encoded image or image reference for the category",type:"string"},nodetypes:{description:"Array of nodes within the current category",type:"array",items:{type:"object",properties:{label:{description:"Node label",type:"string"},description:{description:"Node description",type:"string"},type:{description:"Node classification type",enum:["binding","execution_node","super_node","model_node"]},operator_id_ref:{description:"Unique node type identifier",type:"string"},image:{description:"Encoded image or image reference for the node",type:"string"},subDiagramId:{description:"Optional sub diagram identifier.",type:"string"},input_ports:{description:"Array of node input ports",type:"array",minItems:0,items:{$ref:"#/definitions/port"}},output_ports:{description:"Array of node output ports",type:"array",minItems:0,items:{$ref:"#/definitions/port"}}},required:["label","image"]}}},required:["category","label"]}}},definitions:{port:{description:"Defines a node port for links",type:"object",properties:{id:{description:"Port identifier",type:"string"},label:{description:"Port long label",type:"string"},cardinality:{description:"Property to capture how many connections are allowed for this port, e.g., min: 1, max:1 implies you must supply 1 and only 1; min:0, max:1 implies it is optional and a max of one, min:0, max:-1 means it is optional and you can may have any number of connections. The default value is 1:1 for inputs and 1:-1 for outputs.",type:"object",properties:{min:{description:"Minimum data sets that are required for this port",type:"integer",default:1},max:{description:"Maximum data sets that are allowed on this port. A negative value indicates unlimited. The default value is 1 for inputs and -1 for outputs.",type:"integer"}},additionalProperties:!1}},required:["id"]}}},mi={$schema:"https://json-schema.org/draft-04/schema#",description:"WDP Pipeline Flow Schema",type:"object",id:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v2-schema.json",properties:{doc_type:{description:"Document type",type:"string"},version:{description:"Pipeline-flow schema version",enum:["2.0"]},json_schema:{description:"Refers to the JSON schema used to validate documents of this type",enum:["https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v2-schema.json"]},open_with_tool:{description:"Preferred authoring application",type:"string"},id:{description:"Document identifier, GUID recommended",type:"string"},parameters:{description:"Parameters for the flow document",type:"object",properties:{},additionalProperties:!0},primary_pipeline:{description:"Reference to the primary (main) pipeline flow within the document",type:"string"},pipelines:{description:"Array of pipelines",type:"array",minItems:1,items:{$ref:"#/definitions/pipeline_def"},uniqueItems:!0},schemas:{description:"Array of data record schemas used in the document",type:"array",minItems:0,items:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/datarecord-metadata/datarecord-metadata-v2-schema.json#/definitions/record_schema"},uniqueItems:!0},runtimes:{description:"Array of runtime objects referred to in the document",type:"array",minItems:0,items:{$ref:"#/definitions/runtime_def"},uniqueItems:!0},external_parameters:{description:"Array of parameterized property references",type:"array",minItems:0,items:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/parameters/parameters-v2-schema.json#/definitions/param_property_ref"},uniqueItems:!0},app_data:{$ref:"#/definitions/app_data_def"}},required:["doc_type","version","primary_pipeline","pipelines"],additionalProperties:!1,definitions:{pipeline_def:{description:"Definition of a single pipeline flow",type:"object",properties:{id:{description:"Unique identifier",type:"string"},name:{description:"User-readable name",type:"string"},runtime_ref:{description:"Reference to the id of the runtime associated with the operations in the current pipeline",type:"string"},nodes:{description:"Array of pipeline nodes",type:"array",minItems:0,items:{oneOf:[{$ref:"#/definitions/node_def"},{$ref:"#/definitions/supernode_def"},{$ref:"#/definitions/binding_entry_node_def"},{$ref:"#/definitions/binding_exit_node_def"},{$ref:"#/definitions/model_node_def"}]},uniqueItems:!0},parameters:{description:"Parameters for the pipeline",type:"object",properties:{},additionalProperties:!0},app_data:{$ref:"#/definitions/app_data_def"}},required:["id","runtime_ref","nodes"],additionalProperties:!1},node_def:{description:"Definition of a single pipeline node",type:"object",properties:{id:{description:"Unique identifier for node within the current pipeline",type:"string"},type:{description:"Node type - always 'execution_node' for non-model pipeline elements",enum:["execution_node"]},op:{description:"Operator type identifier",type:"string"},inputs:{$ref:"#/definitions/ports_def"},outputs:{$ref:"#/definitions/ports_def"},parameters:{description:"Input parameters for the operator",type:"object",properties:{},additionalProperties:!0},runtime_ref:{description:"Optional reference to the id of the runtime associated with the current node",type:"string"},app_data:{$ref:"#/definitions/app_data_def"}},required:["id","type","op"],additionalProperties:!1},supernode_def:{description:"Definition of a supernode which serves as the entry point for a sub-pipeline",type:"object",properties:{id:{description:"Unique identifier for the supernode within the current pipeline",type:"string"},type:{description:"Node type - always 'super_node' for supernode elements",enum:["super_node"]},open_with_tool:{description:"Name of the tool which can be used to view or edit the sub-flow for this supernode. The default is 'canvas'",type:"string"},subflow_ref:{description:"Refers to the sub-flow associated with this supernode",type:"object",properties:{url:{description:"Reference to an external sub-flow. When not present the sub-flow is assumed to be in the current document. A value of 'app_defined' indicates a sub-flow identifier is present, but the controlling application will serve up the sub-pipeline in the form of a new pipeline-flow document (no sub-flow is present in the document).",type:"string"},pipeline_id_ref:{description:"Sub-flow identifier reference",type:"string"}},required:["pipeline_id_ref"]},inputs:{$ref:"#/definitions/bound_ports_def"},outputs:{$ref:"#/definitions/bound_ports_def"},parameters:{description:"Input parameters for the supernode",type:"object",properties:{},additionalProperties:!0},app_data:{$ref:"#/definitions/app_data_def"}},required:["id","type","subflow_ref","inputs"],additionalProperties:!1},binding_entry_node_def:{description:"Defines an entry point (source) for a pipeline. Bindings can be concrete: the concrete_binding element is present on the port; or bindings can be abstract: bindings are performed externally via configuration or a wrapper document.",type:"object",properties:{id:{description:"Unique identifier for the binding within the current pipeline",type:"string"},type:{description:"Node type - always 'binding' for binding elements",enum:["binding"]},outputs:{$ref:"#/definitions/ports_def"},app_data:{$ref:"#/definitions/app_data_def"},connection:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-connection/pipeline-connection-v2-schema.json#/definitions/common_pipeline_connection_def"},data_asset:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-connection/pipeline-connection-v2-schema.json#/definitions/common_pipeline_data_asset_def"},op:{description:"Binding node type identifier",type:"string"},parameters:{description:"Parameters for the entry binding node",type:"object",properties:{},additionalProperties:!0}},required:["id","type"],additionalProperties:!1},binding_exit_node_def:{description:"Defines an exit point (sink) for a pipeline. Bindings can be concrete: the concrete_binding element is present on the port; or bindings can be abstract: bindings are performed externally via configuration or a wrapper document.",type:"object",properties:{id:{description:"Unique identifier for the binding within the current pipeline",type:"string"},type:{description:"Node type - always 'binding' for binding elements",enum:["binding"]},inputs:{$ref:"#/definitions/ports_def"},app_data:{$ref:"#/definitions/app_data_def"},connection:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-connection/pipeline-connection-v2-schema.json#/definitions/common_pipeline_connection_def"},data_asset:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-connection/pipeline-connection-v2-schema.json#/definitions/common_pipeline_data_asset_def"},op:{description:"Binding node type identifier",type:"string"},parameters:{description:"Parameters for the binding exit node",type:"object",properties:{},additionalProperties:!0}},required:["id","type"],additionalProperties:!1},model_node_def:{description:"Definition of a single predictive model node",type:"object",properties:{id:{description:"Unique identifier for the model within the current pipeline",type:"string"},type:{description:"Node type - always 'model_node' for model pipeline elements",enum:["model_node"]},model_ref:{description:"Reference to the binary model",type:"string"},inputs:{$ref:"#/definitions/ports_def"},outputs:{$ref:"#/definitions/ports_def"},parameters:{description:"Input parameters for the operator",type:"object",properties:{},additionalProperties:!0},runtime_ref:{description:"Reference to the runtime associated with the current node",type:"string"},app_data:{$ref:"#/definitions/app_data_def"}},required:["id","type","inputs"],additionalProperties:!1},port_def:{description:"Port definition (input/output) on a node",type:"object",properties:{id:{description:"Unique identifier",type:"string"},schema_ref:{description:"Optional data record schema reference associated with the port",type:"string"},links:{description:"Array of links going into the node. Applies to input ports and exit bindings only.",type:"array",minItems:0,items:{$ref:"#/definitions/link_def"},uniqueItems:!0},parameters:{description:"Parameters for the port",type:"object",properties:{},additionalProperties:!0},app_data:{$ref:"#/definitions/app_data_def"}},required:["id"],additionalProperties:!1},ports_def:{type:"array",minItems:1,items:{$ref:"#/definitions/port_def"},uniqueItems:!0},bound_ports_def:{type:"array",minItems:1,items:{$ref:"#/definitions/bound_port_def"},uniqueItems:!0},bound_port_def:{description:"Port definition (input/output) on a node with optional pipeline port binding for supernodes",type:"object",properties:{id:{description:"Unique identifier",type:"string"},schema_ref:{description:"Optional data record schema associated with the port",type:"string"},links:{description:"Array of links going into the node. Applies to input ports and exit bindings only.",type:"array",minItems:1,items:{$ref:"#/definitions/link_def"},uniqueItems:!0},subflow_node_ref:{description:"Optional node id binding within the current document.",type:"string"},parameters:{description:"Parameters for the binding port",type:"object",properties:{},additionalProperties:!0},app_data:{$ref:"#/definitions/app_data_def"}},required:["id"],additionalProperties:!1},link_def:{description:"Node link definition",type:"object",properties:{node_id_ref:{description:"id of a node this link connects to",type:"string"},port_id_ref:{description:"optional port id of a node this link connects to",type:"string"},link_name:{description:"optional link name (used in parameter sets when there are multiple input sources)",type:"string"},app_data:{$ref:"#/definitions/app_data_def"}},required:["node_id_ref"],additionalProperties:!1},app_data_def:{description:"Object containing app-specific data",type:"object",properties:{ui_data:{anyOf:[{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v2-schema.json#/definitions/pipeline_overview_def"},{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v2-schema.json#/definitions/pipeline_def"},{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v2-schema.json#/definitions/port_info_def"},{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v2-schema.json#/definitions/node_info_def"},{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v2-schema.json#/definitions/runtime_info_def"}]}},additionalProperties:!0},runtime_def:{description:"Runtime associated with the operations in the current pipeline",type:"object",properties:{id:{description:"Unique internal runtime identifier",type:"string"},name:{description:"The runtime name",type:"string"},version:{description:"The runtime version. When not present the latest version is assumed",type:"string"},app_data:{$ref:"#/definitions/app_data_def"}},required:["id","name"]}}},vi={$schema:"https://json-schema.org/draft-04/schema#",description:"WDP Pipeline Flow UI Schema. Defines UI-only constructs for pipeline flow documents.",type:"object",id:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v2-schema.json#",properties:{},additionalProperties:!0,definitions:{pipeline_overview_def:{description:"Top level UI information",type:"object",properties:{name:{description:"User-defined name",type:"string"},description:{description:"User-defined description",type:"string"},class_name:{description:"CSS class name",type:"string"}},additionalProperties:!0},pipeline_def:{description:"Pipeline level UI information",type:"object",properties:{zoom:{description:"Zoom factor",type:"integer"},comments:{description:"Array of Comments, optionally associated with nodes",type:"array",minItems:0,items:{$ref:"#/definitions/comment_def"},uniqueItems:!0}},additionalProperties:!0},port_info_def:{description:"Additional UI info for ports",type:"object",properties:{cardinality:{description:"Property to capture how many data assets are allowed for this port, e.g., min: 1, max:1 implies you must supply 1 and only 1; min:0, max:1 implies it is optional and a max of one, min:0, max:-1 means it is optional and you can may have any number of data assets. The default value is 1:1 for inputs and 1:-1 for outputs.",type:"object",properties:{min:{description:"Minimum data sets that are required for this port",type:"integer",default:1},max:{description:"Maximum data sets that are allowed on this port. A negative value indicates unlimited. The default value is 1 for inputs and -1 for outputs.",type:"integer"}},additionalProperties:!1},class_name:{description:"CSS class name",type:"string"},label:{description:"Port name",type:"string"}},additionalProperties:!0},node_info_def:{description:"object with app-specific UI-information",type:"object",properties:{label:{description:"User-defined label",type:"string"},description:{description:"User-defined description",type:"string"},class_name:{description:"CSS class name",type:"string"},image:{description:"Image name (do not embed images inline!)",type:"string"},x_pos:{description:"x-position",type:"integer"},y_pos:{description:"y-position",type:"integer"},is_expanded:{description:"Indicates whether a supernode is shown in expanded state or as a regular node.",type:"boolean"},expanded_height:{description:"Height of expanded supernode. If not provided an appropriate height is calculated.",type:"string"},expanded_width:{description:"Width of expanded supernode. If not provided an appropriate width is calculated.",type:"string"},attributes:{description:"additional attributes",type:"string"},associations:{description:"Array of non-data node linkage",type:"array",minItems:0,items:{$ref:"#/definitions/association_def"}},messages:{descriptions:"An array of messages for the node",type:"array",minItems:0,items:{$ref:"#/definitions/message_def"},uniqueItems:!0},ui_parameters:{description:"UI only parameter values for the node",type:"object",properties:{},additionalProperties:!0},decorations:{description:"Array of decorations used to decorate nodes",type:"array",minItems:0,items:{$ref:"#/definitions/decoration_def"},uniqueItems:!0}},additionalProperties:!0},runtime_info_def:{description:"Runtime information",type:"object",properties:{},required:[],additionalProperties:!0},association_def:{description:"Non-data link",type:"object",properties:{id:{description:"Association identifier",type:"string"},node_ref:{description:"Target node id",type:"string"},class_name:{description:"CSS class name for link styling",type:"string"}},required:["id","node_ref"],additionalProperties:!1},decoration_def:{description:"Decoration used to decorate a node",type:"object",properties:{id:{description:"An identifier used to identify the decoration",type:"string"},hotspot:{description:"Indicates whether the decorator is a hotspot or not. ie does it send an event to consuming app. when clicked",type:"boolean"},class_name:{description:"CSS class name for decoration styling",type:"string"},position:{description:"Shows where the decoration is displayed with respect to the node",enum:["topLeft","topRight","bottomLeft","bottomRight"]},x_pos:{description:"X position of the decorator relative to the node's top left corner. If provided, this is used in preference to the position field.",type:"integer"},y_pos:{description:"Y position of the decorator relative to the node's top left corner. If provided, this is used in preference to the position field.",type:"integer"},image:{description:"Image displayed at the decoration position. Provide either this or a label.",type:"string"},label:{description:"Label displayed at the decoration position. Provide either this or an image.",type:"string"}}},message_def:{description:"Node message definition",type:"object",properties:{id_ref:{description:"Name of the parameter that has the message",type:"string"},validation_id:{description:"Validation identifier from the fail_message validation section.",type:"string"},type:{description:"Type of message",enum:["info","error","warning"]},text:{description:"Message string",type:"string"}},required:["id_ref","type","text"]},comment_def:{type:"object",properties:{id:{description:"Comment identifier. Must be unique.",type:"string"},x_pos:{description:"Horizontal comment position",type:"integer",minimum:0},y_pos:{description:"Vertical comment position",type:"integer",minimum:0},width:{description:"Comment width",type:"integer",minimum:10},height:{description:"Comment height",type:"integer",minimum:10},class_name:{description:"CSS class(es) to apply to the comment",type:"string"},attributes:{description:"Optional attributes to be added to this element. For example: \"attributes\": \"attr1='value1'; attr2='value2'\"",type:"string"},content:{description:"Comment content",type:"string"},associated_id_refs:{description:"Optional array of associated node id references",type:"array",minItems:0,items:{$ref:"#/definitions/comment_link_def"},uniqueItems:!0}},required:["id","x_pos","y_pos","width","height"],additionalProperties:!0},comment_link_def:{description:"Comment link definition",type:"object",properties:{node_ref:{description:"Node reference",type:"string"},class_name:{description:"CSS class name for link styling",type:"string"}},required:["node_ref"],additionalProperties:!0}}},bi={$schema:"https://json-schema.org/draft-04/schema#",id:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-connection/pipeline-connection-v2-schema.json",title:"Watson Data Platform Pipeline Connection Schema",description:"Connection schema for pipelines in the Watson Data Platform",definitions:{common_pipeline_connection_def:{description:"Details of the connection to use for a pipeline binding node.",properties:{name:{description:"A name tag for disambiguating connections",type:"string"},app_data:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v2-schema.json#/definitions/app_data_def"},ref:{description:"A reference to a connection by ID.",type:"string"},catalog_ref:{description:"If ref is set, this refers to the ID of the catalog which contains the connection. If neither this attribute nor project_ref are specified, the connection will be assumed to exist in the project or catalog which contains the pipeline.",type:"string"},project_ref:{description:"If ref is set, this refers to the ID of the project which contains the connection. If neither this attribute nor catalog_ref are specified, the connection will be assumed to exist in the project or catalog which contains the pipeline.",type:"string"},properties:{description:"The properties for the connection. The specific properties allowed depend on the type of connection referenced.",additionalProperties:{type:"object"},type:"object"}},required:["ref"],type:"object"},common_pipeline_data_asset_def:{description:"Details of the data asset contained in a catalog or project to use for a pipeline binding node.",properties:{app_data:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v2-schema.json#/definitions/app_data_def"},ref:{description:"A reference to a data asset by ID.",type:"string"},catalog_ref:{description:"If ref is set, this refers to the ID of the catalog which contains the data asset. If neither this attribute nor project_ref are specified, the data asset will be assumed to exist in the project or catalog which contains the pipeline.",type:"string"},project_ref:{description:"If ref is set, this refers to the ID of the project which contains the data asset. If neither this attribute nor catalog_ref are specified, the data asset will be assumed to exist in the project or catalog which contains the pipeline.",type:"string"},properties:{description:"Properties controlling how the data asset is used.",type:"object",additionalProperties:{type:"object"},properties:{attachment_ref:{description:"The ID of the data asset attachment to use. If not specified and used as a source, the first suitable attachment found will be used. If not specified and used as a target, a new attachment will be created.",type:"string"},name:{description:"Specifies the name of the data asset to read, create or update if ref is unset.",type:"string",default:!1},no_write_schema:{description:"When used as a target, whether to update the data asset with the schema when a run completes or not (will be automatically updated if not supplied by caller).",type:"boolean",default:!1},no_write_status:{description:"When used as a target, whether to update the data asset with the status when a run completes or not (will be automatically updated if not supplied by caller).",type:"boolean",default:!1}}}},type:"object"}}},_i={$schema:"https://json-schema.org/draft-04/schema#",id:"https://api.dataplatform.ibm.com/schemas/common-pipeline/datarecord-metadata/datarecord-metadata-v2-schema.json",title:"Watson Data Platform Datarecord Metadata Schema",description:"Metadata schema for datarecords in the Watson Data Platform",definitions:{record_schema:{description:"Description of a datarecord including column types and metadata",type:"object",properties:{id:{description:"Unique identifier",type:"string"},name:{description:"Name of datarecord",type:"string"},json_schema:{description:"Refers to the JSON schema used to validate documents of this type",enum:["https://api.dataplatform.ibm.com/schemas/common-pipeline/datarecord-metadata/datarecord-metadata-v2-schema.json"],type:"string"},type:{description:"Always 'struct' for datarecord schema",type:"string"},fields:{description:"Array of field definitions",type:"array",minItems:0,items:{$ref:"#/definitions/field"},uniqueItems:!0},struct_types:{description:"The list of custom struct types to be used as field types",type:"object",patternProperties:{".":{type:"object",properties:{fields:{description:"Array of field definitions",type:"array",minItems:0,items:{$ref:"#/definitions/field"},uniqueItems:!0}}}}}},required:["id","fields"]},field:{description:"Definition of a datarecord field",type:"object",properties:{name:{description:"Field name. Must be unique within the datarecord",type:"string"},type:{description:"Field type. Can be a primitive type (string, integer, double, date, time, timestamp, binary, boolean, array[type], map[type, type]. The type can also be a reference to a struct_type declaration.)",type:"string"},nullable:{description:"Whether or not one can place null values into the field",type:"boolean",default:!1},metadata:{$ref:"#/definitions/metadata"}},required:["name","type"]},metadata:{description:"Additional field metadata",type:"object",properties:{description:{description:"Field description",type:"string"},measure:{description:"Field measurement level",enum:["range","discrete","flag","set","ordered-set","typeless","collection","geospatial","default"]},modeling_role:{description:"Field role for modeling",enum:["input","target","both","none","partition","split","frequency","record-id"]},max_length:{description:"Maximum length for fields. Length is unlimited when not present",type:"number"},decimal_precision:{description:"Precision for decimal types",type:"number"},decimal_scale:{description:"Scale for decimal types",type:"number"},values:{description:"Array of unique categorical values for the column",type:"array",minItems:0,items:{description:"A value discovered in the data",type:"string"},uniqueItems:!0},range:{description:"Minimum and maximum discovered values for scalar data",type:"object",properties:{min:{description:"Lowest value discovered in the data",type:"number"},max:{description:"Highest value discovered in the data",type:"number"}},required:["min","max"]},runtime_type:{description:"Type of runtime",type:"string"}},required:[]}}},ki={$schema:"http://json-schema.org/draft-04/schema#",type:"object",description:"Common Canvas palette schema",id:"http://api.dataplatform.ibm.com/schemas/common-canvas/palette/palette-v2-schema.json",version:{description:"Palette schema version",enum:["2.0"]},properties:{categories:{description:"Array of palette categories",type:"array",minItems:0,items:{type:"object",properties:{category:{description:"The palette category that the items belong within",type:"string"},label:{description:"Category label",type:"string"},image:{description:"Encoded image or image reference for the category",type:"string"},nodetypes:{description:"Array of nodes within the current category",type:"array",items:{type:"object",properties:{label:{description:"Node label",type:"string"},description:{description:"Node description",type:"string"},type:{description:"Node classification type",enum:["binding","execution_node","super_node","model_node"]},operator_id_ref:{description:"Unique node type identifier",type:"string"},image:{description:"Encoded image or image reference for the node",type:"string"},subDiagramId:{description:"Optional sub diagram identifier.",type:"string"},input_ports:{description:"Array of node input ports",type:"array",minItems:0,items:{$ref:"#/definitions/port"}},output_ports:{description:"Array of node output ports",type:"array",minItems:0,items:{$ref:"#/definitions/port"}}},required:["label","image"]}}},required:["category","label"]}}},definitions:{port:{description:"Defines a node port for links",type:"object",properties:{id:{description:"Port identifier",type:"string"},label:{description:"Port long label",type:"string"},cardinality:{description:"Property to capture how many connections are allowed for this port, e.g., min: 1, max:1 implies you must supply 1 and only 1; min:0, max:1 implies it is optional and a max of one, min:0, max:-1 means it is optional and you can may have any number of connections. The default value is 1:1 for inputs and 1:-1 for outputs.",type:"object",properties:{min:{description:"Minimum data sets that are required for this port",type:"integer",default:1},max:{description:"Maximum data sets that are allowed on this port. A negative value indicates unlimited. The default value is 1 for inputs and -1 for outputs.",type:"integer"}},additionalProperties:!1}},required:["id"]}}},Pi={$schema:"https://json-schema.org/draft-04/schema#",description:"WDP Pipeline Flow Schema",type:"object",id:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v3-schema.json",properties:{doc_type:{description:"Document type",type:"string"},version:{description:"Pipeline-flow schema version",enum:["3.0"]},json_schema:{description:"Refers to the JSON schema used to validate documents of this type",enum:["http://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v3-schema.json","https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v3-schema.json"]},open_with_tool:{description:"Preferred authoring application",type:"string"},id:{description:"Document identifier, GUID recommended",type:"string"},parameters:{description:"Parameters for the flow document",type:"object",properties:{},additionalProperties:!0},primary_pipeline:{description:"Reference to the primary (main) pipeline flow within the document",type:"string"},pipelines:{description:"Array of pipelines",type:"array",minItems:1,items:{$ref:"#/definitions/pipeline_def"},uniqueItems:!0},schemas:{description:"Array of data record schemas used in the document",type:"array",minItems:0,items:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/datarecord-metadata/datarecord-metadata-v3-schema.json#/definitions/record_schema"},uniqueItems:!0},runtimes:{description:"Array of runtime objects referred to in the document",type:"array",minItems:0,items:{$ref:"#/definitions/runtime_def"},uniqueItems:!0},external_paramsets:{description:"Array of parameter set references",type:"array",minItems:0,items:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/parameters/parametersets-v3-schema.json#/definitions/paramset_ref"},uniqueItems:!0},app_data:{description:"Object containing app-specific data",type:"object",properties:{ui_data:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v3-schema.json#/definitions/pipeline_overview_def"}},additionalProperties:!0}},required:["doc_type","version","primary_pipeline","pipelines"],additionalProperties:!1,definitions:{pipeline_def:{description:"Definition of a single pipeline flow",type:"object",properties:{id:{description:"Unique identifier",type:"string"},description:{description:"Deprecated - use description in pipeline-flow-ui-v3-schema.json#/definitions/pipeline_def instead.",type:"string",deprecated:!0},name:{description:"User-readable name",type:"string"},runtime_ref:{description:"Reference to the id of the runtime associated with the operations in the current pipeline",type:"string"},nodes:{description:"Array of pipeline nodes",type:"array",minItems:0,items:{$ref:"#/definitions/node_type_def"},uniqueItems:!0},parameters:{description:"Parameters for the pipeline",type:"object",properties:{},additionalProperties:!0},app_data:{description:"Object containing app-specific data",type:"object",properties:{ui_data:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v3-schema.json#/definitions/pipeline_def"}},additionalProperties:!0}},required:["id","runtime_ref","nodes"],additionalProperties:!1},node_type_def:{oneOf:[{$ref:"#/definitions/execution_node_def"},{$ref:"#/definitions/supernode_def"},{$ref:"#/definitions/binding_entry_node_def"},{$ref:"#/definitions/binding_exit_node_def"},{$ref:"#/definitions/model_node_def"}]},execution_node_def:{description:"Definition of a single execution pipeline node",type:"object",properties:{id:{description:"Unique identifier for node within the current pipeline",type:"string"},description:{description:"Deprecated - use description in pipeline-flow-ui-v3-schema.json#/definitions/node_info_def instead.",type:"string",deprecated:!0},type:{description:"Node type - always 'execution_node' for non-model pipeline elements",enum:["execution_node"]},op:{description:"Operator type identifier",type:"string"},inputs:{$ref:"#/definitions/ports_def"},outputs:{$ref:"#/definitions/ports_def"},parameters:{description:"Input parameters for the operator",type:"object",properties:{},additionalProperties:!0},runtime_ref:{description:"Optional reference to the id of the runtime associated with the current node",type:"string"},app_data:{description:"Object containing app-specific data",type:"object",properties:{ui_data:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v3-schema.json#/definitions/node_info_def"}},additionalProperties:!0}},required:["id","type","op"],additionalProperties:!1},supernode_def:{description:"Definition of a supernode which serves as the entry point for a sub-pipeline",type:"object",properties:{id:{description:"Unique identifier for the supernode within the current pipeline",type:"string"},description:{description:"Deprecated - use description in pipeline-flow-ui-v3-schema.json#/definitions/node_info_def instead.",type:"string",deprecated:!0},type:{description:"Node type - always 'super_node' for supernode elements",enum:["super_node"]},open_with_tool:{description:"Name of the tool which can be used to view or edit the sub-flow for this supernode. The default is 'canvas'",type:"string"},subflow_ref:{description:"Refers to the sub-flow associated with this supernode",type:"object",properties:{url:{description:"Reference to an external sub-flow. When not present the sub-flow is assumed to be in the current document. A value of 'app_defined' indicates a sub-flow identifier is present, but the controlling application will serve up the sub-pipeline in the form of a new pipeline-flow document (no sub-flow is present in the document).",type:"string"},pipeline_id_ref:{description:"Sub-flow identifier reference",type:"string"}},required:["pipeline_id_ref"]},inputs:{$ref:"#/definitions/bound_ports_def"},outputs:{$ref:"#/definitions/bound_ports_def"},parameters:{description:"Input parameters for the supernode",type:"object",properties:{},additionalProperties:!0},app_data:{description:"Object containing app-specific data",type:"object",properties:{ui_data:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v3-schema.json#/definitions/node_info_def"}},additionalProperties:!0}},required:["id","type","subflow_ref"],additionalProperties:!1},binding_entry_node_def:{description:"Defines an entry point (source) for a pipeline. Bindings can be concrete: the concrete_binding element is present on the port; or bindings can be abstract: bindings are performed externally via configuration or a wrapper document.",type:"object",properties:{id:{description:"Unique identifier for the binding within the current pipeline",type:"string"},description:{description:"Deprecated - use description in pipeline-flow-ui-v3-schema.json#/definitions/node_info_def instead.",type:"string",deprecated:!0},type:{description:"Node type - always 'binding' for binding elements",enum:["binding"]},outputs:{$ref:"#/definitions/ports_def"},app_data:{description:"Object containing app-specific data",type:"object",properties:{ui_data:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v3-schema.json#/definitions/node_info_def"}},additionalProperties:!0},connection:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-connection/pipeline-connection-v3-schema.json#/definitions/common_pipeline_connection_def"},data_asset:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-connection/pipeline-connection-v3-schema.json#/definitions/common_pipeline_data_asset_def"},op:{description:"Binding node type identifier",type:"string"},parameters:{description:"Parameters for the binding entry node",type:"object",properties:{},additionalProperties:!0}},required:["id","type","outputs"],additionalProperties:!1},binding_exit_node_def:{description:"Defines an exit point (sink) for a pipeline. Bindings can be concrete: the concrete_binding element is present on the port; or bindings can be abstract: bindings are performed externally via configuration or a wrapper document.",type:"object",properties:{id:{description:"Unique identifier for the binding within the current pipeline",type:"string"},description:{description:"Deprecated - use description in pipeline-flow-ui-v3-schema.json#/definitions/node_info_def instead.",type:"string",deprecated:!0},type:{description:"Node type - always 'binding' for binding elements",enum:["binding"]},inputs:{$ref:"#/definitions/ports_def"},outputs:{description:"An optional set of output ports, typically used for directing error information out of the binding node.",$ref:"#/definitions/ports_def"},app_data:{description:"Object containing app-specific data",type:"object",properties:{ui_data:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v3-schema.json#/definitions/node_info_def"}},additionalProperties:!0},connection:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-connection/pipeline-connection-v3-schema.json#/definitions/common_pipeline_connection_def"},data_asset:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-connection/pipeline-connection-v3-schema.json#/definitions/common_pipeline_data_asset_def"},op:{description:"Binding node type identifier",type:"string"},parameters:{description:"Parameters for the binding exit node",type:"object",properties:{},additionalProperties:!0}},required:["id","type","inputs"],additionalProperties:!1},model_node_def:{description:"Definition of a single predictive model node",type:"object",properties:{id:{description:"Unique identifier for the model within the current pipeline",type:"string"},description:{description:"Deprecated - use description in pipeline-flow-ui-v3-schema.json#/definitions/node_info_def instead.",type:"string",deprecated:!0},type:{description:"Node type - always 'model_node' for model pipeline elements",enum:["model_node"]},model_ref:{description:"Reference to the binary model",type:"string"},inputs:{$ref:"#/definitions/ports_def"},outputs:{$ref:"#/definitions/ports_def"},op:{description:"Node type identifier of modeling node that created this model.",type:"string"},parameters:{description:"Input parameters for the operator",type:"object",properties:{},additionalProperties:!0},runtime_ref:{description:"Reference to the runtime associated with the current node",type:"string"},app_data:{description:"Object containing app-specific data",type:"object",properties:{ui_data:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v3-schema.json#/definitions/node_info_def"}},additionalProperties:!0}},required:["id","type","inputs"],additionalProperties:!1},port_def:{description:"Port definition (input/output) on a node",type:"object",properties:{id:{description:"Unique identifier",type:"string"},schema_ref:{description:"Optional data record schema reference associated with the port",type:"string"},links:{description:"Array of links going into the node. Applies to input ports and exit bindings only.",type:"array",minItems:0,items:{$ref:"#/definitions/link_def"},uniqueItems:!0},parameters:{description:"Parameters for the port",type:"object",properties:{},additionalProperties:!0},app_data:{description:"Object containing app-specific data",type:"object",properties:{ui_data:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v3-schema.json#/definitions/port_info_def"}},additionalProperties:!0}},required:["id"],additionalProperties:!1},ports_def:{type:"array",minItems:0,items:{$ref:"#/definitions/port_def"},uniqueItems:!0},bound_ports_def:{type:"array",minItems:0,items:{$ref:"#/definitions/bound_port_def"},uniqueItems:!0},bound_port_def:{description:"Port definition (input/output) on a node with optional pipeline port binding for supernodes",type:"object",properties:{id:{description:"Unique identifier",type:"string"},schema_ref:{description:"Optional data record schema associated with the port",type:"string"},links:{description:"Array of links going into the node. Applies to input ports and exit bindings only.",type:"array",minItems:1,items:{$ref:"#/definitions/link_def"},uniqueItems:!0},subflow_node_ref:{description:"Optional node id binding within the current document.",type:"string"},parameters:{description:"Parameters for the binding port",type:"object",properties:{},additionalProperties:!0},app_data:{description:"Object containing app-specific data",type:"object",properties:{ui_data:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v3-schema.json#/definitions/port_info_def"}},additionalProperties:!0}},required:["id"],additionalProperties:!1},link_def:{description:"Node link definition",type:"object",properties:{id:{description:"Unique id of this link within the pipelineFlow. If omitted a new link id will be generated.",type:"string"},node_id_ref:{description:"id of a node this link connects to",type:"string"},port_id_ref:{description:"optional port id of a node this link connects to",type:"string"},link_name:{description:"optional link name (used in parameter sets when there are multiple input sources)",type:"string"},type_attr:{description:"Link type attribute",type:"string"},description:{description:"Deprecated - use description in pipeline-flow-ui-v3-schema.json#/definitions/node_link_info_def instead.",type:"string"},app_data:{description:"Object containing app-specific data",type:"object",properties:{ui_data:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v3-schema.json#/definitions/node_link_info_def"}},additionalProperties:!0}},required:["node_id_ref"],additionalProperties:!1},runtime_def:{description:"Runtime associated with the operations in the current pipeline",type:"object",properties:{id:{description:"Unique internal runtime identifier",type:"string"},name:{description:"The runtime name",type:"string"},version:{description:"The runtime version. When not present the latest version is assumed",type:"string"},app_data:{description:"Object containing app-specific data",type:"object",properties:{ui_data:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v3-schema.json#/definitions/runtime_info_def"}},additionalProperties:!0}},required:["id","name"]}}},Ii={$schema:"https://json-schema.org/draft-04/schema#",description:"WDP Pipeline Flow UI Schema. Defines UI-only constructs for pipeline flow documents.",type:"object",id:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-ui-v3-schema.json",properties:{},additionalProperties:!0,definitions:{pipeline_overview_def:{description:"Top level UI information",type:"object",properties:{name:{description:"User-defined name",type:"string"},description:{description:"User-defined description",type:"string"},class_name:{description:"CSS class name",type:"string"}},additionalProperties:!0},pipeline_def:{description:"Pipeline level UI information",type:"object",properties:{description:{description:"User-defined description",type:"string"},zoom:{oneOf:[{description:"Deprecated - use zoom object instead. Scale factor as a percentage. 100% is standard scale amount. Smaller values zoom out. Larger values zoom in.",type:"integer",deprecated:!0},{description:"A zoom object containing translation and scale amounts.",type:"object",properties:{x:{description:"Horizontal translation amount. Positive value moves right, negative to the left.",type:"number"},y:{description:"Vertical translation amount. Positive value moves down, negative moves up.",type:"number"},k:{description:"Scale amount. 1.0 is the standard scale amount. Smaller values zoom out. Larger values zoom in.",type:"number",minimum:.2,maximum:1.8}},required:["x","y","k"],additionalProperties:!1}]},comments:{description:"Array of Comments, optionally associated with nodes",type:"array",minItems:0,items:{$ref:"#/definitions/comment_def"},uniqueItems:!0}},additionalProperties:!0},port_info_def:{description:"Additional UI info for ports",type:"object",properties:{cardinality:{description:"Property to capture how many data assets are allowed for this port, e.g., min: 1, max:1 implies you must supply 1 and only 1; min:0, max:1 implies it is optional and a max of one, min:0, max:-1 means it is optional and you can may have any number of data assets. The default value is 1:1 for inputs and 1:-1 for outputs.",type:"object",properties:{min:{description:"Minimum data sets that are required for this port",type:"integer",default:1},max:{description:"Maximum data sets that are allowed on this port. A negative value indicates unlimited. The default value is 1 for inputs and -1 for outputs.",type:"integer"}},additionalProperties:!1},class_name:{description:"CSS class name",type:"string"},style:{description:"A 'style spec' object containing CSS strings to be applied to the SVG objects of the port.",type:["string","object"]},label:{description:"Port name",type:"string"}},additionalProperties:!0},node_info_def:{description:"object with app-specific UI-information",type:"object",properties:{label:{description:"User-defined label",type:"string"},description:{description:"User-defined description",type:"string"},class_name:{description:"CSS class name",type:"string"},style:{description:"A 'style spec' object containing CSS strings to be applied to the SVG objects of the node.",type:["string","object"]},image:{description:"Image name (do not embed images inline!)",type:"string"},x_pos:{description:"x-position",type:"number"},y_pos:{description:"y-position",type:"number"},is_expanded:{description:"Indicates whether a supernode is shown in expanded state or as a regular node.",type:"boolean"},expanded_height:{description:"Height of expanded supernode. If not provided an appropriate height is calculated.",type:"number"},expanded_width:{description:"Width of expanded supernode. If not provided an appropriate width is calculated.",type:"number"},is_resized:{description:"Indicates whether a node has been resized or not. If true, resize_width and resize_height are used for node display. If false, the default width and height are used.",type:"boolean"},resize_height:{description:"Height of resized node. The node will be displayed with this height, when is_resized is true, in preference to its default height.",type:"number"},resize_width:{description:"Width of resized node. The node will be displayed with this width, when is_resized is true, in preference to its default width.",type:"number"},attributes:{description:"additional attributes",type:"string"},associations:{description:"Array of non-data node linkage",type:"array",minItems:0,items:{$ref:"#/definitions/association_def"}},messages:{description:"An array of messages for the node",type:"array",minItems:0,items:{$ref:"#/definitions/message_def"},uniqueItems:!0},ui_parameters:{description:"UI only parameter values for the node",type:"object",properties:{},additionalProperties:!0},decorations:{description:"Array of decorations used to decorate nodes",type:"array",minItems:0,items:{$ref:"#/definitions/decoration_def"},uniqueItems:!0}},additionalProperties:!0},node_link_info_def:{description:"object with app-specific UI-information",type:"object",properties:{description:{description:"User-defined description",type:"string"},class_name:{description:"CSS class name",type:"string"},style:{description:"A 'style spec' object containing CSS strings to be applied to the SVG objects of the node to node link.",type:["string","object"]},decorations:{description:"Array of decorations used to decorate node links",type:"array",minItems:0,items:{$ref:"#/definitions/decoration_def"},uniqueItems:!0}},additionalProperties:!0},runtime_info_def:{description:"Runtime information",type:"object",properties:{},additionalProperties:!0},association_def:{description:"Non-data link",type:"object",properties:{id:{description:"Association identifier",type:"string"},node_ref:{description:"Target node id",type:"string"},class_name:{description:"CSS class name for link styling",type:"string"},style:{description:"A 'style spec' object containing CSS strings to be applied to the SVG objects of the association link.",type:["string","object"]},decorations:{description:"Array of decorations used to decorate association links",type:"array",minItems:0,items:{$ref:"#/definitions/decoration_def"},uniqueItems:!0}},required:["id","node_ref"],additionalProperties:!1},decoration_def:{description:"Decoration used to decorate a node",type:"object",properties:{id:{description:"An identifier used to identify the decoration",type:"string"},hotspot:{description:"Indicates whether the decorator is a hotspot or not. ie does it send an event to consuming app. when clicked",type:"boolean"},class_name:{description:"CSS class name for decoration styling",type:"string"},position:{description:"Indicates an anchor point on the node or link from which the decoration will be displayed. If x_pos and y_pos are not provided the decoration is displayed with a default offset from this position.",enum:["topLeft","topCenter","topRight","middleLeft","middleCenter","middleRight","bottomLeft","bottomCenter","bottomRight","source","middle","target"]},x_pos:{description:"X position of the decorator relative to the node's position field. If position is not provided it is relative to the 'topLeft' position",type:"integer"},y_pos:{description:"Y position of the decorator relative to the node's position field. If position is not provided it is relative to the 'topLeft' position",type:"integer"},image:{description:"Image displayed at the decoration position. Provide either this or a label.",type:"string"},label:{description:"Label displayed at the decoration position. Provide either this or an image.",type:"string"}}},message_def:{description:"Node message definition",type:"object",properties:{id_ref:{description:"Name of the parameter that has the message",type:"string"},validation_id:{description:"Validation identifier from the fail_message validation section.",type:"string"},type:{description:"Type of message",enum:["info","error","warning"]},text:{description:"Message string",type:"string"}},required:["id_ref","type","text"]},comment_def:{type:"object",properties:{id:{description:"Comment identifier. Must be unique.",type:"string"},x_pos:{description:"Horizontal comment position",type:"number"},y_pos:{description:"Vertical comment position",type:"number"},width:{description:"Comment width",type:"number",minimum:10},height:{description:"Comment height",type:"number",minimum:10},class_name:{description:"CSS class(es) to apply to the comment",type:"string"},style:{description:"A 'style spec' object containing CSS strings to be applied to the SVG objects of the comment.",type:["string","object"]},attributes:{description:"Optional attributes to be added to this element. For example: \"attributes\": \"attr1='value1'; attr2='value2'\"",type:"string"},content:{description:"Comment content",type:"string"},associated_id_refs:{description:"Optional array of associated node id references",type:"array",minItems:0,items:{$ref:"#/definitions/comment_link_def"},uniqueItems:!0}},required:["id","x_pos","y_pos","width","height"],additionalProperties:!0},comment_link_def:{description:"Comment link definition",type:"object",properties:{node_ref:{description:"Node reference",type:"string"},class_name:{description:"CSS class name for link styling",type:"string"},style:{description:"A 'style spec' object containing CSS strings to be applied to the SVG objects of the comment link.",type:["string","object"]}},required:["node_ref"],additionalProperties:!0}}},Ni={$schema:"https://json-schema.org/draft-04/schema#",id:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-connection/pipeline-connection-v3-schema.json",title:"Watson Data Platform Pipeline Connection Schema",description:"Connection schema for pipelines in the Watson Data Platform",definitions:{common_pipeline_connection_def:{description:"Details of the connection to use for a pipeline binding node.",properties:{name:{description:"A name tag for disambiguating connections",type:"string"},app_data:{$ref:"#/definitions/app_data_def"},ref:{description:"A reference to a connection by ID.",type:"string"},catalog_ref:{description:"If ref is set, this refers to the ID of the catalog which contains the connection. If neither this attribute nor project_ref are specified, the connection will be assumed to exist in the project or catalog which contains the pipeline.",type:"string"},project_ref:{description:"If ref is set, this refers to the ID of the project which contains the connection. If neither this attribute nor catalog_ref are specified, the connection will be assumed to exist in the project or catalog which contains the pipeline.",type:"string"},properties:{description:"The properties for the connection. The specific properties allowed depend on the type of connection referenced.",type:"object"}},required:["ref"],type:"object"},common_pipeline_data_asset_def:{description:"Details of the data asset contained in a catalog or project to use for a pipeline binding node.",properties:{app_data:{$ref:"#/definitions/app_data_def"},ref:{description:"A reference to a data asset by ID.",type:"string"},catalog_ref:{description:"If ref is set, this refers to the ID of the catalog which contains the data asset. If neither this attribute nor project_ref are specified, the data asset will be assumed to exist in the project or catalog which contains the pipeline.",type:"string"},project_ref:{description:"If ref is set, this refers to the ID of the project which contains the data asset. If neither this attribute nor catalog_ref are specified, the data asset will be assumed to exist in the project or catalog which contains the pipeline.",type:"string"},properties:{description:"Properties controlling how the data asset is used.",type:"object",additionalProperties:{type:"object"},properties:{attachment_ref:{description:"The ID of the data asset attachment to use. If not specified and used as a source, the first suitable attachment found will be used. If not specified and used as a target, a new attachment will be created.",type:"string"},name:{description:"Specifies the name of the data asset to read, create or update if ref is unset.",type:"string",default:!1},no_write_schema:{description:"When used as a target, whether to update the data asset with the schema when a run completes or not (will be automatically updated if not supplied by caller).",type:"boolean",default:!1},no_write_status:{description:"When used as a target, whether to update the data asset with the status when a run completes or not (will be automatically updated if not supplied by caller).",type:"boolean",default:!1}}}},type:"object"},app_data_def:{description:"Object containing app-specific data",type:"object",properties:{},additionalProperties:!0}}},Si={$schema:"https://json-schema.org/draft-04/schema#",type:"object",description:"Common Canvas palette schema",id:"https://api.dataplatform.ibm.com/schemas/common-canvas/palette/palette-v3-schema.json",properties:{version:{description:"Palette schema version",enum:["3.0"]},categories:{description:"Array of palette categories",type:"array",minItems:0,items:{$ref:"#/definitions/category_def"},uniqueItems:!0}},additionalProperties:!1,definitions:{category_def:{description:"Palette Category",type:"object",properties:{id:{description:"ID of the category",type:"string"},label:{description:"Category label",type:"string"},description:{description:"Category description",type:"string"},empty_text:{description:"When set to a non-empty string and node_types is empty, is used to indicate that no nodes exist",type:"string"},loading_text:{description:"When set to a non-empty string, causes a loading indicator to appear with this text as a label",type:"string"},image:{description:"Encoded image or image reference for the category",type:"string"},node_types:{description:"Array of pipeline node types",type:"array",minItems:0,items:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v3-schema.json#/definitions/node_type_def"},uniqueItems:!0}},required:["id","label"],additionalProperties:!1}}},Ei=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_9__.L("SchemaValidator");function ji(e,t){switch(t){case 1:var n=function(){var e=new jsonschema__WEBPACK_IMPORTED_MODULE_1__.Validator,t="http://api.dataplatform.ibm.com/schemas/common-pipeline/";return e.addSchema(fi,t+"pipeline-flow/pipeline-flow-ui-schema.json#/definitions/pipeline_overview_def"),e.addSchema(fi,t+"pipeline-flow/pipeline-flow-ui-schema.json#/definitions/pipeline_def"),e.addSchema(fi,t+"pipeline-flow/pipeline-flow-ui-schema.json#/definitions/port_info_def"),e.addSchema(fi,t+"pipeline-flow/pipeline-flow-ui-schema.json#/definitions/node_info_def"),e.addSchema(hi,t+"pipeline-connection/pipeline-connection-v1-schema.json#/definitions/common_pipeline_connection_def"),e.addSchema(hi,t+"pipeline-connection/pipeline-connection-v1-schema.json#/definitions/common_pipeline_data_asset_def"),e.addSchema(gi,t+"datarecord-metadata/datarecord-metadata-v1-schema.json#/definitions/record_schema"),e}();Oi(e,pi,"pipelineFlow",n);break;case 2:var i=function(){var e=new jsonschema__WEBPACK_IMPORTED_MODULE_1__.Validator,t="http://api.dataplatform.ibm.com/schemas/common-pipeline/";return e.addSchema(mi,t+"pipeline-flow/pipeline-flow-v2-schema.json"),e.addSchema(vi,t+"pipeline-flow/pipeline-flow-ui-v2-schema.json"),e.addSchema(bi,t+"pipeline-connection/pipeline-connection-v2-schema.json"),e.addSchema(_i,t+"datarecord-metadata/datarecord-metadata-v2-schema.json"),e}();Oi(e,mi,"pipelineFlow",i);break;default:var o=Ti();Oi(e,Pi,"pipelineFlow",o)}}function wi(e,t){switch(t){case 1:Oi(e,yi,"palette",new jsonschema__WEBPACK_IMPORTED_MODULE_1__.Validator);break;case 2:Oi(e,ki,"palette",new jsonschema__WEBPACK_IMPORTED_MODULE_1__.Validator);break;default:var n=Ti();Oi(e,Si,"palette",n)}}function Oi(e,t,n,i){Ei.logStartTimer("Schema validation");var o=i.validate(e,t,{nestedErrors:!0});if(Ei.logEndTimer("Schema validation"),Ei.log("Schema "+n+" - validation result:"),Ei.log(o),o&&o.errors&&o.errors.length>0)throw Ei.error(o),o}function Ti(){var e=new jsonschema__WEBPACK_IMPORTED_MODULE_1__.Validator,t="http://api.dataplatform.ibm.com/schemas/common-pipeline/";return e.addSchema(Pi,t+"pipeline-flow/pipeline-flow-v3-schema.json"),e.addSchema(Ii,t+"pipeline-flow/pipeline-flow-ui-v3-schema.json"),e.addSchema(Ni,t+"pipeline-connection/pipeline-connection-v3-schema.json"),e.addSchema(_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.d,t+"datarecord-metadata/datarecord-metadata-v3-schema.json"),e}function Li(e,t){var n="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!n){if(Array.isArray(e)||(n=function(e,t){if(!e)return;if("string"==typeof e)return xi(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);"Object"===n&&e.constructor&&(n=e.constructor.name);if("Map"===n||"Set"===n)return Array.from(e);if("Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return xi(e,t)}(e))||t&&e&&"number"==typeof e.length){n&&(e=n);var i=0,o=function(){};return{s:o,n:function(){return i>=e.length?{done:!0}:{done:!1,value:e[i++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var a,r=!0,s=!1;return{s:function(){n=n.call(e)},n:function(){var e=n.next();return r=e.done,e},e:function(e){s=!0,a=e},f:function(){try{r||null==n.return||n.return()}finally{if(s)throw a}}}}function xi(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,i=new Array(t);n<t;n++)i[n]=e[n];return i}var Ci=[function(e){return e},function(e){return Object.assign({},{version:"2.0"},e)},function(e){e.version="3.0";var t,n=Li(e.categories);try{for(n.s();!(t=n.n()).done;){var i=t.value;i.id=i.category,delete i.category,i.node_types=[];for(var o=0;o<i.nodetypes.length;o++){var a=i.nodetypes[o],r={id:""};r.type=a.type,"execution_node"===a.type||"binding"===a.type?r.op=a.operator_id_ref:"super_node"===a.type&&(a.open_with_tool&&(r.open_with_tool=a.open_with_tool),r.subflow_ref={pipeline_id_ref:a.subDiagramId}),a.input_ports&&a.input_ports.length>0&&(r.inputs=Di(a.input_ports)),a.output_ports&&a.output_ports.length>0&&(r.outputs=Di(a.output_ports)),r.parameters={},r.app_data={},r.app_data.ui_data={},r.app_data.ui_data.label=a.label,r.app_data.ui_data.description=a.description,r.app_data.ui_data.image=a.image,r.app_data.ui_data.x_pos=0,r.app_data.ui_data.y_pos=0,i.node_types.push(r)}delete i.nodetypes}}catch(e){n.e(e)}finally{n.f()}return e}];function Ai(e){var t;if(!e)throw new Error("Invalid palette document");if(e.version){if("string"!=typeof e.version||0===e.version.length)throw new Error("Invalid palette document: The 'version' attribute is missing or invalid");if(!(t=parseInt(e.version,10)))throw new Error("Invalid palette document: The 'version' attribute cannot be parsed")}else t=1;return t}function Di(e){var t,n=[],i=Li(e);try{for(i.s();!(t=i.n()).done;){var o=t.value,a={};a.id=o.id,a.app_data={},a.app_data.ui_data={},o.cardinality&&(a.app_data.ui_data.cardinality=o.cardinality),a.app_data.ui_data.label=o.label,n.push(a)}}catch(e){i.e(e)}finally{i.f()}return n}function Mi(e,t){var n="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!n){if(Array.isArray(e)||(n=function(e,t){if(!e)return;if("string"==typeof e)return Ri(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);"Object"===n&&e.constructor&&(n=e.constructor.name);if("Map"===n||"Set"===n)return Array.from(e);if("Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return Ri(e,t)}(e))||t&&e&&"number"==typeof e.length){n&&(e=n);var i=0,o=function(){};return{s:o,n:function(){return i>=e.length?{done:!0}:{done:!1,value:e[i++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var a,r=!0,s=!1;return{s:function(){n=n.call(e)},n:function(){var e=n.next();return r=e.done,e},e:function(e){s=!0,a=e},f:function(){try{r||null==n.return||n.return()}finally{if(s)throw a}}}}function Ri(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,i=new Array(t);n<t;n++)i[n]=e[n];return i}var Ui=function(){function i(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,i),this.logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_9__.L("Object Model");var e=this.getEmptyCanvasInfo();this.store=new ui(e),this.oldCanvas=null,this.idGeneratorHandler=null,this.selectionChangeHandler=null,this.layoutHandler=null}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(i,[{key:"dispatch",value:function(e){this.store.dispatch(e)}},{key:"subscribe",value:function(e){return this.store.subscribe(e)}},{key:"setSchemaValidation",value:function(e){this.setCanvasConfig({schemaValidation:e})}},{key:"setSelectionChangeHandler",value:function(e){this.selectionChangeHandler=e}},{key:"setLayoutHandler",value:function(e){if(e!==this.layoutHandler){this.layoutHandler=e;var t=this.prepareNodes(this.getCanvasInfo().pipelines,this.getNodeLayout(),this.getCanvasLayout());this.store.dispatch({type:"REPLACE_PIPELINES",data:{pipelines:t}})}}},{key:"getStore",value:function(){return this.store.getStore()}},{key:"getUUID",value:function(){return (0,uuid__WEBPACK_IMPORTED_MODULE_0__.v4)()}},{key:"setIdGeneratorHandler",value:function(e){this.idGeneratorHandler=e}},{key:"getUniqueId",value:function(e,t){var n;return this.idGeneratorHandler&&(n=this.idGeneratorHandler(e,t)),n||this.getUUID()}},{key:"clearPaletteData",value:function(){this.store.dispatch({type:"CLEAR_PALETTE_DATA"})}},{key:"setPaletteData",value:function(e){var t=Tn.convertPaletteToPipelineFlowPalette(e);this.setPipelineFlowPalette(t)}},{key:"setPipelineFlowPalette",value:function(e){if(e&&!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(e)){var t=e;Tn.isVersion0Palette(t)&&(t=Tn.convertPaletteToPipelineFlowPalette(t));var n=this.validateAndUpgradePalette(t);this.store.dispatch({type:"SET_PALETTE_DATA",data:{content:n}})}else this.clearPaletteData()}},{key:"getPaletteData",value:function(){return this.store.getPaletteData()}},{key:"togglePalette",value:function(){this.isPaletteOpen()?this.closePalette():this.openPalette()}},{key:"openPalette",value:function(){this.store.dispatch({type:"SET_PALETTE_OPEN_STATE",data:{isOpen:!0}})}},{key:"openPaletteIfNecessary",value:function(e){e&&void 0===this.store.getPalette().isOpen&&void 0!==e.paletteInitialState&&(e.paletteInitialState?this.openPalette():this.closePalette())}},{key:"closePalette",value:function(){this.store.dispatch({type:"SET_PALETTE_OPEN_STATE",data:{isOpen:!1}})}},{key:"isPaletteOpen",value:function(){var e=this.store.getPalette().isOpen;return void 0!==e&&e}},{key:"setCategoryLoadingText",value:function(e,t){this.store.dispatch({type:"SET_CATEGORY_LOADING_TEXT",data:{categoryId:e,loadingText:t}})}},{key:"setCategoryEmptyText",value:function(e,t){this.store.dispatch({type:"SET_CATEGORY_EMPTY_TEXT",data:{categoryId:e,emptyText:t}})}},{key:"addNodeTypeToPalette",value:function(e,t,n,i,o){this.addNodeTypesToPalette([e],t,n,i,o)}},{key:"addNodeTypesToPalette",value:function(e,t,n,i,o){var a={nodeTypes:e,categoryId:t,categoryLabel:n,categoryDescription:i,categoryImage:o};this.store.dispatch({type:"ADD_NODE_TYPES_TO_PALETTE",data:a}),this.store.getCanvasConfig().schemaValidation&&wi(this.getPaletteData(),3)}},{key:"removeNodesFromPalette",value:function(e,t){this.store.dispatch({type:"REMOVE_NODE_TYPES_FROM_PALETTE",data:{selObjectIds:e,categoryId:t}})}},{key:"convertNodeTemplate",value:function(e){var t=null;return e?((t=xn.convertNode(e,this.getCanvasLayout())).type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai&&(t=this.convertPipelineData(t)),t):null}},{key:"convertPipelineData",value:function(e){var t,i=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.k)(e,"app_data.pipeline_data");if(i)t=e.subflow_ref.url?[]:xn.convertPipelinesToCanvasInfoPipelines(i,this.getCanvasLayout()),t=this.cloneSupernodeContents(e,t),t=this.prepareNodes(t,this.getNodeLayout(),this.getCanvasLayout(),e);else{var o=this.createEmptyPipeline();t=[o],(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.s)(e,"subflow_ref.pipeline_id_ref",o.id)}return (0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.s)(e,"app_data.pipeline_data",t),e}},{key:"extractAddDataPipelines",value:function(e){var t=[],i=[];return e.forEach((function(e){if($e.isSupernode(e)){var o=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.k)(e,"app_data.pipeline_data");o&&(t.push.apply(t,(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.b)(o)),delete e.app_data.pipeline_data)}i.push(e)})),{nodes:i,pipelines:t}}},{key:"getPaletteNode",value:function(e){var t=null;return e&&!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(this.getPaletteData())&&this.getPaletteData().categories.forEach((function(n){n.node_types.forEach((function(n){n.op===e&&(t=n)}))})),t}},{key:"getPaletteNodeById",value:function(e){var t=null;return (0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(this.getPaletteData())||this.getPaletteData().categories.forEach((function(n){n.node_types.forEach((function(n){n.id===e&&(t=n)}))})),t}},{key:"getCategoryForNode",value:function(e){var t=null;return this.getPaletteData().categories.forEach((function(n){n.node_types.forEach((function(i){i.op===e&&(t=n)}))})),t}},{key:"validateAndUpgradePalette",value:function(e){var t=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(e),n=Ai(t);return this.store.getCanvasConfig().schemaValidation&&wi(t,n),3!==n&&(t=function(e){for(var t=Math.max(Ai(e),1),n=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(e),i=t;i<3;i++)n=Ci[i](n);return n}(t),this.store.getCanvasConfig().schemaValidation&&wi(t,3)),t}},{key:"getAPIPipeline",value:function(e){return new Fn(e||this.getCurrentBreadcrumb().pipelineId,this)}},{key:"getSelectionAPIPipeline",value:function(){var e=this.getSelectedPipelineId();return e?this.getAPIPipeline(e):null}},{key:"clearPipelineFlow",value:function(){this.setCanvasInfo(this.getEmptyCanvasInfo())}},{key:"setCanvas",value:function(e){this.oldCanvas=e;var t=Tn.convertCanvasToCanvasInfo(e);this.setCanvasInfo(t)}},{key:"getCanvas",value:function(){return this.oldCanvas?Ln.getCanvasBasedOnCanvasInfo(this.oldCanvas,this.getCanvasInfo()):{}}},{key:"getEmptyCanvasInfo",value:function(){var e=this.getUUID(),t=this.getUUID();return{doc_type:"pipeline",version:"3.0",json_schema:"http://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v3-schema.json",id:e,primary_pipeline:t,pipelines:[{id:t,runtime_ref:"",nodes:[],comments:[],links:[]}],schemas:[]}}},{key:"setPipelineFlow",value:function(e){if(e.objectData)this.setCanvas(e);else{var t=this.preparePipelineFlow(e);this.executeWithSelectionChange(this.store.dispatch,{type:"SET_CANVAS_INFO",canvasInfo:t,canvasInfoIdChanged:this.hasCanvasInfoIdChanged(t)})}}},{key:"ensurePipelineIsLoaded",value:function(e){var t=this.getSupernodePipelineUrl(e.targetObject),n=this.getSupernodePipelineId(e.targetObject);if(!this.isPipelineLoaded(n,t)){if(!e.externalPipelineFlow){var i="The external pipeline flow at '"+e.externalUrl+"' was not provided. Make sure you have implemented beforeEditActionHandler to support external pipeline flows.";throw this.logger.error(i),i}if(!this.flowContainsPipeline(e.externalPipelineFlow,n)){var o="The external pipeline flow '"+e.externalPipelineFlow.id+"' does not contain a pipeline with ID: "+n;throw this.logger.error(o),o}return this.addExternalPipelineFlow(e.externalPipelineFlow,t,e.targetObject,!0),!0}return!1}},{key:"getVisibleExpandedExternalSupernodes",value:function(){var e=this.getCurrentPipeline();return this.getVisibleExpandedExternalSupernodesForPipeline(e,this.getPipelines())}},{key:"getVisibleExpandedExternalSupernodesForPipeline",value:function(e,t){var n=this,i=[];return e.nodes.forEach((function(e){if(e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai&&e.is_expanded){var o=t.find((function(t){return t.id===n.getSupernodePipelineId(e)}));if(e.subflow_ref.url&&!o&&i.push(e),o){var a=n.getVisibleExpandedExternalSupernodesForPipeline(o,t);i=i.concat(a)}}})),i}},{key:"flowContainsPipeline",value:function(e,t){return!!e.pipelines&&e.pipelines.some((function(e){return e.id===t}))}},{key:"addExternalPipelineFlow",value:function(e,t,n){var i=!(arguments.length>3&&void 0!==arguments[3])||arguments[3],o=this.preparePipelineFlow(e,n);o.pipelines.forEach((function(e){return e.parentUrl=t}));var a=Object.assign({},o);a.pipelines=[],a.url=t,this.store.dispatch({type:"ADD_EXTERNAL_PIPELINE_FLOW",newPipelineFlow:a,newPipelines:i?o.pipelines:[]})}},{key:"removeExternalPipelineFlow",value:function(e){this.store.dispatch({type:"REMOVE_EXTERNAL_PIPELINE_FLOW",externalUrl:e})}},{key:"createExternalPipelineFlowTemplate",value:function(e,t){return{doc_type:"pipeline",version:"3.0",json_schema:"https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v3-schema.json",id:e,primary_pipeline:t,pipelines:[{id:"",runtime_ref:"",nodes:[]}],schemas:[],runtimes:[]}}},{key:"getExternalPipelineFlows",value:function(){return this.store.getExternalPipelineFlows()}},{key:"getExternalPipelineFlowsForPipelines",value:function(e){var t=this.getUniqueUrls(e);return this.getExternalPipelineFlowsForUrls(t)}},{key:"getUniqueUrls",value:function(e){var t=[];return e.forEach((function(e){e.parentUrl&&!t.includes(e.parentUrl)&&t.push(e.parentUrl)})),t}},{key:"getExternalPipelineFlowsForUrls",value:function(e){var t=this,n=[];return e.forEach((function(e){var i=t.getExternalPipelineFlow(e);i.url=e,n.push(i)})),n}},{key:"getExternalPipelineFlow",value:function(e){var t=this.store.getExternalPipelineFlow(e);if(t){delete t.url;var n=this.getCanvasInfo();t.pipelines=n.pipelines.filter((function(t){return t.parentUrl===e})),t.pipelines.forEach((function(e){return delete e.parentUrl})),t=Cn.createPipelineFlow(t),this.store.getCanvasConfig().schemaValidation&&ji(t)}return t}},{key:"setParentUrl",value:function(e,t){this.store.dispatch({type:"SET_PIPELINE_PARENT_URL",data:{pipelines:e,url:t}})}},{key:"replaceSupernodeAndPipelines",value:function(e){this.store.dispatch({type:"REPLACE_SN_AND_PIPELINES",data:e})}},{key:"preparePipelineFlow",value:function(e,t){var n=this.validateAndUpgrade(e),i=xn.convertPipelineFlowToCanvasInfo(n,this.getCanvasLayout());return i.pipelines=this.prepareNodes(i.pipelines,this.getNodeLayout(),this.getCanvasLayout(),t),i}},{key:"prepareNodes",value:function(e,t,n,i){var o=this;return this.setSupernodesBindingStatus(e,i).map((function(e){return o.setPipelineObjectAttributes(e,t,n)}))}},{key:"setSupernodesBindingStatus",value:function(e,t){var n=this;return e.forEach((function(e){e.nodes&&e.nodes.forEach((function(e){delete e.isSupernodeInputBinding,delete e.isSupernodeOutputBinding}))})),t&&this.setSupernodesBindingStatusForNode(t,e),e.forEach((function(t){t.nodes&&$e.filterSupernodes(t.nodes).forEach((function(t){n.setSupernodesBindingStatusForNode(t,e)}))})),e}},{key:"setSupernodesBindingStatusForNode",value:function(e,t){var n=this,i=this.getSupernodePipelineId(e);i&&(e.inputs&&e.inputs.forEach((function(e){if(e.subflow_node_ref){var o=n.findNode(e.subflow_node_ref,i,t);o&&(o.isSupernodeInputBinding=!0)}})),e.outputs&&e.outputs.forEach((function(e){if(e.subflow_node_ref){var o=n.findNode(e.subflow_node_ref,i,t);o&&(o.isSupernodeOutputBinding=!0)}})))}},{key:"setPipelineObjectAttributes",value:function(e,t,n){var i=this,o=Object.assign({},e);return o.nodes?o.nodes=o.nodes.map((function(e){return i.setNodeAttributesWithLayout(e,t,n)})):o.nodes=[],o.comments?o.comments=o.comments.map((function(e){return i.setCommentAttributesWithLayout(e,n)})):o.comments=[],o}},{key:"setNodeAttributes",value:function(e){return this.setNodeAttributesWithLayout(e,this.getNodeLayout(),this.getCanvasLayout())}},{key:"setCommentAttributes",value:function(e){return this.setCommentAttributesWithLayout(e,this.getCanvasLayout())}},{key:"setNodeAttributesWithLayout",value:function(e,t,n){var i=Object.assign({},e);return i=this.setNodeLayoutAttributes(i,t),i="TopBottom"===n.linkDirection||"BottomTop"===n.linkDirection?this.setNodeDimensionAttributesVertical(i,n):this.setNodeDimensionAttributesLeftRight(i,n),n.snapToGridType!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a5&&n.snapToGridType!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a6||(i.x_pos=$e.snapToGrid(i.x_pos,n.snapToGridXPx),i.y_pos=$e.snapToGrid(i.y_pos,n.snapToGridYPx)),i}},{key:"setCommentAttributesWithLayout",value:function(e,t){var n=Object.assign({},e);return t.snapToGridType!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a5&&t.snapToGridType!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a6||(n.x_pos=$e.snapToGrid(n.x_pos,t.snapToGridXPx),n.y_pos=$e.snapToGrid(n.y_pos,t.snapToGridYPx)),n}},{key:"setNodeLayoutAttributes",value:function(e,t){if(e.layout=t,this.layoutHandler){var n=this.layoutHandler(e);if(n&&!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(n)){var i=$e.getCombinedDecorations(e.layout.decorations,n.decorations);e.layout=Object.assign({},e.layout,n,{decorations:i})}}return e}},{key:"setNodeDimensionAttributesLeftRight",value:function(e,t){return e.inputPortsHeight=e.inputs?e.inputs.length*(2*e.layout.portArcRadius)+(e.inputs.length-1)*e.layout.portArcSpacing+2*e.layout.portArcOffset:0,e.outputPortsHeight=e.outputs?e.outputs.length*(2*e.layout.portArcRadius)+(e.outputs.length-1)*e.layout.portArcSpacing+2*e.layout.portArcOffset:0,e.height=Math.max(e.inputPortsHeight,e.outputPortsHeight,e.layout.defaultNodeHeight),e.width=e.layout.defaultNodeWidth,e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai&&e.is_expanded?(e.height+=t.supernodeTopAreaHeight+t.supernodeSVGAreaPadding,e.expanded_height&&(e.expanded_height=Math.max(e.expanded_height,e.height)),e.width=$e.getSupernodeExpandedWidth(e,t),e.height=$e.getSupernodeExpandedHeight(e,t)):(e.height=e.resizeHeight?e.resizeHeight:e.height,e.width=e.resizeWidth?e.resizeWidth:e.width),e}},{key:"setNodeDimensionAttributesVertical",value:function(e,t){return e.inputPortsWidth=e.inputs?e.inputs.length*(2*e.layout.portArcRadius)+(e.inputs.length-1)*e.layout.portArcSpacing+2*e.layout.portArcOffset:0,e.outputPortsWidth=e.outputs?e.outputs.length*(2*e.layout.portArcRadius)+(e.outputs.length-1)*e.layout.portArcSpacing+2*e.layout.portArcOffset:0,e.height=e.layout.defaultNodeHeight,e.width=Math.max(e.inputPortsWidth,e.outputPortsWidth,e.layout.defaultNodeWidth),e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai&&e.is_expanded?(e.width+=2*t.supernodeSVGAreaPadding,e.expanded_width&&(e.expanded_width=Math.max(e.expanded_width,e.width)),e.width=$e.getSupernodeExpandedWidth(e,t),e.height=$e.getSupernodeExpandedHeight(e,t)):(e.height=e.resizeHeight?e.resizeHeight:e.height,e.width=e.resizeWidth?e.resizeWidth:e.width),e}},{key:"validateAndUpgrade",value:function(e){var t=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(e),n=(0,_elyra_pipeline_schemas__WEBPACK_IMPORTED_MODULE_2__.extractVersion)(t);return this.store.getCanvasConfig().schemaValidation&&ji(t,n),n!==_elyra_pipeline_schemas__WEBPACK_IMPORTED_MODULE_2__.LATEST_VERSION&&(t=(0,_elyra_pipeline_schemas__WEBPACK_IMPORTED_MODULE_2__.upgradePipelineFlow)(t),this.store.getCanvasConfig().schemaValidation&&ji(t,_elyra_pipeline_schemas__WEBPACK_IMPORTED_MODULE_2__.LATEST_VERSION)),t}},{key:"getCanvasInfoPipeline",value:function(e){var t=this.getCanvasInfo();if(!t)return null;var n=e;n||(n=this.getPrimaryPipelineId());var i=t.pipelines.find((function(e){return e.id===n}));return void 0===i?null:i}},{key:"getDescendantPipelineIds",value:function(e){var t=this,n=[];return this.getAPIPipeline(e).getSupernodes().forEach((function(e){var i=t.getSupernodePipelineId(e);i&&(n.push(i),n=n.concat(t.getDescendantPipelineIds(i)))})),n}},{key:"getDescendantPipelinesForSupernodes",value:function(e){var t=this,n=[];return e.forEach((function(e){n=n.concat(t.getDescendantPipelinesForSupernode(e))})),n}},{key:"getDescendantPipelinesForSupernode",value:function(e){var t=this,n=[],i=this.getSupernodePipelineId(e);if(i){var o=this.getCanvasInfoPipeline(i);o&&(n.push(o),this.getAPIPipeline(i).getSupernodes().forEach((function(e){n=n.concat(t.getDescendantPipelinesForSupernode(e))})))}return n}},{key:"getSchemaPipelinesForSupernode",value:function(e){return this.getDescendantPipelinesForSupernode(e).filter((function(e){return!e.parentUrl})).map((function(e){return Cn.createPipeline(e)}))}},{key:"getDescPipelinesToDelete",value:function(e,t){var n=this,i=this.getDescendantSupernodeInfos(e,t),o=this.getOtherSupernodeInfos(e,t),a=[];return i.forEach((function(e){if(n.shouldBeDeleted(e,o)){var t=n.getCanvasInfoPipeline(e.pipelineId);a.push(t)}})),a}},{key:"shouldBeDeleted",value:function(e,t){var n=!0;return t.forEach((function(t){t.pipelineId===e.pipelineId&&(n=!1)})),n}},{key:"getOtherSupernodeInfos",value:function(e,t){var n=this.getPrimaryPipelineId(),i=this.getCanvasInfoPipeline(n),o=$e.filterSupernodes(i.nodes);return this.getDescendantSupernodeInfos(o,n,{supernodesToIgnore:e,parentPipelineId:t})}},{key:"getDescendantSupernodeInfos",value:function(e,t,n){var i=this,o=[];return e.forEach((function(e){i.getDescendantSupernodeInfosForSupernode(e,t,n).forEach((function(e){i.isSupernodeInfoInArray(e,o)||o.push(e)}))})),o}},{key:"getDescendantSupernodeInfosForSupernode",value:function(e,t,n){var i=this,o=[];if(this.continueNavigation(e,t,n)){var a=this.getSupernodePipelineId(e),r=this.getCanvasInfoPipeline(a);if(r)o.push({pipelineId:a,supernode:e,parentPipelineId:t}),$e.filterSupernodes(r.nodes).forEach((function(e){o=o.concat(i.getDescendantSupernodeInfosForSupernode(e,a,n))}))}return o}},{key:"continueNavigation",value:function(e,t,n){return!n||n.parentPipelineId!==t||!n.supernodesToIgnore.some((function(t){return t.id===e.id}))}},{key:"isSupernodeInfoInArray",value:function(e,t){var n=this,i=!1;return t.forEach((function(t){n.isSupernodeInfoEqual(t,e)&&(i=!0)})),i}},{key:"isSupernodeInfoEqual",value:function(e,t){return e.supernode.id===t.supernode.id&&e.parentPipelineId===t.parentPipelineId}},{key:"getAncestorPipelineIds",value:function(e){var t=this.getPrimaryPipelineId();return t===e?[{pipelineId:t}]:[{pipelineId:t}].concat(this.getAncestorsBetween(t,e))}},{key:"getAncestorsBetween",value:function(e,t){var n=this,i=[];return this.getAPIPipeline(e).getSupernodes().forEach((function(o){var a=n.getSupernodePipelineId(o);a&&((n.isAncestorOfPipeline(a,t)||a===t)&&i.push({pipelineId:a,label:o.label,supernodeId:o.id,parentPipelineId:e}),i=i.concat(n.getAncestorsBetween(a,t)))})),i}},{key:"isAncestorOfPipeline",value:function(e,t){return this.getDescendantPipelineIds(e).includes(t)}},{key:"getSupernodePipelineId",value:function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"subflow_ref.pipeline_id_ref")?e.subflow_ref.pipeline_id_ref:null}},{key:"getSupernodePipelineUrl",value:function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"subflow_ref.url")?e.subflow_ref.url:null}},{key:"getSupernodeObjReferencing",value:function(e){var t,n=this;e===this.getPrimaryPipelineId()?t=this.getAPIPipeline(e).getSupernodes().find((function(t){return n.getSupernodePipelineId(t)===e})).id:t=this.getAncestorPipelineIds(e).find((function(t){return t.pipelineId===e&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(t,"supernodeId")}));return t}},{key:"setCanvasInfo",value:function(e){var t=Object.assign({},e);t.pipelines=this.prepareNodes(t.pipelines,this.getNodeLayout(),this.getCanvasLayout()),this.store.dispatch({type:"SET_CANVAS_INFO",canvasInfo:t,canvasInfoIdChanged:this.hasCanvasInfoIdChanged(t)})}},{key:"getPipelineFlow",value:function(){var e=Cn.createPipelineFlow(this.getCanvasInfo());return this.store.getCanvasConfig().schemaValidation&&ji(e),e}},{key:"getPipelines",value:function(){return this.getCanvasInfo().pipelines}},{key:"getPipelineFlowId",value:function(){return this.store.getPipelineFlowId()}},{key:"getPrimaryPipelineId",value:function(){return this.store.getPrimaryPipelineId()}},{key:"getPrimaryPipeline",value:function(){return this.getCanvasInfoPipeline(this.getPrimaryPipelineId())}},{key:"getCurrentPipeline",value:function(){return this.getCanvasInfoPipeline(this.getCurrentPipelineId())}},{key:"getCurrentPipelineId",value:function(){return this.getCurrentBreadcrumb().pipelineId}},{key:"isPrimaryPipelineEmpty",value:function(){return this.getAPIPipeline(this.getPrimaryPipelineId()).isEmpty()}},{key:"deletePipeline",value:function(e){this.store.dispatch({type:"DELETE_PIPELINE",data:{id:e}})}},{key:"isPipelineLoaded",value:function(e,t){var n=this,i=this.getCanvasInfo();return!!i&&i.pipelines.some((function(i){return n.isPipeline(i,e,t)}))}},{key:"isPipeline",value:function(e,t,n){return e.id===t&&(!e.parentUrl&&!n||e.parentUrl===n)}},{key:"cloneSupernodeContents",value:function(e,t){var n=this,i=[],o=this.getSupernodePipelineId(e);if(o){var a=t.find((function(e){return e.id===o}));if(a){var r=this.clonePipelineWithNewId(a);e.subflow_ref.pipeline_id_ref=r.id,i.push(r),r.nodes.forEach((function(e){if(e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai){var o=n.cloneSupernodeContents(e,t);i=i.concat(o)}}))}}return i}},{key:"clonePipelineWithNewId",value:function(e){var t=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_8__.d)(e);return Object.assign({},t,{id:this.getUniqueId(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aE,{pipeline:t})})}},{key:"createCanvasInfoPipeline",value:function(e){var t=this.getUniqueId(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aF,{pipeline:e});return Object.assign({},e,{id:t})}},{key:"getCanvasInfo",value:function(){return this.store.getCanvasInfo()}},{key:"hasCanvasInfoIdChanged",value:function(e){return e.id!==this.getCanvasInfo().id}},{key:"setSubdueStyle",value:function(e){this.store.dispatch({type:"SET_SUBDUE_STYLE",data:{subdueStyle:e}})}},{key:"removeAllStyles",value:function(e){this.store.dispatch({type:"REMOVE_ALL_STYLES",data:{temporary:e}})}},{key:"findNode",value:function(e,t,n){var i=n.find((function(e){return e.id===t}));return i&&i.nodes?i.nodes.find((function(t){return t.id===e})):null}},{key:"createBreadcrumb",value:function(e,t){return{pipelineId:e.subflow_ref.pipeline_id_ref,supernodeId:e.id,supernodeParentPipelineId:t,externalUrl:e.subflow_ref.url,label:e.label}}},{key:"addBreadcrumb",value:function(e){e&&e.pipelineId!==this.getPrimaryPipelineId()?this.store.dispatch({type:"ADD_BREADCRUMB",data:e}):this.resetBreadcrumb()}},{key:"addBreadcrumbs",value:function(e){this.store.dispatch({type:"ADD_BREADCRUMBS",data:e})}},{key:"setIndexedBreadcrumb",value:function(e){this.store.dispatch({type:"SET_TO_INDEXED_BREADCRUMB",data:e})}},{key:"setBreadcrumbs",value:function(e){this.store.dispatch({type:"SET_BREADCRUMBS",data:{breadcrumbs:e}})}},{key:"setPreviousBreadcrumb",value:function(){this.store.dispatch({type:"SET_TO_PREVIOUS_BREADCRUMB"})}},{key:"resetBreadcrumb",value:function(){this.store.dispatch({type:"RESET_BREADCRUMB",data:{pipelineId:this.getPrimaryPipelineId()}})}},{key:"getBreadcrumbs",value:function(){return this.store.getBreadcrumbs()}},{key:"getCurrentBreadcrumb",value:function(){var e=this.getBreadcrumbs();return e[e.length-1]}},{key:"getPreviousBreadcrumb",value:function(){var e=this.getBreadcrumbs();return e.length<2?null:e[e.length-2]}},{key:"isInSubFlowBreadcrumb",value:function(e){return this.getBreadcrumbs().findIndex((function(t){return t.pipelineId===e}))>0}},{key:"setCanvasConfig",value:function(e){var t=this.getCanvasConfig(),n=ot.mergeCanvasConfigs(t,e);if(!ot.compareCanvasConfigs(t,n)){var i=this.prepareNodes(this.getCanvasInfo().pipelines,n.enableNodeLayout,n.enableCanvasLayout);this.store.dispatch({type:"SET_CANVAS_CONFIG_INFO",data:{canvasConfig:n,pipelines:i}})}}},{key:"setToolbarConfig",value:function(e){this.store.dispatch({type:"SET_TOOLBAR_CONFIG",data:{toolbarConfig:e}})}},{key:"setNotificationPanelConfig",value:function(e){this.store.dispatch({type:"SET_NOTIFICATION_PANEL_CONFIG",data:{notificationPanelConfig:e}})}},{key:"getCanvasConfig",value:function(){return this.store.getCanvasConfig()}},{key:"getNodeLayout",value:function(){return this.store.getNodeLayout()}},{key:"getCanvasLayout",value:function(){return this.store.getCanvasLayout()}},{key:"clearNotificationMessages",value:function(){this.store.dispatch({type:"CLEAR_NOTIFICATION_MESSAGES"})}},{key:"setNotificationMessages",value:function(e){this.store.dispatch({type:"SET_NOTIFICATION_MESSAGES",data:{messages:e}})}},{key:"getNotificationMessages",value:function(e){var t=this.store.getNotifications();return e?t.filter((function(t){return t.type===e})):t}},{key:"deleteNotificationMessages",value:function(e){this.store.dispatch({type:"DELETE_NOTIFICATION_MESSAGES",data:{ids:e}})}},{key:"toggleNotificationPanel",value:function(){this.isNotificationPanelOpen()?this.closeNotificationPanel():this.openNotificationPanel()}},{key:"openNotificationPanel",value:function(){this.store.dispatch({type:"SET_NOTIFICATION_PANEL_OPEN_STATE",data:{isOpen:!0}})}},{key:"closeNotificationPanel",value:function(){this.store.dispatch({type:"SET_NOTIFICATION_PANEL_OPEN_STATE",data:{isOpen:!1}})}},{key:"isNotificationPanelOpen",value:function(){return this.store.isNotificationPanelOpen()}},{key:"openContextMenu",value:function(e){this.store.dispatch({type:"SET_CONTEXT_MENU_DEF",data:{menuDef:e}})}},{key:"closeContextMenu",value:function(){this.store.dispatch({type:"SET_CONTEXT_MENU_DEF",data:{menuDef:[]}})}},{key:"isContextMenuDisplayed",value:function(){return this.store.isContextMenuDisplayed()}},{key:"setRightFlyoutConfig",value:function(e){this.store.dispatch({type:"SET_RIGHT_FLYOUT_CONFIG",data:{config:e}})}},{key:"isRightFlyoutOpen",value:function(){return this.store.isRightFlyoutOpen()}},{key:"setBottomPanelConfig",value:function(e){this.store.dispatch({type:"SET_BOTTOM_PANEL_CONFIG",data:{config:e}})}},{key:"isBottomPanelOpen",value:function(){return this.store.isBottomPanelOpen()}},{key:"cloneObjectsToPaste",value:function(e,t,n){var i=this,o=[],a=[],r=[];return e&&e.forEach((function(e){var t=i.cloneNode(e);t.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai&&(t=i.convertPipelineData(t)),o.push({originalId:e.id,node:t})})),t&&t.forEach((function(e){a.push({originalId:e.id,comment:i.cloneComment(e)})})),n&&n.forEach((function(e){if("nodeLink"===e.type||"associationLink"===e.type){var t=i.findClonedNode(e.srcNodeId,o),n=i.findClonedNode(e.trgNodeId,o),s=i.cloneNodeLink(e,t,n);r.push(s)}else{var d=i.findClonedComment(e.srcNodeId,a),c=i.findClonedNode(e.trgNodeId,o);if(d&&c){var l=i.cloneCommentLink(e,d.id,c.id);r.push(l)}}})),{clonedNodes:o.map((function(e){return e.node})),clonedComments:a.map((function(e){return e.comment})),clonedLinks:r}}},{key:"findClonedNode",value:function(e,t){var n=t.find((function(t){return t.originalId===e}));return n?n.node:null}},{key:"findClonedComment",value:function(e,t){var n=t.find((function(t){return t.originalId===e}));return n?n.comment:null}},{key:"cloneNode",value:function(e){var t=Object.assign({},e,{id:this.getUniqueId(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aG,{node:e})});return t=this.setNodeAttributes(t)}},{key:"cloneComment",value:function(e){var t=this.setCommentAttributes(e);return Object.assign({},t,{id:this.getUniqueId(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aH,{comment:t})})}},{key:"cloneNodeLink",value:function(e,t,n){var i=this.getUniqueId(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aI,{link:e,sourceNodeId:t?t.id:null,targetNodeId:n?n.id:null}),o=Object.assign({},e,{id:i});return t?(o.srcNodeId=t.id,o.srcNodePortId=e.srcNodePortId):o.srcPos=e.srcPos,n?(o.trgNodeId=n.id,o.trgNodePortId=e.trgNodePortId):o.trgPos=e.trgPos,o}},{key:"cloneCommentLink",value:function(e,t,n){return{id:this.getUniqueId(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aJ,{link:e,commentId:t,targetNodeId:n}),type:e.type,class_name:e.class_name,srcNodeId:t,trgNodeId:n}}},{key:"getSelectedObjectIds",value:function(){return this.getSelectionInfo().selections||[]}},{key:"getSelectedNodesIds",value:function(){var e=this,t=[];return this.getSelectedPipeline().getNodes().forEach((function(n){e.getSelectedObjectIds().includes(n.id)&&t.push(n.id)})),t}},{key:"getSelectedNodes",value:function(){var e=this,t=[];return this.getSelectedPipeline().getNodes().forEach((function(n){e.getSelectedObjectIds().includes(n.id)&&t.push(n)})),t}},{key:"getSelectedComments",value:function(){var e=this,t=[];return this.getSelectedPipeline().getComments().forEach((function(n){e.getSelectedObjectIds().includes(n.id)&&t.push(n)})),t}},{key:"getSelectedLinks",value:function(){var e=this,t=[];return this.getSelectedPipeline().getLinks().forEach((function(n){e.getSelectedObjectIds().includes(n.id)&&t.push(n)})),t}},{key:"getSelectedObjects",value:function(){return this.getSelectedNodes().concat(this.getSelectedComments()).concat(this.getSelectedLinks())}},{key:"getSelectionInfo",value:function(){return this.store.getSelectionInfo()}},{key:"getSelectedPipeline",value:function(){return this.getAPIPipeline(this.getSelectedPipelineId())}},{key:"getSelectedPipelineId",value:function(){return this.getSelectionInfo().pipelineId}},{key:"clearSelections",value:function(){this.executeWithSelectionChange(this.store.dispatch,{type:"CLEAR_SELECTIONS"})}},{key:"isSelected",value:function(e,t){return t===this.getSelectedPipelineId()&&this.getSelectedObjectIds().indexOf(e)>=0}},{key:"toggleSelection",value:function(e,t,n){var i=[e];if(n===this.getSelectedPipelineId()&&t)if(this.isSelected(e,n)){var o=(i=this.getSelectedObjectIds().slice()).indexOf(e);i.splice(o,1)}else i=this.getSelectedObjectIds().concat(e);this.setSelections(i,n)}},{key:"setSelections",value:function(e,t){var n=this.getAPIPipeline(t).pipelineId;this.executeWithSelectionChange(this.store.dispatch,{type:"SET_SELECTIONS",data:{selections:e},pipelineId:n})}},{key:"deleteSelectedObjects",value:function(){this.getSelectedPipeline().deleteObjects(this.getSelectedObjectIds())}},{key:"selectAll",value:function(e,t){var n,i=[],o=this.getAPIPipeline(t),a=Mi(o.getNodes());try{for(a.s();!(n=a.n()).done;){var r=n.value;$e.isSuperBindingNode(r)||i.push(r.id)}}catch(e){a.e(e)}finally{a.f()}var s,d=Mi(o.getComments());try{for(d.s();!(s=d.n()).done;){var c=s.value;i.push(c.id)}}catch(e){d.e(e)}finally{d.f()}if(e){var l,u=Mi(o.getLinks());try{for(u.s();!(l=u.n()).done;){var p=l.value;i.push(p.id)}}catch(e){u.e(e)}finally{u.f()}}this.setSelections(i,o.pipelineId)}},{key:"findNodesInSubGraph",value:function(e,t,n,i){var o=this.getAPIPipeline(i),a=!1;if(n.push(e),e===t)a=!0;else{var r,s=Mi(o.getLinks());try{for(s.s();!(r=s.n()).done;){var d=r.value;if(d.srcNodeId===e){var c=this.findNodesInSubGraph(d.trgNodeId,t,n,i);!0!==c&&n.pop(),a=a||c}}}catch(e){s.e(e)}finally{s.f()}}return a}},{key:"selectSubGraph",value:function(e,t){var n=[],i=[e];if(t===this.getSelectedPipelineId()){var o,a=!1,r=Mi(this.getSelectedObjectIds());try{for(r.s();!(o=r.n()).done;){var s=o.value;a=a||this.findNodesInSubGraph(s,e,n,t)}}catch(e){r.e(e)}finally{r.f()}a||n.push(e),i=this.getSelectedObjectIds().slice();var d,c=Mi(n);try{for(c.s();!(d=c.n()).done;){var l=d.value;this.isSelected(l,t)||i.push(l)}}catch(e){c.e(e)}finally{c.f()}}this.setSelections(i,t)}},{key:"areSelectedNodesContiguous",value:function(){var e,t=this.getSelectedNodesIds(),n=[t[0]],i=this.getSelectedPipeline(),o=Mi(t);try{for(o.s();!(e=o.n()).done;){var a=e.value;this.addConnectedNodeIdToGroup(a,n,t,i)}}catch(e){o.e(e)}finally{o.f()}return n.length===t.length}},{key:"areAllSelectedObjectsLinks",value:function(){var e=this;return-1===this.getSelectedObjects().findIndex((function(t){return!e.isLink(t)}))}},{key:"addConnectedNodeIdToGroup",value:function(e,t,n,i){if(t.includes(e)){var o,a=i.getLinksContainingId(e).filter((function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H||e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K})),r=Mi(a);try{for(r.s();!(o=r.n()).done;){var s=o.value;n.includes(s.trgNodeId)&&n.includes(s.srcNodeId)&&(t.includes(s.trgNodeId)||(t.push(s.trgNodeId),this.addConnectedNodeIdToGroup(s.trgNodeId,t,n,i)),t.includes(s.srcNodeId)||(t.push(s.srcNodeId),this.addConnectedNodeIdToGroup(s.srcNodeId,t,n,i)))}}catch(e){r.e(e)}finally{r.f()}}}},{key:"createEmptyPipeline",value:function(){var e={runtime_ref:this.getCanvasInfoPipeline(this.getPrimaryPipelineId()).runtime_ref,nodes:[],comments:[],links:[]};return this.createCanvasInfoPipeline(e)}},{key:"createPipeline",value:function(e,t,n){var i={runtime_ref:this.getCanvasInfoPipeline(this.getPrimaryPipelineId()).runtime_ref,nodes:e,comments:t,links:n};return this.createCanvasInfoPipeline(i)}},{key:"executeWithSelectionChange",value:function(e,t){var n={nodes:[],comments:[],pipelineId:""};if(this.selectionChangeHandler&&(n={links:this.getSelectedLinks(),nodes:this.getSelectedNodes(),comments:this.getSelectedComments(),pipelineId:this.getSelectedPipelineId()}),e(t),this.selectionChangeHandler){var i=this.getSelectedLinks(),o=this.getSelectedNodes(),a=this.getSelectedComments(),r={selection:this.getSelectedObjectIds(),selectedLinks:i,selectedNodes:o,selectedComments:a,addedLinks:On(i,n.links,(function(e,t){return e.id===t.id})),addedNodes:On(o,n.nodes,(function(e,t){return e.id===t.id})),addedComments:On(a,n.comments,(function(e,t){return e.id===t.id})),deselectedLinks:On(n.links,i,(function(e,t){return e.id===t.id})),deselectedNodes:On(n.nodes,o,(function(e,t){return e.id===t.id})),deselectedComments:On(n.comments,a,(function(e,t){return e.id===t.id})),previousPipelineId:n.pipelineId,selectedPipelineId:this.getSelectedPipelineId()};(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(r.addedLinks)&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(r.addedNodes)&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(r.addedComments)&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(r.deselectedLinks)&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(r.deselectedNodes)&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(r.deselectedComments)||this.selectionChangeHandler(r)}}},{key:"hasErrorMessage",value:function(e){var t=this.getNodeMessages(e);return!!t&&t.some((function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.E}))}},{key:"hasWarningMessage",value:function(e){var t=this.getNodeMessages(e);return!!t&&t.some((function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.W}))}},{key:"getNodeMessages",value:function(e){return e?e.messages:null}},{key:"getNotificationMessagesMaxType",value:function(){var e=this.getNotificationMessages(),t=this.getNotificationMessages(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.E),n=this.getNotificationMessages(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.W),i=this.getNotificationMessages(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.S),o=this.getNotificationMessages(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.I),a=null;return e.length>0&&(t.length>0?a=_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.E:n.length>0?a=_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.W:i.length>0?a=_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.S:o.length>0&&(a=_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.I)),a}},{key:"isLink",value:function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H||e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O||e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K}},{key:"setZoom",value:function(e,t){var n=this.getCanvasConfig().enableSaveZoom;this.store.dispatch({type:"SET_ZOOM",data:{zoom:e,enableSaveZoom:n},pipelineId:t}),n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aK&&this.setSavedZoomLocal(e,t)}},{key:"getSavedZoom",value:function(e){var t=this.getCanvasConfig().enableSaveZoom;return t===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aD?this.store.getZoom(e):t===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aK?this.getSavedZoomLocal(e):null}},{key:"clearSavedZoomValues",value:function(){An.delete("canvasSavedZoomValues")}},{key:"setSavedZoomLocal",value:function(e,t){var n=An.get("canvasSavedZoomValues"),i=n?JSON.parse(n):{};(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.s)(i,[this.getPipelineFlowId(),t],e),An.set("canvasSavedZoomValues",JSON.stringify(i))}},{key:"getSavedZoomLocal",value:function(e){var t=An.get("canvasSavedZoomValues");if(t){var i=JSON.parse(t);return (0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.k)(i,[this.getPipelineFlowId(),e])}return null}},{key:"setNodesMultiDecorations",value:function(e){this.store.dispatch({type:"SET_NODES_MULTI_DECORATIONS",data:{pipelineNodeDecorations:e}})}},{key:"setLinksMultiDecorations",value:function(e){this.store.dispatch({type:"SET_LINKS_MULTI_DECORATIONS",data:{pipelineLinkDecorations:e}})}},{key:"setObjectsStyle",value:function(e,t,n){this.store.dispatch({type:"SET_OBJECTS_STYLE",data:{pipelineObjIds:e,newStyle:t,temporary:n}})}},{key:"setObjectsMultiStyle",value:function(e,t){this.store.dispatch({type:"SET_OBJECTS_MULTI_STYLE",data:{pipelineObjStyles:e,temporary:t}})}},{key:"setLinksStyle",value:function(e,t,n){this.store.dispatch({type:"SET_LINKS_STYLE",data:{pipelineObjIds:e,newStyle:t,temporary:n}})}},{key:"setLinksMultiStyle",value:function(e,t){this.store.dispatch({type:"SET_LINKS_MULTI_STYLE",data:{pipelineObjStyles:e,temporary:t}})}},{key:"getObjectStyle",value:function(e,t){var n=this.getObject(e);return t?n&&n.style_temp?n.style_temp:null:n&&n.style?n.style:null}},{key:"getHighlightObjectIds",value:function(e,t,n){var i=this,o={},a={};return o[e]=[],a[e]=[],t.forEach((function(t){switch(o[e].push(t),n){case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aN:i.getUpstreamObjIdsFrom(t,e,o,a),i.getDownstreamObjIdsFrom(t,e,o,a);break;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aM:i.getUpstreamObjIdsFrom(t,e,o,a);break;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aL:i.getDownstreamObjIdsFrom(t,e,o,a)}i.getAPIPipeline(e).isSupernode(t)&&i.getSupernodeNodeIds(t,e,o,a)})),{nodes:o,links:a}}},{key:"getSupernodeNodeIds",value:function(e,t,n,i){var o=this,a=this.getAPIPipeline(t).getNode(e);if(a.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai){var r=this.getSupernodePipelineId(a);n[r]=n[r]||[],i[r]=i[r]||[];var s=this.getAPIPipeline(r).getNodeIds(),d=this.getAPIPipeline(r).getLinkIds();n[r]=(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.u)(n[r],s),i[r]=(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.u)(i[r],d),s.forEach((function(e){o.getSupernodeNodeIds(e,r,n,i)}))}}},{key:"getUpstreamObjIdsFrom",value:function(e,t,n,i){var o=this;n[t]=n[t]||[],i[t]=i[t]||[];var a=this.getAPIPipeline(t),r=a.getNode(e),s=a.getAttachedLinksContainingTargetId(e).filter((function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H}));if(s.length>0)s.forEach((function(e){if(!i[t].includes(e.id)){var r=a.getNode(e.srcNodeId);i[t]=(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.u)(i[t],[e.id]),n[t]=(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.u)(n[t],[e.srcNodeId]);var s=o.getSupernodeOutputPortForLink(r,e);if(s){var d=o.getSupernodePipelineId(r),c=o.getAPIPipeline(d).getNode(s.subflow_node_ref);c&&(i[d]=i[d]||[],n[d]=n[d]||[],n[d]=(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.u)(n[d],[c.id]),o.getUpstreamObjIdsFrom(c.id,d,n,i))}else o.getUpstreamObjIdsFrom(e.srcNodeId,t,n,i)}}));else if(a.isEntryBindingNode(r)&&$e.isSuperBindingNode(r)){var d=this.getSupernodeObjReferencing(t),c=d.parentPipelineId,l=this.getAPIPipeline(c),u=l.getNode(d.supernodeId);u.inputs.forEach((function(t){t.subflow_node_ref===e&&l.getAttachedLinksContainingTargetId(u.id).forEach((function(e){if(e.trgNodePortId===t.id)if(n[c]=n[c]||[],i[c]=i[c]||[],n[c]=(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.u)(n[c],[e.srcNodeId]),i[c]=(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.u)(i[c],[e.id]),l.isSupernode(e.srcNodeId)){var a=l.getNode(e.srcNodeId),r=o.getSupernodeOutputPortForLink(a,e);if(r){var s=r.subflow_node_ref;o.getUpstreamObjIdsFrom(s,o.getSupernodePipelineId(a),n,i)}}else o.getUpstreamObjIdsFrom(e.srcNodeId,c,n,i)}))}))}}},{key:"getDownstreamObjIdsFrom",value:function(e,t,n,i){var o=this;n[t]=n[t]||[],i[t]=i[t]||[];var a=this.getAPIPipeline(t),r=a.getNode(e),s=a.getAttachedLinksContainingSourceId(e).filter((function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H}));if(s.length>0)s.forEach((function(e){if(!i[t].includes(e.id)){var r=a.getNode(e.trgNodeId);i[t]=(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.u)(i[t],[e.id]),n[t]=(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.u)(n[t],[e.trgNodeId]);var s=o.getSupernodeInputPortForLink(r,e);if(s){var d=o.getSupernodePipelineId(r),c=o.getAPIPipeline(d).getNode(s.subflow_node_ref);c&&(i[d]=i[d]||[],n[d]=n[d]||[],n[d]=(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.u)(n[d],[c.id]),o.getDownstreamObjIdsFrom(c.id,d,n,i))}else o.getDownstreamObjIdsFrom(e.trgNodeId,t,n,i)}}));else if(a.isExitBindingNode(r)&&$e.isSuperBindingNode(r)){var d=this.getSupernodeObjReferencing(t),c=d.parentPipelineId,l=this.getAPIPipeline(c),u=l.getNode(d.supernodeId);u.outputs.forEach((function(t){t.subflow_node_ref===e&&l.getAttachedLinksContainingSourceId(u.id).forEach((function(e){if(e.srcNodePortId===t.id)if(n[c]=n[c]||[],i[c]=i[c]||[],n[c]=(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.u)(n[c],[e.trgNodeId]),i[c]=(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.u)(i[c],[e.id]),l.isSupernode(e.trgNodeId)){var a=l.getNode(e.trgNodeId),r=o.getSupernodeInputPortForLink(a,e);if(r){var s=r.subflow_node_ref;o.getDownstreamObjIdsFrom(s,o.getSupernodePipelineId(a),n,i)}}else o.getDownstreamObjIdsFrom(e.trgNodeId,c,n,i)}))}))}}},{key:"getSupernodeInputPortForLink",value:function(e,t){var n=null;return this.getSupernodePipelineId(e)&&t.trgNodePortId&&e.inputs.forEach((function(e){e.id!==t.trgNodePortId||(n=e)})),n}},{key:"getSupernodeOutputPortForLink",value:function(e,t){var n=null;return this.getSupernodePipelineId(e)&&t.srcNodePortId&&e.outputs.forEach((function(e){e.id!==t.srcNodePortId||(n=e)})),n}},{key:"copyToClipboard",value:function(e){var t=this,n={},i=this.getSelectionAPIPipeline();if(!i)return!1;var o=this.getSelectedNodes(),a=this.getSelectedComments(),r=i.getLinksBetween(o,a);if(e){var s=i.getNodeDataLinksContainingIds(o.map((function(e){return e.id})));r=$e.concatUniqueBasedOnId(s,r),r=$e.concatUniqueBasedOnId(this.getSelectedLinks(),r)}if(0===o.length&&0===a.length&&0===r.length)return!1;if(o&&o.length>0){n.nodes=o;var d=[];$e.filterSupernodes(o).forEach((function(e){d=d.concat(t.getSchemaPipelinesForSupernode(e)),(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.s)(e,"app_data.pipeline_data",d)}))}a&&a.length>0&&(n.comments=a),r&&r.length>0&&(n.links=r.map((function(e){var t=Object.assign({},e);return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H&&e.srcNodeId&&-1===o.findIndex((function(t){return t.id===e.srcNodeId}))&&(delete t.srcNodeId,delete t.srcNodePortId,t.srcPos=$e.getSrcPos(e,i)),e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H&&e.trgNodeId&&-1===o.findIndex((function(t){return t.id===e.trgNodeId}))&&(delete t.trgNodeId,delete t.trgNodePortId,t.trgPos=$e.getTrgPos(e,i)),t})));var c=JSON.stringify(n);return An.set("canvasClipboard",c),!0}},{key:"isClipboardEmpty",value:function(){var e=An.get("canvasClipboard");return!e||""===e}},{key:"getObjectsToPaste",value:function(){var e=An.get("canvasClipboard");if(!e)return{};var t=JSON.parse(e);return t.nodes||t.comments||t.links?t:null}},{key:"setTooltipDef",value:function(e){this.store.dispatch({type:"SET_TOOLTIP_DEF",data:{tooltipDef:e}})}},{key:"isTooltipOpen",value:function(){return this.store.isTooltipOpen()}}]),i}();function Fi(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.a)(this).constructor;n=Reflect.construct(i,arguments,o)}else n=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__.b)(this,n)}}var Bi=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_7__._)(o,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_4__.A);var i=Fi(o);function o(e,n,a){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,o),(r=i.call(this,e)).data=e,r.objectModel=n,r.labelUtil=a,r.apiPipeline=r.objectModel.getAPIPipeline(e.pipelineId),r.previousObjectsInfo=r.getPreviousObjectsInfo(e),r.previousLinksInfo=r.getPreviousLinksInfo(e),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(o,[{key:"do",value:function(){this.apiPipeline.sizeAndPositionObjects(this.data.objectsInfo,this.data.linksInfo)}},{key:"undo",value:function(){this.apiPipeline.sizeAndPositionObjects(this.previousObjectsInfo,this.previousLinksInfo)}},{key:"redo",value:function(){this.do()}},{key:"getLabel",value:function(){return this.labelUtil.getActionLabel(this,"action.sizeAndPositionObjects")}},{key:"getPreviousObjectsInfo",value:function(e){var t=this,n=[];return Object.keys(e.objectsInfo).forEach((function(e){var i=t.apiPipeline.getObject(e);i&&(n[e]={id:i.id,x_pos:i.x_pos,y_pos:i.y_pos,width:i.width,height:i.height},i.isResized&&(n[e].isResized=i.isResized,n[e].resizeWidth=i.resizeWidth,n[e].resizeHeight=i.resizeHeight))})),n}},{key:"getPreviousLinksInfo",value:function(e){var t=this,n=[];return Object.keys(e.linksInfo).forEach((function(e){var i=t.apiPipeline.getLink(e);i&&(i.srcPos||i.trgPos)&&(n[e]={},i.srcPos&&(n[e].srcPos={x_pos:i.srcPos.x_pos,y_pos:i.srcPos.y_pos}),i.trgPos&&(n[e].trgPos={x_pos:i.trgPos.x_pos,y_pos:i.trgPos.y_pos}))})),n}}]),o}(),Hi=0,qi=function(){function i(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,i),this.logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_9__.L("CanvasController"),this.contextMenuConfig={enableCreateSupernodeNonContiguous:!1,defaultMenuEntries:{saveToPalette:!1,createSupernode:!0,displaySupernodeFullPage:!0,colorBackground:!0}},this.keyboardConfig={actions:{delete:!0,undo:!0,redo:!0,selectAll:!0,copyToClipboard:!0,cutToClipboard:!0,pasteFromClipboard:!0}},this.handlers={contextMenuHandler:null,beforeEditActionHandler:null,editActionHandler:null,clickActionHandler:null,decorationActionHandler:null,tipHandler:null,layoutHandler:null,idGeneratorHandler:null,selectionChangeHandler:null,actionLabelHandler:null},this.contextMenuSource=null,this.objectModel=new Ui,this.commandStack=new _lib_command_stack_es_js__WEBPACK_IMPORTED_MODULE_11__["default"],this.labelUtil=new Nn,this.contextMenuActionHandler=this.contextMenuActionHandler.bind(this),this.closeContextMenu=this.closeContextMenu.bind(this),this.instanceId=Hi++,this.highlight=!1}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(i,[{key:"setCanvasConfig",value:function(e){this.logger.log("Setting Canvas Config");var t=this.correctTypo(e);this.objectModel.openPaletteIfNecessary(e),this.objectModel.setCanvasConfig(t)}},{key:"correctTypo",value:function(e){return (0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(e)||"boolean"!=typeof e.enableHightlightNodeOnNewLinkDrag||(e.enableHighlightNodeOnNewLinkDrag=e.enableHightlightNodeOnNewLinkDrag,delete e.enableHightlightNodeOnNewLinkDrag),e}},{key:"getCanvasConfig",value:function(){return this.objectModel.getCanvasConfig()}},{key:"setIntl",value:function(e){this.labelUtil.setIntl(e)}},{key:"setToolbarConfig",value:function(e){this.logger.log("Setting Toolbar Config"),this.objectModel.setToolbarConfig(e)}},{key:"setNotificationPanelConfig",value:function(e){this.logger.log("Setting Notif Panel Config"),this.objectModel.setNotificationPanelConfig(e)}},{key:"setRightFlyoutConfig",value:function(e){this.logger.log("Setting Right Flyout Config"),this.objectModel.setRightFlyoutConfig(e)}},{key:"setBottomPanelConfig",value:function(e){this.logger.log("Setting Bottom Panel Config"),this.objectModel.setBottomPanelConfig(e)}},{key:"setContextMenuConfig",value:function(e){if(this.logger.log("Setting Context Menu Config"),e){var t=Object.assign(this.contextMenuConfig.defaultMenuEntries,e.defaultMenuEntries);this.contextMenuConfig=Object.assign(this.contextMenuConfig,e,{defaultMenuEntries:t})}}},{key:"setKeyboardConfig",value:function(e){this.logger.log("Setting Keyboard Config"),e&&e.actions&&(this.keyboardConfig.actions=Object.assign({},this.keyboardConfig.actions,e.actions))}},{key:"getKeyboardConfig",value:function(){return this.keyboardConfig}},{key:"setHandlers",value:function(e){this.logger.log("Setting Handlers"),this.handlers=Object.assign(this.handlers,e),this.objectModel.setIdGeneratorHandler(e.idGeneratorHandler),this.objectModel.setSelectionChangeHandler(e.selectionChangeHandler),this.objectModel.setLayoutHandler(e.layoutHandler),this.labelUtil.setActionLabelHandler(e.actionLabelHandler)}},{key:"setCanvasContents",value:function(e){this.canvasContents=e}},{key:"getSVGCanvasD3",value:function(){return this.canvasContents?this.canvasContents.getSVGCanvasD3():null}},{key:"setInstanceId",value:function(e){this.instanceId=e}},{key:"getInstanceId",value:function(){return this.instanceId}},{key:"getObjectModel",value:function(){return this.objectModel}},{key:"isInternalObjectModelEnabled",value:function(){return this.getCanvasConfig().enableInternalObjectModel}},{key:"getStore",value:function(){return this.getObjectModel().getStore()}},{key:"setPipelineFlow",value:function(e){this.objectModel.setPipelineFlow(e),this.ensureVisibleExpandedPipelinesAreLoaded()}},{key:"clearPipelineFlow",value:function(){this.objectModel.clearPipelineFlow()}},{key:"getPipelineFlow",value:function(){return this.objectModel.getPipelineFlow()}},{key:"getPipelineFlowId",value:function(){return this.objectModel.getPipelineFlowId()}},{key:"getPrimaryPipelineId",value:function(){return this.objectModel.getPrimaryPipelineId()}},{key:"getExternalPipelineFlow",value:function(e){return this.objectModel.getExternalPipelineFlow(e)}},{key:"getCanvasInfo",value:function(){return this.objectModel.getCanvasInfo()}},{key:"getAncestorPipelineIds",value:function(e){return this.objectModel.getAncestorPipelineIds(e)}},{key:"removeAllStyles",value:function(e){this.objectModel.removeAllStyles(e)}},{key:"setSubdueStyle",value:function(e){this.objectModel.setSubdueStyle(e)}},{key:"getPipeline",value:function(e){return this.objectModel.getCanvasInfoPipeline(e)}},{key:"getCurrentPipelineId",value:function(){return this.objectModel.getCurrentBreadcrumb().pipelineId}},{key:"isPipelineExternal",value:function(e){return this.objectModel.getAPIPipeline(e).isPipelineExternal()}},{key:"getFlowMessages",value:function(e){return this.objectModel.getAPIPipeline(e).getFlowMessages()}},{key:"isFlowValid",value:function(e,t){return this.objectModel.getAPIPipeline(t).isFlowValid(e)}},{key:"autoLayout",value:function(e,t){this.objectModel.getAPIPipeline(t).autoLayout(e)}},{key:"setCanvas",value:function(e){this.objectModel.setCanvas(e)}},{key:"setPaletteData",value:function(e){this.objectModel.setPaletteData(e)}},{key:"getCanvas",value:function(){return this.objectModel.getCanvas()}},{key:"setPipelineFlowPalette",value:function(e){this.objectModel.setPipelineFlowPalette(e)}},{key:"clearPaletteData",value:function(){this.objectModel.clearPaletteData()}},{key:"setCategoryLoadingText",value:function(e,t){this.objectModel.setCategoryLoadingText(e,t)}},{key:"setCategoryEmptyText",value:function(e,t){this.objectModel.setCategoryEmptyText(e,t)}},{key:"addNodeTypeToPalette",value:function(e,t,n,i,o){this.objectModel.addNodeTypeToPalette(e,t,n,i,o)}},{key:"addNodeTypesToPalette",value:function(e,t,n,i,o){this.objectModel.addNodeTypesToPalette(e,t,n,i,o)}},{key:"removeNodesFromPalette",value:function(e,t){this.objectModel.addNodeTypesToPalette(e,t)}},{key:"getPaletteData",value:function(){return this.objectModel.getPaletteData()}},{key:"getPaletteNode",value:function(e){return this.objectModel.getPaletteNode(e)}},{key:"getPaletteNodeById",value:function(e){return this.objectModel.getPaletteNodeById(e)}},{key:"getCategoryForNode",value:function(e){return this.objectModel.getCategoryForNode(e)}},{key:"convertNodeTemplate",value:function(e){return this.objectModel.convertNodeTemplate(e)}},{key:"setSelections",value:function(e,t){this.objectModel.setSelections(e,t)}},{key:"clearSelections",value:function(){this.objectModel.clearSelections()}},{key:"selectAll",value:function(e){var t=this.getCanvasConfig().enableLinkSelection!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ac;this.objectModel.selectAll(t,e)}},{key:"isPrimaryPipelineEmpty",value:function(){return this.objectModel.isPrimaryPipelineEmpty()}},{key:"getSelectedObjectIds",value:function(){return this.objectModel.getSelectedObjectIds()}},{key:"getSelectedNodes",value:function(){return this.objectModel.getSelectedNodes()}},{key:"getSelectedComments",value:function(){return this.objectModel.getSelectedComments()}},{key:"getSelectedLinks",value:function(){return this.objectModel.getSelectedLinks()}},{key:"getSelectedObjects",value:function(){return this.objectModel.getSelectedObjects()}},{key:"getSelectedPipelineId",value:function(){return this.objectModel.getSelectedPipelineId()}},{key:"deleteSelectedObjects",value:function(){this.objectModel.deleteSelectedObjects()}},{key:"areSelectedNodesContiguous",value:function(){return this.objectModel.areSelectedNodesContiguous()}},{key:"areAllSelectedObjectsLinks",value:function(){return this.objectModel.areAllSelectedObjectsLinks()}},{key:"areDetachableLinksInUse",value:function(){return this.getCanvasConfig().enableLinkSelection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a7}},{key:"isSnapToGridInUse",value:function(){return this.getCanvasConfig().enableSnapToGridType!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aO}},{key:"setNotificationMessages",value:function(e){this.objectModel.setNotificationMessages(e)}},{key:"clearNotificationMessages",value:function(){this.objectModel.clearNotificationMessages()}},{key:"deleteNotificationMessages",value:function(e){this.objectModel.deleteNotificationMessages(e)}},{key:"getNotificationMessages",value:function(e){return this.objectModel.getNotificationMessages(e)}},{key:"getNotificationMessagesMaxType",value:function(){return this.objectModel.getNotificationMessagesMaxType()}},{key:"moveObjects",value:function(e,t){this.objectModel.getAPIPipeline(t).moveObjects(e)}},{key:"deleteObjects",value:function(e,t){this.objectModel.getAPIPipeline(t).deleteObjects(e)}},{key:"disconnectObjects",value:function(e,t){this.objectModel.getAPIPipeline(t).disconnectObjects(e)}},{key:"deleteObject",value:function(e,t){this.objectModel.getAPIPipeline(t).deleteObject(e)}},{key:"setObjectsStyle",value:function(e,t,n){this.objectModel.setObjectsStyle(e,t,n)}},{key:"setObjectsMultiStyle",value:function(e,t){this.objectModel.setObjectsMultiStyle(e,t)}},{key:"getNodes",value:function(e){return this.objectModel.getAPIPipeline(e).getNodes()}},{key:"createNode",value:function(e,t){return this.objectModel.getAPIPipeline(t).createNode(e)}},{key:"addNode",value:function(e,t){this.objectModel.getAPIPipeline(t).addNode(e)}},{key:"createNodeCommand",value:function(e,t){var n=t||this.getCurrentPipelineId();this.createNodeFromTemplateAt(e.nodeTemplate,{x:e.offsetX,y:e.offsetY},n)}},{key:"deleteNode",value:function(e,t){this.objectModel.getAPIPipeline(t).deleteNode(e)}},{key:"setNodeProperties",value:function(e,t,n){this.objectModel.getAPIPipeline(n).setNodeProperties(e,t)}},{key:"setNodeParameters",value:function(e,t,n){this.objectModel.getAPIPipeline(n).setNodeParameters(e,t)}},{key:"setNodeUiParameters",value:function(e,t,n){this.objectModel.getAPIPipeline(n).setNodeUiParameters(e,t)}},{key:"setNodeMessages",value:function(e,t,n){this.objectModel.getAPIPipeline(n).setNodeMessages(e,t)}},{key:"setNodeMessage",value:function(e,t,n){this.objectModel.getAPIPipeline(n).setNodeMessage(e,t)}},{key:"setNodeLabel",value:function(e,t,n){this.objectModel.getAPIPipeline(n).setNodeLabel(e,t)}},{key:"setNodesClassName",value:function(e,t,n){this.objectModel.getAPIPipeline(n).setObjectsClassName(e,t)}},{key:"setNodeDecorations",value:function(e,t,n){this.objectModel.getAPIPipeline(n).setNodeDecorations(e,t)}},{key:"setNodeInputPorts",value:function(e,t,n){this.objectModel.getAPIPipeline(n).setNodeInputPorts(e,t)}},{key:"setNodeOutputPorts",value:function(e,t,n){this.objectModel.getAPIPipeline(n).setNodeOutputPorts(e,t)}},{key:"setNodesMultiDecorations",value:function(e){this.objectModel.setNodesMultiDecorations(e)}},{key:"setInputPortLabel",value:function(e,t,n,i){this.objectModel.getAPIPipeline(i).setInputPortLabel(e,t,n)}},{key:"setOutputPortLabel",value:function(e,t,n,i){this.objectModel.getAPIPipeline(i).setOutputPortLabel(e,t,n)}},{key:"getNode",value:function(e,t){return this.objectModel.getAPIPipeline(t).getNode(e)}},{key:"getNodeUiParameters",value:function(e,t){return this.objectModel.getAPIPipeline(t).getNodeUiParameters(e)}},{key:"getSupernodes",value:function(e){return this.objectModel.getAPIPipeline(e).getSupernodes()}},{key:"getSupernodeObjReferencing",value:function(e){return this.objectModel.getSupernodeObjReferencing(e)}},{key:"getNodeMessages",value:function(e,t){return this.objectModel.getAPIPipeline(t).getNodeMessages(e)}},{key:"getNodeMessage",value:function(e,t,n){return this.objectModel.getAPIPipeline(n).getNodeMessage(e,t)}},{key:"getNodeInputPorts",value:function(e,t){return this.objectModel.getAPIPipeline(t).getNodeInputPorts(e)}},{key:"getNodeOutputPorts",value:function(e,t){return this.objectModel.getAPIPipeline(t).getNodeOutputPorts(e)}},{key:"getNodeDecorations",value:function(e,t){return this.objectModel.getAPIPipeline(t).getNodeDecorations(e)}},{key:"getNodeClassName",value:function(e,t){return this.objectModel.getAPIPipeline(t).getNodeClassName(e)}},{key:"getNodeStyle",value:function(e,t,n){return this.objectModel.getAPIPipeline(n).getNodeStyle(e,t)}},{key:"getBranchNodes",value:function(e,t){var n=t||this.objectModel.getCurrentPipelineId();return this.objectModel.getHighlightObjectIds(n,e,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aN)}},{key:"getUpstreamNodes",value:function(e,t){var n=t||this.objectModel.getCurrentPipelineId();return this.objectModel.getHighlightObjectIds(n,e,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aM)}},{key:"getDownstreamNodes",value:function(e,t){var n=t||this.objectModel.getCurrentPipelineId();return this.objectModel.getHighlightObjectIds(n,e,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aL)}},{key:"addCustomAttrToNodes",value:function(e,t,n){this.objectModel.getAPIPipeline(n).addCustomAttrToNodes(e,t)}},{key:"removeCustomAttrFromNodes",value:function(e,t,n){this.objectModel.getAPIPipeline(n).removeCustomAttrFromNodes(e,t)}},{key:"isSuperNodeExpandedInPlace",value:function(e,t){return this.objectModel.getAPIPipeline(t).isSuperNodeExpandedInPlace(e)}},{key:"getComments",value:function(e){return this.objectModel.getAPIPipeline(e).getComments()}},{key:"getComment",value:function(e,t){return this.objectModel.getAPIPipeline(t).getComment(e)}},{key:"createComment",value:function(e,t){this.objectModel.getAPIPipeline(t).createComment(e)}},{key:"addComment",value:function(e,t){this.objectModel.getAPIPipeline(t).addComment(e)}},{key:"editComment",value:function(e,t){this.objectModel.getAPIPipeline(t).editComment(e)}},{key:"setCommentProperties",value:function(e,t,n){this.objectModel.getAPIPipeline(n).setCommentProperties(e,t)}},{key:"setCommentsClassName",value:function(e,t,n){this.objectModel.getAPIPipeline(n).setObjectsClassName(e,t)}},{key:"deleteComment",value:function(e,t){this.objectModel.getAPIPipeline(t).deleteComment(e)}},{key:"addCustomAttrToComments",value:function(e,t,n){this.objectModel.getAPIPipeline(n).addCustomAttrToComments(e,t)}},{key:"removeCustomAttrFromComments",value:function(e,t,n){this.objectModel.getAPIPipeline(n).removeCustomAttrFromComments(e,t)}},{key:"getCommentClassName",value:function(e,t){return this.objectModel.getAPIPipeline(t).getCommentClassName(e)}},{key:"getCommentStyle",value:function(e,t,n){return this.objectModel.getAPIPipeline(n).getCommentStyle(e,t)}},{key:"getLink",value:function(e,t){return this.objectModel.getAPIPipeline(t).getLink(e)}},{key:"getLinks",value:function(e){return this.objectModel.getAPIPipeline(e).getLinks()}},{key:"setLinkProperties",value:function(e,t,n){this.objectModel.getAPIPipeline(n).setLinkProperties(e,t)}},{key:"setNodeDataLinkSrcInfo",value:function(e,t,n,i){this.objectModel.getAPIPipeline(i).setNodeDataLinkSrcInfo(e,t,n)}},{key:"setNodeDataLinkTrgInfo",value:function(e,t,n,i){this.objectModel.getAPIPipeline(i).setNodeDataLinkTrgInfo(e,t,n)}},{key:"getNodeDataLinkFromInfo",value:function(e,t,n,i,o){return this.objectModel.getAPIPipeline(o).getNodeDataLinkFromInfo(e,t,n,i)}},{key:"getCommentLinkFromInfo",value:function(e,t,n){return this.objectModel.getAPIPipeline(n).getCommentLinkFromInfo(e,t)}},{key:"getNodeAssocLinkFromInfo",value:function(e,t,n){return this.objectModel.getAPIPipeline(n).getNodeAssocLinkFromInfo(e,t)}},{key:"addLinks",value:function(e,t){this.objectModel.getAPIPipeline(t).addLinks(e)}},{key:"deleteLink",value:function(e,t){this.objectModel.getAPIPipeline(t).deleteLink(e)}},{key:"createNodeLinks",value:function(e,t){return this.objectModel.getAPIPipeline(t).createNodeLinks(e)}},{key:"createCommentLinks",value:function(e,t){return this.objectModel.getAPIPipeline(t).createCommentLinks(e)}},{key:"setLinksClassName",value:function(e,t,n){this.objectModel.getAPIPipeline(n).setLinksClassName(e,t)}},{key:"setLinksStyle",value:function(e,t,n){this.objectModel.setLinksStyle(e,t,n)}},{key:"setLinksMultiStyle",value:function(e,t){this.objectModel.setLinksMultiStyle(e,t)}},{key:"getLinkClassName",value:function(e,t){return this.objectModel.getAPIPipeline(t).getLinkClassName(e)}},{key:"getLinkStyle",value:function(e,t,n){return this.objectModel.getAPIPipeline(n).getLinkStyle(e,t)}},{key:"setLinkDecorations",value:function(e,t,n){this.objectModel.getAPIPipeline(n).setLinkDecorations(e,t)}},{key:"setLinksMultiDecorations",value:function(e){this.objectModel.setLinksMultiDecorations(e)}},{key:"getLinkDecorations",value:function(e,t){return this.objectModel.getAPIPipeline(t).getLinkDecorations(e)}},{key:"getCommandStack",value:function(){return this.commandStack}},{key:"undo",value:function(){this.canUndo()&&this.getCommandStack().undo()}},{key:"redo",value:function(){this.canRedo()&&this.getCommandStack().redo()}},{key:"canUndo",value:function(){return this.getCommandStack().canUndo()}},{key:"canRedo",value:function(){return this.getCommandStack().canRedo()}},{key:"getUndoLabel",value:function(){if(this.canUndo()){var e=this.getCommandStack().getUndoCommand();if(e&&e.getLabel)return e.getLabel()}return""}},{key:"getRedoLabel",value:function(){if(this.canRedo()){var e=this.getCommandStack().getRedoCommand();if(e&&e.getLabel)return e.getLabel()}return""}},{key:"getBreadcrumbs",value:function(){return this.objectModel.getBreadcrumbs()}},{key:"getCurrentBreadcrumb",value:function(){return this.objectModel.getCurrentBreadcrumb()}},{key:"setHighlightStyle",value:function(e,t){this.removeAllStyles(!0);var n={body:{default:"fill: ".concat(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aQ," ;stroke: ").concat(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aR,";"),hover:"fill: ".concat(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aS,";")}},i={line:{default:"stroke: ".concat(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aR,";"),hover:"stroke-width: ".concat(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aT)}};this.setObjectsStyle(e.nodes,n,!0,!1),this.setLinksStyle(e.links,i,!0,!1),this.highlight=!0}},{key:"highlightBranch",value:function(e,t){var n=this.objectModel.getHighlightObjectIds(t,e,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aN);return this.setHighlightStyle(n,t),n}},{key:"highlightUpstream",value:function(e,t){var n=this.objectModel.getHighlightObjectIds(t,e,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aM);return this.setHighlightStyle(n,t),n}},{key:"highlightDownstream",value:function(e,t){var n=this.objectModel.getHighlightObjectIds(t,e,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aL);return this.setHighlightStyle(n,t),n}},{key:"getLoggingState",value:function(){return _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_9__.L.getLoggingState()}},{key:"setLoggingState",value:function(e){_canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_9__.L.setLoggingState(e)}},{key:"log",value:function(e){new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_9__.L("Host App").log(e)}},{key:"addAfterUpdateCallback",value:function(e){this.canvasContents&&this.canvasContents.addAfterUpdateCallback(e)}},{key:"removeAfterUpdateCallback",value:function(e){this.canvasContents&&this.canvasContents.removeAfterUpdateCallback(e)}},{key:"togglePalette",value:function(){this.getObjectModel().togglePalette()}},{key:"openPalette",value:function(){this.getObjectModel().openPalette()}},{key:"closePalette",value:function(){this.getObjectModel().closePalette()}},{key:"isPaletteOpen",value:function(){return this.getObjectModel().isPaletteOpen()}},{key:"openContextMenu",value:function(e){this.objectModel.openContextMenu(e)}},{key:"isBottomPanelOpen",value:function(){return this.getObjectModel().isBottomPanelOpen()}},{key:"closeContextMenu",value:function(){this.objectModel.closeContextMenu()}},{key:"isContextMenuDisplayed",value:function(){return this.objectModel.isContextMenuDisplayed()}},{key:"openNotificationPanel",value:function(){this.objectModel.openNotificationPanel()}},{key:"closeNotificationPanel",value:function(){this.objectModel.closeNotificationPanel()}},{key:"toggleNotificationPanel",value:function(){this.objectModel.toggleNotificationPanel()}},{key:"isRightFlyoutOpen",value:function(){return this.objectModel.isRightFlyoutOpen()}},{key:"displaySubPipeline",value:function(e){var t=this.objectModel.getBreadcrumbs(),n=t.findIndex((function(t){return t.pipelineId===e}));if(n>-1){var i={editType:"displaySubPipeline",editSource:"canvas",targetObject:this.getSupernodeFromBreadcrumb(t[n]),breadcrumbIndex:n};this.editActionHandler(i)}}},{key:"displaySubPipelineForSupernode",value:function(e,t){var n=this.getNode(e,t);if(n&&n.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai){var i=this.objectModel.getCurrentBreadcrumb(),o=this.objectModel.createBreadcrumb(n,i.pipelineId);this.displaySubPipelineForBreadcrumbs([o])}}},{key:"displaySubPipelineForBreadcrumbs",value:function(e){var t=e[e.length-1],n={editType:"displaySubPipeline",editSource:"canvas",targetObject:this.getSupernodeFromBreadcrumb(t),addBreadcrumbs:e};this.editActionHandler(n)}},{key:"getSupernodeFromBreadcrumb",value:function(e){return e.supernodeParentPipelineId?this.objectModel.getAPIPipeline(e.supernodeParentPipelineId).getNode(e.supernodeId):null}},{key:"displayPreviousPipeline",value:function(){var e={editType:"displayPreviousPipeline",pipelineInfo:this.objectModel.getPreviousBreadcrumb(),editSource:"canvas"};this.editActionHandler(e)}},{key:"zoomIn",value:function(){this.canvasContents&&this.getSVGCanvasD3().zoomIn()}},{key:"zoomOut",value:function(){this.canvasContents&&this.getSVGCanvasD3().zoomOut()}},{key:"zoomToFit",value:function(){this.canvasContents&&this.getSVGCanvasD3().zoomToFit()}},{key:"zoomTo",value:function(e){this.canvasContents&&this.getSVGCanvasD3().zoomTo(e)}},{key:"translateBy",value:function(e,t,n){this.canvasContents&&this.getSVGCanvasD3().translateBy(e,t,n)}},{key:"getZoom",value:function(){return this.getSVGCanvasD3().getZoom()}},{key:"getZoomToReveal",value:function(e,t,n){return this.canvasContents?this.getSVGCanvasD3().getZoomToReveal(e,t,n):null}},{key:"clearSavedZoomValues",value:function(){this.objectModel.clearSavedZoomValues()}},{key:"getGhostNode",value:function(e){return this.canvasContents?this.getSVGCanvasD3().getGhostNode(e):null}},{key:"nodeTemplateDragStart",value:function(e){i.dragNodeTemplate=e,this.canvasContents&&this.getSVGCanvasD3().nodeTemplateDragStart(i.dragNodeTemplate)}},{key:"nodeTemplateDragEnd",value:function(){this.canvasContents&&i.dragNodeTemplate&&this.getSVGCanvasD3().nodeTemplateDragEnd(i.dragNodeTemplate),i.dragNodeTemplate=null}},{key:"getDragNodeTemplate",value:function(){return i.dragNodeTemplate}},{key:"cutToClipboard",value:function(){this.editActionHandler({editType:"cut",editSource:"api"})}},{key:"copyToClipboard",value:function(){this.editActionHandler({editType:"copy",editSource:"api"})}},{key:"pasteFromClipboard",value:function(e){this.editActionHandler({editType:"paste",editSource:"api",pipelineId:e})}},{key:"isClipboardEmpty",value:function(){return this.objectModel.isClipboardEmpty()}},{key:"canPaste",value:function(){return!this.isClipboardEmpty()}},{key:"canCutCopy",value:function(){return this.getSelectedObjectIds().length>0&&!(this.areAllSelectedObjectsLinks()&&!this.areDetachableLinksInUse())}},{key:"canDelete",value:function(){return this.getSelectedObjectIds().length>0}},{key:"canZoomIn",value:function(){return!this.isPrimaryPipelineEmpty()&&(!this.getSVGCanvasD3()||!this.getSVGCanvasD3().isZoomedToMax())}},{key:"canZoomOut",value:function(){return!this.isPrimaryPipelineEmpty()&&(!this.getSVGCanvasD3()||!this.getSVGCanvasD3().isZoomedToMin())}},{key:"canZoomToFit",value:function(){return!this.isPrimaryPipelineEmpty()}},{key:"getSavedZoom",value:function(e){return this.objectModel.getSavedZoom(e)}},{key:"openTip",value:function(e){if(!this.isTipOpen()&&this.isTipEnabled(e.type)){if(this.handlers.tipHandler){var t={};switch(e.type){case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.r:t.nodeTemplate=e.nodeTemplate;break;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.t:t.category=e.category;break;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.z:t.pipelineId=e.pipelineId,t.node=e.node;break;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.y:t.pipelineId=e.pipelineId,t.node=e.node,t.port=e.port;break;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.x:t.pipelineId=e.pipelineId,t.decoration=e.decoration;break;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.w:t.pipelineId=e.pipelineId,t.link=e.link;break;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.v:t.stateTagText=e.stateTagText,t.stateTagType=e.stateTagType}e.customContent=this.handlers.tipHandler(e.type,t)}var n=this;this.pendingTooltip&&clearTimeout(this.pendingTooltip),this.pendingTooltip=setTimeout((function(){n.objectModel.setTooltipDef(e)}),e.delay?e.delay:200)}}},{key:"closeTip",value:function(){this.pendingTooltip&&clearTimeout(this.pendingTooltip),this.isTipOpen()&&this.objectModel.setTooltipDef({})}},{key:"isTipOpen",value:function(){return this.objectModel.isTooltipOpen()}},{key:"isTipEnabled",value:function(e){var t=this.getCanvasConfig();switch(e){case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.r:case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.t:return t.tipConfig.palette;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.z:return t.tipConfig.nodes;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.y:return t.tipConfig.ports;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.x:return t.tipConfig.decorations;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.w:return t.tipConfig.links;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.v:return t.tipConfig.stateTag;default:return!1}}},{key:"createDroppedExternalObject",value:function(e,t,n){e&&("createFromObject"===e.operation?this.createNodeFromObjectAt(e.sourceId,e.sourceObjectTypeId,e.label,t.x,t.y,n):this.createNodeFromDataAt(t.x,t.y,e,n))}},{key:"createAutoNode",value:function(e){var t=this.objectModel.getSelectionAPIPipeline(),n=t||this.objectModel.getAPIPipeline(),i={editType:"createAutoNode",editSource:"canvas",nodeTemplate:this.convertNodeTemplate(e),pipelineId:n.pipelineId};this.editActionHandler(i)}},{key:"createNodeFromTemplateAt",value:function(e,t,n){var i={editType:"createNode",editSource:"canvas",nodeTemplate:this.convertNodeTemplate(e),offsetX:t.x,offsetY:t.y,pipelineId:n};this.editActionHandler(i)}},{key:"createNodeFromTemplateOnLinkAt",value:function(e,t,n,i){var o=this.convertNodeTemplate(e);if(this.canNewNodeBeDroppedOnLink(o)){var a={editType:"createNodeOnLink",editSource:"canvas",nodeTemplate:o,offsetX:n.x,offsetY:n.y,link:t,pipelineId:i};this.editActionHandler(a)}}},{key:"createNodeFromTemplateAttachLinks",value:function(e,t,n,i){var o=this.convertNodeTemplate(e);if(t&&this.canNewNodeBeAttachedToLinks(o)){var a={editType:"createNodeAttachLinks",editSource:"canvas",nodeTemplate:o,offsetX:n.x,offsetY:n.y,detachedLinks:t,pipelineId:i};this.editActionHandler(a)}}},{key:"createNodeFromObjectAt",value:function(e,t,n,i,o,a){var r={editType:"createNode",editSource:"canvas",label:n,offsetX:i,offsetY:o,sourceObjectId:e,sourceObjectTypeId:t,pipelineId:a};this.editActionHandler(r)}},{key:"createNodeFromDataAt",value:function(e,t,n,i){var o=n.data;o.offsetX=e,o.offsetY=t,o.pipelineId=i,o.editSource="canvas",this.editActionHandler(o)}},{key:"canNewNodeBeDroppedOnLink",value:function(e){return!!(e.inputs&&e.inputs.length>0&&e.outputs&&e.outputs.length>0)}},{key:"canNewNodeBeAttachedToLinks",value:function(e){return!!(e.inputs&&e.inputs.length>0||e.outputs&&e.outputs.length>0)}},{key:"createEditMenu",value:function(e,t){var n=[{action:"cut",label:this.labelUtil.getLabel("edit.cutSelection"),enable:e.selectedObjectIds.length>0},{action:"copy",label:this.labelUtil.getLabel("edit.copySelection"),enable:e.selectedObjectIds.length>0}];return t&&n.push({action:"paste",label:this.labelUtil.getLabel("edit.pasteSelection"),enable:!this.isClipboardEmpty()}),n}},{key:"createHighlightMenu",value:function(e){return[{action:"highlightBranch",label:this.labelUtil.getLabel("menu.highlightBranch")},{action:"highlightUpstream",label:this.labelUtil.getLabel("menu.highlightUpstream")},{action:"highlightDownstream",label:this.labelUtil.getLabel("menu.highlightDownstream")}]}},{key:"createUnhighlightMenu",value:function(e){return[{action:"unhighlight",label:this.labelUtil.getLabel("menu.unhighlight"),enable:this.highlight}]}},{key:"createDefaultMenu",value:function(e){var t=[];("canvas"===e.type&&(t=t.concat([{action:"createComment",label:this.labelUtil.getLabel("canvas.addComment")},{action:"selectAll",label:this.labelUtil.getLabel("canvas.selectAll")},{divider:!0}])),"node"===e.type||"comment"===e.type)&&(this.objectModel.getAPIPipeline(e.pipelineId).getLinksContainingIds(e.selectedObjectIds).length>0&&(t=(t=t.concat({action:"disconnectNode",label:this.labelUtil.getLabel("node.disconnectNode")})).concat({divider:!0})));if("comment"===e.type&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.k)(this,"contextMenuConfig.defaultMenuEntries.colorBackground",!0)&&(t=(t=t.concat({submenu:!0,menu:"colorPicker",label:this.labelUtil.getLabel("comment.colorBackground")})).concat({divider:!0})),"node"===e.type||"comment"===e.type||"link"===e.type&&this.areDetachableLinksInUse()||"canvas"===e.type){var i=this.createEditMenu(e,"canvas"===e.type);t=(t=t.concat({submenu:!0,menu:i,label:this.labelUtil.getLabel("node.editMenu")})).concat({divider:!0})}if("canvas"===e.type&&(t=t.concat([{action:"undo",label:this.labelUtil.getLabel("canvas.undo"),enable:this.canUndo()},{action:"redo",label:this.labelUtil.getLabel("canvas.redo"),enable:this.canRedo()},{divider:!0}])),("node"===e.type||"comment"===e.type||this.getCanvasConfig().enableLinkSelection!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ac&&"link"===e.type)&&(t=t.concat([{action:"deleteSelectedObjects",label:this.labelUtil.getLabel("canvas.deleteObject")},{divider:!0}])),"node"!==e.type&&"comment"!==e.type||this.isCreateSupernodeCMOptionRequired()&&((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(this,"contextMenuConfig.enableCreateSupernodeNonContiguous")&&this.contextMenuConfig.enableCreateSupernodeNonContiguous||this.areSelectedNodesContiguous())&&(t=t.concat([{action:"createSuperNode",label:this.labelUtil.getLabel("node.createSupernode")}]),this.getCanvasConfig().enableExternalPipelineFlows&&(t=t.concat([{action:"createSuperNodeExternal",label:this.labelUtil.getLabel("node.createSupernodeExternal")}])),t=t.concat([{divider:!0}])),"node"!==e.type||1!==e.selectedObjectIds.length||e.targetObject.type!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai||"canvas"!==e.targetObject.open_with_tool&&void 0!==e.targetObject.open_with_tool||(t=(t=t.concat({action:"deconstructSuperNode",label:this.labelUtil.getLabel("node.deconstructSupernode")})).concat({divider:!0}),t=this.isSuperNodeExpandedInPlace(e.targetObject.id,e.pipelineId)?t.concat({action:"collapseSuperNodeInPlace",label:this.labelUtil.getLabel("node.collapseSupernodeInPlace")}):t.concat({action:"expandSuperNodeInPlace",label:this.labelUtil.getLabel("node.expandSupernode")}),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.k)(this,"contextMenuConfig.defaultMenuEntries.displaySupernodeFullPage")&&(t=t.concat({action:"displaySubPipeline",label:this.labelUtil.getLabel("node.displaySupernodeFullPage")})),t=t.concat({divider:!0}),this.getCanvasConfig().enableExternalPipelineFlows&&(e.targetObject.subflow_ref.url?this.isPipelineExternal(e.pipelineId)||(t=t.concat({action:"convertSuperNodeExternalToLocal",label:this.labelUtil.getLabel("node.convertSupernodeExternalToLocal")},{divider:!0})):t=t.concat({action:"convertSuperNodeLocalToExternal",label:this.labelUtil.getLabel("node.convertSupernodeLocalToExternal")},{divider:!0}))),this.getCanvasConfig().enableLinkSelection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ac&&"link"===e.type&&(t=t.concat([{action:"deleteLink",label:this.labelUtil.getLabel("canvas.deleteObject")}])),"node"===e.type){var o=this.createHighlightMenu(e);o.push({divider:!0}),o=o.concat(this.createUnhighlightMenu(e)),t=t.concat({submenu:!0,menu:o,label:this.labelUtil.getLabel("menu.highlight")})}return"canvas"===e.type&&(t=t.concat({action:"unhighlight",label:this.labelUtil.getLabel("menu.unhighlight"),enable:this.highlight})),"node"===e.type&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(this,"contextMenuConfig.defaultMenuEntries.saveToPalette")&&this.contextMenuConfig.defaultMenuEntries.saveToPalette&&(t=t.concat({divider:!0},{action:"saveToPalette",label:this.labelUtil.getLabel("node.saveToPalette")})),t}},{key:"filterOutEditingActions",value:function(e){var t=this,n=[];return e.forEach((function(e){if(e.submenu){var i=t.filterOutEditingActions(e.menu);i&&i.length>0&&(e.menu=i,n.push(e))}else t.isEditingAction(e.action)||n.push(e)})),n}},{key:"isEditingAction",value:function(e){return"createComment"===e||"disconnectNode"===e||"cut"===e||"copy"===e||"paste"===e||"undo"===e||"redo"===e||"deleteSelectedObjects"===e||"createSuperNode"===e||"createSuperNodeExternal"===e||"deconstructSuperNode"===e||"collapseSuperNodeInPlace"===e||"expandSuperNodeInPlace"===e||"convertSuperNodeExternalToLocal"===e||"convertSuperNodeLocalToExternal"===e||"deleteLink"===e||"saveToPalette"===e}},{key:"isCreateSupernodeCMOptionRequired",value:function(){var e=!0;return (0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(this,"contextMenuConfig.defaultMenuEntries.createSupernode")&&!1===this.contextMenuConfig.defaultMenuEntries.createSupernode&&(e=!1),e}},{key:"contextMenuHandler",value:function(e){this.contextMenuSource=e;var t,n=this.createDefaultMenu(e);if("function"==typeof this.handlers.contextMenuHandler){var i=this.handlers.contextMenuHandler(e,n);i&&i.length>0&&(t=i)}else t=n;t&&t.length>0&&!1===this.getCanvasConfig().enableEditingActions&&(t=this.filterOutEditingActions(t)),t&&t.length>0&&!this.allDividers(t)&&this.openContextMenu(t)}},{key:"allDividers",value:function(e){var t=e.filter((function(e){return e.divider}));return e.length===t.length}},{key:"getContextMenuPos",value:function(){return this.contextMenuSource?this.contextMenuSource.cmPos:{x:0,y:0}}},{key:"contextMenuActionHandler",value:function(e,t){this.logger.log("contextMenuActionHandler - action: "+e),this.logger.log(this.contextMenuSource);var n=Object.assign({},this.contextMenuSource,{editType:e,editParam:t,editSource:"contextmenu"});this.editActionHandler(n),this.canvasContents.focusOnCanvas(),this.closeContextMenu()}},{key:"toolbarActionHandler",value:function(e){this.logger.log("toolbarActionHandler - action: "+e),this.editActionHandler({editType:e,editSource:"toolbar",pipelineId:this.objectModel.getSelectedPipelineId()})}},{key:"keyboardActionHandler",value:function(e,t){this.logger.log("keyboardActionHandler - action: "+e),this.editActionHandler({editType:e,editSource:"keyboard",pipelineId:this.objectModel.getSelectedPipelineId(),mousePos:t})}},{key:"clickActionHandler",value:function(e){this.logger.log("clickActionHandler - "+e.clickType+" on "+e.objectType),this.handlers.clickActionHandler&&this.handlers.clickActionHandler(e)}},{key:"decorationActionHandler",value:function(e,t,n){this.logger.log("decorationActionHandler - node: "+e.id+" id: "+t),this.handlers.decorationActionHandler&&this.handlers.decorationActionHandler(e,t,n)}},{key:"editActionHandler",value:function(e){this.logger.log("editActionHandler - "+e.editType),this.logger.log(e);var t=e;if(t.selectedObjectIds=this.getSelectedObjectIds(),t.selectedObjects=this.getSelectedObjects(),"createSuperNodeExternal"===t.editType||"convertSuperNodeLocalToExternal"===t.editType?(t.externalUrl="",t.externalPipelineFlowId=""):"loadPipelineFlow"!==t.editType&&"expandSuperNodeInPlace"!==t.editType&&"displaySubPipeline"!==t.editType&&"deconstructSuperNode"!==t.editType&&"convertSuperNodeExternalToLocal"!==t.editType||(t=this.preProcessForExternalPipelines(t)),this.handlers.beforeEditActionHandler){var n=null;if("undo"===t.editType?n=this.getCommandStack().getUndoCommand():"redo"===t.editType&&(n=this.getCommandStack().getRedoCommand()),!(t=this.handlers.beforeEditActionHandler(t,n)))return;if(!this.wasExtPipelineFlowLoadSuccessful(t))return}this.editAction(t)}},{key:"editAction",value:function(e){var t=e;if("deleteSelectedObjects"!==t.editType||0!==t.selectedObjectIds.length){switch(t.editType){case"selectAll":this.selectAll(t.pipelineId);break;case"zoomIn":this.zoomIn();break;case"zoomOut":this.zoomOut();break;case"zoomToFit":this.zoomToFit();break;case"togglePalette":this.togglePalette();break;case"toggleNotificationPanel":this.toggleNotificationPanel();break;case"loadPipelineFlow":this.objectModel.ensurePipelineIsLoaded(t)}var n=null;if(this.getCanvasConfig().enableInternalObjectModel)switch(t.editType){case"createNode":n=new _t(t,this.objectModel,this.labelUtil),this.commandStack.do(n),t=n.getData();break;case"createNodeOnLink":n=new Et(t,this.objectModel,this.labelUtil),this.commandStack.do(n),t=n.getData();break;case"createNodeAttachLinks":n=new wt(t,this.objectModel,this.labelUtil),this.commandStack.do(n),t=n.getData();break;case"createAutoNode":var i=this.getCanvasConfig().enableAutoLinkOnlyFromSelNodes;n=new ht(t,this.objectModel,this.labelUtil,i),this.commandStack.do(n),this.panToReveal(t),t=n.getData();break;case"createComment":n=new yt(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"createAutoComment":var o=this.getSVGCanvasD3().getSvgViewportOffset();n=new yt(t,this.objectModel,this.labelUtil,o),this.commandStack.do(n),t=n.getData();break;case"insertNodeIntoLink":n=new an(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"attachNodeToLinks":n=new dt(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"moveObjects":n=new sn(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"resizeObjects":n=new Bi(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"setObjectsStyle":n=new mn(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"setLinksStyle":n=new bn(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"updateLink":n=new kn(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"setNodeLabel":n=new en(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"editComment":n=new Kt(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"editDecorationLabel":n=new Zt(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"linkNodes":n=new Pt(t,this.objectModel,this.labelUtil),this.commandStack.do(n),t=n.getData();break;case"linkNodesAndReplace":n=new Pt(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"linkComment":n=new vt(t,this.objectModel,this.labelUtil),this.commandStack.do(n),t=n.getData();break;case"createDetachedLink":n=new Nt(t,this.objectModel,this.labelUtil),this.commandStack.do(n),t=n.getData();break;case"colorSelectedObjects":n=new Mt(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"deleteSelectedObjects":n=new qt(t,this.objectModel,this.labelUtil,this.areDetachableLinksInUse()),this.commandStack.do(n);break;case"displaySubPipeline":n=new Yt(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"displayPreviousPipeline":n=new $t(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"arrangeHorizontally":n=new rt(t,this.objectModel,this.labelUtil,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aP),this.commandStack.do(n);break;case"arrangeVertically":n=new rt(t,this.objectModel,this.labelUtil,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ax),this.commandStack.do(n);break;case"createSuperNode":case"createSuperNodeExternal":n=new xt(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"deconstructSuperNode":n=new Ut(t,this.objectModel,this.labelUtil,this.getCanvasConfig().enableMoveNodesOnSupernodeResize),this.commandStack.do(n);break;case"expandSuperNodeInPlace":n=new nn(t,this.objectModel,this.labelUtil,this.getCanvasConfig().enableMoveNodesOnSupernodeResize),this.commandStack.do(n);break;case"collapseSuperNodeInPlace":n=new At(t,this.objectModel,this.labelUtil,this.getCanvasConfig().enableMoveNodesOnSupernodeResize),this.commandStack.do(n);break;case"convertSuperNodeExternalToLocal":n=new lt(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"convertSuperNodeLocalToExternal":n=new pt(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"deleteLink":n=new Bt(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"disconnectNode":n=new zt(t,this.objectModel,this.labelUtil),this.commandStack.do(n);break;case"saveToPalette":n=new un(t,this.objectModel,this.labelUtil,this.labelUtil),this.commandStack.do(n);break;case"cut":this.objectModel.copyToClipboard(this.areDetachableLinksInUse()),n=new qt(t,this.objectModel,this.labelUtil,this.areDetachableLinksInUse()),this.commandStack.do(n);break;case"copy":this.objectModel.copyToClipboard(this.areDetachableLinksInUse());break;case"paste":var a=this.objectModel.getObjectsToPaste();if(a){t.objects=a;var r=this.getSVGCanvasD3().getTransformedViewportDimensions();n=new cn(t,this.objectModel,this.labelUtil,r,this.areDetachableLinksInUse(),this.isSnapToGridInUse()),this.commandStack.do(n),t=n.getData()}break;case"undo":n=this.getCommandStack().getUndoCommand(),this.commandStack.undo();break;case"redo":n=this.getCommandStack().getRedoCommand(),this.commandStack.redo();break;case"setZoom":this.objectModel.setZoom(t.zoom,t.pipelineId);break;case"highlightBranch":t.highlightedObjectIds=this.highlightBranch(this.objectModel.getSelectedNodesIds(),t.pipelineId);break;case"highlightDownstream":t.highlightedObjectIds=this.highlightDownstream(this.objectModel.getSelectedNodesIds(),t.pipelineId);break;case"highlightUpstream":t.highlightedObjectIds=this.highlightUpstream(this.objectModel.getSelectedNodesIds(),t.pipelineId);break;case"unhighlight":this.removeAllStyles(!0),this.highlight=!1;break;case"openNotificationPanel":this.openNotificationPanel();break;case"closeNotificationPanel":this.closeNotificationPanel()}this.handlers.editActionHandler&&this.handlers.editActionHandler(t,n),this.ensureVisibleExpandedPipelinesAreLoaded()}}},{key:"preProcessForExternalPipelines",value:function(e){if(e.externalPipelineFlowLoad=!1,e.targetObject){var t=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.k)(e,"targetObject.subflow_ref.url");t&&(e.externalUrl=t,e.externalPipelineFlow=this.objectModel.getExternalPipelineFlow(t),e.externalPipelineFlow||(e.externalPipelineFlowLoad=!0))}return e}},{key:"ensureVisibleExpandedPipelinesAreLoaded",value:function(){var e=this.objectModel.getVisibleExpandedExternalSupernodes();e&&e.length>0&&this.editActionHandler({editType:"loadPipelineFlow",targetObject:e[0]})}},{key:"wasExtPipelineFlowLoadSuccessful",value:function(e){if(e.externalPipelineFlowLoad&&!e.externalPipelineFlow){var t="The host app did not provide a pipeline flow when requested for action "+e.editType+" in beforeEditActionHandler, for URL: "+e.externalUrl;return this.logger.error(t),!1}return!0}},{key:"panToReveal",value:function(e){var t=this;this.addAfterUpdateCallback((function n(){var i=t.getZoomToReveal([e.newNode.id]);i&&t.zoomTo(i),t.removeAfterUpdateCallback(n)}))}}]),i}();qi.dragNodeTemplate=null;
//# sourceMappingURL=canvas-controller-e023521c.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/canvas-logger-815781bb.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/canvas-logger-815781bb.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "L": () => (/* binding */ i)
/* harmony export */ });
/* harmony import */ var _createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./createClass-32a0cf0f.js */ "../../node_modules/@elyra/canvas/dist/createClass-32a0cf0f.js");
var i=function(){function i(e){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_0__._)(this,i),this.prefix=e}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_0__.a)(i,[{key:"log",value:function(e){i.active&&("string"==typeof e?console.info(this.getMessage("",e)):console.info(e))}},{key:"logStartTimer",value:function(e){if(i.active){var t=this.getStartMessage("",e),n=this.getEndMessage("",e);console.info(t),console.time(n)}}},{key:"logEndTimer",value:function(e,t){if(i.active){var n=this.getEndMessage("",e);console.timeEnd(n),t&&console.info("--------------------------------------------------")}}},{key:"debug",value:function(e){i.active&&console.log(this.getMessage("DEBUG",e))}},{key:"warn",value:function(e){console.warn(this.getMessage("WARNING",e))}},{key:"error",value:function(e){console.error(this.getMessage("ERROR",e))}},{key:"getStartMessage",value:function(e,t){return this.getMessage(e,t)+" - start"}},{key:"getEndMessage",value:function(e,t){return this.getMessage(e,t)+" - end"}},{key:"getMessage",value:function(e,t){var i="";if(e&&(i+="["+e+"] "),"string"==typeof this.prefix)i+=this.abbreviate(this.prefix)+" - ";else for(var n=0;n<this.prefix.length;n++)i+=this.abbreviate(this.prefix[n])+" - ";return i+t}},{key:"abbreviate",value:function(e){return e&&e.length>20?e.substr(0,17)+"...":e}}],[{key:"getLoggingState",value:function(){return i.active}},{key:"setLoggingState",value:function(e){i.active=e}},{key:"switchLoggingState",value:function(){i.active?(new i("Logger").log("Switching canvas logging off"),i.active=!1):(i.active=!0,new i("Logger").log("Switching canvas logging on"))}}]),i}();i.active=!1;
//# sourceMappingURL=canvas-logger-815781bb.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/common-canvas-bdfb8c87.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/common-canvas-bdfb8c87.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "c": () => (/* binding */ Xs)
/* harmony export */ });
/* harmony import */ var _createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./createClass-32a0cf0f.js */ "../../node_modules/@elyra/canvas/dist/createClass-32a0cf0f.js");
/* harmony import */ var _getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./getPrototypeOf-97272efe.js */ "../../node_modules/@elyra/canvas/dist/getPrototypeOf-97272efe.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react-redux */ "webpack/sharing/consume/default/react-redux/react-redux");
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react_redux__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var react_intl__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! react-intl */ "webpack/sharing/consume/default/react-intl/react-intl");
/* harmony import */ var react_intl__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react_intl__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./isArrayLikeObject-a9c7973b.js */ "../../node_modules/@elyra/canvas/dist/isArrayLikeObject-a9c7973b.js");
/* harmony import */ var _icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./icon-caf4caca.js */ "../../node_modules/@elyra/canvas/dist/icon-caf4caca.js");
/* harmony import */ var react_inlinesvg__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! react-inlinesvg */ "../../node_modules/react-inlinesvg/esm/index.js");
/* harmony import */ var _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./canvas-constants-3c09c7f6.js */ "../../node_modules/@elyra/canvas/dist/canvas-constants-3c09c7f6.js");
/* harmony import */ var _toolbar_a5ec3435_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./toolbar-a5ec3435.js */ "../../node_modules/@elyra/canvas/dist/toolbar-a5ec3435.js");
/* harmony import */ var _datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./datarecord-metadata-v3-schema-81228a9a.js */ "../../node_modules/@elyra/canvas/dist/datarecord-metadata-v3-schema-81228a9a.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/InlineLoading/InlineLoading.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/Search/index.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/Button/Button.js");
/* harmony import */ var _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./canvas-logger-815781bb.js */ "../../node_modules/@elyra/canvas/dist/canvas-logger-815781bb.js");
/* harmony import */ var _lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./lib/tooltip.es.js */ "../../node_modules/@elyra/canvas/dist/lib/tooltip.es.js");
/* harmony import */ var react_resize_detector__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! react-resize-detector */ "../../node_modules/react-resize-detector/lib/esm/index.js");
/* harmony import */ var _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./canvas-controller-e023521c.js */ "../../node_modules/@elyra/canvas/dist/canvas-controller-e023521c.js");
/* harmony import */ var _lib_context_menu_es_js__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./lib/context-menu.es.js */ "../../node_modules/@elyra/canvas/dist/lib/context-menu.es.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-16.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-10.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-11.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var _en_8647c347_js__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./en-8647c347.js */ "../../node_modules/@elyra/canvas/dist/en-8647c347.js");
/* harmony import */ var _baseForOwn_d38b560e_js__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./_baseForOwn-d38b560e.js */ "../../node_modules/@elyra/canvas/dist/_baseForOwn-d38b560e.js");
var Ve="Find palette nodes",Ze="No results found.",$e="Try adjusting your search to find what you're looking for.",qe="Results restricted to 10 nodes. Try refining your search.",Ke="Show more",Je="Show less",Qe="Flyout Palette",et="Dialog Palette";function tt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var nt=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,i);var o=tt(s);function s(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(n=o.call(this,t)).state={hover:!1},n.iconClicked=n.iconClicked.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.mouseEnter=n.mouseEnter.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.mouseLeave=n.mouseLeave.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.mouseDown=n.mouseDown.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"iconClicked",value:function(){this.props.iconClickedMethod()}},{key:"mouseEnter",value:function(){this.setState({hover:!0})}},{key:"mouseLeave",value:function(){this.setState({hover:!1})}},{key:"mouseDown",value:function(e){e.stopPropagation()}},{key:"render",value:function(){var e=this.props.selectedIconName;return this.props.isSelected||(e=this.state.hover?this.props.hoverIconName:this.props.deselectedIconName),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{draggable:"false",className:"palette-three-way-icon-div"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("img",{src:e,draggable:"false",onClick:this.iconClicked,onMouseEnter:this.mouseEnter,onMouseLeave:this.mouseLeave,onMouseDown:this.mouseDown}))}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function it(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var ot=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,i);var o=it(s);function s(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(n=o.call(this,t)).state={},n.mouseDown=n.mouseDown.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.doubleClick=n.doubleClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.close=n.close.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.gridViewSelected=n.gridViewSelected.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.listViewSelected=n.listViewSelected.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"mouseDown",value:function(e){this.props.mouseDownMethod(e)}},{key:"doubleClick",value:function(e){this.props.windowMaximizeMethod(e)}},{key:"close",value:function(e){this.props.canvasController.closePalette(e)}},{key:"gridViewSelected",value:function(){this.props.showGridMethod(!0)}},{key:"listViewSelected",value:function(){this.props.showGridMethod(!1)}},{key:"render",value:function(){return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-dialog-topbar",onMouseDown:this.mouseDown,onDoubleClick:this.doubleClick},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{className:"left-navbar"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(nt,{iconClickedMethod:this.gridViewSelected,isSelected:this.props.showGrid,selectedIconName:"data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2016%2016%22%20enable-background%3D%22new%200%200%2016%2016%22%3E%3Cg%20fill%3D%22%233D70B2%22%3E%3Cpath%20d%3D%22m9.8%200h6.2v6.2h-6.2z%22%2F%3E%3Cpath%20d%3D%22M8.6%2C0H7.4H0v7.4v1.2V16h7.4h1.2H16V8.6V7.4H8.6V0z%20M7.4%2C14.8H1.2V8.6h6.2V14.8z%20M14.8%2C8.6v6.2H8.6V8.6%20%20H14.8z%20M1.2%2C7.4V1.2h6.2v6.2H1.2z%22%2F%3E%3C%2Fg%3E%3C%2Fsvg%3E",hoverIconName:"data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2016%2016%22%20enable-background%3D%22new%200%200%2016%2016%22%3E%3Cg%20fill%3D%22%235596e6%22%3E%3Cpath%20d%3D%22m9.8%200h6.2v6.2h-6.2z%22%2F%3E%3Cpath%20d%3D%22M8.6%2C0H7.4H0v7.4v1.2V16h7.4h1.2H16V8.6V7.4H8.6V0z%20M7.4%2C14.8H1.2V8.6h6.2V14.8z%20M14.8%2C8.6v6.2H8.6V8.6%20%20H14.8z%20M1.2%2C7.4V1.2h6.2v6.2H1.2z%22%2F%3E%3C%2Fg%3E%3C%2Fsvg%3E",deselectedIconName:"data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2016%2016%22%20enable-background%3D%22new%200%200%2016%2016%22%3E%3Cg%20fill%3D%22%23C7C7C7%22%3E%3Cpath%20d%3D%22m9.8%200h6.2v6.2h-6.2z%22%2F%3E%3Cpath%20d%3D%22M8.6%2C0H7.4H0v7.4v1.2V16h7.4h1.2H16V8.6V7.4H8.6V0z%20M7.4%2C14.8H1.2V8.6h6.2V14.8z%20M14.8%2C8.6v6.2H8.6V8.6%20%20H14.8z%20M1.2%2C7.4V1.2h6.2v6.2H1.2z%22%2F%3E%3C%2Fg%3E%3C%2Fsvg%3E"}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(nt,{iconClickedMethod:this.listViewSelected,isSelected:!this.props.showGrid,selectedIconName:"data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2016%2016%22%20enable-background%3D%22new%200%200%2016%2016%22%3E%3Cg%20fill%3D%22%233D70B2%22%3E%3Cpath%20d%3D%22m0%2014.5h1.5v1.5h-1.5z%22%2F%3E%3Cpath%20d%3D%22m3.3%2014.5h12.7v1.5h-12.7z%22%2F%3E%3Cpath%20d%3D%22m0%209.7h1.5v1.5h-1.5z%22%2F%3E%3Cpath%20d%3D%22m3.3%209.7h12.7v1.5h-12.7z%22%2F%3E%3Cpath%20d%3D%22m0%204.8h1.5v1.5h-1.5z%22%2F%3E%3Cpath%20d%3D%22m3.3%204.8h12.7v1.5h-12.7z%22%2F%3E%3Cpath%20d%3D%22m0%200h1.5v1.5h-1.5z%22%2F%3E%3Cpath%20d%3D%22m3.3%200h12.7v1.5h-12.7z%22%2F%3E%3C%2Fg%3E%3C%2Fsvg%3E",hoverIconName:"data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2016%2016%22%20enable-background%3D%22new%200%200%2016%2016%22%3E%3Cg%20fill%3D%22%235596e6%22%3E%3Cpath%20d%3D%22m0%2014.5h1.5v1.5h-1.5z%22%2F%3E%3Cpath%20d%3D%22m3.3%2014.5h12.7v1.5h-12.7z%22%2F%3E%3Cpath%20d%3D%22m0%209.7h1.5v1.5h-1.5z%22%2F%3E%3Cpath%20d%3D%22m3.3%209.7h12.7v1.5h-12.7z%22%2F%3E%3Cpath%20d%3D%22m0%204.8h1.5v1.5h-1.5z%22%2F%3E%3Cpath%20d%3D%22m3.3%204.8h12.7v1.5h-12.7z%22%2F%3E%3Cpath%20d%3D%22m0%200h1.5v1.5h-1.5z%22%2F%3E%3Cpath%20d%3D%22m3.3%200h12.7v1.5h-12.7z%22%2F%3E%3C%2Fg%3E%3C%2Fsvg%3E",deselectedIconName:"data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2016%2016%22%20enable-background%3D%22new%200%200%2016%2016%22%3E%3Cg%20fill%3D%22%23C7C7C7%22%3E%3Cpath%20d%3D%22m0%2014.5h1.5v1.5h-1.5z%22%2F%3E%3Cpath%20d%3D%22m3.3%2014.5h12.7v1.5h-12.7z%22%2F%3E%3Cpath%20d%3D%22m0%209.7h1.5v1.5h-1.5z%22%2F%3E%3Cpath%20d%3D%22m3.3%209.7h12.7v1.5h-12.7z%22%2F%3E%3Cpath%20d%3D%22m0%204.8h1.5v1.5h-1.5z%22%2F%3E%3Cpath%20d%3D%22m3.3%204.8h12.7v1.5h-12.7z%22%2F%3E%3Cpath%20d%3D%22m0%200h1.5v1.5h-1.5z%22%2F%3E%3Cpath%20d%3D%22m3.3%200h12.7v1.5h-12.7z%22%2F%3E%3C%2Fg%3E%3C%2Fsvg%3E"})),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{className:"right-navbar"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("a",{className:"secondary-action",onClick:this.close},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("img",{src:"data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2032%2032%22%3E%3Cpath%20style%3D%22fill%3A%233D70B2%22%20d%3D%22M20.293%2010.293L16%2014.586l-4.293-4.293-1.414%201.414L14.586%2016l-4.293%204.293%201.414%201.414L16%2017.414l4.293%204.293%201.414-1.414L17.414%2016l4.293-4.293z%22%2F%3E%3Cpath%20style%3D%22fill%3A%233D70B2%22%20d%3D%22M16%202C8.269%202%202%208.269%202%2016s6.269%2014%2014%2014%2014-6.269%2014-14S23.731%202%2016%202zm0%2026C9.383%2028%204%2022.617%204%2016S9.383%204%2016%204s12%205.383%2012%2012-5.383%2012-12%2012z%22%2F%3E%3C%2Fsvg%3E",draggable:"false",className:"close-icon"}))))}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function at(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var rt=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,i);var o=at(s);function s(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(n=o.call(this,t)).state={},n.categorySelected=n.categorySelected.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"categorySelected",value:function(e){this.props.categorySelectedMethod(e)}},{key:"render",value:function(){var e="palette-dialog-category";return this.props.selectedCategory===this.props.category.label&&(e="palette-dialog-category-selected"),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":this.props.category.id,className:e,onClick:this.categorySelected},this.props.category.label)}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function st(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var lt=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(a,i);var o=st(a);function a(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,a),(n=o.call(this,t)).state={},n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(a,[{key:"render",value:function(){for(var e=[],t=0;t<this.props.categories.length;t++)e.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement(rt,{key:this.props.categories[t].label,category:this.props.categories[t],selectedCategory:this.props.selectedCategory,categorySelectedMethod:this.props.categorySelectedMethod}));return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-dialog-categories palette-scroll"},e)}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),ct="data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2064%2060%22%3E%20%3Cpath%20d%3D%22M32%2C42a1.61%2C1.61%2C0%2C0%2C1-.8-.2L9.28%2C30.15l1.6-2.94L32%2C38.47%2C53.12%2C27.21l1.6%2C2.94L32.8%2C41.84A1.71%2C1.71%2C0%2C0%2C1%2C32%2C42Z%22%2F%3E%20%3Cpath%20d%3D%22M32%2C52.05a1.72%2C1.72%2C0%2C0%2C1-.8-.2L9.28%2C40.17l1.6-2.94L32%2C48.48%2C53.12%2C37.23l1.6%2C2.94L32.8%2C51.85A1.72%2C1.72%2C0%2C0%2C1%2C32%2C52.05Z%22%2F%3E%20%3Cpath%20d%3D%22M32%2C32a1.72%2C1.72%2C0%2C0%2C1-.8-.2L9.28%2C20.14a1.66%2C1.66%2C0%2C0%2C1%2C0-2.94L31.2%2C5.52a1.68%2C1.68%2C0%2C0%2C1%2C1.6%2C0L54.72%2C17.2a1.66%2C1.66%2C0%2C0%2C1%2C.69%2C2.26%2C1.74%2C1.74%2C0%2C0%2C1-.69.68L32.8%2C31.82A1.72%2C1.72%2C0%2C0%2C1%2C32%2C32ZM13.64%2C18.67%2C32%2C28.46l18.36-9.79L32%2C8.88Z%22%2F%3E%20%3Crect%20x%3D%225.02%22%20y%3D%221.98%22%20width%3D%2253.96%22%20height%3D%2253.41%22%20fill%3D%22none%22%2F%3E%3C%2Fsvg%3E",ut="data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2064%2060%22%3E%20%3Cdefs%3E%20%20%3CclipPath%20id%3D%22a%22%3E%20%20%20%3Cpolygon%20points%3D%2217.28%204.63%2026.88%2014.07%2024.74%2015.87%2018.94%2010.35%2018.94%2026.29%2015.78%2026.29%2015.78%2010.35%209.97%2016.12%207.91%2014.04%2017.28%204.63%22%2F%3E%20%20%3C%2FclipPath%3E%20%20%3CclipPath%20id%3D%22b%22%3E%20%20%20%3Cpath%20d%3D%22M32.39%2C6.36l.2.1%2C20.35%2C11a2.7%2C2.7%2C0%2C0%2C1%2C1.11%2C1.11%2C2.74%2C2.74%2C0%2C0%2C1-.89%2C3.59l-.22.13L33%2C33a2.66%2C2.66%2C0%2C0%2C1-2.51%2C0l-6-3.13a1.83%2C1.83%2C0%2C1%2C1%2C1.69-3.25l5.57%2C2.89%2C18-9.69L30.85%2C9.68A1.83%2C1.83%2C0%2C0%2C1%2C30%2C7.39l.09-.19A1.83%2C1.83%2C0%2C0%2C1%2C32.39%2C6.36Z%22%20%20%20clip-path%3D%22url%28%23a%29%22%2F%3E%20%20%3C%2FclipPath%3E%20%3C%2Fdefs%3E%20%3Cpolygon%20points%3D%2217.28%204.63%2026.88%2014.07%2024.74%2015.87%2018.94%2010.35%2018.94%2026.29%2015.78%2026.29%2015.78%2010.35%209.97%2016.12%207.91%2014.04%2017.28%204.63%22%2F%3E%20%3Cpath%20d%3D%22M32.39%2C6.36l.2.1%2C20.35%2C11a2.7%2C2.7%2C0%2C0%2C1%2C1.11%2C1.11%2C2.74%2C2.74%2C0%2C0%2C1-.89%2C3.59l-.22.13L33%2C33a2.66%2C2.66%2C0%2C0%2C1-2.51%2C0l-6-3.13a1.83%2C1.83%2C0%2C1%2C1%2C1.69-3.25l5.57%2C2.89%2C18-9.69L30.85%2C9.68A1.83%2C1.83%2C0%2C0%2C1%2C30%2C7.39l.09-.19A1.83%2C1.83%2C0%2C0%2C1%2C32.39%2C6.36Z%22%2F%3E%20%3Cpath%20d%3D%22M53%2C28.53l1.62%2C3L32.52%2C43.43a1.59%2C1.59%2C0%2C0%2C1-.8.21%2C1.66%2C1.66%2C0%2C0%2C1-.81-.21L8.8%2C31.53l1.61-3L31.72%2C40Z%22%2F%3E%20%3Cpath%20d%3D%22M53%2C38.74l1.62%2C3L32.52%2C53.64a1.69%2C1.69%2C0%2C0%2C1-.8.2%2C1.76%2C1.76%2C0%2C0%2C1-.81-.2L8.8%2C41.73l1.61-3L31.72%2C50.21Z%22%2F%3E%3C%2Fsvg%3E";function dt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var ht=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,i);var o=dt(s);function s(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(n=o.call(this,t)).state={},n.ghostData=null,n.onDragStart=n.onDragStart.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onDragEnd=n.onDragEnd.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onDoubleClick=n.onDoubleClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onMouseOver=n.onMouseOver.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onMouseLeave=n.onMouseLeave.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onMouseDown=n.onMouseDown.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"onMouseDown",value:function(){this.props.canvasController.closeTip(),this.ghostData=this.props.canvasController.getGhostNode(this.props.nodeTemplate)}},{key:"onDragStart",value:function(e){this.props.canvasController.nodeTemplateDragStart(this.props.nodeTemplate),e.dataTransfer.setData(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.D,""),this.ghostData&&e.dataTransfer.setDragImage(this.ghostData.element,this.ghostData.centerX,this.ghostData.centerY)}},{key:"onDragEnd",value:function(){this.props.canvasController.nodeTemplateDragEnd()}},{key:"onDoubleClick",value:function(){this.props.canvasController.createAutoNode&&this.props.canvasController.createAutoNode(this.props.nodeTemplate)}},{key:"onMouseOver",value:function(e){if(0===e.buttons){var t=this.props.category.empty_text?{app_data:{ui_data:{label:this.props.category.empty_text}}}:this.props.nodeTemplate;this.props.canvasController.openTip({id:"paletteTip_"+this.props.nodeTemplate.op,type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.r,targetObj:e.currentTarget,nodeTemplate:t,category:this.props.category})}}},{key:"onMouseLeave",value:function(){this.props.canvasController.closeTip()}},{key:"render",value:function(){var e="";(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(this.props.nodeTemplate,"app_data.ui_data.label")&&(e=this.props.nodeTemplate.app_data.ui_data.label);var t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"node-icon"});if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(this.props.nodeTemplate,"app_data.ui_data.image")){var n=this.props.nodeTemplate.app_data.ui_data.image;n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.U?n=ct:n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.s&&(n=ut),t=n.endsWith(".svg")?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_inlinesvg__WEBPACK_IMPORTED_MODULE_7__["default"],{src:n,className:"node-icon",alt:e}):react__WEBPACK_IMPORTED_MODULE_0___default().createElement("img",{src:n,className:"node-icon",alt:e})}var i=this.props.isEditingEnabled?"true":"false",o="palette-dialog-grid-node-text";return this.props.category&&0===this.props.category.node_types.length&&this.props.category.empty_text&&(e=this.props.category.empty_text,i="false",o="palette-dialog-grid-node-text-warning",t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_8__.I,{type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a.WARNING_UNFILLED,className:"palette-dialog-grid-node-icon-warning",draggable:"false"})),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{id:this.props.nodeTemplate.id,"data-id":this.props.nodeTemplate.op,draggable:i,onMouseOver:this.onMouseOver,onMouseLeave:this.onMouseLeave,onMouseDown:this.props.isEditingEnabled?this.onMouseDown:null,onDragStart:this.props.isEditingEnabled?this.onDragStart:null,onDragEnd:this.props.isEditingEnabled?this.onDragEnd:null,onDoubleClick:this.props.isEditingEnabled?this.onDoubleClick:null,className:"palette-dialog-grid-node-outer"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-dialog-grid-node-inner"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-dialog-grid-node-icon"},t),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:o},e)))}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),pt=ht;function gt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var ft=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(a,i);var o=gt(a);function a(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,a),(n=o.call(this,t)).state={},n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(a,[{key:"render",value:function(){var e=[];if(this.props.category&&this.props.category.node_types&&0===this.props.category.node_types.length&&this.props.category.empty_text)e.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement(pt,{key:"pal_grid_node_empty",category:this.props.category,nodeTemplate:{},canvasController:this.props.canvasController,isEditingEnabled:this.props.isEditingEnabled}));else for(var t=0;t<this.props.nodeTypes.length;t++)e.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement(pt,{key:"pal_grid_node_"+t,category:this.props.category,nodeTemplate:this.props.nodeTypes[t],canvasController:this.props.canvasController,isEditingEnabled:this.props.isEditingEnabled}));var n=this.props.show?"block":"none";return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{width:"100%",className:"palette-scroll",style:{display:n}},e)}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function vt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var yt=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,i);var o=vt(s);function s(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(n=o.call(this,t)).state={showFullDescription:!1},n.ghostData=null,n.showFullDescription=n.showFullDescription.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.showShortDescription=n.showShortDescription.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onDragStart=n.onDragStart.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onDragEnd=n.onDragEnd.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onDoubleClick=n.onDoubleClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onMouseOver=n.onMouseOver.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onMouseLeave=n.onMouseLeave.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onMouseDown=n.onMouseDown.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"onMouseDown",value:function(){this.props.canvasController.closeTip(),this.ghostData=this.props.canvasController.getGhostNode(this.props.nodeTypeInfo.nodeType)}},{key:"onDragStart",value:function(e){this.props.canvasController.nodeTemplateDragStart(this.props.nodeTypeInfo.nodeType),e.dataTransfer.setData(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.D,""),this.ghostData&&e.dataTransfer.setDragImage(this.ghostData.element,this.ghostData.centerX,this.ghostData.centerY)}},{key:"onDragEnd",value:function(){this.props.canvasController.nodeTemplateDragEnd()}},{key:"onDoubleClick",value:function(){this.props.canvasController.createAutoNode&&this.props.canvasController.createAutoNode(this.props.nodeTypeInfo.nodeType)}},{key:"onMouseOver",value:function(e){if(!this.props.isDisplaySearchResult&&0===e.buttons){var t=this.props.nodeTypeInfo.category.empty_text?{app_data:{ui_data:{label:this.props.nodeTypeInfo.category.empty_text}}}:this.props.nodeTypeInfo.nodeType;this.props.canvasController.openTip({id:"paletteTip_"+this.props.nodeTypeInfo.nodeType.op,type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.r,targetObj:e.currentTarget,nodeTemplate:t,category:this.props.nodeTypeInfo.category})}}},{key:"onMouseLeave",value:function(){this.props.canvasController.closeTip()}},{key:"getHighlightedCategoryLabel",value:function(){return this.getHighlightedText(this.props.nodeTypeInfo.category.label,this.props.nodeTypeInfo.occurrenceInfo.catLabelOccurrences)}},{key:"getHighlightedLabel",value:function(){return this.getHighlightedText(this.props.nodeTypeInfo.nodeType.app_data.ui_data.label,this.props.nodeTypeInfo.occurrenceInfo.nodeLabelOccurrences)}},{key:"getHighlightedDesc",value:function(){var e=this.props.nodeTypeInfo.nodeType.app_data.ui_data.description,t=this.props.nodeTypeInfo.occurrenceInfo.nodeDescOccurrences,n=!1;if(e.length>150&&(n=!0,!this.state.showFullDescription)){var i=this.getAbbreviatedDescription(e,t,150);e=i.abbrDesc,t=i.occurrences}var o=this.getHighlightedText(e,t);if(n)if(this.state.showFullDescription){var a=this.props.intl.formatMessage({id:"palette.flyout.search.less",defaultMessage:Je});o.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:"l_btn",className:"palette-list-item-desc-button",onClick:this.showShortDescription},a))}else{var s=this.props.intl.formatMessage({id:"palette.flyout.search.more",defaultMessage:Ke});o.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:"m_btn",className:"palette-list-item-desc-button",onClick:this.showFullDescription},s))}return o}},{key:"getAbbreviatedDescription",value:function(e,t,n){if(0===t.length)return{abbrDesc:e.substring(0,n)+" ...",occurrences:t};var i=t[0].start,o=e.length-i,a="",r=0;return i<n?(r=0,a=e.substring(r,n)+" ..."):o>n?(r=i,a="... "+e.substring(r,i+n)+" ...",r-=4):(r=e.length-n,a="... "+e.substring(r,e.length),r-=4),{abbrDesc:a,occurrences:t.map((function(e){return{start:e.start-r,end:e.end-r}}))}}},{key:"getHighlightedText",value:function(e,t){if(!t||0===t.length)return[react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{key:"o"},e)];var n=[],i=0,o="";return t.forEach((function(a,s){o=e.substring(i,a.start),n.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{key:"s"+s},o)),o=e.substring(a.start,a.end),n.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("mark",{key:"m"+s},o)),i=a.end,s===t.length-1&&a.end<e.length&&(o=e.substring(a.end),n.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{key:"f"+s},o)))})),n}},{key:"showFullDescription",value:function(){this.setState({showFullDescription:!0})}},{key:"showShortDescription",value:function(){this.setState({showFullDescription:!1})}},{key:"imageDrag",value:function(){return!1}},{key:"render",value:function(){var e=null,t=this.props.isEditingEnabled?"true":"false",n=null;if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(this.props.nodeTypeInfo.nodeType,"app_data.ui_data.image")){var i=this.props.nodeTypeInfo.nodeType.app_data.ui_data.image;i===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.U?i=ct:i===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.s&&(i=ut),n=i.endsWith(".svg")?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_inlinesvg__WEBPACK_IMPORTED_MODULE_7__["default"],{src:i,className:"palette-list-item-icon",draggable:"false"}):react__WEBPACK_IMPORTED_MODULE_0___default().createElement("img",{src:i,className:"palette-list-item-icon",draggable:"false"})}!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(this.props.nodeTypeInfo.nodeType,"app_data.ui_data.label")||!this.props.isPaletteOpen&&n||(e=this.props.isDisplaySearchResult?this.getHighlightedLabel():react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",null,this.props.nodeTypeInfo.nodeType.app_data.ui_data.label));var o=this.props.isShowRanking&&this.props.isDisplaySearchResult&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(this.props.nodeTypeInfo,"occurrenceInfo.ranking")?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",null,this.props.nodeTypeInfo.occurrenceInfo.ranking):null;0===this.props.nodeTypeInfo.category.node_types.length&&this.props.nodeTypeInfo.category.empty_text&&(this.props.isPaletteOpen&&(e=this.props.nodeTypeInfo.category.empty_text),t="false",n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_8__.I,{type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a.WARNING_UNFILLED,className:"palette-list-item-icon-warning",draggable:"false"}));var a=this.props.isDisplaySearchResult?"palette-list-item search-result":"palette-list-item",s=this.props.isDisplaySearchResult?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-list-item-category-label"},this.getHighlightedCategoryLabel()):null,l=this.props.isDisplaySearchResult&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(this.props.nodeTypeInfo.nodeType,"app_data.ui_data.description")&&this.props.nodeTypeInfo.nodeType.app_data.ui_data.description?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-list-item-description"},this.getHighlightedDesc()):null,c=e?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-list-item-text-div"},e):null;return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{id:this.props.nodeTypeInfo.nodeType.id,"data-id":this.props.nodeTypeInfo.nodeType.op,draggable:t,className:a,onMouseOver:this.onMouseOver,onMouseLeave:this.onMouseLeave,onMouseDown:this.props.isEditingEnabled?this.onMouseDown:null,onDragStart:this.props.isEditingEnabled?this.onDragStart:null,onDragEnd:this.props.isEditingEnabled?this.onDragEnd:null,onDoubleClick:this.props.isEditingEnabled?this.onDoubleClick:null},s,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-list-item-icon-and-text"},n,c,o),l)}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),mt=(0,react_intl__WEBPACK_IMPORTED_MODULE_2__.injectIntl)(yt);function kt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var bt=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(a,i);var o=kt(a);function a(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,a),(n=o.call(this,t)).state={},n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(a,[{key:"render",value:function(){var e=[];if(this.props.category&&this.props.category.node_types&&0===this.props.category.node_types.length&&this.props.category.empty_text)e.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:"item_empty"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(mt,{nodeTypeInfo:{nodeType:{},category:this.props.category},isDisplaySearchResult:!1,canvasController:this.props.canvasController,isPaletteOpen:this.props.isPaletteOpen})));else for(var t=0;t<this.props.nodeTypeInfos.length;t++){var n="item_"+t;e.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:n},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(mt,{nodeTypeInfo:this.props.nodeTypeInfos[t],isDisplaySearchResult:!1,canvasController:this.props.canvasController,isPaletteOpen:this.props.isPaletteOpen,isEditingEnabled:this.props.isEditingEnabled})))}var i={};return i.borderBottom=this.props.isLastCategory?"none":null,i.display=this.props.show?"block":"none",react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{width:"100%",draggable:"false",className:"palette-content-list palette-scroll",style:i},e)}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function Ct(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var Pt=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,i);var o=Ct(s);function s(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(n=o.call(this,t)).state={selectedCategory:""},n.categorySelected=n.categorySelected.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.getUniqueCategories=n.getUniqueCategories.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.getSelectedCategory=n.getSelectedCategory.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"getUniqueCategories",value:function(e){var t=[];if(e)for(var n=0;n<e.length;n++)-1===t.indexOf(e[n].label)&&t.push(e[n]);return t}},{key:"getSelectedCategory",value:function(e){var t={};if(e)for(var n=0;n<e.length;n++)e[n].label===this.state.selectedCategory&&(t=e[n]);return t}},{key:"categorySelected",value:function(e){this.setState({selectedCategory:e.target.firstChild.data})}},{key:"render",value:function(){var e=this.getUniqueCategories(this.props.paletteJSON.categories),t=this.getSelectedCategory(this.props.paletteJSON.categories),n=t&&t.node_types?t.node_types:[],i=n.map((function(e){return{nodeType:e,category:t}}));return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-dialog-content",ref:"palettecontent"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(lt,{categories:e,selectedCategory:this.state.selectedCategory,categorySelectedMethod:this.categorySelected}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(ft,{show:this.props.showGrid,category:t,nodeTypes:n,canvasController:this.props.canvasController,isEditingEnabled:this.props.isEditingEnabled}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(bt,{show:!this.props.showGrid,category:t,nodeTypeInfos:i,canvasController:this.props.canvasController,isPaletteOpen:!0,isLastCategory:!1,isEditingEnabled:this.props.isEditingEnabled}))}}],[{key:"getDerivedStateFromProps",value:function(e,t){return e.paletteJSON&&e.paletteJSON.categories&&e.paletteJSON.categories.length>0&&""===t.selectedCategory?{selectedCategory:e.paletteJSON.categories[0].label}:{}}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function wt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var Lt=(0,react_intl__WEBPACK_IMPORTED_MODULE_2__.injectIntl)(function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,i);var o=wt(s);function s(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(n=o.call(this,t)).state={xPos:100,yPos:100,showGrid:!0},n.showGrid=n.showGrid.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.mouseDownOnTopBar=n.mouseDownOnTopBar.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.mouseDownOnPalette=n.mouseDownOnPalette.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.mouseMove=n.mouseMove.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.mouseUp=n.mouseUp.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.windowResize=n.windowResize.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.windowMaximize=n.windowMaximize.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.getPaletteDiv=n.getPaletteDiv.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.resizePalette=n.resizePalette.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.movePalette=n.movePalette.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.setResizingCursors=n.setResizingCursors.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.setSizingHoverEdge=n.setSizingHoverEdge.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.snapToWidth=n.snapToWidth.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.snapToHeight=n.snapToHeight.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.removePx=n.removePx.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.dragging=!1,n.dragOffsetY=0,n.dragOffsetX=0,n.verticalSizingAction="",n.verticalSizingHover="",n.horizontalSizingAction="",n.hoizontalSizingHover="",n.savedWidth=0,n.savedLeft=0,n.savedHeight=0,n.savedTop=0,n.hoverZoneSize=3,n.totalHoverZoneSize=2*n.hoverZoneSize,n.adjustedWidth=137,n.adjustedHeight=51,n.adjustedScrollBarWidth=15,n.isMaximized=!1,n.paletteNodes=[],n.hackPaletteOffset=46,n.hackPaletteTopOffset=n.hackPaletteOffset+4,window.addEventListener("mousemove",n.mouseMove,!1),window.addEventListener("mouseup",n.mouseUp,!1),window.addEventListener("resize",n.windowResize,!1),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"componentDidUpdate",value:function(){this.windowResize()}},{key:"componentWillUnmount",value:function(){window.removeEventListener("mousemove",this.mouseMove),window.removeEventListener("mouseup",this.mouseUp),window.removeEventListener("resize",this.windowResize)}},{key:"getAdjustedMousePositionBottom",value:function(e,t){var n=e.clientY;return n>t.offsetTop+t.offsetHeight-this.hoverZoneSize&&(n=t.offsetTop+t.offsetHeight-this.hoverZoneSize),n}},{key:"getAdjustedMousePositionLeft",value:function(e,t){var n=e.clientX;return n<t.offsetLeft+this.hoverZoneSize&&(n=t.offsetLeft+this.hoverZoneSize),n}},{key:"getAdjustedMousePositionRight",value:function(e,t){var n=e.clientX;return n>t.offsetLeft+t.offsetWidth-this.hoverZoneSize&&(n=t.offsetLeft+t.offsetWidth-this.hoverZoneSize),n}},{key:"getAdjustedMousePositionTop",value:function(e,t){var n=e.clientY;return n<t.offsetTop+this.hoverZoneSize&&(n=t.offsetTop+this.hoverZoneSize),n}},{key:"getPaletteDiv",value:function(){return this.refs.palette}},{key:"getStyleProperty",value:function(e,t){var n=e.charAt(0),i=e.substring(1),o="#"===n?document.getElementById(i):document.getElementsByClassName(i)[0];return window.getComputedStyle(o,null).getPropertyValue(t)}},{key:"setResizingCursors",value:function(e){var t=this.getPaletteDiv();this.setSizingHoverEdge(e,t),"top"===this.verticalSizingHover?"left"===this.horizontalSizingHover?t.style.cursor="nwse-resize":"right"===this.horizontalSizingHover?t.style.cursor="nesw-resize":t.style.cursor="ns-resize":"bottom"===this.verticalSizingHover?"left"===this.horizontalSizingHover?t.style.cursor="nesw-resize":"right"===this.horizontalSizingHover?t.style.cursor="nwse-resize":t.style.cursor="ns-resize":"left"===this.horizontalSizingHover||"right"===this.horizontalSizingHover?t.style.cursor="ew-resize":t.style.cursor="default"}},{key:"setContentDivHeight",value:function(e,t){var n=t-this.removePx(this.getStyleProperty(".palette-dialog-topbar","height"))-this.totalHoverZoneSize+"px",i=e.childNodes[1];i.style.height=n,i.childNodes[0].style.height=n,i.childNodes[1].style.height=n,i.childNodes[2].style.height=n}},{key:"setSizingHoverEdge",value:function(e,t){e.clientX>t.offsetLeft&&e.clientX<t.offsetLeft+this.totalHoverZoneSize?this.horizontalSizingHover="left":e.clientX<t.offsetLeft+t.offsetWidth&&e.clientX>t.offsetLeft+t.offsetWidth-this.totalHoverZoneSize?this.horizontalSizingHover="right":(this.horizontalSizingHover="",this.horizontalSizingAction=""),e.clientY>t.offsetTop+this.hackPaletteTopOffset&&e.clientY<t.offsetTop+this.hackPaletteTopOffset+this.totalHoverZoneSize?this.verticalSizingHover="top":e.clientY<t.offsetTop+t.offsetHeight+this.hackPaletteOffset&&e.clientY>t.offsetTop+t.offsetHeight+this.hackPaletteOffset-this.totalHoverZoneSize?this.verticalSizingHover="bottom":(this.verticalSizingHover="",this.verticalSizingAction="")}},{key:"mouseDownOnTopBar",value:function(e){this.dragging=!0;var t=this.getPaletteDiv();this.dragOffsetX=e.clientX-t.offsetLeft,this.dragOffsetY=e.clientY-t.offsetTop}},{key:"mouseDownOnPalette",value:function(e){var t=this.getPaletteDiv();""===this.verticalSizingHover&&""===this.horizontalSizingHover||(this.verticalSizingAction=this.verticalSizingHover,this.horizontalSizingAction=this.horizontalSizingHover,this.savedWidth=t.offsetWidth,this.savedLeft=t.offsetLeft,this.savedHeight=t.offsetHeight,this.savedTop=t.offsetTop)}},{key:"mouseMove",value:function(e){""!==this.verticalSizingAction||""!==this.horizontalSizingAction?this.resizePalette(e):!0===this.dragging?this.movePalette(e):this.setResizingCursors(e)}},{key:"mouseUp",value:function(){var e=this.getPaletteDiv();if(this.state.showGrid&&""!==this.horizontalSizingAction){var t=this.removePx(e.style.width);""!==t&&(t=this.snapToWidth(t)),e.style.width=t+"px";var n=e.childNodes[1].childNodes[1];n.clientHeight<n.scrollHeight&&(e.style.width=t+this.adjustedScrollBarWidth+"px")}if(""!==this.verticalSizingAction){var i=this.removePx(e.style.height);if(""!==i){var o=this.snapToHeight(i);e.style.height=o+"px",this.setContentDivHeight(e,o)}}this.dragging=!1,this.verticalSizingAction="",this.horizontalSizingAction="",this.verticalSizingHover="",this.horizontalSizingHover=""}},{key:"movePalette",value:function(e){var t=this.getPaletteDiv(),n=document.getElementById(this.props.parentDivId),i=e.clientX-this.dragOffsetX,o=e.clientY-this.dragOffsetY;i<n.offsetLeft+this.hoverZoneSize&&(i=n.offsetLeft+this.hoverZoneSize),o<n.offsetTop+this.hoverZoneSize&&(o=n.offsetTop+this.hoverZoneSize),i+t.offsetWidth>n.offsetLeft+n.offsetWidth&&(i=n.offsetLeft+n.offsetWidth-t.offsetWidth-this.hoverZoneSize),o+t.offsetHeight>n.offsetTop+n.offsetHeight&&(o=n.offsetTop+n.offsetHeight-t.offsetHeight-this.hoverZoneSize),t.style.left=i+"px",t.style.top=o+"px"}},{key:"removePx",value:function(e){return parseInt(e.substring(0,e.indexOf("px")),10)}},{key:"resizePalette",value:function(e){var t=this.getPaletteDiv(),n=document.getElementById(this.props.parentDivId);this.isMaximized=!1;var i=this.removePx(this.getStyleProperty(".palette-dialog-grid-node-outer","width"))+this.removePx(this.getStyleProperty(".palette-dialog-categories","min-width"))+2*this.hoverZoneSize,o=this.removePx(this.getStyleProperty(".palette-dialog-grid-node-outer","height"))+this.removePx(this.getStyleProperty(".palette-dialog-topbar","height"))+2*this.hoverZoneSize;if("left"===this.horizontalSizingAction){var a=this.getAdjustedMousePositionLeft(e,n),r=this.savedWidth-(a-this.savedLeft);r<=i?t.style.width=i+"px":(t.style.width=r+"px",t.style.left=a+"px")}if("right"===this.horizontalSizingAction){var s=this.getAdjustedMousePositionRight(e,n)-this.savedLeft;s<=i&&(s=i),t.style.width=s+"px"}if("top"===this.verticalSizingAction){var l=this.getAdjustedMousePositionTop(e,n),c=this.savedHeight-(l-this.savedTop);c<=o?(t.style.height=o+"px",this.setContentDivHeight(t,this.minHeight)):(t.style.height=c+"px",t.style.top=l-this.dragOffsetY+"px",this.setContentDivHeight(t,c))}if("bottom"===this.verticalSizingAction){var u=this.getAdjustedMousePositionBottom(e,n)-this.savedTop-this.hackPaletteOffset;u<=o&&(u=o),t.style.height=u+"px",this.setContentDivHeight(t,u)}}},{key:"snapToWidth",value:function(e){var t=this.removePx(this.getStyleProperty(".palette-dialog-grid-node-outer","width"));return Math.round((e-this.adjustedWidth)/t)*t+this.adjustedWidth}},{key:"snapToHeight",value:function(e){var t=this.state.showGrid?this.removePx(this.getStyleProperty(".palette-dialog-grid-node-outer","height")):this.removePx(this.getStyleProperty(".palette-list-item","height"));return Math.round((e-this.adjustedHeight)/t)*t+this.adjustedHeight}},{key:"windowResize",value:function(){var e=this.getPaletteDiv(),t=document.getElementById(this.props.parentDivId);if(t)if(this.isMaximized){var n=t.offsetLeft+this.hoverZoneSize;e.style.left=n+"px";var i=t.offsetWidth-this.totalHoverZoneSize;e.style.width=i+"px";var o=t.offsetTop+this.hoverZoneSize;e.style.top=o+"px";var a=t.offsetHeight-this.totalHoverZoneSize;e.style.height=a+"px",this.setContentDivHeight(e,a)}else{if(e.offsetLeft+e.offsetWidth+this.hoverZoneSize>t.offsetLeft+t.offsetWidth){var r=t.offsetLeft+t.offsetWidth-e.offsetWidth-this.hoverZoneSize;e.style.left=r+"px"}var s=t.offsetWidth-this.totalHoverZoneSize;if(s<e.offsetWidth&&(e.style.width=s+"px",e.style.left=t.offsetLeft+t.offsetWidth-e.offsetWidth-this.hoverZoneSize+"px"),e.offsetTop+e.offsetHeight+this.hoverZoneSize>t.offsetTop+t.offsetHeight){var l=t.offsetTop+t.offsetHeight-e.offsetHeight-this.hoverZoneSize;e.style.top=l+"px"}var c=t.offsetHeight-this.totalHoverZoneSize;c<e.offsetHeight&&(e.style.height=c+"px",e.style.top=t.offsetTop+t.offsetHeight-e.offsetHeight-this.hoverZoneSize+"px",this.setContentDivHeight(e,c))}}},{key:"windowMaximize",value:function(){var e=this.getPaletteDiv(),t=document.getElementById(this.props.parentDivId);if(t)if(this.isMaximized)e.style.width=this.savedWidth+"px",e.style.left=this.savedLeft+"px",e.style.height=this.savedHeight+"px",e.style.top=this.savedTop+"px",this.setContentDivHeight(e,this.savedHeight),this.isMaximized=!1,this.windowResize();else{this.savedWidth=e.offsetWidth,this.savedLeft=e.offsetLeft,this.savedHeight=e.offsetHeight,this.savedTop=e.offsetTop;var n=t.offsetWidth-this.totalHoverZoneSize+1;e.style.width=n+"px",e.style.left=t.offsetLeft+this.hoverZoneSize+"px";var i=t.offsetHeight-this.totalHoverZoneSize+1;e.style.height=i+"px",e.style.top=t.offsetTop+this.hoverZoneSize+"px",this.setContentDivHeight(e,i),this.isMaximized=!0}}},{key:"showGrid",value:function(e){this.setState({showGrid:e})}},{key:"render",value:function(){var e=this.props.showPalette?"block":"none";return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("nav",{"aria-label":this.props.intl.formatMessage({id:"palette.dialog.label",defaultMessage:et}),role:"navigation"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-dialog-div",ref:"palette",onMouseDown:this.mouseDownOnPalette,style:{display:e}},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(ot,{mouseDownMethod:this.mouseDownOnTopBar,showGridMethod:this.showGrid,windowMaximizeMethod:this.windowMaximize,showGrid:this.state.showGrid,canvasController:this.props.canvasController}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Pt,{paletteJSON:this.props.paletteJSON,showGrid:this.state.showGrid,canvasController:this.props.canvasController,isEditingEnabled:this.props.isEditingEnabled})))}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component))),xt=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.O,Nt=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.M,St=function(){return xt.Date.now()},Dt=_toolbar_a5ec3435_js__WEBPACK_IMPORTED_MODULE_9__.t,Tt=Math.max,Et=Math.min;var It=function(e,t,n){var i,o,a,r,s,l,c=0,u=!1,d=!1,h=!0;if("function"!=typeof e)throw new TypeError("Expected a function");function p(t){var n=i,a=o;return i=o=void 0,c=t,r=e.apply(a,n)}function g(e){return c=e,s=setTimeout(v,t),u?p(e):r}function f(e){var n=e-l;return void 0===l||n>=t||n<0||d&&e-c>=a}function v(){var e=St();if(f(e))return y(e);s=setTimeout(v,function(e){var n=t-(e-l);return d?Et(n,a-(e-c)):n}(e))}function y(e){return s=void 0,h&&i?p(e):(i=o=void 0,r)}function m(){var e=St(),n=f(e);if(i=arguments,o=this,l=e,n){if(void 0===s)return g(l);if(d)return clearTimeout(s),s=setTimeout(v,t),p(l)}return void 0===s&&(s=setTimeout(v,t)),r}return t=Dt(t)||0,Nt(n)&&(u=!!n.leading,a=(d="maxWait"in n)?Tt(Dt(n.maxWait)||0,t):a,h="trailing"in n?!!n.trailing:h),m.cancel=function(){void 0!==s&&clearTimeout(s),c=0,i=l=o=s=void 0},m.flush=function(){return void 0===s?r:y(St())},m};function Ot(e,t){var n="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!n){if(Array.isArray(e)||(n=function(e,t){if(!e)return;if("string"==typeof e)return _t(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);"Object"===n&&e.constructor&&(n=e.constructor.name);if("Map"===n||"Set"===n)return Array.from(e);if("Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return _t(e,t)}(e))||t&&e&&"number"==typeof e.length){n&&(e=n);var i=0,o=function(){};return{s:o,n:function(){return i>=e.length?{done:!0}:{done:!1,value:e[i++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var a,r=!0,s=!1;return{s:function(){n=n.call(e)},n:function(){var e=n.next();return r=e.done,e},e:function(e){s=!0,a=e},f:function(){try{r||null==n.return||n.return()}finally{if(s)throw a}}}}function _t(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,i=new Array(t);n<t;n++)i[n]=e[n];return i}function At(e,t){var n=[];if(e.node_types){var i,o=Ot(e.node_types);try{for(o.s();!(i=o.n()).done;){var a=i.value,r=zt(a,e,t);r&&n.push({nodeType:a,category:e,occurrenceInfo:r})}}catch(e){o.e(e)}finally{o.f()}}return n}function zt(e,t,n){if(n.length>0){var i=function(e,t){var n=Mt((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"label")&&e.label?e.label.toLowerCase():"",t),i=n.occurrences,o=n.hitCounts;return{catLabelOccurrences:i,catLabelHitCounts:o}}(t,n),o=i.catLabelOccurrences,a=i.catLabelHitCounts,r=function(e,t){var n=Mt((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.label")&&e.app_data.ui_data.label?e.app_data.ui_data.label.toLowerCase():"",t),i=n.occurrences,o=n.hitCounts;return{nodeLabelOccurrences:i,nodeLabelHitCounts:o}}(e,n),s=r.nodeLabelOccurrences,l=r.nodeLabelHitCounts,c=function(e,t){var n=Mt((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e,"app_data.ui_data.description")&&e.app_data.ui_data.description?e.app_data.ui_data.description.toLowerCase():"",t),i=n.occurrences,o=n.hitCounts;return{nodeDescOccurrences:i,nodeDescHitCounts:o}}(e,n),d=c.nodeDescOccurrences,h=c.nodeDescHitCounts;if(o.length>0||s.length>0||d.length>0){var p=function(e,t,n,i){for(var o=0,a=0,r=0;r<i;r++)o+=e[r]+10*t[r]+n[r],e[r]+t[r]+n[r]>0&&a++;return o+50*a}(a,l,h,n.length);return{catLabelOccurrences:o,nodeLabelOccurrences:s,nodeDescOccurrences:d,ranking:p}}}return null}function Mt(e,t){var n=[],i=[];return t.forEach((function(t){if(t){var o=function(e,t){var n=[],i=0,o=0,a=0;for(;o>-1&&a<20;)(o=e.indexOf(t,i))>-1&&(n.push({start:o,end:o+t.length}),i=o+t.length,a++);return n}(e,t);n=function(e,t){if(0===e.length)return t;if(0===t.length)return e;var n=[];t.forEach((function(t){var i=!1;e.forEach((function(e){t.start<=e.start&&t.end>=e.end?(e.start=t.start,e.end=t.end,i=!0):t.start>=e.start&&t.start<e.end?(t.end>=e.end&&(e.end=t.end),i=!0):t.end>e.start&&t.end<=e.end&&(t.start<e.start&&(e.start=t.start),i=!0)})),i||n.push(t)}));var i=e.concat(n);return i=i.sort((function(e,t){return e.start<t.start?-1:1}))}(n,o),i.push(o.length>0?1:0)}})),{occurrences:n,hitCounts:i}}function Ht(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var jt=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,i);var o=Ht(s);function s(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(n=o.call(this,t)).onMouseOver=n.onMouseOver.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onMouseLeave=n.onMouseLeave.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.categorySelected=n.categorySelected.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"onMouseOver",value:function(e){this.props.canvasController.openTip({id:"paletteTip_"+this.props.category.id,type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.t,targetObj:e.currentTarget,category:this.props.category})}},{key:"onMouseLeave",value:function(){this.props.canvasController.closeTip()}},{key:"getDisplayLabel",value:function(){return!0===this.props.isPaletteOpen?this.props.category.label:!this.props.category.image&&this.props.category.label&&this.props.category.label.length>0?this.props.category.label.substr(0,3):null}},{key:"getInlineLoadingRenderCategory",value:function(){var e="";return this.props.isPaletteOpen&&(e=this.props.category.loading_text),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-flyout-category"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-flyout-category-item-loading"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_10__["default"],{description:e,iconDescription:e,onSuccess:function(){return null},status:"active",successDelay:1500})))}},{key:"getRenderCategory",value:function(){var e="palette-flyout-category-caret";this.props.isPaletteOpen||(e+=" palette-flyout-category-caret-closed");var t=null;(this.props.itemCount>0||this.props.category.empty_text)&&(t=this.props.isCategorySelected?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_8__.I,{type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a.CHEVRONARROWS.UP,className:e}):react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_8__.I,{type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a.CHEVRONARROWS.DOWN,className:e}));var n=null;this.props.category.image&&""!==this.props.category.image&&(n=this.props.category.image.endsWith(".svg")?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_inlinesvg__WEBPACK_IMPORTED_MODULE_7__["default"],{src:this.props.category.image,className:"palette-flyout-category-item-icon",draggable:"false"})):react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("img",{src:this.props.category.image,className:"palette-flyout-category-item-icon",draggable:"false"})));var i=null,o=this.getDisplayLabel();if(!0===this.props.isPaletteOpen){var a=this.props.category.image?"palette-flyout-category-text":"palette-flyout-category-text-no-image";i=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{className:a},o)}else!this.props.category.image&&this.props.category.label&&this.props.category.label.length>0&&(i=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{className:"palette-flyout-category-text-abbr"},o));return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-flyout-category","data-id":(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.k)(this.props.category,"id",""),onClick:this.categorySelected,value:this.props.category.label,onMouseOver:this.onMouseOver,onMouseLeave:this.onMouseLeave},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-flyout-category-item"},n,i),t)}},{key:"categorySelected",value:function(){this.props.categorySelectedMethod(this.props.category.id)}},{key:"render",value:function(){return this.props.category.loading_text?this.getInlineLoadingRenderCategory():this.getRenderCategory()}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function Rt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var Ft=(0,react_intl__WEBPACK_IMPORTED_MODULE_2__.injectIntl)(function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,i);var o=Rt(s);function s(){var t;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(t=o.call(this)).state={searchString:""},t.searchOnClick=t.searchOnClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(t)),t.handleSearchStringChange=t.handleSearchStringChange.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(t)),t}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"handleSearchStringChange",value:function(e){var t=this,n=e.target.value||"";this.setState({searchString:n},(function(){return t.props.handleSearchStringChange(n)}))}},{key:"searchOnClick",value:function(){this.props.isPaletteOpen||this.props.canvasController.openPalette()}},{key:"render",value:function(){var e=this.props.intl.formatMessage({id:"palette.flyout.search.placeholder",defaultMessage:Ve});return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-flyout-search-container",id:"palette-flyout-search"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_11__["default"],{key:"palette-flyout-search",className:"palette-flyout-search",placeholder:e,onChange:this.handleSearchStringChange,size:"sm",value:this.state.searchString,labelText:e,onClick:this.searchOnClick}))}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)));function Bt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var Gt=(0,react_intl__WEBPACK_IMPORTED_MODULE_2__.injectIntl)(function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(a,i);var o=Bt(a);function a(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,a),(n=o.call(this,t)).state={},n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(a,[{key:"getNoResultsDiv",value:function(){var e=this.props.intl.formatMessage({id:"palette.flyout.search.noresults",defaultMessage:Ze}),t=this.props.intl.formatMessage({id:"palette.flyout.search.adjustsearch",defaultMessage:$e});return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-no-results-title"},e),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("br",null),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-no-results-desc"},t))}},{key:"getContentListDiv",value:function(){for(var e=[],t=0;t<this.props.nodeTypeInfos.length;t++){var n="item_"+t;e.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:n},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(mt,{nodeTypeInfo:this.props.nodeTypeInfos[t],isDisplaySearchResult:!0,isShowRanking:this.props.isShowRanking,canvasController:this.props.canvasController,isPaletteOpen:this.props.isPaletteOpen,isEditingEnabled:this.props.isEditingEnabled})))}if(this.props.isNodeTypeInfosArrayTruncated){var i=this.props.intl.formatMessage({id:"palette.flyout.search.resultsrestricted",defaultMessage:qe});e.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:"restrict-item",className:"palette-flyout-restrict-item"},i))}return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{width:"100%",draggable:"false",className:"palette-scroll"},e)}},{key:"render",value:function(){return 0===this.props.nodeTypeInfos.length?this.getNoResultsDiv():this.getContentListDiv()}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)));function Ut(e,t){var n="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!n){if(Array.isArray(e)||(n=function(e,t){if(!e)return;if("string"==typeof e)return Yt(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);"Object"===n&&e.constructor&&(n=e.constructor.name);if("Map"===n||"Set"===n)return Array.from(e);if("Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return Yt(e,t)}(e))||t&&e&&"number"==typeof e.length){n&&(e=n);var i=0,o=function(){};return{s:o,n:function(){return i>=e.length?{done:!0}:{done:!1,value:e[i++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var a,r=!0,s=!1;return{s:function(){n=n.call(e)},n:function(){var e=n.next();return r=e.done,e},e:function(e){s=!0,a=e},f:function(){try{r||null==n.return||n.return()}finally{if(s)throw a}}}}function Yt(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,i=new Array(t);n<t;n++)i[n]=e[n];return i}function Xt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var Wt=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_12__.L("PaletteFlyoutContent"),Vt=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,i);var o=Xt(s);function s(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(n=o.call(this,t)).state={selectedCategoryIds:[],searchString:""},n.categories=[],n.categorySelected=n.categorySelected.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.getUniqueCategories=n.getUniqueCategories.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.setSearchString=n.setSearchString.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.handleSearchStringChange=n.handleSearchStringChange.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.setSearchStringThrottled=It(n.setSearchString,200),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"getUniqueCategories",value:function(e){var t=[];if(e){var n,i=Ut(e);try{for(i.s();!(n=i.n()).done;){var o=n.value;-1===t.indexOf(o.label)&&t.push(o)}}catch(e){i.e(e)}finally{i.f()}}return t}},{key:"getContentDivs",value:function(e){for(var t=this,n=[],i=function(i){var o=e[i],a=i===e.length-1,s=o.node_types.map((function(e){return{nodeType:e,category:o}})),l=t.isCategorySelected(o.id),c=null;l&&(c=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(bt,{key:o.label+"-nodes",show:!0,category:o,nodeTypeInfos:s,canvasController:t.props.canvasController,isPaletteOpen:t.props.isPaletteOpen,isLastCategory:a,isEditingEnabled:t.props.isEditingEnabled})),n.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:o.label+"-container"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(jt,{key:o.id,category:o,isCategorySelected:l,categorySelectedMethod:t.categorySelected,itemCount:s.length,canvasController:t.props.canvasController,isPaletteOpen:t.props.isPaletteOpen}),c))},o=0;o<e.length;o++)i(o);return n}},{key:"getFilteredContentDivs",value:function(e){Wt.logStartTimer("getFilteredNodeTypeInfos");var t=function(e,t){for(var n=[],i=t.toLowerCase().split(" ").filter((function(e){return""!==e})),o=0;o<e.length;o++)n.push.apply(n,(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_13__.b)(At(e[o],i)));return n.sort((function(e,t){return e.occurrenceInfo.ranking<=t.occurrenceInfo.ranking?1:-1}))}(this.categories,this.state.searchString);Wt.logEndTimer("getFilteredNodeTypeInfos");var n=!1;return t.length>10&&(t=t.slice(0,10),n=!0),[react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Gt,{key:"filtered-nodes",nodeTypeInfos:t,canvasController:this.props.canvasController,isPaletteOpen:this.props.isPaletteOpen,isEditingEnabled:this.props.isEditingEnabled,isNodeTypeInfosArrayTruncated:n})]}},{key:"setSearchString",value:function(){this.setState({searchString:this.ss})}},{key:"handleSearchStringChange",value:function(e){this.ss=e,this.setSearchStringThrottled()}},{key:"categorySelected",value:function(e){var t=this.isCategorySelected(e)?this.state.selectedCategoryIds.filter((function(t){return t!==e})):this.state.selectedCategoryIds.concat(e);this.setState({selectedCategoryIds:t})}},{key:"isCategorySelected",value:function(e){return this.state.selectedCategoryIds.some((function(t){return t===e}))}},{key:"render",value:function(){this.categories=this.getUniqueCategories(this.props.paletteJSON.categories);var e=this.props.isPaletteOpen&&this.state.searchString?this.getFilteredContentDivs(this.categories):this.getContentDivs(this.categories),t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-flyout-categories"},e),n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ft,{handleSearchStringChange:this.handleSearchStringChange,isPaletteOpen:this.props.isPaletteOpen,canvasController:this.props.canvasController});return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"palette-flyout-content"},n,t)}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function Zt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var $t=(0,react_intl__WEBPACK_IMPORTED_MODULE_2__.injectIntl)(function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(a,i);var o=Zt(a);function a(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,a),(n=o.call(this,t)).paletteNodes=[],n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(a,[{key:"render",value:function(){var e="palette-flyout-div";return this.props.showPalette?e+=" palette-flyout-div-open":(e+=" palette-flyout-div-closed",this.props.enableNarrowPalette&&(e+=" palette-flyout-div-narrow")),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("nav",{"aria-label":this.props.intl.formatMessage({id:"palette.flyout.label",defaultMessage:Qe}),role:"navigation"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:e},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Vt,{paletteJSON:this.props.paletteJSON,canvasController:this.props.canvasController,isPaletteOpen:this.props.showPalette,isEditingEnabled:this.props.isEditingEnabled})))}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)));function qt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var Kt=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(a,i);var o=qt(a);function a(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,a),(n=o.call(this,t)).logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_12__.L("Palette"),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(a,[{key:"render",value:function(){this.logger.log("render");var e=null;return this.props.enablePaletteLayout===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.P?e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement($t,{enableNarrowPalette:this.props.enableNarrowPalette,paletteJSON:this.props.paletteJSON,showPalette:this.props.showPalette,canvasController:this.props.canvasController,isEditingEnabled:this.props.isEditingEnabled}):this.props.enablePaletteLayout===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.u&&(e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Lt,{paletteJSON:this.props.paletteJSON,showPalette:this.props.showPalette,parentDivId:this.props.containingDivId,canvasController:this.props.canvasController,isEditingEnabled:this.props.isEditingEnabled})),e}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Jt=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{enablePaletteLayout:e.canvasconfig.enablePaletteLayout,enableNarrowPalette:e.canvasconfig.enableNarrowPalette,isEditingEnabled:e.canvasconfig.enableEditingActions,paletteJSON:e.palette.content,showPalette:void 0!==e.palette.isOpen&&e.palette.isOpen}}))(Kt);function Qt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var en=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,i);var o=Qt(s);function s(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(n=o.call(this,t)).state={},n.handleClick=n.handleClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"componentDidMount",value:function(){document.addEventListener("mousedown",this.handleClick,!0)}},{key:"componentWillUnmount",value:function(){document.removeEventListener("mousedown",this.handleClick,!0)}},{key:"handleClick",value:function(e){this.props.canvasController.closeTip()}},{key:"render",value:function(){var e=null,t=null;switch(this.props.type){case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.r:case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.t:t="right";break;default:t="bottom"}if(this.props.customContent)e=this.props.customContent;else switch(this.props.type){case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.r:e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"tip-palette-item"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"tip-palette-category"},this.props.category.label),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"tip-palette-label"},this.props.nodeTemplate.app_data.ui_data.label),this.props.nodeTemplate.app_data.ui_data.description?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"tip-palette-desc"},this.props.nodeTemplate.app_data.ui_data.description):"");break;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.t:e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"tip-palette-item"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"tip-palette-label"},this.props.category.label),this.props.category.description?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"tip-palette-desc"},this.props.category.description):"");break;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.z:var n=null;this.props.canvasController.getObjectModel().hasErrorMessage(this.props.node)?n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_8__.I,{type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.E,className:"tip-node-status error"}):this.props.canvasController.getObjectModel().hasWarningMessage(this.props.node)&&(n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_8__.I,{type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.W,className:"tip-node-status warning"}));var i=this.props.canvasController.getObjectModel().getPaletteNode(this.props.node.op),o=this.props.node.label,a=i&&i.app_data&&i.app_data.ui_data?i.app_data.ui_data.label:o;if(o!==a&&(o+=" (".concat(a,")")),!(n||o||a||this.props.node.description))return null;e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"tip-node"},n,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"tip-node-label"},o),this.props.node.description?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"tip-node-desc"},this.props.node.description):"");break;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.y:e=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(this.props.port.label)?null:react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"tip-port"},this.props.port.label);break;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.x:e=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(this.props.decoration.tooltip)?null:react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"tip-decoration"},this.props.decoration.tooltip);break;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.w:break;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.v:e=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(this.props.stateTagText)?null:react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"tip-state-tag"},this.props.stateTagText);break;default:e=null}return null!==e?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_14__["default"],{tip:e,direction:t,id:this.props.id,targetObj:this.props.targetObj,mousePos:this.props.mousePos,className:[_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.z,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.y,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.x,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.w].includes(this.props.type)?"definition-tooltip":null}):null}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),tn=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{id:e.tooltip.id,type:e.tooltip.type,targetObj:e.tooltip.targetObj,mousePos:e.tooltip.mousePos,customContent:e.tooltip.customContent,node:e.tooltip.node,port:e.tooltip.port,decoration:e.tooltip.decoration,nodeTemplate:e.tooltip.nodeTemplate,category:e.tooltip.category,stateTagText:e.tooltip.stateTagText}}))(en);function nn(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var on=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(a,i);var o=nn(a);function a(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,a),(n=o.call(this,t)).logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_12__.L("CC-ContextMenu"),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(a,[{key:"render",value:function(){this.logger.log("render");var e=null;return (0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(this.props.contextMenuDef)||(e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_context_menu_es_js__WEBPACK_IMPORTED_MODULE_15__["default"],{containingDivId:this.props.containingDivId,contextMenuDef:this.props.contextMenuDef,contextMenuActionHandler:this.props.canvasController.contextMenuActionHandler,contextMenuPos:this.props.canvasController.getContextMenuPos(),closeContextMenu:this.props.canvasController.closeContextMenu,stopPropagation:!0})),e}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),an=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{contextMenuDef:e.contextmenu.menuDef}}))(on);function rn(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var sn=(0,react_intl__WEBPACK_IMPORTED_MODULE_2__.injectIntl)(function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,i);var o=rn(s);function s(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(n=o.call(this,t)).logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_12__.L("CC-StateTag"),n.onMouseOver=n.onMouseOver.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onMouseLeave=n.onMouseLeave.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"onMouseOver",value:function(e){var t;this.props.stateTagType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.A?t=this.getLabel("canvas.stateTagTipLocked"):this.props.stateTagType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.B&&(t=this.getLabel("canvas.stateTagTipReadOnly")),this.props.canvasController.openTip({id:"stateTagTip",type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.v,stateTagType:this.props.stateTagType,stateTagText:t,targetObj:e.currentTarget})}},{key:"onMouseLeave",value:function(){this.props.canvasController.closeTip()}},{key:"getLabel",value:function(e){return this.props.intl.formatMessage({id:e,defaultMessage:_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.d[e]})}},{key:"getStateTag",value:function(e,t){return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"state-tag",onMouseOver:this.onMouseOver,onMouseLeave:this.onMouseLeave},t,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",null,e))}},{key:"render",value:function(){this.logger.log("render");var e=null;if(this.props.stateTagType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.A){var t=this.getLabel("canvas.stateTagLocked");e=this.getStateTag(t,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_17__.Locked16,null))}else if(this.props.stateTagType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.B){var n=this.getLabel("canvas.stateTagReadOnly");e=this.getStateTag(n,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_18__.EditOff16,null))}return e}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component))),ln="http://www.w3.org/1999/xhtml",cn={svg:"http://www.w3.org/2000/svg",xhtml:ln,xlink:"http://www.w3.org/1999/xlink",xml:"http://www.w3.org/XML/1998/namespace",xmlns:"http://www.w3.org/2000/xmlns/"};function un(e){var t=e+="",n=t.indexOf(":");return n>=0&&"xmlns"!==(t=e.slice(0,n))&&(e=e.slice(n+1)),cn.hasOwnProperty(t)?{space:cn[t],local:e}:e}function dn(e){return function(){var t=this.ownerDocument,n=this.namespaceURI;return n===ln&&t.documentElement.namespaceURI===ln?t.createElement(e):t.createElementNS(n,e)}}function hn(e){return function(){return this.ownerDocument.createElementNS(e.space,e.local)}}function pn(e){var t=un(e);return(t.local?hn:dn)(t)}function gn(){}function fn(e){return null==e?gn:function(){return this.querySelector(e)}}function vn(e){return null==e?[]:Array.isArray(e)?e:Array.from(e)}function yn(){return[]}function mn(e){return null==e?yn:function(){return this.querySelectorAll(e)}}function kn(e){return function(){return this.matches(e)}}function bn(e){return function(t){return t.matches(e)}}var Cn=Array.prototype.find;function Pn(){return this.firstElementChild}var wn=Array.prototype.filter;function Ln(){return Array.from(this.children)}function xn(e){return new Array(e.length)}function Nn(e,t){this.ownerDocument=e.ownerDocument,this.namespaceURI=e.namespaceURI,this._next=null,this._parent=e,this.__data__=t}function Sn(e){return function(){return e}}function Dn(e,t,n,i,o,a){for(var r,s=0,l=t.length,c=a.length;s<c;++s)(r=t[s])?(r.__data__=a[s],i[s]=r):n[s]=new Nn(e,a[s]);for(;s<l;++s)(r=t[s])&&(o[s]=r)}function Tn(e,t,n,i,o,a,r){var s,l,c,u=new Map,d=t.length,h=a.length,p=new Array(d);for(s=0;s<d;++s)(l=t[s])&&(p[s]=c=r.call(l,l.__data__,s,t)+"",u.has(c)?o[s]=l:u.set(c,l));for(s=0;s<h;++s)c=r.call(e,a[s],s,a)+"",(l=u.get(c))?(i[s]=l,l.__data__=a[s],u.delete(c)):n[s]=new Nn(e,a[s]);for(s=0;s<d;++s)(l=t[s])&&u.get(p[s])===l&&(o[s]=l)}function En(e){return e.__data__}function In(e){return"object"==typeof e&&"length"in e?e:Array.from(e)}function On(e,t){return e<t?-1:e>t?1:e>=t?0:NaN}function _n(e){return function(){this.removeAttribute(e)}}function An(e){return function(){this.removeAttributeNS(e.space,e.local)}}function zn(e,t){return function(){this.setAttribute(e,t)}}function Mn(e,t){return function(){this.setAttributeNS(e.space,e.local,t)}}function Hn(e,t){return function(){var n=t.apply(this,arguments);null==n?this.removeAttribute(e):this.setAttribute(e,n)}}function jn(e,t){return function(){var n=t.apply(this,arguments);null==n?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,n)}}function Rn(e){return e.ownerDocument&&e.ownerDocument.defaultView||e.document&&e||e.defaultView}function Fn(e){return function(){this.style.removeProperty(e)}}function Bn(e,t,n){return function(){this.style.setProperty(e,t,n)}}function Gn(e,t,n){return function(){var i=t.apply(this,arguments);null==i?this.style.removeProperty(e):this.style.setProperty(e,i,n)}}function Un(e,t){return e.style.getPropertyValue(t)||Rn(e).getComputedStyle(e,null).getPropertyValue(t)}function Yn(e){return function(){delete this[e]}}function Xn(e,t){return function(){this[e]=t}}function Wn(e,t){return function(){var n=t.apply(this,arguments);null==n?delete this[e]:this[e]=n}}function Vn(e){return e.trim().split(/^|\s+/)}function Zn(e){return e.classList||new $n(e)}function $n(e){this._node=e,this._names=Vn(e.getAttribute("class")||"")}function qn(e,t){for(var n=Zn(e),i=-1,o=t.length;++i<o;)n.add(t[i])}function Kn(e,t){for(var n=Zn(e),i=-1,o=t.length;++i<o;)n.remove(t[i])}function Jn(e){return function(){qn(this,e)}}function Qn(e){return function(){Kn(this,e)}}function ei(e,t){return function(){(t.apply(this,arguments)?qn:Kn)(this,e)}}function ti(){this.textContent=""}function ni(e){return function(){this.textContent=e}}function ii(e){return function(){var t=e.apply(this,arguments);this.textContent=null==t?"":t}}function oi(){this.innerHTML=""}function ai(e){return function(){this.innerHTML=e}}function ri(e){return function(){var t=e.apply(this,arguments);this.innerHTML=null==t?"":t}}function si(){this.nextSibling&&this.parentNode.appendChild(this)}function li(){this.previousSibling&&this.parentNode.insertBefore(this,this.parentNode.firstChild)}function ci(){return null}function ui(){var e=this.parentNode;e&&e.removeChild(this)}function di(){var e=this.cloneNode(!1),t=this.parentNode;return t?t.insertBefore(e,this.nextSibling):e}function hi(){var e=this.cloneNode(!0),t=this.parentNode;return t?t.insertBefore(e,this.nextSibling):e}function pi(e){return e.trim().split(/^|\s+/).map((function(e){var t="",n=e.indexOf(".");return n>=0&&(t=e.slice(n+1),e=e.slice(0,n)),{type:e,name:t}}))}function gi(e){return function(){var t=this.__on;if(t){for(var n,i=0,o=-1,a=t.length;i<a;++i)n=t[i],e.type&&n.type!==e.type||n.name!==e.name?t[++o]=n:this.removeEventListener(n.type,n.listener,n.options);++o?t.length=o:delete this.__on}}}function fi(e,t,n){return function(){var i,o=this.__on,a=function(e){return function(t){e.call(this,t,this.__data__)}}(t);if(o)for(var r=0,s=o.length;r<s;++r)if((i=o[r]).type===e.type&&i.name===e.name)return this.removeEventListener(i.type,i.listener,i.options),this.addEventListener(i.type,i.listener=a,i.options=n),void(i.value=t);this.addEventListener(e.type,a,n),i={type:e.type,name:e.name,value:t,listener:a,options:n},o?o.push(i):this.__on=[i]}}function vi(e,t,n){var i=Rn(e),o=i.CustomEvent;"function"==typeof o?o=new o(t,n):(o=i.document.createEvent("Event"),n?(o.initEvent(t,n.bubbles,n.cancelable),o.detail=n.detail):o.initEvent(t,!1,!1)),e.dispatchEvent(o)}function yi(e,t){return function(){return vi(this,e,t)}}function mi(e,t){return function(){return vi(this,e,t.apply(this,arguments))}}Nn.prototype={constructor:Nn,appendChild:function(e){return this._parent.insertBefore(e,this._next)},insertBefore:function(e,t){return this._parent.insertBefore(e,t)},querySelector:function(e){return this._parent.querySelector(e)},querySelectorAll:function(e){return this._parent.querySelectorAll(e)}},$n.prototype={add:function(e){this._names.indexOf(e)<0&&(this._names.push(e),this._node.setAttribute("class",this._names.join(" ")))},remove:function(e){var t=this._names.indexOf(e);t>=0&&(this._names.splice(t,1),this._node.setAttribute("class",this._names.join(" ")))},contains:function(e){return this._names.indexOf(e)>=0}};var ki=[null];function bi(e,t){this._groups=e,this._parents=t}function Ci(){return new bi([[document.documentElement]],ki)}function Pi(e){return"string"==typeof e?new bi([[document.querySelector(e)]],[document.documentElement]):new bi([[e]],ki)}bi.prototype=Ci.prototype={constructor:bi,select:function(e){"function"!=typeof e&&(e=fn(e));for(var t=this._groups,n=t.length,i=new Array(n),o=0;o<n;++o)for(var a,r,s=t[o],l=s.length,c=i[o]=new Array(l),u=0;u<l;++u)(a=s[u])&&(r=e.call(a,a.__data__,u,s))&&("__data__"in a&&(r.__data__=a.__data__),c[u]=r);return new bi(i,this._parents)},selectAll:function(e){e="function"==typeof e?function(e){return function(){return vn(e.apply(this,arguments))}}(e):mn(e);for(var t=this._groups,n=t.length,i=[],o=[],a=0;a<n;++a)for(var r,s=t[a],l=s.length,c=0;c<l;++c)(r=s[c])&&(i.push(e.call(r,r.__data__,c,s)),o.push(r));return new bi(i,o)},selectChild:function(e){return this.select(null==e?Pn:function(e){return function(){return Cn.call(this.children,e)}}("function"==typeof e?e:bn(e)))},selectChildren:function(e){return this.selectAll(null==e?Ln:function(e){return function(){return wn.call(this.children,e)}}("function"==typeof e?e:bn(e)))},filter:function(e){"function"!=typeof e&&(e=kn(e));for(var t=this._groups,n=t.length,i=new Array(n),o=0;o<n;++o)for(var a,r=t[o],s=r.length,l=i[o]=[],c=0;c<s;++c)(a=r[c])&&e.call(a,a.__data__,c,r)&&l.push(a);return new bi(i,this._parents)},data:function(e,t){if(!arguments.length)return Array.from(this,En);var n=t?Tn:Dn,i=this._parents,o=this._groups;"function"!=typeof e&&(e=Sn(e));for(var a=o.length,r=new Array(a),s=new Array(a),l=new Array(a),c=0;c<a;++c){var u=i[c],d=o[c],h=d.length,p=In(e.call(u,u&&u.__data__,c,i)),g=p.length,f=s[c]=new Array(g),v=r[c]=new Array(g),y=l[c]=new Array(h);n(u,d,f,v,y,p,t);for(var m,k,b=0,C=0;b<g;++b)if(m=f[b]){for(b>=C&&(C=b+1);!(k=v[C])&&++C<g;);m._next=k||null}}return(r=new bi(r,i))._enter=s,r._exit=l,r},enter:function(){return new bi(this._enter||this._groups.map(xn),this._parents)},exit:function(){return new bi(this._exit||this._groups.map(xn),this._parents)},join:function(e,t,n){var i=this.enter(),o=this,a=this.exit();return"function"==typeof e?(i=e(i))&&(i=i.selection()):i=i.append(e+""),null!=t&&(o=t(o))&&(o=o.selection()),null==n?a.remove():n(a),i&&o?i.merge(o).order():o},merge:function(e){for(var t=e.selection?e.selection():e,n=this._groups,i=t._groups,o=n.length,a=i.length,r=Math.min(o,a),s=new Array(o),l=0;l<r;++l)for(var c,u=n[l],d=i[l],h=u.length,p=s[l]=new Array(h),g=0;g<h;++g)(c=u[g]||d[g])&&(p[g]=c);for(;l<o;++l)s[l]=n[l];return new bi(s,this._parents)},selection:function(){return this},order:function(){for(var e=this._groups,t=-1,n=e.length;++t<n;)for(var i,o=e[t],a=o.length-1,r=o[a];--a>=0;)(i=o[a])&&(r&&4^i.compareDocumentPosition(r)&&r.parentNode.insertBefore(i,r),r=i);return this},sort:function(e){function t(t,n){return t&&n?e(t.__data__,n.__data__):!t-!n}e||(e=On);for(var n=this._groups,i=n.length,o=new Array(i),a=0;a<i;++a){for(var r,s=n[a],l=s.length,c=o[a]=new Array(l),u=0;u<l;++u)(r=s[u])&&(c[u]=r);c.sort(t)}return new bi(o,this._parents).order()},call:function(){var e=arguments[0];return arguments[0]=this,e.apply(null,arguments),this},nodes:function(){return Array.from(this)},node:function(){for(var e=this._groups,t=0,n=e.length;t<n;++t)for(var i=e[t],o=0,a=i.length;o<a;++o){var r=i[o];if(r)return r}return null},size:function(){let e=0;for(const t of this)++e;return e},empty:function(){return!this.node()},each:function(e){for(var t=this._groups,n=0,i=t.length;n<i;++n)for(var o,a=t[n],r=0,s=a.length;r<s;++r)(o=a[r])&&e.call(o,o.__data__,r,a);return this},attr:function(e,t){var n=un(e);if(arguments.length<2){var i=this.node();return n.local?i.getAttributeNS(n.space,n.local):i.getAttribute(n)}return this.each((null==t?n.local?An:_n:"function"==typeof t?n.local?jn:Hn:n.local?Mn:zn)(n,t))},style:function(e,t,n){return arguments.length>1?this.each((null==t?Fn:"function"==typeof t?Gn:Bn)(e,t,null==n?"":n)):Un(this.node(),e)},property:function(e,t){return arguments.length>1?this.each((null==t?Yn:"function"==typeof t?Wn:Xn)(e,t)):this.node()[e]},classed:function(e,t){var n=Vn(e+"");if(arguments.length<2){for(var i=Zn(this.node()),o=-1,a=n.length;++o<a;)if(!i.contains(n[o]))return!1;return!0}return this.each(("function"==typeof t?ei:t?Jn:Qn)(n,t))},text:function(e){return arguments.length?this.each(null==e?ti:("function"==typeof e?ii:ni)(e)):this.node().textContent},html:function(e){return arguments.length?this.each(null==e?oi:("function"==typeof e?ri:ai)(e)):this.node().innerHTML},raise:function(){return this.each(si)},lower:function(){return this.each(li)},append:function(e){var t="function"==typeof e?e:pn(e);return this.select((function(){return this.appendChild(t.apply(this,arguments))}))},insert:function(e,t){var n="function"==typeof e?e:pn(e),i=null==t?ci:"function"==typeof t?t:fn(t);return this.select((function(){return this.insertBefore(n.apply(this,arguments),i.apply(this,arguments)||null)}))},remove:function(){return this.each(ui)},clone:function(e){return this.select(e?hi:di)},datum:function(e){return arguments.length?this.property("__data__",e):this.node().__data__},on:function(e,t,n){var i,o,a=pi(e+""),r=a.length;if(!(arguments.length<2)){for(s=t?fi:gi,i=0;i<r;++i)this.each(s(a[i],t,n));return this}var s=this.node().__on;if(s)for(var l,c=0,u=s.length;c<u;++c)for(i=0,l=s[c];i<r;++i)if((o=a[i]).type===l.type&&o.name===l.name)return l.value},dispatch:function(e,t){return this.each(("function"==typeof t?mi:yi)(e,t))},[Symbol.iterator]:function*(){for(var e=this._groups,t=0,n=e.length;t<n;++t)for(var i,o=e[t],a=0,r=o.length;a<r;++a)(i=o[a])&&(yield i)}};var wi=0;function Li(){return new xi}function xi(){this._="@"+(++wi).toString(36)}function Ni(e){let t;for(;t=e.sourceEvent;)e=t;return e}function Si(e,t){if(e=Ni(e),void 0===t&&(t=e.currentTarget),t){var n=t.ownerSVGElement||t;if(n.createSVGPoint){var i=n.createSVGPoint();return i.x=e.clientX,i.y=e.clientY,[(i=i.matrixTransform(t.getScreenCTM().inverse())).x,i.y]}if(t.getBoundingClientRect){var o=t.getBoundingClientRect();return[e.clientX-o.left-t.clientLeft,e.clientY-o.top-t.clientTop]}}return[e.pageX,e.pageY]}xi.prototype=Li.prototype={constructor:xi,get:function(e){for(var t=this._;!(t in e);)if(!(e=e.parentNode))return;return e[t]},set:function(e,t){return e[this._]=t},remove:function(e){return this._ in e&&delete e[this._]},toString:function(){return this._}};var Di=Object.freeze({__proto__:null,create:function(e){return Pi(pn(e).call(document.documentElement))},creator:pn,local:Li,matcher:kn,namespace:un,namespaces:cn,pointer:Si,pointers:function(e,t){return e.target&&(e=Ni(e),void 0===t&&(t=e.currentTarget),e=e.touches||[e]),Array.from(e,(e=>Si(e,t)))},select:Pi,selectAll:function(e){return"string"==typeof e?new bi([document.querySelectorAll(e)],[document.documentElement]):new bi([vn(e)],ki)},selection:Ci,selector:fn,selectorAll:mn,style:Un,window:Rn});var Ti=function(e){return function(t){return null==e?void 0:e[t]}},Ei=Ti({"&amp;":"&","&lt;":"<","&gt;":">","&quot;":'"',"&#39;":"'"}),Ii=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.a3,Oi=Ei,_i=/&(?:amp|lt|gt|quot|#39);/g,Ai=RegExp(_i.source);var zi=function(e){return(e=Ii(e))&&Ai.test(e)?e.replace(_i,Oi):e},Mi=_baseForOwn_d38b560e_js__WEBPACK_IMPORTED_MODULE_19__._,Hi=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__._;var ji=function(e,t){return e&&Mi(e,Hi(t))},Ri=Ti({"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;"}),Fi=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.a3,Bi=/[&<>"']/g,Gi=RegExp(Bi.source);var Ui=function(e){return(e=Fi(e))&&Gi.test(e)?e.replace(Bi,Ri):e},Yi={value:()=>{}};function Xi(){for(var e,t=0,n=arguments.length,i={};t<n;++t){if(!(e=arguments[t]+"")||e in i||/[\s.]/.test(e))throw new Error("illegal type: "+e);i[e]=[]}return new Wi(i)}function Wi(e){this._=e}function Vi(e,t){return e.trim().split(/^|\s+/).map((function(e){var n="",i=e.indexOf(".");if(i>=0&&(n=e.slice(i+1),e=e.slice(0,i)),e&&!t.hasOwnProperty(e))throw new Error("unknown type: "+e);return{type:e,name:n}}))}function Zi(e,t){for(var n,i=0,o=e.length;i<o;++i)if((n=e[i]).name===t)return n.value}function $i(e,t,n){for(var i=0,o=e.length;i<o;++i)if(e[i].name===t){e[i]=Yi,e=e.slice(0,i).concat(e.slice(i+1));break}return null!=n&&e.push({name:t,value:n}),e}Wi.prototype=Xi.prototype={constructor:Wi,on:function(e,t){var n,i=this._,o=Vi(e+"",i),a=-1,r=o.length;if(!(arguments.length<2)){if(null!=t&&"function"!=typeof t)throw new Error("invalid callback: "+t);for(;++a<r;)if(n=(e=o[a]).type)i[n]=$i(i[n],e.name,t);else if(null==t)for(n in i)i[n]=$i(i[n],e.name,null);return this}for(;++a<r;)if((n=(e=o[a]).type)&&(n=Zi(i[n],e.name)))return n},copy:function(){var e={},t=this._;for(var n in t)e[n]=t[n].slice();return new Wi(e)},call:function(e,t){if((n=arguments.length-2)>0)for(var n,i,o=new Array(n),a=0;a<n;++a)o[a]=arguments[a+2];if(!this._.hasOwnProperty(e))throw new Error("unknown type: "+e);for(a=0,n=(i=this._[e]).length;a<n;++a)i[a].value.apply(t,o)},apply:function(e,t,n){if(!this._.hasOwnProperty(e))throw new Error("unknown type: "+e);for(var i=this._[e],o=0,a=i.length;o<a;++o)i[o].value.apply(t,n)}};const qi={passive:!1},Ki={capture:!0,passive:!1};function Ji(e){e.stopImmediatePropagation()}function Qi(e){e.preventDefault(),e.stopImmediatePropagation()}function eo(e){var t=e.document.documentElement,n=Pi(e).on("dragstart.drag",Qi,Ki);"onselectstart"in t?n.on("selectstart.drag",Qi,Ki):(t.__noselect=t.style.MozUserSelect,t.style.MozUserSelect="none")}function to(e,t){var n=e.document.documentElement,i=Pi(e).on("dragstart.drag",null);t&&(i.on("click.drag",Qi,Ki),setTimeout((function(){i.on("click.drag",null)}),0)),"onselectstart"in n?i.on("selectstart.drag",null):(n.style.MozUserSelect=n.__noselect,delete n.__noselect)}var no=e=>()=>e;function io(e,{sourceEvent:t,subject:n,target:i,identifier:o,active:a,x:r,y:s,dx:l,dy:c,dispatch:u}){Object.defineProperties(this,{type:{value:e,enumerable:!0,configurable:!0},sourceEvent:{value:t,enumerable:!0,configurable:!0},subject:{value:n,enumerable:!0,configurable:!0},target:{value:i,enumerable:!0,configurable:!0},identifier:{value:o,enumerable:!0,configurable:!0},active:{value:a,enumerable:!0,configurable:!0},x:{value:r,enumerable:!0,configurable:!0},y:{value:s,enumerable:!0,configurable:!0},dx:{value:l,enumerable:!0,configurable:!0},dy:{value:c,enumerable:!0,configurable:!0},_:{value:u}})}function oo(e){return!e.ctrlKey&&!e.button}function ao(){return this.parentNode}function ro(e,t){return null==t?{x:e.x,y:e.y}:t}function so(){return navigator.maxTouchPoints||"ontouchstart"in this}io.prototype.on=function(){var e=this._.on.apply(this._,arguments);return e===this._?this:e};var lo=Object.freeze({__proto__:null,drag:function(){var e,t,n,i,o=oo,a=ao,r=ro,s=so,l={},c=Xi("start","drag","end"),u=0,d=0;function h(e){e.on("mousedown.drag",p).filter(s).on("touchstart.drag",v).on("touchmove.drag",y,qi).on("touchend.drag touchcancel.drag",m).style("touch-action","none").style("-webkit-tap-highlight-color","rgba(0,0,0,0)")}function p(r,s){if(!i&&o.call(this,r,s)){var l=k(this,a.call(this,r,s),r,s,"mouse");l&&(Pi(r.view).on("mousemove.drag",g,Ki).on("mouseup.drag",f,Ki),eo(r.view),Ji(r),n=!1,e=r.clientX,t=r.clientY,l("start",r))}}function g(i){if(Qi(i),!n){var o=i.clientX-e,a=i.clientY-t;n=o*o+a*a>d}l.mouse("drag",i)}function f(e){Pi(e.view).on("mousemove.drag mouseup.drag",null),to(e.view,n),Qi(e),l.mouse("end",e)}function v(e,t){if(o.call(this,e,t)){var n,i,r=e.changedTouches,s=a.call(this,e,t),l=r.length;for(n=0;n<l;++n)(i=k(this,s,e,t,r[n].identifier,r[n]))&&(Ji(e),i("start",e,r[n]))}}function y(e){var t,n,i=e.changedTouches,o=i.length;for(t=0;t<o;++t)(n=l[i[t].identifier])&&(Qi(e),n("drag",e,i[t]))}function m(e){var t,n,o=e.changedTouches,a=o.length;for(i&&clearTimeout(i),i=setTimeout((function(){i=null}),500),t=0;t<a;++t)(n=l[o[t].identifier])&&(Ji(e),n("end",e,o[t]))}function k(e,t,n,i,o,a){var s,d,p,g=c.copy(),f=Si(a||n,t);if(null!=(p=r.call(e,new io("beforestart",{sourceEvent:n,target:h,identifier:o,active:u,x:f[0],y:f[1],dx:0,dy:0,dispatch:g}),i)))return s=p.x-f[0]||0,d=p.y-f[1]||0,function n(a,r,c){var v,y=f;switch(a){case"start":l[o]=n,v=u++;break;case"end":delete l[o],--u;case"drag":f=Si(c||r,t),v=u}g.call(a,e,new io(a,{sourceEvent:r,subject:p,target:h,identifier:o,active:v,x:f[0]+s,y:f[1]+d,dx:f[0]-y[0],dy:f[1]-y[1],dispatch:g}),i)}}return h.filter=function(e){return arguments.length?(o="function"==typeof e?e:no(!!e),h):o},h.container=function(e){return arguments.length?(a="function"==typeof e?e:no(e),h):a},h.subject=function(e){return arguments.length?(r="function"==typeof e?e:no(e),h):r},h.touchable=function(e){return arguments.length?(s="function"==typeof e?e:no(!!e),h):s},h.on=function(){var e=c.on.apply(c,arguments);return e===c?h:e},h.clickDistance=function(e){return arguments.length?(d=(e=+e)*e,h):Math.sqrt(d)},h},dragDisable:eo,dragEnable:to});function co(e){return((e*=2)<=1?e*e:--e*(2-e)+1)/2}function uo(e){return((e*=2)<=1?e*e*e:(e-=2)*e*e+2)/2}var ho=function e(t){function n(e){return Math.pow(e,t)}return t=+t,n.exponent=e,n}(3),po=function e(t){function n(e){return 1-Math.pow(1-e,t)}return t=+t,n.exponent=e,n}(3),go=function e(t){function n(e){return((e*=2)<=1?Math.pow(e,t):2-Math.pow(2-e,t))/2}return t=+t,n.exponent=e,n}(3),fo=Math.PI,vo=fo/2;function yo(e){return(1-Math.cos(fo*e))/2}function mo(e){return 1.0009775171065494*(Math.pow(2,-10*e)-.0009765625)}function ko(e){return((e*=2)<=1?mo(1-e):2-mo(e-1))/2}function bo(e){return((e*=2)<=1?1-Math.sqrt(1-e*e):Math.sqrt(1-(e-=2)*e)+1)/2}var Co=4/11,Po=7.5625;function wo(e){return(e=+e)<Co?Po*e*e:e<.7272727272727273?Po*(e-=.5454545454545454)*e+.75:e<.9090909090909091?Po*(e-=.8181818181818182)*e+.9375:Po*(e-=.9545454545454546)*e+.984375}var Lo=function e(t){function n(e){return(e=+e)*e*(t*(e-1)+e)}return t=+t,n.overshoot=e,n}(1.70158),xo=function e(t){function n(e){return--e*e*((e+1)*t+e)+1}return t=+t,n.overshoot=e,n}(1.70158),No=function e(t){function n(e){return((e*=2)<1?e*e*((t+1)*e-t):(e-=2)*e*((t+1)*e+t)+2)/2}return t=+t,n.overshoot=e,n}(1.70158),So=2*Math.PI,Do=function e(t,n){var i=Math.asin(1/(t=Math.max(1,t)))*(n/=So);function o(e){return t*mo(- --e)*Math.sin((i-e)/n)}return o.amplitude=function(t){return e(t,n*So)},o.period=function(n){return e(t,n)},o}(1,.3),To=function e(t,n){var i=Math.asin(1/(t=Math.max(1,t)))*(n/=So);function o(e){return 1-t*mo(e=+e)*Math.sin((e+i)/n)}return o.amplitude=function(t){return e(t,n*So)},o.period=function(n){return e(t,n)},o}(1,.3),Eo=function e(t,n){var i=Math.asin(1/(t=Math.max(1,t)))*(n/=So);function o(e){return((e=2*e-1)<0?t*mo(-e)*Math.sin((i-e)/n):2-t*mo(e)*Math.sin((i+e)/n))/2}return o.amplitude=function(t){return e(t,n*So)},o.period=function(n){return e(t,n)},o}(1,.3),Io=Object.freeze({__proto__:null,easeLinear:e=>+e,easeQuad:co,easeQuadIn:function(e){return e*e},easeQuadOut:function(e){return e*(2-e)},easeQuadInOut:co,easeCubic:uo,easeCubicIn:function(e){return e*e*e},easeCubicOut:function(e){return--e*e*e+1},easeCubicInOut:uo,easePoly:go,easePolyIn:ho,easePolyOut:po,easePolyInOut:go,easeSin:yo,easeSinIn:function(e){return 1==+e?1:1-Math.cos(e*vo)},easeSinOut:function(e){return Math.sin(e*vo)},easeSinInOut:yo,easeExp:ko,easeExpIn:function(e){return mo(1-+e)},easeExpOut:function(e){return 1-mo(e)},easeExpInOut:ko,easeCircle:bo,easeCircleIn:function(e){return 1-Math.sqrt(1-e*e)},easeCircleOut:function(e){return Math.sqrt(1- --e*e)},easeCircleInOut:bo,easeBounce:wo,easeBounceIn:function(e){return 1-wo(1-e)},easeBounceOut:wo,easeBounceInOut:function(e){return((e*=2)<=1?1-wo(1-e):wo(e-1)+1)/2},easeBack:No,easeBackIn:Lo,easeBackOut:xo,easeBackInOut:No,easeElastic:To,easeElasticIn:Do,easeElasticOut:To,easeElasticInOut:Eo});function Oo(e){if(!e.ok)throw new Error(e.status+" "+e.statusText);return e.blob()}function _o(e){if(!e.ok)throw new Error(e.status+" "+e.statusText);return e.arrayBuffer()}var Ao={},zo={};function Mo(e){return new Function("d","return {"+e.map((function(e,t){return JSON.stringify(e)+": d["+t+'] || ""'})).join(",")+"}")}function Ho(e){var t=Object.create(null),n=[];return e.forEach((function(e){for(var i in e)i in t||n.push(t[i]=i)})),n}function jo(e,t){var n=e+"",i=n.length;return i<t?new Array(t-i+1).join(0)+n:n}function Ro(e){var t,n=e.getUTCHours(),i=e.getUTCMinutes(),o=e.getUTCSeconds(),a=e.getUTCMilliseconds();return isNaN(e)?"Invalid Date":((t=e.getUTCFullYear())<0?"-"+jo(-t,6):t>9999?"+"+jo(t,6):jo(t,4))+"-"+jo(e.getUTCMonth()+1,2)+"-"+jo(e.getUTCDate(),2)+(a?"T"+jo(n,2)+":"+jo(i,2)+":"+jo(o,2)+"."+jo(a,3)+"Z":o?"T"+jo(n,2)+":"+jo(i,2)+":"+jo(o,2)+"Z":i||n?"T"+jo(n,2)+":"+jo(i,2)+"Z":"")}function Fo(e){var t=new RegExp('["'+e+"\n\r]"),n=e.charCodeAt(0);function i(e,t){var i,o=[],a=e.length,r=0,s=0,l=a<=0,c=!1;function u(){if(l)return zo;if(c)return c=!1,Ao;var t,i,o=r;if(34===e.charCodeAt(o)){for(;r++<a&&34!==e.charCodeAt(r)||34===e.charCodeAt(++r););return(t=r)>=a?l=!0:10===(i=e.charCodeAt(r++))?c=!0:13===i&&(c=!0,10===e.charCodeAt(r)&&++r),e.slice(o+1,t-1).replace(/""/g,'"')}for(;r<a;){if(10===(i=e.charCodeAt(t=r++)))c=!0;else if(13===i)c=!0,10===e.charCodeAt(r)&&++r;else if(i!==n)continue;return e.slice(o,t)}return l=!0,e.slice(o,a)}for(10===e.charCodeAt(a-1)&&--a,13===e.charCodeAt(a-1)&&--a;(i=u())!==zo;){for(var d=[];i!==Ao&&i!==zo;)d.push(i),i=u();t&&null==(d=t(d,s++))||o.push(d)}return o}function o(t,n){return t.map((function(t){return n.map((function(e){return r(t[e])})).join(e)}))}function a(t){return t.map(r).join(e)}function r(e){return null==e?"":e instanceof Date?Ro(e):t.test(e+="")?'"'+e.replace(/"/g,'""')+'"':e}return{parse:function(e,t){var n,o,a=i(e,(function(e,i){if(n)return n(e,i-1);o=e,n=t?function(e,t){var n=Mo(e);return function(i,o){return t(n(i),o,e)}}(e,t):Mo(e)}));return a.columns=o||[],a},parseRows:i,format:function(t,n){return null==n&&(n=Ho(t)),[n.map(r).join(e)].concat(o(t,n)).join("\n")},formatBody:function(e,t){return null==t&&(t=Ho(e)),o(e,t).join("\n")},formatRows:function(e){return e.map(a).join("\n")},formatRow:a,formatValue:r}}var Bo=Fo(",").parse,Go=Fo("\t").parse;function Uo(e){if(!e.ok)throw new Error(e.status+" "+e.statusText);return e.text()}function Yo(e,t){return fetch(e,t).then(Uo)}function Xo(e){return function(t,n,i){return 2===arguments.length&&"function"==typeof n&&(i=n,n=void 0),Yo(t,n).then((function(t){return e(t,i)}))}}var Wo=Xo(Bo),Vo=Xo(Go);function Zo(e){if(!e.ok)throw new Error(e.status+" "+e.statusText);if(204!==e.status&&205!==e.status)return e.json()}function $o(e){return(t,n)=>Yo(t,n).then((t=>(new DOMParser).parseFromString(t,e)))}var qo=$o("application/xml"),Ko=$o("text/html"),Jo=$o("image/svg+xml"),Qo=Object.freeze({__proto__:null,blob:function(e,t){return fetch(e,t).then(Oo)},buffer:function(e,t){return fetch(e,t).then(_o)},dsv:function(e,t,n,i){3===arguments.length&&"function"==typeof n&&(i=n,n=void 0);var o=Fo(e);return Yo(t,n).then((function(e){return o.parse(e,i)}))},csv:Wo,tsv:Vo,image:function(e,t){return new Promise((function(n,i){var o=new Image;for(var a in t)o[a]=t[a];o.onerror=i,o.onload=function(){n(o)},o.src=e}))},json:function(e,t){return fetch(e,t).then(Zo)},text:Yo,xml:qo,html:Ko,svg:Jo});function ea(e,t,n){e.prototype=t.prototype=n,n.constructor=e}function ta(e,t){var n=Object.create(e.prototype);for(var i in t)n[i]=t[i];return n}function na(){}var ia=1/.7,oa="\\s*([+-]?\\d+)\\s*",aa="\\s*([+-]?(?:\\d*\\.)?\\d+(?:[eE][+-]?\\d+)?)\\s*",ra="\\s*([+-]?(?:\\d*\\.)?\\d+(?:[eE][+-]?\\d+)?)%\\s*",sa=/^#([0-9a-f]{3,8})$/,la=new RegExp(`^rgb\\(${oa},${oa},${oa}\\)$`),ca=new RegExp(`^rgb\\(${ra},${ra},${ra}\\)$`),ua=new RegExp(`^rgba\\(${oa},${oa},${oa},${aa}\\)$`),da=new RegExp(`^rgba\\(${ra},${ra},${ra},${aa}\\)$`),ha=new RegExp(`^hsl\\(${aa},${ra},${ra}\\)$`),pa=new RegExp(`^hsla\\(${aa},${ra},${ra},${aa}\\)$`),ga={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function fa(){return this.rgb().formatHex()}function va(){return this.rgb().formatRgb()}function ya(e){var t,n;return e=(e+"").trim().toLowerCase(),(t=sa.exec(e))?(n=t[1].length,t=parseInt(t[1],16),6===n?ma(t):3===n?new Pa(t>>8&15|t>>4&240,t>>4&15|240&t,(15&t)<<4|15&t,1):8===n?ka(t>>24&255,t>>16&255,t>>8&255,(255&t)/255):4===n?ka(t>>12&15|t>>8&240,t>>8&15|t>>4&240,t>>4&15|240&t,((15&t)<<4|15&t)/255):null):(t=la.exec(e))?new Pa(t[1],t[2],t[3],1):(t=ca.exec(e))?new Pa(255*t[1]/100,255*t[2]/100,255*t[3]/100,1):(t=ua.exec(e))?ka(t[1],t[2],t[3],t[4]):(t=da.exec(e))?ka(255*t[1]/100,255*t[2]/100,255*t[3]/100,t[4]):(t=ha.exec(e))?Da(t[1],t[2]/100,t[3]/100,1):(t=pa.exec(e))?Da(t[1],t[2]/100,t[3]/100,t[4]):ga.hasOwnProperty(e)?ma(ga[e]):"transparent"===e?new Pa(NaN,NaN,NaN,0):null}function ma(e){return new Pa(e>>16&255,e>>8&255,255&e,1)}function ka(e,t,n,i){return i<=0&&(e=t=n=NaN),new Pa(e,t,n,i)}function ba(e){return e instanceof na||(e=ya(e)),e?new Pa((e=e.rgb()).r,e.g,e.b,e.opacity):new Pa}function Ca(e,t,n,i){return 1===arguments.length?ba(e):new Pa(e,t,n,null==i?1:i)}function Pa(e,t,n,i){this.r=+e,this.g=+t,this.b=+n,this.opacity=+i}function wa(){return`#${Sa(this.r)}${Sa(this.g)}${Sa(this.b)}`}function La(){const e=xa(this.opacity);return`${1===e?"rgb(":"rgba("}${Na(this.r)}, ${Na(this.g)}, ${Na(this.b)}${1===e?")":`, ${e})`}`}function xa(e){return isNaN(e)?1:Math.max(0,Math.min(1,e))}function Na(e){return Math.max(0,Math.min(255,Math.round(e)||0))}function Sa(e){return((e=Na(e))<16?"0":"")+e.toString(16)}function Da(e,t,n,i){return i<=0?e=t=n=NaN:n<=0||n>=1?e=t=NaN:t<=0&&(e=NaN),new Ea(e,t,n,i)}function Ta(e){if(e instanceof Ea)return new Ea(e.h,e.s,e.l,e.opacity);if(e instanceof na||(e=ya(e)),!e)return new Ea;if(e instanceof Ea)return e;var t=(e=e.rgb()).r/255,n=e.g/255,i=e.b/255,o=Math.min(t,n,i),a=Math.max(t,n,i),r=NaN,s=a-o,l=(a+o)/2;return s?(r=t===a?(n-i)/s+6*(n<i):n===a?(i-t)/s+2:(t-n)/s+4,s/=l<.5?a+o:2-a-o,r*=60):s=l>0&&l<1?0:r,new Ea(r,s,l,e.opacity)}function Ea(e,t,n,i){this.h=+e,this.s=+t,this.l=+n,this.opacity=+i}function Ia(e){return(e=(e||0)%360)<0?e+360:e}function Oa(e){return Math.max(0,Math.min(1,e||0))}function _a(e,t,n){return 255*(e<60?t+(n-t)*e/60:e<180?n:e<240?t+(n-t)*(240-e)/60:t)}ea(na,ya,{copy(e){return Object.assign(new this.constructor,this,e)},displayable(){return this.rgb().displayable()},hex:fa,formatHex:fa,formatHex8:function(){return this.rgb().formatHex8()},formatHsl:function(){return Ta(this).formatHsl()},formatRgb:va,toString:va}),ea(Pa,Ca,ta(na,{brighter(e){return e=null==e?ia:Math.pow(ia,e),new Pa(this.r*e,this.g*e,this.b*e,this.opacity)},darker(e){return e=null==e?.7:Math.pow(.7,e),new Pa(this.r*e,this.g*e,this.b*e,this.opacity)},rgb(){return this},clamp(){return new Pa(Na(this.r),Na(this.g),Na(this.b),xa(this.opacity))},displayable(){return-.5<=this.r&&this.r<255.5&&-.5<=this.g&&this.g<255.5&&-.5<=this.b&&this.b<255.5&&0<=this.opacity&&this.opacity<=1},hex:wa,formatHex:wa,formatHex8:function(){return`#${Sa(this.r)}${Sa(this.g)}${Sa(this.b)}${Sa(255*(isNaN(this.opacity)?1:this.opacity))}`},formatRgb:La,toString:La})),ea(Ea,(function(e,t,n,i){return 1===arguments.length?Ta(e):new Ea(e,t,n,null==i?1:i)}),ta(na,{brighter(e){return e=null==e?ia:Math.pow(ia,e),new Ea(this.h,this.s,this.l*e,this.opacity)},darker(e){return e=null==e?.7:Math.pow(.7,e),new Ea(this.h,this.s,this.l*e,this.opacity)},rgb(){var e=this.h%360+360*(this.h<0),t=isNaN(e)||isNaN(this.s)?0:this.s,n=this.l,i=n+(n<.5?n:1-n)*t,o=2*n-i;return new Pa(_a(e>=240?e-240:e+120,o,i),_a(e,o,i),_a(e<120?e+240:e-120,o,i),this.opacity)},clamp(){return new Ea(Ia(this.h),Oa(this.s),Oa(this.l),xa(this.opacity))},displayable(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1},formatHsl(){const e=xa(this.opacity);return`${1===e?"hsl(":"hsla("}${Ia(this.h)}, ${100*Oa(this.s)}%, ${100*Oa(this.l)}%${1===e?")":`, ${e})`}`}}));var Aa=e=>()=>e;function za(e){return 1==(e=+e)?Ma:function(t,n){return n-t?function(e,t,n){return e=Math.pow(e,n),t=Math.pow(t,n)-e,n=1/n,function(i){return Math.pow(e+i*t,n)}}(t,n,e):Aa(isNaN(t)?n:t)}}function Ma(e,t){var n=t-e;return n?function(e,t){return function(n){return e+n*t}}(e,n):Aa(isNaN(e)?t:e)}var Ha=function e(t){var n=za(t);function i(e,t){var i=n((e=Ca(e)).r,(t=Ca(t)).r),o=n(e.g,t.g),a=n(e.b,t.b),r=Ma(e.opacity,t.opacity);return function(t){return e.r=i(t),e.g=o(t),e.b=a(t),e.opacity=r(t),e+""}}return i.gamma=e,i}(1);function ja(e,t){return e=+e,t=+t,function(n){return e*(1-n)+t*n}}var Ra=/[-+]?(?:\d+\.?\d*|\.?\d+)(?:[eE][-+]?\d+)?/g,Fa=new RegExp(Ra.source,"g");function Ba(e,t){var n,i,o,a=Ra.lastIndex=Fa.lastIndex=0,r=-1,s=[],l=[];for(e+="",t+="";(n=Ra.exec(e))&&(i=Fa.exec(t));)(o=i.index)>a&&(o=t.slice(a,o),s[r]?s[r]+=o:s[++r]=o),(n=n[0])===(i=i[0])?s[r]?s[r]+=i:s[++r]=i:(s[++r]=null,l.push({i:r,x:ja(n,i)})),a=Fa.lastIndex;return a<t.length&&(o=t.slice(a),s[r]?s[r]+=o:s[++r]=o),s.length<2?l[0]?function(e){return function(t){return e(t)+""}}(l[0].x):function(e){return function(){return e}}(t):(t=l.length,function(e){for(var n,i=0;i<t;++i)s[(n=l[i]).i]=n.x(e);return s.join("")})}var Ga,Ua=180/Math.PI,Ya={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function Xa(e,t,n,i,o,a){var r,s,l;return(r=Math.sqrt(e*e+t*t))&&(e/=r,t/=r),(l=e*n+t*i)&&(n-=e*l,i-=t*l),(s=Math.sqrt(n*n+i*i))&&(n/=s,i/=s,l/=s),e*i<t*n&&(e=-e,t=-t,l=-l,r=-r),{translateX:o,translateY:a,rotate:Math.atan2(t,e)*Ua,skewX:Math.atan(l)*Ua,scaleX:r,scaleY:s}}function Wa(e,t,n,i){function o(e){return e.length?e.pop()+" ":""}return function(a,r){var s=[],l=[];return a=e(a),r=e(r),function(e,i,o,a,r,s){if(e!==o||i!==a){var l=r.push("translate(",null,t,null,n);s.push({i:l-4,x:ja(e,o)},{i:l-2,x:ja(i,a)})}else(o||a)&&r.push("translate("+o+t+a+n)}(a.translateX,a.translateY,r.translateX,r.translateY,s,l),function(e,t,n,a){e!==t?(e-t>180?t+=360:t-e>180&&(e+=360),a.push({i:n.push(o(n)+"rotate(",null,i)-2,x:ja(e,t)})):t&&n.push(o(n)+"rotate("+t+i)}(a.rotate,r.rotate,s,l),function(e,t,n,a){e!==t?a.push({i:n.push(o(n)+"skewX(",null,i)-2,x:ja(e,t)}):t&&n.push(o(n)+"skewX("+t+i)}(a.skewX,r.skewX,s,l),function(e,t,n,i,a,r){if(e!==n||t!==i){var s=a.push(o(a)+"scale(",null,",",null,")");r.push({i:s-4,x:ja(e,n)},{i:s-2,x:ja(t,i)})}else 1===n&&1===i||a.push(o(a)+"scale("+n+","+i+")")}(a.scaleX,a.scaleY,r.scaleX,r.scaleY,s,l),a=r=null,function(e){for(var t,n=-1,i=l.length;++n<i;)s[(t=l[n]).i]=t.x(e);return s.join("")}}}var Va=Wa((function(e){const t=new("function"==typeof DOMMatrix?DOMMatrix:WebKitCSSMatrix)(e+"");return t.isIdentity?Ya:Xa(t.a,t.b,t.c,t.d,t.e,t.f)}),"px, ","px)","deg)"),Za=Wa((function(e){return null==e?Ya:(Ga||(Ga=document.createElementNS("http://www.w3.org/2000/svg","g")),Ga.setAttribute("transform",e),(e=Ga.transform.baseVal.consolidate())?Xa((e=e.matrix).a,e.b,e.c,e.d,e.e,e.f):Ya)}),", ",")",")");function $a(e){return((e=Math.exp(e))+1/e)/2}var qa,Ka,Ja=function e(t,n,i){function o(e,o){var a,r,s=e[0],l=e[1],c=e[2],u=o[0],d=o[1],h=o[2],p=u-s,g=d-l,f=p*p+g*g;if(f<1e-12)r=Math.log(h/c)/t,a=function(e){return[s+e*p,l+e*g,c*Math.exp(t*e*r)]};else{var v=Math.sqrt(f),y=(h*h-c*c+i*f)/(2*c*n*v),m=(h*h-c*c-i*f)/(2*h*n*v),k=Math.log(Math.sqrt(y*y+1)-y),b=Math.log(Math.sqrt(m*m+1)-m);r=(b-k)/t,a=function(e){var i,o=e*r,a=$a(k),u=c/(n*v)*(a*(i=t*o+k,((i=Math.exp(2*i))-1)/(i+1))-function(e){return((e=Math.exp(e))-1/e)/2}(k));return[s+u*p,l+u*g,c*a/$a(t*o+k)]}}return a.duration=1e3*r*t/Math.SQRT2,a}return o.rho=function(t){var n=Math.max(.001,+t),i=n*n;return e(n,i,i*i)},o}(Math.SQRT2,2,4),Qa=0,er=0,tr=0,nr=0,ir=0,or=0,ar="object"==typeof performance&&performance.now?performance:Date,rr="object"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(e){setTimeout(e,17)};function sr(){return ir||(rr(lr),ir=ar.now()+or)}function lr(){ir=0}function cr(){this._call=this._time=this._next=null}function ur(e,t,n){var i=new cr;return i.restart(e,t,n),i}function dr(){ir=(nr=ar.now())+or,Qa=er=0;try{!function(){sr(),++Qa;for(var e,t=qa;t;)(e=ir-t._time)>=0&&t._call.call(void 0,e),t=t._next;--Qa}()}finally{Qa=0,function(){var e,t,n=qa,i=1/0;for(;n;)n._call?(i>n._time&&(i=n._time),e=n,n=n._next):(t=n._next,n._next=null,n=e?e._next=t:qa=t);Ka=e,pr(i)}(),ir=0}}function hr(){var e=ar.now(),t=e-nr;t>1e3&&(or-=t,nr=e)}function pr(e){Qa||(er&&(er=clearTimeout(er)),e-ir>24?(e<1/0&&(er=setTimeout(dr,e-ar.now()-or)),tr&&(tr=clearInterval(tr))):(tr||(nr=ar.now(),tr=setInterval(hr,1e3)),Qa=1,rr(dr)))}function gr(e,t,n){var i=new cr;return t=null==t?0:+t,i.restart((n=>{i.stop(),e(n+t)}),t,n),i}cr.prototype=ur.prototype={constructor:cr,restart:function(e,t,n){if("function"!=typeof e)throw new TypeError("callback is not a function");n=(null==n?sr():+n)+(null==t?0:+t),this._next||Ka===this||(Ka?Ka._next=this:qa=this,Ka=this),this._call=e,this._time=n,pr()},stop:function(){this._call&&(this._call=null,this._time=1/0,pr())}};var fr=Xi("start","end","cancel","interrupt"),vr=[];function yr(e,t,n,i,o,a){var r=e.__transition;if(r){if(n in r)return}else e.__transition={};!function(e,t,n){var i,o=e.__transition;function a(e){n.state=1,n.timer.restart(r,n.delay,n.time),n.delay<=e&&r(e-n.delay)}function r(a){var c,u,d,h;if(1!==n.state)return l();for(c in o)if((h=o[c]).name===n.name){if(3===h.state)return gr(r);4===h.state?(h.state=6,h.timer.stop(),h.on.call("interrupt",e,e.__data__,h.index,h.group),delete o[c]):+c<t&&(h.state=6,h.timer.stop(),h.on.call("cancel",e,e.__data__,h.index,h.group),delete o[c])}if(gr((function(){3===n.state&&(n.state=4,n.timer.restart(s,n.delay,n.time),s(a))})),n.state=2,n.on.call("start",e,e.__data__,n.index,n.group),2===n.state){for(n.state=3,i=new Array(d=n.tween.length),c=0,u=-1;c<d;++c)(h=n.tween[c].value.call(e,e.__data__,n.index,n.group))&&(i[++u]=h);i.length=u+1}}function s(t){for(var o=t<n.duration?n.ease.call(null,t/n.duration):(n.timer.restart(l),n.state=5,1),a=-1,r=i.length;++a<r;)i[a].call(e,o);5===n.state&&(n.on.call("end",e,e.__data__,n.index,n.group),l())}function l(){for(var i in n.state=6,n.timer.stop(),delete o[t],o)return;delete e.__transition}o[t]=n,n.timer=ur(a,0,n.time)}(e,n,{name:t,index:i,group:o,on:fr,tween:vr,time:a.time,delay:a.delay,duration:a.duration,ease:a.ease,timer:null,state:0})}function mr(e,t){var n=br(e,t);if(n.state>0)throw new Error("too late; already scheduled");return n}function kr(e,t){var n=br(e,t);if(n.state>3)throw new Error("too late; already running");return n}function br(e,t){var n=e.__transition;if(!n||!(n=n[t]))throw new Error("transition not found");return n}function Cr(e,t){var n,i,o,a=e.__transition,r=!0;if(a){for(o in t=null==t?null:t+"",a)(n=a[o]).name===t?(i=n.state>2&&n.state<5,n.state=6,n.timer.stop(),n.on.call(i?"interrupt":"cancel",e,e.__data__,n.index,n.group),delete a[o]):r=!1;r&&delete e.__transition}}function Pr(e,t){var n,i;return function(){var o=kr(this,e),a=o.tween;if(a!==n)for(var r=0,s=(i=n=a).length;r<s;++r)if(i[r].name===t){(i=i.slice()).splice(r,1);break}o.tween=i}}function wr(e,t,n){var i,o;if("function"!=typeof n)throw new Error;return function(){var a=kr(this,e),r=a.tween;if(r!==i){o=(i=r).slice();for(var s={name:t,value:n},l=0,c=o.length;l<c;++l)if(o[l].name===t){o[l]=s;break}l===c&&o.push(s)}a.tween=o}}function Lr(e,t,n){var i=e._id;return e.each((function(){var e=kr(this,i);(e.value||(e.value={}))[t]=n.apply(this,arguments)})),function(e){return br(e,i).value[t]}}function xr(e,t){var n;return("number"==typeof t?ja:t instanceof ya?Ha:(n=ya(t))?(t=n,Ha):Ba)(e,t)}function Nr(e){return function(){this.removeAttribute(e)}}function Sr(e){return function(){this.removeAttributeNS(e.space,e.local)}}function Dr(e,t,n){var i,o,a=n+"";return function(){var r=this.getAttribute(e);return r===a?null:r===i?o:o=t(i=r,n)}}function Tr(e,t,n){var i,o,a=n+"";return function(){var r=this.getAttributeNS(e.space,e.local);return r===a?null:r===i?o:o=t(i=r,n)}}function Er(e,t,n){var i,o,a;return function(){var r,s,l=n(this);if(null!=l)return(r=this.getAttribute(e))===(s=l+"")?null:r===i&&s===o?a:(o=s,a=t(i=r,l));this.removeAttribute(e)}}function Ir(e,t,n){var i,o,a;return function(){var r,s,l=n(this);if(null!=l)return(r=this.getAttributeNS(e.space,e.local))===(s=l+"")?null:r===i&&s===o?a:(o=s,a=t(i=r,l));this.removeAttributeNS(e.space,e.local)}}function Or(e,t){return function(n){this.setAttribute(e,t.call(this,n))}}function _r(e,t){return function(n){this.setAttributeNS(e.space,e.local,t.call(this,n))}}function Ar(e,t){var n,i;function o(){var o=t.apply(this,arguments);return o!==i&&(n=(i=o)&&_r(e,o)),n}return o._value=t,o}function zr(e,t){var n,i;function o(){var o=t.apply(this,arguments);return o!==i&&(n=(i=o)&&Or(e,o)),n}return o._value=t,o}function Mr(e,t){return function(){mr(this,e).delay=+t.apply(this,arguments)}}function Hr(e,t){return t=+t,function(){mr(this,e).delay=t}}function jr(e,t){return function(){kr(this,e).duration=+t.apply(this,arguments)}}function Rr(e,t){return t=+t,function(){kr(this,e).duration=t}}function Fr(e,t){if("function"!=typeof t)throw new Error;return function(){kr(this,e).ease=t}}function Br(e,t,n){var i,o,a=function(e){return(e+"").trim().split(/^|\s+/).every((function(e){var t=e.indexOf(".");return t>=0&&(e=e.slice(0,t)),!e||"start"===e}))}(t)?mr:kr;return function(){var r=a(this,e),s=r.on;s!==i&&(o=(i=s).copy()).on(t,n),r.on=o}}var Gr=Ci.prototype.constructor;function Ur(e){return function(){this.style.removeProperty(e)}}function Yr(e,t,n){return function(i){this.style.setProperty(e,t.call(this,i),n)}}function Xr(e,t,n){var i,o;function a(){var a=t.apply(this,arguments);return a!==o&&(i=(o=a)&&Yr(e,a,n)),i}return a._value=t,a}function Wr(e){return function(t){this.textContent=e.call(this,t)}}function Vr(e){var t,n;function i(){var i=e.apply(this,arguments);return i!==n&&(t=(n=i)&&Wr(i)),t}return i._value=e,i}var Zr=0;function $r(e,t,n,i){this._groups=e,this._parents=t,this._name=n,this._id=i}function qr(){return++Zr}var Kr=Ci.prototype;$r.prototype={constructor:$r,select:function(e){var t=this._name,n=this._id;"function"!=typeof e&&(e=fn(e));for(var i=this._groups,o=i.length,a=new Array(o),r=0;r<o;++r)for(var s,l,c=i[r],u=c.length,d=a[r]=new Array(u),h=0;h<u;++h)(s=c[h])&&(l=e.call(s,s.__data__,h,c))&&("__data__"in s&&(l.__data__=s.__data__),d[h]=l,yr(d[h],t,n,h,d,br(s,n)));return new $r(a,this._parents,t,n)},selectAll:function(e){var t=this._name,n=this._id;"function"!=typeof e&&(e=mn(e));for(var i=this._groups,o=i.length,a=[],r=[],s=0;s<o;++s)for(var l,c=i[s],u=c.length,d=0;d<u;++d)if(l=c[d]){for(var h,p=e.call(l,l.__data__,d,c),g=br(l,n),f=0,v=p.length;f<v;++f)(h=p[f])&&yr(h,t,n,f,p,g);a.push(p),r.push(l)}return new $r(a,r,t,n)},selectChild:Kr.selectChild,selectChildren:Kr.selectChildren,filter:function(e){"function"!=typeof e&&(e=kn(e));for(var t=this._groups,n=t.length,i=new Array(n),o=0;o<n;++o)for(var a,r=t[o],s=r.length,l=i[o]=[],c=0;c<s;++c)(a=r[c])&&e.call(a,a.__data__,c,r)&&l.push(a);return new $r(i,this._parents,this._name,this._id)},merge:function(e){if(e._id!==this._id)throw new Error;for(var t=this._groups,n=e._groups,i=t.length,o=n.length,a=Math.min(i,o),r=new Array(i),s=0;s<a;++s)for(var l,c=t[s],u=n[s],d=c.length,h=r[s]=new Array(d),p=0;p<d;++p)(l=c[p]||u[p])&&(h[p]=l);for(;s<i;++s)r[s]=t[s];return new $r(r,this._parents,this._name,this._id)},selection:function(){return new Gr(this._groups,this._parents)},transition:function(){for(var e=this._name,t=this._id,n=qr(),i=this._groups,o=i.length,a=0;a<o;++a)for(var r,s=i[a],l=s.length,c=0;c<l;++c)if(r=s[c]){var u=br(r,t);yr(r,e,n,c,s,{time:u.time+u.delay+u.duration,delay:0,duration:u.duration,ease:u.ease})}return new $r(i,this._parents,e,n)},call:Kr.call,nodes:Kr.nodes,node:Kr.node,size:Kr.size,empty:Kr.empty,each:Kr.each,on:function(e,t){var n=this._id;return arguments.length<2?br(this.node(),n).on.on(e):this.each(Br(n,e,t))},attr:function(e,t){var n=un(e),i="transform"===n?Za:xr;return this.attrTween(e,"function"==typeof t?(n.local?Ir:Er)(n,i,Lr(this,"attr."+e,t)):null==t?(n.local?Sr:Nr)(n):(n.local?Tr:Dr)(n,i,t))},attrTween:function(e,t){var n="attr."+e;if(arguments.length<2)return(n=this.tween(n))&&n._value;if(null==t)return this.tween(n,null);if("function"!=typeof t)throw new Error;var i=un(e);return this.tween(n,(i.local?Ar:zr)(i,t))},style:function(e,t,n){var i="transform"==(e+="")?Va:xr;return null==t?this.styleTween(e,function(e,t){var n,i,o;return function(){var a=Un(this,e),r=(this.style.removeProperty(e),Un(this,e));return a===r?null:a===n&&r===i?o:o=t(n=a,i=r)}}(e,i)).on("end.style."+e,Ur(e)):"function"==typeof t?this.styleTween(e,function(e,t,n){var i,o,a;return function(){var r=Un(this,e),s=n(this),l=s+"";return null==s&&(this.style.removeProperty(e),l=s=Un(this,e)),r===l?null:r===i&&l===o?a:(o=l,a=t(i=r,s))}}(e,i,Lr(this,"style."+e,t))).each(function(e,t){var n,i,o,a,r="style."+t,s="end."+r;return function(){var l=kr(this,e),c=l.on,u=null==l.value[r]?a||(a=Ur(t)):void 0;c===n&&o===u||(i=(n=c).copy()).on(s,o=u),l.on=i}}(this._id,e)):this.styleTween(e,function(e,t,n){var i,o,a=n+"";return function(){var r=Un(this,e);return r===a?null:r===i?o:o=t(i=r,n)}}(e,i,t),n).on("end.style."+e,null)},styleTween:function(e,t,n){var i="style."+(e+="");if(arguments.length<2)return(i=this.tween(i))&&i._value;if(null==t)return this.tween(i,null);if("function"!=typeof t)throw new Error;return this.tween(i,Xr(e,t,null==n?"":n))},text:function(e){return this.tween("text","function"==typeof e?function(e){return function(){var t=e(this);this.textContent=null==t?"":t}}(Lr(this,"text",e)):function(e){return function(){this.textContent=e}}(null==e?"":e+""))},textTween:function(e){var t="text";if(arguments.length<1)return(t=this.tween(t))&&t._value;if(null==e)return this.tween(t,null);if("function"!=typeof e)throw new Error;return this.tween(t,Vr(e))},remove:function(){return this.on("end.remove",function(e){return function(){var t=this.parentNode;for(var n in this.__transition)if(+n!==e)return;t&&t.removeChild(this)}}(this._id))},tween:function(e,t){var n=this._id;if(e+="",arguments.length<2){for(var i,o=br(this.node(),n).tween,a=0,r=o.length;a<r;++a)if((i=o[a]).name===e)return i.value;return null}return this.each((null==t?Pr:wr)(n,e,t))},delay:function(e){var t=this._id;return arguments.length?this.each(("function"==typeof e?Mr:Hr)(t,e)):br(this.node(),t).delay},duration:function(e){var t=this._id;return arguments.length?this.each(("function"==typeof e?jr:Rr)(t,e)):br(this.node(),t).duration},ease:function(e){var t=this._id;return arguments.length?this.each(Fr(t,e)):br(this.node(),t).ease},easeVarying:function(e){if("function"!=typeof e)throw new Error;return this.each(function(e,t){return function(){var n=t.apply(this,arguments);if("function"!=typeof n)throw new Error;kr(this,e).ease=n}}(this._id,e))},end:function(){var e,t,n=this,i=n._id,o=n.size();return new Promise((function(a,r){var s={value:r},l={value:function(){0==--o&&a()}};n.each((function(){var n=kr(this,i),o=n.on;o!==e&&((t=(e=o).copy())._.cancel.push(s),t._.interrupt.push(s),t._.end.push(l)),n.on=t})),0===o&&a()}))},[Symbol.iterator]:Kr[Symbol.iterator]};var Jr={time:null,delay:0,duration:250,ease:uo};function Qr(e,t){for(var n;!(n=e.__transition)||!(n=n[t]);)if(!(e=e.parentNode))throw new Error(`transition ${t} not found`);return n}Ci.prototype.interrupt=function(e){return this.each((function(){Cr(this,e)}))},Ci.prototype.transition=function(e){var t,n;e instanceof $r?(t=e._id,e=e._name):(t=qr(),(n=Jr).time=sr(),e=null==e?null:e+"");for(var i=this._groups,o=i.length,a=0;a<o;++a)for(var r,s=i[a],l=s.length,c=0;c<l;++c)(r=s[c])&&yr(r,e,t,c,s,n||Qr(r,t));return new $r(i,this._parents,e,t)};var es=function(e){return function(){return e}};function ts(e,t){var n=t.sourceEvent,i=t.target,o=t.transform,a=t.dispatch;Object.defineProperties(this,{type:{value:e,enumerable:!0,configurable:!0},sourceEvent:{value:n,enumerable:!0,configurable:!0},target:{value:i,enumerable:!0,configurable:!0},transform:{value:o,enumerable:!0,configurable:!0},_:{value:a}})}function ns(e,t,n){this.k=e,this.x=t,this.y=n}ns.prototype={constructor:ns,scale:function(e){return 1===e?this:new ns(this.k*e,this.x,this.y)},translate:function(e,t){return 0===e&0===t?this:new ns(this.k,this.x+this.k*e,this.y+this.k*t)},apply:function(e){return[e[0]*this.k+this.x,e[1]*this.k+this.y]},applyX:function(e){return e*this.k+this.x},applyY:function(e){return e*this.k+this.y},invert:function(e){return[(e[0]-this.x)/this.k,(e[1]-this.y)/this.k]},invertX:function(e){return(e-this.x)/this.k},invertY:function(e){return(e-this.y)/this.k},rescaleX:function(e){return e.copy().domain(e.range().map(this.invertX,this).map(e.invert,e))},rescaleY:function(e){return e.copy().domain(e.range().map(this.invertY,this).map(e.invert,e))},toString:function(){return"translate("+this.x+","+this.y+") scale("+this.k+")"}};var is=new ns(1,0,0);function os(e){for(;!e.__zoom;)if(!(e=e.parentNode))return is;return e.__zoom}function as(e){e.stopImmediatePropagation()}function rs(e){e.preventDefault(),e.stopImmediatePropagation()}function ss(e){return!(e.ctrlKey&&"wheel"!==e.type||e.button)}function ls(){var e=this;return e instanceof SVGElement?(e=e.ownerSVGElement||e).hasAttribute("viewBox")?[[(e=e.viewBox.baseVal).x,e.y],[e.x+e.width,e.y+e.height]]:[[0,0],[e.width.baseVal.value,e.height.baseVal.value]]:[[0,0],[e.clientWidth,e.clientHeight]]}function cs(){return this.__zoom||is}function us(e){return-e.deltaY*(1===e.deltaMode?.05:e.deltaMode?1:.002)*(e.ctrlKey?10:1)}function ds(){return navigator.maxTouchPoints||"ontouchstart"in this}function hs(e,t,n){var i=e.invertX(t[0][0])-n[0][0],o=e.invertX(t[1][0])-n[1][0],a=e.invertY(t[0][1])-n[0][1],r=e.invertY(t[1][1])-n[1][1];return e.translate(o>i?(i+o)/2:Math.min(0,i)||Math.max(0,o),r>a?(a+r)/2:Math.min(0,a)||Math.max(0,r))}os.prototype=ns.prototype;var ps=Object.freeze({__proto__:null,zoom:function(){var e,t,n,i=ss,o=ls,a=hs,r=us,s=ds,l=[0,1/0],c=[[-1/0,-1/0],[1/0,1/0]],u=250,d=Ja,h=Xi("start","zoom","end"),p=500,g=0,f=10,v=!1,y=!1;function m(e){e.property("__zoom",cs).on("wheel.zoom",x).on("mousedown.zoom",T).on("dblclick.zoom",E).on("gesturestart",N).on("gesturechange",S).on("gestureend",D).filter(s).on("touchstart.zoom",I).on("touchmove.zoom",O).on("touchend.zoom touchcancel.zoom",_).style("-webkit-tap-highlight-color","rgba(0,0,0,0)")}function k(e,t){return(t=Math.max(l[0],Math.min(l[1],t)))===e.k?e:new ns(t,e.x,e.y)}function b(e,t,n){var i=t[0]-n[0]*e.k,o=t[1]-n[1]*e.k;return i===e.x&&o===e.y?e:new ns(e.k,i,o)}function C(e){return[(+e[0][0]+ +e[1][0])/2,(+e[0][1]+ +e[1][1])/2]}function P(e,t,n,i){e.on("start.zoom",(function(){w(this,arguments).event(i).start()})).on("interrupt.zoom end.zoom",(function(){w(this,arguments).event(i).end()})).tween("zoom",(function(){var e=this,a=arguments,r=w(e,a).event(i),s=o.apply(e,a),l=null==n?C(s):"function"==typeof n?n.apply(e,a):n,c=Math.max(s[1][0]-s[0][0],s[1][1]-s[0][1]),u=e.__zoom,h="function"==typeof t?t.apply(e,a):t,p=d(u.invert(l).concat(c/u.k),h.invert(l).concat(c/h.k));return function(e){if(1===e)e=h;else{var t=p(e),n=c/t[2];e=new ns(n,l[0]-t[0]*n,l[1]-t[1]*n)}r.zoom(null,e)}}))}function w(e,t,n){return!n&&e.__zooming||new L(e,t)}function L(e,t){this.that=e,this.args=t,this.active=0,this.sourceEvent=null,this.extent=o.apply(e,t),this.taps=0}function x(e){for(var t=arguments.length,n=new Array(t>1?t-1:0),o=1;o<t;o++)n[o-1]=arguments[o];if(y&&rs(e),i.apply(this,arguments)){var s=w(this,n).event(e),u=this.__zoom,d=Math.max(l[0],Math.min(l[1],u.k*Math.pow(2,r.apply(this,arguments)))),h=Si(e);if(s.wheel)s.mouse[0][0]===h[0]&&s.mouse[0][1]===h[1]||(s.mouse[1]=u.invert(s.mouse[0]=h)),clearTimeout(s.wheel);else{if(u.k===d)return;!v||e.ctrlKey||e.safariPinchZoom||(s.wheelTransX=-u.x,s.wheelTransY=-u.y),s.mouse=[h,u.invert(h)],Cr(this),s.start()}if(rs(e),s.wheel=setTimeout(f,150),!v||e.ctrlKey||e.safariPinchZoom)s.zoom("mouse",a(b(k(u,d),s.mouse[0],s.mouse[1]),s.extent,c));else{s.wheelTransX+=e.deltaX,s.wheelTransY+=e.deltaY;var p=[u.x,u.y],g=[u.x+s.wheelTransX,u.y+s.wheelTransY];s.zoom("mouse",a(b(u,p,g),s.extent,c))}}function f(){s.wheel=null,s.end()}}function N(e){rs(e),this.scale=e.scale}function S(e){rs(e),this.__zoom&&(e.deltaY=100*(this.scale-e.scale),this.scale=e.scale),e.safariPinchZoom=!0,x.apply(this,[e].concat(Array.prototype.slice.call(arguments)))}function D(e){rs(e)}function T(e){for(var t=arguments.length,o=new Array(t>1?t-1:0),r=1;r<t;r++)o[r-1]=arguments[r];if(!n&&i.apply(this,arguments)){var s=w(this,o,!0).event(e),l=Pi(e.view).on("mousemove.zoom",f,!0).on("mouseup.zoom",v,!0),u=Si(e,d),d=e.currentTarget,h=e.clientX,p=e.clientY;eo(e.view),as(e),s.mouse=[u,this.__zoom.invert(u)],Cr(this),s.start()}function f(e){if(rs(e),!s.moved){var t=e.clientX-h,n=e.clientY-p;s.moved=t*t+n*n>g}s.event(e).zoom("mouse",a(b(s.that.__zoom,s.mouse[0]=Si(e,d),s.mouse[1]),s.extent,c))}function v(e){l.on("mousemove.zoom mouseup.zoom",null),to(e.view,s.moved),rs(e),s.event(e).end()}}function E(e){for(var t=arguments.length,n=new Array(t>1?t-1:0),r=1;r<t;r++)n[r-1]=arguments[r];if(i.apply(this,arguments)){var s=this.__zoom,l=Si(e.changedTouches?e.changedTouches[0]:e,this),d=s.invert(l),h=s.k*(e.shiftKey?.5:2),p=a(b(k(s,h),l,d),o.apply(this,n),c);rs(e),u>0?Pi(this).transition().duration(u).call(P,p,l,e):Pi(this).call(m.transform,p,l,e)}}function I(n){for(var o=arguments.length,a=new Array(o>1?o-1:0),r=1;r<o;r++)a[r-1]=arguments[r];if(i.apply(this,arguments)){var s,l,c,u,d=n.touches,h=d.length,g=w(this,a,n.changedTouches.length===h).event(n);for(as(n),l=0;l<h;++l)u=[u=Si(c=d[l],this),this.__zoom.invert(u),c.identifier],g.touch0?g.touch1||g.touch0[2]===u[2]||(g.touch1=u,g.taps=0):(g.touch0=u,s=!0,g.taps=1+!!e);e&&(e=clearTimeout(e)),s&&(g.taps<2&&(t=u[0],e=setTimeout((function(){e=null}),p)),Cr(this),g.start())}}function O(e){if(this.__zooming){for(var t=arguments.length,n=new Array(t>1?t-1:0),i=1;i<t;i++)n[i-1]=arguments[i];var o,r,s,l,u=w(this,n).event(e),d=e.changedTouches,h=d.length;for(rs(e),o=0;o<h;++o)s=Si(r=d[o],this),u.touch0&&u.touch0[2]===r.identifier?u.touch0[0]=s:u.touch1&&u.touch1[2]===r.identifier&&(u.touch1[0]=s);if(r=u.that.__zoom,u.touch1){var p=u.touch0[0],g=u.touch0[1],f=u.touch1[0],v=u.touch1[1],y=(y=f[0]-p[0])*y+(y=f[1]-p[1])*y,m=(m=v[0]-g[0])*m+(m=v[1]-g[1])*m;r=k(r,Math.sqrt(y/m)),s=[(p[0]+f[0])/2,(p[1]+f[1])/2],l=[(g[0]+v[0])/2,(g[1]+v[1])/2]}else{if(!u.touch0)return;s=u.touch0[0],l=u.touch0[1]}u.zoom("touch",a(b(r,s,l),u.extent,c))}}function _(e){for(var i=arguments.length,o=new Array(i>1?i-1:0),a=1;a<i;a++)o[a-1]=arguments[a];if(this.__zooming){var r,s,l=w(this,o).event(e),c=e.changedTouches,u=c.length;for(as(e),n&&clearTimeout(n),n=setTimeout((function(){n=null}),p),r=0;r<u;++r)s=c[r],l.touch0&&l.touch0[2]===s.identifier?delete l.touch0:l.touch1&&l.touch1[2]===s.identifier&&delete l.touch1;if(l.touch1&&!l.touch0&&(l.touch0=l.touch1,delete l.touch1),l.touch0)l.touch0[1]=this.__zoom.invert(l.touch0[0]);else if(l.end(),2===l.taps&&(s=Si(s,this),Math.hypot(t[0]-s[0],t[1]-s[1])<f)){var d=Pi(this).on("dblclick.zoom");d&&d.apply(this,arguments)}}}return m.transform=function(e,t,n,i){var o=e.selection?e.selection():e;o.property("__zoom",cs),e!==o?P(e,t,n,i):o.interrupt().each((function(){w(this,arguments).event(i).start().zoom(null,"function"==typeof t?t.apply(this,arguments):t).end()}))},m.scaleBy=function(e,t,n,i){m.scaleTo(e,(function(){var e=this.__zoom.k,n="function"==typeof t?t.apply(this,arguments):t;return e*n}),n,i)},m.scaleTo=function(e,t,n,i){m.transform(e,(function(){var e=o.apply(this,arguments),i=this.__zoom,r=null==n?C(e):"function"==typeof n?n.apply(this,arguments):n,s=i.invert(r),l="function"==typeof t?t.apply(this,arguments):t;return a(b(k(i,l),r,s),e,c)}),n,i)},m.translateBy=function(e,t,n,i){m.transform(e,(function(){return a(this.__zoom.translate("function"==typeof t?t.apply(this,arguments):t,"function"==typeof n?n.apply(this,arguments):n),o.apply(this,arguments),c)}),null,i)},m.translateTo=function(e,t,n,i,r){m.transform(e,(function(){var e=o.apply(this,arguments),r=this.__zoom,s=null==i?C(e):"function"==typeof i?i.apply(this,arguments):i;return a(is.translate(s[0],s[1]).scale(r.k).translate("function"==typeof t?-t.apply(this,arguments):-t,"function"==typeof n?-n.apply(this,arguments):-n),e,c)}),i,r)},L.prototype={event:function(e){return e&&(this.sourceEvent=e),this},start:function(){return 1==++this.active&&(this.that.__zooming=this,this.emit("start")),this},zoom:function(e,t){return this.mouse&&"mouse"!==e&&(this.mouse[1]=t.invert(this.mouse[0])),this.touch0&&"touch"!==e&&(this.touch0[1]=t.invert(this.touch0[0])),this.touch1&&"touch"!==e&&(this.touch1[1]=t.invert(this.touch1[0])),this.that.__zoom=t,this.emit("zoom"),this},end:function(){return 0==--this.active&&(delete this.that.__zooming,this.emit("end")),this},emit:function(e){var t=Pi(this.that).datum();h.call(e,this.that,new ts(e,{sourceEvent:this.sourceEvent,target:m,type:e,transform:this.that.__zoom,dispatch:h}),t)}},m.wheelDelta=function(e){return arguments.length?(r="function"==typeof e?e:es(+e),m):r},m.filter=function(e){return arguments.length?(i="function"==typeof e?e:es(!!e),m):i},m.touchable=function(e){return arguments.length?(s="function"==typeof e?e:es(!!e),m):s},m.extent=function(e){return arguments.length?(o="function"==typeof e?e:es([[+e[0][0],+e[0][1]],[+e[1][0],+e[1][1]]]),m):o},m.scaleExtent=function(e){return arguments.length?(l[0]=+e[0],l[1]=+e[1],m):[l[0],l[1]]},m.translateExtent=function(e){return arguments.length?(c[0][0]=+e[0][0],c[1][0]=+e[1][0],c[0][1]=+e[0][1],c[1][1]=+e[1][1],m):[[c[0][0],c[0][1]],[c[1][0],c[1][1]]]},m.constrain=function(e){return arguments.length?(a=e,m):a},m.trackpad=function(e){return arguments.length?(v=e,m):v},m.preventBackGesture=function(e){return arguments.length?(y=e,m):y},m.duration=function(e){return arguments.length?(u=+e,m):u},m.interpolate=function(e){return arguments.length?(d=e,m):d},m.on=function(){var e=h.on.apply(h,arguments);return e===h?m:e},m.clickDistance=function(e){return arguments.length?(g=(e=+e)*e,m):Math.sqrt(g)},m.tapDistance=function(e){return arguments.length?(f=+e,m):f},m},zoomTransform:os,zoomIdentity:is}),gs=function(){function n(t,i,o){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,n),this.canvasController=t,this.isSubflow=i,this.pipelineId=o}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(n,[{key:"isDisplayingCurrentPipeline",value:function(){return this.canvasController.getCurrentBreadcrumb().pipelineId===this.pipelineId}},{key:"setDisplayState",value:function(){this.canvasController.getBreadcrumbs().length>1&&this.isDisplayingCurrentPipeline()?this.displayState="sub-flow-full-page":this.isSubflow?this.displayState="sub-flow-in-place":this.displayState="primary-flow-full-page"}},{key:"getDisplayStateMsg",value:function(){return"Display state set to "+this.displayState}},{key:"isDisplayingPrimaryFlowFullPage",value:function(){return"primary-flow-full-page"===this.displayState}},{key:"isDisplayingSubFlow",value:function(){return"sub-flow-in-place"===this.displayState||"sub-flow-full-page"===this.displayState}},{key:"isDisplayingSubFlowInPlace",value:function(){return"sub-flow-in-place"===this.displayState}},{key:"isDisplayingSubFlowFullPage",value:function(){return"sub-flow-full-page"===this.displayState}},{key:"isDisplayingFullPage",value:function(){return"primary-flow-full-page"===this.displayState||"sub-flow-full-page"===this.displayState}}]),n}();function fs(e,t){var n="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!n){if(Array.isArray(e)||(n=function(e,t){if(!e)return;if("string"==typeof e)return vs(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);"Object"===n&&e.constructor&&(n=e.constructor.name);if("Map"===n||"Set"===n)return Array.from(e);if("Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return vs(e,t)}(e))||t&&e&&"number"==typeof e.length){n&&(e=n);var i=0,o=function(){};return{s:o,n:function(){return i>=e.length?{done:!0}:{done:!1,value:e[i++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var a,r=!0,s=!1;return{s:function(){n=n.call(e)},n:function(){var e=n.next();return r=e.done,e},e:function(e){s=!0,a=e},f:function(){try{r||null==n.return||n.return()}finally{if(s)throw a}}}}function vs(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,i=new Array(t);n<t;n++)i[n]=e[n];return i}var ys=function(){function n(t){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,n),this.canvasLayout=t}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(n,[{key:"getNodeImageClass",value:function(e){return"d3-node-image"}},{key:"getNodeLabelForeignClass",value:function(e){return"d3-foreign-object"+(e.layout.labelOutline?" d3-node-label-outline":"")}},{key:"getNodeLabelClass",value:function(e){if(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e))return"d3-node-label d3-label-single-line "+this.getMessageLabelClass(e.messages);var t=e.layout.labelSingleLine?" d3-label-single-line":" d3-label-multi-line",n="center"===e.layout.labelAlign?" d3-label-center":"";return"d3-node-label "+this.getMessageLabelClass(e.messages)+t+n}},{key:"getNodeLabelTextAreaClass",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?"d3-node-label-entry d3-label-single-line":"d3-node-label-entry"+(e.layout.labelSingleLine?" d3-label-single-line":" d3-label-multi-line")+("center"===e.layout.labelAlign?" d3-label-center":"")}},{key:"getErrorMarkerIcon",value:function(e){var t="";switch(this.getMessageLevel(e.messages)){case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.E:t=_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.G;break;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.W:t=_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.N}return t}},{key:"getMessageLevel",value:function(e){var t="";if(e&&e.length>0){var n,i=fs(e);try{for(i.s();!(n=i.n()).done;){var o=n.value;if(o.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.E)return o.type;o.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.W&&(t=o.type)}}catch(e){i.e(e)}finally{i.f()}}return t}},{key:"getMessageLabelClass",value:function(e){var t="";switch(this.getMessageLevel(e)){case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.E:t="d3-node-error-label";break;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.W:t="d3-node-warning-label"}return t}},{key:"getErrorMarkerClass",value:function(e){var t="d3-error-circle-off";switch(this.getMessageLevel(e)){case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.E:t="d3-error-circle";break;case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.W:t="d3-warning-circle"}return t}},{key:"getNodeCenterPosX",value:function(e){return e.x_pos+e.width/2}},{key:"getNodeCenterPosY",value:function(e){return e.y_pos+e.height/2}},{key:"getNodeImageCenterPosX",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?e.x_pos+this.canvasLayout.supernodeImagePosX+this.canvasLayout.supernodeImageWidth/2:e.x_pos+this.getElementPosX(e.width,e.layout.imagePosX,e.layout.imagePosition)+e.layout.imageWidth/2}},{key:"getNodeImageCenterPosY",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?e.y_pos+this.canvasLayout.supernodeImagePosY+this.canvasLayout.supernodeImageHeight/2:e.y_pos+this.getElementPosY(e.height,e.layout.imagePosY,e.layout.imagePosition)+e.layout.imageHeight/2}},{key:"getNodeImagePosX",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?this.canvasLayout.supernodeImagePosX:this.getElementPosX(e.width,e.layout.imagePosX,e.layout.imagePosition)}},{key:"getNodeImagePosY",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?this.canvasLayout.supernodeImagePosY:this.getElementPosY(e.height,e.layout.imagePosY,e.layout.imagePosition)}},{key:"getNodeImageWidth",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?this.canvasLayout.supernodeImageWidth:e.layout.imageWidth}},{key:"getNodeImageHeight",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?this.canvasLayout.supernodeImageHeight:e.layout.imageHeight}},{key:"getNodeLabelPosX",value:function(e){if(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e))return this.canvasLayout.supernodeLabelPosX;var t=this.getElementPosX(e.width,e.layout.labelPosX,e.layout.labelPosition);return"center"===e.layout.labelAlign?t-e.layout.labelWidth/2:t}},{key:"getNodeLabelPosY",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?this.canvasLayout.supernodeLabelPosY:this.getElementPosY(e.height,e.layout.labelPosY,e.layout.labelPosition)}},{key:"getNodeLabelWidth",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?e.width-this.canvasLayout.supernodeLabelPosX+this.canvasLayout.supernodeErrorPosX:e.layout.labelWidth}},{key:"getNodeLabelHeight",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?this.canvasLayout.supernodeLabelHeight:e.layout.labelHeight}},{key:"getNodeLabelEditIconTranslate",value:function(e,t,n,i){return"translate(".concat(this.getNodeLabelEditIconPosX(e,t,n,i),", ").concat(this.getNodeLabelEditIconPosY(e),")")}},{key:"getNodeLabelEditIconPosX",value:function(e,t,n,i){var o=i?this.getNodeLabelHoverWidth(e):this.getNodeLabelWidth(e),a=i?this.getNodeLabelHoverPosX(e):this.getNodeLabelPosX(e),r=t.getBoundingClientRect().width;if("center"===e.layout.labelAlign&&!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)){var s=o/2;return a+s+Math.min(s,r/n/2)}var l=Math.min(o,r/n);return this.getNodeLabelPosX(e)+l}},{key:"getNodeLabelEditIconPosY",value:function(e){return this.getNodeLabelPosY(e)}},{key:"getNodeLabelHoverPosX",value:function(e){return e.layout.labelSingleLine&&"center"===e.layout.labelAlign?this.getNodeLabelPosX(e)-250:this.getNodeLabelPosX(e)}},{key:"getNodeLabelHoverWidth",value:function(e){return e.layout.labelSingleLine?"center"===e.layout.labelAlign?e.layout.labelWidth+500:e.layout.labelWidth+40:e.layout.labelWidth}},{key:"getNodeLabelHoverHeight",value:function(e,t,n){if(e.layout.labelSingleLine)return e.layout.labelHeight;var i=t.getBoundingClientRect().height/n;return Math.max(i,e.layout.labelHeight)}},{key:"getNodeLabelTextAreaWidth",value:function(e){return this.getNodeLabelWidth(e)+2*_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.F}},{key:"getNodeLabelTextAreaHeight",value:function(e){return this.getNodeLabelHeight(e)+2*_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.F}},{key:"getNodeLabelTextAreaPosX",value:function(e){return this.getNodeLabelPosX(e)-_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.F}},{key:"getNodeLabelTextAreaPosY",value:function(e){return this.getNodeLabelPosY(e)-_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.F}},{key:"getNodeEllipsisTranslate",value:function(e){return"translate(".concat(this.getNodeEllipsisPosX(e),", ").concat(this.getNodeEllipsisPosY(e),")")}},{key:"getNodeEllipsisWidth",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?this.canvasLayout.supernodeEllipsisWidth:e.layout.ellipsisWidth}},{key:"getNodeEllipsisHeight",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?this.canvasLayout.supernodeEllipsisHeight:e.layout.ellipsisHeight}},{key:"getNodeEllipsisIconWidth",value:function(e){return this.getNodeEllipsisWidth(e)-2*e.layout.ellipsisHoverAreaPadding}},{key:"getNodeEllipsisIconHeight",value:function(e){return this.getNodeEllipsisHeight(e)-2*e.layout.ellipsisHoverAreaPadding}},{key:"getNodeEllipsisPosX",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?e.width+this.canvasLayout.supernodeEllipsisPosX:this.getElementPosX(e.width,e.layout.ellipsisPosX,e.layout.ellipsisPosition)}},{key:"getNodeEllipsisPosY",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?this.canvasLayout.supernodeEllipsisPosY:this.getElementPosY(e.height,e.layout.ellipsisPosY,e.layout.ellipsisPosition)}},{key:"getNodeExpansionIconTranslate",value:function(e){var t=e.width+this.canvasLayout.supernodeExpansionIconPosX;return"translate(".concat(t,", ").concat(this.canvasLayout.supernodeExpansionIconPosY,")")}},{key:"getNodeErrorPosX",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?e.width+this.canvasLayout.supernodeErrorPosX:this.getElementPosX(e.width,e.layout.errorXPos,e.layout.errorPosition)}},{key:"getNodeErrorPosY",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?this.canvasLayout.supernodeErrorPosY:this.getElementPosY(e.height,e.layout.errorYPos,e.layout.errorPosition)}},{key:"getNodeErrorWidth",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?this.canvasLayout.supernodeErrorWidth:e.layout.errorWidth}},{key:"getNodeErrorHeight",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?this.canvasLayout.supernodeErrorHeight:e.layout.errorHeight}},{key:"getElementPosX",value:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:0,n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"topLeft",i=0;return n.endsWith("Center")?i+=e/2:n.endsWith("Right")&&(i+=e),i+Number(t)}},{key:"getElementPosY",value:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:0,n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"topLeft",i=0;return n.startsWith("middle")?i+=e/2:n.startsWith("bottom")&&(i+=e),i+Number(t)}},{key:"getSupernodePortXOffset",value:function(e,t){return t?t.find((function(t){return t.subflow_node_ref===e})).cx-this.canvasLayout.supernodeSVGAreaPadding:0}},{key:"getSupernodePortYOffset",value:function(e,t){return t?t.find((function(t){return t.subflow_node_ref===e})).cy:0}}]),n}(),ms=function(){function n(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,n)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(n,[{key:"getCommentCenterPosX",value:function(e){return e.x_pos+e.width/2}},{key:"getCommentCenterPosY",value:function(e){return e.y_pos+e.height/2}}]),n}(),ks=Math.PI,bs=function(){function n(t,i,o,a){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,n),this.canvasLayout=i,this.config=t,this.nodeUtils=o,this.commentUtils=a}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(n,[{key:"getNewStraightCommentLinkStartPos",value:function(e,t){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getOuterCoord(e.x_pos,e.y_pos,e.width,e.height,this.canvasLayout.linkGap,this.commentUtils.getCommentCenterPosX(e),this.commentUtils.getCommentCenterPosY(e),t.x,t.y)}},{key:"getNewStraightNodeLinkStartPos",value:function(e,t,n){var i,o;if("image_center"!==e.layout.drawNodeLinkLineFromTo||_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpanded(e))if(n){var a=this.getCenterOffset(e,n);i=a.x,o=a.y}else i=this.nodeUtils.getNodeCenterPosX(e),o=this.nodeUtils.getNodeCenterPosY(e);else i=this.nodeUtils.getNodeImageCenterPosX(e),o=this.nodeUtils.getNodeImageCenterPosY(e);return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getOuterCoord(e.x_pos,e.y_pos,e.width,e.height,this.canvasLayout.linkGap,i,o,t.x,t.y)}},{key:"addConnectionPaths",value:function(e){var t=this;return e.forEach((function(e){e.pathInfo=t.getConnectorPathInfo(e)})),e}},{key:"getConnectorPathInfo",value:function(e,t){var n=this.getMinInitialLine(e,t);if(Math.abs(e.x1-e.x2)<20&&Math.abs(e.y1-e.y2)<20)return this.getStraightPath(e);if(e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H){if(this.canvasLayout.linkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.L||this.canvasLayout.linkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.J)return this.getPortLinkPath(e,n)}else if(e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K&&this.config.enableAssocLinkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.M)return this.getAssociationCurvePath(e,n);return this.getStraightPath(e)}},{key:"getMinInitialLine",value:function(e,t){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O?0:e.minInitialLineForElbow?e.minInitialLineForElbow:e.srcObj&&e.srcObj.layout?e.srcObj.layout.minInitialLine:t||10}},{key:"getLinkCoords",value:function(e,t,n,i,o,a){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H?this.canvasLayout.linkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Q?this.getNodeLinkCoordsForStraightLine(t,i,e):this.getNodeLinkCoordsForPorts(t,n,i,o):e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K?this.config.enableAssocLinkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.M?this.getAssociationCurveLinkCoords(t,i,a):this.getNodeLinkCoordsForStraightLine(t,i):this.getCommentLinkCoords(t,i)}},{key:"getNodeLinkCoordsForStraightLine",value:function(e,t,n){var i,o,a,r;if("image_center"!==e.layout.drawNodeLinkLineFromTo||_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpanded(e))if(n&&n.srcOriginInfo){var s=this.getCenterOffset(e,n.srcOriginInfo);i=s.x,o=s.y}else i=this.nodeUtils.getNodeCenterPosX(e),o=this.nodeUtils.getNodeCenterPosY(e);else i=this.nodeUtils.getNodeImageCenterPosX(e),o=this.nodeUtils.getNodeImageCenterPosY(e);if("image_center"!==t.layout.drawNodeLinkLineFromTo||_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpanded(t))if(n&&n.trgOriginInfo){var l=this.getCenterOffset(t,n.trgOriginInfo);a=l.x,r=l.y}else a=this.nodeUtils.getNodeCenterPosX(t),r=this.nodeUtils.getNodeCenterPosY(t);else a=this.nodeUtils.getNodeImageCenterPosX(t),r=this.nodeUtils.getNodeImageCenterPosY(t);var c=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getOuterCoord(e.x_pos,e.y_pos,e.width,e.height,this.canvasLayout.linkGap,i,o,a,r),u=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getOuterCoord(t.x_pos,t.y_pos,t.width,t.height,this.canvasLayout.linkGap,a,r,i,o);return{x1:c.x,y1:c.y,x2:u.x,y2:u.y}}},{key:"getCenterOffset",value:function(e,t){var n=t.len+1,i=t.idx+1,o=0,a=0;return t.dir===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.R||t.dir===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.V?(o=e.x_pos+e.width/n*i,a=this.nodeUtils.getNodeCenterPosY(e)):t.dir!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.X&&t.dir!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Y||(o=this.nodeUtils.getNodeCenterPosX(e),a=e.y_pos+e.height/n*i),{x:o,y:a}}},{key:"getNodeLinkCoordsForPorts",value:function(e,t,n,i){var o=e.width+e.layout.outputPortRightPosX,a=e.layout.outputPortRightPosY,r=n.layout.inputPortLeftPosX,s=n.layout.inputPortLeftPosY;if(this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Z?(o=e.layout.outputPortBottomPosX,a=e.height+e.layout.outputPortBottomPosY,r=n.layout.inputPortTopPosX,s=n.layout.inputPortTopPosY):this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.$&&(o=e.layout.outputPortBottomPosX,a=e.layout.outputPortBottomPosY,r=n.layout.inputPortTopPosX,s=n.height+n.layout.inputPortTopPosY),e.outputs&&e.outputs.length>0){var l=e.outputs.find((function(e){return e.id===t}));o=l?l.cx:o,a=l?l.cy:a}if(n.inputs&&n.inputs.length>0){var c=n.inputs.find((function(e){return e.id===i}));r=c?c.cx:r,s=c?c.cy:s}return{x1:e.x_pos+o,y1:e.y_pos+a,x2:n.x_pos+r,y2:n.y_pos+s}}},{key:"getAssociationCurveLinkCoords",value:function(e,t,n){var i=0,o=0;return n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a0?(i=e.x_pos+e.width,o=t.x_pos):n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a1?(i=e.x_pos,o=t.x_pos+t.width):n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a2?(i=e.x_pos,o=t.x_pos):(i=e.x_pos+e.width,o=t.x_pos+t.width),{x1:i,y1:e.y_pos+e.layout.outputPortRightPosY,x2:o,y2:t.y_pos+t.layout.inputPortLeftPosY}}},{key:"getCommentLinkCoords",value:function(e,t){var n,i,o=this.commentUtils.getCommentCenterPosX(e),a=this.commentUtils.getCommentCenterPosY(e);"image_center"===t.layout.drawCommentLinkLineTo?(n=this.nodeUtils.getNodeImageCenterPosX(t),i=this.nodeUtils.getNodeImageCenterPosY(t)):(n=this.nodeUtils.getNodeCenterPosX(t),i=this.nodeUtils.getNodeCenterPosY(t));var r=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getOuterCoord(e.x_pos,e.y_pos,e.width,e.height,this.canvasLayout.linkGap,o,a,n,i),s=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getOuterCoord(t.x_pos,t.y_pos,t.width,t.height,this.canvasLayout.linkGap,n,i,o,a);return{x1:r.x,y1:r.y,x2:s.x,y2:s.y}}},{key:"getPortLinkPath",value:function(e,t){var n,i,o,a;e.srcObj&&e.trgNode?this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Z?(n=-(e.srcObj.x_pos+e.srcObj.width),o=-e.srcObj.x_pos,i=-(e.trgNode.x_pos+e.trgNode.width),a=-e.trgNode.x_pos):this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.$?(n=e.srcObj.x_pos,o=e.srcObj.x_pos+e.srcObj.width,i=e.trgNode.x_pos,a=e.trgNode.x_pos+e.trgNode.width):(n=e.srcObj.y_pos,o=e.srcObj.y_pos+e.srcObj.height,i=e.trgNode.y_pos,a=e.trgNode.y_pos+e.trgNode.height):this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Z?(n=-e.x1,i=-e.x2,o=-e.x1,a=-e.x2):this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.$?(n=e.x1,i=e.x2,o=e.x1,a=e.x2):(n=e.y1,i=e.y2,o=e.y1,a=e.y2);var r=e;this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Z?r=this.rotateData90Degrees(r,true):this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.$&&(r=this.rotateData90Degrees(r,false));var s=this.canvasLayout.linkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.J?this.getElbowPathInfo(r,t,n,i,o,a):this.getCurvePathInfo(r,t,n,i,o,a);return this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Z?(s.elements=this.rotateElements90Degrees(s.elements,false),s.centerPoint=this.rotatePoint90Degrees(s.centerPoint.x,s.centerPoint.y,false)):this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.$&&(s.elements=this.rotateElements90Degrees(s.elements,true),s.centerPoint=this.rotatePoint90Degrees(s.centerPoint.x,s.centerPoint.y,true)),s.path=this.createPath(s.elements),s}},{key:"getCurvePathInfo",value:function(e,t,n,i,o,a){var r={x:0,y:0},s=e.x2-e.x1,l=[];if(l.push({p:"M",x:e.x1,y:e.y1}),s>=t||a>n-this.canvasLayout.wrapAroundNodePadding&&i<o+this.canvasLayout.wrapAroundNodePadding&&e.x2>e.x1){var c=e.x1+(e.x2-e.x1)/2,u=e.y1,d=c,h=e.y2;l.push({p:"C",x:c,y:u,x2:d,y2:h,x3:e.x2,y3:e.y2}),r.x=c,r.y=u+(h-u)/2}else{var p=e.y2-e.y1,g=this.calculateMidY(e,n,o,i,a),f=Math.min(Math.abs(p)/2,-(s-t/2)),v=t-Math.max(s/2,0),y=e.x1+v,m=e.y1,k=y,b=e.y1+(g-e.y1)/2,C=e.x1+(e.x2-e.x1)/2,P=g,w=e.x1-f,L=g,x=e.x2+f,N=g,S=e.x2-v,D=g,T=S,E=g+(e.y2-g)/2;w>x?(l.push({p:"Q",x:y,y:m,x2:k,y2:b},{p:"T",x:w,y:L},{p:"L",x:x,y:N},{p:"Q",x:S,y:D,x2:T,y2:E},{p:"T",x:e.x2,y:e.y2}),r.x=w+(x-w)/2,r.y=L):(l.push({p:"Q",x:y,y:m,x2:k,y2:b},{p:"T",x:C,y:P},{p:"Q",x:S,y:D,x2:T,y2:E},{p:"T",x:e.x2,y:e.y2}),r.x=C,r.y=P)}return{elements:l,centerPoint:r}}},{key:"getElbowPathInfo",value:function(e,t,n,i,o,a){var r,s=e.trgNode?e.trgNode.layout.minFinalLine:30,l={x:0,y:0},c=e.x1+t,u=e.y1,d=c,h=e.y2,p=e.x2-e.x1,g=e.y2-e.y1;r=p>0&&g<4*this.canvasLayout.elbowSize&&g>-4*this.canvasLayout.elbowSize?p<t+s?g/4:g/2:g>=0?this.canvasLayout.elbowSize:-this.canvasLayout.elbowSize;var f=this.canvasLayout.elbowSize,v=!1;p<t+s&&(v=!0,d=e.x2-s,f=Math.min(this.canvasLayout.elbowSize,-(p-(t+s))/2));var y=[];if(y.push({p:"M",x:e.x1,y:e.y1},{p:"L",x:c-this.canvasLayout.elbowSize,y:u},{p:"Q",x:c,y:u,x2:c,y2:u+r}),!1===v)y.push({p:"L",x:d,y:h-r}),l.x=d,l.y=h;else{var m,k,b=p<0?this.calculateMidY(e,n,o,i,a):h-(h-u)/2;b<i&&b<n||b>a&&b>o?(m=b-r,k=h+r):(m=b+r,k=h-r),y.push({p:"L",x:c,y:b-r},{p:"Q",x:c,y:b,x2:c-f,y2:b},{p:"L",x:d+f,y:b},{p:"Q",x:d,y:b,x2:d,y2:m},{p:"L",x:d,y:k}),l.x=c,l.y=b}return y.push({p:"Q",x:d,y:h,x2:d+this.canvasLayout.elbowSize,y2:h},{p:"L",x:e.x2,y:e.y2}),{elements:y,centerPoint:l}}},{key:"calculateMidY",value:function(e,t,n,i,o){return i>=n+this.canvasLayout.wrapAroundNodePadding?n+(i-n)/2:o<=t-this.canvasLayout.wrapAroundNodePadding?o+(t-o)/2:e.y1>e.y2?Math.min(t,i)-this.canvasLayout.wrapAroundSpacing:Math.max(n,o)+this.canvasLayout.wrapAroundSpacing}},{key:"rotateData90Degrees",value:function(e,t){var n=this.rotatePoint90Degrees(e.x1,e.y1,t),i=this.rotatePoint90Degrees(e.x2,e.y2,t);return{x1:n.x,y1:n.y,x2:i.x,y2:i.y}}},{key:"rotateElements90Degrees",value:function(e,t){var n,i=this;return e.forEach((function(e){n=i.rotatePoint90Degrees(e.x,e.y,t),e.x=n.x,e.y=n.y,"Q"!==e.p&&"C"!==e.p||(n=i.rotatePoint90Degrees(e.x2,e.y2,t),e.x2=n.x,e.y2=n.y,"C"===e.p&&(n=i.rotatePoint90Degrees(e.x3,e.y3,t),e.x3=n.x,e.y3=n.y))})),e}},{key:"rotatePoint90Degrees",value:function(e,t,n){return n?{x:t,y:-e}:{x:-t,y:e}}},{key:"createPath",value:function(e){var t=e.length-1,n="";return e.forEach((function(e,i){"M"===e.p?n+="M "+e.x+" "+e.y:"L"===e.p?n+="L "+e.x+" "+e.y:"T"===e.p?n+="T "+e.x+" "+e.y:"Q"===e.p?n+="Q "+e.x+" "+e.y+" "+e.x2+" "+e.y2:"C"===e.p&&(n+="C "+e.x+" "+e.y+" "+e.x2+" "+e.y2+" "+e.x3+" "+e.y3),i<t&&(n+=" ")})),n}},{key:"getStraightPath",value:function(e){var t="M "+e.x1+" "+e.y1+" L "+e.x2+" "+e.y2,n=e.x2-e.x1,i=e.y2-e.y1,o={x:e.x1+n/2,y:e.y1+i/2},a=Math.atan(i/n);return n<0&&(a=ks+a),{path:t,centerPoint:o,angle:a}}},{key:"getAssociationCurvePath",value:function(e,t){return e.assocLinkVariation===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a1?this.getCurveLeftPath(e,t):e.assocLinkVariation===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a2?this.getDoubleBackLeft(e,t):e.assocLinkVariation===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a3?this.getDoubleBackRight(e,t):this.getCurveRightPath(e,t)}},{key:"getCurveLeftPath",value:function(e,t){var n=e.x1-(e.x1-e.x2)/2;return this.getCurveOutPath(e,t,n)}},{key:"getCurveRightPath",value:function(e,t){var n=e.x1+(e.x2-e.x1)/2;return this.getCurveOutPath(e,t,n)}},{key:"getCurveOutPath",value:function(e,t,n){var i=e.y1,o=n,a=e.y2;return{path:"M "+e.x1+" "+e.y1+" C "+n+" "+i+" "+o+" "+a+" "+e.x2+" "+e.y2,centerPoint:{x:n,y:i+(a-i)/2}}}},{key:"getDoubleBackLeft",value:function(e,t){var n=Math.min(e.x1,e.x2)-t-100;return this.getDoubleBack(e,t,n)}},{key:"getDoubleBackRight",value:function(e,t){var n=Math.max(e.x1,e.x2)+t+100;return this.getDoubleBack(e,t,n)}},{key:"getDoubleBack",value:function(e,t,n){var i=e.y1,o=n,a=e.y2;return{path:"M "+e.x1+" "+e.y1+" C "+n+" "+i+" "+o+" "+a+" "+e.x2+" "+e.y2,centerPoint:{x:this.calcCenterPoint(e.x1,n,o,e.x2),y:this.calcCenterPoint(e.y1,i,a,e.y2)}}}},{key:"calcCenterPoint",value:function(e,t,n,i){var o=.5;return Math.pow(.5,3)*e+3*Math.pow(.5,2)*o*t+3*Math.pow(.5,2)*o*n+Math.pow(o,3)*i}}]),n}(),Cs=function(){function n(t){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,n),this.canvasLayout=t}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(n,[{key:"getDec",value:function(e,t){return t?t.find((function(t){return t.id===e})):null}},{key:"getDecLabelForeignClass",value:function(e){return"d3-foreign-object"+(e.label_outline?" d3-node-label-outline":"")}},{key:"getDecLabelClass",value:function(e,t){var n=e.label_single_line?" d3-label-single-line":" d3-label-multi-line",i="center"===e.label_align?" d3-label-center":"";return this.getDecClass(e,"d3-".concat(t,"-dec-label"))+n+i}},{key:"getDecLabelTextAreaClass",value:function(e){return"d3-dec-label-entry"+(e.label_single_line?" d3-label-single-line":" d3-label-multi-line")+("center"===e.label_align?" d3-label-center":"")}},{key:"getDecTransform",value:function(e,t,n){return"translate(".concat(this.getDecPosX(e,t,n),", ").concat(this.getDecPosY(e,t,n),")")}},{key:"getDecPosX",value:function(e,t,n){return n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a4?this.getLinkDecPosX(e,t,n):this.getNodeDecPosX(e,t)}},{key:"getNodeDecPosX",value:function(e,t){var n=e.position||"topLeft",i=0;return"topLeft"===n||"middleLeft"===n||"bottomLeft"===n?i=void 0!==e.x_pos?Number(e.x_pos):t.layout.decoratorLeftX:"topCenter"===n||"middleCenter"===n||"bottomCenter"===n?i=t.width/2+(void 0!==e.x_pos?Number(e.x_pos):t.layout.decoratorCenterX):"topRight"!==n&&"middleRight"!==n&&"bottomRight"!==n||(i=t.width+(void 0!==e.x_pos?Number(e.x_pos):t.layout.decoratorRightX)),i}},{key:"getLinkDecPosX",value:function(e,t,n){var i=e.position||"middle",o=0;return"middle"===i?o=t.pathInfo.centerPoint?t.pathInfo.centerPoint.x:t.x1+(t.x2-t.x1)/2:"source"===i?o=t.pathInfo.sourcePoint?t.pathInfo.sourcePoint.x:t.x1:"target"===i&&(o=t.pathInfo.targetPoint?t.pathInfo.targetPoint.x:t.x2),o=void 0!==e.x_pos?o+Number(e.x_pos):o,e.distance&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(t,"pathInfo.angle")&&(o+=Math.cos(t.pathInfo.angle)*e.distance),"center"===e.label_align&&(o-=this.getDecWidth(e,t,n)/2),o}},{key:"getDecPosY",value:function(e,t,n){return n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a4?this.getLinkDecPosY(e,t):this.getNodeDecPosY(e,t)}},{key:"getNodeDecPosY",value:function(e,t){var n=e.position||"topLeft",i=0;return"topLeft"===n||"topCenter"===n||"topRight"===n?i=void 0!==e.y_pos?Number(e.y_pos):t.layout.decoratorTopY:"middleLeft"===n||"middleCenter"===n||"middleRight"===n?i=t.height/2+(void 0!==e.y_pos?Number(e.y_pos):t.layout.decoratorMiddleY):"bottomLeft"!==n&&"bottomCenter"!==n&&"bottomRight"!==n||(i=t.height+(void 0!==e.y_pos?Number(e.y_pos):t.layout.decoratorBottomY)),i}},{key:"getLinkDecPosY",value:function(e,t){var n=e.position||"middle",i=0;return"middle"===n?i=t.pathInfo.centerPoint?t.pathInfo.centerPoint.y:t.y1+(t.y2-t.y1)/2:"source"===n?i=t.pathInfo.sourcePoint?t.pathInfo.sourcePoint.y:t.y1:"target"===n&&(i=t.pathInfo.targetPoint?t.pathInfo.targetPoint.y:t.y2),i=void 0!==e.y_pos?i+Number(e.y_pos):i,e.distance&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(t,"pathInfo.angle")&&(i+=Math.sin(t.pathInfo.angle)*e.distance),i}},{key:"getDecPadding",value:function(e,t,n){return!1===e.outline?0:n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a4?this.canvasLayout.linkDecoratorPadding:t.layout.decoratorPadding}},{key:"getDecWidth",value:function(e,t,n){return void 0!==e.width?Number(e.width):n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a4?this.canvasLayout.linkDecoratorWidth:t.layout.decoratorWidth}},{key:"getDecHeight",value:function(e,t,n){return void 0!==e.height?Number(e.height):n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a4?this.canvasLayout.linkDecoratorHeight:t.layout.decoratorHeight}},{key:"getDecClass",value:function(e,t){var n=t;return e&&e.class_name&&(n+=" "+e.class_name),n}},{key:"getDecImage",value:function(e){return e?e.image:""}},{key:"getDecLabelEditIconTranslate",value:function(e,t,n,i,o){return"translate(".concat(this.getDecLabelEditIconPosX(e,t,n,i,o),", ").concat(this.getDecLabelEditIconPosY(e),")")}},{key:"getDecLabelEditIconPosX",value:function(e,t,n,i,o){return"center"===e.label_align?this.getDecLabelWidth(e,t,n)/2+i.getBoundingClientRect().width/2/o:i.getBoundingClientRect().width/o}},{key:"getDecLabelEditIconPosY",value:function(e){return 0}},{key:"getDecLabelWidth",value:function(e,t,n){return void 0!==e.width?Number(e.width):n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a4?this.canvasLayout.linkDecoratorLabelWidth:t.layout.decoratorLabelWidth}},{key:"getDecLabelHeight",value:function(e,t,n){return void 0!==e.height?Number(e.height):n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a4?this.canvasLayout.linkDecoratorLabelHeight:t.layout.decoratorLabelHeight}},{key:"getDecLabelTextAreaWidth",value:function(e,t,n){return this.getDecLabelWidth(e,t,n)+2*_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.F}},{key:"getDecLabelTextAreaHeight",value:function(e,t,n){return this.getDecLabelHeight(e,t,n)+2*_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.F}},{key:"getDecLabelTextAreaPosX",value:function(){return-_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.F}},{key:"getDecLabelTextAreaPosY",value:function(){return-(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.F-1)}}]),n}(),Ps=function(){function n(t,i){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,n),this.logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_12__.L("SVGCanvasActivePipeline"),this.logger.logStartTimer("constructor"),this.canvasInfo=i,this.pipeline=this.getPipeline(t,i),this.id=this.pipeline.id,this.zoom=this.pipeline.zoom,this.nodes=this.pipeline.nodes,this.comments=this.pipeline.comments,this.links=this.pipeline.links,this.mappedNodes=this.getMappedArray(this.pipeline.nodes),this.mappedComments=this.getMappedArray(this.pipeline.comments),this.mappedLinks=this.getMappedArray(this.pipeline.links),this.pipeline=this.preProcessPipeline(this.pipeline),this.logger.logEndTimer("constructor")}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(n,[{key:"getCanvasDimensions",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getCanvasDimensions(this.pipeline.nodes,this.pipeline.comments,this.pipeline.links,e)}},{key:"getObjectTypeName",value:function(e){return this.getComment(e.id)?"comment":this.getNode(e.id)?"node":"link"}},{key:"getNode",value:function(e){var t=this.mappedNodes[e];return void 0===t?null:t}},{key:"getNodes",value:function(e){var t=this,n=[];return e.forEach((function(e){var i=t.getNode(e);i&&n.push(i)})),n}},{key:"getSupernodes",value:function(){return this.pipeline.nodes.filter((function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSupernode(e)}))}},{key:"isEmptyOrBindingsOnly",value:function(){return((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(this.pipeline.nodes)||this.containsOnlyBindingNodes())&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(this.pipeline.comments)}},{key:"containsOnlyBindingNodes",value:function(){return!this.pipeline.nodes.find((function(e){return!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSuperBindingNode(e)}))}},{key:"getComment",value:function(e){var t=this.mappedComments[e];return void 0===t?null:t}},{key:"getNodesAndComments",value:function(){return this.pipeline.nodes.concat(this.pipeline.comments)}},{key:"getNodeOrComment",value:function(e){var t=this.getNode(e);return null===t&&(t=this.getComment(e)),t}},{key:"getLink",value:function(e){var t=this.mappedLinks[e];return void 0===t?null:t}},{key:"replaceLink",value:function(e){var t=this.pipeline.links.findIndex((function(t){return t.id===e.id}));this.pipeline.links.splice(t,1,e),this.mappedLinks=this.getMappedArray(this.pipeline.links)}},{key:"getPipeline",value:function(e,t){var n=t.pipelines.find((function(t){return t.id===e}));return n||{id:e,nodes:[],comments:[],links:[]}}},{key:"preProcessPipeline",value:function(e){var t=this;return this.setAllPortsDisconnected(e),e.links.forEach((function(e){e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O?(e.srcObj=t.getComment(e.srcNodeId),e.trgNode=t.getNode(e.trgNodeId)):(e.srcObj=t.getNode(e.srcNodeId),e.trgNode=t.getNode(e.trgNodeId),e.srcObj&&t.setOutputPortConnected(e.srcObj,e.srcNodePortId),e.trgNode&&t.setInputPortConnected(e.trgNode,e.trgNodePortId))})),e}},{key:"setAllPortsDisconnected",value:function(e){e.nodes.forEach((function(e){e.inputs&&e.inputs.forEach((function(e){return e.isConnected=!1})),e.outputs&&e.outputs.forEach((function(e){return e.isConnected=!1}))}))}},{key:"setInputPortConnected",value:function(e,t){var n=t||_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getDefaultInputPortId(e);e.inputs&&e.inputs.forEach((function(e){e.id===n&&(e.isConnected=!0)}))}},{key:"setOutputPortConnected",value:function(e,t){var n=t||_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getDefaultOutputPortId(e);e.outputs&&e.outputs.forEach((function(e){e.id===n&&(e.isConnected=!0)}))}},{key:"getMappedArray",value:function(e){return e.reduce((function(e,t){return e[t.id]=t,e}),{})}}]),n}(),ws=Object.assign({},lo,Io,Di,Qo,ps),Ls=function(){function n(t,i,o,a,r){var s=this,l=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{};(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,n),this.logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_12__.L(["SVGCanvasRenderer","PipeId",t]),this.logger.logStartTimer("constructor"+t.substring(0,5)),this.pipelineId=t,this.supernodeInfo=l,this.canvasDiv=i,this.canvasInfo=a,this.config=r,this.canvasController=o,this.objectModel=this.canvasController.getObjectModel(),this.activePipeline=new Ps(t,a),this.superRenderers=[],this.instanceId=this.canvasController.getInstanceId(),this.canvasLayout=this.objectModel.getCanvasLayout(),this.dispUtils=new gs(this.canvasController,this.supernodeInfo.d3Selection,this.pipelineId),this.nodeUtils=new ys(this.canvasLayout),this.commentUtils=new ms,this.linkUtils=new bs(this.config,this.canvasLayout,this.nodeUtils,this.commentUtils),this.decUtils=new Cs(this.canvasLayout),this.dispUtils.setDisplayState(),this.logger.log(this.dispUtils.getDisplayStateMsg()),this.initializeZoomVariables(),this.minScaleExtent=.2,this.maxScaleExtent=1.8,this.resizeObj=null,this.resizeObjInitialInfo=null,this.commentSizing=!1,this.commentSizingDirection="",this.nodeSizing=!1,this.nodeSizingDirection="",this.nodeSizingObjectsInfo=[],this.nodeSizingLinksInfo=[],this.notSnappedXPos=0,this.notSnappedYPos=0,this.notSnappedWidth=0,this.notSnappedHeight=0,this.editingText=!1,this.editingTextId="",this.dragging=!1,this.dragOffsetX=0,this.dragOffsetY=0,this.dragRunningX=0,this.dragRunningY=0,this.dragObjects=[],this.dragStartX=0,this.dragStartY=0,this.dragOverLink=null,this.dragOverDetachedLinks=[],this.dragPointerOffsetInNode=null,this.dragNewLinkOverNode=null,this.existingNodeInsertableIntoLink=!1,this.existingNodeAttachableToDetachedLinks=!1,this.selecting=!1,this.movingBindingNodes=!1,this.contextMenuClosedOnZoom=!1,this.regionSelect=!1,this.region={startX:0,startY:0,width:0,height:0},this.regionStartTransformX=0,this.regionStartTransformY=0,this.drawingNewLinkData=null,this.drag=ws.drag().on("start",this.dragStart.bind(this)).on("drag",this.dragMove.bind(this)).on("end",this.dragEnd.bind(this)),this.draggingLinkData=null,this.dragSelectionHandle=ws.drag().on("start",this.dragStartLinkHandle.bind(this)).on("drag",this.dragMoveLinkHandle.bind(this)).on("end",this.dragEndLinkHandle.bind(this)),this.zoom=ws.zoom().trackpad(this.config.enableInteractionType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a9).preventBackGesture(!0).wheelDelta((function(e){return-e.deltaY*(s.config.enableInteractionType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a9?.02:.002)})).scaleExtent([this.minScaleExtent,this.maxScaleExtent]).on("start",this.zoomStart.bind(this)).on("zoom",this.zoomAction.bind(this)).on("end",this.zoomEnd.bind(this)),this.initializeGhostDiv(),this.canvasSVG=this.createCanvasSVG(),this.canvasGrp=this.createCanvasGroup(this.canvasSVG,"d3-canvas-group"),this.canvasUnderlay=this.createCanvasUnderlay(this.canvasGrp,"d3-canvas-underlay"),this.commentsGrp=this.createCanvasGroup(this.canvasGrp,"d3-comments-group"),this.nodesLinksGrp=this.createCanvasGroup(this.canvasGrp,"d3-nodes-links-group"),this.boundingRectsGrp=this.createBoundingRectanglesGrp(this.canvasGrp,"d3-bounding-rect-group"),this.resetCanvasSVGBehaviors(),this.displayCanvas(),this.dispUtils.isDisplayingFullPage()&&this.restoreZoom(),(this.dispUtils.isDisplayingSubFlowFullPage()||this.canvasLayout.alwaysDisplayBackToParentFlow)&&this.addBackToParentFlowArrow(this.canvasSVG),this.dispUtils.isDisplayingSubFlowFullPage()&&!this.canvasController.getSavedZoom(this.pipelineId)&&this.zoomToFit(),this.dispUtils.isDisplayingSubFlowInPlace()&&(this.supernodeInfo.d3Selection.selectAll(".d3-node-port-input").raise(),this.supernodeInfo.d3Selection.selectAll(".d3-node-port-output").raise()),this.logger.logEndTimer("constructor"+t.substring(0,5))}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(n,[{key:"getParentSupernodeDatum",value:function(){var e=this,t=null;return this.canvasInfo.pipelines.forEach((function(n){n.id===e.supernodeInfo.pipelineId&&(t||(t=n.nodes.find((function(t){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSupernode(t)&&t.id===e.supernodeInfo.id}))))})),t}},{key:"getZoomTransform",value:function(){return this.zoomTransform}},{key:"initializeZoomVariables",value:function(){this.zoomTransform=ws.zoomIdentity.translate(0,0).scale(1),this.zoomStartPoint={x:0,y:0,k:0}}},{key:"setCanvasInfoRenderer",value:function(e){this.logger.logStartTimer("setCanvasInfoRenderer"+this.pipelineId.substring(0,5)),this.canvasInfo=e,this.activePipeline=new Ps(this.pipelineId,e),this.canvasLayout=this.objectModel.getCanvasLayout(),this.dispUtils.setDisplayState(),this.logger.log(this.dispUtils.getDisplayStateMsg()),this.resetCanvasSVGBehaviors(),this.resetCanvasCursor(),this.superRenderers=this.cleanUpSuperRenderers(),this.displayCanvas(),this.logger.logEndTimer("setCanvasInfoRenderer"+this.pipelineId.substring(0,5))}},{key:"cleanUpSuperRenderers",value:function(){var e=this,t=[];return this.activePipeline.getSupernodes().forEach((function(n){var i=e.getRendererForSupernode(n);i&&t.push(i),e.getDiscardedRenderersForSupernode(n).forEach((function(e){return e.canvasSVG.remove()}))})),t}},{key:"clearCanvas",value:function(){this.initializeZoomVariables(),this.canvasSVG.remove()}},{key:"refreshOnSizeChange",value:function(){if(this.logger.log("refreshOnSizeChange"),this.dispUtils.isDisplayingSubFlowFullPage()&&this.displayBindingNodesToFitSVG(),this.config.enableBoundingRectangles&&this.displayBoundingRectangles(),this.config.enablePositionNodeOnRightFlyoutOpen&&this.canvasController.isRightFlyoutOpen()){var e=this.config.enablePositionNodeOnRightFlyoutOpen,t=e.x?e.x:50,n=e.y?e.y:50,i=this.canvasController.getSelectedNodes().map((function(e){return e.id})),o=this.getZoomToReveal(i,t,n);this.zoomTo(o)}}},{key:"hideCanvas",value:function(){this.canvasSVG.style("display","none")}},{key:"displayCanvas",value:function(){this.logger.logStartTimer("displayCanvas"),this.canvasSVG.style("display","inherit"),this.displayComments(),this.displayNodes(),this.displayLinks(),this.dispUtils.isDisplayingSubFlowInPlace()&&this.displaySVGToFitSupernode(),this.dispUtils.isDisplayingSubFlowFullPage()&&this.displayPortsForSubFlowFullPage(),this.config.enableBoundingRectangles&&this.displayBoundingRectangles(),"None"!==this.config.enableCanvasUnderlay&&this.dispUtils.isDisplayingPrimaryFlowFullPage()&&this.setCanvasUnderlaySize(),this.logger.logEndTimer("displayCanvas")}},{key:"displayPortsForSubFlowFullPage",value:function(){this.setPortPositionsForNode(this.getParentSupernodeDatum()),this.displayBindingNodesToFitSVG()}},{key:"displaySVGToFitSupernode",value:function(){this.logger.log("displaySVGToFitSupernode - start");var e=this.getParentSupernodeSVGDimensions();this.canvasSVG.attr("width",e.width),this.canvasSVG.attr("height",e.height),this.canvasSVG.attr("x",e.x),this.canvasSVG.attr("y",e.y);var t=this.canvasSVG.selectChildren(".d3-svg-background");t.attr("width",e.width),t.attr("height",e.height),this.zoomToFit(),this.displayBindingNodesToFitSVG(),this.logger.log("displaySVGToFitSupernode - end")}},{key:"displayBindingNodesToFitSVG",value:function(){this.logger.log("displayBindingNodesToFitSVG - start"),this.setPortPositionsAllNodes(),this.moveSuperBindingNodes(),this.movingBindingNodes=!0,this.displayNodes(),this.displayLinks(),this.movingBindingNodes=!1,this.logger.log("displayBindingNodesToFitSVG - end")}},{key:"getParentSupernodeSVGDimensions",value:function(){var e=this.getParentSupernodeDatum();return{width:e.width-2*this.canvasLayout.supernodeSVGAreaPadding,height:e.height-this.canvasLayout.supernodeTopAreaHeight-this.canvasLayout.supernodeSVGAreaPadding,x:this.canvasLayout.supernodeSVGAreaPadding,y:this.canvasLayout.supernodeTopAreaHeight,x_pos:e.x_pos+this.canvasLayout.supernodeSVGAreaPadding,y_pos:e.y_pos+this.canvasLayout.supernodeTopAreaHeight}}},{key:"moveSuperBindingNodes",value:function(){var e=this,t=this.getTransformedViewportDimensions(),n=this.getParentSupernodeDatum();if(this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Z||this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.$){var i=n.width-2*this.canvasLayout.supernodeSVGAreaPadding;this.activePipeline.nodes.forEach((function(o){if(o.isSupernodeInputBinding){var a=e.nodeUtils.getSupernodePortXOffset(o.id,n.inputs);o.x_pos=t.width*(a/i)+t.x-o.outputs[0].cx,o.y_pos=e.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Z?t.y-o.height:t.y+t.height}if(o.isSupernodeOutputBinding){var r=e.nodeUtils.getSupernodePortXOffset(o.id,n.outputs);o.x_pos=t.width*(r/i)+t.x-o.inputs[0].cx,o.y_pos=e.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Z?o.y_pos=t.y+t.height:o.y_pos=t.y-o.height}}))}else{var o,a;_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpanded(n)?(o=this.canvasLayout.supernodeTopAreaHeight,a=n.height-(this.canvasLayout.supernodeTopAreaHeight+this.canvasLayout.supernodeSVGAreaPadding)):(o=0,a=n.height),this.activePipeline.nodes.forEach((function(i){if(i.isSupernodeInputBinding){i.x_pos=t.x-i.width;var r=e.nodeUtils.getSupernodePortYOffset(i.id,n.inputs)-o;i.y_pos=t.height*(r/a)+t.y-i.outputs[0].cy}if(i.isSupernodeOutputBinding){i.x_pos=t.x+t.width;var s=e.nodeUtils.getSupernodePortYOffset(i.id,n.outputs)-o;i.y_pos=t.height*(s/a)+t.y-i.inputs[0].cy}}))}}},{key:"displayBoundingRectangles",value:function(){if(this.activePipeline){var e=this.getViewportDimensions(),t=this.getTransformedRect(e,1),n=this.getCanvasDimensionsAdjustedForScale(1),i=this.getCanvasDimensionsAdjustedForScale(1,this.getZoomToFitPadding());this.boundingRectsGrp.selectChildren(".d3-bounding").remove();var o=this.boundingRectsGrp.append("g").attr("class","d3-bounding");o.append("rect").attr("height",e.height).attr("width",e.width).attr("x",0).attr("y",0).style("fill","none").style("stroke","darkorange"),o.append("rect").attr("height",t.height).attr("width",t.width-2).attr("x",t.x).attr("y",t.y).style("fill","none").style("stroke","red"),n&&o.append("rect").attr("height",n.height).attr("width",n.width).attr("x",n.left).attr("y",n.top).style("fill","none").style("stroke","blue"),i&&o.append("rect").attr("height",i.height).attr("width",i.width).attr("x",i.left).attr("y",i.top).style("fill","none").style("stroke","green"),this.config.enableBoundingRectangles&&this.superRenderers.length>0&&this.superRenderers.forEach((function(e){return e.displayBoundingRectangles()}))}}},{key:"isEditingText",value:function(){if(this.editingText)return!0;var e=!1;return this.superRenderers.forEach((function(t){e||(e=t.isEditingText())})),e}},{key:"isDragging",value:function(){return this.dragging}},{key:"isNodeResizable",value:function(e){return!(!this.config.enableEditingActions||_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSuperBindingNode(e)||_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isCollapsedSupernode(e)||!this.config.enableResizableNodes&&!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e))}},{key:"shouldDisplayNodeSizingArea",value:function(e){return!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSuperBindingNode(e)&&(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSupernode(e)||this.config.enableResizableNodes)}},{key:"getAllNodeGroupsSelection",value:function(){return this.nodesLinksGrp.selectChildren(".d3-node-group")}},{key:"getAllLinkGroupsSelection",value:function(){return this.nodesLinksGrp.selectChildren(".d3-link-group")}},{key:"getAllCommentGroupsSelection",value:function(){return this.commentsGrp.selectChildren(".d3-comment-group")}},{key:"getNodeGroupSelectionById",value:function(e){var t=this.getSelectorForId("node_grp",e);return this.nodesLinksGrp.selectChildren(t)}},{key:"getLinkGroupSelectionById",value:function(e){var t=this.getSelectorForId("link_grp",e);return this.nodesLinksGrp.selectChildren(t)}},{key:"getSelectorForId",value:function(e,t,n){return"[data-id='".concat(this.getId(e,t,n),"']")}},{key:"getId",value:function(e,t,n){var i="".concat(e,"_").concat(this.instanceId);return t&&(i+="_".concat(t)),n&&(i+="_".concat(n)),i}},{key:"getMousePosSnapToGrid",value:function(e){var t=e;return this.config.enableSnapToGridType!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a5&&this.config.enableSnapToGridType!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a6||(t=this.snapToGridPosition(t)),t}},{key:"snapToGridObject",value:function(e){var t=e;return t.x_pos=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.snapToGrid(t.x_pos,this.canvasLayout.snapToGridXPx),t.y_pos=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.snapToGrid(t.y_pos,this.canvasLayout.snapToGridYPx),t.width=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.snapToGrid(t.width,this.canvasLayout.snapToGridXPx),t.height=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.snapToGrid(t.height,this.canvasLayout.snapToGridYPx),t}},{key:"getTransformedMousePos",value:function(e){return this.transformPos(this.getMousePos(e,this.canvasSVG))}},{key:"getMousePos",value:function(e,t){var n=ws.pointer(e,t.node());return{x:n[0],y:n[1]}}},{key:"convertPageCoordsToCanvasCoords",value:function(e,t){var n=this.canvasSVG.node().getBoundingClientRect();return this.transformPos({x:e-Math.round(n.left),y:t-Math.round(n.top)})}},{key:"transformPos",value:function(e){return{x:(e.x-this.zoomTransform.x)/this.zoomTransform.k,y:(e.y-this.zoomTransform.y)/this.zoomTransform.k}}},{key:"getTransformedRect",value:function(e,t){var n=t/this.zoomTransform.k;return{x:-this.zoomTransform.x/this.zoomTransform.k+n,y:-this.zoomTransform.y/this.zoomTransform.k+n,height:e.height/this.zoomTransform.k-2*n,width:e.width/this.zoomTransform.k-2*n}}},{key:"initializeGhostDiv",value:function(){this.dispUtils.isDisplayingFullPage()&&this.getGhostDivSel().empty()&&this.canvasDiv.append("div").attr("class","d3-ghost-div")}},{key:"getGhostDivSel",value:function(){return this.canvasDiv.selectAll(".d3-ghost-div")}},{key:"getGhostNode",value:function(e){var t=this,n=this.getGhostDimensions(),i=this.canvasController.convertNodeTemplate(e);i.layout=this.canvasController.getObjectModel().getNodeLayout(),i.is_expanded?(i.width=i.expanded_width,i.height=i.expanded_height):i.isResized?(i.width=i.resizeWidth,i.height=i.resizeHeight):(i.width=n.width,i.height=n.height);var o=this.getNodeImage(i),a=this.getImageType(o),r=this.getGhostDivSel(),s=this.objectModel.getNodeLayout(),l=Math.max(s.labelWidth,i.width);r.selectAll(".d3-ghost-svg").remove();var c=r.append("svg").attr("width",l*this.zoomTransform.k).attr("height",(50+i.height)*this.zoomTransform.k).attr("x",0).attr("y",0).attr("class","d3-ghost-svg").append("g").attr("class","d3-node-group");c.append("rect").attr("class","d3-ghost-node").attr("x",0).attr("y",0).attr("width",i.width).attr("height",i.height),c.append(a).attr("class","d3-node-image").each((function(){t.setNodeImageContent(this,i)})).attr("x",this.nodeUtils.getNodeImagePosX(i)).attr("y",this.nodeUtils.getNodeImagePosY(i)).attr("width",this.nodeUtils.getNodeImageWidth(i)).attr("height",this.nodeUtils.getNodeImageHeight(i));var u=c.append("foreignObject").attr("x",this.nodeUtils.getNodeLabelPosX(i)).attr("y",this.nodeUtils.getNodeLabelPosY(i)).attr("width",this.nodeUtils.getNodeLabelWidth(i)).attr("height",this.nodeUtils.getNodeLabelHeight(i)).attr("class",this.nodeUtils.getNodeLabelForeignClass(i)),d=u.append("xhtml:div").attr("class",this.nodeUtils.getNodeLabelClass(i)),h=d.append("xhtml:span").html(i.label).node().getBoundingClientRect().width+4,p=this.nodeUtils.getNodeLabelWidth(i),g=Math.min(p,h),f=Math.max(0,(g-n.width)/2)*this.zoomTransform.k;if(c.attr("transform","translate(".concat(f,", 0) scale(").concat(this.zoomTransform.k,")")),"center"===i.layout.labelAlign){var v=Math.max(0,(p-g)/2);u.attr("width",g).attr("x",this.nodeUtils.getNodeLabelPosX(i)+v),d.attr("width",g)}var y=this.getBrowserZoom(),m=(f+n.width/2*this.zoomTransform.k)*y,k=n.height/2*this.zoomTransform.k*y;return{element:r.node(),centerX:m,centerY:k}}},{key:"getBrowserZoom",value:function(){var e=window.devicePixelRatio;return navigator.userAgent.includes("Chrome")?e=window.devicePixelRatio:navigator.userAgent.includes("Safari")?e=(window.outerWidth-8)/window.innerWidth:navigator.userAgent.includes("Firefox")&&(e=window.devicePixelRatio/2),e}},{key:"getGhostDimensions",value:function(){var e=this.objectModel.getNodeLayout();return{width:e.defaultNodeWidth,height:e.defaultNodeHeight}}},{key:"nodeTemplateDragStart",value:function(e){this.isNodeTemplateInsertableIntoLink(e)&&this.setDataLinkSelectionAreaWider(!0)}},{key:"nodeTemplateDragEnd",value:function(e){this.isNodeTemplateInsertableIntoLink(e)&&this.setDataLinkSelectionAreaWider(!1)}},{key:"nodeTemplateDragOver",value:function(e,t,n){if(this.isNodeTemplateInsertableIntoLink(e)){var i=this.getLinkAtMousePos(t,n);i&&!this.isLinkFullyAttached(i)||this.setInsertNodeIntoLinkHighlighting(i)}if(this.isNodeTemplateAttachableToDetachedLinks(e)){var o=this.convertPageCoordsToCanvasCoords(t,n),a=this.getGhostDimensions(),r={x1:o.x-a.width/2,y1:o.y-a.height/2,x2:o.x+a.width/2,y2:o.y+a.height/2},s=this.canvasController.convertNodeTemplate(e),l=this.getAttachableLinksForNodeAtPos(s,r);this.setDetachedLinkHighlighting(l)}"None"!==this.config.enableCanvasUnderlay&&this.dispUtils.isDisplayingPrimaryFlowFullPage()&&this.setCanvasUnderlaySize(t,n)}},{key:"setInsertNodeIntoLinkHighlighting",value:function(e){e?this.dragOverLink?e.id!==this.dragOverLink.id&&(this.unsetInsertNodeIntoLinkHighlighting(),this.dragOverLink=e,this.setNodeDragOverLinkHighlighting(this.dragOverLink,!0)):(this.dragOverLink=e,this.setNodeDragOverLinkHighlighting(this.dragOverLink,!0)):this.unsetInsertNodeIntoLinkHighlighting()}},{key:"unsetInsertNodeIntoLinkHighlighting",value:function(e){this.dragOverLink&&(this.setNodeDragOverLinkHighlighting(this.dragOverLink,!1),this.dragOverLink=null)}},{key:"setDetachedLinkHighlighting",value:function(e){var t=this;e&&e.length>0?(this.unsetDetachedLinkHighlighting(),this.dragOverDetachedLinks=e,this.dragOverDetachedLinks.forEach((function(e){return t.setNodeDragOverLinkHighlighting(e,!0)}))):this.dragOverDetachedLinks.length>0&&this.unsetDetachedLinkHighlighting()}},{key:"unsetDetachedLinkHighlighting",value:function(){var e=this;this.dragOverDetachedLinks.forEach((function(t){return e.setNodeDragOverLinkHighlighting(t,!1)})),this.dragOverDetachedLinks=[]}},{key:"setNodeDragOverLinkHighlighting",value:function(e,t){this.getLinkGroupSelectionById(e.id).attr("data-drag-node-over",!!t||null)}},{key:"setNewLinkOverNode",value:function(e){var t=this.getNodeNearMousePos(e,this.canvasLayout.nodeProximity);t&&this.isConnectionAllowedToNearbyNode(e,t)?this.dragNewLinkOverNode?t.id!==this.dragNewLinkOverNode.id&&(this.setNewLinkOverNodeHighlighting(this.dragNewLinkOverNode,!1),this.dragNewLinkOverNode=t,this.setNewLinkOverNodeHighlighting(this.dragNewLinkOverNode,!0)):(this.dragNewLinkOverNode=t,this.setNewLinkOverNodeHighlighting(this.dragNewLinkOverNode,!0)):this.dragNewLinkOverNode&&(this.setNewLinkOverNodeHighlighting(this.dragNewLinkOverNode,!1),this.dragNewLinkOverNode=null)}},{key:"isConnectionAllowedToNearbyNode",value:function(e,t){if(this.drawingNewLinkData){if(this.drawingNewLinkData.action===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H){var n=this.drawingNewLinkData.srcNode,i=t,o=this.drawingNewLinkData.srcNodePortId,a=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getDefaultInputPortId(i);return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isDataConnectionAllowed(o,a,n,i,this.activePipeline.links)}if(this.drawingNewLinkData.action===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K){var r=this.drawingNewLinkData.srcNode,s=t;return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isAssocConnectionAllowed(r,s,this.activePipeline.links)}if(this.drawingNewLinkData.action===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O){var l=this.drawingNewLinkData.srcObjId,c=t.id;return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isCommentLinkConnectionAllowed(l,c,this.activePipeline.links)}}else if(this.draggingLinkData){if(this.getNewLinkOnDrag(e,this.canvasLayout.nodeProximity))return!0}return!1}},{key:"setNewLinkOverNodeHighlighting",value:function(e,t){e&&this.getNodeGroupSelectionById(e.id).attr("data-new-link-over",t?"yes":"no")}},{key:"setNewLinkOverNodeCancel",value:function(){this.setNewLinkOverNodeHighlighting(this.dragNewLinkOverNode,!1),this.dragNewLinkOverNode=null}},{key:"nodeTemplateDropped",value:function(e,t,n){if(null!==e){var i=this.transformMousePosForNode(t,n);this.dragOverLink?(this.canvasController.createNodeFromTemplateOnLinkAt(e,this.dragOverLink,i,this.pipelineId),this.unsetInsertNodeIntoLinkHighlighting()):this.dragOverDetachedLinks.length>0?(this.canvasController.createNodeFromTemplateAttachLinks(e,this.dragOverDetachedLinks,i,this.pipelineId),this.unsetDetachedLinkHighlighting()):this.canvasController.createNodeFromTemplateAt(e,i,this.pipelineId)}}},{key:"externalObjectDropped",value:function(e,t,n){if(null!==e){var i=this.transformMousePosForNode(t,n);this.canvasController.createDroppedExternalObject(e,i,this.pipelineId)}}},{key:"transformMousePosForNode",value:function(e,t){var n=this.convertPageCoordsToCanvasCoords(e,t),i=this.getGhostDimensions();return n.x-=i.width/2,n.y-=i.height/2,this.getMousePosSnapToGrid(n)}},{key:"isNodeTemplateInsertableIntoLink",value:function(e){return this.config.enableInsertNodeDroppedOnLink&&_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.hasInputAndOutputPorts(e)&&!this.isPortMaxCardinalityZero(e.inputs[0])&&!this.isPortMaxCardinalityZero(e.outputs[0])}},{key:"isExistingNodeInsertableIntoLink",value:function(){return this.config.enableInsertNodeDroppedOnLink&&1===this.dragObjects.length&&_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isNode(this.dragObjects[0])&&_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.hasInputAndOutputPorts(this.dragObjects[0])&&!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isNodeDefaultPortsCardinalityAtMax(this.dragObjects[0],this.activePipeline.links)}},{key:"isExistingNodeAttachableToDetachedLinks",value:function(){return this.config.enableLinkSelection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a7&&1===this.dragObjects.length&&_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isNode(this.dragObjects[0])}},{key:"isNodeTemplateAttachableToDetachedLinks",value:function(e){return this.config.enableLinkSelection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a7}},{key:"getAttachableLinksForNodeAtPos",value:function(e,t){var n=this,i=e.inputs&&e.inputs.length>0,o=e.outputs&&e.outputs.length>0,a=this.activePipeline.links.filter((function(e){return e.srcPos&&o&&_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isPosInArea(e.srcPos,t,n.canvasLayout.ghostAreaPadding)?(e.nodeOverSrcPos=!0,!0):e.trgPos&&i&&_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isPosInArea(e.trgPos,t,n.canvasLayout.ghostAreaPadding)?(e.nodeOverTrgPos=!0,!0):(e.nodeOverSrcPos=!1,e.nodeOverTrgPos=!1,!1)}));a.length>0&&(a=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getDetachedLinksToUpdate(e,a,this.activePipeline.links).oldLinks);return a}},{key:"isLinkFullyAttached",value:function(e){return!!e&&(void 0!==e.srcNodeId&&void 0!==e.trgNodeId)}},{key:"getNodePort",value:function(e,t,n){var i=this.activePipeline.getNode(e);if(i){var o=("input"===n?i.inputs:i.outputs).find((function(e){return e.id===t}));return void 0===o?null:o}return null}},{key:"setMaxZoomExtent",value:function(e){if(this.dispUtils.isDisplayingFullPage()){var t=this.maxScaleExtent*e;this.zoom.scaleExtent([this.minScaleExtent,t])}else{var n=1*Number(e)/this.zoomTransform.k;this.supernodeInfo.renderer.setMaxZoomExtent(n)}}},{key:"createCanvasSVG",value:function(){var e=this;this.logger.log("Create Canvas SVG.");var t=this.canvasDiv,n={width:"100%",height:"100%",x:0,y:0};this.dispUtils.isDisplayingSubFlowInPlace()&&(t=this.supernodeInfo.d3Selection,n=this.getParentSupernodeSVGDimensions());var i=t.append("svg").attr("class","svg-area").attr("data-pipeline-id",this.activePipeline.id).attr("width",n.width).attr("height",n.height).attr("x",n.x).attr("y",n.y).on("mouseenter",(function(t,n){e.supernodeInfo.renderer&&e.config.enableZoomIntoSubFlows&&e.supernodeInfo.renderer.setMaxZoomExtent(1/e.zoomTransform.k)})).on("mouseleave",(function(t,n){e.supernodeInfo.renderer&&e.config.enableZoomIntoSubFlows&&e.supernodeInfo.renderer.setMaxZoomExtent(1)}));if(i.append("rect").attr("x",0).attr("y",0).attr("width",n.width).attr("height",n.height).attr("data-pipeline-id",this.activePipeline.id).attr("class","d3-svg-background").attr("pointer-events","all").style("cursor",this.getCanvasCursor()),this.dispUtils.isDisplayingFullPage()){var o=i.append("defs");this.createDropShadow(o)}return i}},{key:"resetCanvasSVGBehaviors",value:function(){var e=this;this.canvasSVG.on(".zoom",null),!this.activePipeline.isEmptyOrBindingsOnly()&&this.dispUtils.isDisplayingFullPage()&&this.canvasSVG.call(this.zoom),this.canvasSVG.on("mousemove.zoom",(function(t){e.drawingNewLinkData&&e.drawNewLink(t),e.draggingLinkData&&e.dragLinkHandle(t)})).on("mousedown",(function(t){e.logger.log("Canvas - mousedown"),e.dispUtils.isDisplayingSubFlowInPlace()&&t.button===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a8&&t.stopPropagation()})).on("mouseup.zoom",(function(t){e.logger.log("Canvas - mouseup-zoom"),e.drawingNewLinkData&&e.completeNewLink(t),e.draggingLinkData&&e.completeDraggedLink(t)})).on("click.zoom",(function(t){e.logger.log("Canvas - click-zoom"),e.selecting=!0,e.dispUtils.isDisplayingCurrentPipeline()&&!e.contextMenuClosedOnZoom&&e.canvasController.clearSelections(),e.contextMenuClosedOnZoom=!1,e.selecting=!1,e.canvasController.clickActionHandler({clickType:"contextmenu"===t.type?"SINGLE_CLICK_CONTEXTMENU":"SINGLE_CLICK",objectType:"canvas",selectedObjectIds:e.objectModel.getSelectedObjectIds()})})).on("dblclick.zoom",(function(){e.logger.log("Zoom - double click"),e.canvasController.clickActionHandler({clickType:"DOUBLE_CLICK",objectType:"canvas",selectedObjectIds:e.objectModel.getSelectedObjectIds()})})).on("contextmenu.zoom",(function(t,n){e.logger.log("Zoom - context menu"),e.openContextMenu(t,"canvas")}))}},{key:"resetCanvasCursor",value:function(){var e=".d3-svg-background[data-pipeline-id='"+this.activePipeline.id+"']";this.canvasSVG.select(e).style("cursor",this.getCanvasCursor())}},{key:"getCanvasCursor",value:function(){return this.dispUtils.isDisplayingFullPage()?this.config.enableInteractionType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a9||this.activePipeline.isEmptyOrBindingsOnly()?"default":"grab":"pointer"}},{key:"createCanvasGroup",value:function(e,t){return e.append("g").attr("class",t)}},{key:"createCanvasUnderlay",value:function(e,t){return"None"!==this.config.enableCanvasUnderlay&&this.dispUtils.isDisplayingPrimaryFlowFullPage()?e.append("rect").attr("class",t):null}},{key:"createBoundingRectanglesGrp",value:function(e,t){return this.config.enableBoundingRectangles?e.append("g").attr("class",t):null}},{key:"setCanvasUnderlaySize",value:function(){var e=this.getCanvasDimensionsAdjustedForScale(1,this.getZoomToFitPadding());e&&this.canvasUnderlay.attr("x",e.left-50).attr("y",e.top-50).attr("width",e.width+100).attr("height",e.height+100)}},{key:"addBackToParentFlowArrow",value:function(e){var t=this,n=e.append("g").attr("transform","translate(15, 15)").on("mouseenter",(function(e,t){ws.select(this).select("rect").attr("data-pointer-hover","yes")})).on("mouseleave",(function(e,t){ws.select(this).select("rect").attr("data-pointer-hover","no")})).on("click",(function(e){_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),t.canvasController.displayPreviousPipeline()}));n.append("rect").attr("x",0).attr("y",0).attr("width",210).attr("height",40).attr("class","d3-back-to-previous-flow-box"),n.append("svg").attr("x",16).attr("y",11).attr("width",16).attr("height",16).html(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aa).attr("class","d3-back-to-previous-flow-text"),n.append("text").attr("x",40).attr("y",24).attr("class","d3-back-to-previous-flow-text").text("Return to previous flow")}},{key:"createDropShadow",value:function(e){var t=e.append("filter").attr("id",this.getId("node_drop_shadow")).attr("x","-20%").attr("y","-20%").attr("width","200%").attr("height","200%");t.append("feOffset").attr("in","SourceAlpha").attr("dx",1).attr("dy",1).attr("result","offOut"),t.append("feGaussianBlur").attr("in","offOut").attr("stdDeviation","3").attr("result","blurOut"),t.append("feBlend").attr("in","SourceGraphic").attr("in2","blurOut").attr("mode","normal"),t.append("feComponentTransfer").append("feFuncA").attr("type","linear").attr("slope","0.2");var n=t.append("feMerge");n.append("feMergeNode"),n.append("feMergeNode").attr("in","SourceGraphic")}},{key:"restoreZoom",value:function(){var e=this.canvasController.getSavedZoom(this.pipelineId);if(!e&&this.config.enablePanIntoViewOnOpen){var t=this.getCanvasDimensionsAdjustedForScale(1,this.getZoomToFitPadding());t&&(e={x:-t.left,y:-t.top,k:1})}!e&&this.canvasLayout.initialPanX&&this.canvasLayout.initialPanY&&(e={x:this.canvasLayout.initialPanX,y:this.canvasLayout.initialPanY,k:1}),!e||e.k===this.zoomTransform.k&&e.x===this.zoomTransform.x&&e.y===this.zoomTransform.y||this.zoomCanvasInvokeZoomBehavior(e)}},{key:"zoomCanvasInvokeZoomBehavior",value:function(e,t){if(isFinite(e.x)&&isFinite(e.y)&&isFinite(e.k)){var n=ws.zoomIdentity.translate(e.x,e.y).scale(e.k);t?this.canvasSVG.call(this.zoom).transition().duration(t).call(this.zoom.transform,n):this.canvasSVG.call(this.zoom.transform,n)}}},{key:"zoomToFit",value:function(){var e=this.getZoomToFitPadding(),t=this.getCanvasDimensionsAdjustedForScale(1,e),n=this.getViewportDimensions();if(t){var i=n.width/t.width,o=n.height/t.height,a=Math.min(i,o,1),r=(n.width-t.width*a)/2,s=(n.height-t.height*a)/2;r-=a*t.left,s-=a*t.top,this.zoomingToFit=!0,this.zoomCanvasInvokeZoomBehavior({x:r,y:s,k:a}),this.zoomingToFit=!1}}},{key:"getZoomToFitPadding",value:function(){var e=this.canvasLayout.zoomToFitPadding;if(this.dispUtils.isDisplayingSubFlow()){var t=this.getMaxZoomToFitPaddingForConnections()+2*this.canvasLayout.supernodeBindingPortRadius;e=Math.max(e,t)}return e}},{key:"zoomTo",value:function(e){this.zoomCanvasInvokeZoomBehavior(e,500)}},{key:"getZoom",value:function(){return{x:this.zoomTransform.x,y:this.zoomTransform.y,k:this.zoomTransform.k}}},{key:"translateBy",value:function(e,t,n){var i=this.getZoomTransform(),o=ws.zoomIdentity.translate(i.x+e,i.y+t).scale(i.k);this.zoomCanvasInvokeZoomBehavior(o,n)}},{key:"zoomIn",value:function(){if(this.zoomTransform.k<this.maxScaleExtent){var e=Math.min(1.1*this.zoomTransform.k,this.maxScaleExtent);this.canvasSVG.call(this.zoom.scaleTo,e)}}},{key:"zoomOut",value:function(){if(this.zoomTransform.k>this.minScaleExtent){var e=Math.max(this.zoomTransform.k/1.1,this.minScaleExtent);this.canvasSVG.call(this.zoom.scaleTo,e)}}},{key:"isZoomedToMax",value:function(){return!!this.zoomTransform&&this.zoomTransform.k===this.maxScaleExtent}},{key:"isZoomedToMin",value:function(){return!!this.zoomTransform&&this.zoomTransform.k===this.minScaleExtent}},{key:"getZoomToReveal",value:function(e,t,n){var i,o,a=this.getTransformedViewportDimensions(),r=this.activePipeline.getNodes(e),s=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getCanvasDimensions(r,[],[],0),l=this.convertCanvasDimensionsAdjustedForScaleWithPadding(s,1,10),c=parseInt(t,10),u=void 0===n?c:parseInt(n,10);if(l&&(Number.isNaN(c)||Number.isNaN(u)?(l.right>a.x+a.width&&(i=a.x+a.width-l.right),l.left<a.x&&(i=a.x-l.left),l.bottom>a.y+a.height&&(o=a.y+a.height-l.bottom),l.top<a.y&&(o=a.y-l.top)):(i=a.x+a.width*(c/100)-(l.left+l.width/2),o=a.y+a.height*(u/100)-(l.top+l.height/2)),void 0!==i||void 0!==o))return{x:this.zoomTransform.x+(i||0)*this.zoomTransform.k||0,y:this.zoomTransform.y+(o||0)*this.zoomTransform.k||0,k:this.zoomTransform.k};return null}},{key:"getTransformedViewportDimensions",value:function(){var e=this.getViewportDimensions();return this.getTransformedRect(e,0)}},{key:"getViewportDimensions",value:function(){var e={};if(this.dispUtils.isDisplayingSubFlowInPlace()){var t=this.getParentSupernodeSVGDimensions();e.width=t.width,e.height=t.height}else e=this.canvasSVG&&this.canvasSVG.node()?this.canvasSVG.node().getBoundingClientRect():{x:0,y:0,width:1100,height:640};return e}},{key:"zoomStart",value:function(e){if(this.logger.log("zoomStart - "+JSON.stringify(e.transform)),this.canvasController.closeTip(),this.canvasController.isContextMenuDisplayed()&&!this.dispUtils.isDisplayingSubFlowInPlace()&&(this.canvasController.closeContextMenu(),this.contextMenuClosedOnZoom=!0),this.zoomingToFit?this.regionSelect=!1:this.config.enableInteractionType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a9&&e.sourceEvent&&1===e.sourceEvent.buttons||this.config.enableInteractionType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ab&&e.sourceEvent&&e.sourceEvent.shiftKey?this.regionSelect=!0:this.regionSelect=!1,this.regionSelect){this.regionStartTransformX=e.transform.x,this.regionStartTransformY=e.transform.y;var t=this.getTransformedMousePos(e);this.region={startX:t.x,startY:t.y,width:0,height:0}}var n=".d3-svg-background[data-pipeline-id='"+this.activePipeline.id+"']";this.regionSelect?this.canvasSVG.select(n).style("cursor","crosshair"):this.canvasSVG.select(n).style("cursor","grabbing"),this.zoomStartPoint={x:e.transform.x,y:e.transform.y,k:e.transform.k},this.previousD3Event={x:e.transform.x,y:e.transform.y,k:e.transform.k},this.zoomCanvasDimensions=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getCanvasDimensions(this.activePipeline.nodes,this.activePipeline.comments,this.activePipeline.links,this.canvasLayout.commentHighlightGap)}},{key:"zoomAction",value:function(e){this.logger.log("zoomAction - "+JSON.stringify(e.transform)),e.transform.k===this.zoomStartPoint.k?this.regionSelect?(this.addTempCursorOverlay("crosshair"),this.drawRegionSelector(e)):(this.addTempCursorOverlay("grabbing"),this.zoomCanvasBackground(e)):this.zoomCanvasBackground(e)}},{key:"zoomEnd",value:function(e){if(this.logger.log("zoomEnd - "+JSON.stringify(e.transform)),this.drawingNewLinkData&&(this.stopDrawingNewLink(),this.drawingNewLinkData=null),this.draggingLinkData&&(this.stopDraggingLink(),this.draggingLinkData=null),e.transform.k===this.zoomStartPoint.k&&!0===this.regionSelect){this.removeRegionSelector(),e.transform.x=this.regionStartTransformX,e.transform.y=this.regionStartTransformY;var t=this.getRegionDimensions(),n=t.startX,i=t.startY,o=t.width,a=t.height;this.isSelecting=!0,this.buildLinksArray();var r={x1:n,y1:i,x2:n+o,y2:i+a},s=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.selectInRegion(r,this.activePipeline,this.config.enableLinkSelection!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ac,this.config.enableLinkType,this.config.enableAssocLinkType);this.canvasController.setSelections(s,this.activePipeline.id),this.regionSelect=!1}else if(this.dispUtils.isDisplayingFullPage()){this.canvasSVG.property("__zoom",this.zoomTransform);var l={editType:"setZoom",editSource:"canvas",zoom:this.zoomTransform,pipelineId:this.activePipeline.id};this.canvasController.editActionHandler(l)}this.resetCanvasCursor(),this.removeTempCursorOverlay()}},{key:"zoomCanvasBackground",value:function(e){if(this.regionSelect=!1,this.dispUtils.isDisplayingPrimaryFlowFullPage()){var t=this.getTransformIncrement(e);this.zoomTransform=this.zoomConstrainRegular(t,this.getViewportDimensions(),this.zoomCanvasDimensions)}else this.zoomTransform=ws.zoomIdentity.translate(e.transform.x,e.transform.y).scale(e.transform.k);this.canvasGrp.attr("transform",this.zoomTransform),this.config.enableBoundingRectangles&&this.displayBoundingRectangles(),"None"!==this.config.enableCanvasUnderlay&&this.dispUtils.isDisplayingPrimaryFlowFullPage()&&this.setCanvasUnderlaySize(),this.dispUtils.isDisplayingSubFlowFullPage()&&this.displayPortsForSubFlowFullPage()}},{key:"getTransformIncrement",value:function(e){var t=e.transform.x-this.previousD3Event.x,n=e.transform.y-this.previousD3Event.y,i={x:this.zoomTransform.x+t,y:this.zoomTransform.y+n,k:e.transform.k};return this.previousD3Event={x:e.transform.x,y:e.transform.y,k:e.transform.k},i}},{key:"zoomConstrainRegular",value:function(e,t,n){if(!n)return this.zoomTransform;var i=e.k,o=e.x,a=e.y,r=this.convertCanvasDimensionsAdjustedForScaleWithPadding(n,i,this.getZoomToFitPadding()),s=t.width-Math.min(.25*t.width,.25*r.width),l=-Math.max(r.width-.25*t.width,.75*r.width),c=t.height-Math.min(.25*t.height,.25*r.height),u=-Math.max(r.height-.25*t.height,.75*r.height);return o>-r.left+s?o=-r.left+s:o<-r.left+l&&(o=-r.left+l),a>-r.top+c?a=-r.top+c:a<-r.top+u&&(a=-r.top+u),ws.zoomIdentity.translate(o,a).scale(i)}},{key:"getCanvasDimensionsAdjustedForScale",value:function(e,t){var n=this.canvasLayout.commentHighlightGap,i=this.activePipeline.getCanvasDimensions(n);return this.convertCanvasDimensionsAdjustedForScaleWithPadding(i,e,t)}},{key:"convertCanvasDimensionsAdjustedForScaleWithPadding",value:function(e,t,n){var i=n||0;return e?{left:e.left*t-i,top:e.top*t-i,right:e.right*t+i,bottom:e.bottom*t+i,width:e.width*t+2*i,height:e.height*t+2*i}:null}},{key:"drawRegionSelector",value:function(e){var t=this.getTransformedMousePos(e);this.region.width=t.x-this.region.startX,this.region.height=t.y-this.region.startY,this.removeRegionSelector();var n=this.getRegionDimensions(),i=n.startX,o=n.startY,a=n.width,r=n.height;this.canvasGrp.append("rect").attr("width",a).attr("height",r).attr("x",i).attr("y",o).attr("class","d3-region-selector")}},{key:"removeRegionSelector",value:function(){this.canvasGrp.selectAll(".d3-region-selector").remove()}},{key:"getRegionDimensions",value:function(){var e=this.region.startX,t=this.region.startY,n=this.region.width,i=this.region.height;return n<0&&(n=Math.abs(n),e=this.region.startX-n),i<0&&(i=Math.abs(i),t=this.region.startY-i),{startX:e,startY:t,width:n,height:i}}},{key:"initializeResizeVariables",value:function(e){this.resizeObjInitialInfo={x_pos:e.x_pos,y_pos:e.y_pos,width:e.width,height:e.height},this.notSnappedXPos=e.x_pos,this.notSnappedYPos=e.y_pos,this.notSnappedWidth=e.width,this.notSnappedHeight=e.height}},{key:"getDragObjects",value:function(e){var t=this.getSelectedNodesAndComments();return this.config.enableDragWithoutSelect&&-1===t.findIndex((function(t){return t.id===e.id}))?[e]:t}},{key:"dragStart",value:function(e,t){this.logger.logStartTimer("dragStart"),this.closeContextMenuIfOpen(),this.commentSizing?(this.resizeObj=this.activePipeline.getComment(t.id),this.initializeResizeVariables(this.resizeObj)):this.nodeSizing?(this.resizeObj=this.activePipeline.getNode(t.id),this.initializeResizeVariables(this.resizeObj)):this.dragObjectsStart(e,t),this.logger.logEndTimer("dragStart",!0)}},{key:"dragMove",value:function(e){this.logger.logStartTimer("dragMove"),this.commentSizing?this.resizeComment(e):this.nodeSizing?this.resizeNode(e):this.dragObjectsAction(e),this.logger.logEndTimer("dragMove",!0)}},{key:"dragEnd",value:function(e,t){this.logger.logStartTimer("dragEnd"),this.removeTempCursorOverlay(),this.commentSizing?this.endCommentSizing():this.nodeSizing?this.endNodeSizing():this.dragging&&this.dragObjectsEnd(e,t),this.logger.logEndTimer("dragEnd",!0)}},{key:"dragObjectsStart",value:function(e,t){if(this.existingNodeInsertableIntoLink=!1,this.existingNodeAttachableToDetachedLinks=!1,this.dragging=!0,this.dragOffsetX=0,this.dragOffsetY=0,this.dragRunningX=0,this.dragRunningY=0,this.dragObjects=this.getDragObjects(t),this.dragObjects&&this.dragObjects.length>0&&(this.dragStartX=this.dragObjects[0].x_pos,this.dragStartY=this.dragObjects[0].y_pos),this.isExistingNodeInsertableIntoLink()&&(this.existingNodeInsertableIntoLink=!0,this.setNodeTranslucentState(this.dragObjects[0].id,!0),this.setDataLinkSelectionAreaWider(!0)),this.isExistingNodeAttachableToDetachedLinks()){this.existingNodeAttachableToDetachedLinks=!0;var n=this.getTransformedMousePos(e);this.dragPointerOffsetInNode={x:n.x-this.dragObjects[0].x_pos,y:n.y-this.dragObjects[0].y_pos},this.setNodeTranslucentState(this.dragObjects[0].id,!0)}}},{key:"dragObjectsAction",value:function(e){if(this.dragOffsetX+=e.dx,this.dragOffsetY+=e.dy,this.dispUtils.isDisplayingSubFlowInPlace()&&(this.dragOffsetX>1e3||this.dragOffsetX<-1e3||this.dragOffsetY>1e3||this.dragOffsetY<-1e3))this.dragOffsetX-=e.dx,this.dragOffsetY-=e.dy;else{var t={x:0,y:0};if(this.config.enableSnapToGridType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a5){var n=this.snapToGridDraggedNode();t={x:n.x-this.dragObjects[0].x_pos,y:n.y-this.dragObjects[0].y_pos}}else t={x:e.dx,y:e.dy};this.dragRunningX+=t.x,this.dragRunningY+=t.y,this.dragObjects.forEach((function(e){e.x_pos+=t.x,e.y_pos+=t.y})),this.config.enableLinkSelection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a7&&this.getSelectedLinks().forEach((function(e){e.srcPos&&(e.srcPos.x_pos+=t.x,e.srcPos.y_pos+=t.y),e.trgPos&&(e.trgPos.x_pos+=t.x,e.trgPos.y_pos+=t.y)}))}if(this.displayCanvas(),this.existingNodeInsertableIntoLink){var i=this.getLinkAtMousePos(e.sourceEvent.clientX,e.sourceEvent.clientY);(!i||this.isLinkFullyAttached(i)&&this.dragObjects[0].id!==i.srcNodeId&&this.dragObjects[0].id!==i.trgNodeId)&&this.setInsertNodeIntoLinkHighlighting(i)}if(this.existingNodeAttachableToDetachedLinks){var o=this.getTransformedMousePos(e),a=this.dragObjects[0],r={x1:o.x-this.dragPointerOffsetInNode.x,y1:o.y-this.dragPointerOffsetInNode.y,x2:o.x-this.dragPointerOffsetInNode.x+a.width,y2:o.y-this.dragPointerOffsetInNode.y+a.height},s=this.getAttachableLinksForNodeAtPos(a,r);this.setDetachedLinkHighlighting(s)}}},{key:"dragObjectsEnd",value:function(e,t){if(this.dragging=!1,0===this.dragOffsetX&&0===this.dragOffsetY&&this.config.enableDragWithoutSelect)this.selectObjectSourceEvent(e,t);else if(0!==this.dragRunningX||0!==this.dragRunningY){var n=null;if(this.config.enableSnapToGridType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a6){var i=this.snapToGridDraggedNode();n={x:i.x-this.dragStartX,y:i.y-this.dragStartY}}else n={x:this.dragRunningX,y:this.dragRunningY};this.existingNodeInsertableIntoLink&&this.dragOverLink?this.canvasController.editActionHandler({editType:"insertNodeIntoLink",editSource:"canvas",node:this.dragObjects[0],link:this.dragOverLink,offsetX:n.x,offsetY:n.y,pipelineId:this.activePipeline.id}):this.existingNodeAttachableToDetachedLinks&&this.dragOverDetachedLinks.length>0?this.canvasController.editActionHandler({editType:"attachNodeToLinks",editSource:"canvas",node:this.dragObjects[0],detachedLinks:this.dragOverDetachedLinks,offsetX:n.x,offsetY:n.y,pipelineId:this.activePipeline.id}):this.canvasController.editActionHandler({editType:"moveObjects",editSource:"canvas",nodes:this.dragObjects.map((function(e){return e.id})),links:this.getSelectedLinks().filter((function(e){return e.srcPos||e.trgPos})),offsetX:n.x,offsetY:n.y,pipelineId:this.activePipeline.id})}this.setDataLinkSelectionAreaWider(!1),this.unsetNodeTranslucentState(),this.unsetInsertNodeIntoLinkHighlighting(),this.unsetDetachedLinkHighlighting()}},{key:"dragStartLinkHandle",value:function(e,t){this.logger.logStartTimer("dragStartLinkHandle"),this.closeContextMenuIfOpen(),this.draggingLinkHandle=!0;var n=ws.select(e.sourceEvent.currentTarget),i=this.activePipeline.getLink(t.id),o=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_20__.d)(i),a=this.getLinkGroupSelectionById(t.id);if(this.draggingLinkData={lineInfo:t,link:i,oldLink:o,linkGrpSelection:ws.select(a)},n.attr("class").includes("d3-link-handle-end")?this.draggingLinkData.endBeingDragged="end":n.attr("class").includes("d3-link-handle-start")&&(this.draggingLinkData.endBeingDragged="start"),this.config.enableHighlightUnavailableNodes)if("end"===this.draggingLinkData.endBeingDragged){var r=this.activePipeline.links.filter((function(e){return e.id!==i.id}));this.setUnavailableTargetNodesHighlighting(this.activePipeline.getNode(this.draggingLinkData.link.srcNodeId),this.draggingLinkData.link.srcNodePortId,r)}else if("start"===this.draggingLinkData.endBeingDragged){var s=this.activePipeline.links.filter((function(e){return e.id!==i.id}));this.setUnavailableSourceNodesHighlighting(this.activePipeline.getNode(this.draggingLinkData.oldLink.trgNodeId),this.draggingLinkData.link.trgNodePortId,s)}this.dragLinkHandle(e),this.logger.logEndTimer("dragStartLinkHandle",!0)}},{key:"dragMoveLinkHandle",value:function(e){this.logger.logStartTimer("dragMoveLinkHandle"),this.dragLinkHandle(e),this.logger.logEndTimer("dragMoveLinkHandle",!0)}},{key:"dragEndLinkHandle",value:function(e){this.logger.logStartTimer("dragEndLinkHandle"),this.completeDraggedLink(e),this.draggingLinkHandle=!1,this.logger.logEndTimer("dragEndLinkHandle",!0)}},{key:"setNodeTranslucentState",value:function(e,t){this.getNodeGroupSelectionById(e).classed("d3-node-group-translucent",t)}},{key:"unsetNodeTranslucentState",value:function(){this.dragObjects&&this.dragObjects.length>0&&this.setNodeTranslucentState(this.dragObjects[0].id,!1)}},{key:"snapToGridDraggedNode",value:function(){var e=this.dragStartX+this.dragOffsetX,t=this.dragStartY+this.dragOffsetY;return this.snapToGridPosition({x:e,y:t})}},{key:"snapToGridPosition",value:function(e){return{x:_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.snapToGrid(e.x,this.canvasLayout.snapToGridXPx),y:_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.snapToGrid(e.y,this.canvasLayout.snapToGridYPx)}}},{key:"displayNodes",value:function(){this.logger.logStartTimer("displayNodes "+this.getFlags()),this.setPortPositionsAllNodes(),this.commentSizing||(this.dragging&&!this.nodeSizing&&!this.commentSizing||this.movingBindingNodes?this.displayMovedNodes():this.selecting||this.regionSelect?this.displayNodesSelectionStatus():this.displayAllNodes()),this.logger.logEndTimer("displayNodes "+this.getFlags())}},{key:"displayMovedNodes",value:function(){var e=this,t=this.getAllNodeGroupsSelection();t.datum((function(t){return e.activePipeline.getNode(t.id)})).attr("transform",(function(e){return"translate(".concat(e.x_pos,", ").concat(e.y_pos,")")})),this.dispUtils.isDisplayingSubFlow()&&t.each((function(t,n,i){t.isSupernodeInputBinding&&e.updatePortRadiusAndPos(i[n],t,"d3-node-port-output-main"),t.isSupernodeOutputBinding&&(e.updatePortRadiusAndPos(i[n],t,"d3-node-port-input-main"),e.updatePortArrowPath(i[n],"d3-node-port-input-arrow"))}))}},{key:"displayNodesSelectionStatus",value:function(e){var t=this;this.getAllNodeGroupsSelection().selectChildren(".d3-node-selection-highlight").attr("data-selected",(function(e){return t.objectModel.isSelected(e.id,t.activePipeline.id)?"yes":"no"})),this.superRenderers.forEach((function(e){e.selecting=!0,e.displayNodes(),e.selecting=!1}))}},{key:"displayAllNodes",value:function(){var e=this;this.getAllNodeGroupsSelection().data(this.activePipeline.nodes,(function(e){return e.id})).join((function(t){return e.createNodes(t)})).attr("transform",(function(e){return"translate(".concat(e.x_pos,", ").concat(e.y_pos,")")})).attr("class",(function(t){return e.getNodeGroupClass(t)})).attr("style",(function(t){return e.getNodeGrpStyle(t)})).call((function(t){return e.updateNodes(t)}))}},{key:"createNodes",value:function(e){var t=this;this.logger.logStartTimer("createNodes");var n=e.append("g").attr("data-id",(function(e){return t.getId("node_grp",e.id)})).call(this.attachNodeGroupListeners.bind(this));return this.config.enableEditingActions&&n.call(this.drag),n.filter((function(e){return t.shouldDisplayNodeSizingArea(e)})).append("path").attr("class","d3-node-sizing").call(this.attachNodeSizingListeners.bind(this)),n.filter((function(e){return!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSuperBindingNode(e)})).append("path").attr("class","d3-node-selection-highlight"),n.filter((function(e){return!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSuperBindingNode(e)})).append("path").attr("class","d3-node-body-outline"),n.filter((function(e){return!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSuperBindingNode(e)&&e.layout.imageDisplay})).each((function(e,n,i){var o=t.getNodeImage(e),a=t.getImageType(o);ws.select(i[n]).append(a).attr("class",(function(e){return t.nodeUtils.getNodeImageClass(e)}))})),n.filter((function(e){return!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSuperBindingNode(e)})).append("foreignObject").attr("class","d3-foreign-object").call(this.attachNodeLabelListeners.bind(this)).append("xhtml:div").append("xhtml:span").call(this.attachNodeLabelSpanListeners.bind(this)),this.logger.logEndTimer("createNodes"),n}},{key:"updateNodes",value:function(e){var t=this;this.logger.logStartTimer("updateNodes"),e.selectChildren(".d3-node-sizing").datum((function(e){return t.activePipeline.getNode(e.id)})).attr("d",(function(e){return t.getNodeShapePathSizing(e)})),e.selectChildren(".d3-node-selection-highlight").datum((function(e){return t.activePipeline.getNode(e.id)})).attr("d",(function(e){return t.getNodeSelectionOutline(e)})).attr("data-selected",(function(e){return t.objectModel.isSelected(e.id,t.activePipeline.id)?"yes":"no"})).attr("style",(function(e){return t.getNodeSelectionOutlineStyle(e,"default")})),e.selectChildren(".d3-node-body-outline").datum((function(e){return t.activePipeline.getNode(e.id)})).attr("d",(function(e){return t.getNodeShapePath(e)})).attr("style",(function(e){return t.getNodeBodyStyle(e,"default")})),e.selectChildren(".d3-node-image").datum((function(e){return t.activePipeline.getNode(e.id)})).each((function(e,n,i){return t.setNodeImageContent(i[n],e)})).attr("x",(function(e){return t.nodeUtils.getNodeImagePosX(e)})).attr("y",(function(e){return t.nodeUtils.getNodeImagePosY(e)})).attr("width",(function(e){return t.nodeUtils.getNodeImageWidth(e)})).attr("height",(function(e){return t.nodeUtils.getNodeImageHeight(e)})).attr("style",(function(e){return t.getNodeImageStyle(e,"default")})),e.selectChildren(".d3-foreign-object").datum((function(e){return t.activePipeline.getNode(e.id)})).attr("x",(function(e){return t.nodeUtils.getNodeLabelPosX(e)})).attr("y",(function(e){return t.nodeUtils.getNodeLabelPosY(e)})).attr("width",(function(e){return t.nodeUtils.getNodeLabelWidth(e)})).attr("height",(function(e){return t.nodeUtils.getNodeLabelHeight(e)})).attr("class",(function(e){return t.nodeUtils.getNodeLabelForeignClass(e)})).select("div").attr("class",(function(e){return t.nodeUtils.getNodeLabelClass(e)})).attr("style",(function(e){return t.getNodeLabelStyle(e,"default")})).select("span").html((function(e){return Ui(e.label)})),e.selectChildren(".d3-node-ellipsis-group").attr("transform",(function(e){return t.nodeUtils.getNodeEllipsisTranslate(e)})),e.selectChildren(".d3-node-super-expand-icon-group").attr("transform",(function(e){return t.nodeUtils.getNodeExpansionIconTranslate(e)})),e.each((function(e,n,i){var o=ws.select(i[n]);if(t.displayPorts(o,e),_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSupernode(e)&&t.displaySupernodeContents(e,ws.select(i[n])),!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSuperBindingNode(e)){t.addErrorMarker(e,o);var a=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getCombinedDecorations(e.layout.decorations,e.decorations);t.displayDecorations(e,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ad,o,a)}})),this.logger.logEndTimer("updateNodes")}},{key:"displaySupernodeContents",value:function(e,t){var n=this.getRendererForSupernode(e);_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpanded(e)?n?n.setCanvasInfoRenderer(this.canvasInfo):(n=this.createSupernodeRenderer(e,t),this.superRenderers.push(n)):n&&n.hideCanvas(e)}},{key:"displayPorts",value:function(e,t){t.layout.inputPortDisplay&&Array.isArray(t.inputs)&&this.displayInputPorts(e,t),t.layout.outputPortDisplay&&Array.isArray(t.outputs)&&this.displayOutputPorts(e,t)}},{key:"displayInputPorts",value:function(e,t){var n=this,i="."+this.getNodeInputPortClassName();e.selectChildren(i).data(t.inputs,(function(e){return e.id})).join((function(e){return n.createInputPorts(e,t)})).attr("connected",(function(e){return e.isConnected?"yes":"no"})).attr("class",(function(e){return n.getNodeInputPortClassName()+(e.class_name?" "+e.class_name:"")})).call((function(e){return n.updateInputPorts(e,t)}))}},{key:"createInputPorts",value:function(e,t){var n=e.append("g").attr("data-port-id",(function(e){return e.id})).attr("isSupernodeBinding",_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSuperBindingNode(t)?"yes":"no").call(this.attachInputPortListeners.bind(this),t);return n.append(t.layout.inputPortObject).attr("class","d3-node-port-input-main"),this.config.enableAssocLinkCreation||"circle"!==t.layout.inputPortObject||_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSuperBindingNode(t)||n.append("path").attr("class","d3-node-port-input-arrow"),n}},{key:"updateInputPorts",value:function(e,t){var n=this;e.selectChildren(".d3-node-port-input-main").datum((function(e){return t.inputs.find((function(t){return e.id===t.id}))})).each((function(e,i,o){var a=ws.select(o[i]);t.layout.inputPortObject===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ae?a.attr("xlink:href",t.layout.inputPortImage).attr("x",e.cx-t.layout.inputPortWidth/2).attr("y",e.cy-t.layout.inputPortHeight/2).attr("width",t.layout.inputPortWidth).attr("height",t.layout.inputPortHeight):a.attr("r",n.getPortRadius(t)).attr("cx",e.cx).attr("cy",e.cy)})),e.selectChildren(".d3-node-port-input-arrow").datum((function(e){return t.inputs.find((function(t){return e.id===t.id}))})).each((function(e,i,o){var a=ws.select(o[i]);t.layout.inputPortObject!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ae&&a.attr("d",n.getPortArrowPath(e)).attr("transform",n.getPortArrowPathTransform(e))}))}},{key:"displayOutputPorts",value:function(e,t){var n=this,i="."+this.getNodeOutputPortClassName(),o=this.config.enableSingleOutputPortDisplay&&t.outputs.length>1?[t.outputs[t.outputs.length-1]]:t.outputs;e.selectChildren(i).data(o,(function(e){return e.id})).join((function(e){return n.createOutputPorts(e,t)})).attr("connected",(function(e){return e.isConnected?"yes":"no"})).attr("class",(function(e){return n.getNodeOutputPortClassName()+(e.class_name?" "+e.class_name:"")})).call((function(e){return n.updateOutputPorts(e,t)}))}},{key:"createOutputPorts",value:function(e,t){var n=e.append("g").attr("data-port-id",(function(e){return e.id})).attr("isSupernodeBinding",_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSuperBindingNode(t)?"yes":"no").call(this.attachOutputPortListeners.bind(this),t);return n.append(t.layout.outputPortObject).attr("class","d3-node-port-output-main"),n}},{key:"updateOutputPorts",value:function(e,t){var n=this;e.selectChildren(".d3-node-port-output-main").datum((function(e){return t.outputs.find((function(t){return e.id===t.id}))})).each((function(e,i,o){var a=ws.select(o[i]);t.layout.outputPortObject===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ae?a.attr("xlink:href",t.layout.outputPortImage).attr("x",e.cx-t.layout.outputPortWidth/2).attr("y",e.cy-t.layout.outputPortHeight/2).attr("width",t.layout.outputPortWidth).attr("height",t.layout.outputPortHeight):a.attr("r",n.getPortRadius(t)).attr("cx",e.cx).attr("cy",e.cy)}))}},{key:"attachNodeGroupListeners",value:function(e){var t=this;e.on("mouseenter",(function(e,n){var i=ws.select(e.currentTarget);t.raiseNodeToTop(i),t.setNodeStyles(n,"hover",i),t.addDynamicNodeIcons(n,i),t.canOpenTip(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.z)&&(t.canvasController.closeTip(),t.canvasController.openTip({id:t.getId("node_tip",n.id),type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.z,targetObj:e.currentTarget,pipelineId:t.activePipeline.id,node:n}))})).on("mouseleave",(function(e,n){var i=ws.select(e.currentTarget);t.setNodeStyles(n,"default",i),t.removeDynamicNodeIcons(n,i),t.canvasController.closeTip()})).on("mousedown",(function(e,n){t.logger.log("Node Group - mouse down"),t.config.enableDragWithoutSelect||t.selectObjectD3Event(e,n),t.logger.log("Node Group - finished mouse down")})).on("mousemove",(function(e,t){})).on("mouseup",(function(e,n){e.stopPropagation(),t.logger.log("Node Group - mouse up"),t.drawingNewLinkData&&t.completeNewLink(e),t.draggingLinkData&&t.completeDraggedLink(e,n)})).on("click",(function(e,n){t.logger.log("Node Group - click"),e.stopPropagation()})).on("dblclick",(function(e,n){t.logger.log("Node Group - double click"),_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e);var i=t.objectModel.getSelectedObjectIds();t.canvasController.clickActionHandler({clickType:"DOUBLE_CLICK",objectType:"node",id:n.id,selectedObjectIds:i,pipelineId:t.activePipeline.id})})).on("contextmenu",(function(e,n){t.logger.log("Node Group - context menu"),_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSuperBindingNode(n)||(t.config.enableDragWithoutSelect&&t.selectObjectD3Event(e,n),t.openContextMenu(e,"node",n))}))}},{key:"attachNodeSizingListeners",value:function(e){var t=this;e.on("mousedown",(function(e,n){t.isNodeResizable(n)&&(t.nodeSizing=!0,t.addTempCursorOverlay(t.nodeSizingCursor))})).on("mousemove mouseenter",(function(e,n){if(t.isNodeResizable(n)&&!t.isRegionSelectOrSizingInProgress()){var i="pointer";t.isPointerCloseToBodyEdge(e,n)||(t.nodeSizingDirection=t.getSizingDirection(e,n,n.layout.nodeCornerResizeArea),t.nodeSizingCursor=t.getCursorBasedOnDirection(t.nodeSizingDirection),i=t.nodeSizingCursor),ws.select(e.currentTarget).style("cursor",i)}})).on("mouseleave",(function(e,t){ws.select(e.currentTarget).style("cursor","pointer")}))}},{key:"attachNodeLabelListeners",value:function(e){var t=this;e.on("mouseenter",(function(e,n){var i=ws.select(e.currentTarget);if(t.config.enableDisplayFullLabelOnHover&&!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(n)){var o=i.selectAll("span");i.attr("x",t.nodeUtils.getNodeLabelHoverPosX(n)).attr("width",t.nodeUtils.getNodeLabelHoverWidth(n)).attr("height",t.nodeUtils.getNodeLabelHoverHeight(n,o.node(),t.zoomTransform.k)),o.classed("d3-label-full",!0)}})).on("mouseleave",(function(e,n){var i=ws.select(e.currentTarget);t.config.enableDisplayFullLabelOnHover&&!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(n)&&(i.attr("x",t.nodeUtils.getNodeLabelPosX(n)).attr("width",t.nodeUtils.getNodeLabelWidth(n)).attr("height",t.nodeUtils.getNodeLabelHeight(n)),i.selectAll("span").classed("d3-label-full",!1))})).on("dblclick",(function(e,n){t.logger.log("Node Label - double click"),n.layout.labelEditable&&t.config.enableEditingActions&&(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),t.displayNodeLabelTextArea(n,e.currentTarget.parentNode))}))}},{key:"attachNodeLabelSpanListeners",value:function(e){var t=this;e.on("mouseenter",(function(e,n){n.layout.labelEditable&&t.config.enableEditingActions&&t.displayNodeLabelEditIcon(e.currentTarget,n)})).on("mouseleave",(function(e,n){n.layout.labelEditable&&t.config.enableEditingActions&&(t.hideEditIconPending=setTimeout(t.hideEditIcon.bind(t),500,e.currentTarget,n))}))}},{key:"attachInputPortListeners",value:function(e,t){var n=this;e.on("mousedown",(function(e,i){if(n.config.enableAssocLinkCreation&&0===e.button){_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e);var o=n.activePipeline.getNode(t.id);n.drawingNewLinkData={srcObjId:t.id,srcPortId:i.id,action:n.config.enableAssocLinkCreation?_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H,srcNode:o,startPos:{x:o.x_pos+i.cx,y:o.y_pos+i.cy},portType:"input",portObject:t.layout.inputPortObject,portImage:t.layout.inputPortImage,portWidth:t.layout.inputPortWidth,portHeight:t.layout.inputPortHeight,portRadius:n.getPortRadius(o),minInitialLine:o.layout.minInitialLine,guideObject:t.layout.inputPortGuideObject,guideImage:t.layout.inputPortGuideImage,linkArray:[]},n.drawNewLink(e)}})).on("mouseenter",(function(e,i){_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),n.canOpenTip(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.y)&&(n.canvasController.closeTip(),n.canvasController.openTip({id:n.getId("node_port_tip",i.id),type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.y,targetObj:e.currentTarget,pipelineId:n.activePipeline.id,node:t,port:i}))})).on("mouseleave",(function(){n.canvasController.closeTip()})).on("contextmenu",(function(e,i){n.logger.log("Input Port Circle - context menu"),_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),n.config.enableDragWithoutSelect&&n.selectObjectD3Event(e,t),n.openContextMenu(e,"input_port",t,i)}))}},{key:"attachOutputPortListeners",value:function(e,t){var n=this;e.on("mousedown",(function(e,i){if(0===e.button){_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e);var o=n.activePipeline.getNode(t.id);_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSrcCardinalityAtMax(i.id,o,n.activePipeline.links)||(n.drawingNewLinkData={srcObjId:t.id,srcPortId:i.id,action:n.config.enableAssocLinkCreation?_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H,srcNode:o,startPos:{x:o.x_pos+i.cx,y:o.y_pos+i.cy},portType:"output",portObject:t.layout.outputPortObject,portImage:t.layout.outputPortImage,portWidth:t.layout.outputPortWidth,portHeight:t.layout.outputPortHeight,portRadius:n.getPortRadius(o),minInitialLine:o.layout.minInitialLine,guideObject:t.layout.outputPortGuideObject,guideImage:t.layout.outputPortGuideImage,linkArray:[]},n.config.enableHighlightUnavailableNodes&&n.setUnavailableTargetNodesHighlighting(o,i.id,n.activePipeline.links),n.drawNewLink(e))}})).on("mouseenter",(function(e,i){_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),n.canOpenTip(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.y)&&(n.canvasController.closeTip(),n.canvasController.openTip({id:n.getId("node_port_tip",i.id),type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.y,targetObj:e.currentTarget,pipelineId:n.activePipeline.id,node:t,port:i}))})).on("mouseleave",(function(){n.canvasController.closeTip()})).on("contextmenu",(function(e,i){n.logger.log("Output Port Circle - context menu"),_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),n.config.enableDragWithoutSelect&&n.selectObjectD3Event(e,t),n.openContextMenu(e,"output_port",t,i)}))}},{key:"setUnavailableTargetNodesHighlighting",value:function(e,t,n){this.getAllNodeGroupsSelection().filter((function(i){return!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isTrgNodeAvailable(i,e,t,n)})).classed("d3-node-unavailable",!0)}},{key:"setUnavailableSourceNodesHighlighting",value:function(e,t,n){this.getAllNodeGroupsSelection().filter((function(i){return!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSrcNodeAvailable(i,e,t,n)})).classed("d3-node-unavailable",!0)}},{key:"unsetUnavailableNodesHighlighting",value:function(){this.getAllNodeGroupsSelection().classed("d3-node-unavailable",!1)}},{key:"displayNodeLabelEditIcon",value:function(e,t){var n=this,i=e.parentElement.parentElement.parentElement,o=ws.select(i),a=this.nodeUtils.getNodeLabelEditIconTranslate(t,e,this.zoomTransform.k,this.config.enableDisplayFullLabelOnHover);this.displayEditIcon(e,o,a,(function(e,t){return n.displayNodeLabelTextArea(t,e.currentTarget.parentNode)}))}},{key:"displayDecLabelEditIcon",value:function(e,t,n,i){var o=this,a=e.parentElement.parentElement.parentElement,r=ws.select(a),s=this.decUtils.getDecLabelEditIconTranslate(t,n,i,e,this.zoomTransform.k);this.displayEditIcon(e,r,s,(function(e,a){return o.displayDecLabelTextArea(t,n,i,e.currentTarget.parentNode)}))}},{key:"displayEditIcon",value:function(e,t,n,i){var o=this,a=t.append("g").attr("class","d3-label-edit-icon-group").attr("transform",n).on("mouseenter",(function(e,t){o.mouseOverLabelEditIcon=!0})).on("mouseleave",(function(e,t){o.mouseOverLabelEditIcon=!1,o.hideEditIcon(this)})).on("click",(function(e,t){i(e,t),o.mouseOverLabelEditIcon=!1,o.hideEditIcon(this)}));a.append("rect").attr("class","d3-label-edit-icon-background1").attr("width",29).attr("height",24).attr("x",0).attr("y",-4),a.append("rect").attr("class","d3-label-edit-icon-background2").attr("width",24).attr("height",24).attr("x",5).attr("y",-4),a.append("svg").attr("class","d3-node-edit-label-icon").html(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.af).attr("width",16).attr("height",16).attr("x",9).attr("y",0)}},{key:"hideEditIcon",value:function(e){if(!this.mouseOverLabelEditIcon){var t=e.parentElement.parentElement.parentElement;ws.select(t).selectAll(".d3-label-edit-icon-group").remove()}}},{key:"selectObjectD3Event",value:function(e,t){this.selectObject(t,e.type,e.shiftKey,_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isCmndCtrlPressed(e))}},{key:"selectObjectSourceEvent",value:function(e,t){this.selectObject(t,e.type,e.sourceEvent.shiftKey,_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isCmndCtrlPressed(e.sourceEvent))}},{key:"selectObject",value:function(e,t,n,i){this.selecting=!0,this.objectModel.isSelected(e.id,this.activePipeline.id)?i&&this.objectModel.toggleSelection(e.id,i,this.activePipeline.id):n?this.objectModel.selectSubGraph(e.id,this.activePipeline.id):this.objectModel.toggleSelection(e.id,i,this.activePipeline.id),this.selecting=!1;var o=this.activePipeline.getObjectTypeName(e);"node"!==o&&"link"!==o||(this.canvasController.clickActionHandler({clickType:"contextmenu"===t||this.ellipsisClicked?"SINGLE_CLICK_CONTEXTMENU":"SINGLE_CLICK",objectType:o,id:e.id,selectedObjectIds:this.objectModel.getSelectedObjectIds(),pipelineId:this.activePipeline.id}),this.ellipsisClicked=!1)}},{key:"displayDecorations",value:function(e,t,n,i){var o=this,a=this,r=i||[],s="d3-".concat(t,"-dec-group"),l="."+s;n.selectChildren(l).data(r,(function(e){return e.id})).join((function(e){return o.createDecorations(e,t,s)})).attr("transform",(function(n){return o.decUtils.getDecTransform(n,e,t)})).on("mousedown",(function(t,n){return n.hotspot?a.callDecoratorCallback(t,e,n):null})).each((function(n,i,a){return o.updateDecoration(n,ws.select(a[i]),t,e)}))}},{key:"createDecorations",value:function(e,t,n){var i=this;return e.append("g").attr("data-id",(function(e){return i.getId("".concat(t,"_dec_group"),e.id)})).attr("class",n).call(this.attachDecGroupListeners.bind(this))}},{key:"updateDecoration",value:function(e,t,n,i){this.updateDecOutlines(e,t,n,i),this.updateDecPaths(e,t,n),this.updateDecImages(e,t,n,i),this.updateDecLabels(e,t,n,i)}},{key:"updateDecOutlines",value:function(e,t,n,i){var o=t.selectChild("rect");e.label||e.path||!1===e.outline?o.remove():(o=o.empty()?t.append("rect"):o).attr("class",this.decUtils.getDecClass(e,"d3-".concat(n,"-dec-outline"))).attr("x",0).attr("y",0).attr("width",this.decUtils.getDecWidth(e,i,n)).attr("height",this.decUtils.getDecHeight(e,i,n)).lower()}},{key:"updateDecPaths",value:function(e,t,n){var i=t.selectChild("path");e.path?(i=i.empty()?t.append("path"):i).attr("class",this.decUtils.getDecClass(e,"d3-".concat(n,"-dec-path"))).attr("x",0).attr("y",0).attr("d",e.path):i.remove()}},{key:"updateDecImages",value:function(e,t,n,i){var o=this,a=t.selectChild("g");if(e.image){var r=this.getImageType(e.image);(a=a.empty()?t.append("g").append(r):a.select(r)).attr("class",this.decUtils.getDecClass(e,"d3-".concat(n,"-dec-image"))).attr("x",this.decUtils.getDecPadding(e,i,n)).attr("y",this.decUtils.getDecPadding(e,i,n)).attr("width",this.decUtils.getDecWidth(e,i,n)-2*this.decUtils.getDecPadding(e,i,n)).attr("height",this.decUtils.getDecHeight(e,i,n)-2*this.decUtils.getDecPadding(e,i,n)).each((function(){return o.setImageContent(a,e.image)}))}else a.remove()}},{key:"updateDecLabels",value:function(e,t,n,i){var o=t.selectChild("foreignObject");e.label?(o.empty()&&(o=t.append("foreignObject").attr("class",this.decUtils.getDecLabelForeignClass(e)).attr("x",0).attr("y",0).call(this.attachDecLabelListeners.bind(this,i,n))).append("xhtml:div").append("xhtml:span").call(this.attachDecLabelSpanListeners.bind(this,i,n)),o.attr("width",this.decUtils.getDecLabelWidth(e,i,n)).attr("height",this.decUtils.getDecLabelHeight(e,i,n)).select("div").attr("class",this.decUtils.getDecLabelClass(e,n)).select("span").html(Ui(e.label))):o.remove()}},{key:"attachDecLabelListeners",value:function(e,t,n){var i=this;n.on("dblclick",(function(n,o){i.logger.log("Decoration Label - double click"),o.label_editable&&i.config.enableEditingActions&&(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(n),i.displayDecLabelTextArea(o,e,t,n.currentTarget.parentNode))}))}},{key:"attachDecLabelSpanListeners",value:function(e,t,n){var i=this;n.on("mouseenter",(function(n,o){o.label_editable&&i.config.enableEditingActions&&i.displayDecLabelEditIcon(n.currentTarget,o,e,t)})).on("mouseleave",(function(e,t){t.label_editable&&i.config.enableEditingActions&&(i.hideEditIconPending=setTimeout(i.hideEditIcon.bind(i),500,e.currentTarget,t))}))}},{key:"attachDecGroupListeners",value:function(e){var t=this;e.on("mouseenter",(function(e,n){t.canOpenTip(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.x)&&(t.canvasController.closeTip(),t.canvasController.openTip({id:t.getId("dec_tip",n.id),type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.x,targetObj:e.currentTarget,pipelineId:t.activePipeline.id,decoration:n}))})).on("mouseleave",(function(e,n){t.canvasController.closeTip()}))}},{key:"addErrorMarker",value:function(e,t){var n=this,i=t.selectChildren(".node-error-marker");e.messages&&e.messages.length>0?(i.empty()&&t.append("svg").attr("class","node-error-marker"),t.selectChildren(".node-error-marker").attr("class",(function(){return"node-error-marker "+n.nodeUtils.getErrorMarkerClass(e.messages)})).html(this.nodeUtils.getErrorMarkerIcon(e)).attr("width",this.nodeUtils.getNodeErrorWidth(e)).attr("height",this.nodeUtils.getNodeErrorHeight(e)).attr("x",this.nodeUtils.getNodeErrorPosX(e)).attr("y",this.nodeUtils.getNodeErrorPosY(e))):i.empty()||i.remove()}},{key:"getNodeInputPortClassName",value:function(){return this.config.enableAssocLinkCreation?"d3-node-port-input-assoc":"d3-node-port-input"}},{key:"getNodeOutputPortClassName",value:function(){return this.config.enableAssocLinkCreation?"d3-node-port-output-assoc":"d3-node-port-output"}},{key:"setNodeImageContent",value:function(e,t){var n=this.getNodeImage(t),i=ws.select(e);this.setImageContent(i,n)}},{key:"setImageContent",value:function(e,t){if(t!==e.attr("data-image")){var n=this.getImageType(t);e.attr("data-image",t),"svg"===n?(e.selectChild("svg").remove(),ws.svg(t,{cache:"force-cache"}).then((function(t){e.node().append(t.documentElement)}))):e.attr("xlink:href",t)}}},{key:"getNodeImage",value:function(e){if(!e.image)return null;if(e.image===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.U){if(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSupernode(e))return ct}else if(e.image===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.s&&_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSupernode(e))return ut;return e.image}},{key:"getImageType",value:function(e){return e&&e.endsWith(".svg")?"svg":"image"}},{key:"setNodeStyles",value:function(e,t,n){this.setNodeBodyStyles(e,t,n),this.setNodeSelectionOutlineStyles(e,t,n),this.setNodeImageStyles(e,t,n),this.setNodeLabelStyles(e,t,n)}},{key:"setNodeBodyStyles",value:function(e,t,n){var i=this.getNodeBodyStyle(e,t);n.selectChildren(".d3-node-body-outline").attr("style",i)}},{key:"setNodeSelectionOutlineStyles",value:function(e,t,n){var i=this.getNodeSelectionOutlineStyle(e,t);n.selectChildren(".d3-node-selection-highlight").attr("style",i)}},{key:"setNodeImageStyles",value:function(e,t,n){var i=this.getNodeImageStyle(e,t);n.selectChildren(".d3-node-image").attr("style",i)}},{key:"setNodeLabelStyles",value:function(e,t,n){var i=this.getNodeLabelStyle(e,t);n.selectChildren(".d3-node-label").attr("style",i)}},{key:"getNodeBodyStyle",value:function(e,t){var n=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getObjectStyle(e,"body",t);return null===n&&e.layout.dropShadow&&(n="filter:url(".concat(this.getId("#node_drop_shadow"),")")),n}},{key:"getNodeSelectionOutlineStyle",value:function(e,t){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getObjectStyle(e,"selection_outline",t)}},{key:"getNodeImageStyle",value:function(e,t){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getObjectStyle(e,"image",t)}},{key:"getNodeLabelStyle",value:function(e,t){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getObjectStyle(e,"label",t)}},{key:"getNodeGrpStyle",value:function(e){return e.style_temp||e.style||!this.canvasInfo.subdueStyle||this.doesExpandedSupernodeHaveStyledNodes(e)?null:this.canvasInfo.subdueStyle}},{key:"getLinkGrpStyle",value:function(e){return e.style_temp||e.style||!this.canvasInfo.subdueStyle?null:this.canvasInfo.subdueStyle}},{key:"doesExpandedSupernodeHaveStyledNodes",value:function(e){var t=this,n=!1;_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)&&e.subflow_ref&&e.subflow_ref.pipeline_id_ref&&new Ps(e.subflow_ref.pipeline_id_ref,this.canvasInfo).nodes.forEach((function(e){e.style||e.style_temp?n=!0:!n&&_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)&&(n=t.doesExpandedSupernodeHaveStyledNodes(e))}));return n}},{key:"getMaxZoomToFitPaddingForConnections",value:function(){var e=this.getMaxPaddingForConnectionsFromInputBindingNodes(),t=this.getMaxPaddingForConnectionsToOutputBindingNodes();return Math.max(e,t)}},{key:"getMaxPaddingForConnectionsFromInputBindingNodes",value:function(){var e=this,t=0;return this.activePipeline.nodes.filter((function(e){return e.isSupernodeInputBinding})).forEach((function(n){var i=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getNodePaddingToTargetNodes(n,e.activePipeline.nodes,e.activePipeline.links,e.canvasLayout.linkType);t=Math.max(t,i)})),t}},{key:"getMaxPaddingForConnectionsToOutputBindingNodes",value:function(){var e=this,t=0,n=this.activePipeline.nodes.filter((function(e){return e.isSupernodeOutputBinding}));return this.activePipeline.nodes.forEach((function(i){var o=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getNodePaddingToTargetNodes(i,n,e.activePipeline.links,e.canvasLayout.linkType);t=Math.max(t,o)})),t}},{key:"getPortRadius",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSuperBindingNode(e)?this.getBindingPortRadius():e.layout.portRadius}},{key:"getBindingPortRadius",value:function(){return this.canvasLayout.supernodeBindingPortRadius/this.zoomTransform.k}},{key:"addDynamicNodeIcons",value:function(e,t){var n=this;if(!this.nodeSizing&&!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSuperBindingNode(e)){var i=t.append("g").filter((function(){return e.layout.ellipsisDisplay})).attr("class","d3-node-ellipsis-group").attr("transform",(function(e){return n.nodeUtils.getNodeEllipsisTranslate(e)})).on("mousedown",(function(t){_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(t),n.ellipsisClicked=!0,n.config.enableDragWithoutSelect||n.selectObjectD3Event(t,e),n.openContextMenu(t,"node",e)}));if(i.append("rect").attr("class","d3-node-ellipsis-background").attr("width",(function(e){return n.nodeUtils.getNodeEllipsisWidth(e)})).attr("height",(function(e){return n.nodeUtils.getNodeEllipsisHeight(e)})).attr("x",0).attr("y",0),i.append("svg").attr("class","d3-node-ellipsis").html(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ag).attr("width",(function(e){return n.nodeUtils.getNodeEllipsisIconWidth(e)})).attr("height",(function(e){return n.nodeUtils.getNodeEllipsisIconHeight(e)})).attr("x",(function(e){return e.layout.ellipsisHoverAreaPadding})).attr("y",(function(e){return e.layout.ellipsisHoverAreaPadding})),_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)){var o=t.append("g").attr("transform",(function(e){return n.nodeUtils.getNodeExpansionIconTranslate(e)})).attr("class","d3-node-super-expand-icon-group").on("mousedown",(function(e){_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e);var t=n.getSupernodeBreadcrumbs(e.currentTarget);n.canvasController.displaySubPipelineForBreadcrumbs(t)})).on("mouseenter",(function(){ws.select(this).attr("data-pointer-hover","yes")})).on("mouseleave",(function(){ws.select(this).attr("data-pointer-hover","no")}));o.append("rect").attr("class","d3-node-super-expand-icon-background").attr("width",this.canvasLayout.supernodeExpansionIconWidth).attr("height",this.canvasLayout.supernodeExpansionIconHeight).attr("x",0).attr("y",0),o.append("svg").attr("class","d3-node-super-expand-icon").html(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ah).attr("width",this.canvasLayout.supernodeExpansionIconWidth-2*this.canvasLayout.supernodeExpansionIconHoverAreaPadding).attr("height",this.canvasLayout.supernodeExpansionIconHeight-2*this.canvasLayout.supernodeExpansionIconHoverAreaPadding).attr("x",this.canvasLayout.supernodeExpansionIconHoverAreaPadding).attr("y",this.canvasLayout.supernodeExpansionIconHoverAreaPadding)}}}},{key:"getSupernodeBreadcrumbs",value:function(e){for(var t=[],n=e.closest(".d3-node-group");n;){var i=n.closest(".svg-area"),o=this.getD3DatumFromDomEl(n),a=i.getAttribute("data-pipeline-id");t.push(this.canvasController.getObjectModel().createBreadcrumb(o,a)),n=i.closest(".d3-node-group")}return t.reverse()}},{key:"getD3DatumFromDomEl",value:function(e){var t=ws.select(e);return t?t.datum():null}},{key:"updatePortRadiusAndPos",value:function(e,t,n){var i=this;ws.select(e).selectAll("."+n).attr("r",(function(){return i.getPortRadius(t)})).attr("cx",(function(e){return e.cx})).attr("cy",(function(e){return e.cy}))}},{key:"updatePortArrowPath",value:function(e,t){var n=this;ws.select(e).selectAll("."+t).attr("d",(function(e){return n.getPortArrowPath(e)})).attr("transform",(function(e){return n.getPortArrowPathTransform(e)}))}},{key:"isPortMaxCardinalityZero",value:function(e){return 0===(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.k)(e,"app_data.ui_data.cardinality.max",1)}},{key:"removeDynamicNodeIcons",value:function(e,t){e.layout.ellipsisDisplay&&t.selectChildren(".d3-node-ellipsis-group").remove(),t.selectChildren(".d3-node-super-expand-icon-group").remove()}},{key:"createSupernodeRenderer",value:function(e,t){return e.subflow_ref&&e.subflow_ref.pipeline_id_ref?new n(e.subflow_ref.pipeline_id_ref,this.canvasDiv,this.canvasController,this.canvasInfo,this.config,{id:e.id,pipelineId:this.activePipeline.id,renderer:this,d3Selection:t}):null}},{key:"getRendererForSupernode",value:function(e){return this.superRenderers.find((function(t){return t.supernodeInfo.id===e.id&&t.activePipeline.id===e.subflow_ref.pipeline_id_ref}))}},{key:"getDiscardedRenderersForSupernode",value:function(e){return this.superRenderers.filter((function(t){return t.supernodeInfo.id===e.id&&t.activePipeline.id!==e.subflow_ref.pipeline_id_ref}))}},{key:"openContextMenu",value:function(e,t,n,i){_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),this.canvasController.contextMenuHandler({type:t,targetObject:"canvas"===t?null:n,id:"canvas"===t?null:n.id,pipelineId:this.activePipeline.id,cmPos:this.getMousePos(e,this.canvasDiv.selectAll("svg")),mousePos:this.getMousePosSnapToGrid(this.getTransformedMousePos(e)),selectedObjectIds:this.objectModel.getSelectedObjectIds(),addBreadcrumbs:n&&n.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ai?this.getSupernodeBreadcrumbs(e.currentTarget):null,port:i,zoom:this.zoomTransform.k})}},{key:"closeContextMenuIfOpen",value:function(){this.canvasController.isContextMenuDisplayed()&&this.canvasController.closeContextMenu()}},{key:"callDecoratorCallback",value:function(e,t,n){e.stopPropagation(),this.canvasController.decorationActionHandler&&this.canvasController.decorationActionHandler(t,n.id,this.activePipeline.id)}},{key:"drawNewLink",value:function(e){if(!1!==this.config.enableEditingActions){this.closeContextMenuIfOpen();var t=this.getTransformedMousePos(e);this.drawingNewLinkData.action===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O?this.drawNewCommentLinkForPorts(t):this.drawNewNodeLinkForPorts(t),this.config.enableHighlightNodeOnNewLinkDrag&&this.setNewLinkOverNode(e)}}},{key:"drawNewNodeLinkForPorts",value:function(e){var t,n=this,i=this,o=this.config.enableAssocLinkCreation?_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H;t=this.canvasLayout.linkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Q?this.linkUtils.getNewStraightNodeLinkStartPos(this.drawingNewLinkData.srcNode,e):{x:this.drawingNewLinkData.startPos.x,y:this.drawingNewLinkData.startPos.y},this.drawingNewLinkData.linkArray=[{x1:t.x,y1:t.y,x2:e.x,y2:e.y,type:o}],this.config.enableAssocLinkCreation&&(this.drawingNewLinkData.linkArray[0].assocLinkVariation=this.getNewLinkAssocVariation(this.drawingNewLinkData.linkArray[0].x1,this.drawingNewLinkData.linkArray[0].x2,this.drawingNewLinkData.portType));var a=this.linkUtils.getConnectorPathInfo(this.drawingNewLinkData.linkArray[0],this.drawingNewLinkData.minInitialLine),r=this.nodesLinksGrp.selectAll(".d3-new-connection-line"),s=this.nodesLinksGrp.selectAll(".d3-new-connection-start"),l=this.nodesLinksGrp.selectAll(".d3-new-connection-guide");r.data(this.drawingNewLinkData.linkArray).enter().append("path").attr("class","d3-new-connection-line").attr("linkType",o).merge(r).attr("d",a.path).attr("transform",a.transform),this.canvasLayout.linkType!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Q&&s.data(this.drawingNewLinkData.linkArray).enter().append(this.drawingNewLinkData.portObject).attr("class","d3-new-connection-start").attr("linkType",o).merge(s).each((function(e){i.drawingNewLinkData.portObject===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.aj&&ws.select(this).attr("cx",e.x1).attr("cy",e.y1).attr("r",i.drawingNewLinkData.portRadius)})),l.data(this.drawingNewLinkData.linkArray).enter().append(this.drawingNewLinkData.guideObject).attr("class","d3-new-connection-guide").attr("linkType",o).on("mouseup",(function(e){_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),n.completeNewLink(e)})).merge(l).each((function(e){i.drawingNewLinkData.guideObject===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ae?ws.select(this).attr("xlink:href",i.drawingNewLinkData.guideImage).attr("x",e.x2-i.drawingNewLinkData.portWidth/2).attr("y",e.y2-i.drawingNewLinkData.portHeight/2).attr("width",i.drawingNewLinkData.portWidth).attr("height",i.drawingNewLinkData.portHeight).attr("transform",i.getLinkImageTransform(e)):ws.select(this).attr("cx",e.x2).attr("cy",e.y2).attr("r",i.drawingNewLinkData.portRadius)}))}},{key:"getLinkImageTransform",value:function(e){var t=0;if(this.canvasLayout.linkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Q){var n=e.x2-e.x1,i=e.y2-e.y1;return 0===n&&0===i?t=0:(t=Math.atan(i/n)*(180/Math.PI),t=n>=0?t:t+180,this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Z?t-=90:this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.$&&(t+=90)),"rotate(".concat(t,",").concat(e.x2,",").concat(e.y2,")")}return null}},{key:"drawNewCommentLinkForPorts",value:function(e){var t=this,n=this,i=this.activePipeline.getComment(this.drawingNewLinkData.srcObjId),o=this.linkUtils.getNewStraightCommentLinkStartPos(i,e),a=_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O;this.drawingNewLinkData.linkArray=[{x1:o.x,y1:o.y,x2:e.x,y2:e.y,type:a}];var r=this.nodesLinksGrp.selectAll(".d3-new-connection-line"),s=this.nodesLinksGrp.selectAll(".d3-new-connection-guide");if(r.data(this.drawingNewLinkData.linkArray).enter().append("path").attr("class","d3-new-connection-line").attr("linkType",a).merge(r).attr("d",(function(e){return n.linkUtils.getConnectorPathInfo(e).path})),s.data(this.drawingNewLinkData.linkArray).enter().append("circle").attr("class","d3-new-connection-guide").attr("linkType",a).on("mouseup",(function(e){_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),t.completeNewLink(e)})).merge(s).attr("cx",(function(e){return e.x2})).attr("cy",(function(e){return e.y2})).attr("r",this.canvasLayout.commentPortRadius),this.canvasLayout.commentLinkArrowHead){var l=this.nodesLinksGrp.selectAll(".d3-new-connection-arrow");l.data(this.drawingNewLinkData.linkArray).enter().append("path").attr("class","d3-new-connection-arrow").attr("linkType",a).on("mouseup",(function(e){_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),t.completeNewLink(e)})).merge(l).attr("d",(function(e){return t.getArrowHead(e)})).attr("transform",(function(e){return t.getArrowHeadTransform(e)}))}}},{key:"completeNewLink",value:function(e){if(!1!==this.config.enableEditingActions){this.config.enableHighlightUnavailableNodes&&this.unsetUnavailableNodesHighlighting();var t=this.getNodeAtMousePos(e);null!==t?this.completeNewLinkOnNode(e,t):this.config.enableLinkSelection!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a7||this.drawingNewLinkData.action!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H||this.config.enableAssocLinkCreation?this.stopDrawingNewLink():this.completeNewDetachedLink(e)}}},{key:"completeNewLinkOnNode",value:function(e,t){if(this.removeNewLink(),this.config.enableHighlightNodeOnNewLinkDrag&&this.setNewLinkOverNodeCancel(),null!==t){var n=this.drawingNewLinkData.action;if(n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H){var i=this.activePipeline.getNode(this.drawingNewLinkData.srcObjId),o=this.drawingNewLinkData.srcPortId,a=this.getInputNodePortId(e,t);if(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isDataConnectionAllowed(o,a,i,t,this.activePipeline.links))this.canvasController.editActionHandler({editType:"linkNodes",editSource:"canvas",nodes:[{id:this.drawingNewLinkData.srcObjId,portId:this.drawingNewLinkData.srcPortId}],targetNodes:[{id:t.id,portId:a}],type:n,linkType:"data",pipelineId:this.pipelineId});else if(this.config.enableLinkReplaceOnNewConnection&&_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isDataLinkReplacementAllowed(o,a,i,t,this.activePipeline.links)){var r=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getDataLinksConnectedTo(a,t,this.activePipeline.links);1===r.length&&this.canvasController.editActionHandler({editType:"linkNodesAndReplace",editSource:"canvas",nodes:[{id:this.drawingNewLinkData.srcObjId,portId:this.drawingNewLinkData.srcPortId}],targetNodes:[{id:t.id,portId:a}],type:n,pipelineId:this.pipelineId,replaceLink:r[0]})}}else if(n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K){var s=this.activePipeline.getNode(this.drawingNewLinkData.srcObjId);_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isAssocConnectionAllowed(s,t,this.activePipeline.links)&&this.canvasController.editActionHandler({editType:"linkNodes",editSource:"canvas",nodes:[{id:this.drawingNewLinkData.srcObjId}],targetNodes:[{id:t.id}],type:n,pipelineId:this.pipelineId})}else _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isCommentLinkConnectionAllowed(this.drawingNewLinkData.srcObjId,t.id,this.activePipeline.links)&&this.canvasController.editActionHandler({editType:"linkComment",editSource:"canvas",nodes:[this.drawingNewLinkData.srcObjId],targetNodes:[t.id],type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O,linkType:"comment",pipelineId:this.pipelineId})}this.drawingNewLinkData=null}},{key:"completeNewDetachedLink",value:function(e){this.removeNewLink(),this.config.enableHighlightNodeOnNewLinkDrag&&this.setNewLinkOverNodeCancel();var t=this.getTransformedMousePos(e);this.canvasController.editActionHandler({editType:"createDetachedLink",editSource:"canvas",srcNodeId:this.drawingNewLinkData.srcObjId,srcNodePortId:this.drawingNewLinkData.srcPortId,trgPos:t,type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H,pipelineId:this.pipelineId}),this.drawingNewLinkData=null}},{key:"stopDrawingNewLink",value:function(){this.config.enableHighlightNodeOnNewLinkDrag&&this.setNewLinkOverNodeCancel(),this.stopDrawingNewLinkForPorts()}},{key:"stopDrawingNewLinkForPorts",value:function(){var e=this,t=this.drawingNewLinkData.linkArray[0].x1,n=this.drawingNewLinkData.linkArray[0].y1,i=this.drawingNewLinkData.linkArray[0].x2,o=this.drawingNewLinkData.linkArray[0].y2,a=Object.assign({},this.drawingNewLinkData);this.drawingNewLinkData=null;var r="",s=350;this.canvasLayout.linkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.L?r="M "+t+" "+n+"C "+i+" "+o+" "+i+" "+o+" "+i+" "+o:this.canvasLayout.linkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Q?(t<i&&(s=0),r="M "+t+" "+n+"L "+i+" "+o+" "+i+" "+o+" "+i+" "+o):r="M "+t+" "+n+"L "+i+" "+o+"Q "+i+" "+o+" "+i+" "+o+"L "+i+" "+o+"Q "+i+" "+o+" "+i+" "+o+"L "+i+" "+o+"Q "+i+" "+o+" "+i+" "+o+"L "+i+" "+o+"Q "+i+" "+o+" "+i+" "+o+"L "+i+" "+o,this.nodesLinksGrp.selectAll(".d3-new-connection-line").transition().duration(s).attr("d",r).on("end",(function(){e.nodesLinksGrp.selectAll(".d3-new-connection-arrow").remove(),e.nodesLinksGrp.selectAll(".d3-new-connection-guide").transition().duration(1e3).ease(ws.easeElastic).attr("x",t-a.portWidth/2).attr("y",n-a.portHeight/2).attr("cx",t).attr("cy",n).attr("transform",null),e.nodesLinksGrp.selectAll(".d3-new-connection-line").transition().duration(1e3).ease(ws.easeElastic).attr("d","M "+t+" "+n+"L "+t+" "+n).on("end",e.removeNewLink.bind(e))}))}},{key:"removeNewLink",value:function(){this.nodesLinksGrp.selectAll(".d3-new-connection-line").remove(),this.nodesLinksGrp.selectAll(".d3-new-connection-start").remove(),this.nodesLinksGrp.selectAll(".d3-new-connection-guide").remove(),this.nodesLinksGrp.selectAll(".d3-new-connection-arrow").remove()}},{key:"dragLinkHandle",value:function(e){var t=this.getTransformedMousePos(e),n=this.draggingLinkData.link;"start"===this.draggingLinkData.endBeingDragged?(n.srcPos={x_pos:t.x,y_pos:t.y},delete n.srcNodeId,delete n.srcNodePortId,delete n.srcObj):(n.trgPos={x_pos:t.x,y_pos:t.y},delete n.trgNodeId,delete n.trgNodePortId,delete n.trgNode),this.displayLinks(),this.config.enableHighlightNodeOnNewLinkDrag&&this.setNewLinkOverNode(e)}},{key:"completeDraggedLink",value:function(e){var t=this.getNewLinkOnDrag(e);t?this.canvasController.editActionHandler({editType:"updateLink",editSource:"canvas",newLink:t,pipelineId:this.pipelineId}):(this.activePipeline.replaceLink(this.draggingLinkData.oldLink),this.displayLinks()),this.config.enableHighlightNodeOnNewLinkDrag&&this.setNewLinkOverNodeCancel(),this.unsetUnavailableNodesHighlighting(),this.stopDraggingLink()}},{key:"getNewLinkOnDrag",value:function(e,t){var n=this.draggingLinkData.oldLink,i=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_20__.d)(n);if("start"===this.draggingLinkData.endBeingDragged){delete i.srcNodeId,delete i.srcNodePortId,delete i.srcPos;var o=t?this.getNodeNearMousePos(e,t):this.getNodeAtMousePos(e);o?(i.srcNodeId=o.id,i.srcNodePortId=t?this.getNodePortIdNearMousePos(e,"output_type",o):this.getOutputNodePortId(e,o)):i.srcPos=this.draggingLinkData.link.srcPos}else{delete i.trgNodeId,delete i.trgNodePortId,delete i.trgPos;var a=t?this.getNodeNearMousePos(e,t):this.getNodeAtMousePos(e);a?(i.trgNodeId=a.id,i.trgNodePortId=t?this.getNodePortIdNearMousePos(e,"input_type",a):this.getInputNodePortId(e,a)):i.trgPos=this.draggingLinkData.link.trgPos}return this.config.enableLinkSelection!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a7&&(i.srcPos||i.trgPos)?null:this.canExecuteUpdateLinkCommand(i,n)?i:null}},{key:"canExecuteUpdateLinkCommand",value:function(e,t){var n=this.activePipeline.getNode(e.srcNodeId),i=this.activePipeline.getNode(e.trgNodeId),o=this.hasLinkSrcChanged(e,t),a=this.hasLinkTrgChanged(e,t),r=this.activePipeline.links,s=!0;return o&&n&&!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSrcConnectionAllowedWithDetachedLinks(e.srcNodePortId,n,r)&&(s=!1),a&&i&&!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isTrgConnectionAllowedWithDetachedLinks(e.trgNodePortId,i,r)&&(s=!1),n&&i&&!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isConnectionAllowedWithDetachedLinks(e.srcNodePortId,e.trgNodePortId,n,i,r)&&(s=!1),s}},{key:"hasLinkSrcChanged",value:function(e,t){var n=!1;return e.srcNodeId?(e.srcNodeId!==t.srcNodeId&&(n=!0),e.srcNodePortId!==t.srcNodePortId&&(n=!0)):t.srcPos&&e.srcPos.x_pos===t.srcPos.x_pos&&e.srcPos.y_pos===t.srcPos.y_pos||(n=!0),n}},{key:"hasLinkTrgChanged",value:function(e,t){var n=!1;return e.trgNodeId?(e.trgNodeId!==t.trgNodeId&&(n=!0),e.trgNodePortId!==t.trgNodePortId&&(n=!0)):t.trgPos&&e.trgPos.x_pos===t.trgPos.x_pos&&e.trgPos.y_pos===t.trgPos.y_pos||(n=!0),n}},{key:"stopDraggingLink",value:function(){this.draggingLinkData=null}},{key:"getLinkAtMousePos",value:function(e,t){var n=this.getElementWithClassAtPosition(e,t,"d3-data-link");return this.getNodeLinkForElement(n)}},{key:"getNodeLinkForElement",value:function(e){if(e){var t=ws.select(e).datum();if(t){var n=this.activePipeline.getLink(t.id);if(n&&n.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H)return n}}return null}},{key:"setDataLinkSelectionAreaWider",value:function(e){this.nodesLinksGrp.selectAll(".d3-data-link-selection-area").classed("d3-extra-width",e)}},{key:"getNodeAtMousePos",value:function(e){var t=this.getElementWithClassAtMousePos(e,"d3-node-group");return this.getNodeForElement(t)}},{key:"getInputNodePortId",value:function(e,t){var n=this.getInputNodePortIdAtMousePos(e);return n||(n=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getDefaultInputPortId(t)),n}},{key:"getInputNodePortIdAtMousePos",value:function(e){var t=this.getElementWithClassAtMousePos(e,this.getNodeInputPortClassName());return this.getNodePortIdForElement(t)}},{key:"getOutputNodePortId",value:function(e,t){var n=this.getOutputNodePortIdAtMousePos(e);return n||(n=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getDefaultOutputPortId(t)),n}},{key:"getOutputNodePortIdAtMousePos",value:function(e){var t=this.getElementWithClassAtMousePos(e,this.getNodeOutputPortClassName());return this.getNodePortIdForElement(t)}},{key:"getElementAtPoint",value:function(e,t,n){var i=this;return document.elementsFromPoint(e,t).find((function(e){return i.isClassNameIncluded(e,n)}))}},{key:"getElementWithClassAtMousePos",value:function(e,t){var n=e.clientX?e.clientX:e.sourceEvent.clientX,i=e.clientY?e.clientY:e.sourceEvent.clientY;return this.getElementWithClassAtPosition(n,i,t)}},{key:"getElementWithClassAtPosition",value:function(e,t,n){for(var i=document.elementsFromPoint(e,t),o=null,a=0;!o&&a<i.length;)o=this.getParentElementWithClass(i[a],n),a++;return o}},{key:"getParentElementWithClass",value:function(e,t){for(var n=e,i=null;n;)this.isClassNameIncluded(n,"d3-new-connection-guide")||this.isClassNameIncluded(n,"svg-area")?n=null:this.isClassNameIncluded(n,t)?(i=n,n=null):n=n.parentNode;return i}},{key:"isClassNameIncluded",value:function(e,t){return e.classList&&e.classList.contains(t)}},{key:"getNodeForElement",value:function(e){if(e&&"g"===e.nodeName){var t=ws.select(e).datum();if(t)return this.activePipeline.getNode(t.id)}return null}},{key:"getNodePortIdForElement",value:function(e){return e?ws.select(e).attr("data-port-id"):null}},{key:"getNodeNearMousePos",value:function(e,t){var n=this,i=this.getTransformedMousePos(e),o=null,a=t||0;return this.getAllNodeGroupsSelection().each((function(e){var t=e.layout.portRadius;_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSuperBindingNode(e)&&(t=n.canvasLayout.supernodeBindingPortRadius/n.zoomTransform.k),i.x>=e.x_pos-t-a&&i.x<=e.x_pos+e.width+t+a&&i.y>=e.y_pos-a&&i.y<=e.y_pos+e.height+a&&(o=e)})),o}},{key:"getNodePortIdNearMousePos",value:function(e,t,n){var i=this.getTransformedMousePos(e),o=null,a=null;if(n)if("output_type"===t){var r=this.getAllNodeGroupsSelection().selectChildren("."+this.getNodeOutputPortClassName()).selectChildren(".d3-node-port-output-main");o=this.searchForPortNearMouse(n,i,r,n.layout.outputPortObject,n.width),a=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getDefaultOutputPortId(n)}else{var s=this.getAllNodeGroupsSelection().selectChildren("."+this.getNodeInputPortClassName()).selectChildren(".d3-node-port-input-main");o=this.searchForPortNearMouse(n,i,s,n.layout.inputPortObject,0),a=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getDefaultInputPortId(n)}return o||(o=a),o}},{key:"searchForPortNearMouse",value:function(e,t,n,i,o){var a=null;return n.each((function(n,r,s){var l=ws.select(s[r]);if(i===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ae){var c=e.x_pos+Number(l.attr("x")),u=e.y_pos+Number(l.attr("y")),d=Number(l.attr("width")),h=Number(l.attr("height"));t.x>=c&&t.x<=c+o+d&&t.y>=u&&t.y<=u+h&&(a=s[r].getAttribute("data-port-id"))}else{var p=e.x_pos+Number(l.attr("cx")),g=e.y_pos+Number(l.attr("cy"));t.x>=p-e.layout.portRadius&&t.x<=p+e.layout.portRadius&&t.y>=g-e.layout.portRadius&&t.y<=g+e.layout.portRadius&&(a=s[r].getAttribute("data-port-id"))}})),a}},{key:"getNodeShapePathSizing",value:function(e){return this.getRectangleNodeShapePath(e,e.layout.nodeSizingArea)}},{key:"getNodeSelectionOutline",value:function(e){return e.layout.selectionPath&&!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpanded(e)?e.layout.selectionPath:"port-arcs"===e.layout.nodeShape?this.getPortArcsNodeShapePath(e):this.getRectangleNodeShapePath(e,e.layout.nodeHighlightGap)}},{key:"getNodeShapePath",value:function(e){return e.layout.bodyPath&&!_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpanded(e)?e.layout.bodyPath:"port-arcs"===e.layout.nodeShape?this.getPortArcsNodeShapePath(e):this.getRectangleNodeShapePath(e)}},{key:"getRectangleNodeShapePath",value:function(e,t){var n=t||0,i=0-n,o=0-n,a=e.width+n,r=e.height+n,s="M "+i+" "+o+" L "+a+" "+o;return s+=" L "+a+" "+r,s+=" L "+i+" "+r,s+=" Z"}},{key:"getPortArcsNodeShapePath",value:function(e){return this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Z?this.getPortArcsNodeShapePathVertical(e,e.inputs,e.inputPortsWidth,e.outputs,e.outputPortsWidth):this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.$?this.getPortArcsNodeShapePathVertical(e,e.outputs,e.outputPortsWidth,e.inputs,e.inputPortsWidth):this.getPortArcsNodeShapePathLeftRight(e)}},{key:"getPortArcsNodeShapePathLeftRight",value:function(e){var t="M 0 0 L "+e.width+" 0 ";if(e.outputs&&e.outputs.length>0){var n=e.layout.portArcOffset;e.outputPortsHeight<e.height&&(n=e.outputs[0].cy-e.layout.portArcRadius),t+=" L "+e.width+" "+n,e.outputs.forEach((function(i,o){n+=2*e.layout.portArcRadius,t+=" A "+e.layout.portArcRadius+" "+e.layout.portArcRadius+" 180 0 1 "+e.width+" "+n,o<e.outputs.length-1&&(n+=e.layout.portArcSpacing,t+=" L "+e.width+" "+n)})),t+=" L "+e.width+" "+e.height}else t+=" L "+e.width+" "+e.height;if(t+=" L 0 "+e.height,e.inputs&&e.inputs.length>0){var i=e.height-e.layout.portArcOffset;e.inputPortsHeight<e.height&&(i=e.inputs[e.inputs.length-1].cy+e.layout.portArcRadius),t+=" L 0 "+i,e.inputs.forEach((function(n,o){i-=2*e.layout.portArcRadius,t+=" A "+e.layout.portArcRadius+" "+e.layout.portArcRadius+" 180 0 1 0 "+i,o<e.inputs.length-1&&(i-=e.layout.portArcSpacing,t+=" L 0 "+i)})),t+=" Z"}else t+=" Z";return t}},{key:"getPortArcsNodeShapePathVertical",value:function(e,t,n,i,o){var a="M 0 0 L 0 "+e.height;if(i&&i.length>0){var r=e.layout.portArcOffset;o<e.width&&(r=i[0].cx-e.layout.portArcRadius),a+=" L "+r+" "+e.height,i.forEach((function(t,n){r+=2*e.layout.portArcRadius,a+=" A "+e.layout.portArcRadius+" "+e.layout.portArcRadius+" 180 0 0 "+r+" "+e.height,n<i.length-1&&(r+=e.layout.portArcSpacing,a+=" L "+r+" "+e.height)})),a+=" L "+e.width+" "+e.height}else a+=" L "+e.width+" "+e.height;if(a+=" L "+e.width+" 0 ",t&&t.length>0){var s=e.width-e.layout.portArcOffset;n<e.width&&(s=t[t.length-1].cx+e.layout.portArcRadius),a+=" L "+s+" 0 ",t.forEach((function(n,i){s-=2*e.layout.portArcRadius,a+=" A "+e.layout.portArcRadius+" "+e.layout.portArcRadius+" 180 0 0 "+s+" 0 ",i<t.length-1&&(s-=e.layout.portArcSpacing,a+=" L "+s+" 0 ")})),a+=" Z"}else a+=" Z";return a}},{key:"setPortPositionsAllNodes",value:function(){var e=this;this.activePipeline.nodes.forEach((function(t){e.setPortPositionsForNode(t)}))}},{key:"setPortPositionsForNode",value:function(e){this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Z?(this.setPortPositionsVertical(e,e.inputs,e.inputPortsWidth,e.layout.inputPortTopPosX,e.layout.inputPortTopPosY),this.setPortPositionsVertical(e,e.outputs,e.outputPortsWidth,e.layout.outputPortBottomPosX,this.getOutputPortBottomPosY(e))):this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.$?(this.setPortPositionsVertical(e,e.inputs,e.inputPortsWidth,e.layout.inputPortBottomPosX,this.getInputPortBottomPosY(e)),this.setPortPositionsVertical(e,e.outputs,e.outputPortsWidth,e.layout.outputPortTopPosX,e.layout.outputPortTopPosY)):(this.setPortPositionsLeftRight(e,e.inputs,e.inputPortsHeight,e.layout.inputPortLeftPosX,e.layout.inputPortLeftPosY),this.setPortPositionsLeftRight(e,e.outputs,e.outputPortsHeight,this.getOutputPortRightPosX(e),e.layout.outputPortRightPosY,this.config.enableSingleOutputPortDisplay))}},{key:"getOutputPortRightPosX",value:function(e){return e.width+e.layout.outputPortRightPosX}},{key:"getOutputPortBottomPosY",value:function(e){return e.height+e.layout.outputPortBottomPosY}},{key:"getInputPortBottomPosY",value:function(e){return e.height+e.layout.inputPortBottomPosY}},{key:"setPortPositionsVertical",value:function(e,t,n,i,o){if(t&&t.length>0)if(e.width<=e.layout.defaultNodeWidth&&1===t.length)t[0].cx=i,t[0].cy=o;else{var a=0;if(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)){var r=e.width-2*this.canvasLayout.supernodeSVGAreaPadding-n;a=2*this.canvasLayout.supernodeSVGAreaPadding+r/2}else n<e.width&&(a=(e.width-n)/2);a+=e.layout.portArcOffset;var s=1;_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSuperBindingNode(e)&&(s=1/this.zoomTransform.k),t.forEach((function(t){a+=e.layout.portArcRadius*s,t.cx=a,t.cy=o,a+=(e.layout.portArcRadius+e.layout.portArcSpacing)*s}))}}},{key:"setPortPositionsLeftRight",value:function(e,t,n,i,o){var a=arguments.length>5&&void 0!==arguments[5]&&arguments[5];t&&t.length>0&&(e.height<=e.layout.defaultNodeHeight&&1===t.length?(t[0].cx=i,t[0].cy=o):a?this.setPortPositionsLeftRightSinglePort(e,t,i,o):this.setPortPositionsLeftRightAllPorts(e,t,n,i,o))}},{key:"setPortPositionsLeftRightAllPorts",value:function(e,t,n,i,o){var a=0;if(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)){var r=e.height-this.canvasLayout.supernodeTopAreaHeight-this.canvasLayout.supernodeSVGAreaPadding-n;a=this.canvasLayout.supernodeTopAreaHeight+this.canvasLayout.supernodeSVGAreaPadding+r/2}else n<e.height&&(a=(e.height-n)/2);a+=e.layout.portArcOffset;var s=1;_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSuperBindingNode(e)&&(s=1/this.zoomTransform.k),t.forEach((function(t){a+=e.layout.portArcRadius*s,t.cx=i,t.cy=a,a+=(e.layout.portArcRadius+e.layout.portArcSpacing)*s}))}},{key:"setPortPositionsLeftRightSinglePort",value:function(e,t,n,i){var o=0;if(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)){var a=e.height-this.canvasLayout.supernodeTopAreaHeight-this.canvasLayout.supernodeSVGAreaPadding;o=this.canvasLayout.supernodeTopAreaHeight+a/2}else o=i;t.forEach((function(e){e.cx=n,e.cy=o}))}},{key:"displayComments",value:function(){this.logger.logStartTimer("displayComments "+this.getFlags()),!this.dragging||this.commentSizing||this.nodeSizing||this.isCommentBeingUpdated?this.selecting||this.regionSelect?this.displayCommentsSelectionStatus():this.displayAllComments():this.displayMovedComments(),this.logger.logEndTimer("displayComments "+this.getFlags())}},{key:"displayMovedComments",value:function(){var e=this;this.getAllCommentGroupsSelection().attr("transform",(function(e){return"translate(".concat(e.x_pos,", ").concat(e.y_pos,")")})).datum((function(t){return e.activePipeline.getComment(t.id)}))}},{key:"displayCommentsSelectionStatus",value:function(){var e=this;this.getAllCommentGroupsSelection().selectChildren(".d3-comment-selection-highlight").attr("data-selected",(function(t){return e.objectModel.isSelected(t.id,e.activePipeline.id)?"yes":"no"})),this.superRenderers.forEach((function(e){e.selecting=!0,e.displayComments(),e.selecting=!1}))}},{key:"displayAllComments",value:function(){var e=this;this.getAllCommentGroupsSelection().data(this.activePipeline.comments,(function(e){return e.id})).join((function(t){return e.createComments(t)})).attr("transform",(function(e){return"translate(".concat(e.x_pos,", ").concat(e.y_pos,")")})).attr("class",(function(t){return e.getCommentGroupClass(t)})).call((function(t){return e.updateComments(t)}))}},{key:"createComments",value:function(e){var t=this,n=e.append("g").attr("data-id",(function(e){return t.getId("comment_grp",e.id)})).call(this.attachCommentGroupListeners.bind(this));return this.config.enableEditingActions&&n.call(this.drag),n.append("rect").attr("class","d3-comment-sizing").call(this.attachCommentSizingListeners.bind(this)),n.append("rect").attr("class","d3-comment-selection-highlight"),n.append("rect").attr("width",(function(e){return e.width})).attr("height",(function(e){return e.height})).attr("x",0).attr("y",0).attr("class","d3-comment-rect"),n.append("foreignObject").attr("class","d3-foreign-object").attr("x",0).attr("y",0).append("xhtml:div").attr("class","d3-comment-text"),n}},{key:"updateComments",value:function(e){var t=this;e.attr("transform",(function(e){return"translate(".concat(e.x_pos,", ").concat(e.y_pos,")")})).attr("class",(function(e){return t.getCommentGroupClass(e)})),e.selectChildren(".d3-comment-sizing").datum((function(e){return t.activePipeline.getComment(e.id)})).attr("x",-this.canvasLayout.commentSizingArea).attr("y",-this.canvasLayout.commentSizingArea).attr("height",(function(e){return e.height+2*t.canvasLayout.commentSizingArea})).attr("width",(function(e){return e.width+2*t.canvasLayout.commentSizingArea})).attr("class","d3-comment-sizing"),e.selectChildren(".d3-comment-selection-highlight").datum((function(e){return t.activePipeline.getComment(e.id)})).attr("x",-this.canvasLayout.commentHighlightGap).attr("y",-this.canvasLayout.commentHighlightGap).attr("height",(function(e){return e.height+2*t.canvasLayout.commentHighlightGap})).attr("width",(function(e){return e.width+2*t.canvasLayout.commentHighlightGap})).attr("data-selected",(function(e){return t.objectModel.isSelected(e.id,t.activePipeline.id)?"yes":"no"})).attr("style",(function(e){return t.getNodeSelectionOutlineStyle(e,"default")})),e.selectChildren(".d3-comment-rect").datum((function(e){return t.activePipeline.getComment(e.id)})).attr("height",(function(e){return e.height})).attr("width",(function(e){return e.width})).attr("class","d3-comment-rect").attr("style",(function(e){return t.getCommentBodyStyle(e,"default")})),e.selectChildren(".d3-foreign-object").datum((function(e){return t.activePipeline.getComment(e.id)})).attr("width",(function(e){return e.width})).attr("height",(function(e){return e.height})).select("div").attr("style",(function(e){return t.getNodeLabelStyle(e,"default")})).html((function(e){return Ui(e.content)}))}},{key:"attachCommentGroupListeners",value:function(e){var t=this;e.on("mouseenter",(function(e,n){t.setCommentStyles(n,"hover",ws.select(e.currentTarget)),t.config.enableEditingActions&&t.createCommentPort(e.currentTarget,n)})).on("mouseleave",(function(e,n){t.setCommentStyles(n,"default",ws.select(e.currentTarget)),t.config.enableEditingActions&&t.deleteCommentPort(e.currentTarget)})).on("mousedown",(function(e,n){t.logger.log("Comment Group - mouse down"),t.config.enableDragWithoutSelect||t.selectObjectD3Event(e,n),t.logger.log("Comment Group - finished mouse down")})).on("click",(function(e,n){t.logger.log("Comment Group - click"),e.stopPropagation()})).on("dblclick",(function(e,n){t.logger.log("Comment Group - double click"),t.config.enableEditingActions&&(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),t.displayCommentTextArea(n,e.currentTarget),t.canvasController.clickActionHandler({clickType:"DOUBLE_CLICK",objectType:"comment",id:n.id,selectedObjectIds:t.objectModel.getSelectedObjectIds(),pipelineId:t.activePipeline.id}))})).on("contextmenu",(function(e,n){t.logger.log("Comment Group - context menu"),t.config.enableDragWithoutSelect&&t.selectObjectD3Event(e,n),t.openContextMenu(e,"comment",n)}))}},{key:"attachCommentSizingListeners",value:function(e){var t=this;e.on("mousedown",(function(e,n){t.commentSizing=!0,t.addTempCursorOverlay(t.commentSizingCursor)})).on("mousemove mouseenter",(function(e,n){if(t.config.enableEditingActions&&!t.isRegionSelectOrSizingInProgress()){var i="pointer";t.isPointerCloseToBodyEdge(e,n)||(t.commentSizingDirection=t.getSizingDirection(e,n,t.canvasLayout.commentCornerResizeArea),t.commentSizingCursor=t.getCursorBasedOnDirection(t.commentSizingDirection),i=t.commentSizingCursor),ws.select(e.currentTarget).style("cursor",i)}}))}},{key:"createCommentPort",value:function(e,t){var n=this;ws.select(e).append("circle").attr("cx",0-this.canvasLayout.commentHighlightGap).attr("cy",0-this.canvasLayout.commentHighlightGap).attr("r",this.canvasLayout.commentPortRadius).attr("class","d3-comment-port-circle").on("mousedown",(function(e,i){_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),n.drawingNewLinkData={srcObjId:t.id,action:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O,startPos:{x:t.x_pos-n.canvasLayout.commentHighlightGap,y:t.y_pos-n.canvasLayout.commentHighlightGap},linkArray:[]},n.drawNewLink(e)}))}},{key:"deleteCommentPort",value:function(e){ws.select(e).selectChildren(".d3-comment-port-circle").remove()}},{key:"setCommentStyles",value:function(e,t,n){this.setCommentSelectionOutlineStyles(e,t,n),this.setCommentBodyStyles(e,t,n),this.setCommentTextStyles(e,t,n)}},{key:"setCommentSelectionOutlineStyles",value:function(e,t,n){var i=this.getCommentSelectionOutlineStyle(e,t);n.selectChildren(".d3-comment-selection-highlight").attr("style",i)}},{key:"setCommentBodyStyles",value:function(e,t,n){var i=this.getCommentBodyStyle(e,t);n.selectChildren(".d3-comment-rect").attr("style",i)}},{key:"setCommentTextStyles",value:function(e,t,n){var i=this.getCommentTextStyle(e,t);n.selectChildren(".d3-foreign-object").select("div").attr("style",i)}},{key:"getCommentSelectionOutlineStyle",value:function(e,t){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getObjectStyle(e,"selection_outline",t)}},{key:"getCommentBodyStyle",value:function(e,t){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getObjectStyle(e,"body",t)}},{key:"getCommentTextStyle",value:function(e,t){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getObjectStyle(e,"text",t)}},{key:"displayCommentTextArea",value:function(e,t){this.displayTextArea({id:e.id,text:e.content,singleLine:!1,maxCharacters:null,allowReturnKey:!0,textCanBeEmpty:!0,xPos:0,yPos:0,width:e.width,height:e.height,className:"d3-comment-entry",parentDomObj:t,autoSizeCallback:this.autoSizeComment.bind(this),saveTextChangesCallback:this.saveCommentChanges.bind(this),closeTextAreaCallback:null})}},{key:"autoSizeComment",value:function(e,t,n){this.logger.log("autoSizeComment - textAreaHt = "+this.textAreaHeight+" scroll ht = "+e.scrollHeight);var i=e.scrollHeight+12;this.textAreaHeight<i&&(this.textAreaHeight=i,t.style("height",this.textAreaHeight+"px"),this.activePipeline.getComment(n.id).height=this.textAreaHeight,this.displayComments(),this.displayLinks())}},{key:"saveCommentChanges",value:function(e,t,n){var i=this.activePipeline.getComment(e),o={editType:"editComment",editSource:"canvas",id:i.id,content:t,width:i.width,height:n,x_pos:i.x_pos,y_pos:i.y_pos,pipelineId:this.activePipeline.id};this.canvasController.editActionHandler(o)}},{key:"displayNodeLabelTextArea",value:function(e,t){ws.select(t).selectAll("div").attr("style","display:none;"),this.displayTextArea({id:e.id,text:e.label,singleLine:e.layout.labelSingleLine,maxCharacters:e.layout.labelMaxCharacters,allowReturnKey:e.layout.labelAllowReturnKey,textCanBeEmpty:!1,xPos:this.nodeUtils.getNodeLabelTextAreaPosX(e),yPos:this.nodeUtils.getNodeLabelTextAreaPosY(e),width:this.nodeUtils.getNodeLabelTextAreaWidth(e),height:this.nodeUtils.getNodeLabelTextAreaHeight(e),className:this.nodeUtils.getNodeLabelTextAreaClass(e),parentDomObj:t,autoSizeCallback:this.autoSizeMultiLineLabel.bind(this),saveTextChangesCallback:this.saveNodeLabelChanges.bind(this),closeTextAreaCallback:this.closeNodeLabelTextArea.bind(this)})}},{key:"autoSizeMultiLineLabel",value:function(e,t,n){this.logger.log("autoSizeNodeLabel - textAreaHt = "+this.textAreaHeight+" scroll ht = "+e.scrollHeight),n.maxCharacters&&e.value.length>n.maxCharacters&&(e.value=e.value.substring(0,n.maxCharacters)),t.style("height",0);var i=e.scrollHeight+12;this.textAreaHeight=i,t.style("height",this.textAreaHeight+"px")}},{key:"saveNodeLabelChanges",value:function(e,t,n,i){var o={editType:"setNodeLabel",editSource:"canvas",nodeId:e,label:t,pipelineId:this.activePipeline.id};this.canvasController.editActionHandler(o)}},{key:"closeNodeLabelTextArea",value:function(e){this.getNodeGroupSelectionById(e).selectAll("div").attr("style",null)}},{key:"displayDecLabelTextArea",value:function(e,t,n,i){this.displayTextArea({id:e.id,text:e.label,singleLine:e.label_single_line||!0,maxCharacters:e.label_max_characters||null,allowReturnKey:e.label_allow_return_key||!1,textCanBeEmpty:!1,xPos:this.decUtils.getDecLabelTextAreaPosX(),yPos:this.decUtils.getDecLabelTextAreaPosY(),width:this.decUtils.getDecLabelTextAreaWidth(e,t,n),height:this.decUtils.getDecLabelTextAreaHeight(e,t,n),className:this.decUtils.getDecLabelTextAreaClass(e),parentDomObj:i,objId:t.id,objType:n,autoSizeCallback:this.autoSizeMultiLineLabel.bind(this),saveTextChangesCallback:this.saveDecLabelChanges.bind(this),closeTextAreaCallback:null})}},{key:"saveDecLabelChanges",value:function(e,t,n,i){var o={editType:"editDecorationLabel",editSource:"canvas",decId:e,objId:i.objId,objType:i.objType,label:t,pipelineId:this.activePipeline.id};this.canvasController.editActionHandler(o)}},{key:"displayTextArea",value:function(e){var t=this;this.textAreaHeight=e.height,this.editingText=!0,this.editingTextId=e.id;var n=ws.select(e.parentDomObj).append("foreignObject").attr("class","d3-foreign-object").attr("width",e.width).attr("height",e.height).attr("x",e.xPos).attr("y",e.yPos),i=n.append("xhtml:textarea").attr("class",e.className).text(zi(e.text)).on("keydown",(function(i){!e.singleLine&&e.allowReturnKey||13!==i.keyCode||_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(i),27===i.keyCode&&(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(i),t.textAreaEscKeyPressed=!0,t.closeTextArea(n,e)),e.maxCharacters&&this.value.length>=e.maxCharacters&&!t.textAreaAllowedKeys(i)&&_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(i)})).on("keyup",(function(t){e.autoSizeCallback(this,n,e)})).on("paste",(function(){t.logger.log("Text area - Paste - Scroll Ht = "+this.scrollHeight),setTimeout(e.autoSizeCallback,500,this,n,e)})).on("blur",(function(i,o){if(t.logger.log("Text area - blur"),t.textAreaEscKeyPressed)t.textAreaEscKeyPressed=!1;else{if(!this.value&&!e.textCanBeEmpty)return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(i),void t.closeTextArea(n,e);var a=this.value;t.closeTextArea(n,e),e.text!==a&&(t.isCommentBeingUpdated=!0,e.saveTextChangesCallback(e.id,a,t.textAreaHeight,e),t.isCommentBeingUpdatd=!1)}})).on("focus",(function(i,o){t.logger.log("Text area - focus"),e.autoSizeCallback(this,n,e)})).on("mousedown click dblclick contextmenu",(function(e,t){e.stopPropagation()}));i.node().focus(),i.node().setSelectionRange(e.text.length,e.text.length)}},{key:"closeTextArea",value:function(e,t){t.closeTextAreaCallback&&t.closeTextAreaCallback(t.id),e.remove(),this.editingText=!1,this.editingTextId=""}},{key:"textAreaAllowedKeys",value:function(e){return 46===e.keyCode||8===e.keyCode||37===e.keyCode||39===e.keyCode||38===e.keyCode||40===e.keyCode||65===e.keyCode&&_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isCmndCtrlPressed(e)}},{key:"addTempCursorOverlay",value:function(e){this.dispUtils.isDisplayingFullPage()&&(this.canvasDiv.selectAll(".d3-temp-cursor-overlay").size()>0&&this.removeTempCursorOverlay(),this.canvasSVG.append("rect").attr("x",0).attr("y",0).attr("width","100%").attr("height","100%").attr("data-pipeline-id",this.activePipeline.id).attr("class","d3-temp-cursor-overlay").attr("pointer-events","all").style("cursor",e))}},{key:"removeTempCursorOverlay",value:function(){this.dispUtils.isDisplayingFullPage()&&this.canvasDiv.selectAll(".d3-temp-cursor-overlay").remove()}},{key:"isRegionSelectOrSizingInProgress",value:function(){return!!(this.regionSelect||this.nodeSizing||this.commentSizing)||!(!this.supernodeInfo.renderer||!this.supernodeInfo.renderer.isRegionSelectOrSizingInProgress())}},{key:"isPointerCloseToBodyEdge",value:function(e,t){var n=this.getTransformedMousePos(e),i=t.x_pos+t.width,o=t.y_pos+t.height,a=n.x>=i&&n.x<=i+1&&n.y>=0&&n.y<=o,r=n.y>=o&&n.y<=o+1&&n.x>=0&&n.x<=i;return a||r}},{key:"getSizingDirection",value:function(e,t,n){var i="",o="",a=this.getTransformedMousePos(e);return a.x<t.x_pos+n?i="w":a.x>t.x_pos+t.width-n&&(i="e"),a.y<t.y_pos+n?o="n":a.y>t.y_pos+t.height-n&&(o="s"),o+i}},{key:"getCursorBasedOnDirection",value:function(e){var t;switch(e){case"n":case"s":t="ns-resize";break;case"e":case"w":t="ew-resize";break;case"nw":case"se":t="nwse-resize";break;case"ne":case"sw":t="nesw-resize";break;default:t=""}return t}},{key:"getMinHeight",value:function(e){if(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSupernode(e)){var t=Math.max(e.inputPortsHeight,e.outputPortsHeight)+this.canvasLayout.supernodeTopAreaHeight+this.canvasLayout.supernodeSVGAreaPadding;return Math.max(this.canvasLayout.supernodeMinHeight,t)}return e.layout.defaultNodeHeight}},{key:"getMinWidth",value:function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSupernode(e)?this.canvasLayout.supernodeMinWidth:e.layout.defaultNodeWidth}},{key:"resizeNode",value:function(e){var t=Object.assign({},this.resizeObj),n=this.getMinHeight(this.resizeObj),i=this.getMinWidth(this.resizeObj),o=this.resizeObject(e,this.resizeObj,this.nodeSizingDirection,i,n);if(o&&(0!==o.x_pos||0!==o.y_pos||0!==o.width||0!==o.height)){if(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSupernode(this.resizeObj)&&this.config.enableMoveNodesOnSupernodeResize){var a=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.moveSurroundingObjects(t,this.activePipeline.getNodesAndComments(),this.nodeSizingDirection,this.resizeObj.width,this.resizeObj.height,!0),r=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.moveSurroundingDetachedLinks(t,this.activePipeline.links,this.nodeSizingDirection,this.resizeObj.width,this.resizeObj.height,!0);this.nodeSizingObjectsInfo=Object.assign(this.nodeSizingObjectsInfo,a),this.nodeSizingLinksInfo=Object.assign(this.nodeSizingLinksInfo,r)}this.displayComments(),this.displayNodes(),this.displayLinks(),_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isSupernode(this.resizeObj)&&(this.dispUtils.isDisplayingSubFlow()&&this.displayBindingNodesToFitSVG(),this.superRenderers.forEach((function(e){return e.displaySVGToFitSupernode()})))}}},{key:"resizeComment",value:function(e){this.resizeObject(e,this.resizeObj,this.commentSizingDirection,20,20),this.displayComments(),this.displayLinks()}},{key:"resizeObject",value:function(e,t,n,i,o){var a=0,r=0,s=0,l=0;n.indexOf("e")>-1&&(s+=e.dx),n.indexOf("s")>-1&&(l+=e.dy),n.indexOf("n")>-1&&(r+=e.dy,l-=e.dy),n.indexOf("w")>-1&&(a+=e.dx,s-=e.dx);var c=0,u=0,d=0,h=0;if(this.config.enableSnapToGridType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a5?(this.notSnappedXPos+=a,this.notSnappedYPos+=r,this.notSnappedWidth+=s,this.notSnappedHeight+=l,c=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.snapToGrid(this.notSnappedXPos,this.canvasLayout.snapToGridXPx),u=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.snapToGrid(this.notSnappedYPos,this.canvasLayout.snapToGridYPx),d=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.snapToGrid(this.notSnappedWidth,this.canvasLayout.snapToGridXPx),h=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.snapToGrid(this.notSnappedHeight,this.canvasLayout.snapToGridYPx)):(c=t.x_pos+a,u=t.y_pos+r,d=t.width+s,h=t.height+l),d<i||h<o)return null;var p={width:d-t.width,height:h-t.height,x_pos:c-t.x_pos,y_pos:u-t.y_pos};return t.x_pos=c,t.y_pos=u,t.width=d,t.height=h,p}},{key:"endNodeSizing",value:function(){this.config.enableSnapToGridType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a6&&(this.resizeObj=this.snapToGridObject(this.resizeObj)),this.resizeObjInitialInfo.x_pos===this.resizeObj.x_pos&&this.resizeObjInitialInfo.y_pos===this.resizeObj.y_pos&&this.resizeObjInitialInfo.width===this.resizeObj.width&&this.resizeObjInitialInfo.height===this.resizeObj.height||(this.nodeSizingObjectsInfo[this.resizeObj.id]={width:this.resizeObj.width,height:this.resizeObj.height,x_pos:this.resizeObj.x_pos,y_pos:this.resizeObj.y_pos},this.resizeObjInitialInfo.width===this.resizeObj.width&&this.resizeObjInitialInfo.height===this.resizeObj.height||(this.nodeSizingObjectsInfo[this.resizeObj.id].isResized=!0,this.nodeSizingObjectsInfo[this.resizeObj.id].resizeWidth=this.resizeObj.width,this.nodeSizingObjectsInfo[this.resizeObj.id].resizeHeight=this.resizeObj.height),this.canvasController.editActionHandler({editType:"resizeObjects",editSource:"canvas",objectsInfo:this.nodeSizingObjectsInfo,linksInfo:this.nodeSizingLinksInfo,pipelineId:this.pipelineId})),this.resizeObj=null,this.nodeSizing=!1,this.nodeSizingObjectsInfo=[],this.nodeSizingLinksInfo=[]}},{key:"endCommentSizing",value:function(){if(this.config.enableSnapToGridType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a6&&(this.resizeObj=this.snapToGridObject(this.resizeObj)),this.resizeObjInitialInfo.x_pos!==this.resizeObj.x_pos||this.resizeObjInitialInfo.y_pos!==this.resizeObj.y_pos||this.resizeObjInitialInfo.width!==this.resizeObj.width||this.resizeObjInitialInfo.height!==this.resizeObj.height){var e={editType:"editComment",editSource:"canvas",id:this.resizeObj.id,content:this.resizeObj.content,width:this.resizeObj.width,height:this.resizeObj.height,x_pos:this.resizeObj.x_pos,y_pos:this.resizeObj.y_pos,pipelineId:this.pipelineId};this.canvasController.editActionHandler(e)}this.commentSizing=!1}},{key:"displayLinks",value:function(){this.logger.logStartTimer("displayLinks "+this.getFlags()),this.selecting||this.regionSelect?this.displayLinksSelectionStatus():this.displayAllLinks(),this.logger.logEndTimer("displayLinks "+this.getFlags())}},{key:"displayLinksSelectionStatus",value:function(){var e=this;this.config.enableLinkSelection!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ac&&(this.getAllLinkGroupsSelection().attr("data-selected",(function(t){return!!e.objectModel.isSelected(t.id,e.activePipeline.id)||null})),this.superRenderers.forEach((function(e){e.selecting=!0,e.displayLinks(),e.selecting=!1})))}},{key:"displayAllLinks",value:function(){var e=this,t=this.buildLinksArray();this.getAllLinkGroupsSelection().data(t,(function(e){return e.id})).join((function(t){return e.createLinks(t)})).attr("class",(function(t){return e.getLinkGroupClass(t)})).attr("style",(function(t){return e.getLinkGrpStyle(t)})).attr("data-selected",(function(t){return!!e.objectModel.isSelected(t.id,e.activePipeline.id)||null})).call((function(n){e.updateLinks(n,t)}))}},{key:"createLinks",value:function(e){var t=this,n=e.append("g").attr("data-id",(function(e){return t.getId("link_grp",e.id)})).call(this.attachLinkGroupListeners.bind(this));return n.append("path").attr("class",(function(e){return t.getLinkSelectionAreaClass(e)})),n.append("path").attr("class","d3-link-line"),n.filter((function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H&&t.canvasLayout.dataLinkArrowHead||e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O&&t.canvasLayout.commentLinkArrowHead||e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H&&t.canvasLayout.linkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Q})).append("path").attr("class","d3-link-line-arrow-head"),n.append("g").attr("class","d3-link-decorations-group"),this.config.enableLinkSelection!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ak&&this.config.enableLinkSelection!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a7||n.append("g").attr("class","d3-link-handles-group").each((function(e,n,i){e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H&&t.createNewHandles(ws.select(i[n]))})),n}},{key:"updateLinks",value:function(e,t){var n=this;e.selectAll(".d3-link-selection-area").datum((function(e){return n.activePipeline.getLink(e.id)})).attr("d",(function(e){return e.pathInfo.path})),e.selectAll(".d3-link-line").datum((function(e){return n.activePipeline.getLink(e.id)})).attr("d",(function(e){return e.pathInfo.path})).attr("class","d3-link-line").attr("style",(function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getObjectStyle(e,"line","default")})),e.filter((function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H&&n.canvasLayout.dataLinkArrowHead||e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O&&n.canvasLayout.commentLinkArrowHead||e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H&&n.canvasLayout.linkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Q})).selectAll(".d3-link-line-arrow-head").datum((function(e){return n.activePipeline.getLink(e.id)})).attr("d",(function(e){return n.getArrowHead(e)})).attr("transform",(function(e){return n.getArrowHeadTransform(e)})).attr("class","d3-link-line-arrow-head").attr("style",(function(e){return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getObjectStyle(e,"line","default")})),e.each((function(e,t,i){e.type!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H&&e.type!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K||n.displayDecorations(e,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a4,ws.select(i[t]).selectAll(".d3-link-decorations-group"),e.decorations)})),this.config.enableLinkSelection!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ak&&this.config.enableLinkSelection!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a7||e.each((function(e,i,o){e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H&&n.updateHandles(ws.select(o[i]).selectAll(".d3-link-handles-group"),t)})),this.dragging||this.setDisplayOrder(e)}},{key:"attachLinkGroupListeners",value:function(e){var t=this;e.on("mousedown",(function(e,n,i,o){t.logger.log("Link Group - mouse down"),t.config.enableLinkSelection!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ac&&t.selectObjectD3Event(e,n),e.stopPropagation()})).on("mouseup",(function(){t.logger.log("Link Group - mouse up")})).on("click",(function(e,n){t.logger.log("Link Group - click"),e.stopPropagation()})).on("contextmenu",(function(e,n){t.logger.log("Link Group - context menu"),t.config.enableLinkSelection!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ac&&t.selectObjectD3Event(e,n),t.openContextMenu(e,"link",n)})).on("mouseenter",(function(e,n){var i=e.currentTarget;t.config.enableLinkSelection!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ak&&t.config.enableLinkSelection!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a7||t.raiseLinkToTop(i),t.setLinkLineStyles(i,n,"hover"),t.canOpenTip(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.w)&&!t.draggingLinkData&&t.canvasController.openTip({id:t.getId("link_tip",n.id),type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.w,targetObj:i,mousePos:{x:e.clientX,y:e.clientY},pipelineId:t.activePipeline.id,link:n})})).on("mouseleave",(function(e,n){var i=e.currentTarget;i.getAttribute("data-selected")||t.lowerLinkToBottom(i),t.setLinkLineStyles(i,n,"default"),t.canvasController.closeTip()}))}},{key:"createNewHandles",value:function(e){var t=this,n=e.append(this.canvasLayout.linkStartHandleObject).attr("class",(function(e){return"d3-link-handle-start"})).on("mousedown",(function(e,n){t.logger.log("Link start handle - mouse down"),t.config.enableDragWithoutSelect||t.selectObjectD3Event(e,n),t.logger.log("Link end handle - finished mouse down")}));this.config.enableEditingActions&&n.call(this.dragSelectionHandle);var i=e.append(this.canvasLayout.linkEndHandleObject).attr("class",(function(e){return"d3-link-handle-end"})).on("mousedown",(function(e,n){t.logger.log("Link end handle - mouse down"),t.config.enableDragWithoutSelect||t.selectObjectD3Event(e,n),t.logger.log("Link end handle - finished mouse down")}));this.config.enableEditingActions&&i.call(this.dragSelectionHandle)}},{key:"updateHandles",value:function(e,t){var n=this;e.selectAll(".d3-link-handle-start").datum((function(e){return n.activePipeline.getLink(e.id)})).each((function(e,t,i){var o=ws.select(i[t]);"image"===n.canvasLayout.linkStartHandleObject?o.attr("xlink:href",n.canvasLayout.linkStartHandleImage).attr("x",(function(e){return e.x1-n.canvasLayout.linkStartHandleWidth/2})).attr("y",(function(e){return e.y1-n.canvasLayout.linkStartHandleHeight/2})).attr("width",n.canvasLayout.linkStartHandleWidth).attr("height",n.canvasLayout.linkStartHandleHeight):"circle"===n.canvasLayout.linkStartHandleObject&&o.attr("r",n.canvasLayout.linkStartHandleRadius).attr("cx",(function(e){return e.x1})).attr("cy",(function(e){return e.y1}))})),e.selectAll(".d3-link-handle-end").datum((function(e){return n.activePipeline.getLink(e.id)})).each((function(e,t,i){var o=ws.select(i[t]);"image"===n.canvasLayout.linkEndHandleObject?o.attr("xlink:href",n.canvasLayout.linkEndHandleImage).attr("x",(function(e){return e.x2-n.canvasLayout.linkEndHandleWidth/2})).attr("y",(function(e){return e.y2-n.canvasLayout.linkEndHandleHeight/2})).attr("width",n.canvasLayout.linkEndHandleWidth).attr("height",n.canvasLayout.linkEndHandleHeight).attr("transform",(function(e){return n.getLinkImageTransform(e)})):"circle"===n.canvasLayout.linkEndHandleObject&&o.attr("r",n.canvasLayout.linkEndHandleRadius).attr("cx",(function(e){return e.x2})).attr("cy",(function(e){return e.y2}))}))}},{key:"setLinkLineStyles",value:function(e,t,n){var i=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getObjectStyle(t,"line",n),o=ws.select(e);o.select(".d3-link-line").attr("style",i),o.select(".d3-link-line-arrow-head").attr("style",i)}},{key:"getLinkSelectionAreaClass",value:function(e){return"d3-link-selection-area "+(e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K?"d3-association-link-selection-area":e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O?"d3-comment-link-selection-area":"d3-data-link-selection-area")}},{key:"getLinkGroupClass",value:function(e){return"d3-link-group "+this.getLinkTypeClass(e)+" "+this.getLinkCustomClass(e)}},{key:"getLinkCustomClass",value:function(e){return e.class_name&&"canvas-data-link"!==e.class_name&&"canvas-object-link"!==e.class_name&&"canvas-comment-link"!==e.class_name&&"d3-data-link"!==e.class_name&&"d3-association-link"!==e.class_name&&"d3-object-link"!==e.class_name&&"d3-comment-link"!==e.class_name?e.class_name:""}},{key:"getLinkTypeClass",value:function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K?this.config.enableAssocLinkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.M?"d3-association-link":"d3-object-link":e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O?"d3-comment-link":"d3-data-link"}},{key:"getCommentGroupClass",value:function(e){var t="";return e.class_name&&"canvas-comment"!==e.class_name&&"d3-comment-rect"!==e.class_name&&(t=" "+e.class_name),"d3-comment-group"+(this.config.enableEditingActions?" d3-draggable":" d3-non-draggable")+t}},{key:"getNodeGroupClass",value:function(e){var t="";return e.class_name&&"canvas-node"!==e.class_name&&"d3-node-body"!==e.class_name&&"d3-node-body-outline"!==e.class_name&&(t=" "+e.class_name),"d3-node-group"+(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isExpandedSupernode(e)?" d3-node-supernode-expanded":"")+(this.config.enableEditingActions?" d3-draggable":" d3-non-draggable")+t}},{key:"setDisplayOrder",value:function(e){var t=this;e.filter((function(e){return t.hasOneDecorationOrMore(e)})).lower(),e.filter((function(e){return!t.hasOneDecorationOrMore(e)})).lower(),this.config.enableLinkSelection!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ak&&this.config.enableLinkSelection!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a7||this.raiseSelectedLinksToTop()}},{key:"raiseNodeToTop",value:function(e){null!==this.drawingNewLinkData||this.dragging||0!==this.getSelectedLinks().length||e.raise()}},{key:"raiseSelectedLinksToTop",value:function(){this.nodesLinksGrp.selectAll(".d3-link-group[data-selected]").raise()}},{key:"raiseLinkToTop",value:function(e){ws.select(e).raise()}},{key:"lowerLinkToBottom",value:function(e){ws.select(e).lower()}},{key:"hasOneDecorationOrMore",value:function(e){return e.decorations&&e.decorations.length>0}},{key:"isLinkBeingDragged",value:function(e){return this.draggingLinkData&&this.draggingLinkData.link.id===e.id}},{key:"buildLinksArray",value:function(){var e=this,t=[];return this.canvasLayout.linkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Q&&this.updateLinksForNodes(),this.activePipeline.links.forEach((function(n){var i=null;(i=!(e.config.enableLinkSelection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ak&&e.isLinkBeingDragged(n)||e.config.enableLinkSelection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a7)||n.srcObj&&n.trgNode?e.getAttachedLineObj(n):e.getDetachedLineObj(n))&&t.push(i)})),this.canvasLayout.linkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.J&&(t=this.addMinInitialLineForElbow(t)),t=this.linkUtils.addConnectionPaths(t)}},{key:"getAttachedLineObj",value:function(e){var t=e.srcObj,n=e.trgNode;if(t||this.logger.error("Common Canvas error trying to draw a link. A link was specified for source ID '"+e.srcNodeId+"' in the Canvas data that does not have a valid source node/comment."),n||this.logger.error("Common Canvas error trying to draw a link. A link was specified for target ID '"+e.trgNodeId+"' in the Canvas data that does not have a valid target node."),t&&n&&this.shouldDisplayLink(t,n,e.type)){var i=this.getSourcePortId(e,t),o=this.getTargetPortId(e,n),a=e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.K&&this.config.enableAssocLinkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.M?this.getAssocLinkVariation(t,n):null,r=this.linkUtils.getLinkCoords(e,t,i,n,o,a);return e.assocLinkVariation=a,e.srcPortId=i,e.trgPortId=o,e.x1=r.x1,e.y1=r.y1,e.x2=r.x2,e.y2=r.y2,e}return null}},{key:"getDetachedLineObj",value:function(e){var t=e.srcObj,n=e.trgNode,i=null,o=null,a={};if(t)if(this.canvasLayout.linkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Q){var r={x:e.trgPos.x_pos,y:e.trgPos.y_pos},s=this.linkUtils.getNewStraightNodeLinkStartPos(t,r,e.srcOriginInfo);a.x1=s.x,a.y1=s.y}else{i=this.getSourcePortId(e,t);var l=this.getOutputPort(t,i);l&&(a.x1=t.x_pos+l.cx,a.y1=t.y_pos+l.cy)}else a.x1=e.srcPos.x_pos,a.y1=e.srcPos.y_pos;if(n)if(this.canvasLayout.linkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Q){var c={x:e.srcPos.x_pos,y:e.srcPos.y_pos},u=this.linkUtils.getNewStraightNodeLinkStartPos(n,c,e.trgOriginInfo);a.x2=u.x,a.y2=u.y}else{o=this.getTargetPortId(e,n);var d=this.getInputPort(n,o);d&&(a.x2=n.x_pos+d.cx,a.y2=n.y_pos+d.cy)}else a.x2=e.trgPos.x_pos,a.y2=e.trgPos.y_pos;return e.srcPortId=i,e.trgPortId=o,e.x1=a.x1,e.y1=a.y1,e.x2=a.x2,e.y2=a.y2,e}},{key:"getOutputPort",value:function(e,t){return e&&e.outputs?e.outputs.find((function(e){return e.id===t})):null}},{key:"getInputPort",value:function(e,t){return e&&e.inputs?e.inputs.find((function(e){return e.id===t})):null}},{key:"getSourcePortId",value:function(e,t){return e.srcNodePortId?e.srcNodePortId:t.outputs&&t.outputs.length>0?t.outputs[0].id:null}},{key:"getTargetPortId",value:function(e,t){return e.trgNodePortId?e.trgNodePortId:t.inputs&&t.inputs.length>0?t.inputs[0].id:null}},{key:"shouldDisplayLink",value:function(e,t,n){return!1!==this.canvasLayout.displayLinkOnOverlap||!this.areLinkedObjectsOverlapping(e,t,n)}},{key:"areLinkedObjectsOverlapping",value:function(e,t,n){var i=n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O?this.canvasLayout.commentHighlightGap:e.layout.nodeHighlightGap,o=t.layout.nodeHighlightGap,a=e.x_pos-i,r=e.x_pos+e.width+i,s=t.x_pos-o,l=t.x_pos+t.width+o,c=e.y_pos-i,u=e.y_pos+e.height+i,d=t.y_pos-o,h=t.y_pos+t.height+o;return r>=s&&l>=a&&u>=d&&h>=c}},{key:"addMinInitialLineForElbow",value:function(e){var t=this;return this.activePipeline.nodes.forEach((function(n){if(n.outputs&&n.outputs.length>1){var i=t.getNodeOutputLinks(n,e),o=t.sortNodeOutputLinks(i);t.applyMinInitialLine(n,o)}})),e}},{key:"getNodeOutputLinks",value:function(e,t){var n=[];return t.forEach((function(t){t.srcObj&&t.srcObj.id===e.id&&n.push(t)})),n}},{key:"sortNodeOutputLinks",value:function(e){var t=this;return e.sort((function(e,n){var i,o;return t.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.al?(i=Math.abs(e.y1-e.y2),o=Math.abs(n.y1-n.y2)):(i=Math.abs(e.x1-e.x2),o=Math.abs(n.x1-n.x2)),i===o?t.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.al?e.y1<e.y2?1:-1:e.x1<e.x2?1:-1:i<o?1:-1}))}},{key:"applyMinInitialLine",value:function(e,t){var n=e.layout.minInitialLine;t.forEach((function(e){e.minInitialLineForElbow=n,n+=e.srcObj.layout.minInitialLineIncrement}))}},{key:"updateLinksForNodes",value:function(){var e=this;this.activePipeline.nodes.forEach((function(t){return e.updateLinksForNode(t)}))}},{key:"updateLinksForNode",value:function(e){var t=this,n={n:[],s:[],e:[],w:[]};this.activePipeline.links.forEach((function(i){if(i.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.H)if(i.trgNode&&i.trgNode.id===e.id){if(i.srcObj){var o=t.getDirAdjusted(i.trgNode,i.srcObj);n[o].push({type:"in",endNode:i.srcObj,link:i})}else if(i.srcPos){var a=t.getDirToEndPos(i.trgNode,i.srcPos.x_pos,i.srcPos.y_pos);n[a].push({type:"in",x:i.srcPos.x_pos,y:i.srcPos.y_pos,link:i})}}else if(i.srcObj&&i.srcObj.id===e.id)if(i.trgNode){var r=t.getDirAdjusted(i.srcObj,i.trgNode);n[r].push({type:"out",endNode:i.trgNode,link:i})}else if(i.trgPos){var s=t.getDirToEndPos(i.srcObj,i.trgPos.x_pos,i.trgPos.y_pos);n[s].push({type:"out",x:i.trgPos.x_pos,y:i.trgPos.y_pos,link:i})}})),n.n=this.sortLinksInfo(n.n,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.R),n.s=this.sortLinksInfo(n.s,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.V),n.e=this.sortLinksInfo(n.e,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.X),n.w=this.sortLinksInfo(n.w,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Y),this.updateLinksInfo(n.n,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.R),this.updateLinksInfo(n.s,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.V),this.updateLinksInfo(n.e,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.X),this.updateLinksInfo(n.w,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Y)}},{key:"getDirAdjusted",value:function(e,t){var n=this.getDirToNode(e,t);if(n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.V)this.getDirToNode(t,e)===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Y&&(n=_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.X);else if(n===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.R){this.getDirToNode(t,e)===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.X&&(n=_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Y)}return n}},{key:"getDirToNode",value:function(e,t){var n=this.nodeUtils.getNodeCenterPosX(t),i=this.nodeUtils.getNodeCenterPosY(t);return this.getDirToEndPos(e,n,i)}},{key:"getDirToEndPos",value:function(e,t,n){var i=this.nodeUtils.getNodeCenterPosX(e),o=this.nodeUtils.getNodeCenterPosY(e),a=e.x_pos,r=e.y_pos,s=e.width,l=e.height;return _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.getDir(a,r,s,l,i,o,t,n)}},{key:"sortLinksInfo",value:function(e,t){var n=this,i=e;if(i.length>1){var o=this.getLinkInfoGroups(i);ji(o,(function(e){e.forEach((function(i,o){var a=i.endNode,r=e.length+1;t===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.R||t===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.V?(i.x=a.x_pos+a.width/r*(o+1),i.y=n.nodeUtils.getNodeCenterPosY(a)):(i.x=n.nodeUtils.getNodeCenterPosX(a),i.y=a.y_pos+a.height/r*(o+1))}))})),i=t===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.R||t===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.V?i.sort((function(e,t){return e.x>t.x?1:-1})):i.sort((function(e,t){return e.y>t.y?1:-1}))}return i}},{key:"getLinkInfoGroups",value:function(e){var t={};return e.forEach((function(e){e.endNode&&(t[e.endNode.id]||(t[e.endNode.id]=[]),t[e.endNode.id].push(e))})),t}},{key:"updateLinksInfo",value:function(e,t){e.forEach((function(n,i){"out"===n.type?n.link.srcOriginInfo={dir:t,idx:i,len:e.length}:n.link.trgOriginInfo={dir:t,idx:i,len:e.length}}))}},{key:"getNewLinkAssocVariation",value:function(e,t,n){return"input"===n&&e>t?_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a1:"output"===n&&e<t?_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a0:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a3}},{key:"getAssocLinkVariation",value:function(e,t){var n=e.layout.minInitialLine;return t.x_pos>=e.x_pos+e.width+n?_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a0:e.x_pos>=t.x_pos+t.width+n?_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a1:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.a3}},{key:"getPortArrowPath",value:function(e){return"M -2 3 L 2 0 -2 -3"}},{key:"getPortArrowPathTransform",value:function(e){var t=this.getAngleBasedOnLinkDirection();return"translate(".concat(e.cx,", ").concat(e.cy,") rotate(").concat(t,")")}},{key:"getArrowHead",value:function(e){return e.type===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.O?"string"==typeof this.canvasLayout.commentLinkArrowHead?this.canvasLayout.commentLinkArrowHead:"M -8 3 L 0 0 -8 -3":"string"==typeof this.canvasLayout.dataLinkArrowHead?this.canvasLayout.dataLinkArrowHead:"M -6 6 L 0 0 -6 -6"}},{key:"getArrowHeadTransform",value:function(e){var t=this.canvasLayout.linkType===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.J?this.getAngleBasedOnLinkDirection():Math.atan2(e.y2-e.y1,e.x2-e.x1)*(180/Math.PI);return"translate(".concat(e.x2,", ").concat(e.y2,") rotate(").concat(t,")")}},{key:"getAngleBasedOnLinkDirection",value:function(){return this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.Z?90:this.canvasLayout.linkDirection===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.$?-90:0}},{key:"getSelectedNodesAndComments",value:function(){var e=this,t=[];return this.activePipeline.nodes.forEach((function(n){e.objectModel.getSelectedObjectIds().includes(n.id)&&t.push(n)})),this.activePipeline.comments.forEach((function(n){e.objectModel.getSelectedObjectIds().includes(n.id)&&t.push(n)})),t}},{key:"getSelectedLinks",value:function(){var e=this,t=[];return this.activePipeline.links.forEach((function(n){e.objectModel.getSelectedObjectIds().includes(n.id)&&t.push(n)})),t}},{key:"canOpenTip",value:function(e){return this.canvasController.isTipEnabled(e)&&!this.selecting&&!this.regionSelect&&!this.dragging&&!this.commentSizing&&!this.nodeSizing&&!this.drawingNewLinkData}},{key:"getSvgViewportOffset",value:function(){var e=this.canvasLayout.addCommentOffset,t=this.canvasLayout.addCommentOffset;return this.zoomTransform&&(e=this.zoomTransform.x/this.zoomTransform.k,t=this.zoomTransform.y/this.zoomTransform.k,e=-e+this.canvasLayout.addCommentOffset,t=-t+this.canvasLayout.addCommentOffset),{x_pos:e,y_pos:t}}},{key:"getFlags",value:function(){var e="Flags:";return this.dragging&&(e+=" dragging = true"),this.nodeSizing&&(e+=" nodeSizing = true"),this.commentSizing&&(e+=" commentSizing = true"),this.movingBindingNodes&&(e+=" movingBindingNodes = true"),this.selecting&&(e+=" selecting = true"),this.regionSelect&&(e+=" regionSelect = true"),"Flags:"===e&&(e+=" None"),e}}]),n}(),xs=function(){function n(t,i,o,a){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,n),this.logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_12__.L(["SVGCanvasD3","FlowId",t.id]),this.logger.logStartTimer("constructor"),this.canvasController=a,this.canvasDiv=Pi(i),this.logger.logEndTimer("constructor",!0)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(n,[{key:"setCanvasInfo",value:function(e,t){if(this.logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_12__.L(["SVGCanvasD3","FlowId",e.id]),this.config&&this.renderer&&this.canvasInfo&&e.id===this.canvasInfo.id&&(!this.renderer||this.renderer.pipelineId===this.canvasController.getCurrentBreadcrumb().pipelineId)&&_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.b.compareCanvasConfigs(this.config,t))this.logger.logStartTimer("set canvas info"),this.canvasInfo=this.cloneCanvasInfo(e),this.renderer.setCanvasInfoRenderer(this.canvasInfo),this.logger.logEndTimer("set canvas info",!0);else{this.logger.logStartTimer("initializing"),this.canvasInfo=this.cloneCanvasInfo(e),this.config=this.cloneConfig(t),this.renderer&&(this.renderer.clearCanvas(),this.renderer=null);var n=this.canvasController.getCurrentBreadcrumb();this.renderer=new Ls(n.pipelineId,this.canvasDiv,this.canvasController,this.canvasInfo,t,{id:n.supernodeId,pipelineId:n.supernodeParentPipelineId}),this.logger.logEndTimer("initializing",!0)}}},{key:"cloneConfig",value:function(e){return Object.assign({},e)}},{key:"cloneCanvasInfo",value:function(e){return (0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_20__.d)(e)}},{key:"isEditingText",value:function(){return this.renderer.isEditingText()}},{key:"isDragging",value:function(){return this.renderer.isDragging()}},{key:"convertPageCoordsToSnappedCanvasCoords",value:function(e){var t=this.renderer.convertPageCoordsToCanvasCoords(e.x,e.y);return t=this.renderer.getMousePosSnapToGrid(t)}},{key:"nodeTemplateDragStart",value:function(e){this.renderer.nodeTemplateDragStart(e)}},{key:"nodeTemplateDragOver",value:function(e,t,n){this.renderer.nodeTemplateDragOver(e,t,n)}},{key:"nodeTemplateDragEnd",value:function(e){this.renderer.nodeTemplateDragEnd(e)}},{key:"nodeTemplateDropped",value:function(e,t,n){this.renderer.nodeTemplateDropped(e,t,n)}},{key:"externalObjectDropped",value:function(e,t,n){this.renderer.externalObjectDropped(e,t,n)}},{key:"zoomTo",value:function(e){this.renderer.zoomTo(e)}},{key:"translateBy",value:function(e,t,n){this.renderer.translateBy(e,t,n)}},{key:"zoomIn",value:function(){this.renderer.zoomIn()}},{key:"zoomOut",value:function(){this.renderer.zoomOut()}},{key:"zoomToFit",value:function(){this.renderer.zoomToFit()}},{key:"isZoomedToMax",value:function(){return!!this.renderer&&this.renderer.isZoomedToMax()}},{key:"isZoomedToMin",value:function(){return!!this.renderer&&this.renderer.isZoomedToMin()}},{key:"getZoomToReveal",value:function(e,t,n){return this.renderer?this.renderer.getZoomToReveal(e,t,n):null}},{key:"getZoom",value:function(){return this.renderer?this.renderer.getZoom():null}},{key:"refreshOnSizeChange",value:function(){this.renderer&&this.renderer.refreshOnSizeChange()}},{key:"getSvgViewportOffset",value:function(){return this.renderer.getSvgViewportOffset()}},{key:"getTransformedViewportDimensions",value:function(){return this.renderer.getTransformedViewportDimensions()}},{key:"getGhostNode",value:function(e){return this.renderer.getGhostNode(e)}}]),n}();function Ns(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var Ss=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,i);var o=Ns(s);function s(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(n=o.call(this,t)).state={isDropZoneDisplayed:!1},n.logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_12__.L("CC-Contents"),n.mainCanvasDivId="canvas-div-"+n.props.canvasController.getInstanceId(),n.svgCanvasDivId="d3-svg-canvas-div-"+n.props.canvasController.getInstanceId(),n.svgCanvasDivSelector="#"+n.svgCanvasDivId,n.dragX=null,n.dragY=null,n.eventListenersAdded=!1,n.mousePos={x:0,y:0},n.drop=n.drop.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.focusOnCanvas=n.focusOnCanvas.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.setIsDropZoneDisplayed=n.setIsDropZoneDisplayed.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.dragOver=n.dragOver.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.dragEnter=n.dragEnter.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.dragLeave=n.dragLeave.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.refreshOnSizeChange=n.refreshOnSizeChange.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.getLabel=n.getLabel.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onCut=n.onCut.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onCopy=n.onCopy.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onPaste=n.onPaste.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onKeyDown=n.onKeyDown.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onMouseMove=n.onMouseMove.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.first=!1,n.second=!1,n.afterUpdateCallbacks=[],t.canvasController.setCanvasContents((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"componentDidMount",value:function(){this.logger.log("componentDidMount"),this.svgCanvasD3=new xs(this.props.canvasInfo,this.svgCanvasDivSelector,this.props.canvasConfig,this.props.canvasController),this.svgCanvasD3.setCanvasInfo(this.props.canvasInfo,this.props.canvasConfig),this.props.canvasConfig.enableBrowserEditMenu&&this.addEventListeners(),this.focusOnCanvas()}},{key:"componentDidUpdate",value:function(){this.logger.log("componentDidUpdate"),this.svgCanvasD3&&!this.isDropZoneDisplayed()&&(this.svgCanvasD3.setCanvasInfo(this.props.canvasInfo,this.props.canvasConfig),this.afterUpdate()),this.props.canvasConfig.enableBrowserEditMenu?this.addEventListeners():this.removeEventListeners()}},{key:"componentWillUnmount",value:function(){this.removeEventListeners()}},{key:"onCut",value:function(e){e.currentTarget.activeElement.id===this.svgCanvasDivId&&this.props.canvasConfig.enableEditingActions&&(e.preventDefault(),this.props.canvasController.cutToClipboard())}},{key:"onCopy",value:function(e){e.currentTarget.activeElement.id===this.svgCanvasDivId&&this.props.canvasConfig.enableEditingActions&&(e.preventDefault(),this.props.canvasController.copyToClipboard())}},{key:"onPaste",value:function(e){e.currentTarget.activeElement.id===this.svgCanvasDivId&&this.props.canvasConfig.enableEditingActions&&(e.preventDefault(),this.props.canvasController.pasteFromClipboard())}},{key:"onKeyDown",value:function(e){this.props.canvasController.closeTip();var t=this.props.canvasController.getKeyboardConfig().actions;if(!this.svgCanvasD3.isEditingText()&&!this.svgCanvasD3.isDragging()){if(this.props.canvasConfig.enableEditingActions)if(8!==e.keyCode&&46!==e.keyCode||!t.delete){if(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isCmndCtrlPressed(e)&&!e.shiftKey&&90===e.keyCode&&t.undo)_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),this.props.canvasController.keyboardActionHandler("undo");else if(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isCmndCtrlPressed(e)&&(e.shiftKey&&90===e.keyCode||89===e.keyCode&&t.redo))_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),this.props.canvasController.keyboardActionHandler("redo");else if(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isCmndCtrlPressed(e)&&67===e.keyCode&&t.copyToClipboard)_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),this.props.canvasController.keyboardActionHandler("copy");else if(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isCmndCtrlPressed(e)&&88===e.keyCode&&t.cutToClipboard)_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),this.props.canvasController.keyboardActionHandler("cut");else if(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isCmndCtrlPressed(e)&&86===e.keyCode&&t.pasteFromClipboard)if(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),this.mousePos){var n=this.svgCanvasD3.convertPageCoordsToSnappedCanvasCoords(this.mousePos);this.props.canvasController.keyboardActionHandler("paste",n)}else this.props.canvasController.keyboardActionHandler("paste")}else _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),this.props.canvasController.keyboardActionHandler("deleteSelectedObjects");_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isCmndCtrlPressed(e)&&65===e.keyCode&&t.selectAll?(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),this.props.canvasController.keyboardActionHandler("selectAll")):_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.isCmndCtrlPressed(e)&&e.shiftKey&&e.altKey&&80===e.keyCode&&(_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.a.stopPropagationAndPreventDefault(e),_canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_12__.L.switchLoggingState())}}},{key:"onMouseMove",value:function(e){e.target&&e.target.className&&("svg-area"===e.target.className.baseVal||"d3-svg-background"===e.target.className.baseVal)?this.mousePos={x:e.clientX,y:e.clientY}:this.mousePos=null}},{key:"getLabel",value:function(e){return this.props.intl.formatMessage({id:e,defaultMessage:_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.d[e]})}},{key:"getDNDJson",value:function(e){try{return JSON.parse(e.dataTransfer.getData(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.D))}catch(e){return this.logger.warn("The dragged object's data does not conform to the expected internal format: "+e),null}}},{key:"getSVGCanvasD3",value:function(){return this.svgCanvasD3}},{key:"getStateTag",value:function(){var e=null;return this.props.canvasConfig.enableStateTag!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.B&&this.props.canvasConfig.enableStateTag!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.A||(e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(sn,{stateTagType:this.props.canvasConfig.enableStateTag,canvasController:this.props.canvasController})),e}},{key:"getEmptyCanvas",value:function(){var e=null;return this.props.canvasController.isPrimaryPipelineEmpty()&&(e=this.props.canvasConfig.emptyCanvasContent?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"empty-canvas"},this.props.canvasConfig.emptyCanvasContent):react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"empty-canvas"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"empty-canvas-image"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_21__.FlowData16,null)),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{className:"empty-canvas-text1"},this.getLabel("canvas.flowIsEmpty")),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{className:"empty-canvas-text2"},this.getLabel("canvas.addNodeToStart")))),e}},{key:"getContextMenu",value:function(){return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(an,{canvasController:this.props.canvasController,containingDivId:this.mainCanvasDivId})}},{key:"getDropZone",value:function(){var e=null;return this.isDropZoneDisplayed()&&(e=this.props.canvasConfig.dropZoneCanvasContent?this.props.canvasConfig.dropZoneCanvasContent:react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"dropzone-canvas"}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"dropzone-canvas-rect"}))),e}},{key:"getSVGCanvasDiv",value:function(){return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{tabIndex:"-1",className:"d3-svg-canvas-div",id:this.svgCanvasDivId,onKeyDown:this.onKeyDown})}},{key:"setIsDropZoneDisplayed",value:function(e){e!==this.state.isDropZoneDisplayed&&this.setState({isDropZoneDisplayed:e})}},{key:"isDropZoneDisplayed",value:function(){return this.props.canvasConfig.enableDropZoneOnExternalDrag&&this.state.isDropZoneDisplayed}},{key:"isDataTypeBeingDraggedFile",value:function(e){return!(!e.dataTransfer||!Array.isArray(e.dataTransfer.types))&&e.dataTransfer.types.includes("Files")}},{key:"afterUpdate",value:function(){this.afterUpdateCallbacks.forEach((function(e){return e()}))}},{key:"addAfterUpdateCallback",value:function(e){-1===this.afterUpdateCallbacks.findIndex((function(t){return t===e}))&&this.afterUpdateCallbacks.push(e)}},{key:"removeAfterUpdateCallback",value:function(e){var t=this.afterUpdateCallbacks.findIndex((function(t){return t===e}));t>-1&&this.afterUpdateCallbacks.splice(t,1)}},{key:"addEventListeners",value:function(){this.eventListenersAdded||(document.addEventListener("cut",this.onCut,!0),document.addEventListener("copy",this.onCopy,!0),document.addEventListener("paste",this.onPaste,!0),document.addEventListener("mousemove",this.onMouseMove,!0),this.eventListenersAdded=!0)}},{key:"removeEventListeners",value:function(){this.eventListenersAdded&&(document.removeEventListener("cut",this.onCut,!0),document.removeEventListener("copy",this.onCopy,!0),document.removeEventListener("paste",this.onPaste,!0),document.removeEventListener("mousemove",this.onMouseMove,!0),this.eventListenersAdded=!1)}},{key:"drop",value:function(e){if(e.preventDefault(),this.setIsDropZoneDisplayed(!1),this.first=!1,this.second=!1,this.props.canvasConfig.enableEditingActions){var t=this.props.canvasController.getDragNodeTemplate();if(t)this.svgCanvasD3.nodeTemplateDropped(t,e.clientX,e.clientY),this.props.canvasController.nodeTemplateDragEnd();else{var n=this.getDNDJson(e);n||(n={operation:"addToCanvas",data:{dataTransfer:e.dataTransfer,editType:"createFromExternalObject"}}),this.svgCanvasD3.externalObjectDropped(n,e.clientX,e.clientY)}e.dataTransfer.clearData()}}},{key:"dragOver",value:function(e){if(Math.abs(this.dragX-e.clientX)>5||Math.abs(this.dragY-e.clientY)>5){this.dragX=e.clientX,this.dragY=e.clientY;var t=this.props.canvasController.getDragNodeTemplate();t&&this.svgCanvasD3.nodeTemplateDragOver(t,e.clientX,e.clientY)}}},{key:"dragEnter",value:function(e){this.dragX=null,this.dragY=null,this.isDataTypeBeingDraggedFile(e)&&(this.first?this.second=!0:(this.first=!0,this.setIsDropZoneDisplayed(!0))),e.preventDefault()}},{key:"dragLeave",value:function(e){this.isDataTypeBeingDraggedFile(e)&&(this.second?this.second=!1:this.first&&(this.first=!1),this.first||this.second||this.setIsDropZoneDisplayed(!1)),e.preventDefault()}},{key:"focusOnCanvas",value:function(){document.getElementById(this.svgCanvasDivId)&&document.getElementById(this.svgCanvasDivId).focus()}},{key:"refreshOnSizeChange",value:function(){this.svgCanvasD3&&this.svgCanvasD3.refreshOnSizeChange()}},{key:"render",value:function(){this.logger.log("render");var e=this.getStateTag(),t=this.getEmptyCanvas(),n=this.getContextMenu(),i=this.getDropZone(),o=this.getSVGCanvasDiv(),a=this.props.canvasConfig.enableRightFlyoutUnderToolbar?"common-canvas-main":null,s=this.props.canvasConfig.enableRightFlyoutUnderToolbar?"common-canvas-drop-div-under-toolbar":"common-canvas-drop-div";return s="None"===this.props.canvasConfig.enableToolbarLayout?s+" common-canvas-toolbar-none":s,s=this.props.bottomPanelIsOpen?s+" common-canvas-bottom-panel-is-open":s,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("main",{"aria-label":this.getLabel("canvas.label"),role:"main",className:a},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_resize_detector__WEBPACK_IMPORTED_MODULE_22__["default"],{handleWidth:!0,handleHeight:!0,onResize:this.refreshOnSizeChange},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{id:this.mainCanvasDivId,className:s,onDrop:this.drop,onDragOver:this.dragOver,onDragEnter:this.dragEnter,onDragLeave:this.dragLeave},t,o,n,i,e)))}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Ds=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{canvasInfo:e.canvasinfo,canvasConfig:e.canvasconfig,bottomPanelIsOpen:e.bottompanel.isOpen,selectionInfo:e.selectioninfo,breadcrumbs:e.breadcrumbs}}))((0,react_intl__WEBPACK_IMPORTED_MODULE_2__.injectIntl)(Ss));function Ts(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var Es=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,i);var o=Ts(s);function s(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(n=o.call(this,t)).getLabel=n.getLabel.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.toolbarActionHandler=n.toolbarActionHandler.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_12__.L("CC-Toolbar"),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"getLabel",value:function(e,t){var n=_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.d[e]?_canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_16__.d[e]:_toolbar_a5ec3435_js__WEBPACK_IMPORTED_MODULE_9__.d[e];return this.props.intl.formatMessage({id:e,defaultMessage:n},t)}},{key:"getDefaultToolbar",value:function(){return{leftBar:[{action:"undo",label:this.getLabel("canvas.undo"),enable:!0},{action:"redo",label:this.getLabel("canvas.redo"),enable:!0},{action:"cut",label:this.getLabel("edit.cutSelection"),enable:!0},{action:"copy",label:this.getLabel("edit.copySelection"),enable:!0},{action:"paste",label:this.getLabel("edit.pasteSelection"),enable:!0},{action:"createAutoComment",label:this.getLabel("canvas.addComment"),enable:!0},{action:"deleteSelectedObjects",label:this.getLabel("canvas.deleteObject"),enable:!0}],rightBar:[{action:"zoomIn",label:this.getLabel("toolbar.zoomIn"),enable:!0},{action:"zoomOut",label:this.getLabel("toolbar.zoomOut"),enable:!0},{action:"zoomToFit",label:this.getLabel("toolbar.zoomToFit"),enable:!0}]}}},{key:"getConvertedLegacyToolbar",value:function(e){return{leftBar:e,rightBar:this.getDefaultRightBar()}}},{key:"getDefaultRightBar",value:function(){return[{action:"zoomIn",label:this.getLabel("toolbar.zoomIn"),enable:!0},{action:"zoomOut",label:this.getLabel("toolbar.zoomOut"),enable:!0},{action:"zoomToFit",label:this.getLabel("toolbar.zoomToFit"),enable:!0}]}},{key:"getNotificationClassName",value:function(){var e=this.props.canvasController.getNotificationMessagesMaxType(),t=_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ao;return e===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.E?t+=" error":e===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.W?t+=" warning":e===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.S?t+=" success":e===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.I&&(t+=" info"),t}},{key:"generateToolbarConfig",value:function(){var e=this.copyConfig();return e?Array.isArray(e)?e=this.getConvertedLegacyToolbar(e):void 0===e.rightBar&&(e.rightBar=this.getDefaultRightBar()):e=this.getDefaultToolbar(),e=Object.assign({},e,{leftBar:this.optionallyAddPaletteTool(e.leftBar||[])},{rightBar:this.optionallyAddNotificationTool(e.rightBar||[])})}},{key:"copyConfig",value:function(){if(!this.props.config)return null;if(Array.isArray(this.props.config))return (0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_13__.b)(this.props.config);var e={};return this.props.config.overrideAutoEnableDisable&&(e.overrideAutoEnableDisable=!0),this.props.config&&this.props.config.leftBar&&(e.leftBar=(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_13__.b)(this.props.config.leftBar)),this.props.config&&this.props.config.rightBar&&(e.rightBar=(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_13__.b)(this.props.config.rightBar)),e}},{key:"toolbarActionHandler",value:function(e){this.props.canvasController.toolbarActionHandler(e)}},{key:"optionallyAddPaletteTool",value:function(e){var t=this.getLabel("toolbar.palette"),n=e;return e&&e.length>0&&"palette"===e[0].action&&(t=e[0].label?e[0].label:t,n=e.slice(1),e.length>1&&e[1].divider&&(n=e.slice(2))),this.props.isPaletteEnabled?[{action:"togglePalette",label:t,enable:!0,iconTypeOverride:this.props.isPaletteOpen?"paletteClose":"paletteOpen"},{divider:!0}].concat(n):n}},{key:"optionallyAddNotificationTool",value:function(e){if(this.props.notificationConfig&&void 0!==this.props.notificationConfig.action&&void 0!==this.props.notificationConfig.enable){var t=this.props.notificationMessages.length,n=[{divider:!0},{action:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.T,label:this.props.notificationConfig.label,enable:!0,isSelected:this.props.isNotificationOpen,className:this.getNotificationClassName(),textContent:t>9?"9+":t.toString()}];return e.concat(n)}return e}},{key:"configureToolbarButtonsState",value:function(e){if(!this.props.enableInternalObjectModel||e.overrideAutoEnableDisable)return e;if(void 0!==e){var t=this.props.enableEditingActions;this.applyToolState("undo",e,t&&this.props.canUndo),this.applyToolState("redo",e,t&&this.props.canRedo),this.applyToolState("cut",e,t&&this.props.canCutCopy),this.applyToolState("copy",e,t&&this.props.canCutCopy),this.applyToolState("paste",e,t&&this.props.canPaste),this.applyToolState("deleteSelectedObjects",e,t&&this.props.canDelete),this.applyToolState("createAutoComment",e,t),this.applyToolState("arrangeHorizontally",e,t),this.applyToolState("arrangeVertically",e,t),this.applyToolState("zoomIn",e,this.props.canZoomIn),this.applyToolState("zoomOut",e,this.props.canZoomOut),this.applyToolState("zoomToFit",e,this.props.canZoomToFit)}return e}},{key:"addUndoRedoCommandLabels",value:function(e){var t=this.props.undoLabel,n=this.props.redoLabel;if(t){var i=this.findTool("undo",e);i&&(i.label=this.getLabel("canvas.undoCommand",{undo_command:t}))}if(n){var o=this.findTool("redo",e);o&&(o.label=this.getLabel("canvas.redoCommand",{redo_command:n}))}return e}},{key:"applyToolState",value:function(e,t,n){var i=this.findTool(e,t);i?i.enable=n:this.logger.log("Toolbar tool "+e+" could not be found to set state to "+n)}},{key:"findTool",value:function(e,t){var n={};return t.leftBar&&(n=t.leftBar.find((function(t){return t.action===e}))),!n&&t.rightBar&&(n=t.rightBar.find((function(t){return t.action===e}))),n}},{key:"render",value:function(){this.logger.log("render");var e=this.generateToolbarConfig();e=this.configureToolbarButtonsState(e),e=this.addUndoRedoCommandLabels(e);var t=null;return this.props.enableToolbarLayout===_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.am&&(t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_toolbar_a5ec3435_js__WEBPACK_IMPORTED_MODULE_9__.T,{config:e,instanceId:this.props.canvasController.getInstanceId(),toolbarActionHandler:this.toolbarActionHandler,additionalText:{overflowMenuLabel:this.getLabel("toolbar.overflowMenu")}})),t}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Is=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{enableToolbarLayout:e.canvasconfig.enableToolbarLayout,config:e.canvastoolbar.config,isPaletteEnabled:e.canvasconfig.enablePaletteLayout!==_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.an,isPaletteOpen:e.palette.isOpen,isNotificationOpen:e.notificationpanel.isOpen,notificationConfig:e.notificationpanel.config,notificationMessages:e.notifications,enableInternalObjectModel:e.canvasconfig.enableInternalObjectModel,enableEditingActions:e.canvasconfig.enableEditingActions,canUndo:t.canvasController.canUndo(),canRedo:t.canvasController.canRedo(),canCutCopy:t.canvasController.canCutCopy(),canPaste:t.canvasController.canPaste(),canDelete:t.canvasController.canDelete(),canZoomIn:t.canvasController.canZoomIn(),canZoomOut:t.canvasController.canZoomOut(),canZoomToFit:t.canvasController.canZoomToFit(),undoLabel:t.canvasController.getUndoLabel(),redoLabel:t.canvasController.getRedoLabel()}}))((0,react_intl__WEBPACK_IMPORTED_MODULE_2__.injectIntl)(Es));function Os(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var _s=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(a,i);var o=Os(a);function a(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,a),(n=o.call(this,t)).logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_12__.L("CC-RightFlyout"),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(a,[{key:"render",value:function(){this.logger.log("render");var e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"right-flyout-panel"});if(this.props.content&&this.props.isOpen){var t=this.props.enableRightFlyoutUnderToolbar?"right-flyout-panel under-toolbar":"right-flyout-panel";e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:t},this.props.content)}return e}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),As=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{isOpen:e.rightflyout.isOpen,content:e.rightflyout.content,enableRightFlyoutUnderToolbar:e.canvasconfig.enableRightFlyoutUnderToolbar}}))(_s);function zs(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var Ms=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,i);var o=zs(s);function s(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(n=o.call(this,t)).state={panelHeight:393},n.logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_12__.L("CC-Bottom-Panel"),n.onMouseUp=n.onMouseUp.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onMouseDown=n.onMouseDown.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.onMouseMoveY=n.onMouseMoveY.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"onMouseDown",value:function(e){0===e.button&&(document.addEventListener("mousemove",this.onMouseMoveY,!0),document.addEventListener("mouseup",this.onMouseUp,!0),this.poseY=e.clientY)}},{key:"onMouseUp",value:function(e){document.removeEventListener("mousemove",this.onMouseMoveY,!0),document.removeEventListener("mouseup",this.onMouseUp,!0)}},{key:"onMouseMoveY",value:function(e){if(e.clientY){var t=e.clientY-this.poseY;this.setState({panelHeight:this.state.panelHeight-t}),this.poseY=e.clientY}}},{key:"render",value:function(){this.logger.log("render");var e=null;if(this.props.bottomPanelIsOpen){var t=document.querySelector(".common-canvas-drop-div"),n=t?t.getBoundingClientRect().height:0,i=this.state.panelHeight>=n-60?n-60:this.state.panelHeight;e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"bottom-panel",style:{height:i}},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"bottom-panel-drag",onMouseDown:this.onMouseDown}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"bottom-panel-contents"},this.props.bottomPanelContent))}return e}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Hs=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{bottomPanelIsOpen:e.bottompanel.isOpen,bottomPanelContent:e.bottompanel.content}}))(Ms);function js(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var Rs=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,i);var o=js(s);function s(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(n=o.call(this,t)).state={},n.logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_12__.L("NotificationPanel"),n.handleNotificationPanelClickOutside=n.handleNotificationPanelClickOutside.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.closeNotificationPanel=n.closeNotificationPanel.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"componentDidMount",value:function(){document.addEventListener("click",this.handleNotificationPanelClickOutside,!0)}},{key:"componentWillUnmount",value:function(){document.removeEventListener("click",this.handleNotificationPanelClickOutside,!0)}},{key:"getNotifications",value:function(){var e=[];if(!this.props.messages)return e;for(var t=0;t<this.props.messages.length;t++){var n=this.props.messages[t],i=n.callback?" clickable ":"",o=n.type,a=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-message-type"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_8__.I,{type:o,className:"notification-message-icon-".concat(o)})),s=n.title?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-message-title"},n.title):null,l=n.subtitle?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-message-subtitle"},n.subtitle,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("hr",null)):null,c=n.closeMessage?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-message-close",onClick:this.deleteNotification.bind(this,n.id)},n.closeMessage):null,u=n.timestamp?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-message-timestamp"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-message-timestamp-icon"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_8__.I,{type:"time"})),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-message-string"},n.timestamp)):null;e.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notifications-button-container",key:t+"-"+n.id},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notifications "+i+n.type,onClick:this.notificationCallback.bind(this,n.id,n.callback)},a,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-message-details"},s,l,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-message-content"},n.content),u,c))))}return e}},{key:"handleNotificationPanelClickOutside",value:function(e){if(this.props.isNotificationOpen&&this.props.notificationConfig&&!this.props.notificationConfig.keepOpen){var t=document.getElementsByClassName(_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ao)[0],n=document.getElementsByClassName("notification-panel-header")[0],i=document.getElementsByClassName("notification-panel-messages-container")[0];t&&!t.contains(e.target)&&n&&!n.contains(e.target)&&i&&!i.contains(e.target)&&(this.props.canvasController.toolbarActionHandler("closeNotificationPanel"),e.stopPropagation())}}},{key:"notificationCallback",value:function(e,t){t&&t(e)}},{key:"deleteNotification",value:function(e){this.props.canvasController.deleteNotificationMessages(e)}},{key:"clearNotificationMessages",value:function(){this.props.canvasController.clearNotificationMessages(),"function"==typeof this.props.notificationConfig.clearAllCallback&&this.props.notificationConfig.clearAllCallback()}},{key:"closeNotificationPanel",value:function(){this.props.canvasController.toolbarActionHandler("closeNotificationPanel")}},{key:"render",value:function(){if(this.logger.log("render"),!this.props.notificationConfig)return null;var e=this.props.isNotificationOpen?"":"panel-hidden",t=this.props.notificationConfig&&this.props.notificationConfig.notificationHeader?this.props.notificationConfig.notificationHeader:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.ap,n=this.props.notificationConfig&&this.props.notificationConfig.notificationSubtitle?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-panel-subtitle"},this.props.notificationConfig.notificationSubtitle):null,i=this.props.messages.length>0?this.getNotifications():react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-panel-empty-message-container"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-panel-empty-message"},this.props.notificationConfig&&this.props.notificationConfig.emptyMessage?this.props.notificationConfig.emptyMessage:null)),o=this.props.notificationConfig&&this.props.notificationConfig.clearAllMessage?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-panel-clear-all-container"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_23__["default"],{className:"notification-panel-clear-all",onClick:this.clearNotificationMessages.bind(this),kind:"ghost",size:"small",disabled:0===this.props.messages.length},this.props.notificationConfig.clearAllMessage)):null;return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-panel-container "+e},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-panel"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-panel-header-container"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-panel-header"},t,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_24__.Close16,{className:"notification-panel-close-icon",onClick:this.closeNotificationPanel})),n),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-panel-messages-container"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"notification-panel-messages"},i),o)))}}],[{key:"getDerivedStateFromProps",value:function(e,t){return e.messages!==t.messages?{messages:e.messages}:{}}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Fs=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{notificationConfig:e.notificationpanel.config,isNotificationOpen:e.notificationpanel.isOpen,messages:e.notifications}}))(Rs);function Bs(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var Gs=function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(a,i);var o=Bs(a);function a(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,a),(n=o.call(this,t)).logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_12__.L("CC-CentralItems"),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(a,[{key:"render",value:function(){this.logger.log("render");var e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(As,null),t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Is,{canvasController:this.props.canvasController}),n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Fs,{canvasController:this.props.canvasController}),i=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ds,{canvasController:this.props.canvasController}),o=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Hs,{canvasController:this.props.canvasController});return this.props.enableRightFlyoutUnderToolbar?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"common-canvas-right-side-items-under-toolbar"},t,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{id:this.props.containingDivId,className:"common-canvas-items-container-under-toolbar"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"common-canvas-with-bottom-panel"},i,o),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,e),n)):react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"common-canvas-right-side-items"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{id:this.props.containingDivId,className:"common-canvas-items-container"},t,i,o,n),e)}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Us=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{enableRightFlyoutUnderToolbar:e.canvasconfig.enableRightFlyoutUnderToolbar}}))(Gs);function Ys(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;n=Reflect.construct(a,arguments,r)}else n=a.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,n)}}var Xs=(0,react_intl__WEBPACK_IMPORTED_MODULE_2__.injectIntl)(function(i){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,i);var o=Ys(s);function s(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(n=o.call(this,t)).logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_12__.L(["CommonCanvas"]),n.logger.log("constructor"),n.initializeController=n.initializeController.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(n)),n.containingDivId="common-canvas-items-container-"+t.canvasController.getInstanceId(),t.canvasController.setIntl(t.intl),n.initializeController(t),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"componentDidUpdate",value:function(){this.logger.log("componentDidUpdate"),this.initializeController(this.props)}},{key:"onDragOver",value:function(e){e.preventDefault()}},{key:"onDrop",value:function(e){e.preventDefault()}},{key:"initializeController",value:function(e){this.logger.logStartTimer("initializeController"),e.canvasController.setCanvasConfig(e.config),e.canvasController.setContextMenuConfig(e.contextMenuConfig),e.canvasController.setKeyboardConfig(e.keyboardConfig),e.canvasController.setToolbarConfig(e.toolbarConfig),e.canvasController.setNotificationPanelConfig(e.notificationConfig),e.canvasController.setRightFlyoutConfig({content:e.rightFlyoutContent,isOpen:e.showRightFlyout}),e.canvasController.setBottomPanelConfig({content:e.bottomPanelContent,isOpen:e.showBottomPanel}),e.canvasController.setHandlers({contextMenuHandler:e.contextMenuHandler,beforeEditActionHandler:e.beforeEditActionHandler,editActionHandler:e.editActionHandler,clickActionHandler:e.clickActionHandler,decorationActionHandler:e.decorationActionHandler,tipHandler:e.tipHandler,layoutHandler:e.layoutHandler,idGeneratorHandler:e.idGeneratorHandler,selectionChangeHandler:e.selectionChangeHandler,actionLabelHandler:e.actionLabelHandler}),this.logger.logEndTimer("initializeController")}},{key:"generateClass",value:function(){var e="common-canvas";return e+=this.isEditingAllowed()?"":" config-editing-actions-false",e+=this.props.config&&this.props.config.enableParentClass?" "+this.props.config.enableParentClass:""}},{key:"isEditingAllowed",value:function(){return this.props.config&&(void 0===this.props.config.enableEditingActions||!0===this.props.config.enableEditingActions)}},{key:"render",value:function(){this.logger.log("render");var e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(tn,{canvasController:this.props.canvasController}),t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Jt,{canvasController:this.props.canvasController,containingDivId:this.containingDivId}),n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Us,{canvasController:this.props.canvasController,containingDivId:this.containingDivId}),i=this.generateClass();return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_redux__WEBPACK_IMPORTED_MODULE_1__.Provider,{store:this.props.canvasController.getStore()},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:i,onDragOver:this.onDragOver,onDrop:this.onDrop},t,n,e))}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)));
//# sourceMappingURL=common-canvas-bdfb8c87.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/common-canvas.es.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/common-canvas.es.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "CanvasController": () => (/* reexport safe */ _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_1__.C),
/* harmony export */   "CommandStack": () => (/* reexport safe */ _lib_command_stack_es_js__WEBPACK_IMPORTED_MODULE_5__["default"]),
/* harmony export */   "CommonCanvas": () => (/* reexport safe */ _common_canvas_bdfb8c87_js__WEBPACK_IMPORTED_MODULE_0__.c),
/* harmony export */   "CommonProperties": () => (/* reexport safe */ _common_properties_87fef545_js__WEBPACK_IMPORTED_MODULE_2__.c),
/* harmony export */   "ContextMenuWrapper": () => (/* reexport safe */ _lib_context_menu_es_js__WEBPACK_IMPORTED_MODULE_6__["default"]),
/* harmony export */   "FieldPicker": () => (/* reexport safe */ _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_4__.F),
/* harmony export */   "FlexibleTable": () => (/* reexport safe */ _flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_3__.F),
/* harmony export */   "FlowValidation": () => (/* binding */ f),
/* harmony export */   "PropertiesController": () => (/* reexport safe */ _common_properties_87fef545_js__WEBPACK_IMPORTED_MODULE_2__.P),
/* harmony export */   "ToolTip": () => (/* reexport safe */ _lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_7__["default"])
/* harmony export */ });
/* harmony import */ var _common_canvas_bdfb8c87_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./common-canvas-bdfb8c87.js */ "../../node_modules/@elyra/canvas/dist/common-canvas-bdfb8c87.js");
/* harmony import */ var _canvas_controller_e023521c_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./canvas-controller-e023521c.js */ "../../node_modules/@elyra/canvas/dist/canvas-controller-e023521c.js");
/* harmony import */ var _common_properties_87fef545_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./common-properties-87fef545.js */ "../../node_modules/@elyra/canvas/dist/common-properties-87fef545.js");
/* harmony import */ var _flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./flexible-table-d4a68ebb.js */ "../../node_modules/@elyra/canvas/dist/flexible-table-d4a68ebb.js");
/* harmony import */ var _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./index-beefcd21.js */ "../../node_modules/@elyra/canvas/dist/index-beefcd21.js");
/* harmony import */ var _lib_command_stack_es_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./lib/command-stack.es.js */ "../../node_modules/@elyra/canvas/dist/lib/command-stack.es.js");
/* harmony import */ var _lib_context_menu_es_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./lib/context-menu.es.js */ "../../node_modules/@elyra/canvas/dist/lib/context-menu.es.js");
/* harmony import */ var _lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./lib/tooltip.es.js */ "../../node_modules/@elyra/canvas/dist/lib/tooltip.es.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! react-redux */ "webpack/sharing/consume/default/react-redux/react-redux");
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(react_redux__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var react_intl__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! react-intl */ "webpack/sharing/consume/default/react-intl/react-intl");
/* harmony import */ var react_intl__WEBPACK_IMPORTED_MODULE_10___default = /*#__PURE__*/__webpack_require__.n(react_intl__WEBPACK_IMPORTED_MODULE_10__);
/* harmony import */ var uuid__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! uuid */ "webpack/sharing/consume/default/uuid/uuid");
/* harmony import */ var uuid__WEBPACK_IMPORTED_MODULE_11___default = /*#__PURE__*/__webpack_require__.n(uuid__WEBPACK_IMPORTED_MODULE_11__);
/* harmony import */ var jsonschema__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! jsonschema */ "../../node_modules/jsonschema/lib/index.js");
/* harmony import */ var _elyra_pipeline_schemas__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! @elyra/pipeline-schemas */ "../../node_modules/@elyra/pipeline-schemas/common-pipeline/pipeline-flow/upgrade/upgrade-flow.js");
/* harmony import */ var _elyra_pipeline_schemas__WEBPACK_IMPORTED_MODULE_13___default = /*#__PURE__*/__webpack_require__.n(_elyra_pipeline_schemas__WEBPACK_IMPORTED_MODULE_13__);
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! react-dom */ "webpack/sharing/consume/default/react-dom");
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_14___default = /*#__PURE__*/__webpack_require__.n(react_dom__WEBPACK_IMPORTED_MODULE_14__);
/* harmony import */ var seedrandom__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! seedrandom */ "../../node_modules/seedrandom/index.js");
/* harmony import */ var seedrandom__WEBPACK_IMPORTED_MODULE_15___default = /*#__PURE__*/__webpack_require__.n(seedrandom__WEBPACK_IMPORTED_MODULE_15__);
/* harmony import */ var react_codemirror2__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! react-codemirror2 */ "../../node_modules/@elyra/canvas/node_modules/react-codemirror2/index.js");
/* harmony import */ var react_virtualized__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! react-virtualized */ "../../node_modules/react-virtualized/dist/es/index.js");
/* harmony import */ var react_draggable__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! react-draggable */ "../../node_modules/react-draggable/build/cjs/cjs.js");
/* harmony import */ var react_draggable__WEBPACK_IMPORTED_MODULE_18___default = /*#__PURE__*/__webpack_require__.n(react_draggable__WEBPACK_IMPORTED_MODULE_18__);
/* harmony import */ var react_contextmenu__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! react-contextmenu */ "../../node_modules/react-contextmenu/es6/index.js");
function n(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return i(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return i(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var o=0,a=function(){};return{s:a,n:function(){return o>=e.length?{done:!0}:{done:!1,value:e[o++]}},e:function(e){throw e},f:a}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var n,s=!0,c=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return s=e.done,e},e:function(e){c=!0,n=e},f:function(){try{s||null==r.return||r.return()}finally{if(c)throw n}}}}function i(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,o=new Array(t);r<t;r++)o[r]=e[r];return o}function s(e,t,r,o,a,i){var c,f=!0,d=n(e.getNodes(t));try{for(d.s();!(c=d.n()).done;){var u=c.value;if("super_node"!==u.type||void 0!==u.open_with_tool&&"canvas"!==u.open_with_tool){if("execution_node"===u.type||"binding"===u.type){var b=p(m(u.id,t,r,e),i);b.validatePropertiesValues(),l(u,t,b,e,o)}}else f=s(e,u.subflow_ref.pipeline_id_ref,r,o,a,i)}}catch(e){d.e(e)}finally{d.f()}return e.isFlowValid(a,t)&&f}function m(t,a,n,i){var s={},c=n(t,a,i);return c?(s="parameterDef"===c.type?_common_properties_87fef545_js__WEBPACK_IMPORTED_MODULE_2__.F.makeForm(c.data):c.data.formData)&&s.data&&s.data.inputDataModel&&!s.data.datasetMetadata&&(s.data.datasetMetadata=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_4__.x)(s.data.inputDataModel)):_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_4__.l.warn("flow-validation",{message:"No parameter def found for node "+t}),s}function p(e,r){var o=new _common_properties_87fef545_js__WEBPACK_IMPORTED_MODULE_2__.P;return o.setForm(e,r),o}function l(e,t,r,o,n){var i=o.getNodeMessages(e.id,t),s=r.getErrorMessages(!0,!0,!0);(!i&&s.length>0||i&&!(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_4__.j)(s,i))&&(o.setNodeMessages(e.id,s,t),n&&n(e.id,s))}var f=Object.freeze({__proto__:null,validateFlow:function(e,t,r,o,a){return s(e,e.getPrimaryPipelineId(),t,r,o,a)}});
//# sourceMappingURL=common-canvas.es.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/common-properties-87fef545.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/common-properties-87fef545.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "F": () => (/* binding */ Ko),
/* harmony export */   "P": () => (/* binding */ dc),
/* harmony export */   "c": () => (/* binding */ Ac)
/* harmony export */ });
/* harmony import */ var _createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./createClass-32a0cf0f.js */ "../../node_modules/@elyra/canvas/dist/createClass-32a0cf0f.js");
/* harmony import */ var _getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./getPrototypeOf-97272efe.js */ "../../node_modules/@elyra/canvas/dist/getPrototypeOf-97272efe.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./index-beefcd21.js */ "../../node_modules/@elyra/canvas/dist/index-beefcd21.js");
/* harmony import */ var _en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./en-8647c347.js */ "../../node_modules/@elyra/canvas/dist/en-8647c347.js");
/* harmony import */ var _isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./isArrayLikeObject-a9c7973b.js */ "../../node_modules/@elyra/canvas/dist/isArrayLikeObject-a9c7973b.js");
/* harmony import */ var _datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./datarecord-metadata-v3-schema-81228a9a.js */ "../../node_modules/@elyra/canvas/dist/datarecord-metadata-v3-schema-81228a9a.js");
/* harmony import */ var _flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./flexible-table-d4a68ebb.js */ "../../node_modules/@elyra/canvas/dist/flexible-table-d4a68ebb.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/Modal/index.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/Button/Button.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/Accordion/index.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/AccordionItem/index.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/Tab/index.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/Tabs/index.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_28__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/TextInput/index.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_30__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/TextArea/TextArea.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_32__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/NumberInput/NumberInput.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_37__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/Checkbox/Checkbox.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_41__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/Dropdown/Dropdown.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_42__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/ContentSwitcher/ContentSwitcher.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_43__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/Switch/Switch.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_47__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/RadioButton/index.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_48__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/SelectItem/SelectItem.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_49__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/Select/Select.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_50__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/ComboBox/ComboBox.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_51__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/MultiSelect/index.js");
/* harmony import */ var _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./extends-cf86ca1c.js */ "../../node_modules/@elyra/canvas/dist/extends-cf86ca1c.js");
/* harmony import */ var react_portal__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! react-portal */ "../../node_modules/react-portal/es/PortalCompat.js");
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react-redux */ "webpack/sharing/consume/default/react-redux/react-redux");
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react_redux__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-0.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_31__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-24.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_34__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-23.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_35__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-28.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_36__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-10.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_38__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-1.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_39__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-9.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_44__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-3.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_53__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-14.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_54__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! react-dom */ "webpack/sharing/consume/default/react-dom");
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react_dom__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./icon-caf4caca.js */ "../../node_modules/@elyra/canvas/dist/icon-caf4caca.js");
/* harmony import */ var uuid__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! uuid */ "webpack/sharing/consume/default/uuid/uuid");
/* harmony import */ var uuid__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(uuid__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var _lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./lib/tooltip.es.js */ "../../node_modules/@elyra/canvas/dist/lib/tooltip.es.js");
/* harmony import */ var redux__WEBPACK_IMPORTED_MODULE_26__ = __webpack_require__(/*! redux */ "../../node_modules/redux/es/redux.js");
/* harmony import */ var seedrandom__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! seedrandom */ "../../node_modules/seedrandom/index.js");
/* harmony import */ var seedrandom__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(seedrandom__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _lib_command_stack_es_js__WEBPACK_IMPORTED_MODULE_52__ = __webpack_require__(/*! ./lib/command-stack.es.js */ "../../node_modules/@elyra/canvas/dist/lib/command-stack.es.js");
/* harmony import */ var react_intl__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! react-intl */ "webpack/sharing/consume/default/react-intl/react-intl");
/* harmony import */ var react_intl__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(react_intl__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var date_fns__WEBPACK_IMPORTED_MODULE_27__ = __webpack_require__(/*! date-fns */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/isValid/index.js");
/* harmony import */ var date_fns__WEBPACK_IMPORTED_MODULE_45__ = __webpack_require__(/*! date-fns */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/parse/index.js");
/* harmony import */ var date_fns__WEBPACK_IMPORTED_MODULE_46__ = __webpack_require__(/*! date-fns */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/format/index.js");
/* harmony import */ var react_inlinesvg__WEBPACK_IMPORTED_MODULE_29__ = __webpack_require__(/*! react-inlinesvg */ "../../node_modules/react-inlinesvg/esm/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_40__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_40___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_40__);
/* harmony import */ var _toolbar_a5ec3435_js__WEBPACK_IMPORTED_MODULE_33__ = __webpack_require__(/*! ./toolbar-a5ec3435.js */ "../../node_modules/@elyra/canvas/dist/toolbar-a5ec3435.js");
/* harmony import */ var react_codemirror2__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! react-codemirror2 */ "../../node_modules/@elyra/canvas/node_modules/react-codemirror2/index.js");
/* harmony import */ var jsonschema__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! jsonschema */ "../../node_modules/jsonschema/lib/index.js");
var ir=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__._,ar=_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_9__._,sr=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.a;var lr=function(e,t,r){for(var n=-1,o=t.length,i={};++n<o;){var a=t[n],s=ir(e,a);r(s,a)&&ar(i,sr(a,e),s)}return i},ur=_flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_10__.h;var cr=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.b;var pr=function(e){return(null==e?0:e.length)?cr(e,1):[]},dr=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.c,fr=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.d;var hr=function(e){return fr(dr(e,void 0,pr),e+"")},mr=function(e,t){return lr(e,t,(function(t,r){return ur(e,r)}))},vr=hr((function(e,t){return null==e?{}:mr(e,t)}));var yr=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__._,gr=function(e,t,r){var n=-1,o=e.length;t<0&&(t=-t>o?0:o+t),(r=r>o?o:r)<0&&(r+=o),o=t>r?0:r-t>>>0,t>>>=0;for(var i=Array(o);++n<o;)i[n]=e[n+t];return i};var br=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.a,Er=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.l,Ir=function(e,t){return t.length<2?e:yr(e,gr(t,0,-1))},Sr=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.e;var Cr=function(e,t){return t=br(t,e),null==(e=Ir(e,t))||delete e[Sr(Er(t))]},Rr=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.f,_r=_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__._,Tr=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.i,wr=Function.prototype,kr=Object.prototype,Lr=wr.toString,Ar=kr.hasOwnProperty,Or=Lr.call(Object);var Dr=function(e){if(!Tr(e)||"[object Object]"!=Rr(e))return!1;var t=_r(e);if(null===t)return!0;var r=Ar.call(t,"constructor")&&t.constructor;return"function"==typeof r&&r instanceof r&&Lr.call(r)==Or};var Pr=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.g,Nr=_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.c,xr=Cr,Br=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.a,Mr=_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.a,Fr=function(e){return Dr(e)?void 0:e},Vr=_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.b,Ur=hr((function(e,t){var r={};if(null==e)return r;var n=!1;t=Pr(t,(function(t){return t=Br(t,e),n||(n=t.length>1),t})),Mr(e,Vr(e),r),n&&(r=Nr(r,7,Fr));for(var o=t.length;o--;)xr(r,t[o]);return r}));function jr(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Hr=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,react__WEBPACK_IMPORTED_MODULE_0__.Component);var o=jr(i);function i(){return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),o.apply(this,arguments)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"getCarbonModalSize",value:function(){switch(this.props.bsSize){case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.SMALL:return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.b;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.LARGE:return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.a;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.MEDIUM:default:return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.C}}},{key:"render",value:function(){var e=this.getCarbonModalSize();return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_portal__WEBPACK_IMPORTED_MODULE_16__["default"],null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_17__["default"],{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-modal",{noButtons:!1===this.props.showPropertiesButtons}),open:!0,modalHeading:this.props.title,primaryButtonText:this.props.applyLabel,secondaryButtonText:this.props.rejectLabel,onRequestSubmit:this.props.okHandler,onSecondarySubmit:this.props.cancelHandler,"aria-label":"",size:e},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-modal-children"},this.props.children)))}}]),i}(),qr=Hr;function zr(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Gr=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,react__WEBPACK_IMPORTED_MODULE_0__.Component);var o=zr(i);function i(){return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),o.apply(this,arguments)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"render",value:function(){var e="properties-editing properties-"+(void 0===this.props.bsSize?"large":this.props.bsSize),t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.P,{okHandler:this.props.okHandler,cancelHandler:this.props.cancelHandler,applyLabel:this.props.applyLabel,rejectLabel:this.props.rejectLabel,showPropertiesButtons:this.props.showPropertiesButtons});return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:e},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("h2",null,this.props.title),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-body"},this.props.children),t)}}]),i}(),Wr=Gr;function $r(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Xr=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,react__WEBPACK_IMPORTED_MODULE_0__.Component);var o=$r(i);function i(){return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),o.apply(this,arguments)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"shouldEnabledSaveButton",value:function(){return!!this.props.saveButtonEnabled&&(!this.props.disableSaveOnRequiredErrors||0===Object.keys(this.props.requiredErrorMessages).length)}},{key:"render",value:function(){var e=this.shouldEnabledSaveButton();return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.P,{okHandler:this.props.okHandler,cancelHandler:this.props.cancelHandler,applyLabel:this.props.applyLabel,rejectLabel:this.props.rejectLabel,showPropertiesButtons:this.props.showPropertiesButtons,applyButtonEnabled:e})}}]),i}();Xr.defaultProps={saveButtonEnabled:!0};var Yr=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{saveButtonEnabled:!t.controller.getSaveButtonDisable(),requiredErrorMessages:t.controller.getRequiredErrorMessages()}}),null)(Xr);function Kr(e){return{type:"SET_TITLE",title:e}}function Jr(e){return{type:"SET_ACTIVE_TAB",activeTab:e}}function Zr(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Qr=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,n);var o=Zr(i);function i(){return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),o.apply(this,arguments)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"render",value:function(){var e=this.props.panel;return void 0===e&&(e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-control-panel"})),e}}]),i}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),en=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{panel:t.panels[t.controller.getPropertyValue({name:t.dependsOn})]}}),null)(Qr);function tn(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var rn=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,react__WEBPACK_IMPORTED_MODULE_0__.Component);var o=tn(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).state={style:{height:0}},r.updateDimensions=r.updateDimensions.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"componentDidMount",value:function(){this.updateDimensions(),window.addEventListener("resize",this.updateDimensions)}},{key:"componentWillUnmount",value:function(){window.removeEventListener("resize",this.updateDimensions)}},{key:"updateDimensions",value:function(){if(this.wideFlyout&&(this.commonPropertiesParent||(this.commonPropertiesParent=this.findPropertyWrapper(this.wideFlyout)),this.commonPropertiesParent)){var e=react_dom__WEBPACK_IMPORTED_MODULE_2___default().findDOMNode(this.commonPropertiesParent).getBoundingClientRect();this.setState({style:{height:e.height+"px",top:e.top+"px"}})}}},{key:"findPropertyWrapper",value:function(e){return e&&e.parentNode&&e.parentNode.className&&e.parentNode.className.includes("properties-right-flyout")?e.parentNode:e&&e.parentNode?this.findPropertyWrapper(e.parentNode):null}},{key:"render",value:function(){var e,t,r,n=this,o=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-wf-overlay",{show:this.props.show})});return this.props.show&&(this.props.title&&(e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-wf-title"},this.props.title)),t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.P,{okHandler:this.props.okHandler,cancelHandler:this.props.cancelHandler,showPropertiesButtons:this.props.showPropertiesButtons,applyLabel:this.props.applyLabel,rejectLabel:this.props.rejectLabel}),r=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-wf-children"}," ",this.props.children," ")),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-wf-modal",ref:function(e){return n.wideFlyout=e}},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_portal__WEBPACK_IMPORTED_MODULE_16__["default"],{node:this.commonPropertiesParent},o,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-wf-content",{show:this.props.show,"properties-light-disabled":!this.props.light}),style:this.state.style},e,r,t)))}}]),a}();rn.defaultProps={show:!1};var nn=rn;function on(e,t){var r=t||(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)();return"".concat(an(e),"-").concat(r)}function an(e){var t=e.name;return void 0!==e.row?(t+="_"+e.row,void 0!==e.col&&(t+="_"+e.col)):void 0!==e.col&&(t+="_"+e.col),"properties-"+t}function sn(e,t){var r=t;return e.charLimit&&(r=e.charLimit),r}function ln(e,t){if(e.length>0){var r=e.split(t);return Array.isArray(r)?r:[r]}return[]}function un(e,t){var r=!1;if(Array.isArray(e)){if(0===e.length)return{value:"",truncated:r};var n="";return e.forEach((function(o,i){var a=cn(o),s=i===e.length-1?"":t;n+=a+s,r||(r=a.length!==o.length)})),{value:n,truncated:r}}return{value:e,truncated:r}}function cn(e){return e.length>_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.T?e.substring(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.T)+"...":e}function pn(e,t){var r={};return!e||t||("error"===e.type?(r.invalid=!0,r.invalidText=e.text):"warning"===e.type&&(r.warn=!0,r.warnText=e.text)),r}function dn(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return fn(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return fn(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function fn(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function hn(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var mn=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=hn(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).state={showWideFlyout:!1},r.handleLinkClicked=r.handleLinkClicked.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.hideWideFlyout=r.hideWideFlyout.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.cancelWideFlyout=r.cancelWideFlyout.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r._getSummaryTables=r._getSummaryTables.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"_onMouseMove",value:function(e){this.setState({mousePos:{x:e.clientX,y:e.clientY}})}},{key:"hideWideFlyout",value:function(){this.props.controller.setIsSummaryPanelShowing(!1),this.setState({showWideFlyout:!1}),this.props.controller.clearSelectedRows()}},{key:"cancelWideFlyout",value:function(){this.props.controller.setPropertyValues(this.initialControlValues),this.props.controller.setErrorMessages(this.initialMessages),this.props.controller.setControlStates(this.initialStates),this.hideWideFlyout()}},{key:"handleLinkClicked",value:function(){this.props.children&&(this.props.controller.setIsSummaryPanelShowing(!0),this.setState({showWideFlyout:!0})),this.initialControlValues=this.props.controller.getPropertyValues(),this.initialMessages=this.props.controller.getAllErrorMessages(),this.initialStates=this.props.controller.getControlStates()}},{key:"_getSummaryTables",value:function(){var e=[],t=this.props.controller.getSummaryPanelControls(this.props.panel.id);if(!Array.isArray(t))return e;var r,n=dn(t);try{for(n.s();!(r=n.n()).done;){var o=r.value,i={name:o},a=this.props.controller.getControl(i),l=this.props.controller.getPropertyValue(i,{filterHiddenDisabled:!0}),u=this.props.controller.getCustPropSumPanelValue(i),c=!1;null!=u&&(l=u.value,a.summaryLabel=u.label,c=!0);var d=[];if(Array.isArray(l)){var f=0;if(a.subControls)for(var h=0;h<a.subControls.length;h++){var m={name:i.name,col:h};(this.props.controller.isSummary(m)||c)&&f++}else a.summary&&(f=1);for(var v=0!==f?"calc((100% / "+f+") - 2px)":"100%",y=0;y<l.length;y++){var g=l[y],b=[];if(Array.isArray(g))for(var E=0;E<g.length;E++){var I={name:i.name,col:E};if(this.props.controller.isSummary(I)||c){var S=this._getSummaryDisplayValue(g[E],I),C=void 0===S?"":JSON.stringify(S).replace('"',"").replace(new RegExp('"',"g"),"")+" ";b.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("td",{key:"summary-table-data-"+E,className:"properties-summary-row-data ",style:{width:v},onMouseMove:this._onMouseMove.bind(this)},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_18__["default"],{id:(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)(),tip:C,mousePos:this.state.mousePos,showToolTipIfTruncated:!0},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{id:"span_"+(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)()},C))))}}else if(this.props.controller.isSummary(i)||c){var R=this._getSummaryDisplayValue(g,i);b.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("td",{key:"summary-table-row-data-"+y,className:"properties-summary-row-data "},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_18__["default"],{id:(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)(),tip:R,mousePos:this.state.mousePos,showToolTipIfTruncated:!0},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{id:"span_"+(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)()},R))))}b.length>0&&d.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("tr",{key:"summary-table-row-"+y,className:"properties-summary-row"},b))}}else if(l&&(this.props.controller.isSummary(i)||c)){var _=this._getSummaryDisplayValue(l,i);d.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("tr",{key:"summary-row-"+o,className:"properties-summary-row"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("td",{key:"summary-table-row-data-"+o,className:"properties-summary-rows-data"},_)))}if(d.length>0){var T=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("table",{role:"presentation",key:"summary-table-"+o,className:"properties-summary-table"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("tbody",{key:"summary-body-"+o},d));if(d.length>10){var w=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.LONG_TABLE_SUMMARY_PLACEHOLDER);T=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-summary-table"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",null,w))}e.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:"summary-container-"+o,className:"properties-summary-values"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{key:"summary-text-"+o,className:"properties-summary-label"},a.summaryLabel),T))}}}catch(e){n.e(e)}finally{n.f()}return e}},{key:"_getSummaryDisplayValue",value:function(e,t){var r=e,n=this.props.controller.getControl(t);if(n.values&&n.valueLabels){var o=n.values.indexOf(e);o>-1&&n.valueLabels[o]&&(r=n.valueLabels[o])}return"object"===(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.t)(r)&&(r=n.valueDef.propType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.STRUCTURE&&n.role===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.COLUMN?(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.s)(e,n):JSON.stringify(r)),r}},{key:"_getSummaryIconState",value:function(){var e=this,t=this.props.controller.getSummaryPanelControls(this.props.panel.id),r={},n=0,o=0;if(Array.isArray(t)&&t.forEach((function(t){var i=e.props.controller.getErrorMessage({name:t},!0);(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(i)||(i.type===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.WARNING&&(o+=1),i.type===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.ERROR&&(n+=1)),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(i)||(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(r)&&"error"===r.type||(r=i)})),!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(r)){var i="";return n>0&&0===o?i=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.CONTROL_SUMMARY_ERROR,{errorMsgCount:n}):n>0&&o>0?i=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.CONTROL_SUMMARY_ERROR_WARNING,{errorMsgCount:n,warningMsgCount:o}):0===n&&o>0&&(i=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.CONTROL_SUMMARY_WARNING,{warningMsgCount:o})),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_18__["default"],{id:(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)()+"summary-icon",tip:i,className:"properties-tooltips"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_19__.I,{type:r.type,className:"properties-summary-link-icon ".concat(r.type)}))}return null}},{key:"render",value:function(){var e=this._getSummaryIconState(),t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-summary-link-container"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{className:"properties-summary-link-button",onClick:this.handleLinkClicked,size:"small",kind:"ghost",renderIcon:_carbon_icons_react__WEBPACK_IMPORTED_MODULE_21__.Add16},this.props.panel.label),e),r=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.APPLYBUTTON_LABEL),n=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.REJECTBUTTON_LABEL),o=this.state.showWideFlyout?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(nn,{cancelHandler:this.cancelWideFlyout,okHandler:this.hideWideFlyout,show:!0,applyLabel:r,rejectLabel:n,title:this.props.panel.label,light:this.props.controller.getLight()},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,this.props.children)):react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null),i=this.props.panel.className?this.props.panel.className:"",a=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-summary-panel","properties-control-panel",{hide:this.props.panelState===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},{"properties-control-nested-panel":this.props.panel.nestedPanel},i);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:a,disabled:this.props.panelState===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,"data-id":an({name:this.props.panel.id})},o,t,this._getSummaryTables())}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),vn=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{panelState:t.controller.getPanelState({name:t.panel.id})}}),null)(mn);function yn(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var gn=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,n);var o=yn(i);function i(){return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),o.apply(this,arguments)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"render",value:function(){var e=this.props.panel.className?this.props.panel.className:"",t=this.props.panelState===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED;return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-twisty-panel",{hide:this.props.panelState===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},{"properties-control-nested-panel":this.props.panel.nestedPanel},e),"data-id":an({name:this.props.panel.id})},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_22__["default"],{disabled:t},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_23__["default"],{disabled:t,open:this.props.panel.open,title:this.props.panel.label},this.props.children)))}}]),i}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),bn=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{panelState:t.controller.getPanelState({name:t.panel.id})}}),null)(gn);function En(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var In=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=En(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).state={panel:null,title:null,hideHandler:null,subPanelVisible:!1},r.showSubDialog=r.showSubDialog.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.hideSubDialog=r.hideSubDialog.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"showSubDialog",value:function(e,t,r){this.props.controller.increaseVisibleSubPanelCounter(),this.setState({panel:t,title:e,hideHandler:r,subPanelVisible:!0})}},{key:"hideSubDialog",value:function(e){this.props.controller.decreaseVisibleSubPanelCounter(),this.state.hideHandler(e),this.setState({panel:null,title:null,hideHandler:null,subPanelVisible:!1})}},{key:"render",value:function(){var e=[];return this.state.subPanelVisible&&!this.props.rightFlyout?e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(qr,{title:this.state.title,okHandler:this.hideSubDialog.bind(this,!0),cancelHandler:this.hideSubDialog.bind(this,!1),applyLabel:this.props.applyLabel,rejectLabel:this.props.rejectLabel},this.state.panel):this.props.rightFlyout&&this.state.subPanelVisible&&(e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(nn,{cancelHandler:this.hideSubDialog.bind(this,!1),okHandler:this.hideSubDialog.bind(this,!0),show:!0,applyLabel:this.props.applyLabel,rejectLabel:this.props.rejectLabel,title:this.state.title,light:this.props.controller.getLight()},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,this.state.panel))),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,e,this.props.children)}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function Sn(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}In.defaultProps={rightFlyout:!1};var Cn=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=Sn(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).showSubPanel=r.showSubPanel.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.onSubPanelHidden=r.onSubPanelHidden.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"onSubPanelHidden",value:function(e){_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.info("onSubPanelHidden(): applyChanges="+e)}},{key:"showSubPanel",value:function(){this.subPanelInvoker.showSubDialog(this.props.title,this.props.panel,this.onSubPanelHidden)}},{key:"render",value:function(){var e=this,t=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.APPLYBUTTON_LABEL),r=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.REJECTBUTTON_LABEL),n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{className:"properties-subpanel-button",type:"button",small:!0,kind:"secondary",onClick:this.showSubPanel},this.props.label||"");return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(In,{ref:function(t){return e.subPanelInvoker=t},rightFlyout:this.props.rightFlyout,applyLabel:t,rejectLabel:r,controller:this.props.controller},n)}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function Rn(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var _n=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,n);var o=Rn(i);function i(t){var r;(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),r=o.call(this,t);var n="";return t.children.forEach((function(e,t){0===t?n="1fr":n+=" 1fr"})),r.style={gridTemplateColumns:n},r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"render",value:function(){var e=this.props.panel.className?this.props.panel.className:"";return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-column-panel",{hide:this.props.panelState===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},{"properties-control-nested-panel":this.props.panel.nestedPanel},e),disabled:this.props.panelState===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,"data-id":an({name:this.props.panel.id}),style:this.style},this.props.children)}}]),i}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Tn=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{panelState:t.controller.getPanelState({name:t.panel.id})}}),null)(_n);function wn(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var kn=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,n);var o=wn(i);function i(){return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),o.apply(this,arguments)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"render",value:function(){var e=this.props.panel.className?this.props.panel.className:"";return this.props.children.length>0?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-control-panel",{hide:this.props.panelState===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},{"properties-control-nested-panel":this.props.panel.nestedPanel},e),disabled:this.props.panelState===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,"data-id":an({name:this.props.panel.id})},this.props.children):null}}]),i}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Ln=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{panelState:t.controller.getPanelState({name:t.panel.id})}}),null)(kn);function An(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var On=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,n);var o=An(i);function i(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),(r=o.call(this,t)).state={activeTabId:""},r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"onClick",value:function(e){this.setState({activeTabId:e})}},{key:"render",value:function(){for(var e=[],t=0,r=0,n=this.props.className?this.props.className:"",o=0;o<this.props.tabs.length;o++){var i=this.props.tabs[o],a=this.props.controller.getPanelState({name:i.group});if(a!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN){var l=this.props.genUIItem(o,i.content);this.state.activeTabId===i.group&&a!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED&&(t=r),e.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_24__["default"],{key:"subtabs.tab."+o,disabled:a===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,className:"properties-subtab",tabIndex:r,label:i.text,onClick:this.onClick.bind(this,i.group),"data-id":an({name:i.group})},l)),r++}}return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-sub-tab-container",{vertical:!this.props.rightFlyout},{"properties-control-nested-panel":this.props.nestedPanel},n)},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_25__["default"],{className:"properties-subtabs",selected:t,light:this.props.controller.getLight()},e))}}]),i}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function Dn(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Pn=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,react__WEBPACK_IMPORTED_MODULE_0__.Component);var o=Dn(i);function i(){return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),o.apply(this,arguments)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"render",value:function(){var e=this.props.panel.className?this.props.panel.className:"",t=this.props.panel.label?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"panel-label"},this.props.panel.label):null,r=this.props.panel.description?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"panel-description"},(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.e)(this.props.panel.description,this.props.controller)):null;return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-text-panel",{hide:this.props.panelState===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},{"properties-control-nested-panel":this.props.panel.nestedPanel},e),disabled:this.props.panelState===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED},t,r)}}]),i}(),Nn=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{panelState:t.controller.getPanelState({name:t.panel.id}),propertyValues:t.controller.getPropertyValues()}}),null)(Pn);function xn(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Bn=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,react__WEBPACK_IMPORTED_MODULE_0__.Component);var o=xn(i);function i(){return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),o.apply(this,arguments)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"render",value:function(){var e=this.props.panel.className?this.props.panel.className:"";return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-action-panel",{hide:this.props.panelState===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},{"properties-control-nested-panel":this.props.panel.nestedPanel},e),"data-id":an({name:this.props.panel.id}),disabled:this.props.panelState===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED},this.props.children)}}]),i}(),Mn=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{panelState:t.controller.getPanelState({name:t.panel.id})}}),null)(Bn);function Fn(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Vn=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=Fn(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).state={},r.applyAction=r.applyAction.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.uuid=(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)(),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"getActionButtonKind",value:function(){if(!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(this.props,"action.button.kind"))return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.e.TERTIARY;switch(this.props.action.button.kind){case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.e.PRIMARY:return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.e.PRIMARY;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.e.SECONDARY:return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.e.SECONDARY;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.e.TERTIARY:return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.e.TERTIARY;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.e.GHOST:return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.e.GHOST;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.e.DANGER:return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.e.DANGER;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.e.DANGER_TERTIARY:return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.e.DANGER_TERTIARY;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.e.DANGER_GHOST:return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.e.DANGER_GHOST;default:return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.e.TERTIARY}}},{key:"getActionButtonSize",value:function(){if(!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(this.props,"action.button.size"))return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.f.SMALL;switch(this.props.action.button.size){case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.f.SMALL:return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.f.SMALL;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.f.MEDIUM:return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.f.DEFAULT;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.f.LARGE:return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.f.LARGE;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.f.EXTRA_LARGE:return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.f.EXTRA_LARGE;default:return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.f.SMALL}}},{key:"applyAction",value:function(){var e=this.props.controller.getHandlers().actionHandler;"function"==typeof e&&e(this.props.action.name,this.props.controller.getAppData(),this.props.action.data)}},{key:"render",value:function(){var e=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-action-button",{hide:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN}),t=this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,r=this.getActionButtonKind(),n=this.getActionButtonSize(),o=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{type:"button",size:n,kind:r,onClick:this.applyAction,disabled:t},this.props.action.label.text),i=o;if(this.props.action.description){var a=this.uuid+"-tooltip-action-"+this.props.action.name,l=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-tooltips"},this.props.action.description.text);i=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_18__["default"],{id:a,tip:l,direction:"bottom",className:"properties-tooltips",disable:t},o)}return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:e,"data-id":this.props.action.name},i)}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Un=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{state:t.controller.getActionState(t.controller.convertPropertyId(t.action.name))}}),null)(Vn);function jn(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Hn=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=jn(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).state={},r.applyAction=r.applyAction.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.uuid=(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)(),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"applyAction",value:function(){if(this.props.state!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED){var e=this.props.controller.getHandlers().actionHandler;"function"==typeof e&&e(this.props.action.name,this.props.controller.getAppData(),this.props.action.data)}}},{key:"render",value:function(){var e={},t={};this.props.action.image.size&&(e=this.props.action.image.size.height?{height:this.props.action.image.size.height}:{},t=this.props.action.image.size.width?{width:this.props.action.image.size.width}:{});var r=this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,n=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-action-image",{left:"left"===this.props.action.image.placement},{right:"right"===this.props.action.image.placement},{hide:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},{disabled:r}),o=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":this.props.action.name},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("img",(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({src:this.props.action.image.url,onClick:this.applyAction},e,t))),i=o;if(this.props.action.description){var a=this.uuid+"-tooltip-action-"+this.props.action.name,l=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-tooltips"},this.props.action.description.text),u=this.props.action.image.tooltip_direction&&["left","right","top","bottom"].includes(this.props.action.image.tooltip_direction.toLowerCase())?this.props.action.image.tooltip_direction.toLowerCase():"bottom";i=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_18__["default"],{id:a,tip:l,direction:u,className:"properties-tooltips",disable:r},o)}return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:n},i)}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),qn=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{state:t.controller.getActionState(t.controller.convertPropertyId(t.action.name))}}),null)(Hn),zn=function(){function r(t){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r),this.controller=t}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,[{key:"generateAction",value:function(e,t){if(t){if("button"===t.actionType)return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Un,{key:"action."+e,action:t,controller:this.controller});if("image"===t.actionType)return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(qn,{key:"action."+e,action:t,controller:this.controller})}return null}}]),r}();function Gn(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return Wn(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return Wn(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function Wn(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function $n(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Xn=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=$n(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).state={showFieldPicker:!1},r.genPanel=r.genPanel.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.genUIContent=r.genUIContent.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.genUIItem=r.genUIItem.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r._getGroupedMessages=r._getGroupedMessages.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.closeFieldPicker=r.closeFieldPicker.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.openFieldPicker=r.openFieldPicker.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.generateSharedControlNames=r.generateSharedControlNames.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.messages=r._getGroupedMessages(t.messages),r.ControlFactory=t.controller.getControlFactory(),r.ControlFactory.setFunctions(r.openFieldPicker,r.genUIItem),r.ControlFactory.setRightFlyout(t.rightFlyout),r.actionFactory=new zn(r.props.controller),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"shouldComponentUpdate",value:function(e,t){return this.props.controller.isSummaryPanelShowing()||this.props.controller.isSubPanelsShowing()||(this.messages=this._getGroupedMessages(e.messages)),!0}},{key:"_getMessageCountForCategory",value:function(e){var t=this;if("alertMsgs"===e.group)return" ("+this.messages.length+")";var r=0;return this.messages.forEach((function(n){var o=t.props.controller.getControl({name:n.id_ref});o&&o.parentCategoryId===e.group&&r++})),r>0?" ("+r+")":null}},{key:"_getGroupedMessages",value:function(e){return (0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(e)?[]:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.b)(e,["type"])}},{key:"_getTabId",value:function(e){return e.group}},{key:"_showCategoryPanel",value:function(e){var t=e;this.props.activeTab===e&&(t=""),this.props.setActiveTab(t)}},{key:"_handleMessageClick",value:function(e,t){var r=this.props.controller.getControl(e);this.props.setActiveTab(r.parentCategoryId)}},{key:"_modalTabsOnClick",value:function(e){this.props.setActiveTab(e)}},{key:"genPrimaryTabs",value:function(e,t,r,n){for(var o=[],i=!1,a=0,l=0;l<t.length;l++){var u=t[l];0===l&&"alertMsgs"===u.group&&(i=!0);var c=this.genUIItem(this._getContainerIndex(i,l),u.content,r,n),p=null;if(this.props.additionalComponents&&(p=this.props.additionalComponents[u.group]),1===t.length)return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:"cat."+e,className:"properties-category"},c,p);if(this.props.rightFlyout){var d=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_19__.I,{type:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.g.CHEVRONARROWS.DOWN,className:"properties-category-caret-down"}),f=!1;this.props.activeTab===u.group&&(d=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_19__.I,{type:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.g.CHEVRONARROWS.UP,className:"properties-category-caret-up"}),f=!0),o.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:this._getContainerIndex(i,l)+"-"+e,className:"properties-category-container"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("button",{type:"button",onClick:this._showCategoryPanel.bind(this,u.group),className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-category-title",{"properties-light-enabled":this.props.controller.getLight()})},u.text,this._getMessageCountForCategory(u),d),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-category-content",{show:f})},c,p)))}else this.props.activeTab===u.group&&(a=l),o.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_24__["default"],{key:this._getContainerIndex(i,l)+"-"+e,tabIndex:l,label:u.text,onClick:this._modalTabsOnClick.bind(this,u.group)},c,p))}return this.props.rightFlyout?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:"cat."+e,className:"properties-categories"},o):react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_25__["default"],{key:"tab."+e,className:"properties-primaryTabs",selected:a,light:this.props.controller.getLight()},o)}},{key:"_getContainerIndex",value:function(e,t){return e&&0===t?"alerts":e?t-1:t}},{key:"genPanelSelector",value:function(e,t,r,n,o,i,a){var l=this.generateAdditionalPanels(t,e,n,o,!1,a);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(en,{key:"selectorPanel"+e,panels:l,dependsOn:r,controller:this.props.controller})}},{key:"generateAdditionalPanels",value:function(e,t,r,n,o,i){for(var a={},l=0;l<e.length;l++){var u=e[l],c="properties-control-panel";u.content&&"textPanel"===u.content.itemType&&(c=""),o&&(c+=" properties-control-nested-panel"),a[u.group]=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)(c,i),key:u.group+t},this.genUIItem(l,u.content,r,n))}return a}},{key:"genUIContent",value:function(e,t,r){for(var n=[],o=0;o<e.length;o++)n.push(this.genUIItem(o,e[o],t,r));return n}},{key:"genUIItem",value:function(e,t,r,n){var o="",i=null,a="";switch(t.itemType){case"control":t.additionalItems&&t.additionalItems.length>0&&(t.control.additionalItems=t.additionalItems,t.control.optionalPanels=this.generateAdditionalPanels(t.additionalItems,e,null,n,!0));var l={name:t.control.name};if(r){var u=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(r);return this.props.controller.updateLastChildPropertyId(u,{col:n(t.control.name)}),this.ControlFactory.createControlItem(t.control,u)}return this.ControlFactory.createControlItem(t.control,l);case"additionalLink":var c=this.genPanel(e,t.panel,r,n);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Cn,{key:"sub-panel-button."+e,label:t.text,title:t.secondaryText,panel:c,controller:this.props.controller,rightFlyout:this.props.rightFlyout});case"staticText":return o=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-static-text",t.textType),i="info"===t.textType?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_19__.I,{type:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.g.INFORMATION,className:"properties-static-text-icon-info"})):null,a=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:o},(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.e)(t.text,this.props.controller)),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:"static-text."+e,className:"properties-static-text-container"},i,a);case"linkText":return o=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-link-text-container",t.textType),"warning"===t.textType?i=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_19__.I,{type:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.WARNING}):"error"===t.textType&&(i=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_19__.I,{type:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.ERROR})),a=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("a",{className:"properties-link-text",onClick:this._handleMessageClick.bind(this,t.controlId)},(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.e)(t.text,this.props.controller)),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:"link-text."+e,className:o},i,a);case"hSeparator":return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("hr",{key:"h-separator."+e,className:"properties-h-separator"});case"panel":case"checkboxSelector":return this.genPanel(e,t.panel,r,n);case"subTabs":return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(On,{key:"subtabs."+e,tabs:t.tabs,className:t.className,controller:this.props.controller,rightFlyout:this.props.rightFlyout,genUIItem:this.genUIItem,nestedPanel:t.nestedPanel});case"primaryTabs":return this.genPrimaryTabs(e,t.tabs,r,n);case"panelSelector":return this.genPanelSelector(e,t.tabs,t.dependsOn,r,n,t.id,t.className);case"customPanel":return this.generateCustomPanel(e,t.panel);case"action":return this.actionFactory.generateAction(e,t.action);case"textPanel":return t.panel?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Nn,{key:"text-panel-"+e,panel:t.panel,controller:this.props.controller}):react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:"unknown."+e},"Unknown: ",t.itemType);default:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:"unknown."+e},"Unknown: ",t.itemType)}}},{key:"generateCustomPanel",value:function(e,t){if(this.props.customPanels){var r,n=Gn(this.props.customPanels);try{for(n.s();!(r=n.n()).done;){var o=r.value;if(o.id()===t.id)try{return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-custom-panel",{"properties-control-nested-panel":(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.k)(t,"nestedPanel",!1)}),key:"custom."+e},new o(t.parameters,this.props.controller,t.data).renderPanel())}catch(e){return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Error thrown creating custom panel: "+e),null}}}catch(e){n.e(e)}finally{n.f()}}return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:"custom."+e},"Panel Not Found: ",t.id)}},{key:"generateSharedControlNames",value:function(e){var t,r=Gn(this.props.controller.getSharedCtrlInfo());try{for(r.s();!(t=r.n()).done;){var n=t.value;if(void 0!==n.id&&n.id===e.id)return}}catch(e){r.e(e)}finally{r.f()}var o,i=[],a=Gn(e.uiItems);try{for(a.s();!(o=a.n()).done;){var s=o.value;if(s.control&&s.control.name){var l=s.control.name;i.push({controlName:l})}}}catch(e){a.e(e)}finally{a.f()}this.props.controller.addSharedControls(e.id,i)}},{key:"genPanel",value:function(e,t,r,n){var o=this.genUIContent(t.uiItems,r,n),i="panel."+e;switch(t.panelType){case"columnSelection":return this.generateSharedControlNames(t),o=this.genUIContent(t.uiItems,r,n),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ln,{key:i,controller:this.props.controller,panel:t},o);case"summary":return this.props.rightFlyout?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(vn,{key:"summary-panel-"+i,controller:this.props.controller,panel:t},o):o;case"actionPanel":return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Mn,{key:"action-panel-"+e,controller:this.props.controller,panel:t},o);case"twisty":return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(bn,{key:i,controller:this.props.controller,panel:t},o);case"column":return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Tn,{key:i,controller:this.props.controller,panel:t},o);default:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ln,{key:i,controller:this.props.controller,panel:t},o)}}},{key:"closeFieldPicker",value:function(e,t){this.closeFieldPickerCallback&&(this.closeFieldPickerCallback(e,t),this.closeFieldPickerCallback=null),this.props.showPropertiesButtons(!0),this.fieldPickerPropertyId=null,this.setState({showFieldPicker:!1})}},{key:"openFieldPicker",value:function(e,t){this.props.showPropertiesButtons(!1),this.fieldPickerPropertyId=e,this.closeFieldPickerCallback=t,this.setState({showFieldPicker:!0})}},{key:"fieldPicker",value:function(e){if(this.fieldPickerPropertyId&&this.fieldPickerPropertyId.name){var t,r=this.props.controller.getPropertyValue(this.fieldPickerPropertyId),n=this.props.controller.getFilteredDatasetMetadata(this.fieldPickerPropertyId),o=this.props.controller.getControl(this.fieldPickerPropertyId),i=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.g)(o),a=o.subControls;-1!==i&&(t=a?a[i].dmImage:o.dmImage);var l=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.c)(o,r);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-fp-table"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.F,{key:"field-picker-control",controller:this.props.controller,closeFieldPicker:this.closeFieldPicker,currentFields:l,fields:n,title:e,rightFlyout:this.props.rightFlyout,dmIcon:t}))}return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null)}},{key:"genAlertsTab",value:function(e){var t=e.map((function(e){return{itemType:"linkText",text:e.text,textType:e.type,controlId:{name:e.id_ref}}}));return{text:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.ALERTS_TAB_TITLE),group:"alertMsgs",content:{itemType:"panel",panel:{id:"alerts-panel",panelType:"general",uiItems:t}}}}},{key:"render",value:function(){var e=this.props.controller.getUiItems();!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(this.messages)&&"primaryTabs"===e[0].itemType&&e[0].tabs&&e[0].tabs.length>1&&(e=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(e))[0].tabs.unshift(this.genAlertsTab(this.messages));var t=this.genUIContent(e),r=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null),n=this.props.controller.getForm(),o=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.FIELDPICKER_SAVEBUTTON_LABEL)+" "+n.label;return this.props.rightFlyout&&this.state.showFieldPicker?r=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(nn,{showPropertiesButtons:!1,show:!0,title:o,light:this.props.controller.getLight()},this.fieldPicker(o)):this.state.showFieldPicker&&(t=this.fieldPicker(o)),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-editor-form"},t,r)}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Yn=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{activeTab:e.componentMetadataReducer.activeTab,messages:t.controller.getErrorMessages(!0,!0,!0)}}),(function(e,t){return{setActiveTab:function(t){e(Jr(t))}}}))(Xn),Kn=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__._;var Jn=function(e){return function(t){return null==e?void 0:Kn(e,t)}},Zn=function(){function r(t){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r),this.resources=t}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,[{key:"l10n",value:function(e,t){if(this.resources){var r=Jn(this.resources)(e);if(r||""===r)return r}return t||e}},{key:"l10nResource",value:function(e){var t;return e&&(e.resource_key?(t=this.l10n(e.resource_key))&&t!==e.resource_key||!e.default||(t=e.default):e.default&&(t=e.default)),t}},{key:"l10nLabel",value:function(e,t){return this.l10nResource(e.label)?this.l10nResource(e.label):this.l10n(t+".label",t)}},{key:"l10nDesc",value:function(e,t){return this.l10nResource(e.description)?this.l10nResource(e.description):this.l10n(t+".desc",t)}},{key:"l10nValueLabel",value:function(e,t){var r=e+"."+t+".label";return this.l10n(r,t)}}]),r}(),Qn=function(){function r(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,null,[{key:"make",value:function(e){var t;return e&&((t=new r).default=e.default,t.resource_key=e.resource_key,e.placement&&(t.placement=e.placement),e.type&&(t.type=e.type),e.link&&(t.link=e.link)),t}}]),r}();function eo(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return to(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return to(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function to(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}var ro=function(){function r(t,n,o,i,a,s,l,u,c,p,d,f,h){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r),this.name=t,this.parameters=n,this.actions=o,this.type=i,this.label=Qn.make(a),this.dependsOn=s,this.insertPanels=l,this.nestedPanel=u,this.subGroups=c,this.description=Qn.make(p),this.data=d,this.className=f,this.open=h}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,[{key:"parameterNames",value:function(){return this.parameters}},{key:"actionIds",value:function(){return this.actions}},{key:"groupType",value:function(){return this.type?this.type:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.G.CONTROLS}}],[{key:"makeGroup",value:function(e){if(e){var t;if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(e,"group_info")){t=[];var n,o=eo(e.group_info);try{for(o.s();!(n=o.n()).done;){var i=n.value,a=r.makeGroup(i);null!==a&&t.push(a)}}catch(e){o.e(e)}finally{o.f()}}return new r(Jn(e)("id"),Jn(e)("parameter_refs"),Jn(e)("action_refs"),Jn(e)("type"),Jn(e)("label"),Jn(e)("depends_on_ref"),Jn(e)("insert_panels"),Jn(e)("nested_panel"),t,Jn(e)("description"),Jn(e)("data"),Jn(e)("class_name"),Jn(e)("open"))}return null}}]),r}(),no=function(){function r(t){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r),this.groups=t}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,null,[{key:"makeGroupMetadata",value:function(e,t){var n=[];if(e){var o,i=eo(e);try{for(i.s();!(o=i.n()).done;){var a=o.value,s=ro.makeGroup(a);null!==s&&n.push(s)}}catch(e){i.e(e)}finally{i.f()}}else n.push(new ro((0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)(),t,null,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.G.CONTROLS));return new r(n)}}]),r}();function oo(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return io(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return io(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function io(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}var ao=(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)((function t(r,n,o,i,a,s,l){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,t),this.name=r,this.label=n,this.description=o,this.actionType=i,this.data=a,this.image=s,this.button=l})),so=function(){function r(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,null,[{key:"makeActionDef",value:function(e){if(e){var t=new r;return t.id=e.id,t.label=Qn.make(e.label),t.description=Qn.make(e.description),t.control=e.control,t.data=e.data,t.image=e.image,t.button=e.button,t}return null}}]),r}(),lo=function(){function r(t){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r),this.actionDefs=t}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,[{key:"getAction",value:function(e){var t;return this.actionDefs.forEach((function(r){r.id===e&&(t=r)})),t}}],[{key:"makeActionMetadata",value:function(e){if(e){var t,n=[],o=oo(e);try{for(o.s();!(t=o.n()).done;){var i=t.value,a=so.makeActionDef(i);a&&n.push(a)}}catch(e){o.e(e)}finally{o.f()}return new r(n)}return null}}]),r}();function uo(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return co(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return co(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function co(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}var po=function(){function r(t){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r),t.id&&(this.name=t.id),t.label&&(this.label=Qn.make(t.label)),t.description&&(this.description=Qn.make(t.description)),t.type&&(this.type=t.type),t.role&&(this.role=t.role),t.valueRestriction&&(this.valueRestriction=t.valueRestriction),null!==t.defaultValue&&"undefined"!==(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.t)(t.defaultValue)?t.defaultValue.parameter_ref?(this.defaultValue={},this.defaultValue.parameterRef=t.defaultValue.parameter_ref):this.defaultValue=t.defaultValue:void 0===t.defaultValue&&(this.isList()||this.isMapValue())&&(this.defaultValue=[]),"boolean"==typeof t.labelVisible&&(this.labelVisible=t.labelVisible),t.control&&(this.control=t.control),t.orientation&&(this.orientation=t.orientation),t.width&&(this.width=t.width),t.charLimit&&(this.charLimit=t.charLimit),t.placeHolderText&&(this.placeHolderText=Qn.make(t.placeHolderText)),t.separator&&(this.separator=t.separator),t.resource_key&&(this.resource_key=t.resource_key),"boolean"===(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.t)(t.visible)?this.visible=t.visible:this.visible=!0,t.valueIcons&&(this.valueIcons=t.valueIcons),"boolean"===(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.t)(t.sortable)&&(this.sortable=t.sortable),"boolean"===(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.t)(t.filterable)&&(this.filterable=t.filterable),"boolean"===(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.t)(t.resizable)&&(this.resizable=t.resizable),t.editStyle&&(this.editStyle=t.editStyle),"boolean"===(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.t)(t.required)&&(this.required=t.required),t.numberGenerator&&(t.numberGenerator.label=Qn.make(t.numberGenerator.label),this.numberGenerator=t.numberGenerator),t.isKey&&(this.isKey=t.isKey),t.dmDefault&&(this.dmDefault=t.dmDefault),t.dmImage&&(this.dmImage=t.dmImage),t.language&&(this.language=t.language),"boolean"===(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.t)(t.summary)&&(this.summary=t.summary),t.increment&&(this.increment=t.increment),t.textAfter&&(this.textAfter=Qn.make(t.textAfter)),t.textBefore&&(this.textBefore=Qn.make(t.textBefore)),"boolean"===(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.t)(t.moveableRows)&&(this.moveableRows=t.moveableRows),t.generatedValues&&(this.generatedValues=t.generatedValues),t.dateFormat&&(this.dateFormat=t.dateFormat),t.timeFormat&&(this.timeFormat=t.timeFormat),t.customControlId&&(this.customControlId=t.customControlId),t.data&&(this.data=t.data),t.rows&&(this.rows=t.rows),t.displayChars&&(this.displayChars=t.displayChars),t.uionly&&(this.uionly=t.uionly),t.actionRef&&(this.actionRef=t.actionRef),"boolean"===(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.t)(t.customValueAllowed)&&(this.customValueAllowed=t.customValueAllowed),t.className&&(this.className=t.className)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,[{key:"isList",value:function(){return!!this.type&&this.type.startsWith("array[")}},{key:"isMapValue",value:function(){return!!this.type&&this.type.startsWith("map[")}},{key:"isSubPanelEdit",value:function(){return this.editStyle===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.E.SUBPANEL}},{key:"isCompoundField",value:function(){return!(!this.role||!this.type)&&((this.type===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.OBJECT||this.baseType()===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.OBJECT)&&this.role===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.COLUMN)}},{key:"propType",value:function(){var e;for(var t in _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T)this.baseType()===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T[t]&&(e=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T[t]);return e||(e=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.STRUCTURE),e}},{key:"getRole",value:function(){return this.role?this.role:this.getValidValues()?_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.ENUM:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.UNSPECIFIED}},{key:"baseType",value:function(){var e=this.type;return this.isList()?e.substring(6,this.type.length-1):this.isMapValue()?e.substring(e.indexOf(",")+1,this.type.length-1).trim():this.valueRestriction&&!this.type?_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.STRING:e}},{key:"getValidValues",value:function(){return this.valueRestriction?this.valueRestriction:this.type===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.BOOLEAN?[!0,!1]:void 0}},{key:"getValidValueCount",value:function(){return this.getValidValues()?this.getValidValues().length:0}},{key:"getAdditionalText",value:function(e){return e.l10nResource(this.placeHolderText)}},{key:"getTextAfter",value:function(e){return e.l10nResource(this.textAfter)}},{key:"getTextAfterType",value:function(){return this.textAfter?this.textAfter.type:null}},{key:"getTextBefore",value:function(e){return e.l10nResource(this.textBefore)}},{key:"getTextBeforeType",value:function(){return this.textBefore?this.textBefore.type:null}},{key:"getControl",value:function(e){return this.control?this.control:e}},{key:"columns",value:function(e){return this.width?this.width:e}},{key:"separatorAfter",value:function(){return this.separator===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.d.AFTER}},{key:"separatorBefore",value:function(){return this.separator===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.d.BEFORE}}],[{key:"makeParameterDef",value:function(e,t,n){return e?new r({id:Jn(e)("id"),label:Jn(t)("label"),description:Jn(t)("description"),type:Jn(e)("type"),role:Jn(e)("role"),valueRestriction:Jn(e)("enum"),defaultValue:Jn(e)("default"),labelVisible:Jn(t)("label_visible"),control:Jn(t)("control"),orientation:Jn(t)("orientation"),width:Jn(t)("width"),charLimit:Jn(t)("char_limit"),placeHolderText:Jn(t)("place_holder_text"),separator:Jn(t)("separator"),resource_key:Jn(t)("resource_key"),visible:Jn(t)("visible"),valueIcons:Jn(t)("value_icons"),sortable:Jn(t)("sortable"),filterable:Jn(t)("filterable"),resizable:Jn(t)("resizable"),editStyle:Jn(t)("edit_style"),required:Jn(e)("required"),numberGenerator:Jn(t)("number_generator"),isKey:n,dmDefault:Jn(t)("dm_default"),dmImage:Jn(t)("dm_image"),language:Jn(t)("language"),summary:Jn(t)("summary"),increment:Jn(t)("increment"),textAfter:Jn(t)("text_after"),textBefore:Jn(t)("text_before"),moveableRows:Jn(t)("moveable_rows"),generatedValues:Jn(t)("generated_values"),dateFormat:Jn(t)("date_format"),timeFormat:Jn(t)("time_format"),customControlId:Jn(t)("custom_control_id"),data:Jn(t)("data"),rows:Jn(t)("rows"),displayChars:Jn(t)("display_chars"),uionly:Jn(e)("uionly"),actionRef:Jn(t)("action_ref"),customValueAllowed:Jn(t)("custom_value_allowed"),className:Jn(t)("class_name")}):null}}]),r}();function fo(e,t){if(t){var r,n=uo(t);try{for(n.s();!(r=n.n()).done;){var o=r.value;if(e===o.parameter_ref)return o}}catch(e){n.e(e)}finally{n.f()}}return null}var ho=function(){function r(t){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r),this.paramDefs=t}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,[{key:"getParameter",value:function(e){var t;return this.paramDefs.forEach((function(r){r.name===e&&(t=r)})),t}},{key:"getParameters",value:function(){return this.paramDefs.map((function(e){return e.name}))}}],[{key:"makeParameterMetadata",value:function(e,t,n){var o=[];if(Array.isArray(e)){var i,a=uo(e);try{for(a.s();!(i=a.n()).done;){var s=i.value,l=po.makeParameterDef(s,fo(s.id,t));l&&o.push(l)}}catch(e){a.e(e)}finally{a.f()}}if(Array.isArray(n)){var u,c=uo(n);try{for(c.s();!(u=c.n()).done;){var p=u.value,d=po.makeParameterDef(p,fo(p.id,t));d&&(d.uionly=!0,o.push(d))}}catch(e){c.e(e)}finally{c.f()}}return new r(o)}}]),r}();function mo(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return vo(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return vo(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function vo(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}var yo=(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)((function t(r,n,o,i,a,s,l){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,t),this.id=r,this.label=n,this.description=o,this.icon=i,this.carbonIcon=a,this.enabled=s,this.divider=l})),go=function(){function r(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,null,[{key:"makeButtonDef",value:function(e){if(e){var t=new r;return t.id=e.id,t.label=Qn.make(e.label),t.description=Qn.make(e.description),t.icon=e.icon,t.carbonIcon=e.carbon_icon,t.enabled=e.enabled,t.divider=e.divider,t}return null}}]),r}(),bo=function(){function r(t){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r),this.buttonDefs=t}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,[{key:"getButton",value:function(e){var t;return this.buttonDefs.forEach((function(r){r.id===e&&(t=r)})),t}}],[{key:"makeButtonMetadata",value:function(e){if(e){var t,n=[],o=mo(e);try{for(o.s();!(t=o.n()).done;){var i=t.value,a=go.makeButtonDef(i);a&&n.push(a)}}catch(e){o.e(e)}finally{o.f()}return new r(n)}return null}}]),r}();function Eo(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return Io(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return Io(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function Io(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}var So=function(){function r(t,n,o,i,a,s,l,u,c,p,d,f){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r),this.name=t,this.keyDefinition=n,this.parameterMetadata=o,this.moveableRows=i,this.label=Qn.make(a),this.rowSelection=s,this.buttons=d,this.addRemoveRows="boolean"!=typeof l||l,this.header="boolean"!=typeof u||u,"boolean"==typeof c&&(this.includeAllFields=c),Array.isArray(p)&&(this.layout=p),this.type=void 0===f?"array":f}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,[{key:"parameterNames",value:function(){var e=[];if(this.parameterMetadata){var t,r=Eo(this.parameterMetadata.paramDefs);try{for(r.s();!(t=r.n()).done;){var n=t.value;e.push(n.name)}}catch(e){r.e(e)}finally{r.f()}}return e}},{key:"hasSubPanel",value:function(){if(this.parameterMetadata){var e,t=Eo(this.parameterMetadata.paramDefs);try{for(t.s();!(e=t.n()).done;){if(e.value.isSubPanelEdit())return!0}}catch(e){t.e(e)}finally{t.f()}}return!1}},{key:"keyAttributeIndex",value:function(){return this.keyDefinition?0:-1}},{key:"defaultStructure",value:function(){var e=[];return this.parameterMetadata.paramDefs.forEach((function(t){e.push(t.defaultValue)})),this.keyDefinition&&e.unshift(this.keyDefinition.defaultValue),e}}],[{key:"makeStructure",value:function(e,t){return e?new r(Jn(e)("id"),po.makeParameterDef(Jn(e)("key_definition"),Jn(t)("key_definition"),!0),ho.makeParameterMetadata(Jn(e)("parameters"),Jn(t)("parameters")),Jn(t)("moveable_rows"),Jn(t)("label"),Jn(t)("row_selection"),Jn(t)("add_remove_rows"),Jn(t)("header"),Jn(t)("include_all_fields"),Jn(t)("layout"),bo.makeButtonMetadata(Jn(t)("buttons")),Jn(e)("type")):null}}]),r}();function Co(e,t){if(t){var r,n=Eo(t);try{for(n.s();!(r=n.n()).done;){var o=r.value;if(e===o.complex_type_ref)return o}}catch(e){n.e(e)}finally{n.f()}}return null}var Ro=function(){function r(t){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r),this.structures=t}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,[{key:"getStructure",value:function(e){var t;return this.structures.forEach((function(r){r.name===e&&(t=r)})),t}}],[{key:"makeStructureMetadata",value:function(e,t){if(e){var n,o=[],i=Eo(e);try{for(i.s();!(n=i.n()).done;){var a=n.value,s=So.makeStructure(a,Co(a.id,t));null!==s&&o.push(s)}}catch(e){i.e(e)}finally{i.f()}return new r(o)}return null}}]),r}(),_o=function(){function r(t,n,o,i,a,s,l,u,c,p,d,f,h){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r),this.name=t,this.icon=n,this.editorSize=o,this.pixelWidth=i,this.label=a,this.labelEditable=s,this.help=l,this.description=Qn.make(u),this.structureMetadata=c,this.parameterMetadata=p,this.groupMetadata=d,this.actionMetadata=f,this.heading=h}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,[{key:"editorSizeHint",value:function(e){return this.editorSize?this.editorSize:e||_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.SMALL}}],[{key:"makePropertyDef",value:function(e,t,n,o){var i=Ro.makeStructureMetadata(n,Jn(o)("complex_type_info")),a=ho.makeParameterMetadata(t,Jn(o)("parameter_info"),Jn(o)("ui_parameters")),s=lo.makeActionMetadata(Jn(o)("action_info")),l=no.makeGroupMetadata(Jn(o)("group_info"),a.getParameters()),u=e&&e.title?e.title:"",c=e&&void 0!==e.editable?e.editable:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.D;return new r(Jn(o)("id"),Jn(o)("icon"),Jn(o)("editor_size"),Jn(o)("pixel_width"),u,c,Jn(o)("help"),Jn(o)("description"),i,a,l,s,Jn(o)("label"))}}]),r}(),To=(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)((function t(r){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,t),this.name=r.name,r.label&&(this.label=r.label),r.description&&(this.description=r.description),"boolean"==typeof r.labelVisible&&(this.labelVisible=r.labelVisible),r.controlType&&(this.controlType=r.controlType),r.valueDef&&(this.valueDef=r.valueDef),r.role&&(this.role=r.role),r.additionalText&&(this.additionalText=r.additionalText),r.orientation&&(this.orientation=r.orientation),r.values&&(this.values=r.values),r.valueLabels&&(this.valueLabels=r.valueLabels),r.valueIcons&&(this.valueIcons=r.valueIcons),"boolean"==typeof r.sortable&&(this.sortable=r.sortable),"boolean"==typeof r.filterable&&(this.filterable=r.filterable),"boolean"==typeof r.resizable&&(this.resizable=r.resizable),r.language&&(this.language=r.language),r.charLimit&&(this.charLimit=r.charLimit),r.summary&&(this.summary=r.summary),r.increment&&(this.increment=r.increment),r.generatedValues&&(this.generatedValues={},r.generatedValues.operation&&(this.generatedValues.operation=r.generatedValues.operation),r.generatedValues.start_value&&(this.generatedValues.startValue=r.generatedValues.start_value)),r.dateFormat&&(this.dateFormat=r.dateFormat),r.timeFormat&&(this.timeFormat=r.timeFormat),r.customControlId&&(this.customControlId=r.customControlId),r.data&&(this.data=r.data),r.rows&&(this.rows=r.rows),r.displayChars&&(this.displayChars=r.displayChars),r.action&&(this.action=r.action),r.structureType&&(this.structureType=r.structureType),r.subControls&&(this.subControls=r.subControls),r.childItem&&(this.childItem=r.childItem),r.layout&&(this.layout=r.layout),"number"==typeof r.keyIndex&&(this.keyIndex=r.keyIndex),r.defaultRow&&(this.defaultRow=r.defaultRow),"boolean"==typeof r.moveableRows&&(this.moveableRows=r.moveableRows),"boolean"==typeof r.required&&(this.required=r.required),r.rowSelection&&(this.rowSelection=r.rowSelection),"boolean"==typeof r.addRemoveRows&&(this.addRemoveRows=r.addRemoveRows),"boolean"==typeof r.hideEditButton&&(this.hideEditButton=r.hideEditButton),"boolean"==typeof r.header&&(this.header=r.header),"boolean"==typeof r.uionly&&(this.uionly=r.uionly),"boolean"==typeof r.includeAllFields&&(this.includeAllFields=r.includeAllFields),r.dmImage&&(this.dmImage=r.dmImage),"boolean"==typeof r.visible&&(this.visible=r.visible),"number"==typeof r.width&&(this.width=r.width),r.editStyle?this.editStyle=r.editStyle:r.isKeyField||void 0===r.structureType||(this.editStyle=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.E.INLINE),r.dmDefault&&(this.dmDefault=r.dmDefault),r.dmImage&&(this.dmImage=r.dmImage),r.customValueAllowed&&(this.customValueAllowed=r.customValueAllowed),r.className&&(this.className=r.className),r.buttons&&(this.buttons=r.buttons)})),wo=function(){function r(t){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r),this.id=Jn(t)("id"),this.itemType=Jn(t)("itemType"),this.tabs=Jn(t)("tabs"),this.panel=Jn(t)("panel"),this.control=Jn(t)("control"),this.text=Jn(t)("text"),this.textType=Jn(t)("textType"),this.secondaryText=Jn(t)("secondaryText"),this.dependsOn=Jn(t)("dependsOn"),this.action=Jn(t)("action"),this.className=Jn(t)("className"),this.nestedPanel=Jn(t)("nestedPanel")}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,null,[{key:"makePrimaryTabs",value:function(e){return new r({itemType:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.PRIMARY_TABS,tabs:e})}},{key:"makeSubTabs",value:function(e,t,n){return new r({itemType:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.SUB_TABS,tabs:e,className:t,nestedPanel:n})}},{key:"makePanelSelector",value:function(e,t,n,o){return new r({id:e,itemType:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.PANEL_SELECTOR,tabs:t,dependsOn:n,className:o})}},{key:"makePanel",value:function(e){return new r({itemType:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.PANEL,panel:e})}},{key:"makeAdditionalLink",value:function(e,t,n){return new r({itemType:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.ADDITIONAL_LINK,panel:n,text:e,secondaryText:t})}},{key:"makeControl",value:function(e){return new r({itemType:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.CONTROL,control:e})}},{key:"makeAction",value:function(e){return new r({itemType:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.ACTION,action:e})}},{key:"makeHSeparator",value:function(){return new r({itemType:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.HORIZONTAL_SEPARATOR})}},{key:"makeStaticText",value:function(e,t){return new r({itemType:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.STATIC_TEXT,text:e,textType:t})}},{key:"makeTextPanel",value:function(e,t,n,o,i){return new r({itemType:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.TEXT_PANEL,panel:{id:e,label:t,description:n,className:o,nestedPanel:i}})}},{key:"makeCustomPanel",value:function(e,t){return new r({itemType:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.CUSTOM_PANEL,panel:e,className:t})}}]),r}(),ko=(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)((function t(r,n,o){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,t),this.text=r,this.group=n,this.content=o})),Lo=function(){function r(t,n,o,i){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r),this.propType=t===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.OBJECT?_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.STRUCTURE:t,this.isList=n,this.isMap=o,this.defaultValue=i}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,null,[{key:"make",value:function(e){return new r(e.propType(),e.isList(),e.isMapValue(),e.defaultValue)}}]),r}(),Ao=(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)((function t(r,n){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,t),this.text=r,n&&(this.numberGenerator=n)})),Oo=(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)((function t(r,n,o){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,t),this.text=r,n&&(this.placement=n),o&&(this.link=o)})),Do=(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)((function t(r,n,o,i,a,s){var l=arguments.length>6&&void 0!==arguments[6]&&arguments[6];(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,t),this.id=r,this.panelType=n,this.nestedPanel=i,this.uiItems=a,this.open=l,s&&(this.label=s),o&&(this.className=o)})),Po=(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)((function t(r,n,o,i,a){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,t),this.id=r,this.panelType=n,this.nestedPanel=i,this.uiItems=a,o&&(this.className=o)})),No=(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)((function t(r,n,o,i,a,s){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,t),this.id=r,this.panelType=n,this.nestedPanel=i,this.parameters=a,this.data=s,o&&(this.className=o)})),xo=(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)((function t(r,n){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,t),this.text=r,n.range&&(this.range=n.range)}));function Bo(e,t,r){var n=r.l10nLabel(t,t.name);return new ko(n,t.name,Mo(e.parameterMetadata,e.actionMetadata,t,e.structureMetadata,r))}function Mo(e,t,r,n,o){var i=r.name,a=null,s=null,l=r.className,u=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.k)(r,"nestedPanel",!1);switch(r.groupType()){case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.G.CONTROLS:return wo.makePanel(new Do(i,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.h.GENERAL,l,u,Fo(e,t,r,n,o)));case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.G.COLUMN_SELECTION:return wo.makePanel(new Do(i,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.h.COLUMN_SELECTION,l,u,Fo(e,t,r,n,o)));case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.G.ADDITIONAL:var c=new Do(i,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.h.GENERAL,l,u,Fo(e,t,r,n,o));return s=o.l10nLabel(r,r.name),wo.makeAdditionalLink(s,s,c);case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.G.SUB_TABS:var p=[];return Array.isArray(r.subGroups)&&r.subGroups.forEach((function(r){var i=r.name;a=Mo(e,t,r,n,o),s=o.l10nLabel(r,r.name),p.push(new ko(s,i,a))})),wo.makeSubTabs(p,l,u);case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.G.PANEL_SELECTOR:var d=Vo(r,e,t,n,o);return wo.makePanelSelector(i,d,r.dependsOn,l);case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.G.PANELS:var f=[];return Array.isArray(r.subGroups)&&r.subGroups.forEach((function(r){a=Mo(e,t,r,n,o),f.push(a)})),wo.makePanel(new Do(i,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.h.GENERAL,l,u,f));case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.G.COLUMN_PANEL:var h=[];return Array.isArray(r.subGroups)&&r.subGroups.forEach((function(r){a=Mo(e,t,r,n,o),h.push(a)})),wo.makePanel(new Do(i,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.h.COLUMN_PANEL,l,u,h));case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.G.CUSTOM_PANEL:return wo.makeCustomPanel(new No(i,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.h.CUSTOM,l,u,r.parameterNames(),r.data));case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.G.SUMMARY_PANEL:s=o.l10nLabel(r,r.name);var m=[];return Array.isArray(r.subGroups)&&r.subGroups.forEach((function(r){a=Mo(e,t,r,n,o),m.push(a)})),wo.makePanel(new Do(i,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.h.SUMMARY,l,u,m,s));case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.G.ACTION_PANEL:return wo.makePanel(new Po(i,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.h.ACTION_PANEL,l,u,function(e,t,r,n,o){var i=[];Array.isArray(r.actionIds())&&r.actionIds().forEach((function(e){var r=wo.makeAction(zo(t.getAction(e),o));i.push(r)}));return i}(0,t,r,0,o)));case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.G.TEXT_PANEL:s=o.l10nResource(r.label);var y=o.l10nResource(r.description);return wo.makeTextPanel(i,s,y,l,u);case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.G.TWISTY_PANEL:s=o.l10nLabel(r,r.name);var g=[];return Array.isArray(r.subGroups)&&r.subGroups.forEach((function(r){a=Mo(e,t,r,n,o),g.push(a)})),wo.makePanel(new Do(i,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.h.TWISTY_PANEL,l,u,g,s,r.open));default:return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("(Unknown group type '"+r.groupType()+"')"),null}}function Fo(e,t,r,n,o){var i=[],a=[];return Array.isArray(r.parameterNames())?(r.parameterNames().forEach((function(s){var l,u=e.getParameter(s);if(u.propType()===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.STRUCTURE&&n&&(l=n.getStructure(u.baseType())),!(r instanceof So)||r instanceof So&&u.isSubPanelEdit()){var c=jo(e,s,r,l,o,t,n),p=wo.makeControl(c);if(u.separatorBefore()&&i.push(wo.makeHSeparator()),u.textBefore&&i.push(wo.makeStaticText(u.getTextBefore(o),u.getTextBeforeType())),i.push(p),u.textAfter&&i.push(wo.makeStaticText(u.getTextAfter(o),u.getTextAfterType())),u.separatorAfter()&&i.push(wo.makeHSeparator()),r.subGroups&&r.subGroups.length>0)for(var d=0;d<r.subGroups.length;d++)p.control.controlType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.RADIOSET&&p.control.orientation===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.O.VERTICAL&&r.subGroups[d].type===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.G.PANEL_SELECTOR&&!0===r.subGroups[d].insertPanels&&r.subGroups[d].dependsOn===p.control.name&&(a.push(r.subGroups[d].dependsOn),p.additionalItems=Vo(r.subGroups[d],e,t,n,o))}})),Array.isArray(r.subGroups)&&r.subGroups.forEach((function(r){if(!function(e,t){if(t)for(var r=0;r<e.length;r++)if(e[r]===t)return!0;return!1}(a,r.dependsOn)){var s=Mo(e,t,r,n,o);i.push(s)}})),i):i}function Vo(e,t,r,n,o){var i=[];return Array.isArray(e.subGroups)&&e.subGroups.forEach((function(e){var a=e.name,s=Mo(t,r,e,n,o),l=o.l10nLabel(e,e.name);i.push(new ko(l,a,s))})),i}function Uo(e,t){var r,n=e.getRole();if(e.isList()){var o=function(e){var t={};switch(e.getRole()){case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.TEXT:t.controlType=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TEXTAREA;break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.ENUM:e.getValidValueCount()<5?t.controlType=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.CHECKBOXSET:t.controlType=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SOMEOFSELECT;break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.COLUMN:t.role=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.COLUMN,t.controlType=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SELECTCOLUMNS;break;default:t.controlType=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TEXTAREA}return t}(e);r=o.controlType,o.role&&(n=o.role)}else switch(e.getRole()){case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.TEXT:r=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TEXTAREA;break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.ENUM:r=e.getValidValueCount()>4||t&&!qo(e)?_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.ONEOFSELECT:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.RADIOSET;break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.COLUMN:n=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.COLUMN,r=t&&function(e){if(e.isList()||e.isMapValue())return qo(e);return!1}(e)?_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SELECTCOLUMNS:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SELECTCOLUMN;break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.EXPRESSION:r=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.EXPRESSION;break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.EMAIL:n=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.EMAIL,r=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TEXTFIELD;break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.URL:n=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.URL,r=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TEXTFIELD;break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.COLOR:n=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.COLOR,r=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TEXTFIELD;break;default:r=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TEXTFIELD}return{controlType:r,role:n}}function jo(e,t,r,n,o,i,a,s){var l=void 0!==s,u=l?s:e.getParameter(t),c=u.getAdditionalText(o),p=u.orientation,d=u.required;u.numberGenerator&&(u.numberGenerator=new xo(o.l10nLabel(u.numberGenerator,u.name),u.numberGenerator));var m,y=new Ao(o.l10nLabel(u,u.name),u.numberGenerator);u.description&&(m=new Oo(o.l10nDesc(u,u.name),u.description?u.description.placement:null,u.description?u.description.link:null));var g,b,E,I,C,R,_,k,L,A,O,D,P,N,x=!0,B=u.moveableRows,M=u.structureType;if(l||u.getRole()!==_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.CUSTOM)switch(u.propType()){case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.STRING:var F=Uo(u,l);b=F.controlType,g=F.role;break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.PASSWORD:b=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.PASSWORDFIELD;break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.BOOLEAN:x=!1,b=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.CHECKBOX;break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.INTEGER:case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.LONG:case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.DOUBLE:b=u.isList()?_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TEXTAREA:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.NUMBERFIELD;break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.DATE:g=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.DATE,b=u.isList()?_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TEXTAREA:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.DATEFIELD;break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.TIME:g=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.TIME,b=u.isList()?_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TEXTAREA:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TIMEFIELD;break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.TIMESTAMP:b=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TIMESTAMP;break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.STRUCTURE:var V=l?a.getStructure(u.baseType()):n;if(V){if(V.hasSubPanel()&&(R=function(e,t,r){var n=new Do(e.name,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.h.GENERAL,"properties-editstyle-sub-panel",!1,Fo(e.parameterMetadata,e.actionMetadata,e,r,t)),o=t.l10nLabel(e,e.name);return wo.makeAdditionalLink("...",o,n)}(V,o,a)),I=V.keyAttributeIndex(),C=V.defaultStructure(),E=[],V.parameterMetadata&&Array.isArray(V.parameterMetadata.paramDefs)&&V.parameterMetadata.paramDefs.forEach((function(e){var t=Ho(e,o,a);E.push(t)})),(u.isMapValue()||u.isList())&&V.keyDefinition){var U=Ho(V.keyDefinition,o,a);E.unshift(U)}u.isList()||u.isMapValue()?(!l&&r&&void 0!==r.groupType&&r.groupType()===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.G.COLUMN_SELECTION||u.control===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.STRUCTURETABLE||u.getRole()===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.COLUMN?(b=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.STRUCTURETABLE,B=V.moveableRows,_=V.rowSelection,k=V.addRemoveRows,L=V.header,A=V.includeAllFields):(b=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.STRUCTURELISTEDITOR,B=V.moveableRows,_=V.rowSelection,k=V.addRemoveRows,L=V.header),V.buttons&&(D=function(e,t){var r=[];return e.buttonDefs.forEach((function(n){r.push(function(e,t){var r,n;e.label&&(r=new Ao(t.l10nLabel(e,e.id)));e.description&&(n=new Oo(t.l10nDesc(e,e.description)));return new yo(e.id,r,n,e.icon,e.carbonIcon,e.enabled,e.divider)}(e.getButton(n.id),t))})),r}(V.buttons,o))):(b=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.STRUCTUREEDITOR,V.layout&&(O=V.layout)),M=V.type}else b=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TEXTFIELD;break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.OBJECT:if(l)(g=u.getRole())===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.COLUMN?b=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SELECTCOLUMN:(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Complex subControl type that is not a field! Name: "+u.name),b=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.READONLY);else if(u.isCompoundField()){var j=Uo(u,l);b=j.controlType,g=j.role}else _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Complex parameter type that is not a field! Name: "+u.name),b=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.READONLY;break;default:g="???"+u.propType()+"???",b=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TEXTAREA}else b=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.CUSTOM;u.getRole()===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.ENUM&&(P=function(e,t){if(Array.isArray(e.getValidValues())){var r;r=e.resource_key?e.resource_key:e.name;var n=[];return e.getValidValues().forEach((function(e){n.push(t.l10nValueLabel(r,String(e)))})),n}return[]}(u,o)),!l&&u.actionRef&&(N=zo(i.getAction(u.actionRef),o));var H={};return H.name=u.name,H.label=y,H.description=m,H.labelVisible="boolean"==typeof u.labelVisible?u.labelVisible:x,H.controlType=u.getControl(b),H.valueDef=Lo.make(u),H.structureType=M,H.role=g,H.additionalText=c,H.orientation=p,H.values=u.getValidValues(),H.valueLabels=P,H.valueIcons=u.valueIcons,H.sortable=u.sortable,H.filterable=u.filterable,H.resizable=u.resizable,H.charLimit=u.charLimit,H.subControls=E,H.keyIndex=I,H.defaultRow=C,H.childItem=R,H.moveableRows=B,H.required=d,H.language=u.language,H.summary=u.summary,H.increment=u.increment,H.rowSelection=_,H.generatedValues=u.generatedValues,H.addRemoveRows=k,H.dateFormat=u.dateFormat,H.timeFormat=u.timeFormat,H.customControlId=u.customControlId,H.data=u.data,H.rows=u.rows,H.displayChars=u.displayChars,H.header=L,H.uionly=u.uionly,H.includeAllFields=A,H.layout=O,H.dmImage=u.dmImage,H.action=N,H.customValueAllowed=u.customValueAllowed,H.className=u.className,H.buttons=D,l&&(H.visible=u.visible,H.width=u.columns(8),H.editStyle=u.editStyle,H.isKeyField=u.isKey,H.dmDefault=u.dmDefault),new To(H)}function Ho(e,t,r){return jo(null,null,null,e.propType()===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.STRUCTURE?r.getStructure(e.baseType()):null,t,null,r,e)}function qo(e){return"on_panel"===e.editStyle||"subpanel"===e.editStyle}function zo(e,t){var r,n=new Ao(t.l10nLabel(e,e.id));return e.description&&(r=new Oo(t.l10nDesc(e,e.id))),new ao(e.id,n,r,e.control,e.data,e.image,e.button)}function Go(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return Wo(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return Wo(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function Wo(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function $o(e,t){for(var r in e)(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(e,r)&&"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e[r])&&null!==e[r]&&(e[r].message?e[r].message.default=t.l10nResource(e[r].message):$o(e[r],t))}function Xo(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return Yo(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return Yo(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function Yo(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}var Ko=function(){function r(t,n,o,i,a,s,l,u,c,p,d,f,h){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r),this.componentId=t,this.label=n,this.labelEditable=o,this.help=i,this.editorSize=a,this.pixelWidth=s,this.uiItems=l,this.buttons=u,this.data=c,this.conditions=p,this.resources=d,this.icon=f,this.heading=h}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,null,[{key:"makeForm",value:function(e,t){var n,o,i=_o.makePropertyDef(Jn(e)("titleDefinition"),Jn(e)("parameters"),Jn(e)("complex_types"),Jn(e)("uihints")),a=Jn(e)("resources"),s=Jn(e)("conditions");if(i){var l=new Zn(a),c=[];if(i.groupMetadata&&i.groupMetadata.groups){var p,d=Xo(i.groupMetadata.groups);try{for(d.s();!(p=d.n()).done;){var f=p.value;c.push(Bo(i,f,l))}}catch(e){d.e(e)}finally{d.f()}}var h={currentParameters:Jn(e)("current_parameters"),uiCurrentParameters:Jn(e)("current_ui_parameters"),datasetMetadata:Jn(e)("dataset_metadata")},m=t?_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.LARGE:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.SMALL;return new r(i.name,i.label,i.labelEditable,i.help,i.editorSizeHint(m),i.pixelWidth,[wo.makePrimaryTabs(c)],(n=new Jo("ok","OK",!0,""),o=new Jo("cancel","Cancel",!1,""),[n,o]),h,function(e,t){if(e&&Array.isArray(e)){var r,n=Go(e);try{for(n.s();!(r=n.n()).done;)$o(r.value,t)}catch(e){n.e(e)}finally{n.f()}}return e}(s,l),a,i.icon,l.l10nResource(i.heading))}return null}}]),r}();var Jo=(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)((function t(r,n,o,i){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,t),this.id=r,this.text=n,this.isPrimary=o,this.url=i}));function Zo(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Qo=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_9__.A);var o=Zo(i);function i(t,r,n,a,s){var l;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),(l=o.call(this,t)).newValues=t,l.initialValues=r,l.appData=n,l.applyPropertyChanges=a,l.propertiesActionLabel=s,l}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"do",value:function(){this.applyPropertyChanges(this.newValues.properties,this.appData,this.newValues.additionalInfo,this.newValues.undoInfo,this.newValues.uiProperties)}},{key:"undo",value:function(){this.applyPropertyChanges(this.initialValues.properties,this.appData,this.initialValues.additionalInfo,this.initialValues.undoInfo,this.initialValues.uiProperties)}},{key:"redo",value:function(){this.applyPropertyChanges(this.newValues.properties,this.appData,this.newValues.additionalInfo,this.newValues.undoInfo,this.newValues.uiProperties)}},{key:"getLabel",value:function(){return this.propertiesActionLabel}}]),i}();var ei=function(e){return void 0===e},ti=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.m,ri=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__._;var ni=_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.e,oi=_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.a,ii=function(e){return ti((function(t,r){var n=-1,o=r.length,i=o>1?r[o-1]:void 0,a=o>2?r[2]:void 0;for(i=e.length>3&&"function"==typeof i?(o--,i):void 0,a&&ri(r[0],r[1],a)&&(i=o<3?void 0:i,o=1),t=Object(t);++n<o;){var s=r[n];s&&e(t,s,n,i)}return t}))},ai=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.n,si=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.o,li=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.p,ui=Object.prototype.hasOwnProperty,ci=ii((function(e,t){if(si(t)||ai(t))oi(t,li(t),e);else for(var r in t)ui.call(t,r)&&ni(e,r,t[r])}));function pi(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0,r=t.property&&t.property.propertyId?t.property.propertyId:null;switch(t.type){case"UPDATE_PROPERTY_VALUE":if(null===r)return e;var n=e;return void 0!==r.row?(void 0===n[r.name]&&(n[r.name]=[]),void 0!==r.col?(void 0===n[r.name][r.row]&&(n[r.name][r.row]=[]),void 0!==r.propertyId?di(r.propertyId,n[r.name][r.row][r.col],t.property.value):n[r.name][r.row][r.col]=t.property.value):void 0!==r.propertyId?di(r.propertyId,n[r.name][r.row],t.property.value):n[r.name][r.row]=t.property.value):n[r.name]=t.property.value,Object.assign({},e,n);case"SET_PROPERTY_VALUES":return Object.assign({},t.properties);case"REMOVE_PROPERTY_VALUE":var o=e;return null!==r&&void 0!==r.name&&delete o[r.name],Object.assign({},e,o);default:return e}}function di(e,t,r){void 0!==e.row&&(void 0!==e.col?(void 0===t[e.row]&&(t[e.row]=[]),void 0!==e.propertyId?di(e.propertyId,t[e.row][e.col],r):t[e.row][e.col]=r):t[e.row]=r)}function fi(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"UPDATE_CONTROL_STATE":var r=e,n=t.state.propertyId;if(void 0===r[n.name]&&(r[n.name]={}),void 0!==n.row){var o=n.row.toString();if(void 0===r[n.name][o]&&(r[n.name][o]={}),void 0!==n.col){var i=n.col.toString();void 0===r[n.name][o][i]&&(r[n.name][o][i]={}),r[n.name][o][i]={value:t.state.value}}else r[n.name][o]={value:t.state.value}}else r[n.name]={value:t.state.value};return Object.assign({},e,r);case"SET_CONTROL_STATES":return Object.assign({},t.states);default:return e}}function hi(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"UPDATE_PANEL_STATE":var r=e;return r[t.state.panelId.name]={value:t.state.value},Object.assign({},e,r);case"SET_PANEL_STATES":return Object.assign({},t.states);default:return e}}function mi(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"UPDATE_ACTION_STATE":var r=e;return r[t.state.actionId.name]={value:t.state.value},Object.assign({},e,r);case"SET_ACTION_STATES":return Object.assign({},t.states);default:return e}}function vi(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"UPDATE_ERROR_MESSAGE":var r=e,n=t.message.propertyId;if(void 0===r[n.name]&&(r[n.name]={}),void 0!==n.row){var o=n.row.toString();if(void 0===r[n.name][o]&&(r[n.name][o]={}),void 0!==n.col){var i=n.col.toString();void 0===r[n.name][o][i]&&(r[n.name][o][i]={}),r[n.name][o][i]=t.message.value}else r[n.name][o]=Object.assign({},t.message.value)}else r[n.name]=Object.assign({},t.message.value);return Object.assign({},e,r);case"CLEAR_ERROR_MESSAGE":var a=e;return a[t.message.propertyId.name]&&(void 0!==t.message.propertyId.row?void 0!==t.message.propertyId.col?delete a[t.message.propertyId.name][t.message.propertyId.row][t.message.propertyId.col]:delete a[t.message.propertyId.name][t.message.propertyId.row]:(delete a[t.message.propertyId.name].type,delete a[t.message.propertyId.name].text,delete a[t.message.propertyId.name].validation_id,delete a[t.message.propertyId.name].required,delete a[t.message.propertyId.name].propertyId,delete a[t.message.propertyId.name].displayError,(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(a[t.message.propertyId.name])&&delete a[t.message.propertyId.name])),Object.assign({},e,a);case"SET_ERROR_MESSAGES":return Object.assign({},t.messages);default:return e}}function yi(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=arguments.length>1?arguments[1]:void 0;return"SET_DATASET_METADATA"===t.type?Object.assign({},e,t.datasetMetadata):e}function gi(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"UPDATE_SELECTED_ROWS":var r=e,n=t.info.propertyId;if(r[n.name]||(r[n.name]={}),Number.isInteger(n.row)){var o=String(n.row);if(r[n.name][o]||(r[n.name][o]={}),Number.isInteger(n.col)){var i=String(n.col);r[n.name][o][i]||(r[n.name][o][i]={}),r[n.name][o][i].selectedRows=t.info.selectedRows}else r[n.name][o].selectedRows=t.info.selectedRows}else r[n.name].selectedRows=t.info.selectedRows;return Object.assign({},e,r);case"CLEAR_SELECTED_ROWS":var a=e,s=t.info.propertyId;if(t.info.propertyId){if(a[s.name])if(Number.isInteger(s.row)&&a[s.name][String(s.row)]){var l=String(s.row);Number.isInteger(s.col)&&a[s.name][l][String(s.col)]?a[s.name][l][String(s.col)].selectedRows=[]:a[s.name][l].selectedRows=[]}else a[s.name].selectedRows=[];return Object.assign({},e,a)}return{};default:return e}}function bi(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"UPDATE_STATIC_ROWS":var r=e,n=t.info.propertyId;if(r[n.name]||(r[n.name]={}),Number.isInteger(n.row)){var o=String(n.row);if(r[n.name][o]||(r[n.name][o]={}),Number.isInteger(n.col)){var i=String(n.col);r[n.name][o][i]||(r[n.name][o][i]={}),r[n.name][o][i].staticRows=t.info.staticRows}else r[n.name][o].staticRows=t.info.staticRows}else r[n.name].staticRows=t.info.staticRows;return Object.assign({},e,r);case"CLEAR_STATIC_ROWS":var a=e,s=t.info.propertyId;if(t.info.propertyId){if(a[s.name])if(Number.isInteger(s.row)&&a[s.name][String(s.row)]){var l=String(s.row);Number.isInteger(s.col)&&a[s.name][l][String(s.col)]?a[s.name][l][String(s.col)].staticRows=[]:a[s.name][l].staticRows=[]}else a[s.name].staticRows=[];return Object.assign({},e,a)}return{};default:return e}}function Ei(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"SET_TITLE":var r=e;return r.title=t.title,Object.assign({},e,r);case"SET_ACTIVE_TAB":var n=e;return n.activeTab=t.activeTab,Object.assign({},e,n);default:return e}}function Ii(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=arguments.length>1?arguments[1]:void 0;if("DISABLE_ROW_MOVE_BUTTONS"===t.type){var r=e;return r.propertyIds=t.propertyIds,Object.assign({},e,r)}return e}function Si(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=arguments.length>1?arguments[1]:void 0;if("SET_SAVE_BUTTON_DISABLE"===t.type){var r=e;return r.disable=t.disableState,Object.assign({},e,r)}return e}function Ci(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0,r=t.info&&t.info.propertyId?t.info.propertyId:null;switch(t.type){case"SET_ADD_REMOVE_ROWS":if(null===r)return e;var n=e;return void 0===n[r.name]&&(n[r.name]={}),void 0!==r.row?Ri(r,n[r.name],"addRemoveRows",t.info.value):n[r.name].addRemoveRows=t.info.value,Object.assign({},e,n);case"SET_TABLE_BUTTON_ENABLED":if(null===r)return e;var o=e;return void 0===o[r.name]&&(o[r.name]={}),void 0!==r.row?Ri(r,o[r.name],"tableButtons.".concat(t.info.buttonId),t.info.value):(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_9__.s)(o[r.name],"tableButtons.".concat(t.info.buttonId),t.info.value),Object.assign({},e,o);case"SET_HIDE_EDIT_BUTTON":if(null===r)return e;var i=e;return void 0===i[r.name]&&(i[r.name]={}),void 0!==r.row?Ri(r,i[r.name],"hideEditButton",t.info.value):i[r.name].hideEditButton=t.info.value,Object.assign({},e,i);default:return e}}function Ri(e,t,r,n){void 0!==e.row&&(void 0===t[e.row]&&(t[e.row]={}),void 0!==e.col?(void 0===t[e.row][e.col]&&(t[e.row][e.col]={}),void 0!==e.propertyId?Ri(e.propertyId,t[e.row][e.col],r,n):(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_9__.s)(t[e.row][e.col],r,n)):void 0!==e.propertyId?Ri(e.propertyId,t[e.row],r,n):(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_9__.s)(t[e.row],r,n))}var _i=function(){function r(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r),this.combinedReducer=(0,redux__WEBPACK_IMPORTED_MODULE_26__.combineReducers)({propertiesReducer:pi,controlStatesReducer:fi,panelStatesReducer:hi,errorMessagesReducer:vi,datasetMetadataReducer:yi,rowSelectionsReducer:gi,componentMetadataReducer:Ei,disableRowMoveButtonsReducer:Ii,actionStatesReducer:mi,saveButtonDisableReducer:Si,propertiesSettingsReducer:Ci,rowFreezeReducer:bi});var t=!1;"undefined"!=typeof window&&(t=window.__REDUX_DEVTOOLS_EXTENSION__&&window.__REDUX_DEVTOOLS_EXTENSION__()),this.store=(0,redux__WEBPACK_IMPORTED_MODULE_26__.createStore)(this.combinedReducer,t)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,[{key:"dispatch",value:function(e){this.store.dispatch(e)}},{key:"getStore",value:function(){return this.store}},{key:"subscribe",value:function(e){this.store.subscribe(e)}},{key:"getPropertyValue",value:function(e){var t=this.store.getState().propertiesReducer[e.name];return this.getNestedPropertyValue(e,t)}},{key:"getNestedPropertyValue",value:function(e,t){if(void 0!==e.row&&null!=t){var r=t[e.row];return void 0!==e.col&&null!=r&&Array.isArray(r)?void 0!==e.index?r[e.col][e.index]:void 0!==e.propertyId?this.getNestedPropertyValue(e.propertyId,r[e.col]):r[e.col]:void 0!==e.propertyId?this.getNestedPropertyValue(e.propertyId,r):r}return t}},{key:"getPropertyValues",value:function(){var e=this.store.getState();return (0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.i)(e.propertiesReducer)}},{key:"setPropertyValues",value:function(e){this.store.dispatch(function(e){return{type:"SET_PROPERTY_VALUES",properties:e}}(e))}},{key:"updatePropertyValue",value:function(e,t){this.store.dispatch({type:"UPDATE_PROPERTY_VALUE",property:{propertyId:e,value:t}})}},{key:"removePropertyValue",value:function(e){this.store.dispatch({type:"REMOVE_PROPERTY_VALUE",property:{propertyId:e}})}},{key:"getControlState",value:function(e){if(void 0===e)return null;var t=this.store.getState().controlStatesReducer[e.name];if(t&&("hidden"===t.value||"disabled"===t.value))return t;var r=void 0!==e.col?e.col.toString():null,n=void 0!==e.row?e.row.toString():null;return null!==r&&t&&t[r]&&(void 0!==t[r].value||t[r][n]&&(void 0!==t[r][n].value||void 0!==t[r][n].values))&&(t=t[r],null!==n&&t&&t[n]&&(void 0!==t[n].value||void 0!==t[n].values)&&(t=t[n])),t||null}},{key:"getControlStates",value:function(){var e=this.store.getState();return (0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.i)(e.controlStatesReducer)}},{key:"setControlStates",value:function(e){(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(this.getControlStates(),e)||this.store.dispatch(function(e){return{type:"SET_CONTROL_STATES",states:e}}(e))}},{key:"updateControlState",value:function(e,t){this.store.dispatch({type:"UPDATE_CONTROL_STATE",state:{propertyId:e,value:t}})}},{key:"getPanelState",value:function(e){if(void 0===e)return null;var t=this.store.getState().panelStatesReducer[e.name];return t&&t.value?t.value:null}},{key:"getPanelStates",value:function(){var e=this.store.getState();return (0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.i)(e.panelStatesReducer)}},{key:"setPanelStates",value:function(e){(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(this.getPanelStates(),e)||this.store.dispatch(function(e){return{type:"SET_PANEL_STATES",states:e}}(e))}},{key:"updatePanelState",value:function(e,t){this.store.dispatch({type:"UPDATE_PANEL_STATE",state:{panelId:e,value:t}})}},{key:"getActionState",value:function(e){if(void 0===e)return null;var t=this.store.getState().actionStatesReducer[e.name];return t&&t.value?t.value:null}},{key:"getActionStates",value:function(){var e=this.store.getState();return (0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.i)(e.actionStatesReducer)}},{key:"setActionStates",value:function(e){(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(this.getActionStates(),e)||this.store.dispatch(function(e){return{type:"SET_ACTION_STATES",states:e}}(e))}},{key:"updateActionState",value:function(e,t){this.store.dispatch({type:"UPDATE_ACTION_STATE",state:{actionId:e,value:t}})}},{key:"setSaveButtonDisable",value:function(e){this.store.dispatch(function(e){return{type:"SET_SAVE_BUTTON_DISABLE",disableState:e}}(e))}},{key:"getSaveButtonDisable",value:function(){return this.store.getState().saveButtonDisableReducer.disable}},{key:"getFilteredEnumItems",value:function(e){if(void 0===e)return null;var t=this.store.getState().controlStatesReducer[e.name];return void 0!==e.col&&t&&t[e.col.toString()]&&(t=t[e.col.toString()],void 0!==e.row&&t[e.row.toString()]&&(t=t[e.row.toString()])),t?t.enumFilter:null}},{key:"getErrorMessage",value:function(e,t){if(void 0===e)return null;var r=this.store.getState().errorMessagesReducer[e.name];if(void 0!==e.row&&r){if(r=r[e.row.toString()],void 0!==e.col&&r)return r[e.col.toString()];if(r&&r.text)return r}var n=null,o=null;if(r&&r.text&&(n=r),r){var i=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(r);o=this._getTableCellErrors(i,t)}return null!==n&&null!==o?n.text=n.text+" "+o.text:null===n&&(n=o),n}},{key:"_getTableCellErrors",value:function(e,t){var r=null,n=0,o=0;for(var i in e)if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(e,i)&&"text"!==i){var a=e[i];if(a&&a.text&&(r=a,n+=a.type===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.ERROR?1:0,o+=a.type===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.WARNING?1:0),a)for(var s in a)if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(a,s)&&"text"!==s){var l=a[s];l&&l.text&&(r=l,n+=l.type===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.ERROR?1:0,o+=l.type===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.WARNING?1:0)}}return n+o!==1&&r&&(r.type=n>0?_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.ERROR:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.WARNING,r.text=n>0?(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(t,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.TABLE_SUMMARY_ERROR,{errorMsgCount:n}):"",r.text+=o>0?(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(t,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.TABLE_SUMMARY_WARNING,{warningMsgCount:o}):""),r}},{key:"getErrorMessages",value:function(){var e=this.store.getState();return (0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.i)(e.errorMessagesReducer)}},{key:"setErrorMessages",value:function(e){(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(this.getErrorMessages(),e)||this.store.dispatch(function(e){return{type:"SET_ERROR_MESSAGES",messages:e}}(e))}},{key:"updateErrorMessage",value:function(e,t){(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(this.getErrorMessage(e),t)||this.store.dispatch({type:"UPDATE_ERROR_MESSAGE",message:{propertyId:e,value:t}})}},{key:"clearErrorMessage",value:function(e){null!==this.getErrorMessage(e)&&this.store.dispatch({type:"CLEAR_ERROR_MESSAGE",message:{propertyId:e}})}},{key:"setDatasetMetadata",value:function(e){this.store.dispatch(function(e){return{type:"SET_DATASET_METADATA",datasetMetadata:e}}(e))}},{key:"getDatasetMetadata",value:function(){return this.store.getState().datasetMetadataReducer}},{key:"getSelectedRows",value:function(e){if(void 0===e)return[];var t=this.store.getState().rowSelectionsReducer[e.name];return Number.isInteger(e.row)&&t&&(t=t[String(e.row)],Number.isInteger(e.col)&&t&&(t=t[String(e.col)])),t&&t.selectedRows?t.selectedRows:[]}},{key:"updateSelectedRows",value:function(e,t){this.store.dispatch({type:"UPDATE_SELECTED_ROWS",info:{propertyId:e,selectedRows:t}})}},{key:"clearSelectedRows",value:function(e){this.store.dispatch({type:"CLEAR_SELECTED_ROWS",info:{propertyId:e}})}},{key:"getStaticRows",value:function(e){if(void 0===e)return[];var t=this.store.getState().rowFreezeReducer[e.name];return Number.isInteger(e.row)&&t&&(t=t[String(e.row)],Number.isInteger(e.col)&&t&&(t=t[String(e.col)])),t&&t.staticRows?t.staticRows:[]}},{key:"updateStaticRows",value:function(e,t){this.store.dispatch({type:"UPDATE_STATIC_ROWS",info:{propertyId:e,staticRows:t}})}},{key:"clearStaticRows",value:function(e){this.store.dispatch({type:"CLEAR_STATIC_ROWS",info:{propertyId:e}})}},{key:"setDisableRowMoveButtons",value:function(e){this.store.dispatch(function(e){return{type:"DISABLE_ROW_MOVE_BUTTONS",propertyIds:e}}(e))}},{key:"getDisableRowMoveButtons",value:function(){return this.store.getState().disableRowMoveButtonsReducer.propertyIds}},{key:"setTitle",value:function(e){this.store.dispatch(Kr(e))}},{key:"getTitle",value:function(){return this.store.getState().componentMetadataReducer.title}},{key:"setActiveTab",value:function(e){this.store.dispatch(Jr(e))}},{key:"getActiveTab",value:function(){return this.store.getState().componentMetadataReducer.activeTab}},{key:"setAddRemoveRows",value:function(e,t){this.store.dispatch({type:"SET_ADD_REMOVE_ROWS",info:{propertyId:e,value:t}})}},{key:"getAddRemoveRows",value:function(e){var t=this.store.getState();return!t.propertiesSettingsReducer[e.name]||(void 0!==e.row?Ti(e,t.propertiesSettingsReducer[e.name],"addRemoveRows",true):t.propertiesSettingsReducer[e.name].addRemoveRows)}},{key:"setTableButtonEnabled",value:function(e,t,r){this.store.dispatch({type:"SET_TABLE_BUTTON_ENABLED",info:{propertyId:e,buttonId:t,value:r}})}},{key:"getTableButtons",value:function(e){var t=this.store.getState(),r={};return t.propertiesSettingsReducer[e.name]?void 0!==e.row?Ti(e,t.propertiesSettingsReducer[e.name],"tableButtons",r):t.propertiesSettingsReducer[e.name].tableButtons||r:r}},{key:"getTableButtonEnabled",value:function(e,t){var r=this.store.getState();return!!r.propertiesSettingsReducer[e.name]&&(void 0!==e.row?Ti(e,r.propertiesSettingsReducer[e.name],"tableButtons.".concat(t),false):r.propertiesSettingsReducer[e.name].tableButtons[t])}},{key:"setHideEditButton",value:function(e,t){this.store.dispatch({type:"SET_HIDE_EDIT_BUTTON",info:{propertyId:e,value:t}})}},{key:"getHideEditButton",value:function(e){var t=this.store.getState();return!!t.propertiesSettingsReducer[e.name]&&(void 0!==e.row?Ti(e,t.propertiesSettingsReducer[e.name],"hideEditButton",false):t.propertiesSettingsReducer[e.name].hideEditButton)}}]),r}();function Ti(e,t,r,n){return void 0!==e.row&&t[e.row]?void 0!==e.col&&t[e.row][e.col]?void 0!==e.propertyId?Ti(e.propertyId,t[e.row][e.col],r,n):(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.k)(t[e.row][e.col],r):void 0!==e.propertyId?Ti(e.propertyId,t[e.row],r,n):(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.k)(t[e.row],r):n}function wi(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return ki(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return ki(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function ki(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function Li(e,t,r){if(e.or)!function(e,t,r){for(var n=0;n<e.length;n++)Li(e[n],t,r)}(e.or,t,r);else if(e.and)!function(e,t,r){for(var n=0;n<e.length;n++)Li(e[n],t,r)}(e.and,t,r);else{if(!e.condition)throw new Error("Failed to parse definition");!function(e,t,r){e.parameter_ref?(t.push(e.parameter_ref),e.parameter_2_ref&&t.push(e.parameter_2_ref)):t.push(r)}(e.condition,t,r)}}function Ai(e,t,r){if(t.label&&(t.summaryLabel=t.label.text),r&&(t.parentCategoryId=r),e.push(t),t.subControls)for(var n=0;n<t.subControls.length;n++){var o=t.subControls[n];o.parameterName=t.name,o.columnIndex=n,r&&(o.parentCategoryId=r),e.push(o)}}function Oi(e,t,r,n,o){switch(r.itemType){case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.CONTROL:var i=r.control;if(n&&(i.summaryPanelId=n),o&&(i.parentCategoryId=o),Ai(e,i,o),r.additionalItems){var a,s=wi(r.additionalItems);try{for(s.s();!(a=s.n()).done;){Oi(e,t,a.value.content,n,o)}}catch(e){s.e(e)}finally{s.f()}}break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.ADDITIONAL_LINK:case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.CHECKBOX_SELECTOR:case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.PANEL:if(r.panel&&r.panel.uiItems){var l=n;r.panel.panelType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.h.SUMMARY&&(l=r.panel.id);var u,c=wi(r.panel.uiItems);try{for(c.s();!(u=c.n()).done;){Oi(e,t,u.value,l,o)}}catch(e){c.e(e)}finally{c.f()}}break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.PRIMARY_TABS:case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.PANEL_SELECTOR:case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.SUB_TABS:if(r.tabs){var p,d=wi(r.tabs);try{for(d.s();!(p=d.n()).done;){var f=p.value;Oi(e,t,f.content,n,r.itemType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.PANEL_SELECTOR||r.itemType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.SUB_TABS?o:f.group)}}catch(e){d.e(e)}finally{d.f()}}break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.CUSTOM_PANEL:if(r.panel&&r.panel.parameters){var h,m=wi(r.panel.parameters);try{for(m.s();!(h=m.n()).done;){var y={name:h.value,controlType:"custom"};n&&(y.summaryPanelId=n),o&&(y.parentCategoryId=o),e.push(y)}}catch(e){m.e(e)}finally{m.f()}}break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.ACTION:r.action&&r.action.name&&(t[r.action.name]=r.action);break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.STATIC_TEXT:case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.TEXT_PANEL:case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.HORIZONTAL_SEPARATOR:break;default:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Unknown UiItem type when parsing ui conditions: "+r.itemType)}return e}function Di(e,t,r){try{var n=function(e){var t=e;if(t.evaluate){var r=[];t.parameter_refs?Li(t.evaluate,r,t.parameter_refs):Li(t.evaluate,r,t.parameter_ref);var n=Array.from(new Set(r));return n.length>1?n:n[0]}throw new Error("Invalid validation schema")}(t[r]),o={params:n,definition:t};Pi(e.controls,n,o);var i=t[r].parameter_refs;t[r].group_refs?i=t[r].group_refs:t[r].action_refs?i=t[r].action_refs:t[r].target&&t[r].target.parameter_ref&&(i=[t[r].target.parameter_ref]),i&&Pi(e.refs,i,o)}catch(e){_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.info("Error parsing ui conditions: "+e)}return e}function Pi(e,t,r){if(!0===Array.isArray(t))for(var n=0;n<t.length;n++)void 0===e[t[n]]&&(e[t[n]]=[]),e[t[n]].push(r);else void 0===e[t]&&(e[t]=[]),e[t].push(r)}function Ni(e){var t={};if(e&&e.functions){var r=new Zn(Jn(e)("resources")),n=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(e.functions);if(Array.isArray(n.function_info)&&Array.isArray(n.function_categories)){var o=n.parmsSet?n.function_info:function(e,t){return e.map((function(e){var r=e;return r.locLabel=t.l10nLabel(r,r.id),r.help=t.l10nDesc(r,r.locLabel),r.value=r.locLabel,Array.isArray(e.parameters)&&(r.locLabel&&-1!==r.locLabel.indexOf("?")?e.parameters.forEach((function(e){-1!==r.locLabel.indexOf("?")&&(r.locLabel=r.locLabel.replace("?"," "+t.l10nLabel(e,e.id)+" "))})):(r.value+="(",r.locLabel+="(",e.parameters.forEach((function(e,n){var o=n>0?", ":"";r.locLabel+=o+t.l10nLabel(e,e.id),r.value+=o+"?"})),r.locLabel+=")",r.value+=")")),r}))}(n.function_info,r);n.parmsSet=!0,t.functionCategories=[],n.function_categories.forEach((function(e){t.functionCategories[e.id]={},t.functionCategories[e.id].locLabel=r.l10nLabel(e,e.id),t.functionCategories[e.id].functionList=[],e.function_refs.forEach((function(r){var n=xi(r,o);n&&t.functionCategories[e.id].functionList.push(n)}))})),t.operators=[],n.operator_refs&&n.operator_refs.forEach((function(e){var r=xi(e,o);r&&t.operators.push(r)})),t.fields={field_categories:[],field_table_info:[]},e.fields&&(e.fields.field_categories&&e.fields.field_categories.forEach((function(e){e.locLabel=r.l10nLabel(e,e.id),e.field_columns.field_column_info.locLabel=r.l10nLabel(e.field_columns.field_column_info,e.id+".field_column_info"),e.field_columns.value_column_info.locLabel=r.l10nLabel(e.field_columns.value_column_info,e.id+".value_column_info"),e.field_columns.additional_column_info&&e.field_columns.additional_column_info.forEach((function(t){t.locLabel=r.l10nLabel(t,e.id+".additional_column_info."+t.id)})),t.fields.field_categories.push(e)})),e.fields.field_table_info&&e.fields.field_table_info.forEach((function(e){t.fields.field_table_info.push(e)})))}}return t}function xi(e,t){var r=t.find((function(t){return t.id===e}));return r||(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Expression function information list, no function information found for "+e),null)}function Bi(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return Mi(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return Mi(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function Mi(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function Fi(e,t,r){switch(t.itemType){case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.PRIMARY_TABS:case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.SUB_TABS:if(t.tabs){var n,o=Bi(t.tabs);try{for(o.s();!(n=o.n()).done;){Fi(e,n.value.content,r)}}catch(e){o.e(e)}finally{o.f()}}break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.TEXT_PANEL:case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.PANEL:case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.CUSTOM_PANEL:case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.ADDITIONAL_LINK:case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.CHECKBOX_SELECTOR:if(t.panel&&t.panel.id&&(e[r].panels.push(t.panel.id),Vi(e,t.panel.id),t.panel.uiItems)){var i,a=Bi(t.panel.uiItems);try{for(a.s();!(i=a.n()).done;){Fi(e,i.value,t.panel.id)}}catch(e){a.e(e)}finally{a.f()}}break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.CONTROL:if(e[r].controls.push(t.control.name),t.control.action&&e[r].actions.push(t.control.action.name),t.control.additionalItems){var s,l=Bi(t.control.additionalItems);try{for(l.s();!(s=l.n()).done;){Fi(e,s.value.content,r)}}catch(e){l.e(e)}finally{l.f()}}break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.PANEL_SELECTOR:if(e[r].panels.push(t.id),Vi(e,t.id),t.dependsOn&&e[t.id].controls.push(t.dependsOn),t.tabs){var u,c=Bi(t.tabs);try{for(c.s();!(u=c.n()).done;){Fi(e,u.value.content,t.id)}}catch(e){c.e(e)}finally{c.f()}}break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.ACTION:e[r].actions.push(t.action.name);break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.STATIC_TEXT:case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.I.HORIZONTAL_SEPARATOR:break;default:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Unknown UiItem type when parsing ui conditions: "+t.itemType)}}function Vi(e,t){(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(e,t)&&_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Duplicate panel ids, each panel id must be unique.  Panel id = "+t),e[t]={controls:[],panels:[],actions:[]}}var Ui=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.b,ji=_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_9__.a,Hi=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.q,qi=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.l,zi=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.m)((function(e){var t=qi(e);return t="function"==typeof t?t:void 0,ji(Ui(e,1,Hi,!0),void 0,t)})),Gi=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.r,Wi=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.u,$i=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.v,Xi=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.g,Yi=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.s,Ki=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.t,Ji=Math.min;var Zi=function(e,t,r){for(var n=r?$i:Wi,o=e[0].length,i=e.length,a=i,s=Array(i),l=1/0,u=[];a--;){var c=e[a];a&&t&&(c=Xi(c,Yi(t))),l=Ji(c.length,l),s[a]=!r&&(t||o>=120&&c.length>=120)?new Gi(a&&c):void 0}c=e[0];var p=-1,d=s[0];e:for(;++p<o&&u.length<l;){var f=c[p],h=t?t(f):f;if(f=r||0!==f?f:0,!(d?Ki(d,h):n(u,h,r))){for(a=i;--a;){var m=s[a];if(!(m?Ki(m,h):n(e[a],h,r)))continue e}d&&d.push(h),u.push(f)}}return u},Qi=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.q;var ea=function(e){return Qi(e)?e:[]},ta=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.g,ra=Zi,na=ea,oa=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.l,ia=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.m)((function(e){var t=oa(e),r=ta(e,na);return(t="function"==typeof t?t:void 0)&&r.pop(),r.length&&r[0]===e[0]?ra(r,void 0,t):[]}));function aa(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return sa(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return sa(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function sa(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function la(e,t,r){var n=e;if(n.validation)return function(e,t,r){if(e.fail_message&&e.evaluate){var n=e.evaluate;n.isValidation=!0;var o=ca(n,t,r);return"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(o)?o:o||function(e){if(e.focus_parameter_ref&&e.message)return{text:e.message.default,type:e.type};return"Failed to parse failedMessage"}(e.fail_message)}throw new Error("Invalid validation schema")}(n.validation,t,r);if(n.enabled)return function(e,t,r){if((e.parameter_refs||e.group_refs||e.action_refs)&&e.evaluate)return ca(e.evaluate,t,r);throw new Error("Invalid enabled schema")}(n.enabled,t,r);if(n.visible)return function(e,t,r){if((e.parameter_refs||e.group_refs||e.action_refs)&&e.evaluate)return ca(e.evaluate,t,r);throw new Error("Invalid visible schema")}(n.visible,t,r);if(n.enum_filter)return function(e,t,r){if(e.target&&e.evaluate)return ca(e.evaluate,t,r);throw new Error("Invalid filteredEnum schema")}(n.enum_filter,t,r);if(n.allow_change)return function(e,t,r){if((e.parameter_refs||e.group_refs)&&e.evaluate)return ca(e.evaluate,t,r);throw new Error("Invalid allow change schema")}(n.allow_change,t,r);if(n.default_value)return function(e,t,r){if(e.parameter_ref&&e.value&&e.evaluate)return ca(e.evaluate,t,r);throw new Error("Invalid conditional default schema")}(n.default_value,t,r);throw new Error("Invalid user input validation definition schema")}function ua(e,t,r,n){return t&&t.filter&&t.filter.evaluate?pa(e,t.filter,t.filter.evaluate,r,n):n}function ca(e,t,r){if(e.or)return function(e,t,r){for(var n=0;n<e.length;n++){if(!0===ca(e[n],t,r))return!0}return!1}(e.or,t,r);if(e.and)return function(e,t,r){for(var n=0;n<e.length;n++){var o=ca(e[n],t,r);if(!1===o)return!1;if("object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(o))return o}return!0}(e.and,t,r);if(e.condition)return function(e,t,r,n){var o=e.op,i=e.parameter_ref,a=e.parameter_2_ref,s=e.value,l={},u=r.getPropertiesConfig();n||"null"!==u.conditionDisabledPropertyHandling||(l.filterDisabled=!0);n||"null"!==u.conditionHiddenPropertyHandling||(l.filterHidden=!0);var c,p={param:i,id:da(t,i)};p.value=r.getPropertyValue(p.id,l,null),p.control=r.getControl(p.id),void 0===p.control&&_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Control not found when validating condition for "+i);void 0!==a&&((c={param:a,id:da(t,a)}).value=r.getPropertyValue(c.id,l,null),c.control=r.getControl(c.id));var d=r.getConditionOp(o);if(d)return d(p,c,s,r);return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring unknown condition operation '"+o+"' for parameter_ref "+i),!0}(e.condition,t,r,e.isValidation);throw new Error("Failed to parse definition")}function pa(e,t,r,n,o){if(r.or)return function(e,t,r,n,o){var i,a=[],s=aa(r);try{for(s.s();!(i=s.n()).done;){var l=pa(e,t,i.value,n,o);a=zi(a,l,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)}}catch(e){s.e(e)}finally{s.f()}return a}(e,t,r.or,n,o);if(r.and)return function(e,t,r,n,o){var i,a=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(o),s=aa(r);try{for(s.s();!(i=s.n()).done;){var l=pa(e,t,i.value,n,a);a=ia(a,l,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)}}catch(e){s.e(e)}finally{s.f()}return a}(e,t,r.and,n,o);if(r.condition)return function(e,t,r,n,o){var i=r.op,a=[];void 0!==r.value&&null!==r.value?a.push(r.value):Array.isArray(r.values)&&a.push.apply(a,(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_9__.b)(r.values));switch(i){case"dmMeasurement":return function(e,t){var r=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(e);r&&(r=r.filter((function(e){var r,n=aa(t);try{for(n.s();!(r=n.n()).done;){var o=r.value;if(e.metadata&&e.metadata.measure===o)return!0}}catch(e){n.e(e)}finally{n.f()}return!1})));return r}(o,a);case"dmType":return function(e,t){var r=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(e);r&&(r=r.filter((function(e){var r,n=aa(t);try{for(n.s();!(r=n.n()).done;){var o=r.value;if(e.type===o)return!0}}catch(e){n.e(e)}finally{n.f()}return!1})));return r}(o,a);case"dmModelingRole":return function(e,t){var r=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(e);r&&(r=r.filter((function(e){var r,n=aa(t);try{for(n.s();!(r=n.n()).done;){var o=r.value;if(e.metadata&&e.metadata.modeling_role===o)return!0}}catch(e){n.e(e)}finally{n.f()}return!1})));return r}(o,a);case"dmSharedFields":return function(e,t,r,n){var o=n;t.parameter_refs&&(o=r.filterFieldsFromSharedProps(n,t.parameter_refs,e.name));return o}(e,t,n,o);default:return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring unknown condition operation '"+i+"'"),o}}(e,t,r.condition,n,o);throw new Error("Failed to parse filter definition")}function da(e,t){var r={},n=t.indexOf("[");return n>-1?((r=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(e)).name=t.substring(0,n),r.col=function(e){var t=e.indexOf("[");if(t>-1){var r=e.indexOf("]");return r>-1?parseInt(e.substring(t+1,r),10):-1}return-1}(t)):r.name=t,r}function fa(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return ha(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return ha(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function ha(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function ma(e){var t=!(arguments.length>1&&void 0!==arguments[1])||arguments[1],r=e.getControls();ya(e,r,t)}function va(e){var t={controls:e.getControlStates(),panels:e.getPanelStates(),actions:e.getActionStates()},r=e.getControls();!function(e,t,r){if(Object.keys(t).length>0)for(var n in t)if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(t,n)){var o=t[n];if(!o.parameterName){var i=o.name?{name:o.name}:{name:o},a=e.getPropertyValue(i);if(o.subControls)if(o.valueDef.isList||o.valueDef.isMap){if(ka(i,r,e),Array.isArray(a))for(var s=0;s<a.length;s++)for(var l=0;l<o.subControls.length;l++)i.row=s,i.col=l,ka(i,r,e)}else for(var u={name:i.name},c=0;c<o.subControls.length;c++)u.col=c,ka(u,r,e);else ka(i,r,e)}}}(e,r,t),Ta(e.panelTree,t,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.P);var n=Ia(e);e.setControlStates(t.controls),e.setPanelStates(t.panels),e.setActionStates(t.actions);var o,i=fa(Ea(n,Ia(e)));try{for(i.s();!(o=i.n()).done;){ba(o.value,e,1)}}catch(e){i.e(e)}finally{i.f()}}function ya(e,t,r){if(Object.keys(t).length>0)for(var n in t)if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(t,n)){var o=t[n];if(!o.parameterName)ga(o.name?{name:o.name}:{name:o},e,r)}}function ga(e,t){var r=!(arguments.length>2&&void 0!==arguments[2])||arguments[2],n=t.getControl(e);if(n){var o=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(e),i=t.getPropertyValue(o);if(Array.isArray(i)){if(wa(o,t,n,r),n.subControls)if(n.valueDef.isList||n.valueDef.isMap)for(var a=0;a<i.length;a++)for(var s=0;s<n.subControls.length;s++)o.row=a,o.col=s,wa(o,t,n.subControls[s],r);else for(var l=0;l<n.subControls.length;l++){var u={name:e.name,col:l};wa(u,t,n.subControls[l],r)}else if(void 0===o.row)for(var c=0;c<i.length;c++)o.row=c,o.col=0,wa(o,t,n,r)}else wa(o,t,n,r)}else _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Control not found for "+e.name)}function ba(e,t){var r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:0,n=t.getControl(e);if(n){var o={controls:t.getControlStates(),panels:t.getPanelStates(),actions:t.getActionStates()},i=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(e),a=t.getPropertyValue(i);if(Array.isArray(a)&&n.subControls)if(n.valueDef.isList||n.valueDef.isMap){ka(i,o,t);for(var s=0;s<a.length;s++)for(var l=0;l<n.subControls.length;l++)i.row=s,i.col=l,ka(i,o,t)}else for(var u=0;u<n.subControls.length;u++)i.col=u,ka(i,o,t);else ka(i,o,t);var c=Ia(t);t.setControlStates(o.controls),t.setPanelStates(o.panels),t.setActionStates(o.actions);var p,d=Ia(t),f=Ea(c,d,r),h=fa(f);try{for(h.s();!(p=h.n()).done;){var m=p.value;ba(m,t,r+1)}}catch(e){h.e(e)}finally{h.f()}r>0&&Ta(t.panelTree,o,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.P)}else _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Control not found for "+e.name)}function Ea(e,t,r){var n=[];if(r>10)return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("More than 10 iteration of processing conditions found. Check your conditions for loops. Updated properties: "+JSON.stringify(t)),[];var o,i=fa((0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_9__.u)(Object.keys(e),Object.keys(t)));try{for(i.s();!(o=i.n()).done;){var a=o.value,s=e[a],l=t[a];(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(s,l)||n.push({name:a})}}catch(e){i.e(e)}finally{i.f()}return n}function Ia(e){var t=e.getPropertiesConfig(),r={};return"null"===t.conditionDisabledPropertyHandling&&(r.filterDisabled=!0),"null"===t.conditionHiddenPropertyHandling&&(r.filterHidden=!0),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(r)?{}:e.getPropertyValues(r)}function Sa(e,t,r){var n=e[t.name];n||(n={});var o=Object.assign({},n);if(!(void 0===t.row&&void 0===t.col)||o.value!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN||r!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED&&r!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.ENABLED?o.value=r:o.value=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN,void 0!==t.col){var i=t.col.toString();if(n[i]||(n[i]={}),void 0!==t.row){var a=t.row.toString();n[i][a]||(n[i][a]={}),n[i][a].value=o.value}else n[i].value=o.value}else n.value=o.value;e[t.name]=n}function Ca(e,t,r,n){var o=e[t.name];o||(o={}),o.values||(o.values={}),o.values[r]||(o.values[r]={});var i=Object.assign({},o);if(!(void 0===t.row&&void 0===t.col)||i.values[r].value!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN||n!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED&&n!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.ENABLED?i.values[r].value=n:i.values[r].value=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN,void 0!==t.col){var a=t.col.toString();if(o[a]||(o[a]={}),void 0!==t.row){var s=t.row.toString();o[a][s]||(o[a][s]={}),o[a][s].values||(o[a][s].values={}),o[a][s].values[r]||(o[a][s].values[r]={}),o[a][s].values[r].value=i.values[r].value}else o[a].values||(o[a].values={}),o[a].values[r]||(o[a].values[r]={}),o[a].values[r].value=i.values[r].value}else o.values[r]=i.values[r];e[t.name]=o}function Ra(e,t){var r={name:e},n=e.indexOf("[");return n>-1&&(r.name=e.substring(0,n),r.col=parseInt(e.substring(n+1,e.indexOf("]")),10)),t&&(r.row=t.row),r}function _a(e,t,r,n){for(var o in e)if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(e,o)){var i=e[o],a=1e3*seedrandom__WEBPACK_IMPORTED_MODULE_4___default()(o)();if(!0===i.required&&Ua(i,t,r,o,a,n),"date"!==i.role&&"time"!==i.role||ja(i,t,o,a,n),"column"===i.role){var s=o;i.valueDef.isList&&(s+="[0]"),Ha(i,t,s,a,n)}if(i.subControls){for(var l={},u=0;u<i.subControls.length;u++){l[o+"["+u+"]"]=i.subControls[u]}_a(l,t,r,n)}}}function Ta(e,t,r,n){var o=t.panels[r],i=n?o&&o.value===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED:o&&(o.value===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN||o.value===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED);if(i&&e[r]){if(e[r].controls){var a,s=fa(e[r].controls);try{for(s.s();!(a=s.n()).done;){var l=a.value;n?t.controls[l].value!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN&&Sa(t.controls,{name:l},o.value):Sa(t.controls,{name:l},o.value)}}catch(e){s.e(e)}finally{s.f()}}if(e[r].actions){var u,c=fa(e[r].actions);try{for(c.s();!(u=c.n()).done;){var p=u.value;n?t.actions[p].value!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN&&Sa(t.actions,{name:p},o.value):Sa(t.actions,{name:p},o.value)}}catch(e){c.e(e)}finally{c.f()}}}if(e[r]&&e[r].panels){var d,f=fa(e[r].panels);try{for(f.s();!(d=f.n()).done;){var h=d.value;i&&(n?t.panels[h].value!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN&&Sa(t.panels,{name:h},o.value):Sa(t.panels,{name:h},o.value)),Ta(e,t,h,n)}}catch(e){f.e(e)}finally{f.f()}}}function wa(e,t,r,n){var o=!1,i=t.getDefinitions(e,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.VALIDATION,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.i.CONTROLS);if(i.length>0){var s=t.getRequiredDefinitionIds();try{var l,u=!1,c=fa(i);try{for(c.s();!(l=c.n()).done;){var p=l.value,d=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.j;u=la(p.definition,e,t);var f=!1;"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(u)&&(f=!0,d={type:u.type,text:u.text});var h=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(e);if(p.definition.validation&&p.definition.validation.fail_message&&p.definition.validation.fail_message.focus_parameter_ref&&(h=Ra(p.definition.validation.fail_message.focus_parameter_ref,h)),void 0!==h.col&&void 0===r.columnIndex&&delete h.col,d.validation_id=h.name,p.definition.validation&&p.definition.validation.id&&(d.validation_id=p.definition.validation.id),void 0===h.row&&delete h.row,d.propertyId=h,d.required=s.indexOf(p.definition.validation.id)>-1,n||(d.displayError=!1),t.getErrorMessage(h,!0,!0,!1)||(o=!1),f&&!o)t.updateErrorMessage(h,d),f&&(o=!0);else if(!f&&!o){var m=t.getErrorMessage(h,!1,!1,!1);(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(m)||m.validation_id!==d.validation_id||t.updateErrorMessage(h,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.j)}}}catch(e){c.e(e)}finally{c.f()}}catch(e){_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Error thrown in validation: "+e)}}}function ka(e,t,r){La(e,t,r,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.VISIBLE),La(e,t,r,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.ENABLED),La(e,t,r,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.FILTEREDENUM)}function La(e,t,r,n){Aa(r.getDefinitions(e,n,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.i.CONTROLS),e,t,r,n)}function Aa(e,t,r,n,o){if(e.length>0)try{e.forEach((function(i,a){var s=la(i.definition,t,n);switch(o){case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.VISIBLE:Oa(s,i.definition.visible,t,r,n,!0);break;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.ENABLED:Oa(s,i.definition.enabled,t,r,n,!1);break;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.FILTEREDENUM:var l=function(e,t){var r=e[t].definition.enum_filter.target.parameter_ref,n=!0;return e.forEach((function(e,o){o>t&&e.definition.enum_filter.target.parameter_ref===r&&(n=!1)})),n}(e,a);!function(e,t,r,n,o){if(e.enum_filter.target&&e.enum_filter.target.parameter_ref){var i=r.controls,a=Ra(e.enum_filter.target.parameter_ref,t),s=i[a.name];if(s||(s={}),void 0!==a.col){var l=a.col.toString();if(s[l]||(s[l]={}),void 0!==a.row){var u=a.row.toString();s[l][u]||(s[l][u]={});var c=Fa(e,n,s[l][u].enumFilter,s[l][u].enumFilterApplied,o);s[l][u].enumFilter=c.values,s[l][u].enumFilterApplied=c.filterApplied}else{var p=Fa(e,n,s[l].enumFilter,s[l].enumFilterApplied,o);s[l].enumFilter=p.values,s[l].enumFilterApplied=p.filterApplied}}else{var d=Fa(e,n,s.enumFilter,s.enumFilterApplied,o);s.enumFilter=d.values,s.enumFilterApplied=d.filterApplied}i[a.name]=s}}(i.definition,t,r,s,l)}}))}catch(e){_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Error thrown in validation: "+e)}}function Oa(e,t,r,n,o,i){t.parameter_refs&&Da(e,t,r,n,o,i,t.parameter_refs,"control"),t.action_refs&&Da(e,t,r,n,o,i,t.action_refs,"action"),t.group_refs&&function(e,t,r,n,o,i){var a,s=i?_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.VISIBLE:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.ENABLED,l=i?_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,u=i?_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.ENABLED:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN,c=fa(t.group_refs);try{for(c.s();!(a=c.n()).done;){var p=Ra(a.value),d=Va(n.panels,p);if(!0===e){if(p&&d!==s&&d!==u)Ba(n,p,s,o)&&Pa(n,p,s,o)}else if(p&&(i||!i&&d!==u)){Ba(n,p,l,o)&&Pa(n,p,l,o)}}}catch(e){c.e(e)}finally{c.f()}}(e,t,0,n,o,i)}function Da(e,t,r,n,o,i,a,s){var l,u=i?_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.VISIBLE:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.ENABLED,c=i?_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,p=i?_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.ENABLED:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN,d="control"===s?n.controls:n.actions,f=fa(a);try{for(f.s();!(l=f.n()).done;){var h=Ra(l.value,r),m=Va(d,h);if(Array.isArray(t.values)){var v,y=fa(t.values);try{for(y.s();!(v=y.n()).done;){var g=v.value;Ca(d,h,g,!0===e?u:c)}}catch(e){y.e(e)}finally{y.f()}}else!0===e?h&&m!==u&&m!==p&&Sa(d,h,u):h&&(i||!i&&m!==p)&&Ma(n,h,c,d)}}catch(e){f.e(e)}finally{f.f()}}function Pa(e,t,r,n){if(n.panelTree[t.name]){var o,i=n.panelTree[t.name],a=fa(i.panels);try{for(a.s();!(o=a.n()).done;){var s={name:o.value};Sa(e.panels,s,r),Pa(e,s,r,n),r===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.ENABLED?xa(s,n,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.ENABLED,e):r===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.VISIBLE&&(e.panels[t.name].disabled&&Ta(n.panelTree,e,t.name,!0),xa(s,n,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.ENABLED,e),xa(s,n,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.VISIBLE,e))}}catch(e){a.e(e)}finally{a.f()}var l,u=fa(i.controls);try{for(u.s();!(l=u.n()).done;){Na(e,t,r,n,{name:l.value},e.controls)}}catch(e){u.e(e)}finally{u.f()}var c,p=fa(i.actions);try{for(p.s();!(c=p.n()).done;){Na(e,t,r,n,{name:c.value},e.actions)}}catch(e){p.e(e)}finally{p.f()}}}function Na(e,t,r,n,o,i){Sa(i,o,r),r===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.ENABLED?(xa(o,n,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.ENABLED,e),xa(o,n,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.VISIBLE,e)):r===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.VISIBLE&&(La(o,e,n,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.VISIBLE),xa(o,n,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.VISIBLE,e),e.panels[t.name].value===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED?Sa(i,o,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED):xa(o,n,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.ENABLED,e))}function xa(e,t,r,n){var o=t.getDefinitions(e,r,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.i.REFS);o.length>0&&Aa(o,e,n,t,r)}function Ba(e,t,r,n,o){var i=t.name;if(!e.panels[i])return Sa(e.panels,t,r),!0;var a=e.panels[i].value;return((a===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.ENABLED||a===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.VISIBLE)&&(r===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED||r===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN)||a===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED&&r===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.ENABLED||a===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN&&r===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.VISIBLE)&&(Sa(e.panels,t,r),!0)}function Ma(e,t,r,n){var o=t.name;if(n[o]){var i=n[o].value;void 0!==t.col&&(n[o][t.col]&&void 0!==t.row&&n[o][t.col][t.row]?i=n[o][t.col][t.row].value:Sa(n,t,r)),((i===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.ENABLED||i===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.VISIBLE)&&(r===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED||r===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN)||i===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED&&r===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.ENABLED||i===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED&&r===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN||i===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN&&r===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.VISIBLE)&&Sa(n,t,r)}else Sa(n,t,r)}function Fa(e,t,r,n,o){var i={values:r,filterApplied:!o&&(n||!0)},a=null;return t&&(a=e.enum_filter.target.values),!a&&n||(i.values=a,i.filterApplied=!0),o&&(i.filterApplied=!1),i}function Va(e,t){var r=e[t.name];return void 0!==t.col&&r&&(r=r[t.col.toString()],void 0!==t.row&&r&&(r=r[t.row.toString()])),r?r.value:null}function Ua(e,t,r,n,o,i){var a=e.label&&e.label.text?e.label.text:n,s="required_"+n+"_"+o,l={params:n,definition:{validation:{id:s,fail_message:{type:"error",message:{default:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(i,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.REQUIRED_ERROR,{label:a})},focus_parameter_ref:n},evaluate:{condition:{parameter_ref:n,op:"isNotEmpty"}}}}};t.controls[n]?t.controls[n].push(l):t.controls[n]=[l],r.push(s)}function ja(e,t,r,n,o){var i=e.dateFormat?e.dateFormat:e.timeFormat,a=e.dateFormat?_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.k:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.l,s=i||a,l={params:r,definition:{validation:{id:"Format_"+r+"_"+n,fail_message:{type:"error",message:{default:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(o,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.DATETIME_FORMAT_ERROR,{role:e.role,format:s})},focus_parameter_ref:r},evaluate:{condition:{parameter_ref:r,op:"isDateTime",value:e.role}}}}};t.controls[r]?t.controls[r].push(l):t.controls[r]=[l]}function Ha(e,t,r,n,o){var i=e.label&&e.label.text?e.label.text:r,a={params:r,definition:{validation:{id:"validField_"+r+"_"+n,fail_message:{type:"warning",message:{default:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(o,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.INVALID_FIELD_ERROR,{label:i})},focus_parameter_ref:r},evaluate:{or:[{condition:{parameter_ref:r,op:"colDoesExists"}},{condition:{parameter_ref:r,op:"isEmpty"}}]}}}};t.controls[r]?t.controls[r].push(a):t.controls[r]=[a]}function qa(e,t,r){if(e.value)if("string"==typeof e.value)for(var n=0;n<t.length;n++){var o=t[n];if(o.name===e.value)return"type"===r?o.type:o.metadata[r]}else if("object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value))for(var i=0;i<t.length;i++){var s=t[i];if(s.origName===e.value.field_name&&s.schema===e.value.link_ref)return"type"===r?s.type:s.metadata[r]}return null}var za=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.g,Ga=Zi,Wa=ea,$a=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.m)((function(e){var t=za(e,Wa);return t.length&&t[0]===e[0]?Ga(t):[]}));function Xa(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Ya=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,n);var o=Xa(i);function i(){return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),o.apply(this,arguments)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"render",value:function(){if(!this.props.messageInfo||this.props.tableOnly&&!this.props.inTable)return null;var e=this.props.inTable?null:react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",null,this.props.messageInfo.text),t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"icon"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_19__.I,{type:this.props.messageInfo.type})),r=this.props.inTable?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-tooltips-container table-cell-msg-icon"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_18__["default"],{id:(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)()+"-table-cell-msg-icon",tip:this.props.messageInfo.text,direction:"bottom",className:"properties-tooltips"},t)):null,n=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-validation-message",this.props.messageInfo.type,{hide:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN||this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,inTable:this.props.inTable});return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:n},r,e)}}]),i}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Ka=Ya;function Ja(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Za=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(l,n);var o=Ja(l);function l(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,l),(r=o.call(this,t)).updateValueFromFilterEnum=r.updateValueFromFilterEnum.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(l,[{key:"componentDidMount",value:function(){this.updateValueFromFilterEnum(!0)}},{key:"componentDidUpdate",value:function(e){(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(this.props.controlOpts,e.controlOpts)||this.updateValueFromFilterEnum()}},{key:"updateValueFromFilterEnum",value:function(e){if(Array.isArray(this.props.value)&&Array.isArray(this.props.controlOpts.values)&&this.props.control.controlType!==_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.CUSTOM){var t=$a(this.props.value,this.props.controlOpts.values);(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(this.props.value,t)||this.props.controller.updatePropertyValue(this.props.propertyId,t,e)}}},{key:"render",value:function(){var e=this.props.value;if(this.props.control.values&&this.props.control.valueLabels){var t=this.props.control.values.indexOf(this.props.value);t>-1&&this.props.control.valueLabels[t]&&(e=this.props.control.valueLabels[t])}if(null==e?e="":"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e)&&e.link_ref?e=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.s)(e,this.props.control):Array.isArray(e)?e=e.join(", "):"boolean"==typeof e&&(e=e.toString()),e=cn(e),this.props.control.controlType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.CUSTOM)e=this.props.controller.getCustomControl(this.props.propertyId,this.props.control,{table:!0,editStyle:"summary"});else if(this.props.control.controlType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TIMESTAMP||this.props.control.valueDef&&this.props.control.valueDef.propType===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.m.TIMESTAMP){var r=new Date(e);e=(0,date_fns__WEBPACK_IMPORTED_MODULE_27__["default"])(r)?this.props.tableControl?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_intl__WEBPACK_IMPORTED_MODULE_5__.FormattedDate,{value:r,day:"numeric",month:"long",year:"numeric",hour:"numeric",minute:"numeric"}):react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_intl__WEBPACK_IMPORTED_MODULE_5__.FormattedDate,{value:r,day:"numeric",month:"long",year:"numeric",hour:"numeric",minute:"numeric",weekday:"long"}):""}var n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{className:"properties-field-type",disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED},e),o=n;if(this.props.tableControl){var i=!0;e&&(i=!1);var l=n;this.props.control.icon&&(l=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-field-readonly"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-field-type-icon"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_19__.I,{type:this.props.control.icon})),n)),o=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.k,{content:l,tooltipText:e,disabled:i})}return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-readonly",{hide:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN}),"data-id":an(this.props.propertyId)},this.props.tableControl?null:this.props.controlItem,o,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{inTable:this.props.tableControl,state:this.props.state,messageInfo:this.props.messageInfo}))}}]),l}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Qa=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){var r={value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId)};return r.controlOpts=t.controller.getFilteredEnumItems(t.propertyId,t.control),r}),null)(Za);function es(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var ts=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,n);var o=es(i);function i(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),(r=o.call(this,t)).reactIntl=t.controller.getReactIntl(),r.charLimit=sn(t.control,t.controller.getMaxLengthForSingleLineControls()),r.id=on(t.propertyId),r.isList=!1,r.props.control.valueDef&&(r.props.control.valueDef.isList&&(r.isList=!0),r.defaultValue=r.props.control.valueDef.defaultValue),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"handleChange",value:function(e){var t=e.target.value;-1!==this.charLimit&&t&&(t=t.substring(0,this.charLimit)),this.isList&&(t=ln(t,", ")),0!==t.length||void 0!==this.defaultValue&&null!==this.defaultValue||(t=null),this.props.controller.updatePropertyValue(this.props.propertyId,t)}},{key:"render",value:function(){var e=this.props.value?this.props.value:"",t=!1;if(this.isList){var r=un(e,", ");e=r.value,t=r.truncated}else t=0!==(e=cn(e)).length&&e.length!==this.props.value.length;var n=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-textfield","properties-input-control",{hide:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},this.props.messageInfo?this.props.messageInfo.type:null),o=null;if(t){var i={text:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.TRUNCATE_LONG_STRING_ERROR,{truncate_limit:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.T}),type:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.ERROR,validation_id:this.props.control.name};o=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-textinput-readonly"},this.props.tableControl?null:this.props.controlItem,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Qa,{control:this.props.control,propertyId:this.props.propertyId,controller:this.props.controller,tableControl:this.props.tableControl}),"// TODO this could conflict with the below ValidationMessage.",react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{inTable:this.props.tableControl,state:"",messageInfo:i}))}else{var a=pn(this.props.messageInfo,this.props.tableControl);o=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_28__["default"],(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},a,{autoComplete:!0===this.props.tableControl?"off":"on",id:this.id,disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,placeholder:this.props.control.additionalText,onChange:this.handleChange.bind(this),value:e,labelText:this.props.controlItem,hideLabel:this.props.tableControl,light:this.props.controller.getLight()}))}var l=o;if(this.props.tableControl){var u=(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)()+"-tooltip-column-"+this.props.propertyId.toString(),c=!0;e&&this.props.state!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED&&(c=!1);var d=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-tooltips"},String(e));l=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_18__["default"],{id:u,tip:d,direction:"bottom",className:"properties-tooltips",disable:c},o)}return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:n,"data-id":an(this.props.propertyId)},l,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{inTable:this.props.tableControl,tableOnly:!0,state:this.props.state,messageInfo:this.props.messageInfo}))}}]),i}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),rs=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId)}}),null)(ts);function ns(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var os=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,n);var o=ns(i);function i(t){var r;(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),(r=o.call(this,t)).reactIntl=t.controller.getReactIntl(),r.valuesMap={},r.iconsMap={};for(var n=0;n<t.control.values.length;++n)r.valuesMap[t.control.values[n]]=t.control.valueLabels[n],void 0!==t.control.valueIcons&&(r.iconsMap[t.control.values[n]]=t.control.valueIcons[n]);return r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"onClick",value:function(e){var t=this.props.controller.getPropertyValue(this.props.propertyId)===this.props.control.values[0]?this.props.control.values[1]:this.props.control.values[0];this.props.controller.updatePropertyValue(this.props.propertyId,t)}},{key:"renderIcon",value:function(){var e=null;if(void 0!==this.iconsMap[this.props.value]){var t=this.iconsMap[this.props.value];e="string"==typeof t&&".svg"===t.slice(t.length-4)?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_inlinesvg__WEBPACK_IMPORTED_MODULE_29__["default"],{className:"bx--btn__icon",src:t}):react__WEBPACK_IMPORTED_MODULE_0___default().createElement("img",{className:"bx--btn__icon",src:t,alt:""})}return e}},{key:"render",value:function(){var e=this.valuesMap[this.props.value];void 0===e&&(e=this.props.value);var t=null,r=this.props.tableControl?"ghost":"tertiary";void 0!==e&&(t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{kind:r,size:"small",onClick:this.onClick.bind(this),renderIcon:this.renderIcon.bind(this),iconDescription:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.TOGGLETEXT_ICON_DESCRIPTION,{toggletext_label:this.props.value}),disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED},e));var n=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-toggletext",{hide:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},this.props.messageInfo?this.props.messageInfo.type:null);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"aria-label":this.props.control.label&&this.props.control.label.text?this.props.control.label.text:"",className:n,disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,"data-id":an(this.props.propertyId)},this.props.tableControl?null:this.props.controlItem,t,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{inTable:this.props.tableControl,state:this.props.state,messageInfo:this.props.messageInfo}))}}]),i}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),is=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId)}}),null)(os);function as(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var ss=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,n);var o=as(i);function i(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),(r=o.call(this,t)).reactIntl=t.controller.getReactIntl(),r.charLimit=sn(t.control,t.controller.getMaxLengthForMultiLineControls()),r.id=on(r.props.propertyId),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"handleChange",value:function(e){var t=e.target.value;-1!==this.charLimit&&t&&(t=t.substring(0,this.charLimit)),this.props.control.valueDef&&this.props.control.valueDef.isList&&(t=ln(t,"\n")),this.props.controller.updatePropertyValue(this.props.propertyId,t)}},{key:"render",value:function(){var e=this.props.value?this.props.value:"",t=un(e,"\n");e=t.value;var r=t.truncated,n=null,o=pn(this.props.messageInfo,this.props.tableControl),i=!1;if(o.warn&&(i=!0,o={}),r){var a={text:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.TRUNCATE_LONG_STRING_ERROR,{truncate_limit:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.T}),type:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.ERROR,validation_id:this.props.control.name};o=pn(a,this.props.tableControl),n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_30__["default"],(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},o,{id:this.id,disabled:!0,placeholder:this.props.control.additionalText,value:e,labelText:this.props.controlItem,hideLabel:this.props.tableControl,light:this.props.controller.getLight()})),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{inTable:this.props.tableControl,tableOnly:!i,state:"",messageInfo:a}))}else n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_30__["default"],(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},o,{id:this.id,disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,placeholder:this.props.control.additionalText,onChange:this.handleChange.bind(this),value:e,labelText:this.props.controlItem,hideLabel:this.props.tableControl,light:this.props.controller.getLight()}));var l=n;if(this.props.tableControl){var u=(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)()+"-tooltip-column-"+this.props.propertyId.toString(),c=!0;e&&this.props.state!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED&&(c=!1);var d=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-tooltips"},String(e));l=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_18__["default"],{id:u,tip:d,direction:"bottom",className:"properties-tooltips",disable:c},n)}var f=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-textarea",{hide:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},this.props.messageInfo?this.props.messageInfo.type:null);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:f,"data-id":an(this.props.propertyId)},l,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{inTable:this.props.tableControl,tableOnly:!i,state:this.props.state,messageInfo:this.props.messageInfo}))}}]),i}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),ls=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId)}}),null)(ss);function us(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var cs=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=us(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).onDirection=r.onDirection.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.generateNumber=r.generateNumber.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.id=on(r.props.propertyId),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"onDirection",value:function(e){var t=this.props.controller.getPropertyValue(this.props.propertyId);null==t&&(t=0);var r=t.toString().split(".")[1];this.props.control.increment=this.props.control.increment?this.props.control.increment:1;var n=this.props.control.increment.toString().split(".")[1],o="up"===e?Number(t)+this.props.control.increment:Number(t)-this.props.control.increment;if(n){var i=n.length;r&&(i=r.length>=n.length?r.length:n.length),this.props.controller.updatePropertyValue(this.props.propertyId,Number(o.toFixed(i)))}else this.props.controller.updatePropertyValue(this.props.propertyId,o)}},{key:"handleChange",value:function(e,t){if("string"!=typeof t)if(e.target.validity&&e.target.validity.badInput)this.setState({invalid:!0});else{var r=e.target.value;null==r||""===r?this.props.controller.updatePropertyValue(this.props.propertyId,null):this.props.controller.updatePropertyValue(this.props.propertyId,Number(r))}else this.onDirection(t)}},{key:"generateNumber",value:function(){var e=this.props.control.label.numberGenerator,t=e.range&&e.range.min?e.range.min:1e4,r=e.range&&e.range.max?e.range.max:99999,n=Math.floor(Math.random()*(r-t+1)+t);this.props.controller.updatePropertyValue(this.props.propertyId,n)}},{key:"render",value:function(){var e=this,t="";null!==this.props.value&&void 0!==this.props.value&&(t=this.props.value);var r,n=this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,o=this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN;(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(this.props.control,"label.numberGenerator")&&(r=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-number-generator",{hide:o}),onClick:this.generateNumber,disabled:n,kind:"tertiary",renderIcon:_carbon_icons_react__WEBPACK_IMPORTED_MODULE_31__.Shuffle16,tooltipPosition:"bottom",tooltipAlignment:"end",iconDescription:this.props.control.label.numberGenerator.text,hasIconOnly:!0}));var i=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-numberfield",{"numberfield-with-number-generator":(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(this.props.control,"label.numberGenerator")?this.props.control.label.numberGenerator:null},{hide:o},this.props.messageInfo?this.props.messageInfo.type:null),a=pn(this.props.messageInfo,this.props.tableControl);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:i,"data-id":an(this.props.propertyId)},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_32__["default"],(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},a,{ref:function(t){return e.numberInput=t},id:this.id,onChange:this.handleChange.bind(this),disabled:n,step:this.props.control.increment,value:t,placeholder:this.props.control.additionalText,label:this.props.controlItem,hideLabel:this.props.tableControl,allowEmpty:!0,light:this.props.controller.getLight(),hideSteppers:this.props.tableControl||this.props.control.controlType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.NUMBERFIELD})),r,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{inTable:this.props.tableControl,tableOnly:!0,state:this.props.state,messageInfo:this.props.messageInfo}))}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),ps=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId)}}),null)(cs),ds=_toolbar_a5ec3435_js__WEBPACK_IMPORTED_MODULE_33__.t;var fs=function(e){return e?Infinity===(e=ds(e))||-Infinity===e?17976931348623157e292*(e<0?-1:1):e==e?e:0:0===e?e:0};var hs=function(e){var t=fs(e),r=t%1;return t==t?r?t-r:t:0},ms=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.w,vs=_flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_10__._,ys=hs,gs=Math.max;var bs=function(e,t,r){var n=null==e?0:e.length;if(!n)return-1;var o=null==r?0:ys(r);return o<0&&(o=gs(n+o,0)),ms(e,vs(t),o)};function Es(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Is=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=Es(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).getCustomButtonEnabled=r.getCustomButtonEnabled.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.customButtonIconCallback=r.customButtonIconCallback.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.customButtonOnClick=r.customButtonOnClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.convertToolbarConfig=r.convertToolbarConfig.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"getCustomButtonEnabled",value:function(e,t){var r=void 0!==e&&e===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,n=this.props.customButtonsState&&void 0!==this.props.customButtonsState[t.id]?this.props.customButtonsState[t.id]:t.enabled||!1;return!r&&n}},{key:"customButtonIconCallback",value:function(e,t){var r,n=this.props.controller.getHandlers().buttonIconHandler;return n&&n({type:"customButtonIcon",propertyId:this.props.propertyId,buttonId:e,carbonIcon:t},(function(e){r=e})),r}},{key:"customButtonOnClick",value:function(e){var t=this.props.controller.getHandlers().buttonHandler;t&&t({type:"custom_button",propertyId:this.props.propertyId,buttonId:e})}},{key:"convertToolbarConfig",value:function(e){var t=this,r=arguments.length>1&&void 0!==arguments[1]?arguments[1]:[],n=[];return r.forEach((function(r){var o=t.getCustomButtonEnabled(e,r),i={action:r.id,enable:o};r.icon?i.iconEnabled=r.icon:r.carbonIcon&&(i.iconEnabled=t.customButtonIconCallback(r.id,r.carbonIcon)),r.label&&(i.label=r.label.text,i.incLabelWithIcon="before",i.kind="ghost"),r.description&&(i.tooltip=r.description.text),r.divider&&"before"===r.divider&&n.push({divider:!0}),n.push(i),r.divider&&"after"===r.divider&&n.push({divider:!0})})),n}},{key:"render",value:function(){var e={leftBar:this.convertToolbarConfig(this.props.tableState,this.props.customButtons)};return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-custom-table-buttons"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_toolbar_a5ec3435_js__WEBPACK_IMPORTED_MODULE_33__.T,{config:e,instanceId:0,toolbarActionHandler:this.customButtonOnClick}))}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function Ss(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Cs=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=Ss(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).showSubPanel=r.showSubPanel.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.onSubPanelHidden=r.onSubPanelHidden.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"onSubPanelHidden",value:function(e){e||(this.props.controller.updatePropertyValue(this.props.propertyId,this.initialControlValue),this.props.controller.setErrorMessages(this.initialMessages),this.props.controller.setControlStates(this.initialStates))}},{key:"showSubPanel",value:function(){this.initialControlValue=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(this.props.controller.getPropertyValue(this.props.propertyId)),this.initialMessages=this.props.controller.getAllErrorMessages(),this.initialStates=this.props.controller.getControlStates(),this.subPanelInvoker.showSubDialog(this.props.title,this.props.panel,this.onSubPanelHidden)}},{key:"render",value:function(){var e=this,t=void 0!==this.props.disabled&&this.props.disabled,r=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.SUBPANEL_BUTTON_TOOLTIP),n=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.APPLYBUTTON_LABEL),o=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.REJECTBUTTON_LABEL);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(In,{ref:function(t){return e.subPanelInvoker=t},rightFlyout:this.props.rightFlyout,applyLabel:n,rejectLabel:o,controller:this.props.controller},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_18__["default"],{id:(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)()+"-tooltip-subpanel-cell",tip:r,direction:"left",className:"properties-tooltips icon-tooltip"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{className:"properties-subpanel-button",kind:"ghost",renderIcon:_carbon_icons_react__WEBPACK_IMPORTED_MODULE_34__.Settings16,onClick:this.showSubPanel,disabled:t,iconDescription:r,hasIconOnly:!0})))}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function Rs(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return _s(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return _s(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function _s(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function Ts(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var ws=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=Ts(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).state={filterText:null,enableRemoveIcon:!1},r.onPanelContainer=[],r.allowColumnControls=!1,r.isReadonlyTable=r.isReadonlyTable.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.indexOfColumn=r.indexOfColumn.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.setCurrentControlValueSelected=r.setCurrentControlValueSelected.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.setReadOnlyColumnValue=r.setReadOnlyColumnValue.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.removeSelected=r.removeSelected.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.updateRowSelections=r.updateRowSelections.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.handleRowClick=r.handleRowClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.createTable=r.createTable.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.onFilter=r.onFilter.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.onSort=r.onSort.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.setScrollToRow=r.setScrollToRow.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.includeInFilter=r.includeInFilter.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.makeAddRemoveButtonPanel=r.makeAddRemoveButtonPanel.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.makeEditButtonPanel=r.makeEditButtonPanel.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.makeCustomButtonsPanel=r.makeCustomButtonsPanel.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.buildChildItem=r.buildChildItem.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.makeCells=r.makeCells.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.checkedAll=r.checkedAll.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),t.selectedRows&&t.selectedRows.length>0&&(r.scrollToRow=t.selectedRows[t.selectedRows.length-1]),r.selectSummaryPropertyName="table-multi-select-edit-property-"+t.control.name,t.controller.saveControls([{name:r.selectSummaryPropertyName}]),r.setSelectedSummaryRowValue(t.selectedRows),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"componentDidMount",value:function(){if(this.props.control.subControls){var e=this.setReadOnlyColumnValue();this.props.controller.updatePropertyValue(this.props.propertyId,e,!0)}}},{key:"componentDidUpdate",value:function(){this.isSelectSummaryEdit(this.props.selectedRows)&&this.updateSelectedRowsValues()}},{key:"componentWillUnmount",value:function(){this.props.controller.removePropertyValue({name:this.selectSummaryPropertyName})}},{key:"onFilter",value:function(e){this.setState({filterText:e})}},{key:"onSort",value:function(e){for(var t=this.props.value,r=-1,n=0;n<this.props.control.subControls.length;n++)if(this.props.control.subControls[n].name===e.column){r=n;break}r>-1&&(t=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.b)(t,(function(e){return e[r]})),e.direction===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.n.DESC&&t.reverse(),this.setCurrentControlValueSelected(t,[]))}},{key:"getOnPanelContainer",value:function(e){return 0===this.onPanelContainer.length||0===e.length||this.isSelectSummaryEdit(e)?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null):react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-onpanel-container"},this.onPanelContainer[e[0]])}},{key:"getDefaultRow",value:function(){var e=[];if(this.props.control.defaultRow){var t,r=Rs(this.props.control.defaultRow);try{for(r.s();!(t=r.n()).done;){var n=t.value;null!=n&&n.parameterRef?e.push(this.props.controller.getPropertyValue({name:n.parameterRef})):e.push(n)}}catch(e){r.e(e)}finally{r.f()}}return e}},{key:"setScrollToRow",value:function(e){this.scrollToRow=e}},{key:"setCurrentControlValueSelected",value:function(e,t){var r=e;if(this.props.control.subControls&&(r=this.setReadOnlyColumnValue(e)),Array.isArray(r))for(var n=0;n<r.length;n++){var o=r[n];if(Array.isArray(o))for(var i=0;i<this.props.control.subControls.length;i++){var a=this.props.control.subControls[i];"column"===a.role&&"structure"===a.valueDef.propType&&(r[n][i]=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.m)(o[i],a,this.props.controller))}else"column"===this.props.control.role&&"structure"===this.props.control.valueDef.propType&&(r[n]=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.m)(o,this.props.control,this.props.controller))}this.props.controller.updatePropertyValue(this.props.propertyId,r);var s=Array.isArray(t)?t:[];this.updateRowSelections(s)}},{key:"setReadOnlyColumnValue",value:function(e){var t=e||this.props.value;if(!Array.isArray(t))return t;for(var r=0;r<t.length;r++)for(var n=0;n<this.props.control.subControls.length;n++){var o=this.props.control.subControls[n];if(o.controlType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.READONLY&&o.generatedValues&&"index"===o.generatedValues.operation){var i=void 0!==o.generatedValues.startValue?o.generatedValues.startValue+r:r+1;t[r][n]=i}}return t}},{key:"setSelectedSummaryRowValue",value:function(e){if(this.isSelectSummaryEdit(e)){var t={name:this.selectSummaryPropertyName},r=this.props.controller.getPropertyValue(t);r||(r=[this.getDefaultRow()],this.props.controller.updatePropertyValue(t,r,!0)),this.selectedSummaryRowValue=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(r)}}},{key:"isSelectSummaryEdit",value:function(e){return this.props.control.rowSelection===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.R.MULTIPLE&&e.length>1}},{key:"isReadonlyTable",value:function(){return this.props.control.controlType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.READONLYTABLE}},{key:"indexOfColumn",value:function(e){return bs(this.props.control.subControls,(function(t){return t.name===e}))}},{key:"handleRowClick",value:function(e,t){var r=this.props.selectedRows;if(this.props.control.rowSelection===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.R.SINGLE)r=[e];else if(!0===t.metaKey||!0===t.ctrlKey){var n=r.indexOf(e);n>=0?r.splice(n,1):r=r.concat(e)}else if(!0===t.shiftKey){for(var o=r.length>0?r[0]:e,i=(o>e?o:e)+1,a=[],s=o>e?e:o;s<i;s++)a.push(s);r=a}this.updateRowSelections(r)}},{key:"updateSelectedRowsValues",value:function(){var e=this,t={name:this.selectSummaryPropertyName},r=this.props.controller.getPropertyValue(t);r&&Array.isArray(r)&&(r[0].forEach((function(t,r){if(!(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(t,e.selectedSummaryRowValue[0][r])){var n=void 0===t?null:t;e.props.selectedRows.forEach((function(t){e.props.controller.updatePropertyValue({name:e.props.control.name,row:t,col:r},n,!0)}))}})),this.selectedSummaryRowValue=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(r))}},{key:"updateRowSelections",value:function(e){this.props.controller.updateSelectedRows(this.props.propertyId,e),this.props.rightFlyout&&this.setState({enableRemoveIcon:0!==e.length}),this.setSelectedSummaryRowValue(e)}},{key:"removeSelected",value:function(){for(var e=this.props.value,t=this.props.selectedRows.sort((function(e,t){return t-e})),r=0;r<t.length;r++)e.splice(t[r],1),this.props.controller.removeErrorMessageRow({name:this.props.propertyId.name,row:t[r]});this.setCurrentControlValueSelected(e)}},{key:"_makeCell",value:function(e,t,r,n,o,i,a){var l={name:r,row:n,col:o},u=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(this.props.propertyId),c=l;a||u.name===l.name||(c=this.props.controller.setChildPropertyId(u,l));var p,d={table:!0,allowColumnControls:this.allowColumnControls},f=this.props.controller.getControlFactory(),h=Object.assign({},e),v=h.className?h.className:"";if(e.dmImage){var y=this.props.controller.getDatasetMetadataFields(),g=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.s)(this.props.controller.getPropertyValue(c),e,!0);h.icon=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.n)(y,g,e.dmImage)}return this.isReadonlyTable()?p=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-table-cell-control",v)},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Qa,{control:this.props.controller.getControl(c),propertyId:c,controller:this.props.controller,tableControl:!0})):e.editStyle===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.E.SUBPANEL||e.editStyle===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.E.ON_PANEL?a?p=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null):(p=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-table-cell-control",v)},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Qa,{control:this.props.controller.getControl(c),propertyId:c,controller:this.props.controller,tableControl:!0})),e.editStyle===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.E.ON_PANEL&&this.onPanelContainer[n].push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:o},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("br",null),f.createControlItem(e,c)))):(d.editStyle=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.E.INLINE,p=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-table-cell-control",v)},f.createControl(h,c,d))),{column:e.name,width:e.width,content:p,className:v,value:this.props.controller.getPropertyValue(c),resizable:e.resizable}}},{key:"_getCustomCtrlContent",value:function(e,t,r,n){var o=r;return t.controlType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.CUSTOM&&(n.editStyle="summary",o=this.props.controller.getCustomControl(e,t,n)),o}},{key:"_getDisabledStatus",value:function(e,t){return void 0!==t&&t===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED||this.props.controller.getControlState(e)===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED}},{key:"includeInFilter",value:function(e){if(!this.state.filterText||0===this.state.filterText.length)return!0;for(var t=this.props.value,r=0;r<this.filterFields.length;r++)for(var n=0;n<this.props.control.subControls.length;n++){if(this.props.control.subControls[n].name===this.filterFields[r]){var o=t[e][n];if("string"==typeof o&&o.toLowerCase().indexOf(this.state.filterText.toLowerCase())>-1)return!0;break}}return!1}},{key:"hasFilter",value:function(){var e=!1;if(this.props.control.subControls){var t,r=Rs(this.props.control.subControls);try{for(r.s();!(t=r.n()).done;){if(t.value.filterable){e=!0;break}}}catch(e){r.e(e)}finally{r.f()}}return e}},{key:"addOnClick",value:function(e){this.addOnClickCallback&&this.addOnClickCallback(e,this.onFieldPickerCloseCallback)}},{key:"makeSelectedEditRow",value:function(e){if(e&&Array.isArray(e)&&e.length>1){var t=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.MULTI_SELECTED_ROW_LABEL),r=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.MULTI_SELECTED_ROW_ACTION),n=e.length+" "+t+" "+r,o=[],i=!1===this.props.control.header?[]:this.makeHeader([],[]),a=this.props.controller.getPropertyValue({name:this.selectSummaryPropertyName});this.makeCells(o,a,null,this.selectSummaryPropertyName,!0);var l=this.props.control.label&&this.props.control.label.text?this.props.control.label.text:"";return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-at-selectedEditRows"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-selectedEditRows-title"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",null,n)),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_10__.F,{showHeader:!1,columns:i,data:o,rows:0,scrollKey:this.selectSummaryPropertyName,tableLabel:l,summaryTable:!0,rowSelection:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.R.MULTIPLE,light:this.props.controller.getLight()}))}return null}},{key:"makeAddRemoveButtonPanel",value:function(e,t){this.onFieldPickerCloseCallback=t&&t.fieldPickerCloseFunction?t.fieldPickerCloseFunction.bind(this):null;var r=t&&t.removeButtonFunction?t.removeButtonFunction:this.removeSelected,n=t&&t.removeButtonLabel?t.removeButtonLabel:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.STRUCTURETABLE_REMOVEBUTTON_LABEL),o=!this.state.enableRemoveIcon||e===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,i=!1;this.addOnClickCallback=t&&t.addButtonFunction?t.addButtonFunction:this.props.openFieldPicker;var a=t&&t.addButtonLabel?t.addButtonLabel:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.STRUCTURETABLE_ADDBUTTON_LABEL);return e===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED&&(i=!0,this.addOnClickCallback=null),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-at-buttons-container"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{className:"properties-remove-fields-button",disabled:o,onClick:r,size:"small",kind:"ghost",renderIcon:_carbon_icons_react__WEBPACK_IMPORTED_MODULE_35__.TrashCan16},n),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{className:"properties-add-fields-button",disabled:i,onClick:this.addOnClick.bind(this,this.props.propertyId),size:"small",kind:"ghost",renderIcon:_carbon_icons_react__WEBPACK_IMPORTED_MODULE_21__.Add16},a))}},{key:"makeEditButtonPanel",value:function(e,t){var r=null;return t&&t.editCallback&&(this.editOnClickCallback=t.editCallback,r=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-at-buttons-container"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{className:"properties-edit-button",onClick:this.editOnClick.bind(this,this.props.propertyId),size:"small",kind:"ghost",renderIcon:_carbon_icons_react__WEBPACK_IMPORTED_MODULE_36__.Edit16},t.label))),r}},{key:"makeCustomButtonsPanel",value:function(e,t){var r=null;return t&&(r=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-at-buttons-container"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Is,{controller:this.props.controller,propertyId:this.props.propertyId,tableState:e,customButtons:t,customButtonsState:this.props.tableButtons}))),r}},{key:"editOnClick",value:function(e){this.editOnClickCallback&&this.editOnClickCallback(e)}},{key:"checkedAllValue",value:function(e,t){var r=this.props.value;if(Array.isArray(r)){for(var n=0;n<r.length;n++){var o={name:this.props.control.name,row:n,col:e};this.props.controller.getControlState(o)!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED&&this.props.controller.updatePropertyValue(o,t)}this.checkedAll[e]=t}}},{key:"checkedAll",value:function(e){var t=this.props.value;if(!Array.isArray(t))return!1;if(0===t.length)return!1;for(var r=0;r<t.length;r++){var n={name:this.props.control.name,row:r,col:e};if(this.props.controller.getControlState(n)!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED&&!t[r][e])return!1}return!0}},{key:"disabledAll",value:function(e){var t=this.props.value;if(!Array.isArray(t))return!1;if(0===t.length)return!1;var r,n=Rs(t);try{for(n.s();!(r=n.n()).done;){if(!1===r.value[e])return!1}}catch(e){n.e(e)}finally{n.f()}return!0}},{key:"createTable",value:function(e,t,r){var n=[],o=[],i=[];this.filterFields=i;var a=this.makeHeader(o,i),l=!1!==this.props.control.header,u=this.props.value;this.makeCells(n,u,e);var c,p=this.props.control.rowSelection===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.R.MULTIPLE?this.makeSelectedEditRow(this.props.selectedRows):null,d=null;r?d=this.makeCustomButtonsPanel(e,r):this.isReadonlyTable()?this.props.hideEditButton||(d=this.makeEditButtonPanel(e,t)):this.props.addRemoveRows&&(d=this.makeAddRemoveButtonPanel(e,t)),Number.isInteger(this.scrollToRow)&&n.length>this.scrollToRow&&(c=this.scrollToRow,delete this.scrollToRow);var f,h=this.props.control.label&&this.props.control.label.text?this.props.control.label.text:"";this.isReadonlyTable()&&this.props.control.rowSelection===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.R.SINGLE||(f=this.props.control.rowSelection===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.R.SINGLE?this.handleRowClick:this.updateRowSelections);var m=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_10__.F,{sortable:o,filterable:i,columns:a,data:n,showHeader:l,scrollToRow:c,onFilter:this.onFilter,onSort:this.onSort,topRightPanel:d,selectedEditRow:p,scrollKey:this.props.control.name,tableState:e,messageInfo:this.props.controller.getErrorMessage(this.props.propertyId),rows:this.props.control.rows,tableLabel:h,updateRowSelections:f,selectedRows:this.props.selectedRows,rowSelection:this.props.control.rowSelection,light:this.props.controller.getLight()});return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,m)}},{key:"makeHeader",value:function(e,t){for(var r=[],n=0;n<this.props.control.subControls.length;n++){var o=this.props.control.subControls[n],i=this.props.control.name+n,a=this.props.controller.getControlState({name:this.props.control.name,col:n}),l=a===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED||a===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN,u=o.controlType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.CHECKBOX?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_37__["default"],{disabled:l,id:i,checked:this.checkedAll(n),onChange:this.checkedAllValue.bind(this,n),labelText:o.label.text}):o.label.text;o.visible&&o.controlType!==_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.HIDDEN&&(o.sortable&&e.push(o.name),r.push({key:o.name,label:u,width:o.width,description:o.description?o.description.text:null,resizable:!!o.resizable&&o.resizable,operation:o.generatedValues&&o.generatedValues.operation?o.generatedValues.operation:null}),o.filterable&&t.push(o.name))}return this.props.control.childItem&&!this.isReadonlyTable()&&r.push({key:"subpanel",label:"",width:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.o,staticWidth:!0}),r}},{key:"makeCells",value:function(e,t,r,n,o){if(Array.isArray(t))for(var i=n||this.props.control.name,a=0;a<t.length;a++){var s=[];if(this.onPanelContainer[a]=[],this.includeInFilter(a)||o){for(var l=0;l<this.props.control.subControls.length;l++){var u=this.props.control.subControls[l];if(u.visible||u.editStyle===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.E.ON_PANEL){var c=this._makeCell(u,t,i,a,l,r,o);u.visible&&s.push(c)}}if(this.props.control.childItem&&!o&&!this.isReadonlyTable()){var p=this.buildChildItem(i,a,r);s.push(p)}e.push({columns:s})}}}},{key:"buildChildItem",value:function(e,t,r){var n={name:e,row:t},o=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(this.props.propertyId),i=n;o.name!==n.name&&(i=this.props.controller.setChildPropertyId(o,n));var a=this.props.buildUIItem(t,this.props.control.childItem,i,this.indexOfColumn),l=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-table-subcell"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Cs,{label:a.props.label,title:a.props.title,panel:a.props.panel,disabled:r===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,controller:this.props.controller,propertyId:this.props.propertyId,rightFlyout:this.props.rightFlyout}));return{column:"subpanel",width:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.o,content:l}}}],[{key:"getDerivedStateFromProps",value:function(e,t){var r=0!==e.selectedRows.length;return t.enableRemoveIcon!==r?{enableRemoveIcon:r}:{}}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function ks(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}ws.defaultProps={addRemoveRows:!0,hideEditButton:!1};var Ls=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=ks(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).getEmptyTableText=r.getEmptyTableText.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.isReadonlyTable=r.isReadonlyTable.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"getEmptyTableText",value:function(){var e="".concat(this.props.control.name,".empty.table.text"),t=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.PROPERTIES_EMPTY_TABLE_TEXT,{button_label:this.props.emptyTableButtonLabel});return this.props.controller.getResource(e,t)}},{key:"isReadonlyTable",value:function(){return this.props.control.controlType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.READONLYTABLE}},{key:"render",value:function(){var e=this.getEmptyTableText();return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-empty-table",disabled:this.props.disabled},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",null,e),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("br",null),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{className:"properties-empty-table-button",kind:"tertiary",size:"small",renderIcon:this.isReadonlyTable()?_carbon_icons_react__WEBPACK_IMPORTED_MODULE_36__.Edit16:_carbon_icons_react__WEBPACK_IMPORTED_MODULE_21__.Add16,onClick:this.props.emptyTableButtonClickHandler,disabled:this.props.disabled},this.props.emptyTableButtonLabel))}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),As=Ls;function Os(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Ds=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=Os(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).getTableRowMoveImages=r.getTableRowMoveImages.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.topMoveRow=r.topMoveRow.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.upMoveRow=r.upMoveRow.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.downMoveRow=r.downMoveRow.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.bottomMoveRow=r.bottomMoveRow.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.getMoveableTableRows=r.getMoveableTableRows.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.getLeastValue=r.getLeastValue.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.getMaxValue=r.getMaxValue.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"getMoveableTableRows",value:function(){var e=null;if(void 0!==this.props.control.moveableRows&&this.props.control.moveableRows){var t=this.getTableRowMoveImages();e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-mr-button-container"},t)}var r=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("table",{role:"presentation",className:"properties-mr-table-container"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("tbody",null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("tr",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-mr-table-content",{disabled:this.props.disabled})},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("td",null,this.props.tableContainer),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("td",null,e))));return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,r)}},{key:"getTableRowMoveImages",value:function(){var e=this.props.controller.getSelectedRows(this.props.propertyId).sort(),t=this.props.controller.getPropertyValue(this.props.propertyId),r=!this.props.disableRowMoveButtons&&0!==e.length&&0!==e[0]&&!this.props.disabled,n=!this.props.disableRowMoveButtons&&0!==e.length&&e[e.length-1]!==t.length-1&&!this.props.disabled,o=this.props.controller.getStaticRows(this.props.propertyId).sort();e.length>0&&o.length>0&&o.includes(e[0])?(r=!1,n=!1):e[0]===o[o.length-1]+1?(r=!1,n=!this.props.disableRowMoveButtons&&0!==e.length&&e[e.length-1]!==t.length-1&&!this.props.disabled):e[0]===o[0]-1&&(n=!1);var i=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.MOVEABLE_TABLE_BUTTON_TOP_DESCRIPTION),a=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.MOVEABLE_TABLE_BUTTON_UP_DESCRIPTION),l=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:"topImages"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{className:"table-row-move-button",onClick:this.topMoveRow,disabled:!r,kind:"ghost",renderIcon:_carbon_icons_react__WEBPACK_IMPORTED_MODULE_35__.UpToTop24,iconDescription:i,tooltipPosition:"left",hasIconOnly:!0}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{className:"table-row-move-button",onClick:this.upMoveRow,disabled:!r,kind:"ghost",renderIcon:_carbon_icons_react__WEBPACK_IMPORTED_MODULE_38__.ArrowUp24,iconDescription:a,tooltipPosition:"left",hasIconOnly:!0})),u=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.MOVEABLE_TABLE_BUTTON_DOWN_DESCRIPTION),c=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.MOVEABLE_TABLE_BUTTON_BOTTOM_DESCRIPTION);return[l,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:"bottomImages"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{className:"table-row-move-button",onClick:this.downMoveRow,disabled:!n,kind:"ghost",renderIcon:_carbon_icons_react__WEBPACK_IMPORTED_MODULE_38__.ArrowDown24,iconDescription:u,tooltipPosition:"left",hasIconOnly:!0}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{className:"table-row-move-button",onClick:this.bottomMoveRow,disabled:!n,kind:"ghost",renderIcon:_carbon_icons_react__WEBPACK_IMPORTED_MODULE_39__.DownToBottom24,iconDescription:c,tooltipPosition:"left",hasIconOnly:!0}))]}},{key:"getLeastValue",value:function(){var e=0,t=this.props.controller.getStaticRows(this.props.propertyId).sort();return t&&t.length>0&&t.includes(0)&&(e=t[t.length-1]),e}},{key:"getMaxValue",value:function(){var e=this.props.controller.getPropertyValue(this.props.propertyId),t=e.length-1,r=this.props.controller.getStaticRows(this.props.propertyId).sort();return r&&r.length>0&&r.includes(e.length-1)&&(t=r[0]-1),t}},{key:"topMoveRow",value:function(e){for(var t=this.props.controller.getSelectedRows(this.props.propertyId).sort((function(e,t){return e-t})),r=this.props.controller.getPropertyValue(this.props.propertyId),n=this.getLeastValue(),o=this.props.controller.getStaticRows(this.props.propertyId).sort(),i=t[0];i>n;i--)for(var a=0;a<=t.length-1;a++)if(o.length>0&&t[0]>n+1||0===o.length){var s=t.shift(),l=r[s-1];r[s-1]=r[s],r[s]=l,t.push(s-1),this.props.controller.moveErrorMessageRows(this.props.propertyId.name,s,s-1)}t.length>0&&this.props.setScrollToRow(t[0]),this.props.setCurrentControlValueSelected(r,t)}},{key:"upMoveRow",value:function(e){var t=this.props.controller.getSelectedRows(this.props.propertyId).sort((function(e,t){return e-t})),r=this.getLeastValue(),n=this.props.controller.getStaticRows(this.props.propertyId).sort();if(0!==t.length&&t[0]>r){for(var o=this.props.controller.getPropertyValue(this.props.propertyId),i=0;i<=t.length-1;i++)if(n.length>0&&t[0]>r+1){var a=t.shift(),s=o[a-1];o[a-1]=o[a],o[a]=s,t.push(a-1),this.props.controller.moveErrorMessageRows(this.props.propertyId.name,a,a-1)}else if(0===n.length){var l=t.shift();if(0!==l){var u=o[l-1];o[l-1]=o[l],o[l]=u,t.push(l-1),this.props.controller.moveErrorMessageRows(this.props.propertyId.name,l,l-1)}}this.props.setScrollToRow(t[0]),this.props.setCurrentControlValueSelected(o,t)}}},{key:"downMoveRow",value:function(e){var t=this.props.controller.getSelectedRows(this.props.propertyId).sort((function(e,t){return e-t})),r=this.props.controller.getPropertyValue(this.props.propertyId),n=this.getMaxValue();if(0!==t.length&&t[t.length-1]!==r.length-1){for(var o=t.length-1;o>=0;o--){var i=t.pop();if(i!==n){var a=r[i+1];r[i+1]=r[i],r[i]=a,t.unshift(i+1),this.props.controller.moveErrorMessageRows(this.props.propertyId.name,i,i+1)}}t.length>1?this.props.setScrollToRow(t[t.length-1]):this.props.setScrollToRow(t[0]),this.props.setCurrentControlValueSelected(r,t)}}},{key:"bottomMoveRow",value:function(e){for(var t=this.props.controller.getSelectedRows(this.props.propertyId).sort((function(e,t){return e-t})),r=this.props.controller.getPropertyValue(this.props.propertyId),n=this.getMaxValue(),o=t[t.length-1];o<n;o++)for(var i=t.length-1;i>=0;i--){var a=t.pop(),s=r[a+1];r[a+1]=r[a],r[a]=s,t.unshift(a+1),this.props.controller.moveErrorMessageRows(this.props.propertyId.name,a,a+1)}t.length>0&&this.props.setScrollToRow(t[t.length-1]),this.props.setCurrentControlValueSelected(r,t)}},{key:"render",value:function(){return this.props.isEmptyTable&&this.props.addRemoveRows?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(As,{control:this.props.control,controller:this.props.controller,emptyTableButtonLabel:this.props.emptyTableButtonLabel,emptyTableButtonClickHandler:this.props.emptyTableButtonClickHandler,disabled:this.props.disabled}):this.getMoveableTableRows()}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));Ds.defaultProps={addRemoveRows:!0};var Ps=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{disableRowMoveButtons:t.controller.isDisableRowMoveButtons(t.propertyId),addRemoveRows:t.controller.getAddRemoveRows(t.propertyId),tableButtons:t.controller.getTableButtons(t.propertyId)}}))(Ds);function Ns(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var xs=[_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.INTEGER,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.DOUBLE,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.LONG],Bs=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,ws);var o=Ns(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).addRow=r.addRow.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.reactIntl=t.controller.getReactIntl(),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"addRow",value:function(){var e=this.props.controller.getControlPropType(this.props.propertyId),t=xs.indexOf(e)>-1?null:"",r=this.props.controller.getPropertyValue(this.props.propertyId);void 0===r&&(r=[]);var n=r.concat([t]);this.setCurrentControlValueSelected(n)}},{key:"makeCell",value:function(e,t,r,n){return xs.indexOf(r)>-1?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-table-cell-control"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(ps,{control:e,propertyId:t,controller:this.props.controller,controlItem:n,tableControl:!0})):react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-table-cell-control"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(rs,{control:e,propertyId:t,controller:this.props.controller,controlItem:n,tableControl:!0}))}},{key:"makeRows",value:function(e,t,r){var n=[];if(e)for(var o=0;o<e.length;o++){var i=[],a={name:this.props.control.name,row:o};if(this.props.propertyId.name!==a.name){var s=Object.assign({},this.props.propertyId);a=this.props.controller.setChildPropertyId(s,{name:this.props.control.name,row:o})}var l=this.props.controller.getControlPropType(a),u=void 0===r||0===r.length?"":r[0].label,c=this.makeCell({},a,l,u);i.push({key:o+"-0-value",column:"value",content:c}),n.push({key:o,onClickCallback:this.handleRowClick.bind(this,o,!1),columns:i,className:"list-table-row"})}return n}},{key:"makeHeader",value:function(){var e=[];return e.push({key:"value",label:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.LIST_TABLE_LABEL),description:null}),e}},{key:"render",value:function(){var e,t=this.makeHeader(),r={addButtonLabel:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.STRUCTURELISTEDITOR_ADDBUTTON_LABEL),removeButtonLabel:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.STRUCTURELISTEDITOR_REMOVEBUTTON_LABEL),addButtonFunction:this.addRow},n=this.makeRows(this.props.value,this.props.state,t),o=this.makeAddRemoveButtonPanel(this.props.state,r);Number.isInteger(this.scrollToRow)&&n.length>this.scrollToRow&&(e=this.scrollToRow,delete this.scrollToRow);var i=this.props.control.label&&this.props.control.label.text?this.props.control.label.text:"",a=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_10__.F,{columns:t,data:n,scrollToRow:e,topRightPanel:o,scrollKey:this.props.control.name,tableState:this.props.state,messageInfo:this.props.messageInfo,rows:this.props.control.rows,tableLabel:i,selectedRows:this.props.selectedRows,rowSelection:this.props.control.rowSelection,updateRowSelections:this.updateRowSelections,light:this.props.controller.getLight()}),l=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-list-table"},a),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{state:this.props.state,messageInfo:this.props.messageInfo}));return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":an(this.props.propertyId),className:"properties-list-control"},this.props.controlItem,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ps,{tableContainer:l,control:this.props.control,controller:this.props.controller,propertyId:this.props.propertyId,setScrollToRow:this.setScrollToRow,setCurrentControlValueSelected:this.setCurrentControlValueSelected,disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,isEmptyTable:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(this.props.value),emptyTableButtonLabel:r.addButtonLabel,emptyTableButtonClickHandler:this.addRow}))}}]),a}();Bs.propTypes={control:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object.isRequired),propertyId:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object.isRequired),controller:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object.isRequired),controlItem:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().element),selectedRows:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().array),state:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().string),value:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().array),messageInfo:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object),addRemoveRows:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().bool),tableButtons:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object)};var Ms=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId),selectedRows:t.controller.getSelectedRows(t.propertyId),addRemoveRows:t.controller.getAddRemoveRows(t.propertyId),tableButtons:t.controller.getTableButtons(t.propertyId)}}))(Bs);function Fs(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Vs=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=Fs(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).reactIntl=t.controller.getReactIntl(),r.recentUseCat=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(r.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_RECENTLY_USED),r.recentUseCatInfo={id:r.recentUseCat,locLabel:r.recentUseCat,field_columns:{field_column_info:{locLabel:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(r.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_RECENTLY_USED_COLUMN)},value_column_info:{locLabel:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(r.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_VALUE_COLUMN)}}},r.inCategories=Object.keys(t.functionList),r.fields=r._makeDatasetFields(t.controller.getDatasetMetadataFields(),t.controller.getExpressionInfo().fields),r.state={fieldSelected:0,valueSelected:0,functionSelected:0,fieldTableSortSpec:null,valuesTableSortSpec:null,functionTableSortSpec:null,functionCategory:r.inCategories[0],selectedIndex:0,fieldCategory:"fields",currentFieldDataset:r.fields.field_table_info[0].field_value_groups},r.controller=t.controller,r.onFunctionCatChange=r.onFunctionCatChange.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.onFieldCatChange=r.onFieldCatChange.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.onFieldFilter=r.onFieldFilter.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.onValueFilter=r.onValueFilter.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.onFunctionFilter=r.onFunctionFilter.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.language=t.language,r.onFieldTableClick=r.onFieldTableClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.onFieldTableDblClick=r.onFieldTableDblClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.onFunctionTableClick=r.onFunctionTableClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.onFunctionTableDblClick=r.onFunctionTableDblClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.onValueTableClick=r.onValueTableClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.onValueTableDblClick=r.onValueTableDblClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.sortTableRows=r.sortTableRows.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"onSwitch",value:function(e,t){this.setState({selectedIndex:e.index})}},{key:"onFunctionCatChange",value:function(e){this.setState({functionCategory:e.selectedItem.value,functionSelected:0})}},{key:"onFieldCatChange",value:function(e){var t=[];if(e.selectedItem.value===this.recentUseCat)t=this.props.controller.getExpressionFieldsRecentlyUsed();else for(var r=0;r<this.fields.field_table_info.length;r++)e.selectedItem.value===this.fields.field_table_info[r].id&&(t=this.fields.field_table_info[r].field_value_groups);this.setState({fieldCategory:e.selectedItem.value,fieldSelected:0,currentFieldDataset:t})}},{key:"onFieldTableClick",value:function(e,t,r){this.setState({fieldSelected:r,valueSelected:0})}},{key:"onFieldTableDblClick",value:function(e,t,r){var n=this.state.currentFieldDataset[t],o=n.id;if(this.state.fieldCategory!==this.recentUseCat&&this.props.controller.updateExpressionFieldsRecentlyUsed(n),this.props.onChange){var i="CLEM"===this.language&&"globals"!==this.state.fieldCategory?"'":"";o=i+n.id+i,this.props.onChange(o)}}},{key:"onFieldFilter",value:function(e){this.setState({fieldFilterText:e})}},{key:"onValueTableClick",value:function(e,t,r){this.setState({valueSelected:r})}},{key:"onValueTableDblClick",value:function(e,t,r){if(this.props.onChange){var n=this.state.currentFieldDataset[this.state.fieldSelected],o='"';if(n.values){var i=n.values[t].value,a="string"==typeof i?o+i+o:i;this.props.onChange(a)}else if(n.range){var s="string"==typeof n.range.min.value?o+n.range.min.value+o:n.range.min.value,l="string"==typeof n.range.max.value?o+n.range.max.value+o:n.range.max.value;this.props.onChange(0===t?s:l)}}this.setState({valueSelected:t})}},{key:"onValueFilter",value:function(e){this.setState({valueFilterText:e})}},{key:"onFunctionTableClick",value:function(e,t,r){this.setState({functionSelected:r})}},{key:"onFunctionTableDblClick",value:function(e,t,r){var n;this.state.functionCategory===this.recentUseCat?n=this.props.controller.getExpressionRecentlyUsed()[t]:(n=this.props.functionList[this.state.functionCategory].functionList[t],this.props.controller.updateExpressionRecentlyUsed(n));var o=n.value;this.props.onChange&&this.props.onChange(o)}},{key:"onFunctionFilter",value:function(e){this.setState({functionFilterText:e})}},{key:"setSortColumn",value:function(e,t){switch(e){case"fieldTable":this.setState({fieldTableSortSpec:t});break;case"valuesTable":this.setState({valuesTableSortSpec:t});break;case"functionTable":this.setState({functionTableSortSpec:t})}}},{key:"sortTableRows",value:function(e,t){var r=0;if(e.length>0){for(var n=e[0].columns,o=0;o<n.length;o++)if(n[o].column===t.column){r=o;break}var i=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.b)(e,(function(e){return e.columns[r].value}));return t.direction===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.n.DESC&&i.reverse(),i}return e}},{key:"createContentObject",value:function(e){var t=!0;e&&(t=!1);var r=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{className:"properties-expr-table-cell"},e),n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.k,{content:r,tooltipText:e,disabled:t});return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-table-cell-control"},n)}},{key:"_makeDatasetFields",value:function(e,t){var r,n,o=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_FIELD_COLUMN),i=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_STORAGE_COLUMN),a=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_VALUE_COLUMN),s={id:"fields",locLabel:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_FIELDS_DROPDOWN_TITLE),field_columns:{field_column_info:{locLabel:o},value_column_info:{locLabel:a},additional_column_info:[{id:"storage",locLabel:i}]}},l={id:"fields",field_value_groups:[]};e.forEach((function(e){var t={id:e.name,additional_column_entries:[{id:"storage",value:e.type}]};e.metadata.values&&(t.values=[],e.metadata.values.forEach((function(e){t.values.push({value:e})}))),e.metadata.range&&(t.range={},e.metadata.range.min&&(t.range.min={value:e.metadata.range.min}),e.metadata.range.max&&(t.range.max={value:e.metadata.range.max})),l.field_value_groups.push(t)}));for(var u=0;u<t.field_categories.length;u++)"fields"===t.field_categories[u].id&&(r=u);for(var c=0;c<t.field_table_info.length;c++)"fields"===t.field_table_info[c].id&&(n=c);return void 0!==r?t.field_categories[r]=s:t.field_categories.unshift(s),void 0!==n?t.field_table_info[n]=l:t.field_table_info.unshift(l),t}},{key:"_makeFieldAndValuesContent",value:function(){var e=this,t=this._makeFieldDropdown(),r=[],n=[],o=["fieldName"],i=null,a=null;if(this.state.fieldCategory===this.recentUseCat)i=this.recentUseCatInfo,a={id:this.recentUseCat,field_value_groups:this.props.controller.getExpressionFieldsRecentlyUsed()};else{for(var l=0;l<this.fields.field_categories.length;l++)this.state.fieldCategory===this.fields.field_categories[l].id&&(i=this.fields.field_categories[l]);for(var u=0;u<this.fields.field_table_info.length;u++)this.state.fieldCategory===this.fields.field_table_info[u].id&&(a=this.fields.field_table_info[u])}if(i&&(r.push({key:"fieldName",label:i.field_columns.field_column_info.locLabel,resizable:!0}),n.push({key:"values",label:i.field_columns.value_column_info.locLabel}),i.field_columns.additional_column_info))for(var c=0;c<i.field_columns.additional_column_info.length;c++)o.push(i.field_columns.additional_column_info[c].id),r.push({key:i.field_columns.additional_column_info[c].id,label:i.field_columns.additional_column_info[c].locLabel});var d=[],f=[];if(a&&a.field_value_groups)for(var h=0;h<a.field_value_groups.length;h++){var m=a.field_value_groups[h],v=[];(!this.state.fieldFilterText||0===this.state.fieldFilterText.length||m.id.toLowerCase().indexOf(this.state.fieldFilterText.toLowerCase())>-1)&&(v.push({column:"fieldName",content:this.createContentObject(m.id),value:m.id}),m.additional_column_entries&&this._makeAdditionalColumnsContent(m,v),d.push({columns:v,rowKey:h}),h===this.state.fieldSelected&&(f=this._makeValuesContent(m,f)))}var y=this.state.fieldSelected;null!==this.state.fieldTableSortSpec&&(y=(d=this.sortTableRows(d,this.state.fieldTableSortSpec)).findIndex((function(t){return t.rowKey===e.state.fieldSelected})));var g=this.state.valueSelected;null!==this.state.valuesTableSortSpec&&(g=(f=this.sortTableRows(f,this.state.valuesTableSortSpec)).findIndex((function(t){return t.rowKey===e.state.valueSelected})));var b=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_FIELDS_TABLE_LABEL),E=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_VALUES_TABLE_LABEL);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-field-and-values-table-container"},t,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-field-table-container"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_10__.F,{columns:r,data:d,sortable:o,filterable:["fieldName"],onFilter:this.onFieldFilter,rows:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.E,tableLabel:b,rowSelection:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.R.SINGLE,updateRowSelections:this.onFieldTableClick,selectedRows:[y],onRowDoubleClick:this.onFieldTableDblClick,onSort:this.setSortColumn.bind(this,"fieldTable"),light:this.props.controller.getLight()})),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-value-table-container"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_10__.F,{columns:n,data:f,sortable:["values"],filterable:["values"],onFilter:this.onValueFilter,rows:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.E,tableLabel:E,rowSelection:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.R.SINGLE,updateRowSelections:this.onValueTableClick,selectedRows:[g],onRowDoubleClick:this.onValueTableDblClick,onSort:this.setSortColumn.bind(this,"valuesTable"),light:this.props.controller.getLight()})))}},{key:"_makeValuesContent",value:function(e,t){var r=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_MIN_LABEL),n=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_MAX_LABEL);if(e.values)for(var o=0;o<e.values.length;o++)this._addValueRow(e.values[o].value,o,t);else e.range&&(e.range.min&&this._addValueRow(r+": "+e.range.min.value,0,t),e.range.max&&this._addValueRow(n+": "+e.range.max.value,1,t));return t}},{key:"_addValueRow",value:function(e,t,r){if(!this.state.valueFilterText||0===this.state.valueFilterText.length||String(e).toLowerCase().indexOf(this.state.valueFilterText.toLowerCase())>-1){var n=[{column:"values",content:this.createContentObject(e),value:e}];r.push({columns:n,rowKey:t})}}},{key:"_makeFunctionsContent",value:function(){if(this.props.functionList){var e=Object.keys(this.props.functionList),t=this._makeFunctionDropdown(e),r=this._makeFunctionsTable(e);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-expression-function-table-container"},t,r)}return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",null,"formatMessage(this.reactIntl, MESSAGE_KEYS.EXPRESSION_NO_FUNCTIONS);")}},{key:"_makeAdditionalColumnsContent",value:function(e,t){for(var r=0;r<e.additional_column_entries.length;r++)t.push({column:e.additional_column_entries[r].id,content:this.createContentObject(e.additional_column_entries[r].value),value:e.additional_column_entries[r].value})}},{key:"_makeFunctionDropdown",value:function(e){var t=this,r=e.map((function(e,r){return{value:e,label:t.props.functionList[e].locLabel}})),n=r.slice(0,1),o=r.slice(1);r=n.concat({value:this.recentUseCat,label:this.recentUseCat},o);var i=this.state.functionCategory===this.recentUseCat?this.recentUseCat:this.props.functionList[this.state.functionCategory].locLabel,a=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.TABLE_SEARCH_HEADER),l={"close.menu":(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.DROPDOWN_TOOLTIP_CLOSEMENU),"open.menu":(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.DROPDOWN_TOOLTIP_OPENMENU)};return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-expression-function-select"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_41__["default"],{id:"properties-expression-function-select-dropdown-"+(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)(),light:this.props.controller.getLight(),label:i,items:r,onChange:this.onFunctionCatChange,translateWithId:function(e){return l[e]},titleText:a}))}},{key:"_makeFieldDropdown",value:function(){for(var e=[],t=0;t<this.fields.field_categories.length;t++)e.push({value:this.fields.field_categories[t].id,label:this.fields.field_categories[t].locLabel});var r=e.slice(0,1),n=e.slice(1),o=r.concat({value:this.recentUseCat,label:this.recentUseCat},n),i=this.state.fieldCategory===this.recentUseCat?this.recentUseCat:e[0].label,a=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.TABLE_SEARCH_HEADER),l={"close.menu":(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.DROPDOWN_TOOLTIP_CLOSEMENU),"open.menu":(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.DROPDOWN_TOOLTIP_OPENMENU)};return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-expression-field-select"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_41__["default"],{id:"properties-expression-field-select-dropdown-"+(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)(),light:this.props.controller.getLight(),label:i,items:o,onChange:this.onFieldCatChange,translateWithId:function(e){return l[e]},titleText:a}))}},{key:"_makeFunctionsTable",value:function(e){var t=this,r=[],n=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_FUNCTION_COLUMN),o=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_RETURN_COLUMN);r.push({key:"function",label:n,width:73,resizable:!0}),r.push({key:"return",label:o,width:27});var i=this._buildFunctionTable(this.state.functionCategory),a=i.rows,l=this.state.functionSelected;null!==this.state.functionTableSortSpec&&(l=(a=this.sortTableRows(a,this.state.functionTableSortSpec)).findIndex((function(e){return e.rowKey===t.state.functionSelected})));var u=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_FUNCTIONS_TABLE_LABEL);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-functions-table-container"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-functions-table"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_10__.F,{columns:r,data:a,sortable:["function","return"],filterable:["function"],onFilter:this.onFunctionFilter,rows:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.E,tableLabel:u,rowSelection:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.R.SINGLE,updateRowSelections:this.onFunctionTableClick,selectedRows:[l],onRowDoubleClick:this.onFunctionTableDblClick,onSort:this.setSortColumn.bind(this,"functionTable"),light:this.props.controller.getLight()})),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-help-table-container"},i.helpContainer))}},{key:"_buildFunctionTable",value:function(e){var t={rows:[],helpContainer:react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null)},r=e===this.recentUseCat?this.props.controller.getExpressionRecentlyUsed():this.props.functionList[e].functionList;if(r)for(var n=0;n<r.length;n++){var o=r[n],i=[];(!this.state.functionFilterText||0===this.state.functionFilterText.length||o.locLabel.toLowerCase().indexOf(this.state.functionFilterText.toLowerCase())>-1)&&(i.push({column:"function",content:this.createContentObject(o.locLabel),value:o.locLabel}),i.push({column:"return",content:this.createContentObject(o.return_type),value:o.return_type}),t.rows.push({columns:i,rowKey:n}),n===this.state.functionSelected&&(t.helpContainer=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-function-help-text"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{className:"properties-function-help-command"},o.locLabel,":"),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("br",null),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("br",null),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",null,o.help))))}return t}},{key:"render",value:function(){var e=this._makeFieldAndValuesContent(),t=this._makeFunctionsContent(),r=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_FIELD_TAB),n=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_FUNCTIONS_TAB),o=null;return 0===this.state.selectedIndex?o=e:1===this.state.selectedIndex&&(o=t),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-expression-selection-fieldOrFunction"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-expression-selection-content-switcher"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_42__["default"],{onChange:this.onSwitch.bind(this),selectedIndex:this.state.selectedIndex},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_43__["default"],{key:0,name:"expresson-builder-fields-tab",className:"expresson-builder-fields-tab",text:r}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_43__["default"],{key:1,name:"expresson-builder-function-tab",className:"expresson-builder-function-tab",text:n}))),o)}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function Us(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var js=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,n);var o=Us(i);function i(){return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),o.apply(this,arguments)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"onOperatorClick",value:function(e,t){this.props.onChange&&this.props.onChange(e)}},{key:"_makeOperatorContent",value:function(){var e=this;if(this.props.operatorList){var t=[];return this.props.operatorList.forEach((function(r,n){var o=(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)()+"-tooltip-expression-operator",i=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-tooltips"},r.help);t.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-operator-tooltip-container",key:"expression-operator-"+n},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_18__["default"],{id:o,tip:i,direction:"bottom",className:"properties-tooltips"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-operator-button",{first:n%2==0,second:!(n%2==0)}),size:"small",kind:"tertiary",onClick:e.onOperatorClick.bind(e,r.value)},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-operator-button-label"},r.locLabel)))))})),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-operator-container"},t)}return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null)}},{key:"render",value:function(){var e=this._makeOperatorContent();return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-expression-selection-operator"},e)}}]),i}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function Hs(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var qs=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,n);var o=Hs(i);function i(){return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),o.apply(this,arguments)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"render",value:function(){var e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Vs,{controller:this.props.controller,onChange:this.props.onChange,functionList:this.props.functionList,language:this.props.language}),t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(js,{controller:this.props.controller,onChange:this.props.onChange,operatorList:this.props.operatorList});return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-expression-selection-container"},t,e)}}]),i}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function zs(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Gs,Ws=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=zs(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).selection=[],r.expressionInfo=t.controller.getExpressionInfo(),r.editorDidMount=r.editorDidMount.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.onChange=r.onChange.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.onBlur=r.onBlur.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.onSelectionChange=r.onSelectionChange.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.lastCursorPos=null,r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"onChange",value:function(e){var t="string"==typeof e?e:e.toString(),r=this.editor.getCursor(),n=1;if(this.editor.somethingSelected())n=0,this.editor.replaceSelection(t);else{var o=" ";this.lastCursorPos&&(this.editor.setCursor(this.lastCursorPos),r=this.lastCursorPos);var i=this.editor.getLine(r.line)[r.ch-1];-1!==["(","[","{"].indexOf(i)&&(o=""),this.editor.replaceSelection(o+t)}this._setSelection(t,r,n);var a=this.editor.getValue();this.props.controller.updatePropertyValue(this.props.propertyId,a,!0),this.lastCursorPos=this.editor.getCursor()}},{key:"onSelectionChange",value:function(e){this.selection=e}},{key:"onBlur",value:function(e,t){this.lastCursorPos=e.getCursor();var r=this.editor.getValue(),n=!1;this.expressionSelectionPanel&&this.expressionSelectionPanel.contains(t.relatedTarget)&&(n=!0),this.props.controller.updatePropertyValue(this.props.propertyId,r,n)}},{key:"editorDidMount",value:function(e,t){this.editor=e}},{key:"_setSelection",value:function(e,t,r){if("string"==typeof e){var n=e.indexOf("?");if(-1!==n){var o={anchor:{line:t.line,ch:t.ch+n+r+1},head:{line:t.line,ch:t.ch+n+r}};return void this.onSelectionChange([o])}}for(var i=this.editor.lineCount(),a=0;a<i;a++){var s=this.editor.getLine(a).indexOf("?");if(-1!==s){var l={anchor:{line:a,ch:s+1},head:{line:a,ch:s}};return void this.onSelectionChange([l])}}var u={anchor:{line:t.line,ch:t.ch+e.length+r},head:{line:t.line,ch:t.ch+e.length+r}};this.onSelectionChange([u])}},{key:"render",value:function(){var e=this,t=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_BUILDER_LABEL);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-expression-builder"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(hl,{control:this.props.control,propertyId:this.props.propertyId,controller:this.props.controller,builder:!1,editorDidMount:this.editorDidMount,selectionRange:this.selection,onSelectionChange:this.onSelectionChange,onBlur:this.onBlur,height:96,expressionLabel:t}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{ref:function(t){return e.expressionSelectionPanel=t}},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(qs,{controller:this.props.controller,onChange:this.onChange,functionList:this.expressionInfo.functionCategories,operatorList:this.expressionInfo.operators,language:this.props.control.language})))}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function $s(e,t){for(var r=e.length,n=0;n<r;++n)t(e[n])}function Xs(e,t,r){var n,o=e.getCursor(),i=r(e,o),a=i;/^[\w$_]*$/.test(i.string)||(i=a={start:o.ch,end:o.ch,string:"",state:i.state,className:":"===i.string?"python-type":null}),n||(n=[]),n.push(a);var s=function(e,t){var r=[],n=e.string;function o(e){0!==e.lastIndexOf(n,0)||function(e,t){if(!Array.prototype.indexOf){for(var r=e.length;r--;)if(e[r]===t)return!0;return!1}return-1!==e.indexOf(t)}(r,e)||r.push(e)}function i(e){$s(Zs,o),$s(Js,o)}if(t){var a=t.pop(),s="";for("variable"===a.type?s=a.string:"variable-3"===a.type&&(s=":"+a.string);null!==s&&t.length;)s=s[t.pop().string];null!==s&&i()}return r}(i,n);return s.sort(),{list:s,from:Gs.Pos(o.line,i.start),to:Gs.Pos(o.line,i.end)}}function Ys(e){return Xs(e,0,(function(e,t){return e.getTokenAt(t)}))}var Ks,Js="and del from not while as elif global or with assert else if pass yieldbreak except import print class exec in raise continue finally is return def for lambda try".split(" "),Zs="abs divmod input open staticmethod all enumerate int ord str any eval isinstance pow sum basestring execfile issubclass print superbin file iter property tuple bool filter len range typebytearray float list raw_input unichr callable format locals reduce unicodechr frozenset long reload vars classmethod getattr map repr xrangecmp globals max reversed zip compile hasattr memoryview round __import__complex hash min set apply delattr help next setattr bufferdict hex object slice coerce dir id oct sorted intern ".split(" ").join("() ").split(" ");function Qs(e,t){for(var r=e.length,n=0;n<r;++n)t(e[n])}function el(e,t,r){var n,o=e.getCursor(),i=r(e,o),a=i;/^[\w$_]*$/.test(i.string)||(i=a={start:o.ch,end:o.ch,string:"",state:i.state,className:":"===i.string?"r-type":null}),n||(n=[]),n.push(a);var s=function(e,t){var r=[],n=e.string;function o(e){0!==e.lastIndexOf(n,0)||function(e,t){if(!Array.prototype.indexOf){for(var r=e.length;r--;)if(e[r]===t)return!0;return!1}return-1!==e.indexOf(t)}(r,e)||r.push(e)}function i(e){Qs(ol,o),Qs(nl,o)}if(t){var a=t.pop(),s="";for("variable"===a.type?s=a.string:"variable-3"===a.type&&(s=":"+a.string);null!==s&&t.length;)s=s[t.pop().string];null!==s&&i()}return r}(i,n);return s.sort(),{list:s,from:Ks.Pos(o.line,i.start),to:Ks.Pos(o.line,i.end)}}function tl(e){return el(e,0,(function(e,t){return e.getTokenAt(t)}))}var rl,nl="function|if|in|break|next|repeat|else|for|return|switch|while|try|tryCatch|stop|warning|require|library|attach|detach|source|setMethod|setGeneric|setGroupGeneric|setClass".split("|"),ol="zapsmall xzfile xtfrm xor writeLines writeChar writeBin write withVisible withRestarts withinwithCallingHandlers withAutoprint with while which weekdays warnings warning version Vectorize vector vapplyvalidUTF8 validEnc utf8ToInt UseMethod url unz untracemem untrace unsplit unserialize unname unlockBinding unloadNamespaceunlist unlink unique union undebug unclass typeof tryCatch try truncate trunc trimws trigammatransform tracingState tracemem traceback trace toupper toString topenv tolower textConnectionValue textConnectiontestPlatformEquivalence tempfile tempdir tcrossprod taskCallbackManager tapply tanpi tanh tan tabulate table T t system2 systemswitch sweep svd suspendInterrupts suppressWarnings suppressPackageStartupMessages suppressMessages summary sumsubstring substr substitute subset sub strwrap structure strtrim strtoi strsplit strrep strptime strftimestopifnot stop stdout stdin stderr startsWith standardGeneric srcref srcfilecopy srcfilealias srcfile sQuote sqrt sprintf splitsource sort solve socketSelect socketConnection sinpi sink sinh single sin simplify2array simpleWarning simpleMessage simpleErrorsimpleCondition signif signalCondition sign shQuote showConnections setwd setTimeLimit setSessionTimeLimit setNamespaceInfo setHooksetequal setdiff serialize sequence seq_len seq_along seq seek searchpaths search scan scale saveRDS save sapply sample rowSumsrowsum rownames rowMeans row round RNGversion length lchoose lbeta lazyLoadDBfetch lazyLoadDBexecRNGkind rm rle rev returnValue return retracemem restartFormals restartDescription requireNamespace require replicate replace repeatrep_len rep removeTaskCallback remove regmatches registerS3methods registerS3method regexpr regexec Reduce RecallreadRenviron readRDS readLines readline readChar readBin Re rcond rbind rawToChar rawToBits rawShift rawConnectionValue rawConnectionraw rapply rank range R_system_version quote quit quarters qr q pushBackLength pushBack psigamma provideDimnames prod prmatrix printprettyNum pretty Position polyroot pmin pmax pmatch pipe pi pcre_config paste0 paste parseNamespaceFile parsepackBits packageStartupMessage packageHasNamespace packageEvent package_version outer ordered order options open OlsonNamesoldClass objects nzchar numeric_version numeric NROW nrow normalizePath norm noquote nlevels ngettext NextMethod next Negate NCOL ncolnchar nargs namespaceImportMethods namespaceImportFrom namespaceImportClasses namespaceImport namespaceExportmonths mode Mod missing min mget message merge memDecompress memCompress mean max matrix match mapply MapmakeActiveBinding ls logical logb log2 log1p log10 log lockEnvironment lockBinding local loadNamespace loadingNamespaceInfo loadedNamespacesload list2env list license licence library libcurlVersion lgamma lfactorial levels LETTERS letters lengthslazyLoad lapply labels La_version La_library l10n_info kronecker kappa julian jitter isTRUE isSymmetric isSeekable isS4 isRestart isOpenISOdatetime ISOdate isNamespaceLoaded isNamespace isIncomplete isFALSE isdebugged isBaseNamespace isattyinvokeRestartInteractively invokeRestart invisible intToUtf8 intToBits intersect  acosh acos abs abbreviateinteractive interaction integer inherits importIntoEnv Im ifelse if identity identical icuSetCollate icuGetCollate iconvlist iconv Igzfile gzcon gsub grouping grepRaw grepl grep gregexpr globalenv gl getwd gettextf gettext getTaskCallbackNames getSrcLines getRversiongetOption getNativeSymbolInfo getNamespaceVersion getNamespaceUsers getNamespaceName getNamespaceInfo getNamespaceImports getNamespaceExportsgetNamespace getLoadedDLLs getHook getExportedValue geterrmessage getElement getDLLRegisteredRoutines getConnection getCallingDLLegetCallingDLL getAllConnections get0 get gctorture2 gctorture gcinfo gc gamma function forwardsolve formatDL formatC formatformals forceAndCall force for flush floor findRestart findPackageEnv findInterval Find Filter file fifo factorial factor F extSoftVersionexpression expm1 exp exists evalq eval environmentName environmentIsLocked environment enquote endsWith EncodingencodeString enc2utf8 enc2native emptyenv eigen eapply dynGet duplicated dump droplevels drop dQuote dput double dontCheck dirname dirdigamma difftime diff dget determinant detach det deparse delayedAssign asNamespace asinh asindebugonce debuggingState debug date cut curlGetHeaders cumsum cumprod cummin cummax Cstack_info crossprod cospi cosh cos contributors Conjconflicts conditionMessage conditionCall computeRestarts complex comment commandArgs colSums colnames colMeans colcloseAllConnections close clearPushBack class choose chol2inv chol chkDots check_tzones chartr charToRaw charmatch character ceilingcbind cat casefold capabilities callCC call c bzfile by builtins browserText browserSetDebug browserCondition browser break bquote bodybitwXor bitwShiftR bitwShiftL bitwOr bitwNot bitwAnd bindtextdomain bindingIsLocked bindingIsActive beta besselY besselK besselJ besselIbasename baseenv backsolve autoloader autoload attributes attr attachNamespace attach atanh atan2 atan assign asS4 asS3arrayInd array args Arg apply append aperm anyNA anyDuplicated any allowInterrupts all alist agrepl agrep addTaskCallback addNA".split(" ");var il="@BLANK @DIFF1 @DIFF2 @FIELD @FIELDS_BETWEEN @FIELDS_MATCHING @GLOBAL_MAX @GLOBAL_MEAN @GLOBAL_MIN @GLOBAL_SDEV @GLOBAL_SUM @INDEX @LAST_NON_BLANK @MAX @MEAN @MIN @MULTI_RESPONSE_SET @NULL @OFFSET @PARTITION_FIELD @PREDICTED @SDEV @SINCE @SINCE0 @SUM @TARGET @TESTING_PARTITION @THIS @TODAY @TRAINING_PARTITION @VALIDATION_PARTITION abs allbutfirst allbutlast alphabefore and arccos arccosh arcsin arcsinh arctan arctan2 arctanh area cdf_chisq cdf_f cdf_normal cdf_t close_to COND1 and COND2 COND1 or COND2 cos cosh count_equal count_greater_than count_less_than count_non_nulls count_not_equal count_nulls count_substring crosses date_before date_days_difference date_from_ywd date_in_days date_in_months date_in_weeks date_in_years date_iso_day date_iso_week date_iso_year date_months_difference date_weeks_difference date_years_difference datetime_date datetime_day datetime_day_name datetime_day_short_name datetime_hour datetime_in_seconds datetime_minute datetime_month datetime_month_name datetime_month_short_name datetime_now datetime_second datetime_time datetime_timestamp datetime_weekday datetime_year distance div endstring exp first_index first_non_null first_non_null_index fracof hasendstring hasmidstring hasstartstring hassubstring hassubstring if then else elseif endif integer_bitcount integer_leastbit integer_length intof is_date is_datetime is_integer is_number is_real is_string is_time is_timestamp isalphacode isendstring islowercode ismidstring isnumbercode isstartstring issubstring issubstring issubstring_count issubstring_lim isuppercode last last_index last_non_null last_non_null_index length locchar locchar_back log log10 lowertoupper max max_index max_n MEAN mean_n member min min_index min_n negate not num_points oneof or overlap pi random random0 rem replace replicate round sdev_n sign sin sinh skipchar skipchar_back soundex soundex_difference sqrt startstring stb_centroid_latitude stb_centroid_longitude stripchar strmember subscrs substring substring_between sum_n tan tanh testbit time_before time_hours_difference time_in_hours time_in_mins time_in_secs time_mins_difference".split(" ");function al(e,t){return function(e,t,r,n){var o=e.getCursor(),i=r(e,o);if(/\b(?:string|comment)\b/.test(i.type))return null;i.state=rl.innerMode(e.getMode(),i.state).state,/^[\w$_@]*$/.test(i.string)?i.end>o.ch&&(i.end=o.ch,i.string=i.string.slice(0,o.ch-i.start)):i={start:o.ch,end:o.ch,string:"",state:i.state,type:"."===i.string?"property":null};return{list:sl(i,t),from:rl.Pos(o.line,i.start),to:rl.Pos(o.line,i.end)}}(e,il,(function(e,t){return e.getTokenAt(t)}))}function sl(e,t,r){for(var n=[],o=e.string,i=0;i<t.length;i++)0===t[i].lastIndexOf(o,0)&&-1===n.indexOf(t[i])&&n.push(t[i]);return n}function ll(){var e="@BLANK @DIFF1 @DIFF2 @FIELD @FIELDS_BETWEEN @FIELDS_MATCHING @GLOBAL_MAX @GLOBAL_MEAN @GLOBAL_MIN @GLOBAL_SDEV @GLOBAL_SUM @INDEX @LAST_NON_BLANK @MAX @MEAN @MIN @MULTI_RESPONSE_SET @NULL @OFFSET @PARTITION_FIELD @PREDICTED @SDEV @SINCE @SINCE0 @SUM @TARGET @TESTING_PARTITION @THIS @TODAY @TRAINING_PARTITION @VALIDATION_PARTITION abs allbutfirst allbutlast alphabefore and arccos arccosh arcsin arcsinh arctan arctan2 arctanh area cdf_chisq cdf_f cdf_normal cdf_t close_to COND1 and COND2 COND1 or COND2 cos cosh count_equal count_greater_than count_less_than count_non_nulls count_not_equal count_nulls count_substring crosses date_before date_days_difference date_from_ywd date_in_days date_in_months date_in_weeks date_in_years date_iso_day date_iso_week date_iso_year date_months_difference date_weeks_difference date_years_difference datetime_date datetime_day datetime_day_name datetime_day_short_name datetime_hour datetime_in_seconds datetime_minute datetime_month datetime_month_name datetime_month_short_name datetime_now datetime_second datetime_time datetime_timestamp datetime_weekday datetime_year distance div endstring exp first_index first_non_null first_non_null_index fracof hasendstring hasmidstring hasstartstring hassubstring hassubstring if then else elseif endif integer_bitcount integer_leastbit integer_length intof is_date is_datetime is_integer is_number is_real is_string is_time is_timestamp isalphacode isendstring islowercode ismidstring isnumbercode isstartstring issubstring issubstring issubstring_count issubstring_lim isuppercode last last_index last_non_null last_non_null_index length locchar locchar_back log log10 lowertoupper max max_index max_n MEAN mean_n member min min_index min_n negate not num_points oneof or overlap pi random random0 rem replace replicate round sdev_n sign sin sinh skipchar skipchar_back soundex soundex_difference sqrt startstring stb_centroid_latitude stb_centroid_longitude stripchar strmember subscrs substring substring_between sum_n tan tanh testbit time_before time_hours_difference time_in_hours time_in_mins time_in_secs time_mins_difference".split(" "),t=/[\[\]{}\(\),;\:\.]/,r=/\d/,n=/[\w\.]/,o=/[\w\$_]/,i=/[+\-*&%=<>!?|\/]/;function a(a,s){var l=a.next();if("#"===l&&s.startOfLine)return a.skipToEnd(),"meta";if('"'===l)return function(e,t,r){var n,o=!1;for(;void 0!==(n=t.next());)if(n===e){o=!0;break}o&&(r.tokenize=null)}(l,a,s),"string";if("'"===l)return function(e,t,r){var n,o=!1;for(;void 0!==(n=t.next());)if(n===e){o=!0;break}o&&(r.tokenize=null)}(l,a,s),"variable";if(t.test(l))return null;if(r.test(l))return a.eatWhile(n),"number";if(i.test(l))return a.eatWhile(i),"operator";a.eatWhile(o);var u=a.current();return-1!==e.indexOf(u)?"keyword":"variable"}return{startState:function(){return{tokenize:null}},token:function(e,t){return e.eatSpace()?null:(t.tokenize||a)(e,t)},electricChars:"{}"}}function ul(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return cl(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return cl(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function cl(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function pl(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var dl=null;"undefined"!=typeof window&&void 0!==window.navigator&&(dl=__webpack_require__(/*! codemirror */ "../../node_modules/@elyra/canvas/node_modules/codemirror/lib/codemirror.js"),__webpack_require__(/*! codemirror/addon/hint/show-hint */ "../../node_modules/@elyra/canvas/node_modules/codemirror/addon/hint/show-hint.js"),__webpack_require__(/*! codemirror/addon/display/placeholder */ "../../node_modules/@elyra/canvas/node_modules/codemirror/addon/display/placeholder.js"),__webpack_require__(/*! codemirror/addon/display/autorefresh */ "../../node_modules/@elyra/canvas/node_modules/codemirror/addon/display/autorefresh.js"),__webpack_require__(/*! codemirror/mode/javascript/javascript */ "../../node_modules/@elyra/canvas/node_modules/codemirror/mode/javascript/javascript.js"),__webpack_require__(/*! codemirror/addon/hint/javascript-hint */ "../../node_modules/@elyra/canvas/node_modules/codemirror/addon/hint/javascript-hint.js"),__webpack_require__(/*! codemirror/addon/hint/sql-hint */ "../../node_modules/@elyra/canvas/node_modules/codemirror/addon/hint/sql-hint.js"),__webpack_require__(/*! codemirror/mode/sql/sql */ "../../node_modules/@elyra/canvas/node_modules/codemirror/mode/sql/sql.js"),__webpack_require__(/*! codemirror/mode/python/python */ "../../node_modules/@elyra/canvas/node_modules/codemirror/mode/python/python.js"),__webpack_require__(/*! codemirror/mode/r/r */ "../../node_modules/@elyra/canvas/node_modules/codemirror/mode/r/r.js"),function(e){(Gs=e).registerHelper("hint","python",Ys)}(dl),function(e){(Ks=e).registerHelper("hint","r",tl)}(dl),function(e){(rl=e).registerHelper("hint","CLEM",al),rl.defineMode("CLEM",ll),rl.defineMIME("text/x-CLEM","CLEM")}(dl));var fl=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=pl(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).state={showExpressionBuilder:!1,validationInProgress:!1},r.origHint="",r.expressionInfo=r.props.controller.getExpressionInfo(),r.handleValidate=r.handleValidate.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.hasValidate=r.hasValidate.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.cancelExpressionBuilder=r.cancelExpressionBuilder.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.hideExpressionBuilder=r.hideExpressionBuilder.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.showExpressionBuilder=r.showExpressionBuilder.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.editorDidMount=r.editorDidMount.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.addonHints=r.addonHints.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.getDatasetFields=r.getDatasetFields.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.handleBlur=r.handleBlur.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.handleKeyDown=r.handleKeyDown.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.handleChange=function(e,t,n){if(Array.isArray(t.text)&&1===t.text.length&&1===t.text[0].length&&r.props.onSelectionChange){var o=t.removed[0].length>0?{line:t.from.line,ch:t.from.ch+1}:{line:t.to.line,ch:t.to.ch+1};r.props.onSelectionChange([{anchor:o,head:o}])}r.state.validateIcon&&(r.setState({validateIcon:null}),r.props.controller.updateErrorMessage(r.props.propertyId,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.j))},r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"componentDidUpdate",value:function(){var e=this;this.props.selectionRange&&this.props.selectionRange.length>0&&this.editor&&(this.props.selectionRange.forEach((function(t){e.editor.setSelection(t.anchor,t.head)})),this.editor.focus())}},{key:"componentWillUnmount",value:function(){this.origHint&&dl&&dl.registerHelper("hint",this.props.control.language,this.origHint)}},{key:"getDatasetFields",value:function(){var e,t=[],r=ul(this.props.controller.getDatasetMetadataFields());try{for(r.s();!(e=r.n()).done;){var n=e.value;t.push(n.name)}}catch(e){r.e(e)}finally{r.f()}return t}},{key:"addonHints",value:function(e,t){var r={},n=e.getCursor(),o=e.getTokenAt(n);if(this.origHint){r=this.origHint(e,t);for(var i=this.getDatasetFields(),a=0;a<i.length;++a){var s=i[a];(0===s.lastIndexOf(o.string,0)&&-1===r.list.indexOf(s)||" "===o.string&&null===o.type)&&r.list.unshift(s)}}return r}},{key:"editorDidMount",value:function(e,t){this.editor=e;var r=this.expressionEditorDiv?this.expressionEditorDiv.clientWidth:0,n=r>0?r/8.5:30,o=this.props.control.charLimit?Math.min(this.props.control.charLimit/n*26,390):104;o=this.props.control.rows?26*this.props.control.rows:o,o=this.props.height?this.props.height:o,this.editor.setSize(null,Math.max(Math.floor(o),104)),this.origHint=e.getHelper({line:0,ch:0},"hint");var i=this.props.control.language;switch(this.props.control.language){case"text/x-hive":i="sql";break;case"text/x-python":i="python";break;case"text/x-rsrc":i="r"}dl&&dl.registerHelper("hint",i,this.addonHints),this.props.editorDidMount&&this.props.editorDidMount(e,t)}},{key:"showExpressionBuilder",value:function(){this.initialControlValue=this.props.controller.getPropertyValue(this.props.propertyId),this.initialMessage=this.props.controller.getErrorMessage(this.props.propertyId),this.initialState=this.props.controller.getControlState(this.props.propertyId),this.setState({showExpressionBuilder:!0})}},{key:"hideExpressionBuilder",value:function(){this.setState({showExpressionBuilder:!1})}},{key:"cancelExpressionBuilder",value:function(){this.props.controller.updatePropertyValue(this.props.propertyId,this.initialControlValue),this.props.controller.updateErrorMessage(this.props.propertyId,this.initialMessage),this.props.controller.updateControlState(this.props.propertyId,this.initialState),this.hideExpressionBuilder()}},{key:"handleValidate",value:function(){var e=this;this.setState({validateIcon:null,validationInProgress:!0});var t=this.props.controller.getAppData();this.props.controller.getHandlers().validationHandler(this.props.controller,this.props.propertyId,this.props.value,t,(function(t){e.props.controller.updateErrorMessage(e.props.propertyId,t),e.setState({validateIcon:t.type,validationInProgress:!1})}))}},{key:"hasValidate",value:function(){return"function"==typeof this.props.controller.getHandlers().validationHandler}},{key:"handleKeyDown",value:function(e,t){if("Enter"===t.code&&this.props.selectionRange&&this.props.selectionRange.length>0&&this.props.onSelectionChange){var r={line:this.props.selectionRange[0].anchor.line+1,ch:0};this.props.onSelectionChange([{anchor:r,head:r}])}}},{key:"handleBlur",value:function(e,t){if(this.props.onBlur)this.props.onBlur(e,t);else{var r=this.editor.getValue(),n=t&&t.relatedTarget&&t.relatedTarget.classList.contains("properties-expression-button");this.props.controller.updatePropertyValue(this.props.propertyId,r,n)}}},{key:"_showBuilderButton",value:function(){return this.props.builder&&this.props.rightFlyout&&this.expressionInfo.functionCategories&&Object.keys(this.expressionInfo.functionCategories).length>0}},{key:"render",value:function(){var e=this,t=this.props.messageInfo,r=t?t.type:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.INFO;r===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.SUCCESS&&(t=null);var n=this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED?"disabled":r,o=this.props.controller.getReactIntl(),i=this._showBuilderButton()?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{kind:"ghost",size:"small",className:"properties-expression-button",disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,onClick:this.showExpressionBuilder,renderIcon:_carbon_icons_react__WEBPACK_IMPORTED_MODULE_44__.Calculator24,iconDescription:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(o,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_BUILDER_ICON_DESCRIPTION),tooltipPosition:"right",hasIconOnly:!0}):null,a=null;this.state.validateIcon&&(a=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"icon validateIcon"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_19__.I,{type:this.state.validateIcon,className:"properties-validation-icon-".concat(this.state.validateIcon)})));var l=this.state.validationInProgress?(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(o,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_VALIDATING_LABEL):(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(o,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_VALIDATE_LABEL),u=this.hasValidate()&&this.props.validateLink?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-expression-validate",disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{className:"validateLink",kind:"ghost",onClick:this.handleValidate,disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED||this.state.validationInProgress},l),a):null,c={mode:this.props.control.language,placeholder:this.props.control.additionalText,theme:n+" custom",readOnly:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED&&"nocursor",extraKeys:{"Ctrl-Space":"autocomplete"},autoRefresh:!0},d=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(o,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.APPLYBUTTON_LABEL),f=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(o,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.REJECTBUTTON_LABEL),h=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(o,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.EXPRESSION_BUILDER_TITLE),m=this.state.showExpressionBuilder?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(nn,{cancelHandler:this.cancelExpressionBuilder,okHandler:this.hideExpressionBuilder,show:this.state.showExpressionBuilder,applyLabel:d,rejectLabel:f,title:h,light:this.props.controller.getLight()},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ws,{control:this.props.control,controller:this.props.controller,propertyId:this.props.propertyId}))):null,v=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-expression-editor ".concat(r),{"properties-light-disabled":!this.props.controller.getLight()}),y=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-expression-link-container"},i,u),g=y;return this.props.expressionLabel&&(g=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-expression-header"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-expression-title"},this.props.expressionLabel),y)),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-expression-editor-wrapper"},this.props.controlItem,m,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-editor-container"},g,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{ref:function(t){return e.expressionEditorDiv=t},"data-id":an(this.props.propertyId),className:v},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_codemirror2__WEBPACK_IMPORTED_MODULE_6__.UnControlled,{ref:function(t){return e.codeMirror=t},options:c,onChange:this.handleChange,onKeyDown:this.handleKeyDown,onBlur:this.handleBlur,editorDidMount:this.editorDidMount,value:this.props.value}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{state:this.props.state,messageInfo:t,inTable:this.props.tableControl}))))}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));fl.defaultProps={builder:!0,validateLink:!0};var hl=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId)}}),null)(fl);function ml(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var vl=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,n);var o=ml(i);function i(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),(r=o.call(this,t)).id=on(r.props.propertyId),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"handleChange",value:function(e){this.props.controller.updatePropertyValue(this.props.propertyId,e.target.value)}},{key:"render",value:function(){var e=this.props.value?this.props.value:"",t=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-pwdfield","properties-input-control",{hide:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},this.props.messageInfo?this.props.messageInfo.type:null),r=pn(this.props.messageInfo,this.props.tableControl);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:t,"data-id":an(this.props.propertyId)},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_28__["default"].PasswordInput,(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},r,{autoComplete:"off",id:this.id,disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,placeholder:this.props.control.additionalText,onChange:this.handleChange.bind(this),value:e,labelText:this.props.controlItem,hideLabel:this.props.tableControl,light:this.props.controller.getLight(),tooltipAlignment:"end"})),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{inTable:this.props.tableControl,tableOnly:!0,state:this.props.state,messageInfo:this.props.messageInfo}))}}]),i}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),yl=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId)}}),null)(vl);function gl(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var bl=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=gl(a);function a(t){var r;if((0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).id=on(r.props.propertyId),r.getDateFormat=r.getDateFormat.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.handleChange=r.handleChange.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.value=t.value,r.value){var n=(0,date_fns__WEBPACK_IMPORTED_MODULE_45__["default"])(r.value,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.k,new Date);(0,date_fns__WEBPACK_IMPORTED_MODULE_27__["default"])(n)&&(r.value=(0,date_fns__WEBPACK_IMPORTED_MODULE_46__["default"])(n,r.getDateFormat()))}else r.value="";return r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"getDateFormat",value:function(){var e=this.props.control.dateFormat||_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.k;return e=e.replace(/Y/g,"y").replace(/D/g,"d")}},{key:"handleChange",value:function(e){var t=null;if(this.value="",e.target.value){this.value=e.target.value;var r=(0,date_fns__WEBPACK_IMPORTED_MODULE_45__["default"])(e.target.value,this.getDateFormat(),new Date);t=(0,date_fns__WEBPACK_IMPORTED_MODULE_27__["default"])(r)?(0,date_fns__WEBPACK_IMPORTED_MODULE_46__["default"])(r,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.k):e.target.value}this.props.controller.updatePropertyValue(this.props.propertyId,t)}},{key:"render",value:function(){var e=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-datefield","properties-input-control",{hide:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},this.props.messageInfo?this.props.messageInfo.type:null),t=pn(this.props.messageInfo,this.props.tableControl);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:e,"data-id":an(this.props.propertyId)},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_28__["default"],(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},t,{autoComplete:"off",id:this.id,disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,placeholder:this.props.control.additionalText,onChange:this.handleChange.bind(this),value:this.value,labelText:this.props.controlItem,hideLabel:this.props.tableControl,light:this.props.controller.getLight()})),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{inTable:this.props.tableControl,tableOnly:!0,state:this.props.state,messageInfo:this.props.messageInfo}))}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),El=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId)}}),null)(bl);function Il(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Sl=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=Il(a);function a(t){var r;if((0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).id=on(t.propertyId),r.value=t.value,r.value){var n=(0,date_fns__WEBPACK_IMPORTED_MODULE_45__["default"])(r.value,"HH:mm:ss:xxx",new Date);(0,date_fns__WEBPACK_IMPORTED_MODULE_27__["default"])(n)&&(r.value=(0,date_fns__WEBPACK_IMPORTED_MODULE_46__["default"])(n,r.getTimeFormat()))}else r.value="";return r.getTimeFormat=r.getTimeFormat.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.handleChange=r.handleChange.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"getTimeFormat",value:function(){return this.props.control.timeFormat||_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.l}},{key:"handleChange",value:function(e){var t=null;if(this.value="",e.target.value){this.value=e.target.value;var r=(0,date_fns__WEBPACK_IMPORTED_MODULE_45__["default"])(e.target.value,this.getTimeFormat(),new Date);t=(0,date_fns__WEBPACK_IMPORTED_MODULE_27__["default"])(r)?(0,date_fns__WEBPACK_IMPORTED_MODULE_46__["default"])(r,"HH:mm:ss:xxx"):e.target.value}this.props.controller.updatePropertyValue(this.props.propertyId,t)}},{key:"render",value:function(){var e=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-timefield","properties-input-control",{hide:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},this.props.messageInfo?this.props.messageInfo.type:null),t=pn(this.props.messageInfo,this.props.tableControl);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:e,"data-id":an(this.props.propertyId)},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_28__["default"],(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},t,{autoComplete:"off",id:this.id,disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,placeholder:this.props.control.additionalText,onChange:this.handleChange.bind(this),value:this.value,labelText:this.props.controlItem,hideLabel:this.props.tableControl,light:this.props.controller.getLight()})),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{inTable:this.props.tableControl,tableOnly:!0,state:this.props.state,messageInfo:this.props.messageInfo}))}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Cl=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId)}}),null)(Sl);function Rl(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var _l=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,n);var o=Rl(i);function i(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),(r=o.call(this,t)).id=on(r.props.propertyId),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"handleChange",value:function(e){this.props.controller.updatePropertyValue(this.props.propertyId,e)}},{key:"render",value:function(){var e=this.props.control.label?this.props.control.label.text:"",t=(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)()+"-tooltip-"+this.props.control.name,r="";this.props.control.description&&this.props.state!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED&&this.props.state!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN&&!this.props.tableControl&&(r=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",null,this.props.control.description.text),this.props.control.description.link&&(this.props.control.description.link.propertyId=this.props.propertyId));var n=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(r)?"":react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_18__["default"],{id:t,tip:r,link:this.props.control.description.link?this.props.control.description.link:null,tooltipLinkHandler:this.props.controller.getHandlers().tooltipLinkHandler,direction:"bottom",className:"properties-tooltips",showToolTipOnClick:!0},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_19__.I,{type:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.g.INFORMATION,className:"properties-control-description-icon-info"})),o=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{className:"properties-checkbox-label"},e);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-checkbox",{hide:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},this.props.messageInfo?this.props.messageInfo.type:null),"data-id":an(this.props.propertyId)},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_37__["default"],{disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,id:this.id,labelText:o,onChange:this.handleChange.bind(this),checked:Boolean(this.props.value),hideLabel:this.props.tableControl}),n,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{inTable:this.props.tableControl,state:this.props.state,messageInfo:this.props.controller.getErrorMessage(this.props.propertyId)}))}}]),i}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Tl=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId)}}),null)(_l);function wl(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var kl=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=wl(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).uuid=(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)(),r.handleChange=r.handleChange.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.updateValueFromFilterEnum=r.updateValueFromFilterEnum.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"componentDidMount",value:function(){this.updateValueFromFilterEnum(!0)}},{key:"componentDidUpdate",value:function(e){(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(this.props.controlOpts,e.controlOpts)||this.updateValueFromFilterEnum()}},{key:"updateValueFromFilterEnum",value:function(e){if(Array.isArray(this.props.value)){var t=$a(this.props.value,this.props.controlOpts.values);(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(this.props.value,t)||this.props.controller.updatePropertyValue(this.props.propertyId,t,e)}}},{key:"handleChange",value:function(e,t){var r=this.props.controller.getPropertyValue(this.props.propertyId);null==r&&(r=[]);var n=r.indexOf(e);t&&n<0&&(r=r.concat([e])),!t&&n>=0&&r.splice(n,1);var o=r.concat();this.props.controller.updatePropertyValue(this.props.propertyId,o)}},{key:"render",value:function(){var e=this.props.value;null==e&&(e=[]);for(var t=[],r=0;r<this.props.control.values.length;r++){var n={name:this.props.propertyId.name,row:r},o=this.props.control.values[r],i=e.indexOf(o)>=0,a=this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED||!this.props.controlOpts.values.includes(o);t.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_37__["default"],{disabled:a,id:on(n,this.uuid),key:o+r,labelText:this.props.control.valueLabels[r],onChange:this.handleChange.bind(this,o),checked:i}))}return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("fieldset",null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("legend",null,this.props.controlItem),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-checkboxset",{hide:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN}),"data-id":an(this.props.propertyId)},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-checkboxset-container",this.props.messageInfo?this.props.messageInfo.type:null)},t),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{inTable:this.props.tableControl,state:this.props.state,messageInfo:this.props.messageInfo})))}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Ll=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){var r={value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId)};return r.controlOpts=t.controller.getFilteredEnumItems(t.propertyId,t.control),r}),null)(kl);function Al(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return Ol(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return Ol(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function Ol(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function Dl(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Pl=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=Dl(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).uuid=(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)(),r.handleChange=r.handleChange.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.updateValueFromFilterEnum=r.updateValueFromFilterEnum.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"componentDidMount",value:function(){this.updateValueFromFilterEnum(!0);var e=this.props.controller.getPropertyValue(this.props.propertyId);this.setEnabledStateOfOptionalPanels(e),void 0!==this.props.value&&null!==this.props.value&&this.handleCheckedDisabled(this.props.value,this.isRadioButtonDisabled(String(this.props.value)))}},{key:"componentDidUpdate",value:function(e){(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(this.props.controlOpts,e.controlOpts)||this.updateValueFromFilterEnum(),void 0!==this.props.value&&null!==this.props.value&&this.handleCheckedDisabled(this.props.value,this.isRadioButtonDisabled(String(this.props.value)))}},{key:"setEnabledStateOfOptionalPanels",value:function(e){if(this.props.control.optionalPanels){var t=this.props.controlOpts,r=this.props.controller.getPanelStates();this.props.controller.parsePanelTree();for(var n=0;n<t.values.length;n++){Sa(r,{name:t.values[n]},t.values[n]===e?_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.ENABLED:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED)}this.props.controller.setPanelStates(r),function(e,t){for(var r={controls:t.getControlStates(),panels:t.getPanelStates(),actions:t.getActionStates()},n=0;n<e.length;n++){var o=t.getPanelState({name:e[n]});Pa(r,{name:e[n]},o,t)}t.setControlStates(r.controls),t.setPanelStates(r.panels),t.setActionStates(r.actions)}(t.values,this.props.controller)}}},{key:"getOptionalPanel",value:function(e){return this.props.control.optionalPanels?this.props.control.optionalPanels[e]:null}},{key:"updateValueFromFilterEnum",value:function(e){if(null!==this.props.value&&void 0!==this.props.value&&!this.props.controlOpts.values.includes(this.props.value)){var t=null;this.props.control.valueDef&&this.props.control.valueDef.defaultValue&&this.props.controlOpts.values.includes(this.props.control.valueDef.defaultValue)&&(t=this.props.control.valueDef.defaultValue),this.props.controller.updatePropertyValue(this.props.propertyId,t,e)}}},{key:"convertTargetValue",value:function(e){return"boolean"===this.props.control.valueDef.propType?"true"===e:"integer"===this.props.control.valueDef.propType||"long"===this.props.control.valueDef.propType||"double"===this.props.control.valueDef.propType?Number(e):e}},{key:"handleChange",value:function(e){var t=this.props.controller.getPropertyValue(this.props.propertyId),r=this.convertTargetValue(e);this.props.controller.updatePropertyValue(this.props.propertyId,r),t!==r&&this.setEnabledStateOfOptionalPanels(r)}},{key:"isRadioButtonDisabled",value:function(e){var t=this.props.valueStates;return!!(t&&t[e]&&t[e].value)&&t[e].value===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED}},{key:"handleCheckedDisabled",value:function(e,t){if(null!=e&&t&&this.props.state!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED){var r,n=this.props.controller.getControl(this.props.propertyId),o=this.props.control.valueDef.defaultValue;if(o&&!this.isRadioButtonDisabled(o))r=o;else{var i,a=Al(n.values);try{for(a.s();!(i=a.n()).done;){var s=i.value;if(s!==e&&!this.isRadioButtonDisabled(s)){r=s;break}}}catch(e){a.e(e)}finally{a.f()}}r&&this.props.controller.updatePropertyValue(this.props.propertyId,r)}}},{key:"render",value:function(){this.props.control.values||"radioset"!==this.props.control.controlType||(this.props.control.values=[!0,!1],this.props.control.valueLabels=["true","false"]);for(var e=[],t=this.props.controlOpts,r=0;r<t.values.length;r++){var n=t.values[r]===this.props.value,o="boolean"===this.props.control.valueDef.propType?String(t.values[r]):t.values[r],i=this.isRadioButtonDisabled(o),a=this.getOptionalPanel(o),l={name:this.props.propertyId.name,row:r};e.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:r,className:"properties-radioset-panel"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_47__["default"],{key:r,id:on(l,this.uuid),disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED||i,labelText:t.valueLabels[r],value:o,onChange:this.handleChange,checked:n}),a))}return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":an(this.props.control,this.props.propertyId),className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-radioset ",{hide:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN})},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-radio-button-group",this.props.messageInfo?this.props.messageInfo.type:null,{horizontal:this.props.control.orientation!==_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.O.VERTICAL}),disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED},e),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{state:this.props.state,messageInfo:this.props.messageInfo,inTable:this.props.tableControl}))}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Nl=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),valueStates:t.controller.getControlValueStates(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId),controlOpts:t.controller.getFilteredEnumItems(t.propertyId,t.control)}}),null)(Pl);function xl(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return Bl(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return Bl(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function Bl(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function Ml(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Fl=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=Ml(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).emptyLabel="...",t.control.additionalText&&(r.emptyLabel=t.control.additionalText),r.reactIntl=t.controller.getReactIntl(),r.id=on(r.props.propertyId),r.handleChange=r.handleChange.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.handleComboOnChange=r.handleComboOnChange.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.handleOnInputChange=r.handleOnInputChange.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.genSchemaSelectOptions=r.genSchemaSelectOptions.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.genSelectOptions=r.genSelectOptions.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.genFieldSelectOptions=r.genFieldSelectOptions.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.updateValueFromFilterEnum=r.updateValueFromFilterEnum.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"componentDidMount",value:function(){this.updateValueFromFilterEnum(!0)}},{key:"componentDidUpdate",value:function(e){(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(this.props.controlOpts,e.controlOpts)||this.updateValueFromFilterEnum()}},{key:"getSelectedOption",value:function(e,t){var r=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.s)(t,this.props.control),n=e.find((function(e){return e.value===r}));return null===(n=void 0===n?null:n)&&this.props.control.customValueAllowed&&(n={value:r,label:r}),n}},{key:"genSchemaSelectOptions",value:function(e){var t=[];if(t.push({value:"",label:this.emptyLabel}),Array.isArray(this.props.controlOpts)){var r,n=xl(this.props.controlOpts);try{for(n.s();!(r=n.n()).done;){var o=r.value;t.push({value:o,label:o})}}catch(e){n.e(e)}finally{n.f()}}return{options:t,selectedOption:this.getSelectedOption(t,e)}}},{key:"genFieldSelectOptions",value:function(e){var t=[];t.push({value:"",label:this.emptyLabel});var r,n=xl(this.props.controlOpts);try{for(n.s();!(r=n.n()).done;){var o=r.value;t.push({value:o.name,label:o.name})}}catch(e){n.e(e)}finally{n.f()}return{options:t,selectedOption:this.getSelectedOption(t,e)}}},{key:"genSelectOptions",value:function(e){for(var t=[],r=0;r<this.props.controlOpts.values.length;r++)t.push({value:this.props.controlOpts.values[r],label:this.props.controlOpts.valueLabels[r]});return{options:t,selectedOption:this.getSelectedOption(t,e)}}},{key:"updateValueFromFilterEnum",value:function(e){if(this.props.control.controlType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.ONEOFSELECT&&null!==this.props.value&&void 0!==this.props.value&&!this.props.controlOpts.values.includes(this.props.value)){var t=null;this.props.control.valueDef&&this.props.control.valueDef.defaultValue&&this.props.controlOpts.values.includes(this.props.control.valueDef.defaultValue)?t=this.props.control.valueDef.defaultValue:this.props.control.customValueAllowed&&this.props.value&&(t=this.props.value),this.props.controller.updatePropertyValue(this.props.propertyId,t,e)}}},{key:"handleChange",value:function(e){var t=this.props.tableControl?e.target.value:e.selectedItem.value;this.props.control.controlType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SELECTCOLUMN&&(t=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.m)(t,this.props.control,this.props.controller)),this.props.controller.updatePropertyValue(this.props.propertyId,t)}},{key:"handleComboOnChange",value:function(e){var t=e.selectedItem&&e.selectedItem.value?e.selectedItem.value:"";this.props.control.controlType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SELECTCOLUMN&&(t=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.m)(t,this.props.control,this.props.controller)),this.props.controller.updatePropertyValue(this.props.propertyId,t)}},{key:"handleOnInputChange",value:function(e){if(null!==e){var t=e;this.props.controller.updatePropertyValue(this.props.propertyId,t)}}},{key:"render",value:function(){var e;e=this.props.control.controlType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SELECTSCHEMA?this.genSchemaSelectOptions(this.props.value):this.props.control.controlType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SELECTCOLUMN?this.genFieldSelectOptions(this.props.value):this.genSelectOptions(this.props.value);var t={"close.menu":(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.DROPDOWN_TOOLTIP_CLOSEMENU),"open.menu":(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.DROPDOWN_TOOLTIP_OPENMENU)},r=null,n=pn(this.props.messageInfo,this.props.tableControl);if(this.props.tableControl){var o=[],i=e.selectedOption&&e.selectedOption.value?e.selectedOption.value:"";e.selectedOption||o.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_48__["default"],{text:this.emptyLabel,key:this.id,value:""}));var a,l=xl(e.options);try{for(l.s();!(a=l.n()).done;){var u=a.value;o.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_48__["default"],{text:u.label,key:this.id+"-"+u.value,value:u.value}))}}catch(e){l.e(e)}finally{l.f()}r=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_49__["default"],{id:this.id,hideLabel:!0,inline:!0,labelText:this.props.control.label?this.props.control.label.text:"",disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,onChange:this.handleChange,value:i,light:this.props.controller.getLight()},o)}else r=this.props.control.customValueAllowed?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_50__["default"],(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},n,{ariaLabel:this.props.control.label?this.props.control.label.text:"",id:"".concat(an(this.props.propertyId),"-dropdown"),disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,placeholder:e.selectedOption.label,selectedItem:e.selectedOption.label,items:e.options,onChange:this.handleComboOnChange,onInputChange:this.handleOnInputChange,light:this.props.controller.getLight(),translateWithId:function(e){return t[e]},titleText:this.props.controlItem})):react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_41__["default"],(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},n,{id:"".concat(an(this.props.propertyId),"-dropdown"),disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,type:"default",items:e.options,onChange:this.handleChange,selectedItem:e.selectedOption,label:this.emptyLabel,light:this.props.controller.getLight(),translateWithId:function(e){return t[e]},titleText:this.props.controlItem}));return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":an(this.props.propertyId),className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-dropdown",{hide:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},this.props.messageInfo?this.props.messageInfo.type:null)},r,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{state:this.props.state,messageInfo:this.props.messageInfo,inTable:this.props.tableControl,tableOnly:!0}))}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Vl=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){var r={value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId)};return t.control.controlType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SELECTSCHEMA?r.controlOpts=t.controller.getDatasetMetadataSchemas():t.control.controlType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SELECTCOLUMN?r.controlOpts=t.controller.getFilteredDatasetMetadata(t.propertyId):r.controlOpts=t.controller.getFilteredEnumItems(t.propertyId,t.control),r}),null)(Fl);function Ul(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var jl=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=Ul(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).reactIntl=t.controller.getReactIntl(),r.getSelectedOption=r.getSelectedOption.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.genSelectOptions=r.genSelectOptions.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.handleOnChange=r.handleOnChange.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.updateValueFromFilterEnum=r.updateValueFromFilterEnum.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.setShouldRender=r.setShouldRender.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.state={shouldRender:!0},r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"componentDidMount",value:function(){this.updateValueFromFilterEnum(!0)}},{key:"componentDidUpdate",value:function(e){(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(this.props.controlOpts,e.controlOpts)||this.updateValueFromFilterEnum(),this.setShouldRender(e)}},{key:"setShouldRender",value:function(e){!(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(this.props.controlOpts.values,e.controlOpts.values)&&this.state.shouldRender?this.setState({shouldRender:!1}):this.state.shouldRender||this.setState({shouldRender:!0})}},{key:"getSelectedOption",value:function(e,t){var r=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.s)(t,this.props.control),n=[];return r&&r.forEach((function(t){return n.push(e.find((function(e){return e.id===t})))})),n}},{key:"genSelectOptions",value:function(e){for(var t=[],r=0;r<this.props.controlOpts.values.length;r++)t.push({id:this.props.controlOpts.values[r],label:this.props.controlOpts.valueLabels[r]});return{options:t,selectedOptions:this.getSelectedOption(t,e)}}},{key:"updateValueFromFilterEnum",value:function(e){var t=$a(this.props.value,this.props.controlOpts.values);(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(t,this.props.value)||((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(t)&&this.props.control.valueDef&&this.props.control.valueDef.defaultValue&&(t=$a(this.props.control.valueDef.defaultValue,this.props.controlOpts.values)),this.props.controller.updatePropertyValue(this.props.propertyId,t,e))}},{key:"handleOnChange",value:function(e){for(var t=[],r=0;r<e.selectedItems.length;r++)t.push(e.selectedItems[r].id);this.props.controller.updatePropertyValue(this.props.propertyId,t)}},{key:"render",value:function(){var e=this.genSelectOptions(this.props.value);if(!this.state.shouldRender)return null;var t={"close.menu":(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.DROPDOWN_TOOLTIP_CLOSEMENU),"open.menu":(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.DROPDOWN_TOOLTIP_OPENMENU),"clear.all":(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.DROPDOWN_TOOLTIP_CLEARALL),"clear.selection":(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.DROPDOWN_TOOLTIP_CLEARSELECTION)},r="".concat(this.props.control.name,".multiselect.dropdown.empty.label"),n=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.MULTISELECT_DROPDOWN_EMPTY_LABEL),o="".concat(this.props.control.name,".multiselect.dropdown.options.selected.label"),i=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.MULTISELECT_DROPDOWN_OPTIONS_SELECTED_LABEL),a="";a=0===e.selectedOptions.length?this.props.controller.getResource(r,n):this.props.controller.getResource(o,i);var l=pn(this.props.messageInfo,this.props.tableControl),u=null;return u=this.props.control.filterable?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_51__.FilterableMultiSelect,(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},l,{id:"".concat(an(this.props.propertyId),"-multiselect-filterable"),disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,translateWithId:function(e){return t[e]},items:e.options,initialSelectedItems:e.selectedOptions,onChange:this.handleOnChange,placeholder:a,titleText:this.props.tableControl?null:this.props.controlItem,light:this.props.controller.getLight()})):react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_51__["default"],(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},l,{id:"".concat(an(this.props.propertyId),"-multiselect"),disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,translateWithId:function(e){return t[e]},items:e.options,selectedItems:e.selectedOptions,onChange:this.handleOnChange,label:a,titleText:this.props.tableControl?null:this.props.controlItem,light:this.props.controller.getLight()})),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":an(this.props.propertyId),className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-dropdown",{hide:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},this.props.messageInfo?this.props.messageInfo.type:null)},u,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{state:this.props.state,tableOnly:!0,messageInfo:this.props.messageInfo,inTable:this.props.tableControl}))}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Hl=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId),controlOpts:t.controller.getFilteredEnumItems(t.propertyId,t.control)}}),null)(jl);function ql(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var zl=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=ql(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).genSelectOptions=r.genSelectOptions.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.updateValueFromFilterEnum=r.updateValueFromFilterEnum.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.updateSelections=r.updateSelections.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"componentDidMount",value:function(){this.updateValueFromFilterEnum(!0)}},{key:"componentDidUpdate",value:function(e){(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(this.props.controlOpts,e.controlOpts)||this.updateValueFromFilterEnum()}},{key:"updateValueFromFilterEnum",value:function(e){var t=$a(this.props.value,this.props.controlOpts.values);(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(t,this.props.value)||this.props.controller.updatePropertyValue(this.props.propertyId,t,e)}},{key:"updateSelections",value:function(e){for(var t=[],r=0;r<e.length;r++){var n=this.props.controlOpts.values[e[r]];t.push(n)}this.props.controller.updatePropertyValue(this.props.propertyId,t)}},{key:"genSelectOptions",value:function(e){for(var t={options:[],selected:[]},r=0;r<this.props.controlOpts.values.length;r++){-1!==e.indexOf(this.props.controlOpts.values[r])&&t.selected.push(r);var n=[];n.push({column:"someofselect",state:this.props.state,content:this.props.controlOpts.valueLabels[r]}),t.options.push({className:"table-row",columns:n,disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED})}return t}},{key:"render",value:function(){var e=this.props.value;null==e&&(e=[]);var t=this.genSelectOptions(e),r=this.props.control.rows?this.props.control.rows:5.5,n=this.props.control.label&&this.props.control.label.text?this.props.control.label.text:"";return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":an(this.props.control,this.props.propertyId),className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-someofselect ",{hide:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},this.props.messageInfo?this.props.messageInfo.type:null)},this.props.controlItem,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_10__.F,{columns:[{key:"someofselect",label:""}],rows:r,data:t.options,scrollKey:this.props.control.name,tableLabel:n,selectedRows:t.selected,updateRowSelections:this.updateSelections,selectable:!0,showHeader:!1,light:this.props.controller.getLight()}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{state:this.props.state,messageInfo:this.props.messageInfo,inTable:this.props.tableControl}))}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Gl=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId),controlOpts:t.controller.getFilteredEnumItems(t.propertyId,t.control)}}),null)(zl);function Wl(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var $l=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,ws);var o=Wl(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).reactIntl=t.controller.getReactIntl(),r.emptyTableButtonClickHandler=r.addOnClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r),r.props.propertyId),r.emptyTableButtonLabel=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(r.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.STRUCTURETABLE_ADDBUTTON_LABEL),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"makeRows",value:function(e,t){var r=[];if(e)for(var n=0;n<e.length;n++){var o=[],i=void 0!==this.props.propertyId.row?{row:this.props.propertyId.row,index:n}:{row:n},a=Object.assign({},this.props.propertyId,i),l=Object.assign({},this.props.control);if(l.dmImage){var u=this.props.controller.getDatasetMetadataFields(),c=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.s)(this.props.controller.getPropertyValue(a),l,!0),p=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.n)(u,c,l.dmImage);l.icon=p}var d=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-table-cell-control"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Qa,{control:l,propertyId:a,controller:this.props.controller,tableControl:!0}));o.push({key:n+"-0-field",column:"field",content:d}),r.push({key:n,onClickCallback:this.handleRowClick.bind(this,n,!1),columns:o,className:"column-select-table-row"})}return r}},{key:"onFieldPickerClose",value:function(e,t){if(e&&t){this.setCurrentControlValueSelected(e,t);var r=t[t.length-1];this.setScrollToRow(r)}}},{key:"makeHeader",value:function(){var e=[];return e.push({key:"field",label:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.FIELDPICKER_FIELDCOLUMN_LABEL),description:null}),e}},{key:"render",value:function(){var e,t=this.makeHeader(),r={fieldPickerCloseFunction:this.onFieldPickerClose},n=this.makeRows(this.props.value,this.props.state),o=this.makeAddRemoveButtonPanel(this.props.state,r);Number.isInteger(this.scrollToRow)&&n.length>this.scrollToRow&&(e=this.scrollToRow,delete this.scrollToRow);var i=this.props.control.label&&this.props.control.label.text?this.props.control.label.text:"",a=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_10__.F,{columns:t,data:n,scrollToRow:e,topRightPanel:o,scrollKey:this.props.control.name,tableState:this.props.state,messageInfo:this.props.messageInfo,rows:this.props.control.rows,tableLabel:i,selectedRows:this.props.selectedRows,rowSelection:this.props.control.rowSelection,updateRowSelections:this.updateRowSelections,light:this.props.controller.getLight()}),l=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-column-select-table"},a),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{state:this.props.state,messageInfo:this.props.messageInfo}));return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":an(this.props.propertyId),className:"properties-column-select"},this.props.controlItem,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ps,{tableContainer:l,control:this.props.control,controller:this.props.controller,propertyId:this.props.propertyId,setScrollToRow:this.setScrollToRow,setCurrentControlValueSelected:this.setCurrentControlValueSelected,disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,isEmptyTable:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(this.props.value),emptyTableButtonLabel:this.emptyTableButtonLabel,emptyTableButtonClickHandler:this.emptyTableButtonClickHandler}))}}]),a}();$l.propTypes={control:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object.isRequired),propertyId:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object.isRequired),controller:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object.isRequired),controlItem:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().element),openFieldPicker:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().func.isRequired),selectedRows:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().array),state:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().string),value:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().array),messageInfo:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object),addRemoveRows:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().bool),tableButtons:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object)};var Xl=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId),selectedRows:t.controller.getSelectedRows(t.propertyId),addRemoveRows:t.controller.getAddRemoveRows(t.propertyId),tableButtons:t.controller.getTableButtons(t.propertyId)}}),null)($l);function Yl(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Kl=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,n);var o=Yl(i);function i(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),(r=o.call(this,t)).controlFactory=new Iu(r.props.controller),r.controlFactory.setFunctions(r.props.openFieldPicker,r.props.buildUIItem),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"_getSubControlDef",value:function(e){for(var t=0;t<this.props.control.subControls.length;t++)if(this.props.control.subControls[t].name===e)return this.props.control.subControls[t];return null}},{key:"_getColumnIndex",value:function(e){for(var t=0;t<this.props.control.subControls.length;t++)if(this.props.control.subControls[t].name===e)return t;return null}},{key:"_makeRow",value:function(e){for(var t=[],r=0;r<e.length;r++){var n=this._getSubControlDef(e[r]);if(n&&n.visible){var o={name:this.props.control.name,col:this._getColumnIndex(e[r])},i=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(this.props.propertyId),a=o;i.name!==o.name&&(a=this.props.controller.setChildPropertyId(i,o)),t.push(this.controlFactory.createControlItem(n,a))}}return t}},{key:"_makeControls",value:function(){var e=[];if(Array.isArray(this.props.control.layout))for(var t=this.props.control.layout,r=0;r<t.length;r++)Array.isArray(t[r])&&e.push(this._makeRow(t[r]));else for(var n=0;n<this.props.control.subControls.length;n++)if(this.props.control.subControls[n].visible){var o={name:this.props.control.name,col:this._getColumnIndex(this.props.control.subControls[n].name)},i=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(this.props.propertyId),a=o;i.name!==o.name&&(a=this.props.controller.setChildPropertyId(i,o)),e.push([this.controlFactory.createControlItem(this.props.control.subControls[n],a)])}return e}},{key:"_makeControlTable",value:function(e){for(var t=[],r=0;r<e.length;r++){for(var n=[],o=0;o<e[r].length;o++)n.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("td",{key:(1+r)*o,className:"properties-structureeditor-cell"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,e[r][o])));t.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement("tr",{key:1+r},n))}return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("table",{role:"presentation"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("tbody",null,t))}},{key:"render",value:function(){var e=this._makeControlTable(this._makeControls());return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":an(this.props.control,this.props.propertyId),className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-structureeditor ",{hide:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN},this.props.messageInfo?this.props.messageInfo.type:null)},e,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{state:this.props.state,messageInfo:this.props.messageInfo,inTable:!1}))}}]),i}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),Jl=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId)}}),null)(Kl),Zl=_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.o;var Ql=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.x,eu=function(e,t){var r=[];return Zl(e,(function(e,n,o){t(e,n,o)&&r.push(e)})),r},tu=_flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_10__._,ru=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.y,nu=function(e){if("function"!=typeof e)throw new TypeError("Expected a function");return function(){var t=arguments;switch(t.length){case 0:return!e.call(this);case 1:return!e.call(this,t[0]);case 2:return!e.call(this,t[0],t[1]);case 3:return!e.call(this,t[0],t[1],t[2])}return!e.apply(this,t)}};var ou=function(e,t){return(ru(e)?Ql:eu)(e,nu(tu(t)))};function iu(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return au(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return au(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function au(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function su(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var lu=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,ws);var o=su(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).reactIntl=t.controller.getReactIntl(),r.addColumns=r.addColumns.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.removeColumns=r.removeColumns.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.getDefaultRow=r.getDefaultRow.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.indexOfRow=r.indexOfRow.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.emptyTableButtonClickHandler=r.addOnClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r),r.props.propertyId),r.emptyTableButtonLabel=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(r.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.STRUCTURETABLE_ADDBUTTON_LABEL),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"indexOfRow",value:function(e){var t=this.props.control.keyIndex;return bs(this.props.controller.getPropertyValue(this.props.propertyId),(function(r){return r[t]===e}))}},{key:"addColumns",value:function(e,t){for(var r=[],n=this.props.control.valueDef.isMap,o=0;o<e.length;o++){var i=e[o];if(this.indexOfRow(i)<0){var a=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(this.props.control.defaultRow);n?a.unshift(i):a[this.props.control.keyIndex]=i,r.push(a)}}var s=this.props.controller.getPropertyValue(this.props.propertyId).concat(r);this.setCurrentControlValueSelected(s)}},{key:"removeColumns",value:function(e,t){var r=this.props.controller.getPropertyValue(this.props.propertyId),n=this.props.control.keyIndex,o=ou(r,(function(t){return e.indexOf(t[n])>=0}));this.setCurrentControlValueSelected(o)}},{key:"getDefaultRow",value:function(e){var t=[];if(this.props.value&&e)for(var r=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.g)(this.props.control),n=0;n<this.props.value.length;n++){if(this.props.value[n][r]===e||this.props.value[n]===e)return this.props.value[n]}for(var o=0;o<this.props.control.subControls.length;o++){var i=this.props.control.subControls[o];if(i.role===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.COLUMN)t.push(e);else if(i.role===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.NEW_COLUMN)t.push((0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.s)(e,i).replace(".","_"));else if(void 0!==i.dmDefault)t.push((0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.p)(i,e,this.props.controller.getDatasetMetadataFields()));else if(void 0!==this.props.control.defaultRow){var a=o;this.props.control.subControls.length!==this.props.control.defaultRow.length&&(a-=1);var s=this.props.control.defaultRow[a];this.props.control.subControls[a].valueDef.propType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.STRUCTURE?t.push([]):s&&s.parameterRef?t.push(this.props.controller.getPropertyValue({name:s.parameterRef})):t.push(s)}else i.valueDef&&i.valueDef.defaultValue?i.valueDef.defaultValue.parameterRef?t.push(this.props.controller.getPropertyValue({name:i.valueDef.defaultValue.parameterRef})):t.push(i.valueDef.defaultValue):t.push(null)}return t}},{key:"onFieldPickerClose",value:function(e,t){if(e&&t){var r,n=[],o=iu(e);try{for(o.s();!(r=o.n()).done;){var i=r.value;n.push(this.getDefaultRow(i))}}catch(e){o.e(e)}finally{o.f()}this.setCurrentControlValueSelected(n,t);var a=t[t.length-1];this.setScrollToRow(a)}}},{key:"render",value:function(){var e={fieldPickerCloseFunction:this.onFieldPickerClose},t=this.props.control&&this.props.control.buttons,r=this.createTable(this.props.state,e,t),n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-st properties-st-buttons"},r),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{state:this.props.state,messageInfo:this.props.messageInfo})),o=this.getOnPanelContainer(this.props.selectedRows);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":an(this.props.control,this.props.propertyId),className:"properties-column-structure-wrapper"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-column-structure"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ps,{tableContainer:n,control:this.props.control,controller:this.props.controller,propertyId:this.props.propertyId,setScrollToRow:this.setScrollToRow,setCurrentControlValueSelected:this.setCurrentControlValueSelected,disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,isEmptyTable:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(this.props.value),emptyTableButtonLabel:this.emptyTableButtonLabel,emptyTableButtonClickHandler:this.emptyTableButtonClickHandler})),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,o))}}]),a}();lu.propTypes={buildUIItem:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().func),control:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object.isRequired),propertyId:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object.isRequired),controller:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object.isRequired),openFieldPicker:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().func.isRequired),rightFlyout:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().bool),selectedRows:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().array),state:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().string),value:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().array),messageInfo:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object),addRemoveRows:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().bool),tableButtons:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object)};var uu=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId),selectedRows:t.controller.getSelectedRows(t.propertyId),addRemoveRows:t.controller.getAddRemoveRows(t.propertyId),tableButtons:t.controller.getTableButtons(t.propertyId)}}),null)(lu);function cu(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var pu=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,ws);var o=cu(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).addRow=r.addRow.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.allowColumnControls=!0,r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"addRow",value:function(){var e=this.getDefaultRow(),t=this.props.controller.getPropertyValue(this.props.propertyId).concat([e]);this.setCurrentControlValueSelected(t)}},{key:"render",value:function(){var e={addButtonLabel:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.STRUCTURELISTEDITOR_ADDBUTTON_LABEL),removeButtonLabel:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.STRUCTURELISTEDITOR_REMOVEBUTTON_LABEL),addButtonFunction:this.addRow},t=this.props.control&&this.props.control.buttons,r=this.createTable(this.props.state,e,t),n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-sle properties-sle-buttons"},r),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{state:this.props.state,messageInfo:this.props.messageInfo})),o=this.getOnPanelContainer(this.props.selectedRows);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":an(this.props.control,this.props.propertyId),className:"properties-sle-wrapper"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":an(this.props.control,this.props.propertyId),className:"properties-sle-container"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ps,{tableContainer:n,control:this.props.control,controller:this.props.controller,propertyId:this.props.propertyId,setScrollToRow:this.setScrollToRow,setCurrentControlValueSelected:this.setCurrentControlValueSelected,disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,isEmptyTable:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(this.props.value),emptyTableButtonLabel:e.addButtonLabel,emptyTableButtonClickHandler:this.addRow})),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,o))}}]),a}();pu.propTypes={buildUIItem:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().func),control:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object.isRequired),propertyId:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object.isRequired),controller:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object.isRequired),rightFlyout:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().bool),selectedRows:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().array),state:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().string),value:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().array),messageInfo:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object),addRemoveRows:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().bool),tableButtons:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object)};var du=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId),selectedRows:t.controller.getSelectedRows(t.propertyId),addRemoveRows:t.controller.getAddRemoveRows(t.propertyId),tableButtons:t.controller.getTableButtons(t.propertyId)}}),null)(pu);function fu(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var hu=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,ws);var o=fu(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).reactIntl=t.controller.getReactIntl(),r.editCallback=r.editCallback.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.buttonHandler=r.props.controller.getHandlers().buttonHandler,r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"editCallback",value:function(){this.buttonHandler&&this.buttonHandler({type:"edit",propertyId:this.props.propertyId})}},{key:"render",value:function(){var e="".concat(this.props.control.name,".edit.button.label"),t=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.reactIntl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.READONLYTABLE_EDIT_BUTTON_LABEL),r=this.props.controller.getResource(e,t),n=this.buttonHandler?{editCallback:this.editCallback,label:r}:null,o=this.props.control&&this.props.control.buttons,i=this.createTable(this.props.state,n,o),a=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-rt properties-rt-buttons"},i),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{state:this.props.state,messageInfo:this.props.messageInfo}));return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":an(this.props.control,this.props.propertyId),className:"properties-readonly-table-wrapper"},this.props.controlItem,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-readonly-table"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ps,{tableContainer:a,control:this.props.control,controller:this.props.controller,propertyId:this.props.propertyId,setScrollToRow:this.setScrollToRow,setCurrentControlValueSelected:this.setCurrentControlValueSelected,disabled:this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED,isEmptyTable:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(this.props.value),emptyTableButtonLabel:r,emptyTableButtonClickHandler:this.editCallback})))}}]),a}();hu.propTypes={buildUIItem:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().func),control:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object.isRequired),propertyId:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object.isRequired),controller:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object.isRequired),controlItem:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().element),rightFlyout:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().bool),selectedRows:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().array),state:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().string),value:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().array),messageInfo:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object),addRemoveRows:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().bool),tableButtons:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().object),hideEditButton:(prop_types__WEBPACK_IMPORTED_MODULE_40___default().bool)};var mu=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{value:t.controller.getPropertyValue(t.propertyId),state:t.controller.getControlState(t.propertyId),messageInfo:t.controller.getErrorMessage(t.propertyId),selectedRows:t.controller.getSelectedRows(t.propertyId),addRemoveRows:t.controller.getAddRemoveRows(t.propertyId),tableButtons:t.controller.getTableButtons(t.propertyId),hideEditButton:t.controller.getHideEditButton(t.propertyId)}}),null)(hu);function vu(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var yu=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(i,n);var o=vu(i);function i(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,i),(r=o.call(this,t)).actionFactory=new zn(r.props.controller),r.uuid=(0,uuid__WEBPACK_IMPORTED_MODULE_3__.v4)(),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(i,[{key:"render",value:function(){if(this.props.control.controlType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.HIDDEN)return null;var e,t,r,n,o=this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN,i=this.props.state===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED;this.props.control.label&&!1!==this.props.control.labelVisible&&(this.props.control.description&&!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(this.props.control.description.text)&&("on_panel"===this.props.control.description.placement?t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-control-description"},this.props.control.description.text):(this.props.control.description.link&&(this.props.control.description.link.propertyId=this.props.propertyId),r=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_18__["default"],{id:"".concat(this.uuid,"-tooltip-label-").concat(this.props.control.name),tip:this.props.control.description.text,link:this.props.control.description.link?this.props.control.description.link:null,tooltipLinkHandler:this.props.controller.getHandlers().tooltipLinkHandler,direction:"bottom",disable:o||i,showToolTipOnClick:!0},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_19__.I,{type:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.g.INFORMATION,className:"properties-control-description-icon-info"})))),this.props.control.required&&(n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{className:"properties-required-indicator"},"*")),e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-label-container",{"table-control":!0===this.props.tableControl})},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("label",{className:"properties-control-label"},this.props.control.label.text),n,r));var a=this.actionFactory.generateAction(0,this.props.control.action),l=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-control-item",{hide:o});return this.props.accessibleControls.includes(this.props.control.controlType)?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":"properties-ci-"+this.props.control.name,className:l,disabled:i},e,t):react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":"properties-ci-"+this.props.control.name,className:l,disabled:i},e,t,this.props.controlObj,a)}}]),i}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),gu=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{state:t.controller.getControlState(t.propertyId)}}),null)(yu),bu=[_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.CHECKBOXSET,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.HIDDEN,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.DATEFIELD,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.NUMBERFIELD,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SPINNER,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.PASSWORDFIELD,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TEXTAREA,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TEXTFIELD,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TIMEFIELD,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TOGGLETEXT,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.LIST,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SOMEOFSELECT,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SELECTCOLUMNS,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.READONLY,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.READONLYTABLE,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TIMESTAMP,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.EXPRESSION,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.CODE,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.ONEOFSELECT,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.MULTISELECT,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SELECTSCHEMA,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SELECTCOLUMN],Eu=[_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.LIST,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.READONLYTABLE,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SOMEOFSELECT,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SELECTCOLUMNS,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.STRUCTURETABLE,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.STRUCTURELISTEDITOR],Iu=function(){function r(t){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r),this.rightFlyout=!0,this.controller=t,this.actionFactory=new zn(this.controller)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,[{key:"setFunctions",value:function(e,t){this.genUIItem=t,this.openFieldPicker=e}},{key:"setRightFlyout",value:function(e){this.rightFlyout=e}},{key:"createControlItem",value:function(e,t,r){var n=this.createControl(e,t,r),o=this.controller.getControlState(t)===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN,i=e.className?e.className:"";return bu.includes(e.controlType)?n:react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:"properties-ctrl-"+e.name,"data-id":"properties-ctrl-"+e.name,className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-ctrl-wrapper",{hide:o},i)},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(gu,{key:"ctrl-item-"+e.name,controller:this.controller,propertyId:t,control:e,controlObj:n,accessibleControls:bu,tableControl:Eu.includes(e.controlType)}))}},{key:"createControl",value:function(e,t,r){if(!e||!t)return null;var n,o=an(t),i=this.controller.getControlState(t)===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN,a=this.actionFactory.generateAction(0,e.action),l={};switch(l.key=o,l.control=e,l.controller=this.controller,l.propertyId=t,l.controlItem=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(gu,{key:"ctrl-item-"+e.name,controller:this.controller,propertyId:t,control:e,accessibleControls:bu,tableControl:Eu.includes(e.controlType)}),r&&(l.tableControl=r.table),e.controlType){case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.HIDDEN:return null;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TEXTFIELD:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(rs,l);break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.READONLY:case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TIMESTAMP:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Qa,l);break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TEXTAREA:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(ls,l);break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.LIST:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ms,l);break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.EXPRESSION:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(hl,(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},l,{rightFlyout:this.rightFlyout}));break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.CODE:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(hl,(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},l,{builder:!1,validateLink:!1,rightFlyout:this.rightFlyout}));break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TOGGLETEXT:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(is,l);break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.PASSWORDFIELD:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(yl,l);break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.NUMBERFIELD:case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SPINNER:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(ps,l);break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.DATEFIELD:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(El,l);break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.TIMEFIELD:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Cl,l);break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.CHECKBOX:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Tl,l);break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.CHECKBOXSET:n=r?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Qa,l):react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ll,l);break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.RADIOSET:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Nl,l);break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.ONEOFSELECT:case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SELECTSCHEMA:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Vl,(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},l,{rightFlyout:this.rightFlyout}));break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.MULTISELECT:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Hl,l);break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SELECTCOLUMN:n=!r||r&&r.allowColumnControls?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Vl,(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},l,{rightFlyout:this.rightFlyout})):react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Qa,l);break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SOMEOFSELECT:n=r?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Qa,l):react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Gl,l);break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.SELECTCOLUMNS:n=r?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Qa,l):react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Xl,(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},l,{openFieldPicker:this.openFieldPicker,rightFlyout:this.rightFlyout}));break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.STRUCTURETABLE:n=r?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Qa,l):react__WEBPACK_IMPORTED_MODULE_0___default().createElement(uu,(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},l,{buildUIItem:this.genUIItem,openFieldPicker:this.openFieldPicker,rightFlyout:this.rightFlyout}));break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.STRUCTURELISTEDITOR:n=r?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Qa,l):react__WEBPACK_IMPORTED_MODULE_0___default().createElement(du,(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},l,{buildUIItem:this.genUIItem,rightFlyout:this.rightFlyout}));break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.READONLYTABLE:n=r?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Qa,l):react__WEBPACK_IMPORTED_MODULE_0___default().createElement(mu,(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},l,{buildUIItem:this.genUIItem,rightFlyout:this.rightFlyout}));break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.CUSTOM:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-custom-ctrl",key:o},this.controller.getCustomControl(t,e,r));break;case _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.STRUCTUREEDITOR:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Jl,(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({},l,{buildUIItem:this.genUIItem,openFieldPicker:this.openFieldPicker,rightFlyout:this.rightFlyout}));break;default:n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Qa,l)}if(bu.includes(e.controlType)){if(r)return n;var u=e.className?e.className:"";return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:"properties-ctrl-"+e.name,"data-id":"properties-ctrl-"+e.name,className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-ctrl-wrapper",{hide:i,action:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(e,"action.image.placement")},u)},n,a)}return n}},{key:"createFormControl",value:function(e,t){if(!e)return null;var r=_o.makePropertyDef(null,e.parameters,e.complex_types,e.uihints);if(r&&r.parameterMetadata){var n,o=new Zn(e.resources),i=r.parameterMetadata.getParameter(t);return i.propType()===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.STRUCTURE&&r.structureMetadata&&(n=r.structureMetadata.getStructure(i.baseType())),jo(r.parameterMetadata,t,null,n,o)}return null}}]),r}();function Su(e,t,r,n){if(["structuretable","structureeditor","structurelisteditor"].indexOf(e.control.controlType)>=0){var o=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.t)(e.value);return"undefined"!==o&&"null"!==o&&String(e.value).length>0}return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring unsupported condition operation 'cellNotEmpty' for control type "+e.control.controlType),!0}function Cu(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return Ru(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return Ru(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function Ru(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function _u(e,t,r,n){if(["textfield"].indexOf(e.control.controlType)>=0){var o=n.getDatasetMetadataFields();if(!o)return!0;var i,a=!0,s=Cu(o);try{for(s.s();!(i=s.n()).done;){var l=i.value;if((0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.q)(e.value,l)){a=!1;break}}}catch(e){s.e(e)}finally{s.f()}if(!a){var u,c=function(e,t){var r=[];if(void 0!==e.control.columnIndex){var n=t.getPropertyValue({name:e.id.name,row:e.id.row});Array.isArray(n)&&n.forEach((function(n,o){o!==e.control.columnIndex&&(t.getControl({name:e.id.name,col:o}).role===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.COLUMN&&r.push(n))}))}return r}(e,n),p=Cu(c);try{for(p.s();!(u=p.n()).done;){var d=u.value;if((0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(e.value,d)){a=!0;break}}}catch(e){p.e(e)}finally{p.f()}}return a}return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring unsupported condition operation 'colNotExists' for control type "+e.control.controlType),!0}function Tu(e,t,r,n){var o=n.getDatasetMetadataFields();if(!o)return!1;var i=e.control.controlType;switch(i){case"selectcolumns":case"selectcolumn":if(Array.isArray(e.value)&&void 0!==e.control.editStyle){if(e.value.length>0){var a=!0;return e.value.forEach((function(e){a=a&&void 0!==wu(o,e)})),a}return!0}return void 0!==wu(o,e.value);default:return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring unsupported condition operation 'colDoesExists' for control type "+i),!0}}function wu(e,t){return e.find((function(e){return (0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.q)(t,e)}))}var ku=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.f,Lu=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.y,Au=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.i;var Ou=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.g;var Du=function(e,t){return Ou(t,(function(t){return e[t]}))},Pu=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.p;var Nu=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.z,xu=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.n,Bu=function(e){return"string"==typeof e||!Lu(e)&&Au(e)&&"[object String]"==ku(e)},Mu=hs,Fu=function(e){return null==e?[]:Du(e,Pu(e))},Vu=Math.max;var Uu=function(e,t,r,n){e=xu(e)?e:Fu(e),r=r&&!n?Mu(r):0;var o=e.length;return r<0&&(r=Vu(o+r,0)),Bu(e)?r<=o&&e.indexOf(t,r)>-1:!!o&&Nu(e,t,r)>-1};function ju(e,t,r,n){if(["checkbox","numberfield","passwordfield"].indexOf(e.control.controlType)<0){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value);if(void 0!==t)switch(o){case"undefined":return!1;case"string":case"object":return Uu(e.value,t.value);default:return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'contains' for parameter_ref "+e.param+" with input data type "+o),!0}else if(void 0!==r)switch(o){case"undefined":return!1;case"string":case"object":return Uu(e.value,r);default:return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'contains' for parameter_ref "+e.param+" with input data type "+o),!0}throw new Error("Insufficient parameter for condition operation contains")}return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring unsupported condition operation 'contains' for control type "+e.control.controlType),!0}function Hu(e,t,r,n){if("passwordfield"!==e.control.controlType){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value);if(t){if(null===e.value||null===t.value)return e.value===t.value;switch(o){case"undefined":case"boolean":case"number":return e.value===t.value;case"string":return e.value.trim()===t.value.trim();case"object":return JSON.stringify(e.value)===JSON.stringify(t.value);default:return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'equals' for parameter_ref "+e.param+" with input data type "+o),!0}}else if(void 0!==r){if(null===e.value||null===r)return e.value===r;switch(o){case"undefined":case"boolean":case"number":return e.value===r;case"string":return e.value.trim()===r.toString().trim();case"object":return JSON.stringify(e.value)===JSON.stringify(r);default:return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'equals' for parameter_ref "+e.param+" with input data type "+o),!0}}throw new Error("Insufficient parameter for condition operation equals")}return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring unsupported condition operation 'equals' for control type "+e.control.controlType),!0}function qu(e,t,r,n){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value);switch(o){case"undefined":case"number":if(void 0!==t)return"number"==typeof t.value&&e.value>t.value;if(void 0!==r)return null===r||e.value>r;throw new Error("Insufficient parameter for condition operation 'greaterThan'");case"object":return null===e.value||null===t.value||null===r;default:return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'greaterThan' for parameter_ref "+e.param+" with input data type "+o),!0}}function zu(e,t,r,n){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value);switch(o){case"undefined":return!0;case"boolean":return!1;case"string":return 0===e.value.trim().length;case"number":return null===e.value;case"object":return null===e.value||0===e.value.length;default:return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'isEmpty' for parameter_ref "+e.param+" with input data type "+o),!0}}function Gu(e,t,r,n){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value);switch(o){case"undefined":return!1;case"boolean":return!0;case"string":return 0!==e.value.trim().length;case"number":return null!==e.value;case"object":return null!==e.value&&0!==e.value.length;default:return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'isNotEmpty' for parameter_ref "+e.param+" with input data type "+o),!0}}function Wu(e,t,r,n){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value);switch(o){case"undefined":case"number":if(void 0!==t)return"number"==typeof t.value&&e.value<t.value;if(void 0!==r)return null===r||e.value<r;throw new Error("Insufficient parameter for condition operation 'lessThan'");case"object":return null===e.value||null===t.value||null===r;default:return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'lessThan' for parameter_ref "+e.param+" with input data type "+o),!0}}function $u(e,t,r,n){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value),i="";if(null!=t)i=t.value;else{if(null==r)return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'matches' for parameter_ref "+e.param+" no regular expression specified in condition."),!0;i=r}return"string"===o||"undefined"===o?new RegExp(i).test(e.value):(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'matches' for parameter_ref "+e.param+" with input data type "+o),!0)}function Xu(e,t,r,n){if(["checkbox","numberfield","passwordfield"].indexOf(e.control.controlType)<0){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value);if(void 0!==t)switch(o){case"undefined":return!0;case"string":case"object":return!Uu(e.value,t.value);default:return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'notContains' for parameter_ref "+e.param+" with input data type "+o),!0}else if(void 0!==r)switch(o){case"undefined":return!0;case"string":case"object":return!Uu(e.value,r);default:return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'notContains' for parameter_ref "+e.param+" with input data type "+o),!0}throw new Error("Insufficient parameter for condition operation notContains")}return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring unsupported condition operation 'notContains' for control type "+e.control.controlType),!0}function Yu(e,t,r,n){if("passwordfield"!==e.control.controlType){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value);if(t){if(null===e.value||null===t.value)return e.value!==t.value;switch(o){case"undefined":case"boolean":case"number":return e.value!==t.value;case"string":return e.value.trim()!==t.value.trim();case"object":return JSON.stringify(e.value)!==JSON.stringify(t.value);default:return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'notEquals' for parameter_ref "+e.param+" with input data type "+o),!0}}else if(void 0!==r){if(null===e.value||null===r)return e.value!==r;switch(o){case"undefined":case"boolean":case"number":return e.value!==r;case"string":return e.value.trim()!==r.trim();case"object":return JSON.stringify(e.value)!==JSON.stringify(r);default:return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'notEquals' for parameter_ref "+e.param+" with input data type "+o),!0}}throw new Error("Insufficient parameter for condition operation notEquals")}return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring unsupported condition operation 'notEquals' for control type "+e.control.controlType),!0}function Ku(e,t,r,n){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value),i="";if(null!=t)i=t.value;else{if(null==r)return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'notMatches' for parameter_ref "+e.param+" no regular expression specified in condition."),!0;i=r}return"string"===o||"undefined"===o?!new RegExp(i).test(e.value):(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'notMatches' for parameter_ref "+e.param+" with input data type "+o),!0)}function Ju(e,t,r,n){if(e.value){var o="time"===r?"HH:mm:ss:xxx":_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.k,i=(0,date_fns__WEBPACK_IMPORTED_MODULE_45__["default"])(e.value,o,new Date);return (0,date_fns__WEBPACK_IMPORTED_MODULE_27__["default"])(i)}return!0}function Zu(e,t,r,n){"column"!==e.control.role&&_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Condition Operator dmTypeEquals only intended for use on columns");var o=n.getDatasetMetadataFields(),i=null;if(null!=t&&null!==t.value)"column"===t.control.role&&(i=qa(t,o,"type")),null===i&&(i=t.value);else{if(null==r)return!1;i=r}return!!o&&("string"==typeof e.value||"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value)?qa(e,o,"type")===i:(void 0!==e.value&&_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("dmTypeEquals cannot handle the given type: "+(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value)),!1))}function Qu(e,t,r,n){"column"!==e.control.role&&_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Condition Operator dmTypeNotEquals only intended for use on columns");var o=n.getDatasetMetadataFields(),i=null;if(null!=t&&null!==t.value)"column"===t.control.role&&(i=qa(t,o,"type")),null===i&&(i=t.value);else{if(null==r)return!1;i=r}return!!o&&("string"==typeof e.value||"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value)?qa(e,o,"type")!==i:(void 0!==e.value&&_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("dmTypeNotEquals cannot handle the given type: "+(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value)),!1))}function ec(e,t,r,n){"column"!==e.control.role&&_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Condition Operator dmMeasurementEquals only intended for use on columns");var o=n.getDatasetMetadataFields(),i=null;if(null!=t&&null!==t.value)"column"===t.control.role&&(i=qa(t,o,"measure")),null===i&&(i=t.value);else{if(null==r)return!1;i=r}return!!o&&("string"==typeof e.value||"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value)?qa(e,o,"measure")===i:(void 0!==e.value&&_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("dmMeasurementEquals cannot handle the given type: "+(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value)),!1))}function tc(e,t,r,n){"column"!==e.control.role&&_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Condition Operator dmMeasurementNotEquals only intended for use on columns");var o=n.getDatasetMetadataFields(),i=null;if(null!=t&&null!==t.value)"column"===t.control.role&&(i=qa(t,o,"measure")),null===i&&(i=t.value);else{if(null==r)return!1;i=r}return!!o&&("string"==typeof e.value||"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value)?qa(e,o,"measure")!==i:(void 0!==e.value&&_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("dmMeasurementNotEquals cannot handle the given type: "+(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value)),!1))}function rc(e,t,r,n){"column"!==e.control.role&&_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Condition Operator dmRoleEquals only intended for use on columns");var o=n.getDatasetMetadataFields(),i=null;if(null!=t&&null!==t.value)"column"===t.control.role&&(i=qa(t,o,"modeling_role")),null===i&&(i=t.value);else{if(null==r)return!1;i=r}return!!o&&("string"==typeof e.value||"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value)?qa(e,o,"modeling_role")===i:(void 0!==e.value&&_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("dmRoleEquals cannot handle the given type: "+(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value)),!1))}function nc(e,t,r,n){"column"!==e.control.role&&_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Condition Operator dmRoleEquals only intended for use on columns");var o=n.getDatasetMetadataFields(),i=null;if(null!=t&&null!==t.value)"column"===t.control.role&&(i=qa(t,o,"modeling_role")),null===i&&(i=t.value);else{if(null==r)return!1;i=r}return!!o&&("string"==typeof e.value||"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value)?qa(e,o,"modeling_role")!==i:(void 0!==e.value&&_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("dmRoleEquals cannot handle the given type: "+(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e.value)),!1))}function oc(e,t,r,n){var o,i=r;return t&&(i=t.value),"string"==typeof e.value||Array.isArray(e.value)?o=e.value.length:void 0!==e.value&&null!==e.value||(o=0),"number"==typeof i&&"number"==typeof o?o===i:(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'lengthEquals' for parameter_ref "+e.param),!0)}function ic(e,t,r,n){var o,i=r;return t&&(i=t.value),"string"==typeof e.value||Array.isArray(e.value)?o=e.value.length:void 0!==e.value&&null!==e.value||(o=0),"number"==typeof i&&"number"==typeof o?o<i:(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'lengthLessThan' for parameter_ref "+e.param),!0)}function ac(e,t,r,n){var o,i=r;return t&&(i=t.value),"string"==typeof e.value||Array.isArray(e.value)?o=e.value.length:void 0!==e.value&&null!==e.value||(o=0),"number"==typeof i&&"number"==typeof o?o>i:(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Ignoring condition operation 'lengthGreaterThan' for parameter_ref "+e.param),!0)}function sc(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return lc(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return lc(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function lc(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function uc(e){var t={};if(t.cellNotEmpty=Su,t.colNotExists=_u,t.colDoesExists=Tu,t.contains=ju,t.equals=Hu,t.greaterThan=qu,t.isEmpty=zu,t.isNotEmpty=Gu,t.lessThan=Wu,t.matches=$u,t.notContains=Xu,t.notEquals=Yu,t.notMatches=Ku,t.isDateTime=Ju,t.dmTypeEquals=Zu,t.dmTypeNotEquals=Qu,t.dmMeasurementEquals=ec,t.dmMeasurementNotEquals=tc,t.dmRoleEquals=rc,t.dmRoleNotEquals=nc,t.lengthEquals=oc,t.lengthLessThan=ic,t.lengthGreaterThan=ac,Array.isArray(e)){var r,n=sc(e);try{for(n.s();!(r=n.n()).done;){var o=r.value;o&&"function"==typeof o.op&&"function"==typeof o.evaluate?t[o.op()]=o.evaluate:_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Custom operator missing require function of `op` or `evaluate`")}}catch(e){n.e(e)}finally{n.f()}}return t}function cc(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return pc(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return pc(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,o=function(){};return{s:o,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,a=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return a=e.done,e},e:function(e){s=!0,i=e},f:function(){try{a||null==r.return||r.return()}finally{if(s)throw i}}}}function pc(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}var dc=function(){function r(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,r),this.propertiesStore=new _i,this.handlers={propertyListener:null,controllerHandler:null,actionHandler:null,buttonHandler:null,buttonIconHandler:null,titleChangeHandler:null,tooltipLinkHandler:null},this.propertiesConfig={},this.visibleDefinitions={},this.enabledDefinitions={},this.validationDefinitions={},this.requiredDefinitionsIds=[],this.filterDefinitions={},this.filteredEnumDefinitions={},this.allowChangeDefinitions={},this.conditionalDefaultDefinitions={},this.panelTree={},this.controls={},this.actions={},this.customControls=[],this.summaryPanelControls={},this.controllerHandlerCalled=!1,this.commandStack=new _lib_command_stack_es_js__WEBPACK_IMPORTED_MODULE_52__["default"],this.custPropSumPanelValues={},this.controlFactory=new Iu(this),this.sharedCtrlInfo=[],this.isSummaryPanel=!1,this.visibleSubPanelCounter=0,this.conditionOps=uc(),this.expressionFunctionInfo={},this.expressionRecentlyUsed=[],this.expressionFieldsRecentlyUsed=[],this.selectionListeners={}}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(r,[{key:"getStore",value:function(){return this.propertiesStore.getStore()}},{key:"subscribe",value:function(e){this.propertiesStore.subscribe(e)}},{key:"getHandlers",value:function(){return this.handlers}},{key:"setHandlers",value:function(e){this.handlers=Object.assign(this.handlers,e),this.handlers.controllerHandler&&!this.controllerHandlerCalled&&(this.handlers.controllerHandler(this),this.controllerHandlerCalled=!0)}},{key:"setCommandStack",value:function(e){this.commandStack=e}},{key:"getCommandStack",value:function(){return this.commandStack}},{key:"setEditorSize",value:function(e){this.editorSize=e}},{key:"getEditorSize",value:function(){return this.editorSize}},{key:"setLight",value:function(e){this.light=e}},{key:"getLight",value:function(){return this.light}},{key:"setPropertiesConfig",value:function(e){this.propertiesConfig=e}},{key:"getPropertiesConfig",value:function(){return this.propertiesConfig}},{key:"setParamDef",value:function(e){var t=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.k)(this.getPropertiesConfig(),"rightFlyout",!0),r=Ko.makeForm(e,!t);this.setForm(r)}},{key:"setForm",value:function(e,t){if(this.form=e,this.reactIntl=t,this.form){this.controls={},this.setControlStates({}),this.setErrorMessages({}),this.isSummaryPanel=!1,this.visibleSubPanelCounter=0,this._parseUiConditions();var r,n=[];!function(e,t,r){if(r.uiItems){var n,o=wi(r.uiItems);try{for(o.s();!(n=o.n()).done;)Oi(e,t,n.value)}catch(e){o.e(e)}finally{o.f()}}}(n,this.actions,this.form),this.saveControls(n),this._parseSummaryControls(n),this.parsePanelTree(),_a(this.controls,this.validationDefinitions,this.requiredDefinitionsIds,t);var o={};this.form.data&&(r=this.form.data.datasetMetadata,o=this.form.data.uiCurrentParameters?ci({},this.form.data.currentParameters,this.form.data.uiCurrentParameters):this.form.data.currentParameters),this.setDatasetMetadata(r),this.setPropertyValues(o,!0),this._addToControlValues(),this._addToControlValues(!0),this.setInitialAddRemoveRows(),this.setInitialTableButtonState(),this.uiItems=this.form.uiItems,(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(this.uiItems)||(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(this.uiItems[0].tabs)||this.propertiesStore.setActiveTab(this.uiItems[0].tabs[0].group),this.setTitle(this.form.label)}}},{key:"getForm",value:function(){return this.form}},{key:"getResource",value:function(e,t){return this.form&&this.form.resources&&this.form.resources[e]?this.form.resources[e]:t}},{key:"setAppData",value:function(e){this.appData=e}},{key:"getAppData",value:function(){return this.appData}},{key:"_parseUiConditions",value:function(){if(this.visibleDefinitions={controls:{},refs:{}},this.enabledDefinitions={controls:{},refs:{}},this.validationDefinitions={controls:{},refs:{}},this.filterDefinitions={controls:{},refs:{}},this.filteredEnumDefinitions={controls:{},refs:{}},this.allowChangeDefinitions={controls:{},refs:{}},this.conditionalDefaultDefinitions={controls:{},refs:{}},this.form.conditions){var e,t=cc(this.form.conditions);try{for(t.s();!(e=t.n()).done;){var r=e.value;r.visible?Di(this.visibleDefinitions,r,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.VISIBLE):r.enabled?Di(this.enabledDefinitions,r,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.ENABLED):r.validation?Di(this.validationDefinitions,r,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.VALIDATION):r.filter?Di(this.filterDefinitions,r,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.FILTER):r.enum_filter?Di(this.filteredEnumDefinitions,r,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.FILTEREDENUM):r.allow_change?Di(this.allowChangeDefinitions,r,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.ALLOWCHANGE):r.default_value?Di(this.conditionalDefaultDefinitions,r,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.CONDITIONALDEFAULT):_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.info("Invalid definition: "+JSON.stringify(r))}}catch(e){t.e(e)}finally{t.f()}}}},{key:"getDefinitions",value:function(e,t,r){var n;switch(t){case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.VISIBLE:n=this.visibleDefinitions[r];break;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.ENABLED:n=this.enabledDefinitions[r];break;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.FILTEREDENUM:n=this.filteredEnumDefinitions[r];break;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.ALLOWCHANGE:n=this.allowChangeDefinitions[r];break;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.CONDITIONALDEFAULT:n=this.conditionalDefaultDefinitions[r];break;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.VALIDATION:n=this.validationDefinitions[r]}var o=[];for(var i in n)if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(n,i)){var a=Ra(i);a.name===e.name&&a.col===e.col&&(o=o.concat(n[i]))}return o}},{key:"getRequiredDefinitionIds",value:function(){return this.requiredDefinitionsIds}},{key:"convertPropertyId",value:function(e){return"string"==typeof e?{name:e}:this.convertNestedPropertyId(e)}},{key:"convertNestedPropertyId",value:function(e){var t;return e&&void 0!==e.col&&void 0===e.row?(void 0!==e.propertyId&&(t=this.convertNestedPropertyId(e.propertyId)),{name:e.name,row:e.col,propertyId:t}):e&&void 0!==e.col&&void 0!==e.row&&void 0!==e.propertyId?{name:e.name,row:e.row,col:e.col,propertyId:this.convertNestedPropertyId(e.propertyId)}:e}},{key:"updateLastChildPropertyId",value:function(e,t){return void 0!==e.propertyId?this.updateLastChildPropertyId(e.propertyId,t):(void 0!==t.row&&(e.row=t.row),void 0!==t.col&&(e.col=t.col),e)}},{key:"setChildPropertyId",value:function(e,t){return void 0!==e.propertyId?this.setChildPropertyId(e.propertyId,t):(e.propertyId=t,e)}},{key:"parsePanelTree",value:function(){this.panelTree={},this.panelTree[_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.P]={controls:[],panels:[],actions:[]},function(e,t,r){if(t.uiItems){var n,o=Bi(t.uiItems);try{for(o.s();!(n=o.n()).done;)Fi(e,n.value,r)}catch(e){o.e(e)}finally{o.f()}}}(this.panelTree,this.form,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.P)}},{key:"_addToControlValues",value:function(e){for(var t in this.controls)if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(this.controls,t)){var r=this.controls[t],n={name:r.name},o=this.getPropertyValue(n);e?null!=o&&void 0!==o.parameterRef&&(o=this.getPropertyValue({name:o.parameterRef}),this.updatePropertyValue(n,o,!0)):"structuretable"===r.controlType&&!1===r.addRemoveRows&&!0===r.includeAllFields?(o=this._populateFieldData(o,r),this.updatePropertyValue(n,o,!0)):void 0!==r.valueDef&&void 0!==r.valueDef.defaultValue&&void 0===o?(o=r.valueDef.defaultValue,(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.r)(r)&&(o=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.u)(r.valueDef.isList,r.subControls,o)),this.updatePropertyValue(n,o,!0)):"structureeditor"===r.controlType&&(!o||Array.isArray(o)&&0===o.length)&&Array.isArray(r.defaultRow)&&this.updatePropertyValue(n,r.defaultRow,!0)}}},{key:"_populateFieldData",value:function(e,t){for(var r=this.getDatasetMetadataFields(),n=this._isMultiSchemaControl(t),o=[].concat(e),i=0;i<r.length;i++){var a=[];if(-1===this._indexOfField(r[i].name,e)){for(var s=0;s<t.subControls.length;s++)if(s===t.keyIndex){var l=n?{link_ref:r[i].schema,field_name:r[i].origName}:r[i].name;a.push(l)}else a.push(this._getDefaultSubControlValue(s,r[i].name,r,t));o.push(a)}}return o}},{key:"_isMultiSchemaControl",value:function(e){if(e.role===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.COLUMN&&e.valueDef.propType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.STRUCTURE)return!0;if("array"===(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.t)(e.subControls))for(var t in e.subControls)if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(e.subControls,t)){var r=e.subControls[t];if(r.role===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.a.COLUMN&&r.valueDef.propType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.STRUCTURE)return!0}return!1}},{key:"_canHaveMultipleSchemas",value:function(){for(var e in this.controls)if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(this.controls,e)){var t=this.controls[e];if(this._isMultiSchemaControl(t))return!0}return!1}},{key:"_getDefaultSubControlValue",value:function(e,t,r,n){var o,i=n.subControls[e];return"undefined"!==(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.t)(i.dmDefault)?o=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.p)(i,t,r):"undefined"!==(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.t)(i.valueDef.defaultValue)?(o=i.valueDef.defaultValue).parameterRef&&(o=this.getPropertyValue({name:o.parameterRef})):o=i.values?i.values[0]:"string"===i.valueDef.propType?"":"boolean"!==i.valueDef.propType&&("enum"===i.valueDef.propType?i.values[0]:"integer"===i.valueDef.propType||"long"===i.valueDef.propType||"double"===i.valueDef.propType?0:"structure"===i.valueDef.propType?{}:null),o}},{key:"_indexOfField",value:function(e,t){for(var r=0;r<t.length;r++)if(t[r][0]===e)return r;return-1}},{key:"getUiItems",value:function(){return this.uiItems}},{key:"getReactIntl",value:function(){return this.reactIntl}},{key:"addSharedControls",value:function(e,t){this.sharedCtrlInfo.push({id:e,controlNames:t})}},{key:"getSharedCtrlInfo",value:function(){return this.sharedCtrlInfo}},{key:"isSummaryPanelShowing",value:function(){return this.isSummaryPanel}},{key:"setIsSummaryPanelShowing",value:function(e){this.isSummaryPanel=e}},{key:"increaseVisibleSubPanelCounter",value:function(){this.visibleSubPanelCounter++}},{key:"decreaseVisibleSubPanelCounter",value:function(){this.visibleSubPanelCounter--}},{key:"isSubPanelsShowing",value:function(){return this.visibleSubPanelCounter>0}},{key:"getTitle",value:function(){return this.propertiesStore.getTitle()}},{key:"setTitle",value:function(e){return this.propertiesStore.setTitle(e)}},{key:"setConditionOps",value:function(e){this.conditionOps=uc(e)}},{key:"getConditionOp",value:function(e){return this.conditionOps?this.conditionOps[e]:null}},{key:"getConditionOps",value:function(){return this.conditionOps}},{key:"getDatasetMetadata",value:function(){return this.propertiesStore.getDatasetMetadata().schemas}},{key:"getDatasetMetadataFields",value:function(){return this.propertiesStore.getDatasetMetadata().fields}},{key:"getDatasetMetadataSchemas",value:function(){return this.propertiesStore.getDatasetMetadata().schemaNames}},{key:"getFilteredDatasetMetadata",value:function(e){var t=this.getDatasetMetadataFields();return e&&(t=this._filterSharedDataset(e,t),t=function(e,t,r,n){var o=n;if(t&&Array.isArray(t[e.name]))try{for(var i=t[e.name],a=0;a<i.length;a++)o=ua(e,t[e.name][a].definition,r,o)}catch(t){_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Error thrown in filter for propertyId ("+e.name+"): "+t)}return o}(e,this.filterDefinitions.controls,this,t)),t}},{key:"_filterSharedDataset",value:function(e,t){if(!this.sharedCtrlInfo||!e)return t;var r,n=e.name,o=[],i=cc(this.sharedCtrlInfo);try{for(i.s();!(r=i.n()).done;){var a,s=r.value,l=cc(s.controlNames);try{for(l.s();!(a=l.n()).done;){if(n===a.value.controlName){o=s.controlNames;break}}}catch(e){l.e(e)}finally{l.f()}}}catch(e){i.e(e)}finally{i.f()}var u=o.map((function(e){return e.controlName}));return this.filterFieldsFromSharedProps(t,u,n)}},{key:"filterFieldsFromSharedProps",value:function(e,t,r){try{var n,o=[],i=cc(t);try{for(i.s();!(n=i.n()).done;){var a=n.value;if(a!==r){var s=this.getControl({name:a}),l=this.getPropertyValue({name:a});if(Array.isArray(l)){var u,c=cc(l);try{for(c.s();!(u=c.n()).done;){var p=u.value;if(Array.isArray(p)){var d=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.g)(s);d>=0&&d<p.length&&o.push((0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.s)(p[d],s))}else o.push((0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.s)(p,s))}}catch(e){c.e(e)}finally{c.f()}}else o.push((0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.s)(l,s))}}}catch(e){i.e(e)}finally{i.f()}var f=Array.from(new Set(o));return e.filter((function(e){return-1===f.indexOf(e.name)}))}catch(e){_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Error filtering shared controls "+e)}return e}},{key:"setDatasetMetadata",value:function(e){var t=[],r=[];if(e){var n=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(e);Array.isArray(n)||(n=[n]);for(var o=0;o<n.length;o++)n[o].name||(n[o].name=o.toString()),n[o].idx=o;var i,a=cc(n);try{var s=function(){var e=i.value,t=n.filter((function(t){return t.name===e.name}));if(t&&t.length>1)for(var r=0;r<t.length;r++)t[r].name=t[r].name+"_"+t[r].idx};for(a.s();!(i=a.n()).done;)s()}catch(e){a.e(e)}finally{a.f()}var l,u=cc(n);try{for(u.s();!(l=u.n()).done;){var c=l.value;if(t.push(c.name),c.fields){var p,d=cc(c.fields);try{for(d.s();!(p=d.n()).done;){var f=p.value;f.schema=c.name,f.origName=f.name,r.push(f)}}catch(e){d.e(e)}finally{d.f()}}}}catch(e){u.e(e)}finally{u.f()}}if(void 0===this.multipleSchemas&&(this.multipleSchemas=this._canHaveMultipleSchemas()),this.multipleSchemas){var h,m=cc(r);try{for(m.s();!(h=m.n()).done;){var v=h.value;v.name=v.schema+"."+v.origName}}catch(e){m.e(e)}finally{m.f()}}this.propertiesStore.setDatasetMetadata({schemas:e,fields:r,schemaNames:t})}},{key:"validateInput",value:function(e){var t=!(arguments.length>1&&void 0!==arguments[1])||arguments[1];ga(e,this,t)}},{key:"validatePropertiesValues",value:function(){var e=!(arguments.length>0&&void 0!==arguments[0])||arguments[0];ma(this,e)}},{key:"getSelectedRows",value:function(e){var t=this.convertPropertyId(e);return this.propertiesStore.getSelectedRows(t)}},{key:"updateSelectedRows",value:function(e,t){var r=this.convertPropertyId(e);this.propertiesStore.updateSelectedRows(r,t),this._notifySelectionListener(r,t)}},{key:"clearSelectedRows",value:function(e){var t=this.convertPropertyId(e);this.propertiesStore.clearSelectedRows(t)}},{key:"setDisableRowMoveButtons",value:function(e){Array.isArray(e)&&this.propertiesStore.setDisableRowMoveButtons(e)}},{key:"getDisableRowMoveButtons",value:function(){return this.propertiesStore.getDisableRowMoveButtons()}},{key:"isDisableRowMoveButtons",value:function(e){var t=this.getDisableRowMoveButtons();return!!Array.isArray(t)&&t.some((function(t){return (0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(t,e)}))}},{key:"addRowSelectionListener",value:function(e,t){var r=this.convertPropertyId(e),n=r.name;if(this.selectionListeners[n]||(this.selectionListeners[n]={}),Number.isInteger(r.row))throw new Error("Listening for row selection changes on controls within table cells is not currently supported");this.selectionListeners[n].listener=t}},{key:"removeRowSelectionListener",value:function(e){var t=this.convertPropertyId(e),r=t.name;if(Number.isInteger(t.row))throw new Error("Listening for row selection changes on controls within table cells is not currently supported");this.selectionListeners[r]&&delete this.selectionListeners[r]}},{key:"_notifySelectionListener",value:function(e,t){var r=this.convertPropertyId(e).name;this.selectionListeners[r]&&this.selectionListeners[r].listener(t)}},{key:"setExpressionInfo",value:function(e){this.expressionFunctionInfo=Ni(e)}},{key:"getExpressionInfo",value:function(){return this.expressionFunctionInfo}},{key:"getExpressionRecentlyUsed",value:function(){return this.expressionRecentlyUsed}},{key:"updateExpressionRecentlyUsed",value:function(e){var t=this.expressionRecentlyUsed.indexOf(e);-1===t?this.expressionRecentlyUsed.splice(0,0,e):(this.expressionRecentlyUsed.splice(t,1),this.expressionRecentlyUsed.unshift(e))}},{key:"clearExpressionRecentlyUsed",value:function(){this.expressionRecentlyUsed=[]}},{key:"getExpressionFieldsRecentlyUsed",value:function(){return this.expressionFieldsRecentlyUsed}},{key:"updateExpressionFieldsRecentlyUsed",value:function(e){var t=this.expressionFieldsRecentlyUsed.indexOf(e);-1===t?this.expressionFieldsRecentlyUsed.splice(0,0,e):(this.expressionFieldsRecentlyUsed.splice(t,1),this.expressionFieldsRecentlyUsed.unshift(e))}},{key:"clearExpressionFieldsRecentlyUsed",value:function(){this.expressionFieldsRecentlyUsed=[]}},{key:"getFilteredEnumItems",value:function(e,t){var r=this.propertiesStore.getFilteredEnumItems(e);if(Array.isArray(r)){for(var n={values:[],valueLabels:[]},o=function(e){n.values.push(r[e]);var o=r[e],i=t.values.findIndex((function(t){return t===r[e]}));i>-1&&(o=t.valueLabels[i]),n.valueLabels.push(o)},i=0;i<r.length;i++)o(i);return n}return t}},{key:"updatePropertyValue",value:function(e,t,r){var n=this.convertPropertyId(e),o=this.getPropertyValue(n);if(void 0===t?this.removePropertyValue(n):this.propertiesStore.updatePropertyValue(n,t),function(e,t){var r=!0;if(!t.getControl(e))return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Control not found for "+e.name),r;var n=t.getDefinitions(e,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.ALLOWCHANGE,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.i.CONTROLS);if(n.length>0)try{var o,i=fa(n);try{for(i.s();!(o=i.n()).done;)if(!(r=la(o.value.definition,e,t)))return r}catch(e){i.e(e)}finally{i.f()}}catch(e){_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Error thrown in validation: "+e)}return r}(e,this)){if(ba(e,this),r||ga(e,this,!0),this.handlers.propertyListener){var i=this._convertObjectStructure(n,t);this.handlers.propertyListener({action:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.A.UPDATE_PROPERTY,property:n,value:i})}}else this.propertiesStore.updatePropertyValue(n,o)}},{key:"getPropertyValue",value:function(e,t,r){var n=this.convertPropertyId(e),o=this.propertiesStore.getPropertyValue(n),i=r,a=t&&(t.filterHiddenDisabled||t.filterHidden),s=t&&(t.filterHiddenDisabled||t.filterDisabled);if(a||s){var l=this.getControlState(n);if(l===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED&&s||l===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN&&a)return i;if(i=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.i)(o),Array.isArray(i))for(var u=0;u<i.length;u++){var c=i[u];if(Array.isArray(c))for(var p=0;p<c.length;p++){var d={name:n.name,row:u,col:p},f=this.getControlState(d);(f===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED&&s||f===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN&&a)&&(i[u][p]=null)}}return t&&!0===t.applyProperties?this._convertObjectStructure(n,i):i}return t&&!0===t.applyProperties?this._convertObjectStructure(n,o):o}},{key:"removePropertyValue",value:function(e){var t=this.convertPropertyId(e);this.propertiesStore.removePropertyValue(t)}},{key:"_convertObjectStructure",value:function(e,t){var r=this.getControl(e);if((0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.r)(r)){var n=r.structureType&&"object"===r.structureType;return (0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.v)(r.valueDef.isList,r.subControls,t,n)}return t}},{key:"getPropertyValues",value:function(e){var t=this.propertiesStore.getPropertyValues(),r=t;if(e&&(e.filterHiddenDisabled||e.filterHidden||e.filterDisabled)){var n={};for(var o in t)if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(t,o)){var i=this.getPropertyValue({name:o},e);void 0!==i&&(n[o]=i)}r=n}if(e&&!0===e.applyProperties)for(var a in r)if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(r,a)){var s=this.convertPropertyId(a),l=this.propertiesStore.getPropertyValue(s);r[a]=this._convertObjectStructure(s,l)}return r}},{key:"setPropertyValues",value:function(e,t){var r=this,n=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(e);if(e){var o=this.getControls();Object.keys(n).forEach((function(t){if((0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.r)(o[t])){var r=e[t],i=o[t],a=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.u)(i.valueDef.isList,i.subControls,r);n[t]=a}}))}if(this.propertiesStore.setPropertyValues(n),t){var i={};(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(n)||(Object.keys(n).forEach((function(e){!function(e,t,r){if(!t.getControl(e))return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Control not found for "+e.name),null;var n=t.getDefinitions(e,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.h.CONDITIONALDEFAULT,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.i.CONTROLS);if(n.length>0)try{var o,i=fa(n);try{for(i.s();!(o=i.n()).done;){var a=o.value,s=a.definition.default_value.parameter_ref;s in r||la(a.definition,e,t)&&(r[s]=a.definition.default_value.value)}}catch(e){i.e(e)}finally{i.f()}}catch(e){_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Error thrown in validation: "+e)}}({name:e},r,i)})),(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(i)||Object.keys(i).forEach((function(e){if(!(e in n)){var t=r.getControl({name:e});(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.r)(t)&&(i[e]=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.u)(t.valueDef.isList,t.subControls,i[e])),r.propertiesStore.updatePropertyValue({name:e},i[e])}})))}va(this),this.handlers.propertyListener&&this.handlers.propertyListener({action:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.A.SET_PROPERTIES})}},{key:"setControlStates",value:function(e){this.propertiesStore.setControlStates(e)}},{key:"updateControlState",value:function(e,t){var r=this.convertPropertyId(e);this.propertiesStore.updateControlState(r,t)}},{key:"getControlState",value:function(e){var t=this.propertiesStore.getControlState(e);return t?t.value:""}},{key:"getControlStates",value:function(){return this.propertiesStore.getControlStates()}},{key:"getControlValueStates",value:function(e){var t=this.propertiesStore.getControlState(e);return t?t.values:{}}},{key:"getControlEnumFilterStates",value:function(e){var t=this.propertiesStore.getControlState(e);return t?t.enumFilter:{}}},{key:"setPanelStates",value:function(e){this.propertiesStore.setPanelStates(e)}},{key:"updatePanelState",value:function(e,t){this.propertiesStore.updatePanelState(e,t)}},{key:"getPanelState",value:function(e){return this.propertiesStore.getPanelState(e)}},{key:"getPanelStates",value:function(){return this.propertiesStore.getPanelStates()}},{key:"setActionStates",value:function(e){this.propertiesStore.setActionStates(e)}},{key:"updateActionState",value:function(e,t){this.propertiesStore.updateActionState(e,t)}},{key:"getActionState",value:function(e){return this.propertiesStore.getActionState(e)}},{key:"getActionStates",value:function(){return this.propertiesStore.getActionStates()}},{key:"getAction",value:function(e){return this.actions[e.name]}},{key:"setErrorMessages",value:function(e){this.propertiesStore.setErrorMessages(e)}},{key:"getErrorMessage",value:function(e){var t=arguments.length>1&&void 0!==arguments[1]&&arguments[1],r=arguments.length>2&&void 0!==arguments[2]&&arguments[2],n=!(arguments.length>3&&void 0!==arguments[3])||arguments[3],o=this.convertPropertyId(e);if(t){var i=this.getControlState(o);if(i===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED||i===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN)return null}var a=this.propertiesStore.getErrorMessage(o,this.reactIntl);return r&&a&&a.type===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.SUCCESS||n&&a&&!ei(a.displayError)&&!a.displayError?null:a}},{key:"getErrorMessages",value:function(e,t,r){var n=!(arguments.length>3&&void 0!==arguments[3])||arguments[3],o=this.propertiesStore.getErrorMessages();return n&&(o=this._filterDisplayErrors(o)),(e||t)&&(o=this._filterMessages(o,e,t,r)),o}},{key:"getAllErrorMessages",value:function(){return this.getErrorMessages(!1,!1,!1,!1)}},{key:"getRequiredErrorMessages",value:function(){var e=this.propertiesStore.getErrorMessages(),t=this._filterNonRequiredErrors(e);return this._filterHiddenDisabledErrors(t)}},{key:"_filterMessages",value:function(e,t,r,n){var o={},i=[];for(var a in e)if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(e,a)){var s=this.getErrorMessage({name:a},r,n);s&&s.text&&(t?i.push({id_ref:a,validation_id:s.validation_id,type:s.type,text:s.text}):o[a]=s)}return t?i:o}},{key:"_filterDisplayErrors",value:function(e){return this._filterErrors(e,(function(e){return ei(e.displayError)||e.displayError}))}},{key:"_filterNonRequiredErrors",value:function(e){return this._filterErrors(e,(function(e){return!0===e.required}))}},{key:"_filterHiddenDisabledErrors",value:function(e){var t=this;return this._filterErrors(e,(function(e,r){var n=t.getControlState(r);return"hidden"!==n&&"disabled"!==n}))}},{key:"_filterErrors",value:function(e,t){var r={};return Object.keys(e).forEach((function(n){var o=e[n];if(o.text&&t(o,o.propertyId))r[n]=o;else for(var i in o)if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(o,i)){var a=o[i];if(a&&a.text&&t(a,a.propertyId))void 0===r[n]&&(r[n]={}),r[n][i]=a;else for(var s in a)if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(a,s)){var l=a[s];l&&l.text&&t(l,l.propertyId)&&(void 0===r[n]&&(r[n]={}),void 0===r[n][i]&&(r[n][i]={}),r[n][i][s]=l)}}})),r}},{key:"updateErrorMessage",value:function(e,t){var r=this.convertPropertyId(e);t&&"info"!==t.type?this.propertiesStore.updateErrorMessage(r,t):this.propertiesStore.clearErrorMessage(r)}},{key:"removeErrorMessageRow",value:function(e){var t=this.convertPropertyId(e),r=this.propertiesStore.getErrorMessages(),n=r[t.name];if(void 0!==n){for(var o=0,i=Object.keys(n);o<i.length;o++){var a=i[o],s=parseInt(a,10);s===t.row?delete r[t.name][s]:s>t.row&&(r=this._moveMessageRows(r,t.name,s,s-1))}this.setErrorMessages(r)}}},{key:"moveErrorMessageRows",value:function(e,t,r){var n=this.propertiesStore.getErrorMessages(),o=n[e];if(void 0!==o){var i=o[t],a=o[r];if(void 0!==i&&void 0!==a){(n=this._moveMessageRows(n,e,t,r))[e][t]={};for(var s=0,l=Object.keys(a);s<l.length;s++){var u=l[s];n[e][t][u]=a[u]}}else void 0!==i?n=this._moveMessageRows(n,e,t,r):void 0!==a&&(n=this._moveMessageRows(n,e,r,t));this.setErrorMessages(n)}}},{key:"_moveMessageRows",value:function(e,t,r,n){return e[t][n]=e[t][r],delete e[t][r],e}},{key:"saveControls",value:function(e){var t=this;e.forEach((function(e){void 0===e.columnIndex?(!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(t.controls,e.name)||(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(t.controls,e.name)&&e.controlType!==_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.C.CUSTOM)&&(t.controls[e.name]=e):t.controls[e.parameterName][e.columnIndex]=e}))}},{key:"getControl",value:function(e){var t=this.controls[e.name];if(void 0!==e.col&&t){var r=this.controls[e.name][e.col.toString()];if(r)return r}return t}},{key:"getControlPropType",value:function(e){var t=this.getControl(e);return void 0!==t.valueDef?t.valueDef.propType:null}},{key:"updateControlEnumValues",value:function(e,t){var r=this.getControl(e);Array.isArray(t)&&r?(r.values=t.map((function(e){return e.value})),r.valueLabels=t.map((function(e){return e.label?e.label:e.value}))):_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("properties-controller",new Error("updateControlEnumValues - control not found or valuesObj not valid"))}},{key:"getControls",value:function(){return this.controls}},{key:"setSaveButtonDisable",value:function(e){this.propertiesStore.setSaveButtonDisable(e)}},{key:"getSaveButtonDisable",value:function(){return this.propertiesStore.getSaveButtonDisable()}},{key:"isRequired",value:function(e){var t=this.getControl(e);if(t){var r=t.required;return r||!1}return!1}},{key:"isSummary",value:function(e){var t=this.getControl(e);if(t){var r=t.summary;return r||!1}return!1}},{key:"getControlType",value:function(e){var t=this.getControl(e);return t?t.controlType:null}},{key:"_parseSummaryControls",value:function(e){var t={};e.forEach((function(e){e.summaryPanelId&&(void 0===t[e.summaryPanelId]&&(t[e.summaryPanelId]=[]),void 0===e.columnIndex&&t[e.summaryPanelId].push(e.name))})),this.setSummaryPanelControls(t)}},{key:"setSummaryPanelControls",value:function(e){this.summaryPanelControls=e}},{key:"getSummaryPanelControls",value:function(e){return this.summaryPanelControls[e]}},{key:"updateCustPropSumPanelValue",value:function(e,t){void 0!==e.name&&(this.custPropSumPanelValues[e.name]=t)}},{key:"getCustPropSumPanelValue",value:function(e){var t=this.getControlState(e);return t===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.DISABLED||t===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.S.HIDDEN?null:this.custPropSumPanelValues[e.name]}},{key:"setControlInSummary",value:function(e,t,r){var n=this.getControl(e);n&&(n.summary=!0,n.summaryLabel=t)}},{key:"createControl",value:function(e,t,r){var n=this.controlFactory.createFormControl(t,r),o=[];return Ai(o,n,this.getControl(e).parentCategoryId),this.saveControls(o),this.controlFactory.createControlItem(n,e)}},{key:"getControlFactory",value:function(){return this.controlFactory}},{key:"setCustomControls",value:function(e){this.customControls=e}},{key:"getCustomControl",value:function(e,t,r){if(t.customControlId){var n,o=cc(this.customControls);try{for(o.s();!(n=o.n()).done;){var i=n.value;if(i.id()===t.customControlId)try{return new i(e,this,t.data,r).renderControl()}catch(e){return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Error thrown creating custom control: "+e),""}}}catch(e){o.e(e)}finally{o.f()}}return"Custom control not found: "+t.customControlId}},{key:"getMaxLengthForMultiLineControls",value:function(){return void 0!==this.getPropertiesConfig().maxLengthForMultiLineControls?this.getPropertiesConfig().maxLengthForMultiLineControls:1024}},{key:"getMaxLengthForSingleLineControls",value:function(){return void 0!==this.getPropertiesConfig().maxLengthForSingleLineControls?this.getPropertiesConfig().maxLengthForSingleLineControls:128}},{key:"setInitialAddRemoveRows",value:function(){var e=this;Object.keys(this.controls).forEach((function(t){var r=e.controls[t];if(r.valueDef&&r.valueDef.propType===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.T.STRUCTURE&&!ei(r.addRemoveRows)){var n={name:r.name};e.setAddRemoveRows(n,r.addRemoveRows)}}))}},{key:"setAddRemoveRows",value:function(e,t){this.propertiesStore.setAddRemoveRows(e,t)}},{key:"getAddRemoveRows",value:function(e){return this.propertiesStore.getAddRemoveRows(e)}},{key:"setHideEditButton",value:function(e,t){this.propertiesStore.setHideEditButton(e,t)}},{key:"getHideEditButton",value:function(e){return this.propertiesStore.getHideEditButton(e)}},{key:"getStaticRows",value:function(e){var t=this.convertPropertyId(e);return this.propertiesStore.getStaticRows(t)}},{key:"updateStaticRows",value:function(e,t){var r=this.convertPropertyId(e),n=this.getPropertyValue(e),o=t.sort();this.validateSelectionValues(o,n)&&this.propertiesStore.updateStaticRows(r,o)}},{key:"clearStaticRows",value:function(e){var t=this.convertPropertyId(e);this.propertiesStore.clearStaticRows(t)}},{key:"setInitialTableButtonState",value:function(){var e=this;Object.keys(this.controls).forEach((function(t){var r=e.controls[t],n={name:r.name};ei(r.buttons)||r.buttons.forEach((function(t){e.setTableButtonEnabled(n,t.id,t.enabled||!1)})),r.subControls&&e.setInitialTableButtonSubControlState(n,r.subControls)}))}},{key:"setInitialTableButtonSubControlState",value:function(e,t){var r=this;t.forEach((function(t){var n=r.getPropertyValue(e);ei(t.buttons)||n.forEach((function(n,o){var i={name:e.name,row:o,col:t.columnIndex};t.buttons.forEach((function(e){r.setTableButtonEnabled(i,e.id,e.enabled||!1)}))}))}))}},{key:"setTableButtonEnabled",value:function(e,t,r){this.propertiesStore.setTableButtonEnabled(e,t,r)}},{key:"getTableButtons",value:function(e){return this.propertiesStore.getTableButtons(e)}},{key:"getTableButtonEnabled",value:function(e,t){return this.propertiesStore.getTableButtonEnabled(e,t)}},{key:"validateSelectionValues",value:function(e,t){var r=!1;e&&t.length>0?r=!(!e.slice(1).map((function(t,r){return t-e[r]})).every((function(e){return 1===e}))||!(e.includes(0)&&!e.includes(t.length-1)||!e.includes(0)&&e.includes(t.length-1))):r=!1;return r}}]),r}(),fc={$schema:"https://json-schema.org/draft-04/schema#",id:"https://api.dataplatform.ibm.com/schemas/common-canvas/parameter-defs/parameter-defs-v3-schema.json",title:"Property Definitions Schema",description:"Watson Data Platform Property Definition Schema for the Common Properties editor",type:"object",properties:{titleDefinition:{type:"object",properties:{title:{type:"string"},editable:{description:"True if the title can be edited. False if the title should be readonly.",default:!0,type:"boolean"}}},current_parameters:{description:"Current parameter set upon input. Keys are parameter names, values are their values.",type:"object",properties:{},additionalProperties:!0},current_ui_parameters:{description:"Current UI only parameter set upon input. Keys are parameter names, values are their values.",type:"object",properties:{},additionalProperties:!0},parameters:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/operators/operator-v3-schema.json#/properties/parameters"},complex_types:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/operators/operator-v3-schema.json#/properties/complex_types"},uihints:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/operators/uihints-v3-schema.json#"},conditions:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/operators/conditions-v3-schema.json#/properties/conditions"},dataset_metadata:{oneOf:[{description:"A single datarecord object. Deprecated.",$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/datarecord-metadata/datarecord-metadata-v3-schema.json#"},{description:"An array of datarecord objects",type:"array",items:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/datarecord-metadata/datarecord-metadata-v3-schema.json#"}}]},resources:{description:"Map of string resources.",type:"object",properties:{},additionalProperties:!0}}},hc={$schema:"https://json-schema.org/draft-04/schema#",id:"https://api.dataplatform.ibm.com/schemas/common-pipeline/operators/uihints-v3-schema.json#",description:"WDP UI Hints schema",title:"WDP UI Hints schema",type:"object",properties:{id:{description:"Operator identifier",type:"string"},json_schema:{description:"Refers to the JSON schema used to validate documents of this type",enum:["https://api.dataplatform.ibm.com/schemas/common-pipeline/operators/uihints-v3-schema.json"]},label:{description:"External name of operator",type:"object",$ref:"#/definitions/resource_definition"},description:{description:"Description of operator",type:"object",$ref:"#/definitions/resource_definition"},icon:{description:"URL to operation icon",type:"string"},group_info:{type:"array",items:{$ref:"#/definitions/group_definition"}},editor_size:{description:"Editor size for node edits",enum:["small","medium","large"]},pixel_width:{description:"Gives more control of editor panel width. The panel is shown at min size if editor_size is small and max size if editor_size is medium. If min and max are the same no sizing button is displayed.",type:"object",properties:{min:{description:"Minimum size in pixels for the right side editor flyout",type:"number"},max:{description:"Maximum size in pixels for the right side editor flyout",type:"number"}}},parameter_info:{items:{$ref:"#/definitions/parameter_definition"},type:"array"},complex_type_info:{items:{$ref:"#/definitions/complex_type_definition"},type:"array"},ui_parameters:{description:"List of UI only parameters",type:"array",items:{$ref:"https://api.dataplatform.ibm.com/schemas/common-pipeline/operators/operator-v3-schema.json#/definitions/parameter_definition"}},action_info:{items:{$ref:"#/definitions/action_definition"},type:"array"},help:{description:"Help information",type:"object",properties:{data:{description:"Data passed in the helpClickHandler.",type:"object",additionalProperties:!0}},additionalProperties:!0}},required:["id"],definitions:{group_definition:{description:"Grouping for parameters and groups",type:"object",properties:{id:{description:"Identifier for this group",type:"string"},type:{description:"The group type to be displayed",type:"string",enum:["controls","tabs","subTabs","panels","columnSelection","columnSelectionRecursive","panelSelector","customPanel","summaryPanel","actionPanel","textPanel","twistyPanel","columnPanel"]},depends_on_ref:{description:"Parameter name this group depends upon. Valid for panelSelector groups only.",type:"string"},insert_panels:{description:"Indicates whether panels, contained with a panelSelector, should be inserted between the radio buttons of a radio button set indicated by the depends_on_ref parameter.",type:"boolean"},nested_panel:{description:"Indicate whether panel should be nested. Nested panels are indented by 16px from the left and display left border. Default is false.",type:"boolean"},open:{description:"Used to determine if a panel is open or closed when UI is displayed.  Currenty only supported with twistyPanel. Default is false.",type:"boolean"},label:{description:"Group label",type:"object",$ref:"#/definitions/resource_definition"},description:{description:"Group description. Used in a textPanel",type:"object",$ref:"#/definitions/resource_definition"},parameter_refs:{description:"List of parameters to be displayed",type:"array",items:{type:"string"}},action_refs:{description:"List of actions to be displayed.  Used with an actionPanel",type:"array",items:{type:"string"}},data:{description:"Data passed to custom panel when group type is 'customPanel'",additionalProperties:!0,oneOf:[{type:"object"},{type:"array"}]},group_info:{items:{$ref:"#/definitions/group_definition"},type:"array"},class_name:{description:"Optional class name to set for this group",type:"string"}},required:["id"]},parameter_definition:{description:"Operator parameters hints",type:"object",properties:{parameter_ref:{description:"Parameter reference to base operator parameter definition",type:"string"},label:{description:"External name for parameter",type:"object",$ref:"#/definitions/resource_definition"},label_visible:{description:"Whether to display the label or not. If not displayed, the label can still be used by screen readers",type:"boolean",default:!0},description:{description:"Description of parameter with optional placement context and optional link",type:"object",allOf:[{$ref:"#/definitions/resource_definition"},{properties:{placement:{description:"Optional placement context for the text",enum:["as_tooltip","on_panel"],default:"as_tooltip"},link:{description:"Optional link in the description. tooltipLinkHandler callback must be defined whenever link object is added in uiHints.",type:"object",properties:{id:{description:"link id",type:"string"},data:{description:"Data passed to the tooltipLinkHandler callback",type:"object",additionalProperties:!0}},required:["id"]}}}]},control:{description:"Which control to use.  In most cases the control gets to be determined and should not be set",type:"string",enum:["readonly","readonlyTable","textfield","passwordfield","textarea","expression","numberfield","spinner","checkbox","radioset","checkboxset","toggletext","oneofselect","multiselect","someofselect","selectcolumn","selectcolumns","selectschema","structuretable","structurelisteditor","structureeditor","custom","datefield","timefield","timestampfield","code","list","hidden"]},increment:{description:"Determines the increment/decrement value for the spinner control only",type:"number",default:1},orientation:{description:"Determines how the control is displayed",type:"string",enum:["vertical","horizontal"]},width:{description:"Percentage of group width the control should use",type:"number"},char_limit:{description:"Limits the number of characters a user can enter into the control for string parameters only",type:"number"},display_chars:{description:"This has been deprecated and is subject to removal. Limits the number of characters displayed for a text field in a column in a table.  The text will have an ellipsis appended at this limit.",type:"number",default:64},separator:{description:"Determines where to put a separator relative to the current control",type:"string",enum:["before","after"]},visible:{description:"Determines whether to display parameter in control. Used in complex structures",type:"boolean"},place_holder_text:{description:"Text hint for the user displayed input controls",type:"object",$ref:"#/definitions/resource_definition"},text_before:{description:"Static text to be displayed before the control",type:"object",$ref:"#/definitions/text_definition"},text_after:{description:"Static text to be displayed after the control",type:"object",$ref:"#/definitions/text_definition"},resource_key:{description:"Used as a key for enum value labels",type:"string"},edit_style:{description:"Editing style of elements in a table",type:"string",enum:["subpanel","inline","on_panel"]},value_icons:{description:"For enumerated types, this defines the set of icons for the valid values. The ordering must be consistent with the order in the parameter enum attribute.",type:"array",items:{type:"string"}},sortable:{description:"Determines if this column values can be sorted into ascending/descending order in a table. Applies to structure parameters only.",type:"boolean"},filterable:{description:"Determines if this column values can be filtered so that only rows that match the filter in column values are shown in the table. Applies to structure parameters and multiselect control only.",type:"boolean"},resizable:{description:"Determines if this column can be resized in a table. When a column is resized, width of all the columns to the right of resized column is adjusted. Applies to structure parameters only.",type:"boolean",default:!1},language:{description:"The language for the expression editor syntax highlight and autocomplete workds. Applies to expression control type.",type:"string",enum:["CLEM","javascript","text/x-hive","text/x-rsrc","text/x-python"]},summary:{description:"Determines if this column values will be shown in the summaryPanel",type:"boolean"},generated_values:{description:"Generates values for a column in a 'readonly' parameter.",type:"object",properties:{operation:{description:"Currently only 'index' is supported which will auto-increment the integer column value starting at 1. The start value can be configured by setting a start_value.",type:"string",enum:["index"]},start_value:{description:"Optional start value to increment from when the 'type' is 'index'. If the start_value is not set, it will default to 1.",type:"integer"}},required:["operation"]},number_generator:{description:"Adds a number generation button beside the numeric control",type:"object",properties:{label:{description:"Number generator button label. It is visible on hover.",type:"object",$ref:"#/definitions/resource_definition"},range:{description:"Number generator range",type:"object",properties:{min:{description:"Maximum value for generated numbers",type:"number"}},required:["min","max"]}},required:["label"]},dm_default:{description:"Used within complex structures containing 'column' key_definition fields. This associates the subControl parameter with a field attribute in the current record schema.",type:"string",enum:["type","description","measure","modeling_role"]},dm_icon:{description:"This can be set to display an icon of the corresponding dm type in the `role`:`column' field of a table.",type:"string",enum:["measure","none"]},custom_control_id:{description:"Used to determine which custom control to use when control=custom.",type:"string"},data:{description:"Data passed to custom control when control=custom",type:"object",additionalProperties:!0},date_format:{description:"A format string such as YYYY-MM-DD which describes the display and entry format for a date field.",type:"string"},time_format:{description:"A format string such as HH:mm:ss which describes the display and entry format for a time field.",type:"string"},moveable_rows:{description:"Determines if rows can be moved up or down in a table or array of strings",type:"boolean"},rows:{description:"Number of rows to display in tables",type:"integer",default:4},action_ref:{description:"Determines an action should be added to the control",type:"string"},custom_value_allowed:{description:"Determines if a dropdown, outside of a table, can allow a custom value to be entered",type:"boolean"},class_name:{description:"Optional class name to set for this control",type:"string"}},required:["parameter_ref"]},complex_type_definition:{type:"object",description:"Complex parameters",properties:{complex_type_ref:{type:"string",description:"Name of complex type, can be referenced in other places."},label:{description:"External name used in subpanels",type:"object",$ref:"#/definitions/resource_definition"},key_definition:{$ref:"#/definitions/parameter_definition"},layout:{description:"Array of rows containing structure element names",type:"array",items:{description:"A single row of structure parameter names for laying out horizontally",type:"array",items:{description:"A parameter name within the current structure",type:"string"}}},parameters:{type:"array",description:"List of parameters",items:{anyOf:[{$ref:"#/definitions/parameter_definition"},{$ref:"#/definitions/complex_type_definition"}]}},add_remove_rows:{description:"Determines if the table can have rows added and removed",type:"boolean",default:!0},row_selection:{description:"Determines how many rows can be selected at a time.  'multiple-edit': select multiple rows and allow the editing of column values for all selected rows.",type:"string",enum:["single","multiple","multiple-edit"]},header:{description:"Determines if the table header should be displayed",type:"boolean",default:!0},include_all_fields:{description:"Use when `add_remove_rows` is false. Ensures the control contains a record for each field in the data model.",type:"boolean",default:!0},buttons:{description:"Display custom buttons in place of any buttons from the table. Will override 'add_remove_rows' and readonlyTable edit buttons.",type:"array",items:{$ref:"#/definitions/button_definition"}}},required:["complex_type_ref","parameters"]},action_definition:{description:"Actions that callback to application",type:"object",properties:{id:{description:"Identifier for this action",type:"string"},description:{description:"Description of action.  Use for tooltip.",type:"object",$ref:"#/definitions/resource_definition"},control:{description:"The action type to be displayed",type:"string",enum:["button","image"]},label:{description:"Action label",type:"object",$ref:"#/definitions/resource_definition"},button:{description:"Properties for button kind and size. Use when control=button.",type:"object",properties:{kind:{description:"button kind",type:"string",enum:["primary","secondary","tertiary","ghost","danger","danger--tertiary","danger--ghost"],default:"tertiary"},size:{description:"button size",enum:["sm","md","lg","xl"],default:"sm"}}},image:{description:"Properties for how the image will look.  Use when control=image.",type:"object",properties:{url:{description:"image url to be used for action",type:"string"},placement:{description:"placement of the action image",enum:["right","left"]},size:{description:"pixel size of the image.",type:"object",properties:{height:{description:"image height in pixels",type:"number"},width:{description:"image width in pixels",type:"number"}}},tooltip_direction:{description:"Action image tooltip direction.",enum:["right","left","top","bottom"],default:"bottom"}}},data:{description:"Data returned when action called",type:"object",additionalProperties:!0}},required:["id"]},resource_definition:{description:"Localizable string resource",type:"object",properties:{default:{type:"string"},resource_key:{type:"string"}},anyOf:[{required:["default"]},{required:["resource_key"]}]},text_definition:{description:"Static text to be displayed before or after the control",type:"object",allOf:[{$ref:"#/definitions/resource_definition"},{properties:{type:{description:"Type of text message to display",enum:["info"]}}}]},button_definition:{description:"Button to be displayed after the table's search bar",type:"object",properties:{id:{description:"Button identifier used to idenify the button in the callback function",type:"string"},label:{description:"Button label to display. If an icon is specified as well, the icon will be shown to the right of the label.",type:"object",$ref:"#/definitions/resource_definition"},description:{description:"Tooltip text to display when the button is hovered",type:"object",$ref:"#/definitions/resource_definition"},icon:{description:"URL to .svg image to display",type:"string"},carbon_icon:{description:"Host provided name of Carbon icon to display. A callback function is required for the host application to return the jsx icon object imported from @carbon/icons-react library",type:"string"},enabled:{description:"Button will be enabled if true, disabled if false",type:"boolean",default:!1},divider:{description:"Display a divider before or after this button",type:"string",enum:["before","after"],default:"after"}},anyOf:[{required:["id","label"]},{required:["id","icon","description"]},{required:["id","carbon_icon","description"]}]}}},mc={$schema:"https://json-schema.org/draft-04/schema#",id:"https://api.dataplatform.ibm.com/schemas/common-pipeline/operators/conditions-v3-schema.json#",title:"Watson Data Platform Validation Schema",description:"User Interface Condition schema for the Watson Data Platform",type:"object",properties:{json_schema:{description:"Refers to the JSON schema used to validate documents of this type",enum:["https://api.dataplatform.ibm.com/schemas/common-pipeline/operators/conditions-v3-schema.json"]},conditions:{type:"array",items:{$ref:"#/definitions/conditions_definition"}}},required:["conditions"],definitions:{conditions_definition:{type:"object",oneOf:[{$ref:"#/definitions/validation_definition"},{$ref:"#/definitions/enabled_definition"},{$ref:"#/definitions/visible_definition"},{$ref:"#/definitions/filter_definition"},{$ref:"#/definitions/enum_filter_definition"},{$ref:"#/definitions/allow_change_definition"},{$ref:"#/definitions/default_value_definition"}]},validation_definition:{properties:{validation:{description:"A single validation. The fail_message is displayed upon validation failure.",type:"object",properties:{id:{description:"Unique identifier.  Required when multiple fail_message sections have the same focus_parameter_ref value.",type:"string"},fail_message:{description:"Error/warning",type:"object",$ref:"#/definitions/fail_message_definition"},evaluate:{description:"Evaluates to a boolean result",type:"object",$ref:"#/definitions/evaluate_definition"}},required:["fail_message","evaluate"]}},required:["validation"]},enabled_definition:{properties:{enabled:{description:"Enablement test. Disables controls if evaluate is false.",type:"object",properties:{parameter_refs:{description:"Array of parameter names affected by this operation",type:"array",minItems:1,items:{type:"string"},uniqueItems:!0},values:{description:"Optional array of enumeration item names to operate upon",type:"array",minItems:1,items:{type:"string"},uniqueItems:!0},group_refs:{description:"Array of group ids affected by this operation",type:"array",minItems:1,items:{type:"string"},uniqueItems:!0},action_refs:{description:"Array of action ids affected by this operation",type:"array",minItems:1,items:{type:"string"},uniqueItems:!0},evaluate:{description:"Evaluates to a boolean result",type:"object",$ref:"#/definitions/evaluate_definition"}},anyOf:[{required:["parameter_refs"]},{required:["group_refs"]},{required:["action_refs"]}],required:["evaluate"]}},required:["enabled"]},visible_definition:{properties:{visible:{description:"Visibility test. Hides controls if evaluate is false.",type:"object",properties:{parameter_refs:{description:"Array of parameter names affected by this operation",type:"array",minItems:1,items:{type:"string"},uniqueItems:!0},values:{description:"Optional array of enumeration item names to operate upon",type:"array",minItems:1,items:{type:"string"},uniqueItems:!0},group_refs:{description:"Array of group ids affected by this operation",type:"array",minItems:1,items:{type:"string"},uniqueItems:!0},action_refs:{description:"Array of action ids affected by this operation",type:"array",minItems:1,items:{type:"string"},uniqueItems:!0},evaluate:{description:"Evaluates to a boolean result",type:"object",$ref:"#/definitions/evaluate_definition"}},anyOf:[{required:["parameter_refs"]},{required:["group_refs"]},{required:["action_refs"]}],required:["evaluate"]}},required:["visible"]},evaluate_definition:{oneOf:[{$ref:"#/definitions/and_definition"},{$ref:"#/definitions/or_definition"},{$ref:"#/definitions/condition_definition"},{$ref:"#/definitions/filter_condition_definition"}]},or_definition:{description:"Container for 'or' operations",type:"object",properties:{or:{description:"The 'or' condition. Any sub-condition evaluates to true. Can nest any number of additional conditional types.",type:"array",items:{anyOf:[{$ref:"#/definitions/and_definition"},{$ref:"#/definitions/or_definition"},{$ref:"#/definitions/condition_definition"},{$ref:"#/definitions/filter_condition_definition"}]}}},required:["or"]},and_definition:{description:"Container for 'and' operations",type:"object",properties:{and:{description:"The 'and' condition. All sub-conditions evaluate to true. Can nest any number of additional conditional types.",type:"array",items:{anyOf:[{$ref:"#/definitions/and_definition"},{$ref:"#/definitions/or_definition"},{$ref:"#/definitions/condition_definition"},{$ref:"#/definitions/filter_condition_definition"}]}}},required:["and"]},condition_definition:{description:"A parameter condition. Evaluates to true or false.",type:"object",properties:{condition:{description:"The condition that is evaluated",type:"object",properties:{op:{description:"A single operator for the properties of the condition.",anyOf:[{enum:["isEmpty","isNotEmpty","greaterThan","lessThan","equals","notEquals","contains","notContains","colNotExists","cellNotEmpty","colDoesExist","isDateTime","dmTypeEquals","dmTypeNotEquals","dmMeasurementEquals","dmMeasurementNotEquals","dmRoleEquals","dmRoleNotEquals","matches","notMatches"]},{description:"The name of the custom operator",type:"string"}]},parameter_ref:{description:"The primary parameter - must be present",type:"string"},parameter_2_ref:{description:"Optional second parameter for multi-parameter validation",type:"string"},value:{description:"Optional value against which to compare the primary parameter value",oneOf:[{type:"string"},{type:"number"},{type:"boolean"},{type:"array"},{type:"null"}]}},required:["op","parameter_ref"]}},required:["condition"]},fail_message_definition:{properties:{focus_parameter_ref:{description:"The parameter control to get the error/warning message.",type:"string"},message:{description:"User message",type:"object",$ref:"#/definitions/message_definition"},type:{enum:["error","warning","info"]}},required:["focus_parameter_ref","message"]},message_definition:{description:"User message",type:"object",properties:{default:{type:"string"},resource_key:{type:"string"}},anyOf:[{required:["default"]},{required:["resource_key"]}]},filter_definition:{properties:{filter:{description:"Filter test. Includes support for filtering the values to be displayed in a control",type:"object",properties:{parameter_ref:{description:"Parameter affected by this operation",type:"string"},parameter_refs:{description:"Parameters affected by this operation - exclusive with parameter_ref",type:"array",items:{type:"string"}},evaluate:{description:"Evaluates to return values included in a control",type:"object",$ref:"#/definitions/evaluate_definition"}},oneOf:[{required:["evaluate","parameter_ref"]},{required:["evaluate","parameter_refs"]}]}},required:["filter"]},enum_filter_definition:{properties:{enum_filter:{description:"Allows filtering of available enumeration options",type:"object",properties:{target:{description:"The target parameter information",type:"object",properties:{parameter_ref:{description:"The enumeration parameter affected by this operation",type:"string"},values:{description:"Array of available enumeration options when the condition evaluates to 'true'",type:"array",minItems:1,uniqueItems:!0}},required:["parameter_ref","values"]},evaluate:{description:"Evaluates to return values included in an enumeration control",type:"object",$ref:"#/definitions/evaluate_definition"}},required:["target","evaluate"]}},required:["enum_filter"]},filter_condition_definition:{description:"Allows for filtering available fields in the data record schema(s)",type:"object",properties:{condition:{description:"The condition that is evaluated",type:"object",anyOf:[{properties:{op:{$ref:"#/definitions/filter_op_definition"},value:{description:"Value to compare against data record schema field attribute",type:"string"}},required:["op"]},{properties:{op:{$ref:"#/definitions/filter_op_definition"},values:{description:"Array of values which are compared to a data record schema field attribute",type:"array",minItems:1,items:{type:"string"},uniqueItems:!0}},required:["op","values"]}]}},required:["condition"]},filter_op_definition:{description:"A single operator for comparing data record schema field attributes and sharing source fields",enum:["dmMeasurement","dmType","dmModelingRole","dmSharedFields"]},allow_change_definition:{properties:{allow_change:{description:"Allow change test. Allows a field value to be changed if evaluates to true.",type:"object",properties:{parameter_refs:{description:"Array of parameter names who values changes are allowed by this operation",type:"array",minItems:1,items:{type:"string"},uniqueItems:!0},evaluate:{description:"Evaluates to a boolean result",type:"object",$ref:"#/definitions/evaluate_definition"}},required:["parameter_refs","evaluate"]}},required:["allow_change"]},default_value_definition:{properties:{default_value:{description:"Set default value of the parameter_ref if condition evaluates to true.",type:"object",properties:{parameter_ref:{description:"Parameter whose default value is to be set.",type:"string"},value:{description:"This will be the default value of parameter_ref if condition evaluates to true.",type:["number","string","boolean","object","array"]},evaluate:{description:"Evaluates to a boolean result",type:"object",$ref:"#/definitions/evaluate_definition"}},required:["parameter_ref","value","evaluate"]}},required:["default_value"]}}},vc={$schema:"https://json-schema.org/draft-04/schema#",id:"https://api.dataplatform.ibm.com/schemas/common-pipeline/operators/operator-v3-schema.json#",title:"Watson Data Platform Operator Schema",description:"Operator schema for the Watson Data Platform",type:"object",properties:{id:{description:"Operator identifier",type:"string"},json_schema:{description:"Refers to the JSON schema used to validate documents of this type",enum:["https://api.dataplatform.ibm.com/schemas/common-pipeline/operators/operator-v3-schema.json"]},operator_type:{description:"operator type",enum:["model","transformer","estimator","dataReader","dataWriter"]},input_ports:{description:"List of input ports. If no ports are defined this is a source operator that accepts no data inputs. If the input_ports array is missing a single input port with id 'input_port' is assumed which accepts only a single connection.",type:"array",minItems:0,items:{$ref:"#/definitions/port_definition"}},output_ports:{description:"List of output ports. If no ports are defined this is a terminal operator that provides no data outputs. If the output_ports array is missing a single output port named 'output_port' is assumed which accepts multiple connections.",type:"array",minItems:0,items:{$ref:"#/definitions/port_definition"}},complex_types:{description:"List of complex types",type:"array",items:{$ref:"#/definitions/complex_type_definition"}},parameters:{description:"List of parameters",type:"array",items:{$ref:"#/definitions/parameter_definition"}},app_data:{$ref:"#/definitions/app_data_def"}},required:["id","operator_type","parameters"],definitions:{parameter_definition:{description:"Operator parameters definition",type:"object",properties:{id:{description:"A unique name for the parameter.",type:"string"},required:{description:"Indication whether parameter is required or optional",type:"boolean",default:!1},role:{description:"Role of parameter",enum:["column","new_column","expression"]},type:{description:"Field type. Can be a primitive type (string, integer, double, date, time, timestamp, or custom), an array, or map containing those types(note arrays and maps can contain complex_types)",type:"string"},enum:{description:"List of valid values. Can be used instead of specifying type.",type:"array"},default:{description:"default value based on type of parameter",anyOf:[{$ref:"#/definitions/parameter_ref_definition"},{oneOf:[{type:"string"},{type:"number"},{type:"boolean"},{type:"array"},{type:"object"},{type:"null"}]}]}},anyOf:[{required:["id","type"]},{required:["id","enum"]},{required:["id","type","enum"]}]},parameter_ref_definition:{description:"Structure for parameter refs",type:"object",properties:{parameter_ref:{description:"Reference to another parameter.",type:"string"}},required:["parameter_ref"]},complex_type_definition:{description:"Structure for complex parameters",type:"object",properties:{id:{description:"Identifier of complex type, can be referenced in other places.",type:"string"},type:{description:"Used to determine how parameters in the complex_type stored. Valid values are array and object.",type:"string"},key_definition:{$ref:"#/definitions/parameter_definition"},parameters:{description:"List of parameters",type:"array",items:{anyOf:[{$ref:"#/definitions/parameter_definition"},{$ref:"#/definitions/complex_type_definition"}]}}},required:["id","parameters"]},port_definition:{description:"Operator ports support multiple differentiated connections for either inputs or outputs.",type:"object",properties:{id:{description:"Unique identifier within the node",type:"string"},cardinality:{description:"Property to capture how many connections are allowed for this port, e.g., min: 1, max:1 implies you must supply 1 and only 1; min:0, max:1 implies it is optional and a max of one, min:0, max:-1 means it is optional and you can may have any number of connections. The default value is 1:1 for inputs and 1:-1 for outputs.",type:"object",properties:{min:{description:"Minimum data sets that are required for this port",type:"integer",default:1},max:{description:"Maximum data sets that are allowed on this port. A negative value indicates unlimited. The default value is 1 for inputs and -1 for outputs.",type:"integer"}},additionalProperties:!1},parameters:{description:"List of parameters",type:"array",items:{$ref:"#/definitions/parameter_definition"}},complex_types:{description:"List of complex types",type:"array",items:{$ref:"#/definitions/complex_type_definition"}}}},app_data_def:{description:"Object containing application-specific data",type:"object",properties:{},additionalProperties:!0}}};function yc(e){var t=function(){var e=new jsonschema__WEBPACK_IMPORTED_MODULE_7__.Validator,t="https://api.dataplatform.ibm.com/schemas/common-canvas/",r="https://api.dataplatform.ibm.com/schemas/common-pipeline/";return e.addSchema(fc,t+"parameter-defs/pipeline-flow-v3-schema.json"),e.addSchema(hc,r+"operators/uihints-v3-schema.json"),e.addSchema(mc,r+"operators/conditions-v3-schema.json"),e.addSchema(vc,r+"operators/operator-v3-schema.json"),e.addSchema(_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_9__.d,r+"datarecord-metadata/datarecord-metadata-v3-schema.json"),e}();!function(e,t,r,n){var o=n.validate(e,t,{nestedErrors:!0});o&&o.errors&&o.errors.length>0&&console.error(o)}(e,fc,0,t)}function gc(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var bc=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(u,react__WEBPACK_IMPORTED_MODULE_0__.Component);var o=gc(u);function u(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,u),(r=o.call(this,t)).state={focused:!1,titleValidation:null},r.editTitleClickHandler=r.editTitleClickHandler.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.helpClickHandler=r.helpClickHandler.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.id=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.w)(),r.textInputRef=react__WEBPACK_IMPORTED_MODULE_0___default().createRef(),r.labelText=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(t.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.TITLE_EDITOR_LABEL),r.textInputOnFocus=r.textInputOnFocus.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.textInputOnBlur=r.textInputOnBlur.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.headingEnabled=r.props.showHeading&&(r.props.heading||r.props.icon),r.handleTitleChange=r.handleTitleChange.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.titleChangeHandler=r.props.controller.getHandlers().titleChangeHandler,r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(u,[{key:"_handleKeyPress",value:function(e){"Enter"===e.key&&this.textInputRef.current.blur()}},{key:"editTitleClickHandler",value:function(){this.textInputRef.current.focus()}},{key:"helpClickHandler",value:function(){this.props.helpClickHandler&&this.props.helpClickHandler(this.props.controller.getForm().componentId,this.props.help.data,this.props.controller.getAppData())}},{key:"textInputOnFocus",value:function(){this.setState({focused:!0})}},{key:"textInputOnBlur",value:function(){this.setState({focused:!1})}},{key:"handleTitleChange",value:function(e){var t=this;null!==this.state.titleValidation&&this.setState({titleValidation:null});var r=e.target.value;"function"==typeof this.titleChangeHandler&&this.titleChangeHandler(r,(function(e){e&&"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.d)(e)&&e.type&&e.message?t.setState({titleValidation:e}):t.setState({titleValidation:null})})),this.props.setTitle(r)}},{key:"render",value:function(){var e=this,t=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.TITLE_EDITOR_LABEL),r=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.TITLE_EDITOR_HELPBUTTON_LABEL),n=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.PROPERTIESEDIT_CLOSEBUTTON_LABEL),o=[_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.ERROR,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.WARNING],i=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.k)(this.state.titleValidation,"type",null)===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.WARNING,a=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.k)(this.state.titleValidation,"type",null)===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.d.ERROR,l=!1===this.props.labelEditable||this.state.focused?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null):react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{kind:"ghost",className:"properties-title-editor-btn edit","data-id":"edit",onClick:this.editTitleClickHandler,tooltipPosition:"bottom",tooltipAlignment:"end",renderIcon:_carbon_icons_react__WEBPACK_IMPORTED_MODULE_36__.Edit16,size:"small",iconDescription:t,hasIconOnly:!0}),u=this.props.help?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{kind:"ghost",className:"properties-title-editor-btn help","data-id":"help",onClick:this.helpClickHandler,tooltipPosition:"bottom",renderIcon:_carbon_icons_react__WEBPACK_IMPORTED_MODULE_53__.Information16,size:"small",iconDescription:r,hasIconOnly:!0}):null,c=this.props.closeHandler?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-close-button"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{kind:"ghost",size:"small","data-id":"close",onClick:this.props.closeHandler,tooltipPosition:"left",renderIcon:_carbon_icons_react__WEBPACK_IMPORTED_MODULE_54__.Close16,iconDescription:n,hasIconOnly:!0})):null,d=null;if(this.headingEnabled){var f=this.props.heading?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-title-heading-label"},this.props.heading):null,h=this.props.icon&&"string"==typeof this.props.icon?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_inlinesvg__WEBPACK_IMPORTED_MODULE_29__["default"],{className:"properties-title-heading-icon",src:this.props.icon}):null;(f||h)&&(d=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-title-heading"},h,f,u))}return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-title-editor",{"properties-title-with-heading":this.headingEnabled})},c,d,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-title-editor-input",{"properties-title-editor-with-help":this.props.help&&!this.headingEnabled&&!o.includes((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.k)(this.state.titleValidation,"type")),"properties-title-editor-with-warning":i,"properties-title-editor-with-error":a})},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_28__["default"],(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__._)({id:this.id,ref:this.textInputRef,value:this.props.title,onChange:this.handleTitleChange,onKeyPress:function(t){return e._handleKeyPress(t)},readOnly:!1===this.props.labelEditable,labelText:this.labelText,hideLabel:!0,size:"sm",onFocus:this.textInputOnFocus,onBlur:this.textInputOnBlur,light:this.props.controller.getLight(),invalid:a,invalidText:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.k)(this.state.titleValidation,"message"),warn:i,warnText:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.k)(this.state.titleValidation,"message")},this.state.focused&&{className:"properties-title-editor-focused"})),o.includes((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.k)(this.state.titleValidation,"type"))?null:l),this.headingEnabled||o.includes((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.k)(this.state.titleValidation,"type"))?null:u)}}]),u}(),Ec=(0,react_redux__WEBPACK_IMPORTED_MODULE_1__.connect)((function(e,t){return{title:e.componentMetadataReducer.title}}),(function(e,t){return{setTitle:function(t){e(Kr(t))}}}))(bc),Ic='/*\n * Copyright 2017-2022 Elyra Authors\n *\n * Licensed under the Apache License, Version 2.0 (the "License");\n * you may not use this file except in compliance with the License.\n * You may obtain a copy of the License at\n *\n * http://www.apache.org/licenses/LICENSE-2.0\n *\n * Unless required by applicable law or agreed to in writing, software\n * distributed under the License is distributed on an "AS IS" BASIS,\n * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n * See the License for the specific language governing permissions and\n * limitations under the License.\n */\n:export {\n  flyoutWidthSmall: 320px;\n  flyoutWidthMedium: 480px;\n  flyoutWidthLarge: 640px;\n}';function Sc(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Cc=parseInt(Ic.flyoutWidthSmall,10),Rc=parseInt(Ic.flyoutWidthMedium,10),_c=parseInt(Ic.flyoutWidthLarge,10),Tc=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=Sc(a);function a(t){var r;(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).propertiesController=new dc,r.propertiesController.setPropertiesConfig(r.props.propertiesConfig),r.props.propertiesInfo.initialEditorSize&&r.propertiesController.setEditorSize(r.props.propertiesInfo.initialEditorSize),r.propertiesController.setCustomControls(t.customControls),r.propertiesController.setConditionOps(t.customConditionOps),r.propertiesController.setLight(t.light),r.propertiesController.setAppData(t.propertiesInfo.appData),r.propertiesController.setExpressionInfo(t.propertiesInfo.expressionInfo),r.propertiesController.setHandlers({controllerHandler:t.callbacks.controllerHandler,propertyListener:t.callbacks.propertyListener,actionHandler:t.callbacks.actionHandler,buttonHandler:t.callbacks.buttonHandler,buttonIconHandler:t.callbacks.buttonIconHandler,validationHandler:t.callbacks.validationHandler,titleChangeHandler:t.callbacks.titleChangeHandler,tooltipLinkHandler:t.callbacks.tooltipLinkHandler}),r.setForm(t.propertiesInfo),r.previousErrorMessages={},r.propertiesController.validatePropertiesValues(!1),t.propertiesInfo.messages&&(r.propertiesController.validatePropertiesValues(!0),r.previousErrorMessages=r.propertiesController.getAllErrorMessages()),r.props.callbacks.propertyListener&&r.props.callbacks.propertyListener({action:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.A.PROPERTIES_LOADED}),r.currentParameters=r.propertiesController.getPropertyValues();var n=r.getEditorSize();return r.state={showPropertiesButtons:!0,editorSize:n},r.applyPropertiesEditing=r.applyPropertiesEditing.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.showPropertiesButtons=r.showPropertiesButtons.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.updateEditorSize=r.updateEditorSize.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.cancelHandler=r.cancelHandler.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r._getOverrideSize=r._getOverrideSize.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r._getResizeButton=r._getResizeButton.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r._isResizeButtonRequired=r._isResizeButtonRequired.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.onBlur=r.onBlur.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"componentDidMount",value:function(){this.props.callbacks.setPropertiesHasMounted()}},{key:"UNSAFE_componentWillReceiveProps",value:function(e){if(e.propertiesInfo&&(!(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(Object.keys(e.propertiesInfo),Object.keys(this.props.propertiesInfo))||e.propertiesInfo.formData&&!(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(e.propertiesInfo.formData,this.props.propertiesInfo.formData)||e.propertiesInfo.parameterDef&&!(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(e.propertiesInfo.parameterDef,this.props.propertiesInfo.parameterDef)||e.propertiesInfo.appData&&!(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.j)(e.propertiesInfo.appData,this.props.propertiesInfo.appData))){this.setForm(e.propertiesInfo);var t=this.propertiesController.getForm().editorSize;this.state.editorSize!==t&&this.setState({editorSize:t}),this.currentParameters=this.propertiesController.getPropertyValues(),this.propertiesController.setAppData(e.propertiesInfo.appData),this.propertiesController.setCustomControls(e.customControls),this.propertiesController.setConditionOps(e.customConditionOps),this.previousErrorMessages={},e.propertiesInfo.messages&&(this.propertiesController.validatePropertiesValues(),this.previousErrorMessages=this.propertiesController.getAllErrorMessages())}}},{key:"onBlur",value:function(e){!this.props.propertiesConfig.applyOnBlur||!this.commonProperties||this.commonProperties.contains(e.relatedTarget)||this.propertiesController.isSummaryPanelShowing()||this.propertiesController.isSubPanelsShowing()||this.applyPropertiesEditing(!1)}},{key:"setForm",value:function(e){var t=null;e.formData&&0!==Object.keys(e.formData).length?t=e.formData:e.parameterDef&&(this.props.propertiesConfig.schemaValidation&&yc(e.parameterDef),t=Ko.makeForm(e.parameterDef,!this.props.propertiesConfig.rightFlyout)),t&&t.data&&t.data.inputDataModel&&!t.data.datasetMetadata&&(t.data.datasetMetadata=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.x)(t.data.inputDataModel)),this.propertiesController.setForm(t,this.props.intl),t&&(this.originalTitle=t.label),this.initialValueInfo={additionalInfo:{messages:[]},undoInfo:{}},this.uiParameterKeys=this._getUiOnlyKeys(),this.initialValueInfo=this._setValueInforProperties(this.initialValueInfo),e.messages&&(this.initialValueInfo.additionalInfo.messages=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(e.messages)),this.initialValueInfo.undoInfo.properties=this.propertiesController.getPropertyValues(),this.initialValueInfo.undoInfo.messages=this.propertiesController.getAllErrorMessages(),this.initialValueInfo.additionalInfo.title=this.propertiesController.getTitle()}},{key:"getApplyButtonLabel",value:function(){return this.props.propertiesConfig.buttonLabels&&this.props.propertiesConfig.buttonLabels.primary?this.props.propertiesConfig.buttonLabels.primary:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.intl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.PROPERTIESEDIT_APPLYBUTTON_LABEL)}},{key:"getRejectButtonLabel",value:function(){return this.props.propertiesConfig.buttonLabels&&this.props.propertiesConfig.buttonLabels.secondary?this.props.propertiesConfig.buttonLabels.secondary:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.intl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.PROPERTIESEDIT_REJECTBUTTON_LABEL)}},{key:"getPropertiesActionLabel",value:function(){if(this.props.callbacks.propertiesActionLabelHandler){var e=this.props.callbacks.propertiesActionLabelHandler();if(e)return e}return (0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.intl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.PROPERTIES_ACTION_LABEL)}},{key:"getEditorSize",value:function(){var e=this.propertiesController.getForm().editorSize,t=this.props.propertiesInfo.initialEditorSize;return e===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.SMALL&&t===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.LARGE||e===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.MEDIUM&&t===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.SMALL||e===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.LARGE?e:t||e}},{key:"_getOverrideSize",value:function(){var e=this.propertiesController.getForm().pixelWidth,t=this.propertiesController.getForm().editorSize,r=null;return e&&(t===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.SMALL?this.state.editorSize===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.SMALL&&e.min?r=e.min:this.state.editorSize===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.MEDIUM&&e.max&&(r=e.max):t===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.MEDIUM?this.state.editorSize===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.MEDIUM&&e.min?r=e.min:this.state.editorSize===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.LARGE&&e.max&&(r=e.max):t===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.LARGE&&e.max&&(r=e.max)),r}},{key:"_getResizeButton",value:function(){var e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_19__.I,{type:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.g.CHEVRONARROWS.LEFT,className:"properties-resize-caret-left"});return this.propertiesController.getForm().editorSize===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.SMALL?this.state.editorSize===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.MEDIUM&&(e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_19__.I,{type:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.g.CHEVRONARROWS.RIGHT,className:"properties-resize-caret-right"})):this.propertiesController.getForm().editorSize===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.MEDIUM&&this.state.editorSize===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.LARGE&&(e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_19__.I,{type:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.g.CHEVRONARROWS.RIGHT,className:"properties-resize-caret-right"})),e}},{key:"_isResizeButtonRequired",value:function(){var e=this.propertiesController.getForm().pixelWidth;if(!1!==this.props.propertiesConfig.enableResize){if(e){if(!e.min&&!e.max)return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("Pixel width was provided but no min or max property was found in it."),!0;if(this.propertiesController.getForm().editorSize===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.SMALL){if(e.min&&!e.max&&e.min>=Rc)return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("No resize button shown. Pixel width min size is greater than or equal to default max size: "+Rc),!1;if(!e.min&&e.max&&e.max<=Cc)return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("No resize button shown. Pixel width max size is less than or equal to default min size: "+Cc),!1;if(e.min>=e.max)return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("No resize button shown. Pixel width min size is greater than or equal to pixel width max size."),!1}else if(this.propertiesController.getForm().editorSize===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.MEDIUM){if(e.min&&!e.max&&e.min>=_c)return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("No resize button shown. Pixel width min size is greater than or equal to default max size: "+_c),!1;if(!e.min&&e.max&&e.max<=Rc)return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("No resize button shown. Pixel width max size is less than or equal to default min size: "+Rc),!1;if(e.min>=e.max)return _index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("No resize button shown. Pixel width min size is greater than or equal to default max size."),!1}else if(this.propertiesController.getForm().editorSize===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.LARGE)return!!e.min&&(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.l.warn("No resize button shown. Pixel width min size ignored."),!1)}else if(this.propertiesController.getForm().editorSize===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.LARGE)return!1;return!0}return!1}},{key:"_setValueInforProperties",value:function(e,t){var r=t&&!0===t.applyProperties,n=this.props.propertiesConfig.conditionReturnValueHandling===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.p.NULL,o=this.propertiesController.getPropertyValues({filterHiddenDisabled:n,applyProperties:r});return this.uiParameterKeys.length>0?(e.properties=Ur(o,this.uiParameterKeys),e.uiProperties=vr(o,this.uiParameterKeys)):e.properties=o,e}},{key:"_getUiOnlyKeys",value:function(){var e=[],t=this.propertiesController.getControls();if(Object.keys(t).length>0)for(var r in t){if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(t,r))t[r].uionly&&e.push(r)}return e}},{key:"cancelHandler",value:function(e){this.props.callbacks.closePropertiesDialog&&this.props.callbacks.closePropertiesDialog(e)}},{key:"applyPropertiesEditing",value:function(e){this.propertiesController.validatePropertiesValues();var t=this.propertiesController.getAllErrorMessages();if(this.originalTitle!==this.propertiesController.getTitle()||this.currentParameters&&JSON.stringify(this.currentParameters)!==JSON.stringify(this.propertiesController.getPropertyValues())||JSON.stringify(this.previousErrorMessages)!==JSON.stringify(t)||this.props.propertiesConfig.applyPropertiesWithoutEdit){var r={additionalInfo:{},undoInfo:{}};(r=this._setValueInforProperties(r,{applyProperties:!0})).undoInfo.properties=this.propertiesController.getPropertyValues();var n=this.propertiesController.getErrorMessages(!0,!0,!0,!1);n&&(r.additionalInfo.messages=n),r.undoInfo.messages=this.propertiesController.getAllErrorMessages(),this.propertiesController.getTitle()&&(r.additionalInfo.title=this.propertiesController.getTitle());var o=this.getPropertiesActionLabel(),i=new Qo(r,this.initialValueInfo,this.props.propertiesInfo.appData,this.props.callbacks.applyPropertyChanges,o);this.propertiesController.getCommandStack().do(i),this.currentParameters=this.propertiesController.getPropertyValues(),this.initialValueInfo=(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(r),this.previousErrorMessages=this.propertiesController.getAllErrorMessages()}e&&this.cancelHandler(_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.q)}},{key:"showPropertiesButtons",value:function(e){this.setState({showPropertiesButtons:e})}},{key:"updateEditorSize",value:function(e){this.setState({editorSize:e}),this.propertiesController.setEditorSize(e)}},{key:"resize",value:function(){this.propertiesController.getForm().editorSize===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.SMALL?this.state.editorSize===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.SMALL?this.updateEditorSize(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.MEDIUM):this.updateEditorSize(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.SMALL):this.propertiesController.getForm().editorSize===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.MEDIUM&&(this.state.editorSize===_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.MEDIUM?this.updateEditorSize(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.LARGE):this.updateEditorSize(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.S.MEDIUM))}},{key:"render",value:function(){var e=this,t=this.props.propertiesConfig.applyOnBlur&&this.props.propertiesConfig.rightFlyout,r=this.cancelHandler.bind(this,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.r);t&&(r=null);var n=this.getApplyButtonLabel(),o=this.getRejectButtonLabel(),i=this.propertiesController.getForm();if(null!==i){var a=[],l=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null),u=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null),c=null,d=!1;if(this.props.propertiesConfig.rightFlyout&&(l=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ec,{labelEditable:i.labelEditable,help:i.help,controller:this.propertiesController,helpClickHandler:this.props.callbacks.helpClickHandler,closeHandler:t?this.applyPropertiesEditing.bind(this,!0):null,icon:i.icon,heading:i.heading,showHeading:this.props.propertiesConfig.heading}),d=this.props.propertiesConfig.heading&&(i.icon||i.heading),u=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Yr,{controller:this.propertiesController,okHandler:t?null:this.applyPropertiesEditing.bind(this,!0),cancelHandler:r,applyLabel:n,rejectLabel:o,showPropertiesButtons:this.state.showPropertiesButtons,disableSaveOnRequiredErrors:this.props.propertiesConfig.disableSaveOnRequiredErrors}),this._isResizeButtonRequired())){var f=this._getResizeButton(),h=f.props&&"properties-resize-caret-left"===f.props.className?(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.intl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.PROPERTIESEDIT_RESIZEBUTTON_EXPAND_LABEL):(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.intl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.PROPERTIESEDIT_RESIZEBUTTON_CONTRACT_LABEL);c=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_20__["default"],{kind:"ghost",className:"properties-btn-resize",onClick:this.resize.bind(this),"aria-label":h},f)}var m=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Yn,{key:"editor-form-key",controller:this.propertiesController,additionalComponents:this.props.propertiesInfo.additionalComponents,showPropertiesButtons:this.showPropertiesButtons,customPanels:this.props.customPanels,rightFlyout:this.props.propertiesConfig.rightFlyout});a="Editing"===this.props.propertiesConfig.containerType?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Wr,{applyLabel:n,rejectLabel:o,bsSize:this.state.editorSize,title:this.propertiesController.getTitle(),okHandler:this.applyPropertiesEditing.bind(this,!0),cancelHandler:r,showPropertiesButtons:this.state.showPropertiesButtons},m):"Custom"===this.props.propertiesConfig.containerType?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-custom-container",{"properties-custom-container-with-heading":!t&&d,"properties-custom-container-applyOnBlur":t&&!d,"properties-custom-container-applyOnBlur-with-heading":t&&d})},m):react__WEBPACK_IMPORTED_MODULE_0___default().createElement(qr,{onHide:this.props.callbacks.closePropertiesDialog,title:this.propertiesController.getTitle(),bsSize:this.state.editorSize,okHandler:this.applyPropertiesEditing.bind(this,!0),cancelHandler:r,showPropertiesButtons:this.state.showPropertiesButtons,applyLabel:n,rejectLabel:o},m);var v=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.c)("properties-wrapper",{"properties-right-flyout":this.props.propertiesConfig.rightFlyout,"properties-light-enabled":this.props.light,"properties-light-disabled":!this.props.light},"properties-".concat(this.state.editorSize)),y=this._getOverrideSize(),g=null;return null!==y&&(g={width:y+"px"}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_redux__WEBPACK_IMPORTED_MODULE_1__.Provider,{store:this.propertiesController.getStore()},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("aside",{"aria-label":(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.intl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.PROPERTIES_LABEL),role:"complementary",ref:function(t){return e.commonProperties=t},className:v,tabIndex:"0",onBlur:this.onBlur,style:g},c,l,a,u))}return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null)}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),wc=(0,react_intl__WEBPACK_IMPORTED_MODULE_5__.injectIntl)(Tc,{forwardRef:!0});function kc(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(e);if(t){var a=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.a)(this).constructor;r=Reflect.construct(i,arguments,a)}else r=i.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.b)(this,r)}}var Lc=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__._)(a,n);var o=kc(a);function a(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__._)(this,a),(r=o.call(this,t)).state={hasError:!1,error:null,info:null},r.createPropertiesMainComponent=r.createPropertiesMainComponent.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.revertState=r.revertState.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.propertiesMainHasMounted=!1,r.setPropertiesHasMounted=r.setPropertiesHasMounted.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r.applyPropertiesEditing=r.applyPropertiesEditing.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_12__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_13__.a)(a,[{key:"componentDidCatch",value:function(e,t){this.setState({hasError:!0,error:e,info:t})}},{key:"setPropertiesHasMounted",value:function(){this.propertiesMainHasMounted=!0}},{key:"applyPropertiesEditing",value:function(e){this.PropertiesMain.applyPropertiesEditing(e)}},{key:"createPropertiesMainComponent",value:function(){var e=this;return Object.assign(this.props.callbacks,{setPropertiesHasMounted:this.setPropertiesHasMounted}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement(wc,{ref:function(t){e.PropertiesMain=t},propertiesInfo:this.props.propertiesInfo,propertiesConfig:this.props.propertiesConfig,customPanels:this.props.customPanels,callbacks:this.props.callbacks,customControls:this.props.customControls,customConditionOps:this.props.customConditionOps,light:this.props.light})}},{key:"revertState",value:function(){this.setState({hasError:!1,error:null,info:null})}},{key:"displayAppropriateUIFallback",value:function(){var e,t,r={text:(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.intl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.PROPERTIES_UNEXPECTED_MESSAGE),type:"error"},n=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-error-heading"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Ka,{messageInfo:r})),o=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.intl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.PROPERTIES_SUPPORT_MESSAGE),i=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.intl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.PROPERTIESEDIT_CLOSEBUTTON_LABEL),a=this.props.callbacks.closePropertiesDialog,l=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.intl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.PROPERTIESEDIT_REVERTBUTTON_LABEL),u=this.revertState,d=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.intl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.PROPERTIES_LABEL);return"Custom"===this.props.propertiesConfig.containerType?(!0===this.propertiesMainHasMounted?(e=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.intl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.PROPERTIES_REVERT_MESSAGE),t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-modal-buttons"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.P,{className:"properties-error-display-close-button",okHandler:a,cancelHandler:u,showPropertiesButtons:!0,applyLabel:i,rejectLabel:l}))):(e=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.intl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.PROPERTIES_CLOSE_MESSAGE),t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-modal-buttons"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.P,{className:"properties-error-display-close-button",okHandler:a,showPropertiesButtons:!0,applyLabel:i}))),this.props.propertiesConfig.rightFlyout?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("aside",{"aria-label":d,role:"complementary",className:"properties-wrapper properties-right-flyout properties-small"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-flyout-error-container"},n,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("br",null),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("br",null),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-error-content"},e,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("br",null),o)),t):react__WEBPACK_IMPORTED_MODULE_0___default().createElement("aside",{"aria-label":d,role:"complementary",className:"properties-wrapper properties-custom-container"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-flyout-error-container"},n,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("br",null),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("br",null),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-error-content"},e,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("br",null),o)),t)):(!0===this.propertiesMainHasMounted?(e=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.intl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.PROPERTIES_REVERT_MESSAGE),t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(qr,{bsSize:"large",showPropertiesButtons:!0,applyLabel:i,rejectLabel:l,okHandler:a,cancelHandler:u,title:n},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-modal-container properties-error-content"},e,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("br",null),o))):(e=(0,_index_beefcd21_js__WEBPACK_IMPORTED_MODULE_14__.f)(this.props.intl,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_15__.M.PROPERTIES_CLOSE_MESSAGE),t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-modal-error"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(qr,{okHandler:a,bsSize:"large",showPropertiesButtons:!0,applyLabel:i,rejectLabel:"null",title:n},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-modal-container properties-error-content"},e,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("br",null),o)))),t)}},{key:"render",value:function(){return this.state.hasError?this.displayAppropriateUIFallback():this.createPropertiesMainComponent()}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));Lc.defaultProps={propertiesConfig:{containerType:"Custom",rightFlyout:!0,applyOnBlur:!1,disableSaveOnRequiredErrors:!1,enableResize:!0,conditionReturnValueHandling:"value",schemaValidation:!1,applyPropertiesWithoutEdit:!1,maxLengthForMultiLineControls:1024,maxLengthForSingleLineControls:128},callbacks:{},light:!0};var Ac=(0,react_intl__WEBPACK_IMPORTED_MODULE_5__.injectIntl)(Lc,{forwardRef:!0});
//# sourceMappingURL=common-properties-87fef545.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/createClass-32a0cf0f.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/createClass-32a0cf0f.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "_": () => (/* binding */ e),
/* harmony export */   "a": () => (/* binding */ r)
/* harmony export */ });
function e(e,n){if(!(e instanceof n))throw new TypeError("Cannot call a class as a function")}function n(e,n){for(var r=0;r<n.length;r++){var t=n[r];t.enumerable=t.enumerable||!1,t.configurable=!0,"value"in t&&(t.writable=!0),Object.defineProperty(e,t.key,t)}}function r(e,r,t){return r&&n(e.prototype,r),t&&n(e,t),Object.defineProperty(e,"prototype",{writable:!1}),e}
//# sourceMappingURL=createClass-32a0cf0f.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/datarecord-metadata-v3-schema-81228a9a.js":
/*!***************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/datarecord-metadata-v3-schema-81228a9a.js ***!
  \***************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "A": () => (/* binding */ A),
/* harmony export */   "_": () => (/* binding */ j),
/* harmony export */   "a": () => (/* binding */ O),
/* harmony export */   "b": () => (/* binding */ N),
/* harmony export */   "d": () => (/* binding */ E),
/* harmony export */   "s": () => (/* binding */ w),
/* harmony export */   "u": () => (/* binding */ U)
/* harmony export */ });
/* harmony import */ var _createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./createClass-32a0cf0f.js */ "../../node_modules/@elyra/canvas/dist/createClass-32a0cf0f.js");
/* harmony import */ var _en_8647c347_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./en-8647c347.js */ "../../node_modules/@elyra/canvas/dist/en-8647c347.js");
/* harmony import */ var _isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./isArrayLikeObject-a9c7973b.js */ "../../node_modules/@elyra/canvas/dist/isArrayLikeObject-a9c7973b.js");
var h=_en_8647c347_js__WEBPACK_IMPORTED_MODULE_0__.e,b=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_1__.a,g=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_1__.L,v=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_1__.M,_=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_1__.e;var j=function(e,t,i,r){if(!v(e))return e;for(var a=-1,n=(t=b(t,e)).length,o=n-1,s=e;null!=s&&++a<n;){var d=_(t[a]),p=i;if("__proto__"===d||"constructor"===d||"prototype"===d)return e;if(a!=o){var c=s[d];void 0===(p=r?r(c,d,s):void 0)&&(p=v(c)?c:g(t[a+1])?[]:{})}h(s,d,p),s=s[d]}return e},A=function(){function i(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_2__._)(this,i)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_2__.a)(i,[{key:"do",value:function(){}},{key:"undo",value:function(){}},{key:"redo",value:function(){}},{key:"getLabel",value:function(){}}]),i}(),q=j;var w=function(e,t,i){return null==e?e:q(e,t,i)};var I=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_1__.a0,S=function(){},M=I&&1/(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_1__.a1)(new I([,-0]))[1]==1/0?function(e){return new I(e)}:S,k=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_1__.r,x=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_1__.u,$=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_1__.v,D=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_1__.t,F=M,L=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_1__.a1;var O=function(e,t,i){var r=-1,a=x,n=e.length,o=!0,s=[],d=s;if(i)o=!1,a=$;else if(n>=200){var p=t?null:F(e);if(p)return L(p);o=!1,a=D,d=new k}else d=t?[]:s;e:for(;++r<n;){var c=e[r],m=t?t(c):c;if(c=i||0!==c?c:0,o&&m==m){for(var l=d.length;l--;)if(d[l]===m)continue e;t&&d.push(m),s.push(c)}else a(d,m,i)||(d!==s&&d.push(m),s.push(c))}return s},P=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_1__.b,T=O,C=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_1__.q,U=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_1__.m)((function(e){return T(P(e,1,C,!0))}));function W(e,t){(null==t||t>e.length)&&(t=e.length);for(var i=0,r=new Array(t);i<t;i++)r[i]=e[i];return r}function N(e){return function(e){if(Array.isArray(e))return W(e)}(e)||function(e){if("undefined"!=typeof Symbol&&null!=e[Symbol.iterator]||null!=e["@@iterator"])return Array.from(e)}(e)||function(e,t){if(e){if("string"==typeof e)return W(e,t);var i=Object.prototype.toString.call(e).slice(8,-1);return"Object"===i&&e.constructor&&(i=e.constructor.name),"Map"===i||"Set"===i?Array.from(e):"Arguments"===i||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(i)?W(e,t):void 0}}(e)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}var E={$schema:"https://json-schema.org/draft-04/schema#",id:"https://api.dataplatform.ibm.com/schemas/common-pipeline/datarecord-metadata/datarecord-metadata-v3-schema.json",title:"Watson Data Platform Datarecord Metadata Schema",description:"Metadata schema for datarecords in the Watson Data Platform",type:"object",definitions:{record_schema:{description:"Description of a datarecord including column types and metadata",type:"object",properties:{id:{description:"Unique identifier",type:"string"},name:{description:"Name of datarecord",type:"string"},json_schema:{description:"Refers to the JSON schema used to validate documents of this type",enum:["https://api.dataplatform.ibm.com/schemas/common-pipeline/datarecord-metadata/datarecord-metadata-v3-schema.json"],type:"string"},type:{description:"Always 'struct' for datarecord schema",type:"string"},fields:{description:"Array of field definitions",type:"array",minItems:0,items:{$ref:"#/definitions/field"},uniqueItems:!0},struct_types:{description:"The list of custom struct types to be used as field types",type:"object",patternProperties:{".":{type:"object",properties:{fields:{description:"Array of field definitions",type:"array",minItems:0,items:{$ref:"#/definitions/field"},uniqueItems:!0}}}}}},required:["id","fields"]},field:{description:"Definition of a datarecord field",type:"object",properties:{name:{description:"Field name. Must be unique within the datarecord",type:"string"},type:{description:"Field type. Can be a primitive type (string, integer, double, date, time, timestamp, binary, boolean, array[type], map[type, type]. The type can also be a reference to a struct_type declaration.)",type:"string"},nullable:{description:"Whether or not one can place null values into the field",type:"boolean",default:!1},metadata:{$ref:"#/definitions/metadata"},app_data:{$ref:"#/definitions/app_data_def"}},required:["name","type"]},metadata:{description:"Additional field metadata",type:"object",properties:{description:{description:"Field description",type:"string"},measure:{description:"Field measurement level",enum:["range","discrete","flag","set","ordered-set","typeless","collection","geospatial","default"]},modeling_role:{description:"Field role for modeling",enum:["input","target","both","none","partition","split","frequency","record-id"]},max_length:{description:"Maximum length for fields. Length is unlimited when not present",type:"number"},min_length:{description:"Minimum length for fields",type:"number"},decimal_precision:{description:"Precision for decimal, time, and timestamp types",type:"number"},decimal_scale:{description:"Scale for decimal, time, and timestamp types",type:"number"},values:{description:"Array of unique categorical values for the column",type:"array",minItems:0,items:{description:"A value discovered in the data",type:["string","number","boolean"]},uniqueItems:!0},range:{description:"Minimum and maximum discovered values for scalar data",type:"object",properties:{min:{description:"Lowest value discovered in the data",type:["string","number"]},max:{description:"Highest value discovered in the data",type:["string","number"]}},required:["min","max"]},runtime_type:{description:"Type of runtime",type:"string"},is_key:{description:"A field is key",type:"boolean"},is_signed:{description:"Signed or Unsigned for number",type:"boolean"},item_index:{description:"Item record level",type:"number"},source_field_id:{description:"Source field for a target field",type:"string"}}},app_data_def:{description:"Object containing app-specific data",type:"object",properties:{},additionalProperties:!0}}};
//# sourceMappingURL=datarecord-metadata-v3-schema-81228a9a.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/en-8647c347.js":
/*!************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/en-8647c347.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "_": () => (/* binding */ oe),
/* harmony export */   "a": () => (/* binding */ C),
/* harmony export */   "b": () => (/* binding */ ve),
/* harmony export */   "c": () => (/* binding */ Ot),
/* harmony export */   "d": () => (/* binding */ gt),
/* harmony export */   "e": () => (/* binding */ L),
/* harmony export */   "f": () => (/* binding */ _t),
/* harmony export */   "k": () => (/* binding */ V)
/* harmony export */ });
/* harmony import */ var _isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./isArrayLikeObject-a9c7973b.js */ "../../node_modules/@elyra/canvas/dist/isArrayLikeObject-a9c7973b.js");
var S=function(e,t){for(var n=-1,o=null==e?0:e.length;++n<o&&!1!==t(e[n],n,e););return e},g=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.H,_=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.K,w=Object.prototype.hasOwnProperty;var L=function(e,t,n){var o=e[t];w.call(e,t)&&_(o,n)&&(void 0!==n||t in e)||g(e,t,n)},N=L,x=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.H;var C=function(e,t,n,o){var r=!n;n||(n={});for(var a=-1,c=t.length;++a<c;){var i=t[a],s=o?o(n[i],e[i],i,n,e):void 0;void 0===s&&(s=e[i]),r?x(n,i,s):N(n,i,s)}return n},D=C,P=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.p;var I=function(e,t){return e&&D(t,P(t),e)};var E=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.M,U=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.o,M=function(e){var t=[];if(null!=e)for(var n in Object(e))t.push(n);return t},T=Object.prototype.hasOwnProperty;var B=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.N,F=function(e){if(!E(e))return M(e);var t=U(e),n=[];for(var o in e)("constructor"!=o||!t&&T.call(e,o))&&n.push(o);return n},R=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.n;var V=function(e){return R(e)?B(e,!0):F(e)},z=C,W=V;var $,G,H,K,Q,X,Y,Z=function(e,t){return e&&z(t,W(t),e)},q={exports:{}};$=q,H=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.O,K=(G=q.exports)&&!G.nodeType&&G,Q=K&&$&&!$.nodeType&&$,X=Q&&Q.exports===K?H.Buffer:void 0,Y=X?X.allocUnsafe:void 0,$.exports=function(e,t){if(t)return e.slice();var n=e.length,o=Y?Y(n):new e.constructor(n);return e.copy(o),o};var J=function(e,t){var n=-1,o=e.length;for(t||(t=Array(o));++n<o;)t[n]=e[n];return t},ee=C,te=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.P;var ne=function(e,t){return ee(e,te(e),t)},oe=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.Q)(Object.getPrototypeOf,Object),re=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.R,ae=oe,ce=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.P,ie=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.S,se=Object.getOwnPropertySymbols?function(e){for(var t=[];e;)re(t,ce(e)),e=ae(e);return t}:ie,le=C,ue=se;var de=function(e,t){return le(e,ue(e),t)},be=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.T,pe=se,fe=V;var ve=function(e){return be(e,fe,pe)},je=Object.prototype.hasOwnProperty;var me=function(e){var t=e.length,n=new e.constructor(t);return t&&"string"==typeof e[0]&&je.call(e,"index")&&(n.index=e.index,n.input=e.input),n},ye=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.U;var ke=function(e){var t=new e.constructor(e.byteLength);return new ye(t).set(new ye(e)),t},he=ke;var Ae=function(e,t){var n=t?he(e.buffer):e.buffer;return new e.constructor(n,e.byteOffset,e.byteLength)},Oe=/\w*$/;var Se=function(e){var t=new e.constructor(e.source,Oe.exec(e));return t.lastIndex=e.lastIndex,t},ge=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.V?_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.V.prototype:void 0,_e=ge?ge.valueOf:void 0;var we=ke;var Le=ke,Ne=Ae,xe=Se,Ce=function(e){return _e?Object(_e.call(e)):{}},De=function(e,t){var n=t?we(e.buffer):e.buffer;return new e.constructor(n,e.byteOffset,e.length)};var Pe=function(e,t,n){var o=e.constructor;switch(t){case"[object ArrayBuffer]":return Le(e);case"[object Boolean]":case"[object Date]":return new o(+e);case"[object DataView]":return Ne(e,n);case"[object Float32Array]":case"[object Float64Array]":case"[object Int8Array]":case"[object Int16Array]":case"[object Int32Array]":case"[object Uint8Array]":case"[object Uint8ClampedArray]":case"[object Uint16Array]":case"[object Uint32Array]":return De(e,n);case"[object Map]":case"[object Set]":return new o;case"[object Number]":case"[object String]":return new o(e);case"[object RegExp]":return xe(e);case"[object Symbol]":return Ce(e)}},Ie=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.M,Ee=Object.create,Ue=function(){function e(){}return function(t){if(!Ie(t))return{};if(Ee)return Ee(t);e.prototype=t;var n=new e;return e.prototype=void 0,n}}(),Me=oe,Te=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.o;var Be=function(e){return"function"!=typeof e.constructor||Te(e)?{}:Ue(Me(e))},Fe=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.W,Re=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.i;var Ve=function(e){return Re(e)&&"[object Map]"==Fe(e)},ze=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.s,We=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.X.exports,$e=We&&We.isMap,Ge=$e?ze($e):Ve,He=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.W,Ke=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.i;var Qe=function(e){return Ke(e)&&"[object Set]"==He(e)},Xe=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.s,Ye=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.X.exports,Ze=Ye&&Ye.isSet,qe=Ze?Xe(Ze):Qe,Je=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.Y,et=S,tt=L,nt=I,ot=Z,rt=q.exports,at=J,ct=ne,it=de,st=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.$,lt=ve,ut=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.W,dt=me,bt=Pe,pt=Be,ft=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.y,vt=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.Z.exports,jt=Ge,mt=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.M,yt=qe,kt=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_0__.p,ht=V,At={};At["[object Arguments]"]=At["[object Array]"]=At["[object ArrayBuffer]"]=At["[object DataView]"]=At["[object Boolean]"]=At["[object Date]"]=At["[object Float32Array]"]=At["[object Float64Array]"]=At["[object Int8Array]"]=At["[object Int16Array]"]=At["[object Int32Array]"]=At["[object Map]"]=At["[object Number]"]=At["[object Object]"]=At["[object RegExp]"]=At["[object Set]"]=At["[object String]"]=At["[object Symbol]"]=At["[object Uint8Array]"]=At["[object Uint8ClampedArray]"]=At["[object Uint16Array]"]=At["[object Uint32Array]"]=!0,At["[object Error]"]=At["[object Function]"]=At["[object WeakMap]"]=!1;var Ot=function e(t,n,o,r,a,c){var i,s=1&n,l=2&n,u=4&n;if(o&&(i=a?o(t,r,a,c):o(t)),void 0!==i)return i;if(!mt(t))return t;var d=ft(t);if(d){if(i=dt(t),!s)return at(t,i)}else{var b=ut(t),p="[object Function]"==b||"[object GeneratorFunction]"==b;if(vt(t))return rt(t,s);if("[object Object]"==b||"[object Arguments]"==b||p&&!a){if(i=l||p?{}:pt(t),!s)return l?it(t,ot(i,t)):ct(t,nt(i,t))}else{if(!At[b])return a?t:{};i=bt(t,b,s)}}c||(c=new Je);var f=c.get(t);if(f)return f;c.set(t,i),yt(t)?t.forEach((function(r){i.add(e(r,n,o,r,t,c))})):jt(t)&&t.forEach((function(r,a){i.set(a,e(r,n,o,a,t,c))}));var v=d?void 0:(u?l?lt:st:l?ht:kt)(t);return et(v||t,(function(r,a){v&&(r=t[a=r]),tt(i,a,e(r,n,o,a,t,c))})),i},St=Ot;var gt=function(e){return St(e,5)},_t={"action.createNode":"Create {node_label} node","action.arrangeLayout":"Arrange layout","action.attachNodeToLinks":"Attach {node_label} node to link","action.collapseSuperNodeInPlace":"Collapse supernode","action.commonProperties":"Save properties","action.colorComments":"Color {comments_count, plural, one {# comment} other {# comments} }","action.convertSuperNodeExternalToLocal":"Convert external supernode {node_label} to local","action.convertSuperNodeLocalToExternal":"Convert local supernode {node_label} to external","action.createComment":"Create comment","action.createCommentLink":"Create comment link","action.createNodeAttachLinks":"Create {node_label} node and attach to link","action.replaceNodeLink":"Replace link to {node_label} node","action.createNodeLink":"Create link to {node_label} node","action.createNodeLinkDetached":"Create detached link","action.createNodeOnLink":"Create {node_label} node and insert into link","action.createSuperNode":"Create {node_label} supernode","action.deconstructSuperNode":"Deconstruct {node_label} supernode","action.deleteLink":"Delete link","action.deleteComments":"Delete {comments_count, plural, one {# comment} other {# comments} }","action.deleteNodes":"Delete {nodes_count, plural, one {# node} other {# nodes} }","action.deleteLinks":"Delete {links_count, plural, one {# link} other {# links} }","action.deleteCommentsLinks":"Delete {comments_count, plural, one {# comment} other {# comments} } and {links_count, plural, one {# link} other {# links} }","action.deleteNodesLinks":"Delete {nodes_count, plural, one {# node} other {# nodes} } and {links_count, plural, one {# link} other {# links} }","action.deleteNodesCommentsLinks":"Delete {nodes_count, plural, one {# node} other {# nodes} }, {comments_count, plural, one {# comment} other {# comments} } and {links_count, plural, one {# link} other {# links} }","action.deleteNodesComments":"Delete {nodes_count, plural, one {# node} other {# nodes} } and {comments_count, plural, one {# comment} other {# comments} }","action.disconnectObjects":"Disconnect objects","action.displayPreviousPipeline":"Display previous pipline","action.displaySubPipeline":"Display supernode full page","action.editComment":"Edit comment","action.editLinkDecorationLabel":"Edit link decoration label","action.editNodeDecorationLabel":"Edit node decoration label","action.expandSuperNodeInPlace":"Expand {node_label} supernode in place","action.insertNodeIntoLink":"Insert {node_label} node into link","action.moveObject":"Move object","action.moveObjects":"Move objects","action.pasteObjects":"Paste objects","action.saveToPalette":"Save node to palette","action.setLinksStyle":"Set link style","action.setNodeLabel":"Set node label","action.setObjectsStyle":"Set objects style","action.sizeAndPositionObjects":"Size node","action.updateLink":"Update link","supernode.template.description":"This supernode was created by common-canvas.","supernode.template.label":"Supernode","supernode.new.port.label":"Binding port for supernode","supernode.binding.node.label":"Binding","supernode.binding.node.description":"Supernode binding node","palette.saved.nodes.label":"Saved Nodes","palette.saved.nodes.description":"Nodes in this category were previously saved from a flow."};
//# sourceMappingURL=en-8647c347.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/extends-cf86ca1c.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/extends-cf86ca1c.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "A": () => (/* binding */ I),
/* harmony export */   "C": () => (/* binding */ c),
/* harmony export */   "D": () => (/* binding */ n),
/* harmony export */   "E": () => (/* binding */ A),
/* harmony export */   "M": () => (/* binding */ l),
/* harmony export */   "P": () => (/* binding */ s),
/* harmony export */   "R": () => (/* binding */ p),
/* harmony export */   "S": () => (/* binding */ R),
/* harmony export */   "T": () => (/* binding */ T),
/* harmony export */   "_": () => (/* binding */ g),
/* harmony export */   "a": () => (/* binding */ U),
/* harmony export */   "b": () => (/* binding */ b),
/* harmony export */   "c": () => (/* binding */ t),
/* harmony export */   "d": () => (/* binding */ L),
/* harmony export */   "e": () => (/* binding */ M),
/* harmony export */   "f": () => (/* binding */ f),
/* harmony export */   "g": () => (/* binding */ D),
/* harmony export */   "h": () => (/* binding */ O),
/* harmony export */   "i": () => (/* binding */ i),
/* harmony export */   "j": () => (/* binding */ r),
/* harmony export */   "k": () => (/* binding */ _),
/* harmony export */   "l": () => (/* binding */ a),
/* harmony export */   "m": () => (/* binding */ o),
/* harmony export */   "n": () => (/* binding */ B),
/* harmony export */   "o": () => (/* binding */ N),
/* harmony export */   "p": () => (/* binding */ P),
/* harmony export */   "q": () => (/* binding */ u),
/* harmony export */   "r": () => (/* binding */ d),
/* harmony export */   "s": () => (/* binding */ C),
/* harmony export */   "t": () => (/* binding */ m),
/* harmony export */   "u": () => (/* binding */ S)
/* harmony export */ });
var e,E={exports:{}};
/*!
  Copyright (c) 2018 Jed Watson.
  Licensed under the MIT License (MIT), see
  http://jedwatson.github.io/classnames
*/e=E,function(){var E={}.hasOwnProperty;function t(){for(var e=[],l=0;l<arguments.length;l++){var T=arguments[l];if(T){var r=typeof T;if("string"===r||"number"===r)e.push(T);else if(Array.isArray(T)){if(T.length){var L=t.apply(null,T);L&&e.push(L)}}else if("object"===r)if(T.toString===Object.prototype.toString)for(var o in T)E.call(T,o)&&T[o]&&e.push(o);else e.push(T.toString())}}return e.join(" ")}e.exports?(t.default=t,e.exports=t):window.classNames=t}();var t=E.exports,l={SUBPANEL_BUTTON_TOOLTIP:"subPanel.button.tooltip",STRUCTURELISTEDITOR_ADDBUTTON_LABEL:"structureListEditor.addButton.label",STRUCTURELISTEDITOR_REMOVEBUTTON_LABEL:"structureListEditor.removeButton.label",STRUCTURETABLE_ADDBUTTON_LABEL:"structureTable.addButton.label",STRUCTURETABLE_REMOVEBUTTON_LABEL:"structureTable.removeButton.label",FIELDPICKER_SAVEBUTTON_LABEL:"fieldPicker.saveButton.label",FIELDPICKER_SAVEBUTTON_TOOLTIP:"fieldPicker.saveButton.tooltip",FIELDPICKER_RESETBUTTON_LABEL:"fieldPicker.resetButton.label",FIELDPICKER_FILTER_LABEL:"fieldPicker.filter.label",FIELDPICKER_FIELDCOLUMN_LABEL:"fieldPicker.fieldColumn.label",FIELDPICKER_SCHEMACOLUMN_LABEL:"fieldPicker.schemaColumn.label",FIELDPICKER_DATATYPECOLUMN_LABEL:"fieldPicker.dataTypeColumn.label",FIELDPICKER_INTEGER_LABEL:"fieldPicker.integer.label",FIELDPICKER_DOUBLE_LABEL:"fieldPicker.double.label",FIELDPICKER_STRING_LABEL:"fieldPicker.string.label",FIELDPICKER_DATE_LABEL:"fieldPicker.date.label",FIELDPICKER_TIME_LABEL:"fieldPicker.time.label",FIELDPICKER_TIMESTAMP_LABEL:"fieldPicker.timestamp.label",APPLYBUTTON_LABEL:"flyout.applyButton.label",REJECTBUTTON_LABEL:"flyout.rejectButton.label",PROPERTIESEDIT_CLOSEBUTTON_LABEL:"propertiesEdit.closeButton.label",PROPERTIESEDIT_APPLYBUTTON_LABEL:"propertiesEdit.applyButton.label",PROPERTIESEDIT_REJECTBUTTON_LABEL:"propertiesEdit.rejectButton.label",PROPERTIESEDIT_REVERTBUTTON_LABEL:"propertiesEdit.revertButton.label",PROPERTIESEDIT_RESIZEBUTTON_EXPAND_LABEL:"propertiesEdit.resizeButton.expand.label",PROPERTIESEDIT_RESIZEBUTTON_CONTRACT_LABEL:"propertiesEdit.resizeButton.contract.label",PROPERTIES_REVERT_MESSAGE:"properties.revert.message",PROPERTIES_CLOSE_MESSAGE:"properties.close.message",PROPERTIES_SUPPORT_MESSAGE:"properties.support.message",PROPERTIES_UNEXPECTED_MESSAGE:"properties.unexpected.message",TABLE_SEARCH_HEADER:"table.search.header",LONG_TABLE_SUMMARY_PLACEHOLDER:"summary.longTable.placeholder",ALERTS_TAB_TITLE:"alerts.tab.title",TITLE_EDITOR_LABEL:"title.editor.label",TITLE_EDITOR_HELPBUTTON_LABEL:"title.editor.helpButton.label",TABLE_SUMMARY_ERROR:"table.summary.error",TABLE_SUMMARY_WARNING:"table.summary.warning",CONTROL_SUMMARY_ERROR:"control.summary.error",CONTROL_SUMMARY_WARNING:"control.summary.warning",CONTROL_SUMMARY_ERROR_WARNING:"control.summary.error.warning",REQUIRED_ERROR:"required.error",DATETIME_FORMAT_ERROR:"datetime.format.error",INVALID_FIELD_ERROR:"invalid.field.error",EXPRESSION_VALIDATE_LABEL:"expression.validate.label",EXPRESSION_VALIDATING_LABEL:"expression.validating.label",EXPRESSION_BUILDER_TITLE:"expression.builder.title",EXPRESSION_BUILDER_ICON_DESCRIPTION:"expression.builder.icon.description",EXPRESSION_BUILDER_LABEL:"expression.builder.label",EXPRESSION_FIELDS_TABLE_LABEL:"expression.fields.table.label",EXPRESSION_VALUES_TABLE_LABEL:"expression.values.table.label",EXPRESSION_FUNCTIONS_TABLE_LABEL:"expression.functions.table.label",EXPRESSION_FIELDS_DROPDOWN_TITLE:"expression.fields.dropdown",EXPRESSION_FIELDS_TITLE:"expression.fields.title",EXPRESSION_VALUES_TITLE:"expression.values.title",EXPRESSION_FIELD_COLUMN:"expression.field.column",EXPRESSION_STORAGE_COLUMN:"expression.storage.column",EXPRESSION_VALUE_COLUMN:"expression.value.column",EXPRESSION_FUNCTION_COLUMN:"expression.function.column",EXPRESSION_RETURN_COLUMN:"expression.return.column",EXPRESSION_RECENTLY_USED_COLUMN:"expression.recently.used.column",EXPRESSION_FIELD_TAB:"expression.field.tab",EXPRESSION_FUNCTIONS_TAB:"expression.functions.tab",EXPRESSION_RECENTLY_USED:"expression.recently.used",EXPRESSION_ALL_FUNCTIONS:"expression.all.functions",EXPRESSION_MIN_LABEL:"expression.min.label",EXPRESSION_MAX_LABEL:"expression.max.label",EXPRESSION_NO_FUNCTIONS:"expression.no.functions",MULTI_SELECTED_ROW_LABEL:"multi.selected.row.label",MULTI_SELECTED_ROW_ACTION:"multi.selected.row.action",MOVEABLE_TABLE_BUTTON_TOP_DESCRIPTION:"moveable.table.button.top",MOVEABLE_TABLE_BUTTON_UP_DESCRIPTION:"moveable.table.button.up",MOVEABLE_TABLE_BUTTON_DOWN_DESCRIPTION:"moveable.table.button.down",MOVEABLE_TABLE_BUTTON_BOTTOM_DESCRIPTION:"moveable.table.button.bottom",LIST_TABLE_LABEL:"list.table.label",DROPDOWN_TOOLTIP_OPENMENU:"dropdown.tooltip.openMenu",DROPDOWN_TOOLTIP_CLOSEMENU:"dropdown.tooltip.closeMenu",DROPDOWN_TOOLTIP_CLEARALL:"dropdown.tooltip.clear.all",DROPDOWN_TOOLTIP_CLEARSELECTION:"dropdown.tooltip.clear.selection",TRUNCATE_LONG_STRING_ERROR:"truncate.long.string.error",PROPERTIES_LABEL:"properties.label",PROPERTIES_ACTION_LABEL:"action.commonProperties",READONLYTABLE_EDIT_BUTTON_LABEL:"readonlytable.edit.button.label",TOGGLETEXT_ICON_DESCRIPTION:"toggletext.icon.description",MULTISELECT_DROPDOWN_EMPTY_LABEL:"multiselect.dropdown.empty.label",MULTISELECT_DROPDOWN_OPTIONS_SELECTED_LABEL:"multiselect.dropdown.options.selected.label",PROPERTIES_EMPTY_TABLE_TEXT:"properties.empty.table.text"},T=1e4,r={type:"info",text:""},L={INFO:"info",ERROR:"error",WARNING:"warning",SUCCESS:"success"},o={INTEGER:"integer",DOUBLE:"double",STRING:"string",DATE:"date",TIME:"time",TIMESTAMP:"timestamp"},_="yyyy-mm-dd",a="H:m:s",R={VISIBLE:"visible",HIDDEN:"hidden",ENABLED:"enabled",DISABLED:"disabled"},s="PanelTreeRoot",O={VISIBLE:"visible",ENABLED:"enabled",FILTEREDENUM:"enum_filter",ALLOWCHANGE:"allow_change",FILTER:"filter",VALIDATION:"validation",CONDITIONALDEFAULT:"default_value"},i={CONTROLS:"controls",REFS:"refs"},I={SET_PROPERTIES:"SET_PROPERTIES",UPDATE_PROPERTY:"UPDATE_PROPERTY",PROPERTIES_LOADED:"PROPERTIES_LOADED"},n=!0,S=32,A=7,N="36px",P={VALUE:"value",NULL:"null"},B={ASC:"ASC",DESC:"DESC",NOT_SORTED:"not-sorted"},p={SINGLE:"single",MULTIPLE:"multiple-edit"},D={CHEVRONARROWS:{UP:"chevron-up",DOWN:"chevron-down",LEFT:"chevron-left",RIGHT:"chevron-right"},CALCULATOR:"calculator",ADD:"add",REMOVE:"remove",EDIT:"edit",MEASUREMENTS:{EMPTY:"measurement-empty",ORDINAL:"measurement-ordinal",NOMINAL:"measurement-nominal",SCALE:"measurement-scale",FLAG:"measurement-flag",DISCRETE:"measurement-discrete"},INFORMATION:"informationHollow",SETTINGS:"settings"},u="apply",d="cancel",b="xs",c="sm",U="lg",C=56,m=32,M={PRIMARY:"primary",SECONDARY:"secondary",TERTIARY:"tertiary",GHOST:"ghost",DANGER:"danger",DANGER_TERTIARY:"danger--tertiary",DANGER_GHOST:"danger--ghost"},f={SMALL:"sm",MEDIUM:"md",LARGE:"lg",EXTRA_LARGE:"xl",DEFAULT:"default"};function g(){return g=Object.assign||function(e){for(var E=1;E<arguments.length;E++){var t=arguments[E];for(var l in t)Object.prototype.hasOwnProperty.call(t,l)&&(e[l]=t[l])}return e},g.apply(this,arguments)}
//# sourceMappingURL=extends-cf86ca1c.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/flexible-table-d4a68ebb.js":
/*!************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/flexible-table-d4a68ebb.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "F": () => (/* binding */ je),
/* harmony export */   "_": () => (/* binding */ Ce),
/* harmony export */   "d": () => (/* binding */ J),
/* harmony export */   "h": () => (/* binding */ ee)
/* harmony export */ });
/* harmony import */ var _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./extends-cf86ca1c.js */ "../../node_modules/@elyra/canvas/dist/extends-cf86ca1c.js");
/* harmony import */ var _getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./getPrototypeOf-97272efe.js */ "../../node_modules/@elyra/canvas/dist/getPrototypeOf-97272efe.js");
/* harmony import */ var _createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./createClass-32a0cf0f.js */ "../../node_modules/@elyra/canvas/dist/createClass-32a0cf0f.js");
/* harmony import */ var _isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./isArrayLikeObject-a9c7973b.js */ "../../node_modules/@elyra/canvas/dist/isArrayLikeObject-a9c7973b.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react_intl__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react-intl */ "webpack/sharing/consume/default/react-intl/react-intl");
/* harmony import */ var react_intl__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react_intl__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! react-dom */ "webpack/sharing/consume/default/react-dom");
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react_dom__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/Checkbox/Checkbox.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/Loading/Loading.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/Search/index.js");
/* harmony import */ var _baseForOwn_d38b560e_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./_baseForOwn-d38b560e.js */ "../../node_modules/@elyra/canvas/dist/_baseForOwn-d38b560e.js");
/* harmony import */ var react_virtualized__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! react-virtualized */ "../../node_modules/react-virtualized/dist/es/index.js");
/* harmony import */ var react_draggable__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! react-draggable */ "../../node_modules/react-draggable/build/cjs/cjs.js");
/* harmony import */ var react_draggable__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react_draggable__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-1.js");
/* harmony import */ var _lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./lib/tooltip.es.js */ "../../node_modules/@elyra/canvas/dist/lib/tooltip.es.js");
/* harmony import */ var uuid__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! uuid */ "webpack/sharing/consume/default/uuid/uuid");
/* harmony import */ var uuid__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(uuid__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var react_resize_detector__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! react-resize-detector */ "../../node_modules/react-resize-detector/lib/esm/index.js");
var J={"subPanel.button.tooltip":"Edit","structureListEditor.addButton.label":"Add value","structureListEditor.removeButton.label":"Remove","structureTable.addButton.label":"Add columns","structureTable.removeButton.label":"Remove","fieldPicker.saveButton.label":"Select Fields for","fieldPicker.saveButton.tooltip":"Save and return","fieldPicker.resetButton.label":"Reset ","fieldPicker.filter.label":"Filter:","fieldPicker.fieldColumn.label":"Field name","fieldPicker.schemaColumn.label":"Schema name","fieldPicker.dataTypeColumn.label":"Data type","fieldPicker.integer.label":"integer","fieldPicker.double.label":"double","fieldPicker.string.label":"string","fieldPicker.date.label":"date","fieldPicker.time.label":"time","fieldPicker.timestamp.label":"timestamp","flyout.applyButton.label":"OK","flyout.rejectButton.label":"Cancel","propertiesEdit.closeButton.label":"Close","propertiesEdit.applyButton.label":"Save","propertiesEdit.rejectButton.label":"Cancel","propertiesEdit.revertButton.label":"Revert","propertiesEdit.resizeButton.expand.label":"Expand","propertiesEdit.resizeButton.contract.label":"Contract","properties.revert.message":"Click Revert to go back to the previous screen or click Close to exit the pane. Then try your operation again.","properties.close.message":"Click Close to exit the pane. Then try your operation again.","properties.support.message":"If the problem persists, contact support.","properties.unexpected.message":"Oops, the pane didn't load.","table.search.header":"View in tables","table.search.placeholder":"Find in column {column_name}","table.search.label":"Search in {table_name} table","summary.longTable.placeholder":"More than ten fields...","alerts.tab.title":"Alerts","title.editor.label":"edit title","title.editor.helpButton.label":"help","table.summary.error":"There are {errorMsgCount} error cells. ","table.summary.warning":"There are {warningMsgCount} warning cells. ","control.summary.error":"There are {errorMsgCount} parameters with errors. ","control.summary.warning":"There are {warningMsgCount} parameters with warnings. ","control.summary.error.warning":"There are {errorMsgCount} parameters with errors and {warningMsgCount} parameters with warnings.","required.error":"You must provide your {label}.","datetime.format.error":"Invalid {role}. Format should be {format}.","invalid.field.error":"Invalid {label}, field not found in data set.","expression.validate.label":"Validate","expression.validating.label":"Validating","expression.builder.title":"Expression Builder","expression.builder.icon.description":"launch expression builder","expression.builder.label":"Expression","expression.fields.table.label":"Fields table","expression.values.table.label":"Values table","expression.functions.table.label":"Functions table","expression.fields.dropdown":"Fields","expression.fields.title":"Fields","expression.values.title":"Values","expression.field.column":"Field","expression.storage.column":"Storage","expression.value.column":"Value","expression.function.column":"Function","expression.return.column":"Return","expression.recently.used.column":"Item","expression.field.tab":"Fields","expression.functions.tab":"Functions","expression.recently.used":"Recently Used","expression.all.functions":"All Functions","expression.min.label":"Min","expression.max.label":"Max","expression.no.functions":"No functions found.","multi.selected.row.label":"rows selected.","multi.selected.row.action":"Changing a value in this row will change the value in all allowed selected rows.","datetimefield.format.error.message":"Invalid format object provided. Check input definitions.","editorform.group.type.error":"(Unknown group type '{group.groupType()}')","moveable.table.button.top":"Move to top","moveable.table.button.up":"Move up","moveable.table.button.down":"Move down","moveable.table.button.bottom":"Move to bottom","list.table.label":"Values","dropdown.tooltip.openMenu":"Open menu","dropdown.tooltip.closeMenu":"Close menu","dropdown.tooltip.clear.all":"Clear all","dropdown.tooltip.clear.selection":"Clear selection","truncate.long.string.error":"These values exceed the display limit of {truncate_limit} characters and can't be edited.","properties.label":"Properties","readonlytable.edit.button.label":"Edit","toggletext.icon.description":"{toggletext_label} Icon","multiselect.dropdown.empty.label":"None selected","multiselect.dropdown.options.selected.label":"options selected","virtualizedTable.header.checkbox.label":"Select all {header_checkbox_label}","virtualizedTable.row.checkbox.label":"Select row {row_index} from {table_label}","properties.empty.table.text":'To begin, click "{button_label}"'};var Q=function(e,t){return null!=e&&t in Object(e)},Z=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.A;var ee=function(e,t){return null!=e&&Z(e,t,Q)};var te=function(e,t){return function(r){return null!=r&&(r[e]===t&&(void 0!==t||e in Object(r)))}},re=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.B,oe=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.C,le=te;var ie=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.D,ne=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.k,se=ee,ae=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.E,ce=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.F,de=te,pe=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.e;var ue=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__._;var he=function(e){return function(t){return null==t?void 0:t[e]}},be=function(e){return function(t){return ue(t,e)}},fe=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.E,me=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.e;var ve=function(e){var t=oe(e);return 1==t.length&&t[0][2]?le(t[0][0],t[0][1]):function(r){return r===e||re(r,e,t)}},we=function(e,t){return ae(e)&&ce(t)?de(pe(e),t):function(r){var o=ne(r,e);return void 0===o&&o===t?se(r,e):ie(t,o,3)}},ge=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.G,ye=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.y,ke=function(e){return fe(e)?he(me(e)):be(e)};var Ce=function(e){return"function"==typeof e?e:null==e?ge:"object"==typeof e?ye(e)?we(e[0],e[1]):ve(e):ke(e)},Re=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.H,Se=_baseForOwn_d38b560e_js__WEBPACK_IMPORTED_MODULE_7__._,xe=Ce;var Ee=function(e,t){var r={};return t=xe(t),Se(e,(function(e,o,l){Re(r,o,t(e,o,l))})),r},Te=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.I,Ie=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.b,Oe=Ce,Ne=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.q,Ae=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.l,He=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.m)((function(e,t){var r=Ae(t);return Ne(r)&&(r=void 0),Ne(e)?Te(e,Ie(t,1,Ne,!0),Oe(r)):[]}));function De(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.a)(e);if(t){var l=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.a)(this).constructor;r=Reflect.construct(o,arguments,l)}else r=o.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.b)(this,r)}}var Me=function(s){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__._)(d,s);var c=De(d);function d(e,t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_9__._)(this,d),(r=c.call(this,e,t)).state={rowCount:r.props.rowCount,columns:r.props.columns,columnResized:!1},r.virtualizedTableRef=react__WEBPACK_IMPORTED_MODULE_0___default().createRef(),r.lastChecked=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(e.rowsSelected)?null:e.rowsSelected.slice(-1).pop(),r.isOverSelectOption=!1,r.mouseEventCalled=!1,r.keyBoardEventCalled=!1,r.cellRenderer=r.cellRenderer.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r.selectAll=r.selectAll.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r.headerRowRenderer=r.headerRowRenderer.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r.headerColRenderer=r.headerColRenderer.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r.onRowClick=r.onRowClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r.overSelectOption=r.overSelectOption.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r.resizeColumn=r.resizeColumn.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_9__.a)(d,[{key:"componentDidUpdate",value:function(){"function"==typeof this.props.rowHeight&&this.recomputeRowHeights()}},{key:"onRowClick",value:function(e,t,r){if("bx--select-option"===e.target.className)e.stopPropagation();else{var o=!this.isRowSelected(t.originalRowIndex);"function"==typeof this.props.setRowsSelected&&(this.props.setRowsSelected({index:r,originalRowIndex:t.originalRowIndex,selected:o,isOverSelectOption:this.isOverSelectOption,selectMultipleRows:!!e.shiftKey&&e.shiftKey,lastCheckedRow:null===this.lastChecked?0:this.lastChecked},e),this.lastChecked=t.index)}}},{key:"onRowDoubleClick",value:function(e,t,r){this.props.onRowDoubleClick&&this.props.onRowDoubleClick(e,t,r)}},{key:"getCheckboxLabelColumnIndex",value:function(e){for(var t=0;t<e.length;t++)if("index"!==e[t].operation)return t;return 0}},{key:"getColumnIndex",value:function(e,t){return e.findIndex((function(e){return e.key===t}))}},{key:"getColumnWiseDeltas",value:function(r,o){var l={};if(r.length>0){r.sort((function(e,t){return e.width-t.width}));for(var i=o,n=0;n<r.length;n++){var s=r.slice(n).reduce((function(e,t){return e+t.width}),0),a=Math.round(r[n].width*i/s);r[n].headerLabel.length>0&&r[n].width-a<_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.s?a=r[n].width-_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.s:r[n].width-a<_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.t&&(a=r[n].width-_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.t),i-=a,l[r[n].key]=a}if(i>0)return Ee(l,(function(){return 0}))}return l}},{key:"isRowSelected",value:function(e){return!!this.props.rowsSelected&&this.props.rowsSelected.indexOf(e)>-1}},{key:"isLastColumn",value:function(e){var t=this.getColumnIndex(this.props.columns,e)===this.props.columns.length-1;return t}},{key:"selectAll",value:function(e){this.props.setAllRowsSelected(e)}},{key:"cellRenderer",value:function(e){var t=e.cellData;return null==t?"":t}},{key:"cellRendererHTML",value:function(e){var t=e.cellData;return null==t?"":react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{dangerouslySetInnerHTML:{__html:t}})}},{key:"recomputeRowHeights",value:function(e){this.virtualizedTableRef&&this.virtualizedTableRef.current&&this.virtualizedTableRef.current.recomputeRowHeights(e)}},{key:"headerRowRenderer",value:function(e,t){var o=t.className,l=t.columns,i=t.style,n=void 0===this.props.columns||0===this.props.columns.length?0:this.getCheckboxLabelColumnIndex(this.props.columns),s=void 0===this.props.columns||0===this.props.columns.length?"":this.props.columns[n].headerLabel,a=this.props.intl.formatMessage({id:"virtualizedTable.header.checkbox.label",defaultMessage:J["virtualizedTable.header.checkbox.label"]},{header_checkbox_label:s}),c=this.props.selectable&&this.props.rowSelection!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.R.SINGLE?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{role:"columnheader",className:"properties-vt-header-checkbox"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_11__["default"],{id:"properties-vt-hd-cb-".concat(e),onChange:this.selectAll,checked:this.props.checkedAll,labelText:a,hideLabel:!0})):"";return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:o,"data-role":"properties-header-row",role:"row",style:i},c,l)}},{key:"headerColRenderer",value:function(e){var t=this,r=e.columnData,n=e.dataKey,s=e.disableSort,a=e.label;e.sortBy,e.sortDirection;var c=null;if(void 0!==this.props.sortColumns[n]){var d=null;switch(this.props.sortColumns[n]){case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.n.ASC:d=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_12__.ArrowUp16,{disabled:this.props.tableState===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.S.DISABLED});break;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.n.DESC:d=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_12__.ArrowDown16,{disabled:this.props.tableState===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.S.DISABLED});break;default:d=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_12__.ArrowsVertical16,{disabled:this.props.tableState===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.S.DISABLED})}c=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{className:"properties-ft-column-sort-icon"},d)}var p=null;r.description&&r.headerLabel?p=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-tooltips"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{style:{fontWeight:"bold"}},r.headerLabel),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("br",null),r.description):r.description?p=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-tooltips"},r.description):r.headerLabel&&(p=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-tooltips"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{style:{fontWeight:"bold"}},r.headerLabel)));var u=(0,uuid__WEBPACK_IMPORTED_MODULE_5__.v4)()+"-tooltip-column-"+n,h=r.resizable&&!this.isLastColumn(n)?react__WEBPACK_IMPORTED_MODULE_0___default().createElement((react_draggable__WEBPACK_IMPORTED_MODULE_4___default()),{axis:"x",defaultClassName:"properties-vt-header-resize",defaultClassNameDragging:"properties-vt-header-resize-active",onDrag:function(e,r){var o=r.deltaX;t.resizeColumn({dataKey:n,deltaX:o})},position:{x:0},zIndex:999},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{role:"button",tabIndex:"0","aria-label":"Resize column"})):"";return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.c)({"properties-vt-column-with-resize":""!==h,"properties-vt-column-without-resize":""===h})},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.c)("properties-vt-column properties-tooltips-container",{"sort-column-active":n===this.props.sortBy})},(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(p)?a:react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_13__["default"],{id:u,tip:p,direction:"bottom",className:"properties-tooltips"},a),!1===s&&c),h)}},{key:"resizeColumn",value:function(r){var o=this,l=r.dataKey,i=r.deltaX;this.setState((function(r){var n=r.columns,s=o.getColumnIndex(n,l),a=n.slice(s+1).filter((function(e){return!e.staticWidth})).filter((function(r){return!(i>=0)||(r.headerLabel.length>0?r.width>_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.s:r.width>_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.t)})),c=o.getColumnWiseDeltas(a,i),d=Object.keys(c),p=Object.values(c).every((function(e){return 0===e}));return n[s].width+i>_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.s&&!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(c)&&!p&&(n[s].width+=i,d.forEach((function(e){var t=n.findIndex((function(t){return t.key===e}));n[t].width-=c[e]}))),{columnResized:!0,columns:n}}))}},{key:"overSelectOption",value:function(e){"mouseenter"!==e.type||this.keyBoardEventCalled?"mouseleave"===e.type&&this.mouseEventCalled?(this.mouseEventCalled=!1,this.isOverSelectOption=!this.isOverSelectOption):"focus"!==e.type||this.mouseEventCalled?"blur"===e.type&&this.keyBoardEventCalled&&(this.keyBoardEventCalled=!1,this.isOverSelectOption=!this.isOverSelectOption):(this.keyBoardEventCalled=!0,this.isOverSelectOption=!this.isOverSelectOption):(this.mouseEventCalled=!0,this.isOverSelectOption=!this.isOverSelectOption)}},{key:"rowRenderer",value:function(e,t){var o=this,l=t.className,n=t.columns,s=t.index,a=t.key,c=t.rowData,d=t.style,p="",u=!1,h="boolean"==typeof c.disabled&&c.disabled;if("function"==typeof this.props.rowHeight&&0===this.props.rowHeight({index:s}))return null;if(this.props.selectable){var b=this.isRowSelected(c.originalRowIndex);if(u=this.props.selectable&&b,this.props.rowSelection!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.R.SINGLE){var f=this.props.intl.formatMessage({id:"virtualizedTable.row.checkbox.label",defaultMessage:J["virtualizedTable.row.checkbox.label"]},{row_index:s+1,table_label:this.props.tableLabel?this.props.tableLabel:""});p=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-vt-row-checkbox",role:"gridcell",onMouseEnter:function(e){return o.overSelectOption(e)},onMouseLeave:function(e){return o.overSelectOption(e)},onFocus:function(e){return o.overSelectOption(e)},onBlur:function(e){return o.overSelectOption(e)}},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_11__["default"],{id:"properties-vt-row-cb-".concat(e,"-").concat(s),key:"properties-vt-row-cb-".concat(e,"-").concat(s),labelText:f,hideLabel:!0,checked:b,disabled:h}))}}if(this.props.summaryTable&&(p=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-vt-row-checkbox"})),!0===c.loading)return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:l,key:a,"data-role":"properties-loading-row",role:"row",style:d},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_14__["default"],{className:"properties-vt-small-loading",small:!0,withOverlay:!1}));var m=parseInt(d.width,10)+"px",v=Object.assign({},d,{width:m});return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{style:{},key:a,className:"properties-vt-double-click",onDoubleClick:function(e){return o.onRowDoubleClick(e,c.rowKey,s)}},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.c)(l,{"properties-vt-row-selected":u},{"properties-vt-row-disabled":h},{"properties-vt-row-non-interactive":!this.props.selectable}),"data-role":"properties-data-row",role:"row",style:v,onMouseDown:function(e){return o.onRowClick(e,c,s)},onKeyPress:function(e){"Space"!==e.code&&"Enter"!==e.code||o.onRowClick(e,c,s)}},p,n))}},{key:"render",value:function(){var e=this;return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-vt"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.c)("properties-vt-autosizer",{"properties-vt-single-selection":this.props.rowSelection&&this.props.rowSelection===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.R.SINGLE,"properties-light-disabled":!this.props.light})},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_virtualized__WEBPACK_IMPORTED_MODULE_3__.AutoSizer,null,(function(t){var r=t.height,o=t.width;return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_virtualized__WEBPACK_IMPORTED_MODULE_3__.Table,{ref:e.virtualizedTableRef,width:o||500,height:r||2e3,className:"properties-autosized-vt","aria-label":e.props.tableLabel?e.props.tableLabel:"",disableHeader:e.props.disableHeader,headerClassName:"properties-autosized-vt-header",headerHeight:32,headerRowRenderer:e.headerRowRenderer.bind(e,e.props.scrollKey),onHeaderClick:e.props.onHeaderClick,rowClassName:"properties-vt-row-class",rowHeight:e.props.rowHeight?e.props.rowHeight:32,rowCount:e.state.rowCount,rowGetter:e.props.rowGetter,rowRenderer:e.rowRenderer.bind(e,e.props.scrollKey),scrollToIndex:e.props.scrollToIndex,scrollToAlignment:e.props.scrollToAlignment,sort:e.props.onSort,sortDirection:e.props.sortDirection},e.state.columns.map((function(t){return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_virtualized__WEBPACK_IMPORTED_MODULE_3__.Column,(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__._)({key:t.key,label:t.label,dataKey:t.key,width:t.width,columnData:t,disableSort:void 0===e.props.sortColumns[t.key],cellRenderer:t.isHTML?e.cellRendererHTML:e.cellRenderer,headerRenderer:e.headerColRenderer},t.minWidth&&{minWidth:t.minWidth}))})))}))))}}],[{key:"getDerivedStateFromProps",value:function(e,t){var r={};return e.rowCount!==t.rowCount&&(r.rowCount=e.rowCount),t.columnResized&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.h)(He(e.columns,t.columns,"headerLabel"))||(r.columns=e.columns),r}}]),d}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));Me.defaultProps={disableHeader:!1};var Le=(0,react_intl__WEBPACK_IMPORTED_MODULE_1__.injectIntl)(Me);function ze(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return Be(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return Be(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var o=0,l=function(){};return{s:l,n:function(){return o>=e.length?{done:!0}:{done:!1,value:e[o++]}},e:function(e){throw e},f:l}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,n=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return n=e.done,e},e:function(e){s=!0,i=e},f:function(){try{n||null==r.return||r.return()}finally{if(s)throw i}}}}function Be(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,o=new Array(t);r<t;r++)o[r]=e[r];return o}function _e(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.a)(e);if(t){var l=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.a)(this).constructor;r=Reflect.construct(o,arguments,l)}else r=o.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.b)(this,r)}}var Pe=function(e){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__._)(c,e);var t=_e(c);function c(e){var r;(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_9__._)(this,c);var o={};if(void 0!==(r=t.call(this,e)).props.sortable)for(var i=0;i<r.props.sortable.length;i++){o[r.props.sortable[i]]=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.n.NOT_SORTED}return r.state={checkedAllRows:!1,columnSortDir:o,currentSortColumn:"",tableWidth:0,tableHeight:0},r.rowHeight=r.rowHeight.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r.rowGetter=r.rowGetter.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r.getOriginalRowIndex=r.getOriginalRowIndex.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r.getLastChildPropertyIdRow=r.getLastChildPropertyIdRow.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r.calculateColumnWidths=r.calculateColumnWidths.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r.handleFilterChange=r.handleFilterChange.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r.onSort=r.onSort.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r.sortHeaderClick=r.sortHeaderClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r._updateTableWidth=r._updateTableWidth.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r._adjustTableHeight=r._adjustTableHeight.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r.handleCheckedRow=r.handleCheckedRow.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r.handleCheckedAllRows=r.handleCheckedAllRows.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r.handleCheckedMultipleRows=r.handleCheckedMultipleRows.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_9__.a)(c,[{key:"componentDidMount",value:function(){this._adjustTableHeight(),window.addEventListener("resize",this._adjustTableHeight),this.tableNode=react_dom__WEBPACK_IMPORTED_MODULE_2___default().findDOMNode(this.refs.table)}},{key:"componentDidUpdate",value:function(e,t){e.rows===this.props.rows&&e.columns===this.props.columns&&e.noAutoSize===this.props.noAutoSize||this._adjustTableHeight(),this.props.selectedRows&&this.setCheckedAll(this.props.selectedRows),this.tableNode=react_dom__WEBPACK_IMPORTED_MODULE_2___default().findDOMNode(this.refs.table)}},{key:"componentWillUnmount",value:function(){window.removeEventListener("resize",this._adjustTableHeight)}},{key:"onSort",value:function(e){var t=e.sortBy;if(this.props.onSort){var r={column:t,direction:this.state.columnSortDir[t]===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.n.ASC?_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.n.DESC:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.n.ASC};this.props.onSort(r)}}},{key:"getOriginalRowIndex",value:function(e,t){var r=t;return e.columns&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e.columns[0],"content.props.children.props.propertyId.propertyId")?r=this.getLastChildPropertyIdRow(e.columns[0].content.props.children.props.propertyId,t):e.columns&&(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_6__.j)(e.columns[0],"content.props.children.props.propertyId.row")?r=e.columns[0].content.props.children.props.propertyId.row:"number"==typeof e.rowKey&&(r=parseInt(e.rowKey,10)),r}},{key:"getLastChildPropertyIdRow",value:function(e,t){return void 0!==e.propertyId?this.getLastChildPropertyIdRow(e.propertyId):void 0!==e.row?e.row:t}},{key:"setCheckedAll",value:function(e){for(var t=!0,r=0;r<this.props.data.length;r++){var o=this.props.data[r],l=this.getOriginalRowIndex(o,r);if(e.indexOf(l)<0){t=!1;break}}this.state.checkedAllRows!==t&&this.setState({checkedAllRows:t})}},{key:"calculateColumnWidths",value:function(e,t){var o=t-12;this.props.rowSelection!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.R.SINGLE&&(o-=40);var l,i=e.length,n=0,s=ze(e);try{for(s.s();!(l=s.n()).done;){var a=l.value;a.width&&("string"==typeof a.width&&a.width.includes("px")?(o-=parseInt(a.width,10),i--):n=Math.max(n,a.width))}}catch(e){s.e(e)}finally{s.f()}var c,d=[],p=Math.floor(o/i),u=[],h=0,b=ze(e);try{for(b.s();!(c=b.n()).done;){var f=c.value;f.width&&!isNaN(f.width)?(u.push(f.width/n),h+=f.width/n):u.push(null)}}catch(e){b.e(e)}finally{b.f()}for(var m=o/h,v=0,w=0;w<e.length;w++){var g=e[w];if(g.width)if("string"==typeof g.width&&g.width.includes("px"))d.push(Math.floor(parseInt(g.width,10))+"px"),v+=parseInt(g.width,10);else{var y=Math.floor(u[w]*m);d.push(y+"px"),v+=y}else d.push(p),v+=p}var k=t;if(this.props.rowSelection!==_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.R.SINGLE&&(k-=40),v<k){var C=parseInt(d[0],10);d[0]=C+k-v+"px"}return d}},{key:"_updateTableWidth",value:function(e,t){this.state.tableWidth!==Math.floor(e-2)&&this.setState({tableWidth:Math.floor(e-2)})}},{key:"_adjustTableHeight",value:function(){if(!this.props.noAutoSize){var e=this.state.tableHeight,t=void 0!==this.props.rows?this.props.rows:5.5;if(Array.isArray(this.props.data)&&this.props.data.length<t)e=2*this.props.data.length+2+"rem";else if(t>0)e=2*t+2+"rem";else if(0===t)e="2rem";else if(-1===t&&this.flexibleTable){var r=void 0!==this.flexibleTableHeader?react_dom__WEBPACK_IMPORTED_MODULE_2___default().findDOMNode(this.flexibleTableHeader).getBoundingClientRect().height:0,o=this.findPropertyNodeHeight(this.flexibleTable,"properties-wf-children");e=0===o?"100vh":"calc(".concat(o-r-50,"px - 3.5rem)")}e!==this.state.tableHeight&&this.setState({tableHeight:e})}}},{key:"findPropertyNodeHeight",value:function(e,t){if(e&&e.parentNode&&e.parentNode.className&&e.parentNode.className.includes(t)){var r=react_dom__WEBPACK_IMPORTED_MODULE_2___default().findDOMNode(e.parentNode).getBoundingClientRect();return r?r.height:0}return e&&e.parentNode?this.findPropertyNodeHeight(e.parentNode,t):0}},{key:"sortHeaderClick",value:function(e){var t=e.dataKey,r=this.state.columnSortDir;void 0!==r[t]&&(Object.keys(r).forEach((function(e){e!==t&&(r[e]=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.n.NOT_SORTED)})),r[t]=r[t]===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.n.ASC?_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.n.DESC:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.n.ASC,this.setState({columnSortDir:r,currentSortColumn:t}))}},{key:"handleFilterChange",value:function(e){this.props.onFilter&&this.props.onFilter(e.target.value)}},{key:"handleCheckedAllRows",value:function(e){var t=[],r=this.props.data;if(e){t=Array.from(this.props.selectedRows);for(var o=0;o<r.length;o++){var l=this.getOriginalRowIndex(r[o],o);t.push(l)}}t=Array.from(new Set(t)),this.props.updateRowSelections(t),this.setState({checkedAllRows:e})}},{key:"handleCheckedMultipleRows",value:function(e,t,r){var o,l=this.props.selectedRows?this.props.selectedRows:[];return o=e<t?Array.from({length:t-e+1},(function(t,r){return e+r})):Array.from({length:e-t+1},(function(e,r){return t+r})),l=l.filter((function(e){return!o.includes(e)})),r&&(l=l.concat(o)),l}},{key:"handleCheckedRow",value:function(e,t){var o=e.originalRowIndex,l=e.index,i=e.selected,n=e.isOverSelectOption;if(!this.props.data[l].disabled)if(n){var s=this.props.selectedRows?this.props.selectedRows:[];e.selectMultipleRows?(s=this.handleCheckedMultipleRows(e.lastCheckedRow,l,i),this.setCheckedAll(s)):i?(s=s.concat(o),this.setCheckedAll(s)):s&&(s=s.filter((function(e){return e!==o})),this.setState({checkedAllRows:!1})),s.sort((function(e,t){return e-t})),this.props.updateRowSelections(s)}else this.props.rowSelection===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.R.SINGLE&&void 0!==this.props.updateRowSelections&&this.props.updateRowSelections(e.index,t,this.props.data[e.index].rowKey)}},{key:"generateTableHeaderRow",value:function(e){for(var t=[],r="",o=0;o<this.props.columns.length;o++){var l=this.props.columns[o];void 0!==this.props.filterable&&this.props.filterable[0]===l.key&&(r=l.label);var i=Math.abs(parseInt(e[o],10)),n=void 0;"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_8__.d)(l.label)?n=l.label.props.labelText:"string"==typeof l.label&&(n=l.label),t.push({key:l.key,label:l.label,width:i,description:l.description,headerLabel:n,resizable:l.resizable,operation:l.operation,staticWidth:!!l.staticWidth&&l.staticWidth})}return{headers:t,searchLabel:r}}},{key:"rowGetter",value:function(e){var t=e.index,r=this.props.data[t],o=this.getOriginalRowIndex(r,t),l={};if(r.columns)for(var i=0;i<r.columns.length;i++){var n=r.columns[i];l[n.column]=n.content}return Object.assign({},l,{loading:!1,index:t,originalRowIndex:o,rowKey:void 0!==r.rowKey?r.rowKey:this.props.scrollKey+"-row-"+t,disabled:r.disabled})}},{key:"rowHeight",value:function(e){return e.index,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.u}},{key:"render",value:function(){var e=this,t=this.state.tableWidth,r=this.calculateColumnWidths(this.props.columns,t),l=this.generateTableHeaderRow(r),s=l.headers,a=l.searchLabel,c=this.props.tableState===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.S.DISABLED,d=null;if(void 0!==this.props.filterable&&0!==this.props.filterable.length){var p=this.props.intl.formatMessage({id:"table.search.placeholder",defaultMessage:J["table.search.placeholder"]},{column_name:a}),u=this.props.intl.formatMessage({id:"table.search.label",defaultMessage:J["table.search.label"]},{table_name:this.props.tableLabel});d=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.c)("properties-ft-search-container",{disabled:c})},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_15__["default"],{className:"properties-ft-search-text",placeholder:p,onChange:this.handleFilterChange,disabled:c,size:"sm",labelText:u,light:this.props.light}))}var h=-1;void 0!==this.props.scrollToRow&&null!==this.props.scrollToRow&&(h=this.props.scrollToRow);var b={};this.props.noAutoSize||(b={height:this.state.tableHeight});var f=this.props.showHeader?"properties-ft-container-absolute ":"properties-ft-container-absolute-noheader ",m=this.props.messageInfo?f+this.props.messageInfo.type:f+_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__.S.INFO,v=d||this.props.topRightPanel?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-ft-table-header",ref:function(t){return e.flexibleTableHeader=t}},d,this.props.topRightPanel):null;return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":"properties-ft-"+this.props.scrollKey,className:"properties-ft-control-container",ref:function(t){return e.flexibleTable=t}},v,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-ft-container-panel"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_resize_detector__WEBPACK_IMPORTED_MODULE_16__["default"],{handleWidth:!0,onResize:this._updateTableWidth},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-ft-container-wrapper",style:b},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:m},this.props.selectedEditRow,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Le,(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_10__._)({tableLabel:this.props.tableLabel,columns:s,onHeaderClick:this.sortHeaderClick,rowCount:this.props.data.length,rowHeight:this.rowHeight,rowGetter:this.rowGetter,summaryTable:this.props.summaryTable,selectable:void 0!==this.props.updateRowSelections,rowSelection:this.props.rowSelection,disableHeader:!this.props.showHeader,onRowDoubleClick:this.props.onRowDoubleClick,rowsSelected:this.props.selectedRows,checkedAll:this.state.checkedAllRows,setRowsSelected:this.handleCheckedRow,setAllRowsSelected:this.handleCheckedAllRows,scrollKey:this.props.scrollKey,onSort:this.onSort,sortBy:this.state.currentSortColumn,sortColumns:this.state.columnSortDir,sortDirection:this.state.columnSortDir[this.state.currentSortColumn],tableState:this.props.tableState,light:this.props.light},-1!==h&&{scrollToIndex:h,scrollToAlignment:"center"})))))))}}]),c}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));Pe.defaultProps={showHeader:!0,light:!0};var je=(0,react_intl__WEBPACK_IMPORTED_MODULE_1__.injectIntl)(Pe);
//# sourceMappingURL=flexible-table-d4a68ebb.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/getPrototypeOf-97272efe.js":
/*!************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/getPrototypeOf-97272efe.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "_": () => (/* binding */ o),
/* harmony export */   "a": () => (/* binding */ u),
/* harmony export */   "b": () => (/* binding */ n),
/* harmony export */   "c": () => (/* binding */ t),
/* harmony export */   "d": () => (/* binding */ r)
/* harmony export */ });
function t(t){if(void 0===t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return t}function e(t,o){return e=Object.setPrototypeOf||function(t,e){return t.__proto__=e,t},e(t,o)}function o(t,o){if("function"!=typeof o&&null!==o)throw new TypeError("Super expression must either be null or a function");t.prototype=Object.create(o&&o.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),Object.defineProperty(t,"prototype",{writable:!1}),o&&e(t,o)}function r(t){return r="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},r(t)}function n(e,o){if(o&&("object"===r(o)||"function"==typeof o))return o;if(void 0!==o)throw new TypeError("Derived constructors may only return object or undefined");return t(e)}function u(t){return u=Object.setPrototypeOf?Object.getPrototypeOf:function(t){return t.__proto__||Object.getPrototypeOf(t)},u(t)}
//# sourceMappingURL=getPrototypeOf-97272efe.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/icon-caf4caca.js":
/*!**************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/icon-caf4caca.js ***!
  \**************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "I": () => (/* binding */ P)
/* harmony export */ });
/* harmony import */ var _createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./createClass-32a0cf0f.js */ "../../node_modules/@elyra/canvas/dist/createClass-32a0cf0f.js");
/* harmony import */ var _getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./getPrototypeOf-97272efe.js */ "../../node_modules/@elyra/canvas/dist/getPrototypeOf-97272efe.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./extends-cf86ca1c.js */ "../../node_modules/@elyra/canvas/dist/extends-cf86ca1c.js");
/* harmony import */ var react_inlinesvg__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! react-inlinesvg */ "../../node_modules/react-inlinesvg/esm/index.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-10.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-29.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-14.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-0.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-23.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-22.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-15.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-11.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-4.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-3.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-27.js");
/* harmony import */ var _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./canvas-constants-3c09c7f6.js */ "../../node_modules/@elyra/canvas/dist/canvas-constants-3c09c7f6.js");
function G(e){var s=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var a,c=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_1__.a)(e);if(s){var i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_1__.a)(this).constructor;a=Reflect.construct(c,arguments,i)}else a=c.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_1__.b)(this,a)}}var P=function(t){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_1__._)(P,t);var r=G(P);function P(){var s;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_2__._)(this,P),(s=r.call(this)).canvasIcons={double:"data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2032%2032%22%3E%3Cpath%20d%3D%22M17%2C8V6H13V2H11V6H8V2H6V6H2V8H6v3H2v2H6v4H8V13h3v4h2V13h4V11H13V8Zm-6%2C3H8V8h3Z%22%2F%3E%3Cpath%20d%3D%22M30%2C21V19H26V15H24v4H21V15H19v4H15v2h4v3H15v2h4v4h2V26h3v4h2V26h4V24H26V21Zm-6%2C3H21V21h3Z%22%2F%3E%3Crect%20width%3D%2232%22%20height%3D%2232%22%20fill%3D%22none%22%2F%3E%3C%2Fsvg%3E",integer:"data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2032%2032%22%3E%3Cpath%20d%3D%22M28%2C12V10H22V4H20v6H12V4H10v6H4v2h6v8H4v2h6v6h2V22h8v6h2V22h6V20H22V12Zm-8%2C8H12V12h8Z%22%2F%3E%3Crect%20width%3D%2232%22%20height%3D%2232%22%20fill%3D%22none%22%2F%3E%3C%2Fsvg%3E",string:"data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2032%2032%22%3E%3Cpath%20d%3D%22M29%2C22H24a2%2C2%2C0%2C0%2C1-2-2V14a2%2C2%2C0%2C0%2C1%2C2-2h5v2H24v6h5Z%22%2F%3E%3Cpath%20d%3D%22M18%2C12H14V8H12V22h6a2%2C2%2C0%2C0%2C0%2C2-2V14A2%2C2%2C0%2C0%2C0%2C18%2C12Zm-4%2C8V14h4v6Z%22%2F%3E%3Cpath%20d%3D%22M8%2C12H3v2H8v2H4a2%2C2%2C0%2C0%2C0-2%2C2v2a2%2C2%2C0%2C0%2C0%2C2%2C2h6V14A2%2C2%2C0%2C0%2C0%2C8%2C12Zm0%2C8H4V18H8Z%22%2F%3E%3Crect%20width%3D%2232%22%20height%3D%2232%22%20fill%3D%22none%22%2F%3E%3C%2Fsvg%3E"},s}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_2__.a)(P,[{key:"getCarbonIcon",value:function(e,s){var a="properties-icon "+s;switch(e){case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_3__.E:case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.d.ERROR:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_5__.ErrorFilled16,{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.c)("canvas-state-icon-error",a),disabled:this.props.disabled});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_3__.W:case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.d.WARNING:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_6__.WarningFilled16,{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.c)("canvas-state-icon-warning",a),disabled:this.props.disabled});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_3__.S:case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.d.SUCCESS:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_7__.CheckmarkFilled16,{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.c)("canvas-state-icon-success",a),disabled:this.props.disabled});case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.d.INFO:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__.InformationFilled16,{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.c)("canvas-state-icon-info",a),disabled:this.props.disabled});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_3__.I:case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.g.INFORMATION:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__.Information16,{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.c)("canvas-state-icon-information-hollow",a),disabled:this.props.disabled});case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.g.CHEVRONARROWS.UP:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_7__.ChevronUp16,{className:a,disabled:this.props.disabled});case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.g.CHEVRONARROWS.DOWN:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_7__.ChevronDown16,{className:a,disabled:this.props.disabled});case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.g.CHEVRONARROWS.LEFT:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_7__.ChevronLeft16,{className:a,disabled:this.props.disabled});case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.g.CHEVRONARROWS.RIGHT:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_7__.ChevronRight16,{className:a,disabled:this.props.disabled});case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.g.ADD:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_9__.AddAlt16,{className:a,disabled:this.props.disabled});case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.g.SETTINGS:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_10__.Settings16,{className:a,disabled:this.props.disabled});case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.g.EDIT:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_5__.Edit16,{className:a,disabled:this.props.disabled});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_3__.a.SEARCH:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_10__.Search16,{className:a,disabled:this.props.disabled});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_3__.a.WARNING_UNFILLED:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_6__.Warning16,{className:a,disabled:this.props.disabled});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_3__.C.CHEVRONARROWS.RIGHT:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_7__.ChevronRight16,{className:a,disabled:this.props.disabled});case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.g.MEASUREMENTS.EMPTY:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_7__.CircleDash16,{className:a,disabled:this.props.disabled});case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.g.MEASUREMENTS.SCALE:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_11__.RulerAlt16,{className:a,disabled:this.props.disabled});case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.g.MEASUREMENTS.ORDINAL:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_12__.ListNumbered16,{className:a,disabled:this.props.disabled});case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.g.MEASUREMENTS.NOMINAL:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_12__.ListBulleted16,{className:a,disabled:this.props.disabled});case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.g.MEASUREMENTS.FLAG:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_13__.Flag16,{className:a,disabled:this.props.disabled});case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.g.MEASUREMENTS.DISCRETE:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_14__.ChartVennDiagram16,{className:a,disabled:this.props.disabled});case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.m.DATE:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_15__.Calendar16,{className:a,disabled:this.props.disabled});case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.m.TIME:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_16__.Time16,{className:a,disabled:this.props.disabled});case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.m.TIMESTAMP:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_5__.EventSchedule16,{className:a,disabled:this.props.disabled});default:return null}}},{key:"getCanvasIcon",value:function(e){return this.canvasIcons[e]}},{key:"render",value:function(){var e=this.getCarbonIcon(this.props.type,this.props.className);if(!e)if(void 0!==(e=this.getCanvasIcon(this.props.type))){var s=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_4__.c)("canvas-icon","properties-icon",this.props.className);e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_inlinesvg__WEBPACK_IMPORTED_MODULE_17__["default"],{src:e,className:s,disabled:this.props.disabled})}else e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null);return e}}]),P}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));P.defaultProps={className:"",disabled:!1};
//# sourceMappingURL=icon-caf4caca.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/index-beefcd21.js":
/*!***************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/index-beefcd21.js ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "C": () => (/* binding */ ee),
/* harmony export */   "E": () => (/* binding */ J),
/* harmony export */   "F": () => (/* binding */ lt),
/* harmony export */   "G": () => (/* binding */ q),
/* harmony export */   "I": () => (/* binding */ $),
/* harmony export */   "O": () => (/* binding */ ae),
/* harmony export */   "P": () => (/* binding */ X),
/* harmony export */   "S": () => (/* binding */ Z),
/* harmony export */   "T": () => (/* binding */ re),
/* harmony export */   "_": () => (/* binding */ Se),
/* harmony export */   "a": () => (/* binding */ te),
/* harmony export */   "b": () => (/* binding */ Re),
/* harmony export */   "c": () => (/* binding */ We),
/* harmony export */   "d": () => (/* binding */ ne),
/* harmony export */   "e": () => (/* binding */ xe),
/* harmony export */   "f": () => (/* binding */ je),
/* harmony export */   "g": () => (/* binding */ He),
/* harmony export */   "h": () => (/* binding */ Q),
/* harmony export */   "i": () => (/* binding */ Ue),
/* harmony export */   "j": () => (/* binding */ W),
/* harmony export */   "k": () => (/* binding */ nt),
/* harmony export */   "l": () => (/* binding */ ke),
/* harmony export */   "m": () => (/* binding */ Ze),
/* harmony export */   "n": () => (/* binding */ Qe),
/* harmony export */   "o": () => (/* binding */ ie),
/* harmony export */   "p": () => (/* binding */ qe),
/* harmony export */   "q": () => (/* binding */ Je),
/* harmony export */   "r": () => (/* binding */ Ve),
/* harmony export */   "s": () => (/* binding */ $e),
/* harmony export */   "t": () => (/* binding */ we),
/* harmony export */   "u": () => (/* binding */ Xe),
/* harmony export */   "v": () => (/* binding */ ze),
/* harmony export */   "w": () => (/* binding */ Be),
/* harmony export */   "x": () => (/* binding */ Ke)
/* harmony export */ });
/* harmony import */ var _createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./createClass-32a0cf0f.js */ "../../node_modules/@elyra/canvas/dist/createClass-32a0cf0f.js");
/* harmony import */ var _getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./getPrototypeOf-97272efe.js */ "../../node_modules/@elyra/canvas/dist/getPrototypeOf-97272efe.js");
/* harmony import */ var _isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./isArrayLikeObject-a9c7973b.js */ "../../node_modules/@elyra/canvas/dist/isArrayLikeObject-a9c7973b.js");
/* harmony import */ var _flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./flexible-table-d4a68ebb.js */ "../../node_modules/@elyra/canvas/dist/flexible-table-d4a68ebb.js");
/* harmony import */ var _baseForOwn_d38b560e_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./_baseForOwn-d38b560e.js */ "../../node_modules/@elyra/canvas/dist/_baseForOwn-d38b560e.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var uuid__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! uuid */ "webpack/sharing/consume/default/uuid/uuid");
/* harmony import */ var uuid__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(uuid__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./lib/tooltip.es.js */ "../../node_modules/@elyra/canvas/dist/lib/tooltip.es.js");
/* harmony import */ var react_intl__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! react-intl */ "webpack/sharing/consume/default/react-intl/react-intl");
/* harmony import */ var react_intl__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react_intl__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/Button/Button.js");
/* harmony import */ var _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./extends-cf86ca1c.js */ "../../node_modules/@elyra/canvas/dist/extends-cf86ca1c.js");
/* harmony import */ var _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./canvas-constants-3c09c7f6.js */ "../../node_modules/@elyra/canvas/dist/canvas-constants-3c09c7f6.js");
/* harmony import */ var _en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./en-8647c347.js */ "../../node_modules/@elyra/canvas/dist/en-8647c347.js");
/* harmony import */ var _icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./icon-caf4caca.js */ "../../node_modules/@elyra/canvas/dist/icon-caf4caca.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-1.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-22.js");
function Y(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,s=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;r=Reflect.construct(s,arguments,i)}else r=s.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,r)}}var V=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,react__WEBPACK_IMPORTED_MODULE_0__.Component);var a=Y(s);function s(){return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),a.apply(this,arguments)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"render",value:function(){var e,t,r=void 0===this.props.applyLabel?this.props.intl.formatMessage({id:"propertiesEdit.applyButton.label",defaultMessage:_flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_5__.d["propertiesEdit.applyButton.label"]}):this.props.applyLabel,n=void 0===this.props.rejectLabel?this.props.intl.formatMessage({id:"propertiesEdit.rejectButton.label",defaultMessage:_flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_5__.d["propertiesEdit.rejectButton.label"]}):this.props.rejectLabel;return this.props.cancelHandler&&(e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_6__["default"],{"data-id":"properties-cancel-button",className:"properties-cancel-button",type:"button",size:"small",kind:"secondary",onClick:this.props.cancelHandler},n)),this.props.okHandler&&(t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_6__["default"],{"data-id":"properties-apply-button",className:"properties-apply-button",type:"button",size:"small",onClick:this.props.okHandler,disabled:!this.props.applyButtonEnabled},r)),this.props.okHandler||this.props.cancelHandler?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.c)("properties-modal-buttons",{hide:void 0!==this.props.showPropertiesButtons&&!this.props.showPropertiesButtons})},e,t):null}}]),s}();V.defaultProps={applyButtonEnabled:!0};var X=(0,react_intl__WEBPACK_IMPORTED_MODULE_2__.injectIntl)(V),z=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.D;var W=function(e,t){return z(e,t)},$={CONTROL:"control",ADDITIONAL_LINK:"additionalLink",STATIC_TEXT:"staticText",HORIZONTAL_SEPARATOR:"hSeparator",PANEL:"panel",SUB_TABS:"subTabs",PRIMARY_TABS:"primaryTabs",PANEL_SELECTOR:"panelSelector",CUSTOM_PANEL:"customPanel",ACTION:"action",TEXT_PANEL:"textPanel"},J={INLINE:"inline",SUBPANEL:"subpanel",ON_PANEL:"on_panel"},Z={LARGE:"large",MEDIUM:"medium",SMALL:"small"},q={CONTROLS:"controls",TABS:"tabs",SUB_TABS:"subTabs",PANELS:"panels",ADDITIONAL:"additional",COLUMN_SELECTION:"columnSelection",PANEL_SELECTOR:"panelSelector",CUSTOM_PANEL:"customPanel",SUMMARY_PANEL:"summaryPanel",ACTION_PANEL:"actionPanel",TEXT_PANEL:"textPanel",TWISTY_PANEL:"twistyPanel",COLUMN_PANEL:"columnPanel"},Q={GENERAL:"general",COLUMN_SELECTION:"columnSelection",CUSTOM:"custom",SUMMARY:"summary",ACTION_PANEL:"actionPanel",TWISTY_PANEL:"twisty",COLUMN_PANEL:"column"},ee={CUSTOM:"custom",TEXTFIELD:"textfield",PASSWORDFIELD:"passwordfield",TEXTAREA:"textarea",LIST:"list",EXPRESSION:"expression",NUMBERFIELD:"numberfield",DATEFIELD:"datefield",TIMEFIELD:"timefield",TIMESTAMP:"timestampfield",CHECKBOX:"checkbox",RADIOSET:"radioset",CHECKBOXSET:"checkboxset",ONEOFSELECT:"oneofselect",MULTISELECT:"multiselect",SOMEOFSELECT:"someofselect",SELECTCOLUMN:"selectcolumn",SELECTCOLUMNS:"selectcolumns",SELECTSCHEMA:"selectschema",STRUCTURETABLE:"structuretable",STRUCTUREEDITOR:"structureeditor",STRUCTURELISTEDITOR:"structurelisteditor",TOGGLETEXT:"toggletext",READONLY:"readonly",READONLYTABLE:"readonlyTable",SPINNER:"spinner",CODE:"code",HIDDEN:"hidden"},te={TEXT:"text",ENUM:"enum",COLUMN:"column",NEW_COLUMN:"new_column",EXPRESSION:"expression",EMAIL:"email",URL:"url",COLOR:"color",INTERVAL_YEAR:"interval_year",INTERVAL_DAY:"interval_day",INTERVAL_SECOND:"interval_second",CUSTOM:"custom",UNSPECIFIED:""},re={BOOLEAN:"boolean",INTEGER:"integer",LONG:"long",DOUBLE:"double",STRING:"string",PASSWORD:"password",DATE:"date",TIME:"time",TIMESTAMP:"timestamp",STRUCTURE:"structure",OBJECT:"object"},ne={BEFORE:"before",AFTER:"after"},ae={VERTICAL:"vertical",HORIZONTAL:"horizontal"},se=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.n;var ie=function(e,t){return function(r,n){if(null==r)return r;if(!se(r))return e(r,n);for(var a=r.length,s=t?a:-1,i=Object(r);(t?s--:++s<a)&&!1!==n(i[s],s,i););return r}}(_baseForOwn_d38b560e_js__WEBPACK_IMPORTED_MODULE_9__._),oe=ie,le=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.n;var ce=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.J;var ue=function(e,t){if(e!==t){var r=void 0!==e,n=null===e,a=e==e,s=ce(e),i=void 0!==t,o=null===t,l=t==t,c=ce(t);if(!o&&!c&&!s&&e>t||s&&i&&l&&!o&&!c||n&&i&&l||!r&&l||!a)return 1;if(!n&&!s&&!c&&e<t||c&&r&&a&&!n&&!s||o&&r&&a||!i&&a||!l)return-1}return 0};var fe=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.g,pe=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__._,de=_flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_5__._,me=function(e,t){var r=-1,n=le(e)?Array(e.length):[];return oe(e,(function(e,a,s){n[++r]=t(e,a,s)})),n},he=function(e,t){var r=e.length;for(e.sort(t);r--;)e[r]=e[r].value;return e},Ee=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.s,ve=function(e,t,r){for(var n=-1,a=e.criteria,s=t.criteria,i=a.length,o=r.length;++n<i;){var l=ue(a[n],s[n]);if(l)return n>=o?l:l*("desc"==r[n]?-1:1)}return e.index-t.index},ye=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.G,be=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.y;var Te=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.K,Ne=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.n,Le=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.L,ge=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.M;var Se=function(e,t,r){if(!ge(r))return!1;var n=typeof t;return!!("number"==n?Ne(r)&&Le(t,r.length):"string"==n&&t in r)&&Te(r[t],e)},Ae=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.b,Oe=function(e,t,r){t=t.length?fe(t,(function(e){return be(e)?function(t){return pe(t,1===e.length?e[0]:e)}:e})):[ye];var n=-1;t=fe(t,Ee(de));var a=me(e,(function(e,r,a){return{criteria:fe(t,(function(t){return t(e)})),index:++n,value:e}}));return he(a,(function(e,t){return ve(e,t,r)}))},Ie=Se,Re=(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.m)((function(e,t){if(null==e)return[];var r=t.length;return r>1&&Ie(e,t[0],t[1])?t=[]:r>2&&Ie(t[0],t[1],t[2])&&(t=[t[0]]),Oe(e,Ae(t,1),[])})),Ce={};function Me(e,t,r){var n="",a="",s="";return r&&(n=r+": "),t&&(t.lineNumber&&(a="(line "+t.lineNumber+"): "),s=t.message?t.message:"Message unavailable"),"["+e+"]: "+n+a+s}Ce.debug=function(e,t){console.log(Me("DEBUG",t,e))},Ce.info=function(e,t){console.log(Me("INFO",t,e))},Ce.warn=function(e,t){console.warn(Me("WARNING",t,e))},Ce.error=function(e,t){console.error(Me("ERROR",t,e))};var ke=Ce;function _e(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return Pe(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return Pe(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,a=function(){};return{s:a,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:a}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var s,i=!0,o=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return i=e.done,e},e:function(e){o=!0,s=e},f:function(){try{i||null==r.return||r.return()}finally{if(o)throw s}}}}function Pe(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function De(e,t){var r=Object.keys(e);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(e);t&&(n=n.filter((function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable}))),r.push.apply(r,n)}return r}function Fe(e){for(var t=1;t<arguments.length;t++){var r=null!=arguments[t]?arguments[t]:{};t%2?De(Object(r),!0).forEach((function(t){(0,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_10__._)(e,t,r[t])})):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(r)):De(Object(r)).forEach((function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(r,t))}))}return e}function we(e){return{}.toString.call(e).match(/\s([a-zA-Z]+)/)[1].toLowerCase()}function Ue(e){return void 0!==e?(0,_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.d)(e):e}function je(e,t,r){var n=Fe(Fe({},_flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_5__.d),_en_8647c347_js__WEBPACK_IMPORTED_MODULE_11__.f);return null!=e?e.formatMessage({id:t,defaultMessage:n[t]},r):n[t]}function Be(){return"properties-"+(0,uuid__WEBPACK_IMPORTED_MODULE_1__.v4)()}function xe(e,t){try{if(!e)return e;var r=e.indexOf("${");if(r<0)return e;var n=e.substr(r+2).indexOf("}");if(n<0)return e;var a=e.substr(r+2,n),s=e.replace("${"+a+"}",function(e,t){var r,n,a=e.indexOf("("),s=e.substr(0,a),i=e.slice(a+1,-1).split(",");if(0===i.length)return"";switch(s){case"percent":return!(n=Ge(i[0],t))||isNaN(n)?0:(r=100/n,i.length>1&&(r=r.toFixed(parseInt(i[1],10))),r);case"sum":r=0;var o,l=_e(i);try{for(l.s();!(o=l.n()).done;){n=Ge(o.value,t),isNaN(n)||(r+=n)}}catch(e){l.e(e)}finally{l.f()}return r}return""}(a,t));return xe(s,t)}catch(t){return ke.warn("Invalid expression.  Make sure replacement expression in text is a valid expression."),e}}function Ge(e,t){return isNaN(e)?t.getPropertyValue({name:e.trim()}):parseFloat(e)}function He(e){if(e)if(e.subControls){for(var t=0;t<e.subControls.length;t++)if(e.subControls[t].role===te.COLUMN)return t}else if(e.role===te.COLUMN)return 0;return-1}function Ke(e){var t={fields:[]};if(e&&e.columns){var r,n=_e(e.columns);try{for(n.s();!(r=n.n()).done;){var a=r.value,s={};s.name=a.name,s.type=Ye(a.storage),s.metadata={},s.metadata.description="",a.measure&&(s.metadata.measure=a.measure.toLowerCase()),a.modelingRole&&(s.metadata.modeling_role=a.modelingRole.toLowerCase()),t.fields.push(s)}}catch(e){n.e(e)}finally{n.f()}}return t}function Ye(e){var t=e.toLowerCase();return"Real"===e&&(t="double"),t}function Ve(e){if(e){if(e.structureType&&"object"===e.structureType)return!0;if(e.subControls){var t,r=_e(e.subControls);try{for(r.s();!(t=r.n()).done;){var n=t.value;if(n.structureType&&"object"===n.structureType)return!0;if(n.subControls&&Ve(n))return!0}}catch(e){r.e(e)}finally{r.f()}return!1}}return!1}function Xe(e,t,r){var n=[];if(t.forEach((function(e){n.push(e.name)})),e){var a=[];return"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.d)(r)&&null!==r&&Object.keys(r).length>0&&r.forEach((function(e){if(Array.isArray(e)){var r=[];e.forEach((function(e,n){var a=e;"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.d)(e)&&null!==e&&Object.keys(e).length>0&&(a=Xe(t[n].valueDef.isList,t[n].subControls,e)),r.push(a)})),a.push(r)}else if("object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.d)(e)){var i=[];n.forEach((function(r,n){var a=void 0!==e[r]?e[r]:null;t[n].structureType&&"object"===t[n].structureType&&(a=Xe(t[n].valueDef.isList,t[n].subControls,e[r])),i.push(a)})),a.push(i)}})),a}var i=[];return n.forEach((function(e,t){var n=void 0!==r[e]?r[e]:null;i.push(n)})),i}function ze(e,t,r,n){var a=[];if(t.forEach((function(e){a.push(e.name)})),e&&Array.isArray(r)){var s=[];return r.forEach((function(e,r){if(n){var i={};a.forEach((function(r,n){t[n].structureType&&"object"===t[n].structureType?i[r]=ze(t[n].valueDef.isList,t[n].subControls,e[n],!0):void 0!==t.subControls?i[r]=ze(t[n].valueDef.isList,t[n].subControls,e[n],!1):i[r]=void 0!==e[n]?e[n]:null})),s.push(i)}else{var o=[];e.forEach((function(e,r){var n=e;t[r].structureType&&"object"===t[r].structureType&&(n=ze(t[r].valueDef.isList,t[r].subControls,e,!0)),o.push(n)})),s.push(o)}})),s}var i={};return a.forEach((function(e,t){i[e]=r&&void 0!==r[t]?r[t]:null})),i}function We(e,t,r){var n=He(e),a=[];if(t&&-1!==n){var s,i=_e(t);try{for(i.s();!(s=i.n()).done;){var o=s.value,l=o;Array.isArray(o)?l=$e(o[n],e):"object"===we(o)&&(l=$e(o,e)),a.push(l)}}catch(e){i.e(e)}finally{i.f()}}return a}function $e(e,t,r){return"object"===we(e)?t&&t.valueDef&&e.link_ref?r?e.field_name:e.link_ref+"."+e.field_name:null:e}function Je(e,t){return"object"===we(e)&&e.link_ref?e.link_ref===t.schema&&e.field_name===t.origName:e===t.name}function Ze(e,t,r){if("column"===t.role&&"structure"===t.valueDef.propType){var n,a=_e(r.getDatasetMetadataFields());try{for(a.s();!(n=a.n()).done;){var s=n.value;if(s.name===e)return{link_ref:s.schema,field_name:s.origName}}}catch(e){a.e(e)}finally{a.f()}}return e}function qe(e,t,r){var n,a=e.dmDefault;if(t){var s,i=_e(r);try{for(i.s();!(s=i.n()).done;){var o=s.value;if(o.name===t){switch(a){case"type":n=o.type;break;case"description":n=o.metadata.description;break;case"measure":n=et(o.metadata.measure,e.values);break;case"modeling_role":n=et(o.metadata.modeling_role,e.values)}break}}}catch(e){i.e(e)}finally{i.f()}}return n}function Qe(e,t,r){var n,a=e.find((function(e){return e.origName===t}));switch(r){case"measure":if(!a)return _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.g.MEASUREMENTS.EMPTY;switch(a.metadata.measure){case"range":n=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.g.MEASUREMENTS.SCALE;break;case"ordered_set":n=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.g.MEASUREMENTS.ORDINAL;break;case"discrete":n=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.g.MEASUREMENTS.DISCRETE;break;case"set":case"collection":case"geospatial":n=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.g.MEASUREMENTS.NOMINAL;break;case"flag":n=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.g.MEASUREMENTS.FLAG;break;default:n=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.g.MEASUREMENTS.EMPTY}break;case"type":if(!a)return"typeEmpty";switch(a.type){case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.m.DATE:n=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.m.DATE;break;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.m.TIME:n=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.m.TIME;break;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.m.TIMESTAMP:n=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.m.TIMESTAMP;break;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.m.STRING:n=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.m.STRING;break;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.m.INTEGER:n=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.m.INTEGER;break;case _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.m.DOUBLE:n=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.m.DOUBLE;break;default:n="typeEmpty"}}return n}function et(e,t){var r=t.indexOf(e);if(r>-1)return t[r];var n,a=e.toLowerCase(),s=_e(t);try{for(s.s();!(n=s.n()).done;){var i=n.value;if(a===i.toLowerCase())return i}}catch(e){s.e(e)}finally{s.f()}var o,l=_e(t);try{for(l.s();!(o=l.n()).done;){var c=o.value;if(a.startsWith(c.substring(0,6).toLowerCase()))return c}}catch(e){l.e(e)}finally{l.f()}return e}function tt(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,s=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;r=Reflect.construct(s,arguments,i)}else r=s.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,r)}}var rt=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(i,n);var a=tt(i);function i(){return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,i),a.apply(this,arguments)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(i,[{key:"render",value:function(){var e=this.props.tooltipText;"object"!==(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.d)(this.props.tooltipText)&&(e=String(this.props.tooltipText));var t=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-tooltips"},e);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-truncated-tooltip"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_12__["default"],{id:"".concat((0,uuid__WEBPACK_IMPORTED_MODULE_1__.v4)(),"-properties"),tip:t,direction:"bottom",className:"properties-tooltips",disable:!(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(this.props,"disabled")||this.props.disabled,showToolTipIfTruncated:!0},this.props.content))}}]),i}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),nt=rt;function at(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(!e)return;if("string"==typeof e)return st(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return st(e,t)}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,a=function(){};return{s:a,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:a}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var s,i=!0,o=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return i=e.done,e},e:function(e){o=!0,s=e},f:function(){try{i||null==r.return||r.return()}finally{if(o)throw s}}}}function st(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function it(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,s=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;r=Reflect.construct(s,arguments,i)}else r=s.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,r)}}var ot=function(n){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(s,n);var a=it(s);function s(t){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,s),(r=a.call(this,t)).state={fields:r.props.fields,origFields:r.props.fields,filterIcons:[],filterText:"",selectedFields:r.props.currentFields},r.multiSchema=t.controller.getDatasetMetadataSchemas()&&t.controller.getDatasetMetadataSchemas().length>1,r.filterList=[],r.filterType=r.filterType.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(r)),r.getTableData=r.getTableData.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(r)),r.getVisibleData=r.getVisibleData.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(r)),r.handleSave=r.handleSave.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(r)),r.handleCancel=r.handleCancel.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(r)),r.handleReset=r.handleReset.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(r)),r.getNewSelections=r.getNewSelections.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(r)),r.onSort=r.onSort.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(r)),r.onFilter=r.onFilter.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(r)),r.updateFieldSelections=r.updateFieldSelections.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(r)),r.filterList=r.getAvailableFilters(),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(s,[{key:"onFilter",value:function(e){this.setState({filterText:e})}},{key:"onSort",value:function(e){var t=Array.from(this.state.fields);t=Re(t,(function(t){switch(e.column){case"fieldName":return t.origName;case"dataType":return t.type;case"schemaName":return t.schema;default:return null}})),e.direction===_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.n.DESC&&t.reverse(),this.setState({fields:t})}},{key:"getAvailableFilters",value:function(){var e=[];for(var t in _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.m)if((0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.j)(_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.m,t)){var r,n=_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.m[t],a=at(this.props.fields);try{for(a.s();!(r=a.n()).done;){var s=r.value;if(n===s.type){var i,o={type:s.type},l=!1,c=at(e);try{for(c.s();!(i=c.n()).done;){if(i.value.type===o.type){l=!0;break}}}catch(e){c.e(e)}finally{c.f()}l||e.push(o);break}}}catch(e){a.e(e)}finally{a.f()}}return e}},{key:"getTableData",value:function(){for(var e=this.getVisibleData(),t=[],r=this.state.selectedFields,n=[],a=function(t){var a=e.findIndex((function(e){return e.name===r[t]}));-1!==a&&n.push(a)},s=0;s<r.length;s++)a(s);for(var i=0;i<e.length;i++){var o=e[i],l=[],c=null;if(this.props.dmIcon&&"type"!==this.props.dmIcon){var u=Qe(this.props.controller.getDatasetMetadataFields(),o.origName,this.props.dmIcon),f=u?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_13__.I,{type:u}):null;f&&(c=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-fp-field-type-icon"},f))}var p=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{className:"properties-fp-field-name"},o.origName),d=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(nt,{content:p,tooltipText:o.origName,disabled:!1}),m=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-fp-field"},c,d);if(l.push({column:"fieldName",content:m,fieldName:o.origName}),this.multiSchema){var h=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-fp-schema"},o.schema);l.push({column:"schemaName",content:h})}l.push({column:"dataType",content:react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-fp-data"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-fp-data-type-icon"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_13__.I,{type:o.type})),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-fp-field-type"},o.type)),value:o.type}),t.push({className:"properties-fp-data-rows",columns:l})}return this.selectedRowsIndex=n,t}},{key:"getVisibleData",value:function(){var e=this;return this.state.fields.filter((function(t){return e.state.filterIcons.indexOf(t.type)<0})).filter((function(t){return void 0===e.state.filterText||null===e.state.filterText||t.origName.toLowerCase().indexOf(e.state.filterText.toLowerCase())>-1}))}},{key:"getNewSelections",value:function(){var e=[],t=this.props.currentFields;if(this.state.selectedFields)for(var r=0;r<this.state.selectedFields.length;r++)(null==t||t.indexOf(this.state.selectedFields[r])<0)&&e.push(r);return e}},{key:"handleSave",value:function(){this.props.closeFieldPicker(this.state.selectedFields,this.getNewSelections())}},{key:"handleCancel",value:function(){this.handleReset(),this.props.closeFieldPicker()}},{key:"updateFieldSelections",value:function(e){var t=this.getVisibleData(),r=Array.from(this.state.selectedFields),n=r.filter((function(e,n,a){return-1===t.findIndex((function(e){return e.name===r[n]}))}));e.forEach((function(e){n.push(t[e].name)})),n=Array.from(new Set(n)),this.setState({selectedFields:n})}},{key:"isFieldInList",value:function(e,t){return e.some((function(e){return e.name===t}))}},{key:"handleReset",value:function(){this.setState({selectedFields:this.props.currentFields,filterIcons:[],filterText:""})}},{key:"filterType",value:function(e){var t=e.currentTarget.getAttribute("data-type"),r=Array.from(this.state.filterIcons),n=r.indexOf(t);n<0?r.push(t):r.splice(n,1),this.setState({filterIcons:r})}},{key:"_genBackButton",value:function(){if(this.props.rightFlyout){var e=je(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.M.APPLYBUTTON_LABEL),t=je(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.M.REJECTBUTTON_LABEL);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(X,{okHandler:this.handleSave,cancelHandler:this.handleCancel,showPropertiesButtons:!0,applyLabel:e,rejectLabel:t})}var r=je(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.M.FIELDPICKER_SAVEBUTTON_TOOLTIP),n=(0,uuid__WEBPACK_IMPORTED_MODULE_1__.v4)()+"-tooltip-fp",a=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-tooltips"},r);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_12__["default"],{id:n,tip:a,direction:"left",className:"properties-tooltips"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_6__["default"],{className:"properties-fp-back-button",renderIcon:_carbon_icons_react__WEBPACK_IMPORTED_MODULE_14__.ArrowLeft24,iconDescription:this.props.title,size:"small",kind:"primary",onClick:this.handleSave}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("label",{className:"properties-fp-button-label"},this.props.title))))}},{key:"_genResetButton",value:function(){var e=je(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.M.FIELDPICKER_RESETBUTTON_LABEL);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_6__["default"],{className:"properties-fp-reset-button-container",onClick:this.handleReset,renderIcon:_carbon_icons_react__WEBPACK_IMPORTED_MODULE_15__.Reset24,iconDescription:e,size:"small",kind:"ghost"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",null,e))}},{key:"_genFilterTypes",value:function(){var e=this,t=je(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.M.FIELDPICKER_FILTER_LABEL),r=this.filterList.map((function(r,n){for(var a=!0,s=0;s<e.state.filterIcons.length;s++)if(r.type===e.state.filterIcons[s]){a=!1;break}var i=(0,uuid__WEBPACK_IMPORTED_MODULE_1__.v4)()+"-tooltip-filters-"+n,o=je(e.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.M["FIELDPICKER_".concat(r.type.toUpperCase(),"_LABEL")]),l=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-tooltips"},o);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("li",{key:"filters"+n,className:"properties-fp-filter-list-li"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-tooltips-filter"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_12__["default"],{id:i,tip:l,direction:"bottom",className:"properties-tooltips icon-tooltip",disable:(0,_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_8__.h)(r.type)},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_6__["default"],{className:"properties-fp-filter","data-type":r.type,onClick:e.filterType.bind(e),"aria-label":t+" "+r.type,kind:"ghost"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_13__.I,{type:r.type,disabled:!a})))))}));return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("ul",{className:"properties-fp-filter-list"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("li",{className:"properties-fp-filter-list-title properties-fp-filter-list-li"},t),r)}},{key:"_genTable",value:function(){var e=je(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.M.FIELDPICKER_FIELDCOLUMN_LABEL),t=je(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.M.FIELDPICKER_SCHEMACOLUMN_LABEL),r=je(this.props.controller.getReactIntl(),_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.M.FIELDPICKER_DATATYPECOLUMN_LABEL),n=[];n.push({key:"fieldName",label:e}),this.multiSchema&&n.push({key:"schemaName",label:t}),n.push({key:"dataType",label:r});var a=this.getTableData();return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_flexible_table_d4a68ebb_js__WEBPACK_IMPORTED_MODULE_5__.F,{className:"properties-fp-table",sortable:["fieldName","schemaName","dataType"],filterable:["fieldName"],onFilter:this.onFilter,columns:n,data:a,onSort:this.onSort,filterKeyword:this.state.filterText,scrollKey:"field-picker",noAutoSize:!0,tableLabel:this.props.title?this.props.title:"",selectedRows:this.selectedRowsIndex,updateRowSelections:this.updateFieldSelections,rowSelection:_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_7__.R.MULTIPLE,light:this.props.controller.getLight()})}},{key:"render",value:function(){var e=this._genBackButton(),t=this._genResetButton(),r=this._genFilterTypes(),n=this._genTable();return this.props.rightFlyout?react__WEBPACK_IMPORTED_MODULE_0___default().createElement((react__WEBPACK_IMPORTED_MODULE_0___default().Fragment),null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-fp-top-row"},r,t),n,e):react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"properties-fp-top-row"},e,t),r,n)}}],[{key:"getDerivedStateFromProps",value:function(e,t){if(!W(e.fields,t.origFields)){var r=t.selectedFields;return e.currentFields&&(W(Object.keys(e.currentFields),Object.keys(t.selectedFields))||(r=e.currentFields)),{fields:e.fields,selectedFields:r,origFields:e.fields}}return{}}}]),s}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)),lt=ot;
//# sourceMappingURL=index-beefcd21.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/isArrayLikeObject-a9c7973b.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/isArrayLikeObject-a9c7973b.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "$": () => (/* binding */ pe),
/* harmony export */   "A": () => (/* binding */ dn),
/* harmony export */   "B": () => (/* binding */ ma),
/* harmony export */   "C": () => (/* binding */ Pa),
/* harmony export */   "D": () => (/* binding */ ha),
/* harmony export */   "E": () => (/* binding */ qe),
/* harmony export */   "F": () => (/* binding */ za),
/* harmony export */   "G": () => (/* binding */ Pn),
/* harmony export */   "H": () => (/* binding */ tt),
/* harmony export */   "I": () => (/* binding */ ao),
/* harmony export */   "J": () => (/* binding */ De),
/* harmony export */   "K": () => (/* binding */ n),
/* harmony export */   "L": () => (/* binding */ bt),
/* harmony export */   "M": () => (/* binding */ q),
/* harmony export */   "N": () => (/* binding */ Bt),
/* harmony export */   "O": () => (/* binding */ S),
/* harmony export */   "P": () => (/* binding */ oe),
/* harmony export */   "Q": () => (/* binding */ Rt),
/* harmony export */   "R": () => (/* binding */ ue),
/* harmony export */   "S": () => (/* binding */ re),
/* harmony export */   "T": () => (/* binding */ se),
/* harmony export */   "U": () => (/* binding */ Te),
/* harmony export */   "V": () => (/* binding */ x),
/* harmony export */   "W": () => (/* binding */ Ee),
/* harmony export */   "X": () => (/* binding */ At),
/* harmony export */   "Y": () => (/* binding */ Xr),
/* harmony export */   "Z": () => (/* binding */ pt),
/* harmony export */   "_": () => (/* binding */ ln),
/* harmony export */   "a": () => (/* binding */ on),
/* harmony export */   "a0": () => (/* binding */ be),
/* harmony export */   "a1": () => (/* binding */ Nn),
/* harmony export */   "a2": () => (/* binding */ ka),
/* harmony export */   "a3": () => (/* binding */ rn),
/* harmony export */   "a4": () => (/* binding */ r),
/* harmony export */   "a5": () => (/* binding */ t),
/* harmony export */   "b": () => (/* binding */ An),
/* harmony export */   "c": () => (/* binding */ xn),
/* harmony export */   "d": () => (/* binding */ $n),
/* harmony export */   "e": () => (/* binding */ cn),
/* harmony export */   "f": () => (/* binding */ C),
/* harmony export */   "g": () => (/* binding */ Ge),
/* harmony export */   "h": () => (/* binding */ Va),
/* harmony export */   "i": () => (/* binding */ nt),
/* harmony export */   "j": () => (/* binding */ da),
/* harmony export */   "k": () => (/* binding */ ja),
/* harmony export */   "l": () => (/* binding */ Dn),
/* harmony export */   "m": () => (/* binding */ $a),
/* harmony export */   "n": () => (/* binding */ Jt),
/* harmony export */   "o": () => (/* binding */ qt),
/* harmony export */   "p": () => (/* binding */ Yt),
/* harmony export */   "q": () => (/* binding */ io),
/* harmony export */   "r": () => (/* binding */ qn),
/* harmony export */   "s": () => (/* binding */ mt),
/* harmony export */   "t": () => (/* binding */ Rn),
/* harmony export */   "u": () => (/* binding */ Qa),
/* harmony export */   "v": () => (/* binding */ Xa),
/* harmony export */   "w": () => (/* binding */ Wa),
/* harmony export */   "x": () => (/* binding */ Zt),
/* harmony export */   "y": () => (/* binding */ vt),
/* harmony export */   "z": () => (/* binding */ Ja)
/* harmony export */ });
var r="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof __webpack_require__.g?__webpack_require__.g:"undefined"!=typeof self?self:{};function t(r){throw new Error('Could not dynamically require "'+r+'". Please configure the dynamicRequireTargets or/and ignoreDynamicRequires option of @rollup/plugin-commonjs appropriately for this require call to work.')}var e=function(){this.__data__=[],this.size=0};var n=function(r,t){return r===t||r!=r&&t!=t},a=n;var o=function(r,t){for(var e=r.length;e--;)if(a(r[e][0],t))return e;return-1},u=o,i=Array.prototype.splice;var c=o;var s=o;var f=o;var l=e,v=function(r){var t=this.__data__,e=u(t,r);return!(e<0)&&(e==t.length-1?t.pop():i.call(t,e,1),--this.size,!0)},p=function(r){var t=this.__data__,e=c(t,r);return e<0?void 0:t[e][1]},h=function(r){return s(this.__data__,r)>-1},y=function(r,t){var e=this.__data__,n=f(e,r);return n<0?(++this.size,e.push([r,t])):e[n][1]=t,this};function b(r){var t=-1,e=null==r?0:r.length;for(this.clear();++t<e;){var n=r[t];this.set(n[0],n[1])}}b.prototype.clear=l,b.prototype.delete=v,b.prototype.get=p,b.prototype.has=h,b.prototype.set=y;var _=b,d=_;var g=function(){this.__data__=new d,this.size=0};var j=function(r){var t=this.__data__,e=t.delete(r);return this.size=t.size,e};var w=function(r){return this.__data__.get(r)};var O=function(r){return this.__data__.has(r)},m="object"==typeof r&&r&&r.Object===Object&&r,A=m,z="object"==typeof self&&self&&self.Object===Object&&self,S=A||z||Function("return this")(),x=S.Symbol,P=x,k=Object.prototype,E=k.hasOwnProperty,T=k.toString,M=P?P.toStringTag:void 0;var $=function(r){var t=E.call(r,M),e=r[M];try{r[M]=void 0;var n=!0}catch(r){}var a=T.call(r);return n&&(t?r[M]=e:delete r[M]),a},D=Object.prototype.toString;var F=$,I=function(r){return D.call(r)},B=x?x.toStringTag:void 0;var C=function(r){return null==r?void 0===r?"[object Undefined]":"[object Null]":B&&B in Object(r)?F(r):I(r)};var q=function(r){var t=typeof r;return null!=r&&("object"==t||"function"==t)},R=C,U=q;var L,V=function(r){if(!U(r))return!1;var t=R(r);return"[object Function]"==t||"[object GeneratorFunction]"==t||"[object AsyncFunction]"==t||"[object Proxy]"==t},W=S["__core-js_shared__"],N=(L=/[^.]+$/.exec(W&&W.keys&&W.keys.IE_PROTO||""))?"Symbol(src)_1."+L:"";var G=function(r){return!!N&&N in r},H=Function.prototype.toString;var J=function(r){if(null!=r){try{return H.call(r)}catch(r){}try{return r+""}catch(r){}}return""},K=V,Q=G,X=q,Y=J,Z=/^\[object .+?Constructor\]$/,rr=Function.prototype,tr=Object.prototype,er=rr.toString,nr=tr.hasOwnProperty,ar=RegExp("^"+er.call(nr).replace(/[\\^$.*+?()[\]{}|]/g,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$");var or=function(r){return!(!X(r)||Q(r))&&(K(r)?ar:Z).test(Y(r))},ur=function(r,t){return null==r?void 0:r[t]};var ir=function(r,t){var e=ur(r,t);return or(e)?e:void 0},cr=ir(S,"Map"),sr=ir(Object,"create"),fr=sr;var lr=function(){this.__data__=fr?fr(null):{},this.size=0};var vr=function(r){var t=this.has(r)&&delete this.__data__[r];return this.size-=t?1:0,t},pr=sr,hr=Object.prototype.hasOwnProperty;var yr=function(r){var t=this.__data__;if(pr){var e=t[r];return"__lodash_hash_undefined__"===e?void 0:e}return hr.call(t,r)?t[r]:void 0},br=sr,_r=Object.prototype.hasOwnProperty;var dr=sr;var gr=lr,jr=vr,wr=yr,Or=function(r){var t=this.__data__;return br?void 0!==t[r]:_r.call(t,r)},mr=function(r,t){var e=this.__data__;return this.size+=this.has(r)?0:1,e[r]=dr&&void 0===t?"__lodash_hash_undefined__":t,this};function Ar(r){var t=-1,e=null==r?0:r.length;for(this.clear();++t<e;){var n=r[t];this.set(n[0],n[1])}}Ar.prototype.clear=gr,Ar.prototype.delete=jr,Ar.prototype.get=wr,Ar.prototype.has=Or,Ar.prototype.set=mr;var zr=Ar,Sr=_,xr=cr;var Pr=function(r){var t=typeof r;return"string"==t||"number"==t||"symbol"==t||"boolean"==t?"__proto__"!==r:null===r};var kr=function(r,t){var e=r.__data__;return Pr(t)?e["string"==typeof t?"string":"hash"]:e.map},Er=kr;var Tr=kr;var Mr=kr;var $r=kr;var Dr=function(){this.size=0,this.__data__={hash:new zr,map:new(xr||Sr),string:new zr}},Fr=function(r){var t=Er(this,r).delete(r);return this.size-=t?1:0,t},Ir=function(r){return Tr(this,r).get(r)},Br=function(r){return Mr(this,r).has(r)},Cr=function(r,t){var e=$r(this,r),n=e.size;return e.set(r,t),this.size+=e.size==n?0:1,this};function qr(r){var t=-1,e=null==r?0:r.length;for(this.clear();++t<e;){var n=r[t];this.set(n[0],n[1])}}qr.prototype.clear=Dr,qr.prototype.delete=Fr,qr.prototype.get=Ir,qr.prototype.has=Br,qr.prototype.set=Cr;var Rr=qr,Ur=_,Lr=cr,Vr=Rr;var Wr=_,Nr=g,Gr=j,Hr=w,Jr=O,Kr=function(r,t){var e=this.__data__;if(e instanceof Ur){var n=e.__data__;if(!Lr||n.length<199)return n.push([r,t]),this.size=++e.size,this;e=this.__data__=new Vr(n)}return e.set(r,t),this.size=e.size,this};function Qr(r){var t=this.__data__=new Wr(r);this.size=t.size}Qr.prototype.clear=Nr,Qr.prototype.delete=Gr,Qr.prototype.get=Hr,Qr.prototype.has=Jr,Qr.prototype.set=Kr;var Xr=Qr,Yr=ir,Zr=function(){try{var r=Yr(Object,"defineProperty");return r({},"",{}),r}catch(r){}}(),rt=Zr;var tt=function(r,t,e){"__proto__"==t&&rt?rt(r,t,{configurable:!0,enumerable:!0,value:e,writable:!0}):r[t]=e};var et=function(r,t){for(var e=-1,n=Array(r);++e<r;)n[e]=t(e);return n};var nt=function(r){return null!=r&&"object"==typeof r},at=C,ot=nt;var ut=function(r){return ot(r)&&"[object Arguments]"==at(r)},it=nt,ct=Object.prototype,st=ct.hasOwnProperty,ft=ct.propertyIsEnumerable,lt=ut(function(){return arguments}())?ut:function(r){return it(r)&&st.call(r,"callee")&&!ft.call(r,"callee")},vt=Array.isArray,pt={exports:{}};var ht=function(){return!1};!function(r,t){var e=S,n=ht,a=t&&!t.nodeType&&t,o=a&&r&&!r.nodeType&&r,u=o&&o.exports===a?e.Buffer:void 0,i=(u?u.isBuffer:void 0)||n;r.exports=i}(pt,pt.exports);var yt=/^(?:0|[1-9]\d*)$/;var bt=function(r,t){var e=typeof r;return!!(t=null==t?9007199254740991:t)&&("number"==e||"symbol"!=e&&yt.test(r))&&r>-1&&r%1==0&&r<t};var _t=function(r){return"number"==typeof r&&r>-1&&r%1==0&&r<=9007199254740991},dt=C,gt=_t,jt=nt,wt={};wt["[object Float32Array]"]=wt["[object Float64Array]"]=wt["[object Int8Array]"]=wt["[object Int16Array]"]=wt["[object Int32Array]"]=wt["[object Uint8Array]"]=wt["[object Uint8ClampedArray]"]=wt["[object Uint16Array]"]=wt["[object Uint32Array]"]=!0,wt["[object Arguments]"]=wt["[object Array]"]=wt["[object ArrayBuffer]"]=wt["[object Boolean]"]=wt["[object DataView]"]=wt["[object Date]"]=wt["[object Error]"]=wt["[object Function]"]=wt["[object Map]"]=wt["[object Number]"]=wt["[object Object]"]=wt["[object RegExp]"]=wt["[object Set]"]=wt["[object String]"]=wt["[object WeakMap]"]=!1;var Ot=function(r){return jt(r)&&gt(r.length)&&!!wt[dt(r)]};var mt=function(r){return function(t){return r(t)}},At={exports:{}};!function(r,t){var e=m,n=t&&!t.nodeType&&t,a=n&&r&&!r.nodeType&&r,o=a&&a.exports===n&&e.process,u=function(){try{var r=a&&a.require&&a.require("util").types;return r||o&&o.binding&&o.binding("util")}catch(r){}}();r.exports=u}(At,At.exports);var zt=Ot,St=mt,xt=At.exports,Pt=xt&&xt.isTypedArray,kt=Pt?St(Pt):zt,Et=et,Tt=lt,Mt=vt,$t=pt.exports,Dt=bt,Ft=kt,It=Object.prototype.hasOwnProperty;var Bt=function(r,t){var e=Mt(r),n=!e&&Tt(r),a=!e&&!n&&$t(r),o=!e&&!n&&!a&&Ft(r),u=e||n||a||o,i=u?Et(r.length,String):[],c=i.length;for(var s in r)!t&&!It.call(r,s)||u&&("length"==s||a&&("offset"==s||"parent"==s)||o&&("buffer"==s||"byteLength"==s||"byteOffset"==s)||Dt(s,c))||i.push(s);return i},Ct=Object.prototype;var qt=function(r){var t=r&&r.constructor;return r===("function"==typeof t&&t.prototype||Ct)};var Rt=function(r,t){return function(e){return r(t(e))}},Ut=Rt(Object.keys,Object),Lt=qt,Vt=Ut,Wt=Object.prototype.hasOwnProperty;var Nt=function(r){if(!Lt(r))return Vt(r);var t=[];for(var e in Object(r))Wt.call(r,e)&&"constructor"!=e&&t.push(e);return t},Gt=V,Ht=_t;var Jt=function(r){return null!=r&&Ht(r.length)&&!Gt(r)},Kt=Bt,Qt=Nt,Xt=Jt;var Yt=function(r){return Xt(r)?Kt(r):Qt(r)};var Zt=function(r,t){for(var e=-1,n=null==r?0:r.length,a=0,o=[];++e<n;){var u=r[e];t(u,e,r)&&(o[a++]=u)}return o};var re=function(){return[]},te=Zt,ee=re,ne=Object.prototype.propertyIsEnumerable,ae=Object.getOwnPropertySymbols,oe=ae?function(r){return null==r?[]:(r=Object(r),te(ae(r),(function(t){return ne.call(r,t)})))}:ee;var ue=function(r,t){for(var e=-1,n=t.length,a=r.length;++e<n;)r[a+e]=t[e];return r},ie=ue,ce=vt;var se=function(r,t,e){var n=t(r);return ce(r)?n:ie(n,e(r))},fe=se,le=oe,ve=Yt;var pe=function(r){return fe(r,ve,le)},he=ir(S,"DataView"),ye=ir(S,"Promise"),be=ir(S,"Set"),_e=he,de=cr,ge=ye,je=be,we=ir(S,"WeakMap"),Oe=C,me=J,Ae=me(_e),ze=me(de),Se=me(ge),xe=me(je),Pe=me(we),ke=Oe;(_e&&"[object DataView]"!=ke(new _e(new ArrayBuffer(1)))||de&&"[object Map]"!=ke(new de)||ge&&"[object Promise]"!=ke(ge.resolve())||je&&"[object Set]"!=ke(new je)||we&&"[object WeakMap]"!=ke(new we))&&(ke=function(r){var t=Oe(r),e="[object Object]"==t?r.constructor:void 0,n=e?me(e):"";if(n)switch(n){case Ae:return"[object DataView]";case ze:return"[object Map]";case Se:return"[object Promise]";case xe:return"[object Set]";case Pe:return"[object WeakMap]"}return t});var Ee=ke,Te=S.Uint8Array,Me=C,$e=nt;var De=function(r){return"symbol"==typeof r||$e(r)&&"[object Symbol]"==Me(r)},Fe=vt,Ie=De,Be=/\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,Ce=/^\w*$/;var qe=function(r,t){if(Fe(r))return!1;var e=typeof r;return!("number"!=e&&"symbol"!=e&&"boolean"!=e&&null!=r&&!Ie(r))||(Ce.test(r)||!Be.test(r)||null!=t&&r in Object(t))},Re=Rr;function Ue(r,t){if("function"!=typeof r||null!=t&&"function"!=typeof t)throw new TypeError("Expected a function");var e=function(){var n=arguments,a=t?t.apply(this,n):n[0],o=e.cache;if(o.has(a))return o.get(a);var u=r.apply(this,n);return e.cache=o.set(a,u)||o,u};return e.cache=new(Ue.Cache||Re),e}Ue.Cache=Re;var Le=Ue;var Ve=/[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g,We=/\\(\\)?/g,Ne=function(r){var t=Le(r,(function(r){return 500===e.size&&e.clear(),r})),e=t.cache;return t}((function(r){var t=[];return 46===r.charCodeAt(0)&&t.push(""),r.replace(Ve,(function(r,e,n,a){t.push(n?a.replace(We,"$1"):e||r)})),t}));var Ge=function(r,t){for(var e=-1,n=null==r?0:r.length,a=Array(n);++e<n;)a[e]=t(r[e],e,r);return a},He=Ge,Je=vt,Ke=De,Qe=x?x.prototype:void 0,Xe=Qe?Qe.toString:void 0;var Ye=function r(t){if("string"==typeof t)return t;if(Je(t))return He(t,r)+"";if(Ke(t))return Xe?Xe.call(t):"";var e=t+"";return"0"==e&&1/t==-Infinity?"-0":e},Ze=Ye;var rn=function(r){return null==r?"":Ze(r)},tn=vt,en=qe,nn=Ne,an=rn;var on=function(r,t){return tn(r)?r:en(r,t)?[r]:nn(an(r))},un=De;var cn=function(r){if("string"==typeof r||un(r))return r;var t=r+"";return"0"==t&&1/r==-Infinity?"-0":t},sn=on,fn=cn;var ln=function(r,t){for(var e=0,n=(t=sn(t,r)).length;null!=r&&e<n;)r=r[fn(t[e++])];return e&&e==n?r:void 0},vn=on,pn=lt,hn=vt,yn=bt,bn=_t,_n=cn;var dn=function(r,t,e){for(var n=-1,a=(t=vn(t,r)).length,o=!1;++n<a;){var u=_n(t[n]);if(!(o=null!=r&&e(r,u)))break;r=r[u]}return o||++n!=a?o:!!(a=null==r?0:r.length)&&bn(a)&&yn(u,a)&&(hn(r)||pn(r))},gn=lt,jn=vt,wn=x?x.isConcatSpreadable:void 0;var On=ue,mn=function(r){return jn(r)||gn(r)||!!(wn&&r&&r[wn])};var An=function r(t,e,n,a,o){var u=-1,i=t.length;for(n||(n=mn),o||(o=[]);++u<i;){var c=t[u];e>0&&n(c)?e>1?r(c,e-1,n,a,o):On(o,c):a||(o[o.length]=c)}return o};var zn=function(r,t,e){switch(e.length){case 0:return r.call(t);case 1:return r.call(t,e[0]);case 2:return r.call(t,e[0],e[1]);case 3:return r.call(t,e[0],e[1],e[2])}return r.apply(t,e)},Sn=Math.max;var xn=function(r,t,e){return t=Sn(void 0===t?r.length-1:t,0),function(){for(var n=arguments,a=-1,o=Sn(n.length-t,0),u=Array(o);++a<o;)u[a]=n[t+a];a=-1;for(var i=Array(t+1);++a<t;)i[a]=n[a];return i[t]=e(u),zn(r,this,i)}};var Pn=function(r){return r},kn=function(r){return function(){return r}},En=Zr,Tn=En?function(r,t){return En(r,"toString",{configurable:!0,enumerable:!1,value:kn(t),writable:!0})}:Pn,Mn=Date.now;var $n=function(r){var t=0,e=0;return function(){var n=Mn(),a=16-(n-e);if(e=n,a>0){if(++t>=800)return arguments[0]}else t=0;return r.apply(void 0,arguments)}}(Tn);var Dn=function(r){var t=null==r?0:r.length;return t?r[t-1]:void 0};var Fn=Rr,In=function(r){return this.__data__.set(r,"__lodash_hash_undefined__"),this},Bn=function(r){return this.__data__.has(r)};function Cn(r){var t=-1,e=null==r?0:r.length;for(this.__data__=new Fn;++t<e;)this.add(r[t])}Cn.prototype.add=Cn.prototype.push=In,Cn.prototype.has=Bn;var qn=Cn;var Rn=function(r,t){return r.has(t)},Un=qn,Ln=function(r,t){for(var e=-1,n=null==r?0:r.length;++e<n;)if(t(r[e],e,r))return!0;return!1},Vn=Rn;var Wn=function(r,t,e,n,a,o){var u=1&e,i=r.length,c=t.length;if(i!=c&&!(u&&c>i))return!1;var s=o.get(r),f=o.get(t);if(s&&f)return s==t&&f==r;var l=-1,v=!0,p=2&e?new Un:void 0;for(o.set(r,t),o.set(t,r);++l<i;){var h=r[l],y=t[l];if(n)var b=u?n(y,h,l,t,r,o):n(h,y,l,r,t,o);if(void 0!==b){if(b)continue;v=!1;break}if(p){if(!Ln(t,(function(r,t){if(!Vn(p,t)&&(h===r||a(h,r,e,n,o)))return p.push(t)}))){v=!1;break}}else if(h!==y&&!a(h,y,e,n,o)){v=!1;break}}return o.delete(r),o.delete(t),v};var Nn=function(r){var t=-1,e=Array(r.size);return r.forEach((function(r){e[++t]=r})),e},Gn=Te,Hn=n,Jn=Wn,Kn=function(r){var t=-1,e=Array(r.size);return r.forEach((function(r,n){e[++t]=[n,r]})),e},Qn=Nn,Xn=x?x.prototype:void 0,Yn=Xn?Xn.valueOf:void 0;var Zn=function(r,t,e,n,a,o,u){switch(e){case"[object DataView]":if(r.byteLength!=t.byteLength||r.byteOffset!=t.byteOffset)return!1;r=r.buffer,t=t.buffer;case"[object ArrayBuffer]":return!(r.byteLength!=t.byteLength||!o(new Gn(r),new Gn(t)));case"[object Boolean]":case"[object Date]":case"[object Number]":return Hn(+r,+t);case"[object Error]":return r.name==t.name&&r.message==t.message;case"[object RegExp]":case"[object String]":return r==t+"";case"[object Map]":var i=Kn;case"[object Set]":var c=1&n;if(i||(i=Qn),r.size!=t.size&&!c)return!1;var s=u.get(r);if(s)return s==t;n|=2,u.set(r,t);var f=Jn(i(r),i(t),n,a,o,u);return u.delete(r),f;case"[object Symbol]":if(Yn)return Yn.call(r)==Yn.call(t)}return!1},ra=pe,ta=Object.prototype.hasOwnProperty;var ea=Xr,na=Wn,aa=Zn,oa=function(r,t,e,n,a,o){var u=1&e,i=ra(r),c=i.length;if(c!=ra(t).length&&!u)return!1;for(var s=c;s--;){var f=i[s];if(!(u?f in t:ta.call(t,f)))return!1}var l=o.get(r),v=o.get(t);if(l&&v)return l==t&&v==r;var p=!0;o.set(r,t),o.set(t,r);for(var h=u;++s<c;){var y=r[f=i[s]],b=t[f];if(n)var _=u?n(b,y,f,t,r,o):n(y,b,f,r,t,o);if(!(void 0===_?y===b||a(y,b,e,n,o):_)){p=!1;break}h||(h="constructor"==f)}if(p&&!h){var d=r.constructor,g=t.constructor;d==g||!("constructor"in r)||!("constructor"in t)||"function"==typeof d&&d instanceof d&&"function"==typeof g&&g instanceof g||(p=!1)}return o.delete(r),o.delete(t),p},ua=Ee,ia=vt,ca=pt.exports,sa=kt,fa="[object Object]",la=Object.prototype.hasOwnProperty;var va=function(r,t,e,n,a,o){var u=ia(r),i=ia(t),c=u?"[object Array]":ua(r),s=i?"[object Array]":ua(t),f=(c="[object Arguments]"==c?fa:c)==fa,l=(s="[object Arguments]"==s?fa:s)==fa,v=c==s;if(v&&ca(r)){if(!ca(t))return!1;u=!0,f=!1}if(v&&!f)return o||(o=new ea),u||sa(r)?na(r,t,e,n,a,o):aa(r,t,c,e,n,a,o);if(!(1&e)){var p=f&&la.call(r,"__wrapped__"),h=l&&la.call(t,"__wrapped__");if(p||h){var y=p?r.value():r,b=h?t.value():t;return o||(o=new ea),a(y,b,e,n,o)}}return!!v&&(o||(o=new ea),oa(r,t,e,n,a,o))},pa=nt;var ha=function r(t,e,n,a,o){return t===e||(null==t||null==e||!pa(t)&&!pa(e)?t!=t&&e!=e:va(t,e,n,a,r,o))},ya=Object.prototype.hasOwnProperty;var ba=function(r,t){return null!=r&&ya.call(r,t)},_a=dn;var da=function(r,t){return null!=r&&_a(r,t,ba)},ga=ln;var ja=function(r,t,e){var n=null==r?void 0:ga(r,t);return void 0===n?e:n},wa=Xr,Oa=ha;var ma=function(r,t,e,n){var a=e.length,o=a,u=!n;if(null==r)return!o;for(r=Object(r);a--;){var i=e[a];if(u&&i[2]?i[1]!==r[i[0]]:!(i[0]in r))return!1}for(;++a<o;){var c=(i=e[a])[0],s=r[c],f=i[1];if(u&&i[2]){if(void 0===s&&!(c in r))return!1}else{var l=new wa;if(n)var v=n(s,f,c,r,t,l);if(!(void 0===v?Oa(f,s,3,n,l):v))return!1}}return!0},Aa=q;var za=function(r){return r==r&&!Aa(r)},Sa=za,xa=Yt;var Pa=function(r){for(var t=xa(r),e=t.length;e--;){var n=t[e],a=r[n];t[e]=[n,a,Sa(a)]}return t};var ka=function(r){return function(t,e,n){for(var a=-1,o=Object(t),u=n(t),i=u.length;i--;){var c=u[r?i:++a];if(!1===e(o[c],c,o))break}return t}}(),Ea=Pn,Ta=xn,Ma=$n;var $a=function(r,t){return Ma(Ta(r,t,Ea),r+"")},Da=Nt,Fa=Ee,Ia=lt,Ba=vt,Ca=Jt,qa=pt.exports,Ra=qt,Ua=kt,La=Object.prototype.hasOwnProperty;var Va=function(r){if(null==r)return!0;if(Ca(r)&&(Ba(r)||"string"==typeof r||"function"==typeof r.splice||qa(r)||Ua(r)||Ia(r)))return!r.length;var t=Fa(r);if("[object Map]"==t||"[object Set]"==t)return!r.size;if(Ra(r))return!Da(r).length;for(var e in r)if(La.call(r,e))return!1;return!0};var Wa=function(r,t,e,n){for(var a=r.length,o=e+(n?1:-1);n?o--:++o<a;)if(t(r[o],o,r))return o;return-1};var Na=Wa,Ga=function(r){return r!=r},Ha=function(r,t,e){for(var n=e-1,a=r.length;++n<a;)if(r[n]===t)return n;return-1};var Ja=function(r,t,e){return t==t?Ha(r,t,e):Na(r,Ga,e)},Ka=Ja;var Qa=function(r,t){return!!(null==r?0:r.length)&&Ka(r,t,0)>-1};var Xa=function(r,t,e){for(var n=-1,a=null==r?0:r.length;++n<a;)if(e(t,r[n]))return!0;return!1},Ya=qn,Za=Qa,ro=Xa,to=Ge,eo=mt,no=Rn;var ao=function(r,t,e,n){var a=-1,o=Za,u=!0,i=r.length,c=[],s=t.length;if(!i)return c;e&&(t=to(t,eo(e))),n?(o=ro,u=!1):t.length>=200&&(o=no,u=!1,t=new Ya(t));r:for(;++a<i;){var f=r[a],l=null==e?f:e(f);if(f=n||0!==f?f:0,u&&l==l){for(var v=s;v--;)if(t[v]===l)continue r;c.push(f)}else o(t,l,n)||c.push(f)}return c},oo=Jt,uo=nt;var io=function(r){return uo(r)&&oo(r)};
//# sourceMappingURL=isArrayLikeObject-a9c7973b.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/lib/command-stack.es.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/lib/command-stack.es.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ u)
/* harmony export */ });
/* harmony import */ var _createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../createClass-32a0cf0f.js */ "../../node_modules/@elyra/canvas/dist/createClass-32a0cf0f.js");
/* harmony import */ var immutable__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! immutable */ "../../node_modules/immutable/dist/immutable.es.js");
var d=function(){function d(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_0__._)(this,d);var n=new immutable__WEBPACK_IMPORTED_MODULE_1__.Record({undoCmnds:new immutable__WEBPACK_IMPORTED_MODULE_1__.List,redoCmnds:new immutable__WEBPACK_IMPORTED_MODULE_1__.Stack});this.rec=n()}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_0__.a)(d,[{key:"do",value:function(n){this.rec=this.rec.merge({undoCmnds:this.rec.undoCmnds.push(n),redoCmnds:new immutable__WEBPACK_IMPORTED_MODULE_1__.Stack}),this.rec.undoCmnds.size>100&&(this.rec=this.rec.set("undoCmnds",this.rec.undoCmnds.shift())),n.do()}},{key:"undo",value:function(){if(this.canUndo()){var n=this.getPrevious();this.rec=this.rec.merge({undoCmnds:this.rec.undoCmnds.pop(),redoCmnds:this.rec.redoCmnds.push(n)}),n.undo()}}},{key:"redo",value:function(){if(this.canRedo()){var n=this.getNext();this.rec=this.rec.merge({undoCmnds:this.rec.undoCmnds.push(n),redoCmnds:this.rec.redoCmnds.pop()}),n.redo()}}},{key:"canUndo",value:function(){return!this.rec.undoCmnds.isEmpty()}},{key:"canRedo",value:function(){return!this.rec.redoCmnds.isEmpty()}},{key:"getPrevious",value:function(){return this.rec.undoCmnds.last()}},{key:"getNext",value:function(){return this.rec.redoCmnds.first()}},{key:"getUndoCommands",value:function(){return this.rec.undoCmnds}},{key:"getRedoCommands",value:function(){return this.rec.redoCmnds}}]),d}(),u=function(){function t(){(0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_0__._)(this,t),this.commands=new d}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_0__.a)(t,[{key:"do",value:function(n){this.commands.do(n)}},{key:"undo",value:function(){this.commands.undo()}},{key:"redo",value:function(){this.commands.redo()}},{key:"getUndoCommand",value:function(){return this.commands.canUndo()?this.commands.getPrevious():null}},{key:"getRedoCommand",value:function(){return this.commands.canRedo()?this.commands.getNext():null}},{key:"getStack",value:function(){return{undos:this.commands.getUndoCommands(),redos:this.commands.getRedoCommands()}}},{key:"canUndo",value:function(){return this.commands.canUndo()}},{key:"canRedo",value:function(){return this.commands.canRedo()}},{key:"clearCommandStack",value:function(){this.commands=new d}}]),t}();
//# sourceMappingURL=command-stack.es.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/lib/context-menu.es.js":
/*!********************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/lib/context-menu.es.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ y)
/* harmony export */ });
/* harmony import */ var _createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../createClass-32a0cf0f.js */ "../../node_modules/@elyra/canvas/dist/createClass-32a0cf0f.js");
/* harmony import */ var _getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../getPrototypeOf-97272efe.js */ "../../node_modules/@elyra/canvas/dist/getPrototypeOf-97272efe.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../canvas-constants-3c09c7f6.js */ "../../node_modules/@elyra/canvas/dist/canvas-constants-3c09c7f6.js");
/* harmony import */ var _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../extends-cf86ca1c.js */ "../../node_modules/@elyra/canvas/dist/extends-cf86ca1c.js");
/* harmony import */ var react_contextmenu__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react-contextmenu */ "../../node_modules/react-contextmenu/es6/index.js");
/* harmony import */ var _icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../icon-caf4caca.js */ "../../node_modules/@elyra/canvas/dist/icon-caf4caca.js");
/* harmony import */ var _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../canvas-logger-815781bb.js */ "../../node_modules/@elyra/canvas/dist/canvas-logger-815781bb.js");
function p(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__.a)(e);if(t){var i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__.a)(this).constructor;n=Reflect.construct(r,arguments,i)}else n=r.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__.b)(this,n)}}var h=function(o){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__._)(a,o);var c=p(a);function a(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,a),(n=c.call(this,t)).logger=new _canvas_logger_815781bb_js__WEBPACK_IMPORTED_MODULE_4__.L("CC-ContextMenu"),n.onClick=n.onClick.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__.c)(n)),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(a,[{key:"onClick",value:function(e){var t=e.target.dataset.color;this.props.clickActionHandler(t)}},{key:"render",value:function(){return this.logger.log("render"),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"color-picker-panel",onClick:this.onClick},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{tabIndex:"0","data-color":"bkg-col-white-0",className:"color-picker-item white-0"}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{tabIndex:"0","data-color":"bkg-col-yellow-20",className:"color-picker-item yellow-20"}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{tabIndex:"0","data-color":"bkg-col-gray-20",className:"color-picker-item gray-20"}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{tabIndex:"0","data-color":"bkg-col-green-20",className:"color-picker-item green-20"}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{tabIndex:"0","data-color":"bkg-col-teal-20",className:"color-picker-item teal-20"}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{tabIndex:"0","data-color":"bkg-col-cyan-20",className:"color-picker-item cyan-20"}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{tabIndex:"0","data-color":"bkg-col-red-50",className:"color-picker-item red-50"}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{tabIndex:"0","data-color":"bkg-col-orange-40",className:"color-picker-item orange-40"}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{tabIndex:"0","data-color":"bkg-col-gray-50",className:"color-picker-item gray-50"}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{tabIndex:"0","data-color":"bkg-col-green-50",className:"color-picker-item green-50"}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{tabIndex:"0","data-color":"bkg-col-teal-50",className:"color-picker-item teal-50"}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{tabIndex:"0","data-color":"bkg-col-cyan-50",className:"color-picker-item cyan-50"}))}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function v(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__.a)(e);if(t){var i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__.a)(this).constructor;n=Reflect.construct(r,arguments,i)}else n=r.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__.b)(this,n)}}var k=function(o){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__._)(f,o);var c=v(f);function f(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,f),(n=c.call(this,t)).state={},n.itemSelected=n.itemSelected.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__.c)(n)),n.colorClicked=n.colorClicked.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__.c)(n)),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(f,[{key:"onContextMenu",value:function(e){e.preventDefault()}},{key:"itemSelected",value:function(e,t){this.props.contextHandler(e),t&&t.stopPropagation()}},{key:"colorClicked",value:function(e){this.props.contextHandler("colorSelectedObjects",{color:e})}},{key:"calculateMenuSize",value:function(e){for(var t=0,n=0;n<e.length;++n){e[n].divider&&t++}return{height:30*(e.length-t)+1*t,width:160}}},{key:"calculateMenuPos",value:function(e,t,n){var o={x:e.x,y:e.y};return e.y+t.height>n.height&&(o.y=n.height-t.height-5,o.y<0&&(o.y=0)),e.x+t.width>n.width&&(o.x-=t.width),o}},{key:"areAllSubmenuItemsDisabled",value:function(e){var t=0,n=0;return e.forEach((function(e){e.divider||t++,!1===e.enable&&n++})),n===t}},{key:"buildMenu",value:function(e,t,n,o){for(var c={className:"contextmenu-divider"},r=[],a=0,l=!1,d=0;d<e.length;++d){var m=e[d].divider,f=e[d].submenu;if(m)l||(r.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_contextmenu__WEBPACK_IMPORTED_MODULE_1__.MenuItem,{attributes:c,key:d+1,onClick:function(){},divider:!0})),a+=1,l=!0);else if(f)if(l=!1,"colorPicker"===e[d].menu){var p={width:160,height:50},h=this.buildColorPickerPanel(),v=this.buildSubMenu(e,d,h,a,n,t,p,o,!1);r.push(v),a+=30}else{var k={disabled:this.areAllSubmenuItemsDisabled(e[d].menu)},b=this.calculateMenuSize(e[d].menu),y=this.buildMenu(e[d].menu,t,n,o),g=this.buildSubMenu(e,d,y,a,n,t,b,o,k);r.push(g),a+=30}else{l=!1;var x={disabled:!1===e[d].enable};r.push(react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_contextmenu__WEBPACK_IMPORTED_MODULE_1__.MenuItem,(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_5__._)({onClick:this.itemSelected.bind(null,e[d].action),key:d+1},x),e[d].label)),a+=30}}return r}},{key:"buildColorPickerPanel",value:function(){return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(h,(0,_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_6__._)({clickActionHandler:this.colorPickHandler},"clickActionHandler",this.colorClicked))}},{key:"buildSubMenu",value:function(e,t,n,o,c,r,a,s,f){var p=this.buildRtlState(c,r,a,s),h=this.buildSubMenuPosStyle(o,c,a,s),v=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_icon_caf4caca_js__WEBPACK_IMPORTED_MODULE_7__.I,{type:_canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_6__.C.CHEVRONARROWS.RIGHT,disabled:!1,className:"react-contextmenu-submenu-icon"}),k=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",null,e[t].label,v," ");return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_contextmenu__WEBPACK_IMPORTED_MODULE_1__.SubMenu,(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_5__._)({title:k,key:t+1,className:"contextmenu-submenu",rtl:p},f),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{key:t+1,style:h,className:"context-menu-popover"},n))}},{key:"buildRtlState",value:function(e,t,n,o){return e.x+t.width+n.width>o.right}},{key:"buildSubMenuPosStyle",value:function(e,t,n,o){var c=o.bottom-(t.y+e+n.height);return{top:(c>0?0:c-5)+"px"}}},{key:"render",value:function(){var e=this.calculateMenuSize(this.props.menuDefinition),t=this.calculateMenuPos(this.props.mousePos,e,this.props.canvasRect),n={left:t.x+"px",top:t.y+"px"},o=this.buildMenu(this.props.menuDefinition,e,t,this.props.canvasRect);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{id:"context-menu-popover",className:"context-menu-popover",style:n,onContextMenu:this.onContextMenu},o)}}]),f}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function b(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,r=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__.a)(e);if(t){var i=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__.a)(this).constructor;n=Reflect.construct(r,arguments,i)}else n=r.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__.b)(this,n)}}var y=function(o){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__._)(a,o);var c=b(a);function a(t){var n;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__._)(this,a),(n=c.call(this,t)).state={},n.contextMenuClicked=n.contextMenuClicked.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__.c)(n)),n.handleClickOutside=n.handleClickOutside.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_2__.c)(n)),n}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_3__.a)(a,[{key:"componentDidMount",value:function(){document.addEventListener("click",this.handleClickOutside,!0)}},{key:"componentWillUnmount",value:function(){document.removeEventListener("click",this.handleClickOutside,!0)}},{key:"getCanvasRect",value:function(){var e=document.getElementById(this.props.containingDivId).getBoundingClientRect();return{top:0,bottom:e.bottom-e.top,left:0,right:e.right-e.left,height:e.height,width:e.width}}},{key:"handleClickOutside",value:function(e){if(2===e.button||e.ctrlKey)e.stopPropagation();else{var t=document.getElementById("context-menu-popover");t&&!t.contains(e.target)&&(this.props.stopPropagation&&e.stopPropagation(),this.props.closeContextMenu())}}},{key:"contextMenuClicked",value:function(e,t){this.props.contextMenuActionHandler(e,t)}},{key:"render",value:function(){return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(k,{contextHandler:this.contextMenuClicked,menuDefinition:this.props.contextMenuDef,canvasRect:this.getCanvasRect(),mousePos:this.props.contextMenuPos})}}]),a}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));
//# sourceMappingURL=context-menu.es.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/lib/tooltip.es.js":
/*!***************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/lib/tooltip.es.js ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ u)
/* harmony export */ });
/* harmony import */ var _getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../getPrototypeOf-97272efe.js */ "../../node_modules/@elyra/canvas/dist/getPrototypeOf-97272efe.js");
/* harmony import */ var _createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../createClass-32a0cf0f.js */ "../../node_modules/@elyra/canvas/dist/createClass-32a0cf0f.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react_portal__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! react-portal */ "../../node_modules/react-portal/es/PortalCompat.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/Link/Link.js");
function a(t){var o=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var l,s=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_1__.a)(t);if(o){var n=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_1__.a)(this).constructor;l=Reflect.construct(s,arguments,n)}else l=s.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_1__.b)(this,l)}}var u=function(e){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_1__._)(u,e);var i=a(u);function u(t){var e;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_2__._)(this,u),(e=i.call(this,t)).state={isTooltipVisible:!1},e.pendingTooltip=null,e.hideTooltipOnScrollAndResize=e.hideTooltipOnScrollAndResize.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_1__.c)(e)),e}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_2__.a)(u,[{key:"componentDidMount",value:function(){window.addEventListener("scroll",this.hideTooltipOnScrollAndResize,!0),window.addEventListener("resize",this.hideTooltipOnScrollAndResize,!0),this.props.targetObj&&this.setTooltipVisible(!0)}},{key:"componentWillUnmount",value:function(){window.removeEventListener("scroll",this.hideTooltipOnScrollAndResize,!0),window.removeEventListener("resize",this.hideTooltipOnScrollAndResize,!0),this.pendingTooltip&&clearTimeout(this.pendingTooltip)}},{key:"setTooltipVisible",value:function(t){if((!this.showTooltip()||!t&&this.pendingTooltip)&&(clearTimeout(this.pendingTooltip),this.pendingTooltip=null,this.setState({isTooltipVisible:!1})),this.showTooltip()){var e=document.querySelector("[data-id='"+this.props.id+"']");if(this.pendingTooltip=null,this.setState({isTooltipVisible:t}),t){var i=null;(i=this.props.targetObj?this.props.targetObj:document.querySelector("[data-id='"+this.props.id+"-trigger']"))&&e&&this.updateTooltipLayout(e,i,e.getAttribute("direction"))}}}},{key:"getStyleValue",value:function(t){return t+"px"}},{key:"getNewDirection",value:function(t){var e;switch(t){case"top":e="bottom";break;case"bottom":e="top";break;case"left":e="right";break;default:e="left"}return e}},{key:"showTooltip",value:function(){var t=this.canDisplayFullText(this.triggerRef);return!this.props.disable&&!this.props.showToolTipIfTruncated||!this.props.disable&&this.props.showToolTipIfTruncated&&!t}},{key:"canDisplayFullText",value:function(t){if(t){var e=t.firstChild&&t.firstChild.scrollWidth?t.firstChild.scrollWidth:0,i=t.offsetWidth,o=e;0===e&&(o=t.scrollWidth);var l=o<=i;return l}return!1}},{key:"showTooltipWithDelay",value:function(){if(!this.pendingTooltip&&this.showTooltip()){var t=this;this.pendingTooltip=setTimeout((function(){t.setTooltipVisible(!0)}),this.props.delay)}}},{key:"updateTooltipLayout",value:function(t,e,i){var o=i,l=document.documentElement.clientWidth,s=document.documentElement.clientHeight,n=e.getBoundingClientRect(),r=t.querySelector("svg"),p=r.getBoundingClientRect();if(t.style.left=this.getStyleValue(n.left),t.style.top=this.getStyleValue(n.top),this.props.mousePos)this.updateLocationBasedOnMousePos(t,this.props.mousePos,i);else{if("top"===o||"bottom"===o){var h=n.left;t.offsetWidth>n.width?(h-=(t.offsetWidth-n.width)/2)<0&&(h=2):t.offsetWidth<n.width&&(h+=(n.width-t.offsetWidth)/2),t.style.left=this.getStyleValue(h),h+t.offsetWidth>l&&(t.style.left=this.getStyleValue(l-t.offsetWidth))}else if("left"===o)for(;t.offsetLeft+t.offsetWidth+p.width>n.left;)t.style.left=this.getStyleValue(n.left-t.offsetWidth-p.width);else"right"===o&&(t.style.left=this.getStyleValue(n.right+p.width));if("top"===o)t.style.top=this.getStyleValue(n.top-p.height-t.offsetHeight);else if("bottom"===o)t.style.top=this.getStyleValue(n.bottom+p.height);else if("left"===o||"right"===o){var a=n.top;t.offsetHeight>n.height?(a-=(t.offsetHeight-n.height)/2)<0&&(a=n.top):t.offsetHeight<n.height&&(a+=(n.height-t.offsetHeight)/2),t.style.top=this.getStyleValue(a+1),s-t.offsetHeight<n.top&&(t.style.top=this.getStyleValue(s-t.offsetHeight))}"top"===o||"bottom"===o?r.style.left=this.getStyleValue(n.left-t.getBoundingClientRect().left+e.getBoundingClientRect().width/2-p.width/2+1):"left"===o?r.style.left=this.getStyleValue(t.offsetWidth-3):"right"===o&&(r.style.left=this.getStyleValue(2-p.width)),"top"===o?r.style.top=this.getStyleValue(t.offsetHeight-5):"bottom"===o?r.style.top="-11px":"left"!==o&&"right"!==o||(r.style.top=this.getStyleValue(n.top-t.getBoundingClientRect().top+e.offsetHeight/2-p.height/2))}if(this.isOutOfBounds(t)&&t.getAttribute("direction")===o){var u=this.getNewDirection(o);return this.updateTooltipLayout(t,e,u),void t.setAttribute("direction",u)}}},{key:"updateLocationBasedOnMousePos",value:function(t,e,i){var o=i,l=document.documentElement.clientWidth,s=document.documentElement.clientHeight,n=t.querySelector("svg"),r=n.getBoundingClientRect(),p=this.props.mousePos.x,h=this.props.mousePos.y;if("top"===o||"bottom"===o){var a=p-t.offsetWidth/2;l-t.offsetWidth<a?a=l-t.offsetWidth:a<0&&(a=2),t.style.left=this.getStyleValue(a)}else"left"===o?t.style.left=this.getStyleValue(p-t.offsetWidth-r.width-5):"right"===o&&(t.style.left=this.getStyleValue(p+r.width+5));if("top"===o)t.style.top=this.getStyleValue(h-r.height-t.offsetHeight);else if("bottom"===o)t.style.top=this.getStyleValue(h+2*r.height);else if("left"===o||"right"===o){var u=h-t.offsetHeight/2;s-t.offsetHeight<u?u=s-t.offsetHeight:u<0&&(u=2),t.style.top=this.getStyleValue(u+1)}"top"===o||"bottom"===o?n.style.left=this.getStyleValue(p-t.getBoundingClientRect().left-r.width/2):"left"===o?n.style.left=this.getStyleValue(t.offsetWidth-3):"right"===o&&(n.style.left=this.getStyleValue(2-r.width)),"top"===o?n.style.top=this.getStyleValue(t.offsetHeight-5):"bottom"===o?n.style.top="-11px":"left"!==o&&"right"!==o||(n.style.top=this.getStyleValue(h-t.getBoundingClientRect().top-r.height/2))}},{key:"isOutOfBounds",value:function(t){var e=parseFloat(t.style.left),i=parseFloat(t.style.top);return e+t.offsetWidth>document.documentElement.clientWidth||e<0||i<0||i+t.offsetHeight>document.documentElement.clientHeight}},{key:"toggleTooltipOnClick",value:function(t){t.stopPropagation(),t.preventDefault(),this.state.isTooltipVisible?this.setTooltipVisible(!1):this.setTooltipVisible(!0)}},{key:"hideTooltipOnScrollAndResize",value:function(t){this.state.isTooltipVisible&&this.setTooltipVisible(!1)}},{key:"tooltipLinkOnClick",value:function(t){window.open(t,"_blank","noopener")}},{key:"render",value:function(){var t=this,e=null,i=null;if(this.props.children){i=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":this.props.id+"-trigger",className:"tooltip-trigger",onMouseOver:this.props.showToolTipOnClick?null:function(){return t.setTooltipVisible(!0)},onMouseLeave:this.props.showToolTipOnClick?null:function(){return t.setTooltipVisible(!1)},onMouseDown:this.props.showToolTipOnClick?null:function(){return t.setTooltipVisible(!1)},onClick:this.props.showToolTipOnClick?function(e){return t.toggleTooltipOnClick(e)}:null,onFocus:this.props.showToolTipOnClick?function(){return t.showTooltipWithDelay()}:null,onBlur:this.props.showToolTipOnClick?function(e){null!==e.relatedTarget&&t.setTooltipVisible(!1)}:null,tabIndex:this.props.showToolTipOnClick?0:null,ref:function(e){return t.triggerRef=e}},this.props.children)}"string"==typeof this.props.tip?e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("span",{id:"tooltipContainer"},this.props.tip):"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_1__.d)(this.props.tip)&&(e=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{id:"tooltipContainer"},this.props.tip));var o="common-canvas-tooltip";this.props.className&&(o+=" "+this.props.className);var s=null;if(this.state.isTooltipVisible&&this.props.tooltipLinkHandler&&this.props.link){var n=this.props.tooltipLinkHandler(this.props.link);"object"===(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_1__.d)(n)&&n.label&&n.url&&(s=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_3__["default"],{className:"tooltip-link",id:this.props.link.id,onClick:this.tooltipLinkOnClick.bind(this,n.url)},n.label))}return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"tooltip-container"},i,react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_portal__WEBPACK_IMPORTED_MODULE_4__["default"],null,react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{"data-id":this.props.id,className:o,"aria-hidden":!this.state.isTooltipVisible,direction:this.props.direction},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("svg",{id:"tipArrow",x:"0px",y:"0px",viewBox:"0 0 9.1 16.1"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("polyline",{points:"9.1,15.7 1.4,8.1 9.1,0.5"}),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("polygon",{points:"8.1,16.1 0,8.1 8.1,0 8.1,1.4 1.4,8.1 8.1,14.7"})),e,s)))}}]),u}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));u.defaultProps={delay:200,direction:"bottom",showToolTipIfTruncated:!1,showToolTipOnClick:!1};
//# sourceMappingURL=tooltip.es.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/toolbar-a5ec3435.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/toolbar-a5ec3435.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "T": () => (/* binding */ ue),
/* harmony export */   "d": () => (/* binding */ re),
/* harmony export */   "t": () => (/* binding */ te)
/* harmony export */ });
/* harmony import */ var _isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./isArrayLikeObject-a9c7973b.js */ "../../node_modules/@elyra/canvas/dist/isArrayLikeObject-a9c7973b.js");
/* harmony import */ var _datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./datarecord-metadata-v3-schema-81228a9a.js */ "../../node_modules/@elyra/canvas/dist/datarecord-metadata-v3-schema-81228a9a.js");
/* harmony import */ var _createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./createClass-32a0cf0f.js */ "../../node_modules/@elyra/canvas/dist/createClass-32a0cf0f.js");
/* harmony import */ var _getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./getPrototypeOf-97272efe.js */ "../../node_modules/@elyra/canvas/dist/getPrototypeOf-97272efe.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react_intl__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react-intl */ "webpack/sharing/consume/default/react-intl/react-intl");
/* harmony import */ var react_intl__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react_intl__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var react_resize_detector__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! react-resize-detector */ "../../node_modules/react-resize-detector/lib/esm/index.js");
/* harmony import */ var _lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./lib/tooltip.es.js */ "../../node_modules/@elyra/canvas/dist/lib/tooltip.es.js");
/* harmony import */ var carbon_components_react__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! carbon-components-react */ "../../node_modules/carbon-components-react/es/components/Button/Button.js");
/* harmony import */ var react_inlinesvg__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! react-inlinesvg */ "../../node_modules/react-inlinesvg/esm/index.js");
/* harmony import */ var _extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./extends-cf86ca1c.js */ "../../node_modules/@elyra/canvas/dist/extends-cf86ca1c.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-25.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-20.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-28.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-21.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-7.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-6.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-19.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-0.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-30.js");
/* harmony import */ var _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./canvas-constants-3c09c7f6.js */ "../../node_modules/@elyra/canvas/dist/canvas-constants-3c09c7f6.js");
var $=/\s/;var _=function(e){for(var t=e.length;t--&&$.test(e.charAt(t)););return t},J=/^\s+/;var G=function(e){return e?e.slice(0,_(e)+1).replace(J,""):e},K=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_2__.M,Q=_isArrayLikeObject_a9c7973b_js__WEBPACK_IMPORTED_MODULE_2__.J,U=/^[-+]0x[0-9a-f]+$/i,X=/^0b[01]+$/i,Y=/^0o[0-7]+$/i,ee=parseInt;var te=function(e){if("number"==typeof e)return e;if(Q(e))return NaN;if(K(e)){var t="function"==typeof e.valueOf?e.valueOf():e;e=K(t)?t+"":t}if("string"!=typeof e)return 0===e?e:+e;e=G(e);var r=X.test(e);return r||Y.test(e)?ee(e.slice(2),r?2:8):U.test(e)?NaN:+e},re={"toolbar.palette":"Palette","toolbar.zoomIn":"Zoom in","toolbar.zoomOut":"Zoom out","toolbar.zoomToFit":"Zoom to fit","toolbar.overflowMenu":"Overflow menu","toolbar.label":"Canvas toolbar"};function ne(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,n=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;r=Reflect.construct(n,arguments,o)}else r=n.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,r)}}var oe=function(e){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(r,e);var t=ne(r);function r(e){var o;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,r),(o=t.call(this,e)).actionClickHandler=o.actionClickHandler.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(o)),o}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(r,[{key:"getDefaultIcon",value:function(e){var t=e.iconTypeOverride?e.iconTypeOverride:e.action,r=!e.enable;switch(t){case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.q:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_6__.StopFilledAlt16,{disabled:r});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.p:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_7__.Play16,{disabled:r});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.o:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__.Undo16,{disabled:r});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.n:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_9__.Redo16,{disabled:r});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.m:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_10__.Cut16,{disabled:r});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.l:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_11__.Copy16,{disabled:r});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.k:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_12__.Paste16,{disabled:r});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.j:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_13__.AddComment16,{disabled:r});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.i:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__.TrashCan16,{disabled:r});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.h:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_14__.ZoomIn16,{disabled:r});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.g:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_14__.ZoomOut16,{disabled:r});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.f:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_inlinesvg__WEBPACK_IMPORTED_MODULE_15__["default"],{src:"data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2016%2016%22%20fill%3D%22currentColor%22%3E%20%3Cpath%20d%3D%22M6%2C7.5h4v1H6Z%22%2F%3E%20%3Cpath%20d%3D%22M4%2C12h8a.94.94%2C0%2C0%2C0%2C1-1V5a.94.94%2C0%2C0%2C0-1-1H4A.94.94%2C0%2C0%2C0%2C3%2C5v6A.94.94%2C0%2C0%2C0%2C4%2C12ZM4%2C5h8v6H4Z%22%2F%3E%20%3Cpolygon%20points%3D%222%203.5%201%203.5%201%201%203.5%201%203.5%202%202%202%202%203.5%22%2F%3E%20%3Cpolygon%20points%3D%2215%203.5%2014%203.5%2014%202%2012.5%202%2012.5%201%2015%201%2015%203.5%22%2F%3E%20%3Cpolygon%20points%3D%2215%2015%2012.5%2015%2012.5%2014%2014%2014%2014%2012.5%2015%2012.5%2015%2015%22%2F%3E%20%3Cpolygon%20points%3D%223.5%2015%201%2015%201%2012.5%202%2012.5%202%2014%203.5%2014%203.5%2015%22%2F%3E%3C%2Fsvg%3E",disabled:r});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.e:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_inlinesvg__WEBPACK_IMPORTED_MODULE_15__["default"],{src:"data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2016%2016%22%3E%3Crect%20x%3D%221.5%22%20y%3D%222%22%20width%3D%2213%22%20height%3D%221%22%2F%3E%3Crect%20x%3D%221.5%22%20y%3D%2213%22%20width%3D%2213%22%20height%3D%221%22%2F%3E%3Cpath%20d%3D%22M7%2C10.5H2a.47.47%2C0%2C0%2C1-.5-.5V6A.47.47%2C0%2C0%2C1%2C2%2C5.5H7a.47.47%2C0%2C0%2C1%2C.5.5v4A.47.47%2C0%2C0%2C1%2C7%2C10.5Zm-4.5-1h4v-3h-4Z%22%2F%3E%3Cpath%20d%3D%22M14%2C10.5H9a.47.47%2C0%2C0%2C1-.5-.5V6A.47.47%2C0%2C0%2C1%2C9%2C5.5h5a.47.47%2C0%2C0%2C1%2C.5.5v4A.47.47%2C0%2C0%2C1%2C14%2C10.5Zm-4.5-1h4v-3h-4Z%22%2F%3E%3C%2Fsvg%3E",disabled:r});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.d:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_inlinesvg__WEBPACK_IMPORTED_MODULE_15__["default"],{src:"data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2016%2016%22%3E%3Crect%20x%3D%222%22%20y%3D%221.5%22%20width%3D%221%22%20height%3D%2213%22%2F%3E%3Crect%20x%3D%2213%22%20y%3D%221.5%22%20width%3D%221%22%20height%3D%2213%22%2F%3E%3Cpath%20d%3D%22M10.5%2C7.5h-5A.47.47%2C0%2C0%2C1%2C5%2C7V3a.47.47%2C0%2C0%2C1%2C.5-.5h5A.47.47%2C0%2C0%2C1%2C11%2C3V7A.47.47%2C0%2C0%2C1%2C10.5%2C7.5ZM6%2C6.5h4v-3H6Z%22%2F%3E%3Cpath%20d%3D%22M10.5%2C13.5h-5A.47.47%2C0%2C0%2C1%2C5%2C13V9a.47.47%2C0%2C0%2C1%2C.5-.5h5A.47.47%2C0%2C0%2C1%2C11%2C9v4A.47.47%2C0%2C0%2C1%2C10.5%2C13.5ZM6%2C12.5h4v-3H6Z%22%2F%3E%3C%2Fsvg%3E",disabled:r});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.c:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_inlinesvg__WEBPACK_IMPORTED_MODULE_15__["default"],{src:"data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2032%2032%22%20fill%3D%22currentColor%22%3E%20%3Crect%20width%3D%2232%22%20height%3D%2232%22%20fill%3D%22none%22%2F%3E%20%3Cpath%20d%3D%22M28%2C4H4A2%2C2%2C0%2C0%2C0%2C2%2C6V26a2%2C2%2C0%2C0%2C0%2C2%2C2H28a2%2C2%2C0%2C0%2C0%2C2-2V6A2%2C2%2C0%2C0%2C0%2C28%2C4Zm0%2C22H12V17.1h8.9l-2.5%2C2.5%2C1.5%2C1.5L25%2C16l-5.1-5.1-1.5%2C1.5%2C2.5%2C2.5H12V6H28Z%22%2F%3E%3C%2Fsvg%3E",disabled:r});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.b:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_inlinesvg__WEBPACK_IMPORTED_MODULE_15__["default"],{src:"data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2032%2032%22%20fill%3D%22currentColor%22%3E%20%3Crect%20width%3D%2232%22%20height%3D%2232%22%20fill%3D%22none%22%2F%3E%20%3Cpath%20d%3D%22M28%2C4H4A2%2C2%2C0%2C0%2C0%2C2%2C6V26a2%2C2%2C0%2C0%2C0%2C2%2C2H28a2%2C2%2C0%2C0%2C0%2C2-2V6A2%2C2%2C0%2C0%2C0%2C28%2C4Zm0%2C11H19.1l2.5-2.5L20.1%2C11%2C15%2C16l5.1%2C5.1%2C1.5-1.5-2.5-2.5H28V26H12V6H28Z%22%2F%3E%3C%2Fsvg%3E",disabled:r});case _canvas_constants_3c09c7f6_js__WEBPACK_IMPORTED_MODULE_5__.T:return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_inlinesvg__WEBPACK_IMPORTED_MODULE_15__["default"],{src:"data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2032%2032%22%20fill%3D%22currentColor%22%3E%20%3Cpath%20d%3D%22M27%2C12V27H5V5H20V3H5A2%2C2%2C0%2C0%2C0%2C3%2C5V27a2%2C2%2C0%2C0%2C0%2C2%2C2H27a2%2C2%2C0%2C0%2C0%2C2-2V12Z%22%2F%3E%20%3Ccircle%20class%3D%22dot%22%20cx%3D%2226.5%22%20cy%3D%225.5%22%20r%3D%223.5%22%2F%3E%3C%2Fsvg%3E",disabled:r});default:return null}}},{key:"generateLabel",value:function(e,t,r,n){var o="toolbar-icon-label";return o+=this.generateLabelType(r,n),o+=t?" disabled":"",react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:o},e)}},{key:"generateLabelType",value:function(e,t){return e?" overflow":"before"===t?" before":"after"===t?" after":""}},{key:"generateIcon",value:function(e){var t=this.getDefaultIcon(e);if(e.iconEnabled){var r=e.iconEnabled,n=e.iconDisabled||e.iconEnabled,o=e.enable?r:n,a="toolbar-icon-"+this.props.instanceId+" -"+e.action;t="string"==typeof o?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_inlinesvg__WEBPACK_IMPORTED_MODULE_15__["default"],{id:a,src:o,disabled:!e.enable}):o}return t?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"toolbar-icon"},t):null}},{key:"actionClickHandler",value:function(){this.props.toolbarActionHandler(this.props.actionObj.action)}},{key:"generateButton",value:function(e){var t=null,r=null;this.props.overflow?r=this.generateLabel(e.label,!e.enable,!0):"before"===e.incLabelWithIcon?t=this.generateLabel(e.label,!e.enable,!1,e.incLabelWithIcon):"after"===e.incLabelWithIcon&&(r=this.generateLabel(e.label,!e.enable,!1,e.incLabelWithIcon));var n=this.generateIcon(e),o=e.textContent?react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"toolbar-text-content"}," ",e.textContent," "):null,a=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_16__.c)("toolbar-item-content",e.className?e.className:null,{overflow:this.props.overflow,disabled:!e.enable,default:!e.kind}),i=e.kind||"ghost",s=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:a},t,n,r,o);return s=this.wrapInTooltip(s),s=react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_17__["default"],{kind:i,onClick:this.actionClickHandler,disabled:!e.enable,onFocus:this.props.onFocus,"aria-label":e.label},s)}},{key:"generateActionName",value:function(e){return this.props.actionObj.action+"-action"}},{key:"wrapInTooltip",value:function(e){if(!this.props.overflow&&(this.showLabelAsTip(this.props.actionObj)||this.props.actionObj.tooltip)){var t=this.generateActionName(),r=this.props.actionObj.tooltip?this.props.actionObj.tooltip:this.props.actionObj.label,n=t+"-"+this.props.instanceId+"-tooltip",o=!!this.props.actionObj.enable&&this.props.actionObj.enable;return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_lib_tooltip_es_js__WEBPACK_IMPORTED_MODULE_18__["default"],{id:n,tip:r,disable:!o,className:"icon-tooltip"},e)}return e}},{key:"showLabelAsTip",value:function(e){return!!e.label&&("before"!==e.incLabelWithIcon&&"after"!==e.incLabelWithIcon)}},{key:"render",value:function(){var e=this.props.actionObj,t=this.generateActionName(),r=null;r=e.jsx?this.wrapInTooltip(e.jsx):this.generateButton(e);var n=!this.props.overflow||null,o=e.kind?e.kind:"default",a=(0,_extends_cf86ca1c_js__WEBPACK_IMPORTED_MODULE_16__.c)({"toolbar-overflow-menu-item":this.props.overflow,"toolbar-item":!this.props.overflow&&!e.jsx,"toolbar-jsx-item":!this.props.overflow&&e.jsx,"toolbar-overflow-jsx-item":this.props.overflow&&e.jsx,"toolbar-item-selected":e.isSelected},o,t);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:a,"data-toolbar-item":n},r)}}]),r}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function ae(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,n=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;r=Reflect.construct(n,arguments,o)}else r=n.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,r)}}var ie=function(e){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(r,e);var t=ae(r);function r(e){var o;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,r),(o=t.call(this,e)).toggleExtendedMenu=o.toggleExtendedMenu.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(o)),o}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(r,[{key:"toggleExtendedMenu",value:function(){this.props.toggleExtendedMenu(this.props.index)}},{key:"render",value:function(){var e=this.props.showExtendedMenu?this.props.generateExtensionMenuItems(this.props.index):[],t=this.props.showExtendedMenu?"":"toolbar-popover-list-hide",r=null;e.length>0&&(r=react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"toolbar-popover-list "+t},e));var n="toolbar-spacer toolbar-index-"+this.props.index;return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:n},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"toolbar-overflow-item"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(carbon_components_react__WEBPACK_IMPORTED_MODULE_17__["default"],{kind:"ghost",onClick:this.toggleExtendedMenu,onFocus:this.props.onFocus,"aria-label":this.props.label},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"toolbar-item-content default"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"toolbar-icon"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_12__.OverflowMenuVertical16,null))))),r)}}]),r}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function se(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,n=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;r=Reflect.construct(n,arguments,o)}else r=n.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,r)}}var le=function(e){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(r,e);var t=se(r);function r(){return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,r),t.apply(this,arguments)}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(r,[{key:"render",value:function(){var e=this.props.overflow?"toolbar-divider-overflow":"toolbar-divider";return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:e,"data-toolbar-item":!0,tabIndex:-1,"aria-hidden":!0}," ")}}]),r}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));function ce(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var r,n=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(e);if(t){var o=(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.a)(this).constructor;r=Reflect.construct(n,arguments,o)}else r=n.apply(this,arguments);return (0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.b)(this,r)}}var ue=(0,react_intl__WEBPACK_IMPORTED_MODULE_1__.injectIntl)(function(e){(0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__._)(i,e);var t=ce(i);function i(e){var r;return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__._)(this,i),(r=t.call(this,e)).state={showExtendedMenuIndex:-1},r.leftBar=[],r.rightBar=[],r.onFocus=r.onFocus.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(r)),r.onToolbarResize=r.onToolbarResize.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(r)),r.toggleExtendedMenu=r.toggleExtendedMenu.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(r)),r.generateExtensionMenuItems=r.generateExtensionMenuItems.bind((0,_getPrototypeOf_97272efe_js__WEBPACK_IMPORTED_MODULE_3__.c)(r)),r}return (0,_createClass_32a0cf0f_js__WEBPACK_IMPORTED_MODULE_4__.a)(i,[{key:"onFocus",value:function(){this.setLeftBarItemsTabIndex(),this.setRightBarItemsTabIndex()}},{key:"onScroll",value:function(e){e.currentTarget.scroll(0,0),e.preventDefault()}},{key:"onToolbarResize",value:function(){this.state.showExtendedMenuIndex>-1&&this.setState({showExtendedMenuIndex:-1}),this.setLeftBarItemsTabIndex(),this.setRightBarItemsTabIndex()}},{key:"setLeftBarItemsTabIndex",value:function(){var e=this.getBar("left");if(e){for(var t=e.querySelectorAll("[data-toolbar-item=true]")||[],r=this.getTopOfFirstOverflowItem(e),n=-1,o=0;o<t.length;o++){var a=t[o].getBoundingClientRect();this.setOverflowItemButtonTabIndex(o,-1,e),a.top===r?(n=o,this.setToolbarItemButtonTabIndex(t[o],0)):this.setToolbarItemButtonTabIndex(t[o],-1)}n<t.length&&this.setOverflowItemButtonTabIndex(n+1,0,e)}}},{key:"setRightBarItemsTabIndex",value:function(){for(var e=this.getRightBarItems(),t=0,r=0;r<e.length;r++){var n=e[r].getBoundingClientRect();0===r&&(t=n.top),n.top===t?this.setToolbarItemButtonTabIndex(e[r],0):this.setToolbarItemButtonTabIndex(e[r],-1)}}},{key:"getBar",value:function(e){var t=this.props.instanceId;return document.querySelector(".toolbar-div[instanceid='".concat(t,"'] > .toolbar-").concat(e,"-bar"))||[]}},{key:"getRightBarItems",value:function(){var e=this.getBar("right");return e&&e.querySelectorAll("[data-toolbar-item=true]")||[]}},{key:"getTopOfFirstOverflowItem",value:function(e){var t=this.getOverflowItem(0,e);return t?t.getBoundingClientRect().top:0}},{key:"getOverflowItem",value:function(e,t){var r="toolbar-index-"+e;return t.getElementsByClassName(r)[0]}},{key:"setToolbarItemButtonTabIndex",value:function(e,t){var r=e.querySelector("button");r&&r.setAttribute("tabindex",t)}},{key:"setOverflowItemButtonTabIndex",value:function(e,t,r){var n=this.getOverflowItem(e,r);if(n){var o=n.querySelector("button");o&&o.setAttribute("tabindex",t)}}},{key:"generateToolbarItems",value:function(e,t,r){for(var n=[],o=0;o<e.length;o++){var a=e[o];a&&(r&&!a.divider&&n.push(this.generateOverflowIcon(o)),n.push(this.generateToolbarItem(a,o,t)))}return n}},{key:"generateToolbarItem",value:function(e,t,r){var n=null;return e&&(n=e.divider?react__WEBPACK_IMPORTED_MODULE_0___default().createElement(le,{key:"toolbar-item-key-"+t,overflow:r}):react__WEBPACK_IMPORTED_MODULE_0___default().createElement(oe,{key:"toolbar-item-key-"+t,actionObj:e,toolbarActionHandler:this.props.toolbarActionHandler,overflow:r,instanceId:this.props.instanceId,onFocus:this.onFocus})),n}},{key:"generateOverflowIcon",value:function(e){var t=this.props.additionalText?this.props.additionalText.overflowMenuLabel:"";return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(ie,{key:"toolbar-overflow-item-key-"+e,index:e,showExtendedMenu:this.state.showExtendedMenuIndex===e,toggleExtendedMenu:this.toggleExtendedMenu,generateExtensionMenuItems:this.generateExtensionMenuItems,onFocus:this.onFocus,label:t})}},{key:"generateExtensionMenuItems",value:function(e){var t=this.generateRightOverflowItems();t.reverse();var r=this.leftBar.slice(e).concat(t);return this.generateToolbarItems(r,!0,!1)}},{key:"generateRightOverflowItems",value:function(){for(var e=[],t=this.getRightBarItems(),r=0,n=0;n<t.length;n++){var o=t[n].getBoundingClientRect();0===n&&(r=o.top),o.top!==r&&e.push(this.rightBar[n])}return e}},{key:"toggleExtendedMenu",value:function(e){var t=e===this.state.showExtendedMenuIndex?-1:e;this.setState({showExtendedMenuIndex:t})}},{key:"render",value:function(){this.leftBar=this.props.config.leftBar||[],this.rightBar=this.props.config.rightBar||[],this.rightBar=(0,_datarecord_metadata_v3_schema_81228a9a_js__WEBPACK_IMPORTED_MODULE_19__.b)(this.rightBar).reverse()||[];var e=this.generateToolbarItems(this.leftBar,!1,!0),t=this.generateToolbarItems(this.rightBar,!1,!1);return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("section",{"aria-label":this.props.intl.formatMessage({id:"toolbar.label",defaultMessage:re["toolbar.label"]}),role:"toolbar"},react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_resize_detector__WEBPACK_IMPORTED_MODULE_20__["default"],{handleWidth:!0,onResize:this.onToolbarResize},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"toolbar-div",instanceid:this.props.instanceId},react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"toolbar-left-bar",onScroll:this.onScroll},e),react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div",{className:"toolbar-right-bar"},t))))}}]),i}((react__WEBPACK_IMPORTED_MODULE_0___default().Component)));
//# sourceMappingURL=toolbar-a5ec3435.js.map


/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/codemirror/addon/display/autorefresh.js":
/*!*********************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/codemirror/addon/display/autorefresh.js ***!
  \*********************************************************************************************/
/***/ ((__unused_webpack_module, __unused_webpack_exports, __webpack_require__) => {

// CodeMirror, copyright (c) by Marijn Haverbeke and others
// Distributed under an MIT license: https://codemirror.net/LICENSE

(function(mod) {
  if (true) // CommonJS
    mod(__webpack_require__(/*! ../../lib/codemirror */ "../../node_modules/@elyra/canvas/node_modules/codemirror/lib/codemirror.js"))
  else {}
})(function(CodeMirror) {
  "use strict"

  CodeMirror.defineOption("autoRefresh", false, function(cm, val) {
    if (cm.state.autoRefresh) {
      stopListening(cm, cm.state.autoRefresh)
      cm.state.autoRefresh = null
    }
    if (val && cm.display.wrapper.offsetHeight == 0)
      startListening(cm, cm.state.autoRefresh = {delay: val.delay || 250})
  })

  function startListening(cm, state) {
    function check() {
      if (cm.display.wrapper.offsetHeight) {
        stopListening(cm, state)
        if (cm.display.lastWrapHeight != cm.display.wrapper.clientHeight)
          cm.refresh()
      } else {
        state.timeout = setTimeout(check, state.delay)
      }
    }
    state.timeout = setTimeout(check, state.delay)
    state.hurry = function() {
      clearTimeout(state.timeout)
      state.timeout = setTimeout(check, 50)
    }
    CodeMirror.on(window, "mouseup", state.hurry)
    CodeMirror.on(window, "keyup", state.hurry)
  }

  function stopListening(_cm, state) {
    clearTimeout(state.timeout)
    CodeMirror.off(window, "mouseup", state.hurry)
    CodeMirror.off(window, "keyup", state.hurry)
  }
});


/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/codemirror/addon/display/placeholder.js":
/*!*********************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/codemirror/addon/display/placeholder.js ***!
  \*********************************************************************************************/
/***/ ((__unused_webpack_module, __unused_webpack_exports, __webpack_require__) => {

// CodeMirror, copyright (c) by Marijn Haverbeke and others
// Distributed under an MIT license: https://codemirror.net/LICENSE

(function(mod) {
  if (true) // CommonJS
    mod(__webpack_require__(/*! ../../lib/codemirror */ "../../node_modules/@elyra/canvas/node_modules/codemirror/lib/codemirror.js"));
  else {}
})(function(CodeMirror) {
  CodeMirror.defineOption("placeholder", "", function(cm, val, old) {
    var prev = old && old != CodeMirror.Init;
    if (val && !prev) {
      cm.on("blur", onBlur);
      cm.on("change", onChange);
      cm.on("swapDoc", onChange);
      CodeMirror.on(cm.getInputField(), "compositionupdate", cm.state.placeholderCompose = function() { onComposition(cm) })
      onChange(cm);
    } else if (!val && prev) {
      cm.off("blur", onBlur);
      cm.off("change", onChange);
      cm.off("swapDoc", onChange);
      CodeMirror.off(cm.getInputField(), "compositionupdate", cm.state.placeholderCompose)
      clearPlaceholder(cm);
      var wrapper = cm.getWrapperElement();
      wrapper.className = wrapper.className.replace(" CodeMirror-empty", "");
    }

    if (val && !cm.hasFocus()) onBlur(cm);
  });

  function clearPlaceholder(cm) {
    if (cm.state.placeholder) {
      cm.state.placeholder.parentNode.removeChild(cm.state.placeholder);
      cm.state.placeholder = null;
    }
  }
  function setPlaceholder(cm) {
    clearPlaceholder(cm);
    var elt = cm.state.placeholder = document.createElement("pre");
    elt.style.cssText = "height: 0; overflow: visible";
    elt.style.direction = cm.getOption("direction");
    elt.className = "CodeMirror-placeholder CodeMirror-line-like";
    var placeHolder = cm.getOption("placeholder")
    if (typeof placeHolder == "string") placeHolder = document.createTextNode(placeHolder)
    elt.appendChild(placeHolder)
    cm.display.lineSpace.insertBefore(elt, cm.display.lineSpace.firstChild);
  }

  function onComposition(cm) {
    setTimeout(function() {
      var empty = false
      if (cm.lineCount() == 1) {
        var input = cm.getInputField()
        empty = input.nodeName == "TEXTAREA" ? !cm.getLine(0).length
          : !/[^\u200b]/.test(input.querySelector(".CodeMirror-line").textContent)
      }
      if (empty) setPlaceholder(cm)
      else clearPlaceholder(cm)
    }, 20)
  }

  function onBlur(cm) {
    if (isEmpty(cm)) setPlaceholder(cm);
  }
  function onChange(cm) {
    var wrapper = cm.getWrapperElement(), empty = isEmpty(cm);
    wrapper.className = wrapper.className.replace(" CodeMirror-empty", "") + (empty ? " CodeMirror-empty" : "");

    if (empty) setPlaceholder(cm);
    else clearPlaceholder(cm);
  }

  function isEmpty(cm) {
    return (cm.lineCount() === 1) && (cm.getLine(0) === "");
  }
});


/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/codemirror/addon/hint/javascript-hint.js":
/*!**********************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/codemirror/addon/hint/javascript-hint.js ***!
  \**********************************************************************************************/
/***/ ((__unused_webpack_module, __unused_webpack_exports, __webpack_require__) => {

// CodeMirror, copyright (c) by Marijn Haverbeke and others
// Distributed under an MIT license: https://codemirror.net/LICENSE

(function(mod) {
  if (true) // CommonJS
    mod(__webpack_require__(/*! ../../lib/codemirror */ "../../node_modules/@elyra/canvas/node_modules/codemirror/lib/codemirror.js"));
  else {}
})(function(CodeMirror) {
  var Pos = CodeMirror.Pos;

  function forEach(arr, f) {
    for (var i = 0, e = arr.length; i < e; ++i) f(arr[i]);
  }

  function arrayContains(arr, item) {
    if (!Array.prototype.indexOf) {
      var i = arr.length;
      while (i--) {
        if (arr[i] === item) {
          return true;
        }
      }
      return false;
    }
    return arr.indexOf(item) != -1;
  }

  function scriptHint(editor, keywords, getToken, options) {
    // Find the token at the cursor
    var cur = editor.getCursor(), token = getToken(editor, cur);
    if (/\b(?:string|comment)\b/.test(token.type)) return;
    var innerMode = CodeMirror.innerMode(editor.getMode(), token.state);
    if (innerMode.mode.helperType === "json") return;
    token.state = innerMode.state;

    // If it's not a 'word-style' token, ignore the token.
    if (!/^[\w$_]*$/.test(token.string)) {
      token = {start: cur.ch, end: cur.ch, string: "", state: token.state,
               type: token.string == "." ? "property" : null};
    } else if (token.end > cur.ch) {
      token.end = cur.ch;
      token.string = token.string.slice(0, cur.ch - token.start);
    }

    var tprop = token;
    // If it is a property, find out what it is a property of.
    while (tprop.type == "property") {
      tprop = getToken(editor, Pos(cur.line, tprop.start));
      if (tprop.string != ".") return;
      tprop = getToken(editor, Pos(cur.line, tprop.start));
      if (!context) var context = [];
      context.push(tprop);
    }
    return {list: getCompletions(token, context, keywords, options),
            from: Pos(cur.line, token.start),
            to: Pos(cur.line, token.end)};
  }

  function javascriptHint(editor, options) {
    return scriptHint(editor, javascriptKeywords,
                      function (e, cur) {return e.getTokenAt(cur);},
                      options);
  };
  CodeMirror.registerHelper("hint", "javascript", javascriptHint);

  function getCoffeeScriptToken(editor, cur) {
  // This getToken, it is for coffeescript, imitates the behavior of
  // getTokenAt method in javascript.js, that is, returning "property"
  // type and treat "." as independent token.
    var token = editor.getTokenAt(cur);
    if (cur.ch == token.start + 1 && token.string.charAt(0) == '.') {
      token.end = token.start;
      token.string = '.';
      token.type = "property";
    }
    else if (/^\.[\w$_]*$/.test(token.string)) {
      token.type = "property";
      token.start++;
      token.string = token.string.replace(/\./, '');
    }
    return token;
  }

  function coffeescriptHint(editor, options) {
    return scriptHint(editor, coffeescriptKeywords, getCoffeeScriptToken, options);
  }
  CodeMirror.registerHelper("hint", "coffeescript", coffeescriptHint);

  var stringProps = ("charAt charCodeAt indexOf lastIndexOf substring substr slice trim trimLeft trimRight " +
                     "toUpperCase toLowerCase split concat match replace search").split(" ");
  var arrayProps = ("length concat join splice push pop shift unshift slice reverse sort indexOf " +
                    "lastIndexOf every some filter forEach map reduce reduceRight ").split(" ");
  var funcProps = "prototype apply call bind".split(" ");
  var javascriptKeywords = ("break case catch class const continue debugger default delete do else export extends false finally for function " +
                  "if in import instanceof new null return super switch this throw true try typeof var void while with yield").split(" ");
  var coffeescriptKeywords = ("and break catch class continue delete do else extends false finally for " +
                  "if in instanceof isnt new no not null of off on or return switch then throw true try typeof until void while with yes").split(" ");

  function forAllProps(obj, callback) {
    if (!Object.getOwnPropertyNames || !Object.getPrototypeOf) {
      for (var name in obj) callback(name)
    } else {
      for (var o = obj; o; o = Object.getPrototypeOf(o))
        Object.getOwnPropertyNames(o).forEach(callback)
    }
  }

  function getCompletions(token, context, keywords, options) {
    var found = [], start = token.string, global = options && options.globalScope || window;
    function maybeAdd(str) {
      if (str.lastIndexOf(start, 0) == 0 && !arrayContains(found, str)) found.push(str);
    }
    function gatherCompletions(obj) {
      if (typeof obj == "string") forEach(stringProps, maybeAdd);
      else if (obj instanceof Array) forEach(arrayProps, maybeAdd);
      else if (obj instanceof Function) forEach(funcProps, maybeAdd);
      forAllProps(obj, maybeAdd)
    }

    if (context && context.length) {
      // If this is a property, see if it belongs to some object we can
      // find in the current environment.
      var obj = context.pop(), base;
      if (obj.type && obj.type.indexOf("variable") === 0) {
        if (options && options.additionalContext)
          base = options.additionalContext[obj.string];
        if (!options || options.useGlobalScope !== false)
          base = base || global[obj.string];
      } else if (obj.type == "string") {
        base = "";
      } else if (obj.type == "atom") {
        base = 1;
      } else if (obj.type == "function") {
        if (global.jQuery != null && (obj.string == '$' || obj.string == 'jQuery') &&
            (typeof global.jQuery == 'function'))
          base = global.jQuery();
        else if (global._ != null && (obj.string == '_') && (typeof global._ == 'function'))
          base = global._();
      }
      while (base != null && context.length)
        base = base[context.pop().string];
      if (base != null) gatherCompletions(base);
    } else {
      // If not, just look in the global object, any local scope, and optional additional-context
      // (reading into JS mode internals to get at the local and global variables)
      for (var v = token.state.localVars; v; v = v.next) maybeAdd(v.name);
      for (var c = token.state.context; c; c = c.prev)
        for (var v = c.vars; v; v = v.next) maybeAdd(v.name)
      for (var v = token.state.globalVars; v; v = v.next) maybeAdd(v.name);
      if (options && options.additionalContext != null)
        for (var key in options.additionalContext)
          maybeAdd(key);
      if (!options || options.useGlobalScope !== false)
        gatherCompletions(global);
      forEach(keywords, maybeAdd);
    }
    return found;
  }
});


/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/codemirror/addon/hint/show-hint.js":
/*!****************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/codemirror/addon/hint/show-hint.js ***!
  \****************************************************************************************/
/***/ ((__unused_webpack_module, __unused_webpack_exports, __webpack_require__) => {

// CodeMirror, copyright (c) by Marijn Haverbeke and others
// Distributed under an MIT license: https://codemirror.net/LICENSE

// declare global: DOMRect

(function(mod) {
  if (true) // CommonJS
    mod(__webpack_require__(/*! ../../lib/codemirror */ "../../node_modules/@elyra/canvas/node_modules/codemirror/lib/codemirror.js"));
  else {}
})(function(CodeMirror) {
  "use strict";

  var HINT_ELEMENT_CLASS        = "CodeMirror-hint";
  var ACTIVE_HINT_ELEMENT_CLASS = "CodeMirror-hint-active";

  // This is the old interface, kept around for now to stay
  // backwards-compatible.
  CodeMirror.showHint = function(cm, getHints, options) {
    if (!getHints) return cm.showHint(options);
    if (options && options.async) getHints.async = true;
    var newOpts = {hint: getHints};
    if (options) for (var prop in options) newOpts[prop] = options[prop];
    return cm.showHint(newOpts);
  };

  CodeMirror.defineExtension("showHint", function(options) {
    options = parseOptions(this, this.getCursor("start"), options);
    var selections = this.listSelections()
    if (selections.length > 1) return;
    // By default, don't allow completion when something is selected.
    // A hint function can have a `supportsSelection` property to
    // indicate that it can handle selections.
    if (this.somethingSelected()) {
      if (!options.hint.supportsSelection) return;
      // Don't try with cross-line selections
      for (var i = 0; i < selections.length; i++)
        if (selections[i].head.line != selections[i].anchor.line) return;
    }

    if (this.state.completionActive) this.state.completionActive.close();
    var completion = this.state.completionActive = new Completion(this, options);
    if (!completion.options.hint) return;

    CodeMirror.signal(this, "startCompletion", this);
    completion.update(true);
  });

  CodeMirror.defineExtension("closeHint", function() {
    if (this.state.completionActive) this.state.completionActive.close()
  })

  function Completion(cm, options) {
    this.cm = cm;
    this.options = options;
    this.widget = null;
    this.debounce = 0;
    this.tick = 0;
    this.startPos = this.cm.getCursor("start");
    this.startLen = this.cm.getLine(this.startPos.line).length - this.cm.getSelection().length;

    if (this.options.updateOnCursorActivity) {
      var self = this;
      cm.on("cursorActivity", this.activityFunc = function() { self.cursorActivity(); });
    }
  }

  var requestAnimationFrame = window.requestAnimationFrame || function(fn) {
    return setTimeout(fn, 1000/60);
  };
  var cancelAnimationFrame = window.cancelAnimationFrame || clearTimeout;

  Completion.prototype = {
    close: function() {
      if (!this.active()) return;
      this.cm.state.completionActive = null;
      this.tick = null;
      if (this.options.updateOnCursorActivity) {
        this.cm.off("cursorActivity", this.activityFunc);
      }

      if (this.widget && this.data) CodeMirror.signal(this.data, "close");
      if (this.widget) this.widget.close();
      CodeMirror.signal(this.cm, "endCompletion", this.cm);
    },

    active: function() {
      return this.cm.state.completionActive == this;
    },

    pick: function(data, i) {
      var completion = data.list[i], self = this;
      this.cm.operation(function() {
        if (completion.hint)
          completion.hint(self.cm, data, completion);
        else
          self.cm.replaceRange(getText(completion), completion.from || data.from,
                               completion.to || data.to, "complete");
        CodeMirror.signal(data, "pick", completion);
        self.cm.scrollIntoView();
      });
      if (this.options.closeOnPick) {
        this.close();
      }
    },

    cursorActivity: function() {
      if (this.debounce) {
        cancelAnimationFrame(this.debounce);
        this.debounce = 0;
      }

      var identStart = this.startPos;
      if(this.data) {
        identStart = this.data.from;
      }

      var pos = this.cm.getCursor(), line = this.cm.getLine(pos.line);
      if (pos.line != this.startPos.line || line.length - pos.ch != this.startLen - this.startPos.ch ||
          pos.ch < identStart.ch || this.cm.somethingSelected() ||
          (!pos.ch || this.options.closeCharacters.test(line.charAt(pos.ch - 1)))) {
        this.close();
      } else {
        var self = this;
        this.debounce = requestAnimationFrame(function() {self.update();});
        if (this.widget) this.widget.disable();
      }
    },

    update: function(first) {
      if (this.tick == null) return
      var self = this, myTick = ++this.tick
      fetchHints(this.options.hint, this.cm, this.options, function(data) {
        if (self.tick == myTick) self.finishUpdate(data, first)
      })
    },

    finishUpdate: function(data, first) {
      if (this.data) CodeMirror.signal(this.data, "update");

      var picked = (this.widget && this.widget.picked) || (first && this.options.completeSingle);
      if (this.widget) this.widget.close();

      this.data = data;

      if (data && data.list.length) {
        if (picked && data.list.length == 1) {
          this.pick(data, 0);
        } else {
          this.widget = new Widget(this, data);
          CodeMirror.signal(data, "shown");
        }
      }
    }
  };

  function parseOptions(cm, pos, options) {
    var editor = cm.options.hintOptions;
    var out = {};
    for (var prop in defaultOptions) out[prop] = defaultOptions[prop];
    if (editor) for (var prop in editor)
      if (editor[prop] !== undefined) out[prop] = editor[prop];
    if (options) for (var prop in options)
      if (options[prop] !== undefined) out[prop] = options[prop];
    if (out.hint.resolve) out.hint = out.hint.resolve(cm, pos)
    return out;
  }

  function getText(completion) {
    if (typeof completion == "string") return completion;
    else return completion.text;
  }

  function buildKeyMap(completion, handle) {
    var baseMap = {
      Up: function() {handle.moveFocus(-1);},
      Down: function() {handle.moveFocus(1);},
      PageUp: function() {handle.moveFocus(-handle.menuSize() + 1, true);},
      PageDown: function() {handle.moveFocus(handle.menuSize() - 1, true);},
      Home: function() {handle.setFocus(0);},
      End: function() {handle.setFocus(handle.length - 1);},
      Enter: handle.pick,
      Tab: handle.pick,
      Esc: handle.close
    };

    var mac = /Mac/.test(navigator.platform);

    if (mac) {
      baseMap["Ctrl-P"] = function() {handle.moveFocus(-1);};
      baseMap["Ctrl-N"] = function() {handle.moveFocus(1);};
    }

    var custom = completion.options.customKeys;
    var ourMap = custom ? {} : baseMap;
    function addBinding(key, val) {
      var bound;
      if (typeof val != "string")
        bound = function(cm) { return val(cm, handle); };
      // This mechanism is deprecated
      else if (baseMap.hasOwnProperty(val))
        bound = baseMap[val];
      else
        bound = val;
      ourMap[key] = bound;
    }
    if (custom)
      for (var key in custom) if (custom.hasOwnProperty(key))
        addBinding(key, custom[key]);
    var extra = completion.options.extraKeys;
    if (extra)
      for (var key in extra) if (extra.hasOwnProperty(key))
        addBinding(key, extra[key]);
    return ourMap;
  }

  function getHintElement(hintsElement, el) {
    while (el && el != hintsElement) {
      if (el.nodeName.toUpperCase() === "LI" && el.parentNode == hintsElement) return el;
      el = el.parentNode;
    }
  }

  function Widget(completion, data) {
    this.id = "cm-complete-" + Math.floor(Math.random(1e6))
    this.completion = completion;
    this.data = data;
    this.picked = false;
    var widget = this, cm = completion.cm;
    var ownerDocument = cm.getInputField().ownerDocument;
    var parentWindow = ownerDocument.defaultView || ownerDocument.parentWindow;

    var hints = this.hints = ownerDocument.createElement("ul");
    hints.setAttribute("role", "listbox")
    hints.setAttribute("aria-expanded", "true")
    hints.id = this.id
    var theme = completion.cm.options.theme;
    hints.className = "CodeMirror-hints " + theme;
    this.selectedHint = data.selectedHint || 0;

    var completions = data.list;
    for (var i = 0; i < completions.length; ++i) {
      var elt = hints.appendChild(ownerDocument.createElement("li")), cur = completions[i];
      var className = HINT_ELEMENT_CLASS + (i != this.selectedHint ? "" : " " + ACTIVE_HINT_ELEMENT_CLASS);
      if (cur.className != null) className = cur.className + " " + className;
      elt.className = className;
      if (i == this.selectedHint) elt.setAttribute("aria-selected", "true")
      elt.id = this.id + "-" + i
      elt.setAttribute("role", "option")
      if (cur.render) cur.render(elt, data, cur);
      else elt.appendChild(ownerDocument.createTextNode(cur.displayText || getText(cur)));
      elt.hintId = i;
    }

    var container = completion.options.container || ownerDocument.body;
    var pos = cm.cursorCoords(completion.options.alignWithWord ? data.from : null);
    var left = pos.left, top = pos.bottom, below = true;
    var offsetLeft = 0, offsetTop = 0;
    if (container !== ownerDocument.body) {
      // We offset the cursor position because left and top are relative to the offsetParent's top left corner.
      var isContainerPositioned = ['absolute', 'relative', 'fixed'].indexOf(parentWindow.getComputedStyle(container).position) !== -1;
      var offsetParent = isContainerPositioned ? container : container.offsetParent;
      var offsetParentPosition = offsetParent.getBoundingClientRect();
      var bodyPosition = ownerDocument.body.getBoundingClientRect();
      offsetLeft = (offsetParentPosition.left - bodyPosition.left - offsetParent.scrollLeft);
      offsetTop = (offsetParentPosition.top - bodyPosition.top - offsetParent.scrollTop);
    }
    hints.style.left = (left - offsetLeft) + "px";
    hints.style.top = (top - offsetTop) + "px";

    // If we're at the edge of the screen, then we want the menu to appear on the left of the cursor.
    var winW = parentWindow.innerWidth || Math.max(ownerDocument.body.offsetWidth, ownerDocument.documentElement.offsetWidth);
    var winH = parentWindow.innerHeight || Math.max(ownerDocument.body.offsetHeight, ownerDocument.documentElement.offsetHeight);
    container.appendChild(hints);
    cm.getInputField().setAttribute("aria-autocomplete", "list")
    cm.getInputField().setAttribute("aria-owns", this.id)
    cm.getInputField().setAttribute("aria-activedescendant", this.id + "-" + this.selectedHint)

    var box = completion.options.moveOnOverlap ? hints.getBoundingClientRect() : new DOMRect();
    var scrolls = completion.options.paddingForScrollbar ? hints.scrollHeight > hints.clientHeight + 1 : false;

    // Compute in the timeout to avoid reflow on init
    var startScroll;
    setTimeout(function() { startScroll = cm.getScrollInfo(); });

    var overlapY = box.bottom - winH;
    if (overlapY > 0) {
      var height = box.bottom - box.top, curTop = pos.top - (pos.bottom - box.top);
      if (curTop - height > 0) { // Fits above cursor
        hints.style.top = (top = pos.top - height - offsetTop) + "px";
        below = false;
      } else if (height > winH) {
        hints.style.height = (winH - 5) + "px";
        hints.style.top = (top = pos.bottom - box.top - offsetTop) + "px";
        var cursor = cm.getCursor();
        if (data.from.ch != cursor.ch) {
          pos = cm.cursorCoords(cursor);
          hints.style.left = (left = pos.left - offsetLeft) + "px";
          box = hints.getBoundingClientRect();
        }
      }
    }
    var overlapX = box.right - winW;
    if (scrolls) overlapX += cm.display.nativeBarWidth;
    if (overlapX > 0) {
      if (box.right - box.left > winW) {
        hints.style.width = (winW - 5) + "px";
        overlapX -= (box.right - box.left) - winW;
      }
      hints.style.left = (left = pos.left - overlapX - offsetLeft) + "px";
    }
    if (scrolls) for (var node = hints.firstChild; node; node = node.nextSibling)
      node.style.paddingRight = cm.display.nativeBarWidth + "px"

    cm.addKeyMap(this.keyMap = buildKeyMap(completion, {
      moveFocus: function(n, avoidWrap) { widget.changeActive(widget.selectedHint + n, avoidWrap); },
      setFocus: function(n) { widget.changeActive(n); },
      menuSize: function() { return widget.screenAmount(); },
      length: completions.length,
      close: function() { completion.close(); },
      pick: function() { widget.pick(); },
      data: data
    }));

    if (completion.options.closeOnUnfocus) {
      var closingOnBlur;
      cm.on("blur", this.onBlur = function() { closingOnBlur = setTimeout(function() { completion.close(); }, 100); });
      cm.on("focus", this.onFocus = function() { clearTimeout(closingOnBlur); });
    }

    cm.on("scroll", this.onScroll = function() {
      var curScroll = cm.getScrollInfo(), editor = cm.getWrapperElement().getBoundingClientRect();
      if (!startScroll) startScroll = cm.getScrollInfo();
      var newTop = top + startScroll.top - curScroll.top;
      var point = newTop - (parentWindow.pageYOffset || (ownerDocument.documentElement || ownerDocument.body).scrollTop);
      if (!below) point += hints.offsetHeight;
      if (point <= editor.top || point >= editor.bottom) return completion.close();
      hints.style.top = newTop + "px";
      hints.style.left = (left + startScroll.left - curScroll.left) + "px";
    });

    CodeMirror.on(hints, "dblclick", function(e) {
      var t = getHintElement(hints, e.target || e.srcElement);
      if (t && t.hintId != null) {widget.changeActive(t.hintId); widget.pick();}
    });

    CodeMirror.on(hints, "click", function(e) {
      var t = getHintElement(hints, e.target || e.srcElement);
      if (t && t.hintId != null) {
        widget.changeActive(t.hintId);
        if (completion.options.completeOnSingleClick) widget.pick();
      }
    });

    CodeMirror.on(hints, "mousedown", function() {
      setTimeout(function(){cm.focus();}, 20);
    });

    // The first hint doesn't need to be scrolled to on init
    var selectedHintRange = this.getSelectedHintRange();
    if (selectedHintRange.from !== 0 || selectedHintRange.to !== 0) {
      this.scrollToActive();
    }

    CodeMirror.signal(data, "select", completions[this.selectedHint], hints.childNodes[this.selectedHint]);
    return true;
  }

  Widget.prototype = {
    close: function() {
      if (this.completion.widget != this) return;
      this.completion.widget = null;
      if (this.hints.parentNode) this.hints.parentNode.removeChild(this.hints);
      this.completion.cm.removeKeyMap(this.keyMap);
      var input = this.completion.cm.getInputField()
      input.removeAttribute("aria-activedescendant")
      input.removeAttribute("aria-owns")

      var cm = this.completion.cm;
      if (this.completion.options.closeOnUnfocus) {
        cm.off("blur", this.onBlur);
        cm.off("focus", this.onFocus);
      }
      cm.off("scroll", this.onScroll);
    },

    disable: function() {
      this.completion.cm.removeKeyMap(this.keyMap);
      var widget = this;
      this.keyMap = {Enter: function() { widget.picked = true; }};
      this.completion.cm.addKeyMap(this.keyMap);
    },

    pick: function() {
      this.completion.pick(this.data, this.selectedHint);
    },

    changeActive: function(i, avoidWrap) {
      if (i >= this.data.list.length)
        i = avoidWrap ? this.data.list.length - 1 : 0;
      else if (i < 0)
        i = avoidWrap ? 0  : this.data.list.length - 1;
      if (this.selectedHint == i) return;
      var node = this.hints.childNodes[this.selectedHint];
      if (node) {
        node.className = node.className.replace(" " + ACTIVE_HINT_ELEMENT_CLASS, "");
        node.removeAttribute("aria-selected")
      }
      node = this.hints.childNodes[this.selectedHint = i];
      node.className += " " + ACTIVE_HINT_ELEMENT_CLASS;
      node.setAttribute("aria-selected", "true")
      this.completion.cm.getInputField().setAttribute("aria-activedescendant", node.id)
      this.scrollToActive()
      CodeMirror.signal(this.data, "select", this.data.list[this.selectedHint], node);
    },

    scrollToActive: function() {
      var selectedHintRange = this.getSelectedHintRange();
      var node1 = this.hints.childNodes[selectedHintRange.from];
      var node2 = this.hints.childNodes[selectedHintRange.to];
      var firstNode = this.hints.firstChild;
      if (node1.offsetTop < this.hints.scrollTop)
        this.hints.scrollTop = node1.offsetTop - firstNode.offsetTop;
      else if (node2.offsetTop + node2.offsetHeight > this.hints.scrollTop + this.hints.clientHeight)
        this.hints.scrollTop = node2.offsetTop + node2.offsetHeight - this.hints.clientHeight + firstNode.offsetTop;
    },

    screenAmount: function() {
      return Math.floor(this.hints.clientHeight / this.hints.firstChild.offsetHeight) || 1;
    },

    getSelectedHintRange: function() {
      var margin = this.completion.options.scrollMargin || 0;
      return {
        from: Math.max(0, this.selectedHint - margin),
        to: Math.min(this.data.list.length - 1, this.selectedHint + margin),
      };
    }
  };

  function applicableHelpers(cm, helpers) {
    if (!cm.somethingSelected()) return helpers
    var result = []
    for (var i = 0; i < helpers.length; i++)
      if (helpers[i].supportsSelection) result.push(helpers[i])
    return result
  }

  function fetchHints(hint, cm, options, callback) {
    if (hint.async) {
      hint(cm, callback, options)
    } else {
      var result = hint(cm, options)
      if (result && result.then) result.then(callback)
      else callback(result)
    }
  }

  function resolveAutoHints(cm, pos) {
    var helpers = cm.getHelpers(pos, "hint"), words
    if (helpers.length) {
      var resolved = function(cm, callback, options) {
        var app = applicableHelpers(cm, helpers);
        function run(i) {
          if (i == app.length) return callback(null)
          fetchHints(app[i], cm, options, function(result) {
            if (result && result.list.length > 0) callback(result)
            else run(i + 1)
          })
        }
        run(0)
      }
      resolved.async = true
      resolved.supportsSelection = true
      return resolved
    } else if (words = cm.getHelper(cm.getCursor(), "hintWords")) {
      return function(cm) { return CodeMirror.hint.fromList(cm, {words: words}) }
    } else if (CodeMirror.hint.anyword) {
      return function(cm, options) { return CodeMirror.hint.anyword(cm, options) }
    } else {
      return function() {}
    }
  }

  CodeMirror.registerHelper("hint", "auto", {
    resolve: resolveAutoHints
  });

  CodeMirror.registerHelper("hint", "fromList", function(cm, options) {
    var cur = cm.getCursor(), token = cm.getTokenAt(cur)
    var term, from = CodeMirror.Pos(cur.line, token.start), to = cur
    if (token.start < cur.ch && /\w/.test(token.string.charAt(cur.ch - token.start - 1))) {
      term = token.string.substr(0, cur.ch - token.start)
    } else {
      term = ""
      from = cur
    }
    var found = [];
    for (var i = 0; i < options.words.length; i++) {
      var word = options.words[i];
      if (word.slice(0, term.length) == term)
        found.push(word);
    }

    if (found.length) return {list: found, from: from, to: to};
  });

  CodeMirror.commands.autocomplete = CodeMirror.showHint;

  var defaultOptions = {
    hint: CodeMirror.hint.auto,
    completeSingle: true,
    alignWithWord: true,
    closeCharacters: /[\s()\[\]{};:>,]/,
    closeOnPick: true,
    closeOnUnfocus: true,
    updateOnCursorActivity: true,
    completeOnSingleClick: true,
    container: null,
    customKeys: null,
    extraKeys: null,
    paddingForScrollbar: true,
    moveOnOverlap: true,
  };

  CodeMirror.defineOption("hintOptions", null);
});


/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/codemirror/addon/hint/sql-hint.js":
/*!***************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/codemirror/addon/hint/sql-hint.js ***!
  \***************************************************************************************/
/***/ ((__unused_webpack_module, __unused_webpack_exports, __webpack_require__) => {

// CodeMirror, copyright (c) by Marijn Haverbeke and others
// Distributed under an MIT license: https://codemirror.net/LICENSE

(function(mod) {
  if (true) // CommonJS
    mod(__webpack_require__(/*! ../../lib/codemirror */ "../../node_modules/@elyra/canvas/node_modules/codemirror/lib/codemirror.js"), __webpack_require__(/*! ../../mode/sql/sql */ "../../node_modules/@elyra/canvas/node_modules/codemirror/mode/sql/sql.js"));
  else {}
})(function(CodeMirror) {
  "use strict";

  var tables;
  var defaultTable;
  var keywords;
  var identifierQuote;
  var CONS = {
    QUERY_DIV: ";",
    ALIAS_KEYWORD: "AS"
  };
  var Pos = CodeMirror.Pos, cmpPos = CodeMirror.cmpPos;

  function isArray(val) { return Object.prototype.toString.call(val) == "[object Array]" }

  function getKeywords(editor) {
    var mode = editor.doc.modeOption;
    if (mode === "sql") mode = "text/x-sql";
    return CodeMirror.resolveMode(mode).keywords;
  }

  function getIdentifierQuote(editor) {
    var mode = editor.doc.modeOption;
    if (mode === "sql") mode = "text/x-sql";
    return CodeMirror.resolveMode(mode).identifierQuote || "`";
  }

  function getText(item) {
    return typeof item == "string" ? item : item.text;
  }

  function wrapTable(name, value) {
    if (isArray(value)) value = {columns: value}
    if (!value.text) value.text = name
    return value
  }

  function parseTables(input) {
    var result = {}
    if (isArray(input)) {
      for (var i = input.length - 1; i >= 0; i--) {
        var item = input[i]
        result[getText(item).toUpperCase()] = wrapTable(getText(item), item)
      }
    } else if (input) {
      for (var name in input)
        result[name.toUpperCase()] = wrapTable(name, input[name])
    }
    return result
  }

  function getTable(name) {
    return tables[name.toUpperCase()]
  }

  function shallowClone(object) {
    var result = {};
    for (var key in object) if (object.hasOwnProperty(key))
      result[key] = object[key];
    return result;
  }

  function match(string, word) {
    var len = string.length;
    var sub = getText(word).substr(0, len);
    return string.toUpperCase() === sub.toUpperCase();
  }

  function addMatches(result, search, wordlist, formatter) {
    if (isArray(wordlist)) {
      for (var i = 0; i < wordlist.length; i++)
        if (match(search, wordlist[i])) result.push(formatter(wordlist[i]))
    } else {
      for (var word in wordlist) if (wordlist.hasOwnProperty(word)) {
        var val = wordlist[word]
        if (!val || val === true)
          val = word
        else
          val = val.displayText ? {text: val.text, displayText: val.displayText} : val.text
        if (match(search, val)) result.push(formatter(val))
      }
    }
  }

  function cleanName(name) {
    // Get rid name from identifierQuote and preceding dot(.)
    if (name.charAt(0) == ".") {
      name = name.substr(1);
    }
    // replace duplicated identifierQuotes with single identifierQuotes
    // and remove single identifierQuotes
    var nameParts = name.split(identifierQuote+identifierQuote);
    for (var i = 0; i < nameParts.length; i++)
      nameParts[i] = nameParts[i].replace(new RegExp(identifierQuote,"g"), "");
    return nameParts.join(identifierQuote);
  }

  function insertIdentifierQuotes(name) {
    var nameParts = getText(name).split(".");
    for (var i = 0; i < nameParts.length; i++)
      nameParts[i] = identifierQuote +
        // duplicate identifierQuotes
        nameParts[i].replace(new RegExp(identifierQuote,"g"), identifierQuote+identifierQuote) +
        identifierQuote;
    var escaped = nameParts.join(".");
    if (typeof name == "string") return escaped;
    name = shallowClone(name);
    name.text = escaped;
    return name;
  }

  function nameCompletion(cur, token, result, editor) {
    // Try to complete table, column names and return start position of completion
    var useIdentifierQuotes = false;
    var nameParts = [];
    var start = token.start;
    var cont = true;
    while (cont) {
      cont = (token.string.charAt(0) == ".");
      useIdentifierQuotes = useIdentifierQuotes || (token.string.charAt(0) == identifierQuote);

      start = token.start;
      nameParts.unshift(cleanName(token.string));

      token = editor.getTokenAt(Pos(cur.line, token.start));
      if (token.string == ".") {
        cont = true;
        token = editor.getTokenAt(Pos(cur.line, token.start));
      }
    }

    // Try to complete table names
    var string = nameParts.join(".");
    addMatches(result, string, tables, function(w) {
      return useIdentifierQuotes ? insertIdentifierQuotes(w) : w;
    });

    // Try to complete columns from defaultTable
    addMatches(result, string, defaultTable, function(w) {
      return useIdentifierQuotes ? insertIdentifierQuotes(w) : w;
    });

    // Try to complete columns
    string = nameParts.pop();
    var table = nameParts.join(".");

    var alias = false;
    var aliasTable = table;
    // Check if table is available. If not, find table by Alias
    if (!getTable(table)) {
      var oldTable = table;
      table = findTableByAlias(table, editor);
      if (table !== oldTable) alias = true;
    }

    var columns = getTable(table);
    if (columns && columns.columns)
      columns = columns.columns;

    if (columns) {
      addMatches(result, string, columns, function(w) {
        var tableInsert = table;
        if (alias == true) tableInsert = aliasTable;
        if (typeof w == "string") {
          w = tableInsert + "." + w;
        } else {
          w = shallowClone(w);
          w.text = tableInsert + "." + w.text;
        }
        return useIdentifierQuotes ? insertIdentifierQuotes(w) : w;
      });
    }

    return start;
  }

  function eachWord(lineText, f) {
    var words = lineText.split(/\s+/)
    for (var i = 0; i < words.length; i++)
      if (words[i]) f(words[i].replace(/[`,;]/g, ''))
  }

  function findTableByAlias(alias, editor) {
    var doc = editor.doc;
    var fullQuery = doc.getValue();
    var aliasUpperCase = alias.toUpperCase();
    var previousWord = "";
    var table = "";
    var separator = [];
    var validRange = {
      start: Pos(0, 0),
      end: Pos(editor.lastLine(), editor.getLineHandle(editor.lastLine()).length)
    };

    //add separator
    var indexOfSeparator = fullQuery.indexOf(CONS.QUERY_DIV);
    while(indexOfSeparator != -1) {
      separator.push(doc.posFromIndex(indexOfSeparator));
      indexOfSeparator = fullQuery.indexOf(CONS.QUERY_DIV, indexOfSeparator+1);
    }
    separator.unshift(Pos(0, 0));
    separator.push(Pos(editor.lastLine(), editor.getLineHandle(editor.lastLine()).text.length));

    //find valid range
    var prevItem = null;
    var current = editor.getCursor()
    for (var i = 0; i < separator.length; i++) {
      if ((prevItem == null || cmpPos(current, prevItem) > 0) && cmpPos(current, separator[i]) <= 0) {
        validRange = {start: prevItem, end: separator[i]};
        break;
      }
      prevItem = separator[i];
    }

    if (validRange.start) {
      var query = doc.getRange(validRange.start, validRange.end, false);

      for (var i = 0; i < query.length; i++) {
        var lineText = query[i];
        eachWord(lineText, function(word) {
          var wordUpperCase = word.toUpperCase();
          if (wordUpperCase === aliasUpperCase && getTable(previousWord))
            table = previousWord;
          if (wordUpperCase !== CONS.ALIAS_KEYWORD)
            previousWord = word;
        });
        if (table) break;
      }
    }
    return table;
  }

  CodeMirror.registerHelper("hint", "sql", function(editor, options) {
    tables = parseTables(options && options.tables)
    var defaultTableName = options && options.defaultTable;
    var disableKeywords = options && options.disableKeywords;
    defaultTable = defaultTableName && getTable(defaultTableName);
    keywords = getKeywords(editor);
    identifierQuote = getIdentifierQuote(editor);

    if (defaultTableName && !defaultTable)
      defaultTable = findTableByAlias(defaultTableName, editor);

    defaultTable = defaultTable || [];

    if (defaultTable.columns)
      defaultTable = defaultTable.columns;

    var cur = editor.getCursor();
    var result = [];
    var token = editor.getTokenAt(cur), start, end, search;
    if (token.end > cur.ch) {
      token.end = cur.ch;
      token.string = token.string.slice(0, cur.ch - token.start);
    }

    if (token.string.match(/^[.`"'\w@][\w$#]*$/g)) {
      search = token.string;
      start = token.start;
      end = token.end;
    } else {
      start = end = cur.ch;
      search = "";
    }
    if (search.charAt(0) == "." || search.charAt(0) == identifierQuote) {
      start = nameCompletion(cur, token, result, editor);
    } else {
      var objectOrClass = function(w, className) {
        if (typeof w === "object") {
          w.className = className;
        } else {
          w = { text: w, className: className };
        }
        return w;
      };
    addMatches(result, search, defaultTable, function(w) {
        return objectOrClass(w, "CodeMirror-hint-table CodeMirror-hint-default-table");
    });
    addMatches(
        result,
        search,
        tables, function(w) {
          return objectOrClass(w, "CodeMirror-hint-table");
        }
    );
    if (!disableKeywords)
      addMatches(result, search, keywords, function(w) {
          return objectOrClass(w.toUpperCase(), "CodeMirror-hint-keyword");
      });
  }

    return {list: result, from: Pos(cur.line, start), to: Pos(cur.line, end)};
  });
});


/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/codemirror/lib/codemirror.js":
/*!**********************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/codemirror/lib/codemirror.js ***!
  \**********************************************************************************/
/***/ (function(module) {

// CodeMirror, copyright (c) by Marijn Haverbeke and others
// Distributed under an MIT license: https://codemirror.net/LICENSE

// This is CodeMirror (https://codemirror.net), a code editor
// implemented in JavaScript on top of the browser's DOM.
//
// You can find some technical background for some of the code below
// at http://marijnhaverbeke.nl/blog/#cm-internals .

(function (global, factory) {
   true ? module.exports = factory() :
  0;
}(this, (function () { 'use strict';

  // Kludges for bugs and behavior differences that can't be feature
  // detected are enabled based on userAgent etc sniffing.
  var userAgent = navigator.userAgent;
  var platform = navigator.platform;

  var gecko = /gecko\/\d/i.test(userAgent);
  var ie_upto10 = /MSIE \d/.test(userAgent);
  var ie_11up = /Trident\/(?:[7-9]|\d{2,})\..*rv:(\d+)/.exec(userAgent);
  var edge = /Edge\/(\d+)/.exec(userAgent);
  var ie = ie_upto10 || ie_11up || edge;
  var ie_version = ie && (ie_upto10 ? document.documentMode || 6 : +(edge || ie_11up)[1]);
  var webkit = !edge && /WebKit\//.test(userAgent);
  var qtwebkit = webkit && /Qt\/\d+\.\d+/.test(userAgent);
  var chrome = !edge && /Chrome\//.test(userAgent);
  var presto = /Opera\//.test(userAgent);
  var safari = /Apple Computer/.test(navigator.vendor);
  var mac_geMountainLion = /Mac OS X 1\d\D([8-9]|\d\d)\D/.test(userAgent);
  var phantom = /PhantomJS/.test(userAgent);

  var ios = safari && (/Mobile\/\w+/.test(userAgent) || navigator.maxTouchPoints > 2);
  var android = /Android/.test(userAgent);
  // This is woefully incomplete. Suggestions for alternative methods welcome.
  var mobile = ios || android || /webOS|BlackBerry|Opera Mini|Opera Mobi|IEMobile/i.test(userAgent);
  var mac = ios || /Mac/.test(platform);
  var chromeOS = /\bCrOS\b/.test(userAgent);
  var windows = /win/i.test(platform);

  var presto_version = presto && userAgent.match(/Version\/(\d*\.\d*)/);
  if (presto_version) { presto_version = Number(presto_version[1]); }
  if (presto_version && presto_version >= 15) { presto = false; webkit = true; }
  // Some browsers use the wrong event properties to signal cmd/ctrl on OS X
  var flipCtrlCmd = mac && (qtwebkit || presto && (presto_version == null || presto_version < 12.11));
  var captureRightClick = gecko || (ie && ie_version >= 9);

  function classTest(cls) { return new RegExp("(^|\\s)" + cls + "(?:$|\\s)\\s*") }

  var rmClass = function(node, cls) {
    var current = node.className;
    var match = classTest(cls).exec(current);
    if (match) {
      var after = current.slice(match.index + match[0].length);
      node.className = current.slice(0, match.index) + (after ? match[1] + after : "");
    }
  };

  function removeChildren(e) {
    for (var count = e.childNodes.length; count > 0; --count)
      { e.removeChild(e.firstChild); }
    return e
  }

  function removeChildrenAndAdd(parent, e) {
    return removeChildren(parent).appendChild(e)
  }

  function elt(tag, content, className, style) {
    var e = document.createElement(tag);
    if (className) { e.className = className; }
    if (style) { e.style.cssText = style; }
    if (typeof content == "string") { e.appendChild(document.createTextNode(content)); }
    else if (content) { for (var i = 0; i < content.length; ++i) { e.appendChild(content[i]); } }
    return e
  }
  // wrapper for elt, which removes the elt from the accessibility tree
  function eltP(tag, content, className, style) {
    var e = elt(tag, content, className, style);
    e.setAttribute("role", "presentation");
    return e
  }

  var range;
  if (document.createRange) { range = function(node, start, end, endNode) {
    var r = document.createRange();
    r.setEnd(endNode || node, end);
    r.setStart(node, start);
    return r
  }; }
  else { range = function(node, start, end) {
    var r = document.body.createTextRange();
    try { r.moveToElementText(node.parentNode); }
    catch(e) { return r }
    r.collapse(true);
    r.moveEnd("character", end);
    r.moveStart("character", start);
    return r
  }; }

  function contains(parent, child) {
    if (child.nodeType == 3) // Android browser always returns false when child is a textnode
      { child = child.parentNode; }
    if (parent.contains)
      { return parent.contains(child) }
    do {
      if (child.nodeType == 11) { child = child.host; }
      if (child == parent) { return true }
    } while (child = child.parentNode)
  }

  function activeElt() {
    // IE and Edge may throw an "Unspecified Error" when accessing document.activeElement.
    // IE < 10 will throw when accessed while the page is loading or in an iframe.
    // IE > 9 and Edge will throw when accessed in an iframe if document.body is unavailable.
    var activeElement;
    try {
      activeElement = document.activeElement;
    } catch(e) {
      activeElement = document.body || null;
    }
    while (activeElement && activeElement.shadowRoot && activeElement.shadowRoot.activeElement)
      { activeElement = activeElement.shadowRoot.activeElement; }
    return activeElement
  }

  function addClass(node, cls) {
    var current = node.className;
    if (!classTest(cls).test(current)) { node.className += (current ? " " : "") + cls; }
  }
  function joinClasses(a, b) {
    var as = a.split(" ");
    for (var i = 0; i < as.length; i++)
      { if (as[i] && !classTest(as[i]).test(b)) { b += " " + as[i]; } }
    return b
  }

  var selectInput = function(node) { node.select(); };
  if (ios) // Mobile Safari apparently has a bug where select() is broken.
    { selectInput = function(node) { node.selectionStart = 0; node.selectionEnd = node.value.length; }; }
  else if (ie) // Suppress mysterious IE10 errors
    { selectInput = function(node) { try { node.select(); } catch(_e) {} }; }

  function bind(f) {
    var args = Array.prototype.slice.call(arguments, 1);
    return function(){return f.apply(null, args)}
  }

  function copyObj(obj, target, overwrite) {
    if (!target) { target = {}; }
    for (var prop in obj)
      { if (obj.hasOwnProperty(prop) && (overwrite !== false || !target.hasOwnProperty(prop)))
        { target[prop] = obj[prop]; } }
    return target
  }

  // Counts the column offset in a string, taking tabs into account.
  // Used mostly to find indentation.
  function countColumn(string, end, tabSize, startIndex, startValue) {
    if (end == null) {
      end = string.search(/[^\s\u00a0]/);
      if (end == -1) { end = string.length; }
    }
    for (var i = startIndex || 0, n = startValue || 0;;) {
      var nextTab = string.indexOf("\t", i);
      if (nextTab < 0 || nextTab >= end)
        { return n + (end - i) }
      n += nextTab - i;
      n += tabSize - (n % tabSize);
      i = nextTab + 1;
    }
  }

  var Delayed = function() {
    this.id = null;
    this.f = null;
    this.time = 0;
    this.handler = bind(this.onTimeout, this);
  };
  Delayed.prototype.onTimeout = function (self) {
    self.id = 0;
    if (self.time <= +new Date) {
      self.f();
    } else {
      setTimeout(self.handler, self.time - +new Date);
    }
  };
  Delayed.prototype.set = function (ms, f) {
    this.f = f;
    var time = +new Date + ms;
    if (!this.id || time < this.time) {
      clearTimeout(this.id);
      this.id = setTimeout(this.handler, ms);
      this.time = time;
    }
  };

  function indexOf(array, elt) {
    for (var i = 0; i < array.length; ++i)
      { if (array[i] == elt) { return i } }
    return -1
  }

  // Number of pixels added to scroller and sizer to hide scrollbar
  var scrollerGap = 50;

  // Returned or thrown by various protocols to signal 'I'm not
  // handling this'.
  var Pass = {toString: function(){return "CodeMirror.Pass"}};

  // Reused option objects for setSelection & friends
  var sel_dontScroll = {scroll: false}, sel_mouse = {origin: "*mouse"}, sel_move = {origin: "+move"};

  // The inverse of countColumn -- find the offset that corresponds to
  // a particular column.
  function findColumn(string, goal, tabSize) {
    for (var pos = 0, col = 0;;) {
      var nextTab = string.indexOf("\t", pos);
      if (nextTab == -1) { nextTab = string.length; }
      var skipped = nextTab - pos;
      if (nextTab == string.length || col + skipped >= goal)
        { return pos + Math.min(skipped, goal - col) }
      col += nextTab - pos;
      col += tabSize - (col % tabSize);
      pos = nextTab + 1;
      if (col >= goal) { return pos }
    }
  }

  var spaceStrs = [""];
  function spaceStr(n) {
    while (spaceStrs.length <= n)
      { spaceStrs.push(lst(spaceStrs) + " "); }
    return spaceStrs[n]
  }

  function lst(arr) { return arr[arr.length-1] }

  function map(array, f) {
    var out = [];
    for (var i = 0; i < array.length; i++) { out[i] = f(array[i], i); }
    return out
  }

  function insertSorted(array, value, score) {
    var pos = 0, priority = score(value);
    while (pos < array.length && score(array[pos]) <= priority) { pos++; }
    array.splice(pos, 0, value);
  }

  function nothing() {}

  function createObj(base, props) {
    var inst;
    if (Object.create) {
      inst = Object.create(base);
    } else {
      nothing.prototype = base;
      inst = new nothing();
    }
    if (props) { copyObj(props, inst); }
    return inst
  }

  var nonASCIISingleCaseWordChar = /[\u00df\u0587\u0590-\u05f4\u0600-\u06ff\u3040-\u309f\u30a0-\u30ff\u3400-\u4db5\u4e00-\u9fcc\uac00-\ud7af]/;
  function isWordCharBasic(ch) {
    return /\w/.test(ch) || ch > "\x80" &&
      (ch.toUpperCase() != ch.toLowerCase() || nonASCIISingleCaseWordChar.test(ch))
  }
  function isWordChar(ch, helper) {
    if (!helper) { return isWordCharBasic(ch) }
    if (helper.source.indexOf("\\w") > -1 && isWordCharBasic(ch)) { return true }
    return helper.test(ch)
  }

  function isEmpty(obj) {
    for (var n in obj) { if (obj.hasOwnProperty(n) && obj[n]) { return false } }
    return true
  }

  // Extending unicode characters. A series of a non-extending char +
  // any number of extending chars is treated as a single unit as far
  // as editing and measuring is concerned. This is not fully correct,
  // since some scripts/fonts/browsers also treat other configurations
  // of code points as a group.
  var extendingChars = /[\u0300-\u036f\u0483-\u0489\u0591-\u05bd\u05bf\u05c1\u05c2\u05c4\u05c5\u05c7\u0610-\u061a\u064b-\u065e\u0670\u06d6-\u06dc\u06de-\u06e4\u06e7\u06e8\u06ea-\u06ed\u0711\u0730-\u074a\u07a6-\u07b0\u07eb-\u07f3\u0816-\u0819\u081b-\u0823\u0825-\u0827\u0829-\u082d\u0900-\u0902\u093c\u0941-\u0948\u094d\u0951-\u0955\u0962\u0963\u0981\u09bc\u09be\u09c1-\u09c4\u09cd\u09d7\u09e2\u09e3\u0a01\u0a02\u0a3c\u0a41\u0a42\u0a47\u0a48\u0a4b-\u0a4d\u0a51\u0a70\u0a71\u0a75\u0a81\u0a82\u0abc\u0ac1-\u0ac5\u0ac7\u0ac8\u0acd\u0ae2\u0ae3\u0b01\u0b3c\u0b3e\u0b3f\u0b41-\u0b44\u0b4d\u0b56\u0b57\u0b62\u0b63\u0b82\u0bbe\u0bc0\u0bcd\u0bd7\u0c3e-\u0c40\u0c46-\u0c48\u0c4a-\u0c4d\u0c55\u0c56\u0c62\u0c63\u0cbc\u0cbf\u0cc2\u0cc6\u0ccc\u0ccd\u0cd5\u0cd6\u0ce2\u0ce3\u0d3e\u0d41-\u0d44\u0d4d\u0d57\u0d62\u0d63\u0dca\u0dcf\u0dd2-\u0dd4\u0dd6\u0ddf\u0e31\u0e34-\u0e3a\u0e47-\u0e4e\u0eb1\u0eb4-\u0eb9\u0ebb\u0ebc\u0ec8-\u0ecd\u0f18\u0f19\u0f35\u0f37\u0f39\u0f71-\u0f7e\u0f80-\u0f84\u0f86\u0f87\u0f90-\u0f97\u0f99-\u0fbc\u0fc6\u102d-\u1030\u1032-\u1037\u1039\u103a\u103d\u103e\u1058\u1059\u105e-\u1060\u1071-\u1074\u1082\u1085\u1086\u108d\u109d\u135f\u1712-\u1714\u1732-\u1734\u1752\u1753\u1772\u1773\u17b7-\u17bd\u17c6\u17c9-\u17d3\u17dd\u180b-\u180d\u18a9\u1920-\u1922\u1927\u1928\u1932\u1939-\u193b\u1a17\u1a18\u1a56\u1a58-\u1a5e\u1a60\u1a62\u1a65-\u1a6c\u1a73-\u1a7c\u1a7f\u1b00-\u1b03\u1b34\u1b36-\u1b3a\u1b3c\u1b42\u1b6b-\u1b73\u1b80\u1b81\u1ba2-\u1ba5\u1ba8\u1ba9\u1c2c-\u1c33\u1c36\u1c37\u1cd0-\u1cd2\u1cd4-\u1ce0\u1ce2-\u1ce8\u1ced\u1dc0-\u1de6\u1dfd-\u1dff\u200c\u200d\u20d0-\u20f0\u2cef-\u2cf1\u2de0-\u2dff\u302a-\u302f\u3099\u309a\ua66f-\ua672\ua67c\ua67d\ua6f0\ua6f1\ua802\ua806\ua80b\ua825\ua826\ua8c4\ua8e0-\ua8f1\ua926-\ua92d\ua947-\ua951\ua980-\ua982\ua9b3\ua9b6-\ua9b9\ua9bc\uaa29-\uaa2e\uaa31\uaa32\uaa35\uaa36\uaa43\uaa4c\uaab0\uaab2-\uaab4\uaab7\uaab8\uaabe\uaabf\uaac1\uabe5\uabe8\uabed\udc00-\udfff\ufb1e\ufe00-\ufe0f\ufe20-\ufe26\uff9e\uff9f]/;
  function isExtendingChar(ch) { return ch.charCodeAt(0) >= 768 && extendingChars.test(ch) }

  // Returns a number from the range [`0`; `str.length`] unless `pos` is outside that range.
  function skipExtendingChars(str, pos, dir) {
    while ((dir < 0 ? pos > 0 : pos < str.length) && isExtendingChar(str.charAt(pos))) { pos += dir; }
    return pos
  }

  // Returns the value from the range [`from`; `to`] that satisfies
  // `pred` and is closest to `from`. Assumes that at least `to`
  // satisfies `pred`. Supports `from` being greater than `to`.
  function findFirst(pred, from, to) {
    // At any point we are certain `to` satisfies `pred`, don't know
    // whether `from` does.
    var dir = from > to ? -1 : 1;
    for (;;) {
      if (from == to) { return from }
      var midF = (from + to) / 2, mid = dir < 0 ? Math.ceil(midF) : Math.floor(midF);
      if (mid == from) { return pred(mid) ? from : to }
      if (pred(mid)) { to = mid; }
      else { from = mid + dir; }
    }
  }

  // BIDI HELPERS

  function iterateBidiSections(order, from, to, f) {
    if (!order) { return f(from, to, "ltr", 0) }
    var found = false;
    for (var i = 0; i < order.length; ++i) {
      var part = order[i];
      if (part.from < to && part.to > from || from == to && part.to == from) {
        f(Math.max(part.from, from), Math.min(part.to, to), part.level == 1 ? "rtl" : "ltr", i);
        found = true;
      }
    }
    if (!found) { f(from, to, "ltr"); }
  }

  var bidiOther = null;
  function getBidiPartAt(order, ch, sticky) {
    var found;
    bidiOther = null;
    for (var i = 0; i < order.length; ++i) {
      var cur = order[i];
      if (cur.from < ch && cur.to > ch) { return i }
      if (cur.to == ch) {
        if (cur.from != cur.to && sticky == "before") { found = i; }
        else { bidiOther = i; }
      }
      if (cur.from == ch) {
        if (cur.from != cur.to && sticky != "before") { found = i; }
        else { bidiOther = i; }
      }
    }
    return found != null ? found : bidiOther
  }

  // Bidirectional ordering algorithm
  // See http://unicode.org/reports/tr9/tr9-13.html for the algorithm
  // that this (partially) implements.

  // One-char codes used for character types:
  // L (L):   Left-to-Right
  // R (R):   Right-to-Left
  // r (AL):  Right-to-Left Arabic
  // 1 (EN):  European Number
  // + (ES):  European Number Separator
  // % (ET):  European Number Terminator
  // n (AN):  Arabic Number
  // , (CS):  Common Number Separator
  // m (NSM): Non-Spacing Mark
  // b (BN):  Boundary Neutral
  // s (B):   Paragraph Separator
  // t (S):   Segment Separator
  // w (WS):  Whitespace
  // N (ON):  Other Neutrals

  // Returns null if characters are ordered as they appear
  // (left-to-right), or an array of sections ({from, to, level}
  // objects) in the order in which they occur visually.
  var bidiOrdering = (function() {
    // Character types for codepoints 0 to 0xff
    var lowTypes = "bbbbbbbbbtstwsbbbbbbbbbbbbbbssstwNN%%%NNNNNN,N,N1111111111NNNNNNNLLLLLLLLLLLLLLLLLLLLLLLLLLNNNNNNLLLLLLLLLLLLLLLLLLLLLLLLLLNNNNbbbbbbsbbbbbbbbbbbbbbbbbbbbbbbbbb,N%%%%NNNNLNNNNN%%11NLNNN1LNNNNNLLLLLLLLLLLLLLLLLLLLLLLNLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLN";
    // Character types for codepoints 0x600 to 0x6f9
    var arabicTypes = "nnnnnnNNr%%r,rNNmmmmmmmmmmmrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrmmmmmmmmmmmmmmmmmmmmmnnnnnnnnnn%nnrrrmrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrmmmmmmmnNmmmmmmrrmmNmmmmrr1111111111";
    function charType(code) {
      if (code <= 0xf7) { return lowTypes.charAt(code) }
      else if (0x590 <= code && code <= 0x5f4) { return "R" }
      else if (0x600 <= code && code <= 0x6f9) { return arabicTypes.charAt(code - 0x600) }
      else if (0x6ee <= code && code <= 0x8ac) { return "r" }
      else if (0x2000 <= code && code <= 0x200b) { return "w" }
      else if (code == 0x200c) { return "b" }
      else { return "L" }
    }

    var bidiRE = /[\u0590-\u05f4\u0600-\u06ff\u0700-\u08ac]/;
    var isNeutral = /[stwN]/, isStrong = /[LRr]/, countsAsLeft = /[Lb1n]/, countsAsNum = /[1n]/;

    function BidiSpan(level, from, to) {
      this.level = level;
      this.from = from; this.to = to;
    }

    return function(str, direction) {
      var outerType = direction == "ltr" ? "L" : "R";

      if (str.length == 0 || direction == "ltr" && !bidiRE.test(str)) { return false }
      var len = str.length, types = [];
      for (var i = 0; i < len; ++i)
        { types.push(charType(str.charCodeAt(i))); }

      // W1. Examine each non-spacing mark (NSM) in the level run, and
      // change the type of the NSM to the type of the previous
      // character. If the NSM is at the start of the level run, it will
      // get the type of sor.
      for (var i$1 = 0, prev = outerType; i$1 < len; ++i$1) {
        var type = types[i$1];
        if (type == "m") { types[i$1] = prev; }
        else { prev = type; }
      }

      // W2. Search backwards from each instance of a European number
      // until the first strong type (R, L, AL, or sor) is found. If an
      // AL is found, change the type of the European number to Arabic
      // number.
      // W3. Change all ALs to R.
      for (var i$2 = 0, cur = outerType; i$2 < len; ++i$2) {
        var type$1 = types[i$2];
        if (type$1 == "1" && cur == "r") { types[i$2] = "n"; }
        else if (isStrong.test(type$1)) { cur = type$1; if (type$1 == "r") { types[i$2] = "R"; } }
      }

      // W4. A single European separator between two European numbers
      // changes to a European number. A single common separator between
      // two numbers of the same type changes to that type.
      for (var i$3 = 1, prev$1 = types[0]; i$3 < len - 1; ++i$3) {
        var type$2 = types[i$3];
        if (type$2 == "+" && prev$1 == "1" && types[i$3+1] == "1") { types[i$3] = "1"; }
        else if (type$2 == "," && prev$1 == types[i$3+1] &&
                 (prev$1 == "1" || prev$1 == "n")) { types[i$3] = prev$1; }
        prev$1 = type$2;
      }

      // W5. A sequence of European terminators adjacent to European
      // numbers changes to all European numbers.
      // W6. Otherwise, separators and terminators change to Other
      // Neutral.
      for (var i$4 = 0; i$4 < len; ++i$4) {
        var type$3 = types[i$4];
        if (type$3 == ",") { types[i$4] = "N"; }
        else if (type$3 == "%") {
          var end = (void 0);
          for (end = i$4 + 1; end < len && types[end] == "%"; ++end) {}
          var replace = (i$4 && types[i$4-1] == "!") || (end < len && types[end] == "1") ? "1" : "N";
          for (var j = i$4; j < end; ++j) { types[j] = replace; }
          i$4 = end - 1;
        }
      }

      // W7. Search backwards from each instance of a European number
      // until the first strong type (R, L, or sor) is found. If an L is
      // found, then change the type of the European number to L.
      for (var i$5 = 0, cur$1 = outerType; i$5 < len; ++i$5) {
        var type$4 = types[i$5];
        if (cur$1 == "L" && type$4 == "1") { types[i$5] = "L"; }
        else if (isStrong.test(type$4)) { cur$1 = type$4; }
      }

      // N1. A sequence of neutrals takes the direction of the
      // surrounding strong text if the text on both sides has the same
      // direction. European and Arabic numbers act as if they were R in
      // terms of their influence on neutrals. Start-of-level-run (sor)
      // and end-of-level-run (eor) are used at level run boundaries.
      // N2. Any remaining neutrals take the embedding direction.
      for (var i$6 = 0; i$6 < len; ++i$6) {
        if (isNeutral.test(types[i$6])) {
          var end$1 = (void 0);
          for (end$1 = i$6 + 1; end$1 < len && isNeutral.test(types[end$1]); ++end$1) {}
          var before = (i$6 ? types[i$6-1] : outerType) == "L";
          var after = (end$1 < len ? types[end$1] : outerType) == "L";
          var replace$1 = before == after ? (before ? "L" : "R") : outerType;
          for (var j$1 = i$6; j$1 < end$1; ++j$1) { types[j$1] = replace$1; }
          i$6 = end$1 - 1;
        }
      }

      // Here we depart from the documented algorithm, in order to avoid
      // building up an actual levels array. Since there are only three
      // levels (0, 1, 2) in an implementation that doesn't take
      // explicit embedding into account, we can build up the order on
      // the fly, without following the level-based algorithm.
      var order = [], m;
      for (var i$7 = 0; i$7 < len;) {
        if (countsAsLeft.test(types[i$7])) {
          var start = i$7;
          for (++i$7; i$7 < len && countsAsLeft.test(types[i$7]); ++i$7) {}
          order.push(new BidiSpan(0, start, i$7));
        } else {
          var pos = i$7, at = order.length, isRTL = direction == "rtl" ? 1 : 0;
          for (++i$7; i$7 < len && types[i$7] != "L"; ++i$7) {}
          for (var j$2 = pos; j$2 < i$7;) {
            if (countsAsNum.test(types[j$2])) {
              if (pos < j$2) { order.splice(at, 0, new BidiSpan(1, pos, j$2)); at += isRTL; }
              var nstart = j$2;
              for (++j$2; j$2 < i$7 && countsAsNum.test(types[j$2]); ++j$2) {}
              order.splice(at, 0, new BidiSpan(2, nstart, j$2));
              at += isRTL;
              pos = j$2;
            } else { ++j$2; }
          }
          if (pos < i$7) { order.splice(at, 0, new BidiSpan(1, pos, i$7)); }
        }
      }
      if (direction == "ltr") {
        if (order[0].level == 1 && (m = str.match(/^\s+/))) {
          order[0].from = m[0].length;
          order.unshift(new BidiSpan(0, 0, m[0].length));
        }
        if (lst(order).level == 1 && (m = str.match(/\s+$/))) {
          lst(order).to -= m[0].length;
          order.push(new BidiSpan(0, len - m[0].length, len));
        }
      }

      return direction == "rtl" ? order.reverse() : order
    }
  })();

  // Get the bidi ordering for the given line (and cache it). Returns
  // false for lines that are fully left-to-right, and an array of
  // BidiSpan objects otherwise.
  function getOrder(line, direction) {
    var order = line.order;
    if (order == null) { order = line.order = bidiOrdering(line.text, direction); }
    return order
  }

  // EVENT HANDLING

  // Lightweight event framework. on/off also work on DOM nodes,
  // registering native DOM handlers.

  var noHandlers = [];

  var on = function(emitter, type, f) {
    if (emitter.addEventListener) {
      emitter.addEventListener(type, f, false);
    } else if (emitter.attachEvent) {
      emitter.attachEvent("on" + type, f);
    } else {
      var map = emitter._handlers || (emitter._handlers = {});
      map[type] = (map[type] || noHandlers).concat(f);
    }
  };

  function getHandlers(emitter, type) {
    return emitter._handlers && emitter._handlers[type] || noHandlers
  }

  function off(emitter, type, f) {
    if (emitter.removeEventListener) {
      emitter.removeEventListener(type, f, false);
    } else if (emitter.detachEvent) {
      emitter.detachEvent("on" + type, f);
    } else {
      var map = emitter._handlers, arr = map && map[type];
      if (arr) {
        var index = indexOf(arr, f);
        if (index > -1)
          { map[type] = arr.slice(0, index).concat(arr.slice(index + 1)); }
      }
    }
  }

  function signal(emitter, type /*, values...*/) {
    var handlers = getHandlers(emitter, type);
    if (!handlers.length) { return }
    var args = Array.prototype.slice.call(arguments, 2);
    for (var i = 0; i < handlers.length; ++i) { handlers[i].apply(null, args); }
  }

  // The DOM events that CodeMirror handles can be overridden by
  // registering a (non-DOM) handler on the editor for the event name,
  // and preventDefault-ing the event in that handler.
  function signalDOMEvent(cm, e, override) {
    if (typeof e == "string")
      { e = {type: e, preventDefault: function() { this.defaultPrevented = true; }}; }
    signal(cm, override || e.type, cm, e);
    return e_defaultPrevented(e) || e.codemirrorIgnore
  }

  function signalCursorActivity(cm) {
    var arr = cm._handlers && cm._handlers.cursorActivity;
    if (!arr) { return }
    var set = cm.curOp.cursorActivityHandlers || (cm.curOp.cursorActivityHandlers = []);
    for (var i = 0; i < arr.length; ++i) { if (indexOf(set, arr[i]) == -1)
      { set.push(arr[i]); } }
  }

  function hasHandler(emitter, type) {
    return getHandlers(emitter, type).length > 0
  }

  // Add on and off methods to a constructor's prototype, to make
  // registering events on such objects more convenient.
  function eventMixin(ctor) {
    ctor.prototype.on = function(type, f) {on(this, type, f);};
    ctor.prototype.off = function(type, f) {off(this, type, f);};
  }

  // Due to the fact that we still support jurassic IE versions, some
  // compatibility wrappers are needed.

  function e_preventDefault(e) {
    if (e.preventDefault) { e.preventDefault(); }
    else { e.returnValue = false; }
  }
  function e_stopPropagation(e) {
    if (e.stopPropagation) { e.stopPropagation(); }
    else { e.cancelBubble = true; }
  }
  function e_defaultPrevented(e) {
    return e.defaultPrevented != null ? e.defaultPrevented : e.returnValue == false
  }
  function e_stop(e) {e_preventDefault(e); e_stopPropagation(e);}

  function e_target(e) {return e.target || e.srcElement}
  function e_button(e) {
    var b = e.which;
    if (b == null) {
      if (e.button & 1) { b = 1; }
      else if (e.button & 2) { b = 3; }
      else if (e.button & 4) { b = 2; }
    }
    if (mac && e.ctrlKey && b == 1) { b = 3; }
    return b
  }

  // Detect drag-and-drop
  var dragAndDrop = function() {
    // There is *some* kind of drag-and-drop support in IE6-8, but I
    // couldn't get it to work yet.
    if (ie && ie_version < 9) { return false }
    var div = elt('div');
    return "draggable" in div || "dragDrop" in div
  }();

  var zwspSupported;
  function zeroWidthElement(measure) {
    if (zwspSupported == null) {
      var test = elt("span", "\u200b");
      removeChildrenAndAdd(measure, elt("span", [test, document.createTextNode("x")]));
      if (measure.firstChild.offsetHeight != 0)
        { zwspSupported = test.offsetWidth <= 1 && test.offsetHeight > 2 && !(ie && ie_version < 8); }
    }
    var node = zwspSupported ? elt("span", "\u200b") :
      elt("span", "\u00a0", null, "display: inline-block; width: 1px; margin-right: -1px");
    node.setAttribute("cm-text", "");
    return node
  }

  // Feature-detect IE's crummy client rect reporting for bidi text
  var badBidiRects;
  function hasBadBidiRects(measure) {
    if (badBidiRects != null) { return badBidiRects }
    var txt = removeChildrenAndAdd(measure, document.createTextNode("A\u062eA"));
    var r0 = range(txt, 0, 1).getBoundingClientRect();
    var r1 = range(txt, 1, 2).getBoundingClientRect();
    removeChildren(measure);
    if (!r0 || r0.left == r0.right) { return false } // Safari returns null in some cases (#2780)
    return badBidiRects = (r1.right - r0.right < 3)
  }

  // See if "".split is the broken IE version, if so, provide an
  // alternative way to split lines.
  var splitLinesAuto = "\n\nb".split(/\n/).length != 3 ? function (string) {
    var pos = 0, result = [], l = string.length;
    while (pos <= l) {
      var nl = string.indexOf("\n", pos);
      if (nl == -1) { nl = string.length; }
      var line = string.slice(pos, string.charAt(nl - 1) == "\r" ? nl - 1 : nl);
      var rt = line.indexOf("\r");
      if (rt != -1) {
        result.push(line.slice(0, rt));
        pos += rt + 1;
      } else {
        result.push(line);
        pos = nl + 1;
      }
    }
    return result
  } : function (string) { return string.split(/\r\n?|\n/); };

  var hasSelection = window.getSelection ? function (te) {
    try { return te.selectionStart != te.selectionEnd }
    catch(e) { return false }
  } : function (te) {
    var range;
    try {range = te.ownerDocument.selection.createRange();}
    catch(e) {}
    if (!range || range.parentElement() != te) { return false }
    return range.compareEndPoints("StartToEnd", range) != 0
  };

  var hasCopyEvent = (function () {
    var e = elt("div");
    if ("oncopy" in e) { return true }
    e.setAttribute("oncopy", "return;");
    return typeof e.oncopy == "function"
  })();

  var badZoomedRects = null;
  function hasBadZoomedRects(measure) {
    if (badZoomedRects != null) { return badZoomedRects }
    var node = removeChildrenAndAdd(measure, elt("span", "x"));
    var normal = node.getBoundingClientRect();
    var fromRange = range(node, 0, 1).getBoundingClientRect();
    return badZoomedRects = Math.abs(normal.left - fromRange.left) > 1
  }

  // Known modes, by name and by MIME
  var modes = {}, mimeModes = {};

  // Extra arguments are stored as the mode's dependencies, which is
  // used by (legacy) mechanisms like loadmode.js to automatically
  // load a mode. (Preferred mechanism is the require/define calls.)
  function defineMode(name, mode) {
    if (arguments.length > 2)
      { mode.dependencies = Array.prototype.slice.call(arguments, 2); }
    modes[name] = mode;
  }

  function defineMIME(mime, spec) {
    mimeModes[mime] = spec;
  }

  // Given a MIME type, a {name, ...options} config object, or a name
  // string, return a mode config object.
  function resolveMode(spec) {
    if (typeof spec == "string" && mimeModes.hasOwnProperty(spec)) {
      spec = mimeModes[spec];
    } else if (spec && typeof spec.name == "string" && mimeModes.hasOwnProperty(spec.name)) {
      var found = mimeModes[spec.name];
      if (typeof found == "string") { found = {name: found}; }
      spec = createObj(found, spec);
      spec.name = found.name;
    } else if (typeof spec == "string" && /^[\w\-]+\/[\w\-]+\+xml$/.test(spec)) {
      return resolveMode("application/xml")
    } else if (typeof spec == "string" && /^[\w\-]+\/[\w\-]+\+json$/.test(spec)) {
      return resolveMode("application/json")
    }
    if (typeof spec == "string") { return {name: spec} }
    else { return spec || {name: "null"} }
  }

  // Given a mode spec (anything that resolveMode accepts), find and
  // initialize an actual mode object.
  function getMode(options, spec) {
    spec = resolveMode(spec);
    var mfactory = modes[spec.name];
    if (!mfactory) { return getMode(options, "text/plain") }
    var modeObj = mfactory(options, spec);
    if (modeExtensions.hasOwnProperty(spec.name)) {
      var exts = modeExtensions[spec.name];
      for (var prop in exts) {
        if (!exts.hasOwnProperty(prop)) { continue }
        if (modeObj.hasOwnProperty(prop)) { modeObj["_" + prop] = modeObj[prop]; }
        modeObj[prop] = exts[prop];
      }
    }
    modeObj.name = spec.name;
    if (spec.helperType) { modeObj.helperType = spec.helperType; }
    if (spec.modeProps) { for (var prop$1 in spec.modeProps)
      { modeObj[prop$1] = spec.modeProps[prop$1]; } }

    return modeObj
  }

  // This can be used to attach properties to mode objects from
  // outside the actual mode definition.
  var modeExtensions = {};
  function extendMode(mode, properties) {
    var exts = modeExtensions.hasOwnProperty(mode) ? modeExtensions[mode] : (modeExtensions[mode] = {});
    copyObj(properties, exts);
  }

  function copyState(mode, state) {
    if (state === true) { return state }
    if (mode.copyState) { return mode.copyState(state) }
    var nstate = {};
    for (var n in state) {
      var val = state[n];
      if (val instanceof Array) { val = val.concat([]); }
      nstate[n] = val;
    }
    return nstate
  }

  // Given a mode and a state (for that mode), find the inner mode and
  // state at the position that the state refers to.
  function innerMode(mode, state) {
    var info;
    while (mode.innerMode) {
      info = mode.innerMode(state);
      if (!info || info.mode == mode) { break }
      state = info.state;
      mode = info.mode;
    }
    return info || {mode: mode, state: state}
  }

  function startState(mode, a1, a2) {
    return mode.startState ? mode.startState(a1, a2) : true
  }

  // STRING STREAM

  // Fed to the mode parsers, provides helper functions to make
  // parsers more succinct.

  var StringStream = function(string, tabSize, lineOracle) {
    this.pos = this.start = 0;
    this.string = string;
    this.tabSize = tabSize || 8;
    this.lastColumnPos = this.lastColumnValue = 0;
    this.lineStart = 0;
    this.lineOracle = lineOracle;
  };

  StringStream.prototype.eol = function () {return this.pos >= this.string.length};
  StringStream.prototype.sol = function () {return this.pos == this.lineStart};
  StringStream.prototype.peek = function () {return this.string.charAt(this.pos) || undefined};
  StringStream.prototype.next = function () {
    if (this.pos < this.string.length)
      { return this.string.charAt(this.pos++) }
  };
  StringStream.prototype.eat = function (match) {
    var ch = this.string.charAt(this.pos);
    var ok;
    if (typeof match == "string") { ok = ch == match; }
    else { ok = ch && (match.test ? match.test(ch) : match(ch)); }
    if (ok) {++this.pos; return ch}
  };
  StringStream.prototype.eatWhile = function (match) {
    var start = this.pos;
    while (this.eat(match)){}
    return this.pos > start
  };
  StringStream.prototype.eatSpace = function () {
    var start = this.pos;
    while (/[\s\u00a0]/.test(this.string.charAt(this.pos))) { ++this.pos; }
    return this.pos > start
  };
  StringStream.prototype.skipToEnd = function () {this.pos = this.string.length;};
  StringStream.prototype.skipTo = function (ch) {
    var found = this.string.indexOf(ch, this.pos);
    if (found > -1) {this.pos = found; return true}
  };
  StringStream.prototype.backUp = function (n) {this.pos -= n;};
  StringStream.prototype.column = function () {
    if (this.lastColumnPos < this.start) {
      this.lastColumnValue = countColumn(this.string, this.start, this.tabSize, this.lastColumnPos, this.lastColumnValue);
      this.lastColumnPos = this.start;
    }
    return this.lastColumnValue - (this.lineStart ? countColumn(this.string, this.lineStart, this.tabSize) : 0)
  };
  StringStream.prototype.indentation = function () {
    return countColumn(this.string, null, this.tabSize) -
      (this.lineStart ? countColumn(this.string, this.lineStart, this.tabSize) : 0)
  };
  StringStream.prototype.match = function (pattern, consume, caseInsensitive) {
    if (typeof pattern == "string") {
      var cased = function (str) { return caseInsensitive ? str.toLowerCase() : str; };
      var substr = this.string.substr(this.pos, pattern.length);
      if (cased(substr) == cased(pattern)) {
        if (consume !== false) { this.pos += pattern.length; }
        return true
      }
    } else {
      var match = this.string.slice(this.pos).match(pattern);
      if (match && match.index > 0) { return null }
      if (match && consume !== false) { this.pos += match[0].length; }
      return match
    }
  };
  StringStream.prototype.current = function (){return this.string.slice(this.start, this.pos)};
  StringStream.prototype.hideFirstChars = function (n, inner) {
    this.lineStart += n;
    try { return inner() }
    finally { this.lineStart -= n; }
  };
  StringStream.prototype.lookAhead = function (n) {
    var oracle = this.lineOracle;
    return oracle && oracle.lookAhead(n)
  };
  StringStream.prototype.baseToken = function () {
    var oracle = this.lineOracle;
    return oracle && oracle.baseToken(this.pos)
  };

  // Find the line object corresponding to the given line number.
  function getLine(doc, n) {
    n -= doc.first;
    if (n < 0 || n >= doc.size) { throw new Error("There is no line " + (n + doc.first) + " in the document.") }
    var chunk = doc;
    while (!chunk.lines) {
      for (var i = 0;; ++i) {
        var child = chunk.children[i], sz = child.chunkSize();
        if (n < sz) { chunk = child; break }
        n -= sz;
      }
    }
    return chunk.lines[n]
  }

  // Get the part of a document between two positions, as an array of
  // strings.
  function getBetween(doc, start, end) {
    var out = [], n = start.line;
    doc.iter(start.line, end.line + 1, function (line) {
      var text = line.text;
      if (n == end.line) { text = text.slice(0, end.ch); }
      if (n == start.line) { text = text.slice(start.ch); }
      out.push(text);
      ++n;
    });
    return out
  }
  // Get the lines between from and to, as array of strings.
  function getLines(doc, from, to) {
    var out = [];
    doc.iter(from, to, function (line) { out.push(line.text); }); // iter aborts when callback returns truthy value
    return out
  }

  // Update the height of a line, propagating the height change
  // upwards to parent nodes.
  function updateLineHeight(line, height) {
    var diff = height - line.height;
    if (diff) { for (var n = line; n; n = n.parent) { n.height += diff; } }
  }

  // Given a line object, find its line number by walking up through
  // its parent links.
  function lineNo(line) {
    if (line.parent == null) { return null }
    var cur = line.parent, no = indexOf(cur.lines, line);
    for (var chunk = cur.parent; chunk; cur = chunk, chunk = chunk.parent) {
      for (var i = 0;; ++i) {
        if (chunk.children[i] == cur) { break }
        no += chunk.children[i].chunkSize();
      }
    }
    return no + cur.first
  }

  // Find the line at the given vertical position, using the height
  // information in the document tree.
  function lineAtHeight(chunk, h) {
    var n = chunk.first;
    outer: do {
      for (var i$1 = 0; i$1 < chunk.children.length; ++i$1) {
        var child = chunk.children[i$1], ch = child.height;
        if (h < ch) { chunk = child; continue outer }
        h -= ch;
        n += child.chunkSize();
      }
      return n
    } while (!chunk.lines)
    var i = 0;
    for (; i < chunk.lines.length; ++i) {
      var line = chunk.lines[i], lh = line.height;
      if (h < lh) { break }
      h -= lh;
    }
    return n + i
  }

  function isLine(doc, l) {return l >= doc.first && l < doc.first + doc.size}

  function lineNumberFor(options, i) {
    return String(options.lineNumberFormatter(i + options.firstLineNumber))
  }

  // A Pos instance represents a position within the text.
  function Pos(line, ch, sticky) {
    if ( sticky === void 0 ) sticky = null;

    if (!(this instanceof Pos)) { return new Pos(line, ch, sticky) }
    this.line = line;
    this.ch = ch;
    this.sticky = sticky;
  }

  // Compare two positions, return 0 if they are the same, a negative
  // number when a is less, and a positive number otherwise.
  function cmp(a, b) { return a.line - b.line || a.ch - b.ch }

  function equalCursorPos(a, b) { return a.sticky == b.sticky && cmp(a, b) == 0 }

  function copyPos(x) {return Pos(x.line, x.ch)}
  function maxPos(a, b) { return cmp(a, b) < 0 ? b : a }
  function minPos(a, b) { return cmp(a, b) < 0 ? a : b }

  // Most of the external API clips given positions to make sure they
  // actually exist within the document.
  function clipLine(doc, n) {return Math.max(doc.first, Math.min(n, doc.first + doc.size - 1))}
  function clipPos(doc, pos) {
    if (pos.line < doc.first) { return Pos(doc.first, 0) }
    var last = doc.first + doc.size - 1;
    if (pos.line > last) { return Pos(last, getLine(doc, last).text.length) }
    return clipToLen(pos, getLine(doc, pos.line).text.length)
  }
  function clipToLen(pos, linelen) {
    var ch = pos.ch;
    if (ch == null || ch > linelen) { return Pos(pos.line, linelen) }
    else if (ch < 0) { return Pos(pos.line, 0) }
    else { return pos }
  }
  function clipPosArray(doc, array) {
    var out = [];
    for (var i = 0; i < array.length; i++) { out[i] = clipPos(doc, array[i]); }
    return out
  }

  var SavedContext = function(state, lookAhead) {
    this.state = state;
    this.lookAhead = lookAhead;
  };

  var Context = function(doc, state, line, lookAhead) {
    this.state = state;
    this.doc = doc;
    this.line = line;
    this.maxLookAhead = lookAhead || 0;
    this.baseTokens = null;
    this.baseTokenPos = 1;
  };

  Context.prototype.lookAhead = function (n) {
    var line = this.doc.getLine(this.line + n);
    if (line != null && n > this.maxLookAhead) { this.maxLookAhead = n; }
    return line
  };

  Context.prototype.baseToken = function (n) {
    if (!this.baseTokens) { return null }
    while (this.baseTokens[this.baseTokenPos] <= n)
      { this.baseTokenPos += 2; }
    var type = this.baseTokens[this.baseTokenPos + 1];
    return {type: type && type.replace(/( |^)overlay .*/, ""),
            size: this.baseTokens[this.baseTokenPos] - n}
  };

  Context.prototype.nextLine = function () {
    this.line++;
    if (this.maxLookAhead > 0) { this.maxLookAhead--; }
  };

  Context.fromSaved = function (doc, saved, line) {
    if (saved instanceof SavedContext)
      { return new Context(doc, copyState(doc.mode, saved.state), line, saved.lookAhead) }
    else
      { return new Context(doc, copyState(doc.mode, saved), line) }
  };

  Context.prototype.save = function (copy) {
    var state = copy !== false ? copyState(this.doc.mode, this.state) : this.state;
    return this.maxLookAhead > 0 ? new SavedContext(state, this.maxLookAhead) : state
  };


  // Compute a style array (an array starting with a mode generation
  // -- for invalidation -- followed by pairs of end positions and
  // style strings), which is used to highlight the tokens on the
  // line.
  function highlightLine(cm, line, context, forceToEnd) {
    // A styles array always starts with a number identifying the
    // mode/overlays that it is based on (for easy invalidation).
    var st = [cm.state.modeGen], lineClasses = {};
    // Compute the base array of styles
    runMode(cm, line.text, cm.doc.mode, context, function (end, style) { return st.push(end, style); },
            lineClasses, forceToEnd);
    var state = context.state;

    // Run overlays, adjust style array.
    var loop = function ( o ) {
      context.baseTokens = st;
      var overlay = cm.state.overlays[o], i = 1, at = 0;
      context.state = true;
      runMode(cm, line.text, overlay.mode, context, function (end, style) {
        var start = i;
        // Ensure there's a token end at the current position, and that i points at it
        while (at < end) {
          var i_end = st[i];
          if (i_end > end)
            { st.splice(i, 1, end, st[i+1], i_end); }
          i += 2;
          at = Math.min(end, i_end);
        }
        if (!style) { return }
        if (overlay.opaque) {
          st.splice(start, i - start, end, "overlay " + style);
          i = start + 2;
        } else {
          for (; start < i; start += 2) {
            var cur = st[start+1];
            st[start+1] = (cur ? cur + " " : "") + "overlay " + style;
          }
        }
      }, lineClasses);
      context.state = state;
      context.baseTokens = null;
      context.baseTokenPos = 1;
    };

    for (var o = 0; o < cm.state.overlays.length; ++o) loop( o );

    return {styles: st, classes: lineClasses.bgClass || lineClasses.textClass ? lineClasses : null}
  }

  function getLineStyles(cm, line, updateFrontier) {
    if (!line.styles || line.styles[0] != cm.state.modeGen) {
      var context = getContextBefore(cm, lineNo(line));
      var resetState = line.text.length > cm.options.maxHighlightLength && copyState(cm.doc.mode, context.state);
      var result = highlightLine(cm, line, context);
      if (resetState) { context.state = resetState; }
      line.stateAfter = context.save(!resetState);
      line.styles = result.styles;
      if (result.classes) { line.styleClasses = result.classes; }
      else if (line.styleClasses) { line.styleClasses = null; }
      if (updateFrontier === cm.doc.highlightFrontier)
        { cm.doc.modeFrontier = Math.max(cm.doc.modeFrontier, ++cm.doc.highlightFrontier); }
    }
    return line.styles
  }

  function getContextBefore(cm, n, precise) {
    var doc = cm.doc, display = cm.display;
    if (!doc.mode.startState) { return new Context(doc, true, n) }
    var start = findStartLine(cm, n, precise);
    var saved = start > doc.first && getLine(doc, start - 1).stateAfter;
    var context = saved ? Context.fromSaved(doc, saved, start) : new Context(doc, startState(doc.mode), start);

    doc.iter(start, n, function (line) {
      processLine(cm, line.text, context);
      var pos = context.line;
      line.stateAfter = pos == n - 1 || pos % 5 == 0 || pos >= display.viewFrom && pos < display.viewTo ? context.save() : null;
      context.nextLine();
    });
    if (precise) { doc.modeFrontier = context.line; }
    return context
  }

  // Lightweight form of highlight -- proceed over this line and
  // update state, but don't save a style array. Used for lines that
  // aren't currently visible.
  function processLine(cm, text, context, startAt) {
    var mode = cm.doc.mode;
    var stream = new StringStream(text, cm.options.tabSize, context);
    stream.start = stream.pos = startAt || 0;
    if (text == "") { callBlankLine(mode, context.state); }
    while (!stream.eol()) {
      readToken(mode, stream, context.state);
      stream.start = stream.pos;
    }
  }

  function callBlankLine(mode, state) {
    if (mode.blankLine) { return mode.blankLine(state) }
    if (!mode.innerMode) { return }
    var inner = innerMode(mode, state);
    if (inner.mode.blankLine) { return inner.mode.blankLine(inner.state) }
  }

  function readToken(mode, stream, state, inner) {
    for (var i = 0; i < 10; i++) {
      if (inner) { inner[0] = innerMode(mode, state).mode; }
      var style = mode.token(stream, state);
      if (stream.pos > stream.start) { return style }
    }
    throw new Error("Mode " + mode.name + " failed to advance stream.")
  }

  var Token = function(stream, type, state) {
    this.start = stream.start; this.end = stream.pos;
    this.string = stream.current();
    this.type = type || null;
    this.state = state;
  };

  // Utility for getTokenAt and getLineTokens
  function takeToken(cm, pos, precise, asArray) {
    var doc = cm.doc, mode = doc.mode, style;
    pos = clipPos(doc, pos);
    var line = getLine(doc, pos.line), context = getContextBefore(cm, pos.line, precise);
    var stream = new StringStream(line.text, cm.options.tabSize, context), tokens;
    if (asArray) { tokens = []; }
    while ((asArray || stream.pos < pos.ch) && !stream.eol()) {
      stream.start = stream.pos;
      style = readToken(mode, stream, context.state);
      if (asArray) { tokens.push(new Token(stream, style, copyState(doc.mode, context.state))); }
    }
    return asArray ? tokens : new Token(stream, style, context.state)
  }

  function extractLineClasses(type, output) {
    if (type) { for (;;) {
      var lineClass = type.match(/(?:^|\s+)line-(background-)?(\S+)/);
      if (!lineClass) { break }
      type = type.slice(0, lineClass.index) + type.slice(lineClass.index + lineClass[0].length);
      var prop = lineClass[1] ? "bgClass" : "textClass";
      if (output[prop] == null)
        { output[prop] = lineClass[2]; }
      else if (!(new RegExp("(?:^|\\s)" + lineClass[2] + "(?:$|\\s)")).test(output[prop]))
        { output[prop] += " " + lineClass[2]; }
    } }
    return type
  }

  // Run the given mode's parser over a line, calling f for each token.
  function runMode(cm, text, mode, context, f, lineClasses, forceToEnd) {
    var flattenSpans = mode.flattenSpans;
    if (flattenSpans == null) { flattenSpans = cm.options.flattenSpans; }
    var curStart = 0, curStyle = null;
    var stream = new StringStream(text, cm.options.tabSize, context), style;
    var inner = cm.options.addModeClass && [null];
    if (text == "") { extractLineClasses(callBlankLine(mode, context.state), lineClasses); }
    while (!stream.eol()) {
      if (stream.pos > cm.options.maxHighlightLength) {
        flattenSpans = false;
        if (forceToEnd) { processLine(cm, text, context, stream.pos); }
        stream.pos = text.length;
        style = null;
      } else {
        style = extractLineClasses(readToken(mode, stream, context.state, inner), lineClasses);
      }
      if (inner) {
        var mName = inner[0].name;
        if (mName) { style = "m-" + (style ? mName + " " + style : mName); }
      }
      if (!flattenSpans || curStyle != style) {
        while (curStart < stream.start) {
          curStart = Math.min(stream.start, curStart + 5000);
          f(curStart, curStyle);
        }
        curStyle = style;
      }
      stream.start = stream.pos;
    }
    while (curStart < stream.pos) {
      // Webkit seems to refuse to render text nodes longer than 57444
      // characters, and returns inaccurate measurements in nodes
      // starting around 5000 chars.
      var pos = Math.min(stream.pos, curStart + 5000);
      f(pos, curStyle);
      curStart = pos;
    }
  }

  // Finds the line to start with when starting a parse. Tries to
  // find a line with a stateAfter, so that it can start with a
  // valid state. If that fails, it returns the line with the
  // smallest indentation, which tends to need the least context to
  // parse correctly.
  function findStartLine(cm, n, precise) {
    var minindent, minline, doc = cm.doc;
    var lim = precise ? -1 : n - (cm.doc.mode.innerMode ? 1000 : 100);
    for (var search = n; search > lim; --search) {
      if (search <= doc.first) { return doc.first }
      var line = getLine(doc, search - 1), after = line.stateAfter;
      if (after && (!precise || search + (after instanceof SavedContext ? after.lookAhead : 0) <= doc.modeFrontier))
        { return search }
      var indented = countColumn(line.text, null, cm.options.tabSize);
      if (minline == null || minindent > indented) {
        minline = search - 1;
        minindent = indented;
      }
    }
    return minline
  }

  function retreatFrontier(doc, n) {
    doc.modeFrontier = Math.min(doc.modeFrontier, n);
    if (doc.highlightFrontier < n - 10) { return }
    var start = doc.first;
    for (var line = n - 1; line > start; line--) {
      var saved = getLine(doc, line).stateAfter;
      // change is on 3
      // state on line 1 looked ahead 2 -- so saw 3
      // test 1 + 2 < 3 should cover this
      if (saved && (!(saved instanceof SavedContext) || line + saved.lookAhead < n)) {
        start = line + 1;
        break
      }
    }
    doc.highlightFrontier = Math.min(doc.highlightFrontier, start);
  }

  // Optimize some code when these features are not used.
  var sawReadOnlySpans = false, sawCollapsedSpans = false;

  function seeReadOnlySpans() {
    sawReadOnlySpans = true;
  }

  function seeCollapsedSpans() {
    sawCollapsedSpans = true;
  }

  // TEXTMARKER SPANS

  function MarkedSpan(marker, from, to) {
    this.marker = marker;
    this.from = from; this.to = to;
  }

  // Search an array of spans for a span matching the given marker.
  function getMarkedSpanFor(spans, marker) {
    if (spans) { for (var i = 0; i < spans.length; ++i) {
      var span = spans[i];
      if (span.marker == marker) { return span }
    } }
  }

  // Remove a span from an array, returning undefined if no spans are
  // left (we don't store arrays for lines without spans).
  function removeMarkedSpan(spans, span) {
    var r;
    for (var i = 0; i < spans.length; ++i)
      { if (spans[i] != span) { (r || (r = [])).push(spans[i]); } }
    return r
  }

  // Add a span to a line.
  function addMarkedSpan(line, span, op) {
    var inThisOp = op && window.WeakSet && (op.markedSpans || (op.markedSpans = new WeakSet));
    if (inThisOp && line.markedSpans && inThisOp.has(line.markedSpans)) {
      line.markedSpans.push(span);
    } else {
      line.markedSpans = line.markedSpans ? line.markedSpans.concat([span]) : [span];
      if (inThisOp) { inThisOp.add(line.markedSpans); }
    }
    span.marker.attachLine(line);
  }

  // Used for the algorithm that adjusts markers for a change in the
  // document. These functions cut an array of spans at a given
  // character position, returning an array of remaining chunks (or
  // undefined if nothing remains).
  function markedSpansBefore(old, startCh, isInsert) {
    var nw;
    if (old) { for (var i = 0; i < old.length; ++i) {
      var span = old[i], marker = span.marker;
      var startsBefore = span.from == null || (marker.inclusiveLeft ? span.from <= startCh : span.from < startCh);
      if (startsBefore || span.from == startCh && marker.type == "bookmark" && (!isInsert || !span.marker.insertLeft)) {
        var endsAfter = span.to == null || (marker.inclusiveRight ? span.to >= startCh : span.to > startCh)
        ;(nw || (nw = [])).push(new MarkedSpan(marker, span.from, endsAfter ? null : span.to));
      }
    } }
    return nw
  }
  function markedSpansAfter(old, endCh, isInsert) {
    var nw;
    if (old) { for (var i = 0; i < old.length; ++i) {
      var span = old[i], marker = span.marker;
      var endsAfter = span.to == null || (marker.inclusiveRight ? span.to >= endCh : span.to > endCh);
      if (endsAfter || span.from == endCh && marker.type == "bookmark" && (!isInsert || span.marker.insertLeft)) {
        var startsBefore = span.from == null || (marker.inclusiveLeft ? span.from <= endCh : span.from < endCh)
        ;(nw || (nw = [])).push(new MarkedSpan(marker, startsBefore ? null : span.from - endCh,
                                              span.to == null ? null : span.to - endCh));
      }
    } }
    return nw
  }

  // Given a change object, compute the new set of marker spans that
  // cover the line in which the change took place. Removes spans
  // entirely within the change, reconnects spans belonging to the
  // same marker that appear on both sides of the change, and cuts off
  // spans partially within the change. Returns an array of span
  // arrays with one element for each line in (after) the change.
  function stretchSpansOverChange(doc, change) {
    if (change.full) { return null }
    var oldFirst = isLine(doc, change.from.line) && getLine(doc, change.from.line).markedSpans;
    var oldLast = isLine(doc, change.to.line) && getLine(doc, change.to.line).markedSpans;
    if (!oldFirst && !oldLast) { return null }

    var startCh = change.from.ch, endCh = change.to.ch, isInsert = cmp(change.from, change.to) == 0;
    // Get the spans that 'stick out' on both sides
    var first = markedSpansBefore(oldFirst, startCh, isInsert);
    var last = markedSpansAfter(oldLast, endCh, isInsert);

    // Next, merge those two ends
    var sameLine = change.text.length == 1, offset = lst(change.text).length + (sameLine ? startCh : 0);
    if (first) {
      // Fix up .to properties of first
      for (var i = 0; i < first.length; ++i) {
        var span = first[i];
        if (span.to == null) {
          var found = getMarkedSpanFor(last, span.marker);
          if (!found) { span.to = startCh; }
          else if (sameLine) { span.to = found.to == null ? null : found.to + offset; }
        }
      }
    }
    if (last) {
      // Fix up .from in last (or move them into first in case of sameLine)
      for (var i$1 = 0; i$1 < last.length; ++i$1) {
        var span$1 = last[i$1];
        if (span$1.to != null) { span$1.to += offset; }
        if (span$1.from == null) {
          var found$1 = getMarkedSpanFor(first, span$1.marker);
          if (!found$1) {
            span$1.from = offset;
            if (sameLine) { (first || (first = [])).push(span$1); }
          }
        } else {
          span$1.from += offset;
          if (sameLine) { (first || (first = [])).push(span$1); }
        }
      }
    }
    // Make sure we didn't create any zero-length spans
    if (first) { first = clearEmptySpans(first); }
    if (last && last != first) { last = clearEmptySpans(last); }

    var newMarkers = [first];
    if (!sameLine) {
      // Fill gap with whole-line-spans
      var gap = change.text.length - 2, gapMarkers;
      if (gap > 0 && first)
        { for (var i$2 = 0; i$2 < first.length; ++i$2)
          { if (first[i$2].to == null)
            { (gapMarkers || (gapMarkers = [])).push(new MarkedSpan(first[i$2].marker, null, null)); } } }
      for (var i$3 = 0; i$3 < gap; ++i$3)
        { newMarkers.push(gapMarkers); }
      newMarkers.push(last);
    }
    return newMarkers
  }

  // Remove spans that are empty and don't have a clearWhenEmpty
  // option of false.
  function clearEmptySpans(spans) {
    for (var i = 0; i < spans.length; ++i) {
      var span = spans[i];
      if (span.from != null && span.from == span.to && span.marker.clearWhenEmpty !== false)
        { spans.splice(i--, 1); }
    }
    if (!spans.length) { return null }
    return spans
  }

  // Used to 'clip' out readOnly ranges when making a change.
  function removeReadOnlyRanges(doc, from, to) {
    var markers = null;
    doc.iter(from.line, to.line + 1, function (line) {
      if (line.markedSpans) { for (var i = 0; i < line.markedSpans.length; ++i) {
        var mark = line.markedSpans[i].marker;
        if (mark.readOnly && (!markers || indexOf(markers, mark) == -1))
          { (markers || (markers = [])).push(mark); }
      } }
    });
    if (!markers) { return null }
    var parts = [{from: from, to: to}];
    for (var i = 0; i < markers.length; ++i) {
      var mk = markers[i], m = mk.find(0);
      for (var j = 0; j < parts.length; ++j) {
        var p = parts[j];
        if (cmp(p.to, m.from) < 0 || cmp(p.from, m.to) > 0) { continue }
        var newParts = [j, 1], dfrom = cmp(p.from, m.from), dto = cmp(p.to, m.to);
        if (dfrom < 0 || !mk.inclusiveLeft && !dfrom)
          { newParts.push({from: p.from, to: m.from}); }
        if (dto > 0 || !mk.inclusiveRight && !dto)
          { newParts.push({from: m.to, to: p.to}); }
        parts.splice.apply(parts, newParts);
        j += newParts.length - 3;
      }
    }
    return parts
  }

  // Connect or disconnect spans from a line.
  function detachMarkedSpans(line) {
    var spans = line.markedSpans;
    if (!spans) { return }
    for (var i = 0; i < spans.length; ++i)
      { spans[i].marker.detachLine(line); }
    line.markedSpans = null;
  }
  function attachMarkedSpans(line, spans) {
    if (!spans) { return }
    for (var i = 0; i < spans.length; ++i)
      { spans[i].marker.attachLine(line); }
    line.markedSpans = spans;
  }

  // Helpers used when computing which overlapping collapsed span
  // counts as the larger one.
  function extraLeft(marker) { return marker.inclusiveLeft ? -1 : 0 }
  function extraRight(marker) { return marker.inclusiveRight ? 1 : 0 }

  // Returns a number indicating which of two overlapping collapsed
  // spans is larger (and thus includes the other). Falls back to
  // comparing ids when the spans cover exactly the same range.
  function compareCollapsedMarkers(a, b) {
    var lenDiff = a.lines.length - b.lines.length;
    if (lenDiff != 0) { return lenDiff }
    var aPos = a.find(), bPos = b.find();
    var fromCmp = cmp(aPos.from, bPos.from) || extraLeft(a) - extraLeft(b);
    if (fromCmp) { return -fromCmp }
    var toCmp = cmp(aPos.to, bPos.to) || extraRight(a) - extraRight(b);
    if (toCmp) { return toCmp }
    return b.id - a.id
  }

  // Find out whether a line ends or starts in a collapsed span. If
  // so, return the marker for that span.
  function collapsedSpanAtSide(line, start) {
    var sps = sawCollapsedSpans && line.markedSpans, found;
    if (sps) { for (var sp = (void 0), i = 0; i < sps.length; ++i) {
      sp = sps[i];
      if (sp.marker.collapsed && (start ? sp.from : sp.to) == null &&
          (!found || compareCollapsedMarkers(found, sp.marker) < 0))
        { found = sp.marker; }
    } }
    return found
  }
  function collapsedSpanAtStart(line) { return collapsedSpanAtSide(line, true) }
  function collapsedSpanAtEnd(line) { return collapsedSpanAtSide(line, false) }

  function collapsedSpanAround(line, ch) {
    var sps = sawCollapsedSpans && line.markedSpans, found;
    if (sps) { for (var i = 0; i < sps.length; ++i) {
      var sp = sps[i];
      if (sp.marker.collapsed && (sp.from == null || sp.from < ch) && (sp.to == null || sp.to > ch) &&
          (!found || compareCollapsedMarkers(found, sp.marker) < 0)) { found = sp.marker; }
    } }
    return found
  }

  // Test whether there exists a collapsed span that partially
  // overlaps (covers the start or end, but not both) of a new span.
  // Such overlap is not allowed.
  function conflictingCollapsedRange(doc, lineNo, from, to, marker) {
    var line = getLine(doc, lineNo);
    var sps = sawCollapsedSpans && line.markedSpans;
    if (sps) { for (var i = 0; i < sps.length; ++i) {
      var sp = sps[i];
      if (!sp.marker.collapsed) { continue }
      var found = sp.marker.find(0);
      var fromCmp = cmp(found.from, from) || extraLeft(sp.marker) - extraLeft(marker);
      var toCmp = cmp(found.to, to) || extraRight(sp.marker) - extraRight(marker);
      if (fromCmp >= 0 && toCmp <= 0 || fromCmp <= 0 && toCmp >= 0) { continue }
      if (fromCmp <= 0 && (sp.marker.inclusiveRight && marker.inclusiveLeft ? cmp(found.to, from) >= 0 : cmp(found.to, from) > 0) ||
          fromCmp >= 0 && (sp.marker.inclusiveRight && marker.inclusiveLeft ? cmp(found.from, to) <= 0 : cmp(found.from, to) < 0))
        { return true }
    } }
  }

  // A visual line is a line as drawn on the screen. Folding, for
  // example, can cause multiple logical lines to appear on the same
  // visual line. This finds the start of the visual line that the
  // given line is part of (usually that is the line itself).
  function visualLine(line) {
    var merged;
    while (merged = collapsedSpanAtStart(line))
      { line = merged.find(-1, true).line; }
    return line
  }

  function visualLineEnd(line) {
    var merged;
    while (merged = collapsedSpanAtEnd(line))
      { line = merged.find(1, true).line; }
    return line
  }

  // Returns an array of logical lines that continue the visual line
  // started by the argument, or undefined if there are no such lines.
  function visualLineContinued(line) {
    var merged, lines;
    while (merged = collapsedSpanAtEnd(line)) {
      line = merged.find(1, true).line
      ;(lines || (lines = [])).push(line);
    }
    return lines
  }

  // Get the line number of the start of the visual line that the
  // given line number is part of.
  function visualLineNo(doc, lineN) {
    var line = getLine(doc, lineN), vis = visualLine(line);
    if (line == vis) { return lineN }
    return lineNo(vis)
  }

  // Get the line number of the start of the next visual line after
  // the given line.
  function visualLineEndNo(doc, lineN) {
    if (lineN > doc.lastLine()) { return lineN }
    var line = getLine(doc, lineN), merged;
    if (!lineIsHidden(doc, line)) { return lineN }
    while (merged = collapsedSpanAtEnd(line))
      { line = merged.find(1, true).line; }
    return lineNo(line) + 1
  }

  // Compute whether a line is hidden. Lines count as hidden when they
  // are part of a visual line that starts with another line, or when
  // they are entirely covered by collapsed, non-widget span.
  function lineIsHidden(doc, line) {
    var sps = sawCollapsedSpans && line.markedSpans;
    if (sps) { for (var sp = (void 0), i = 0; i < sps.length; ++i) {
      sp = sps[i];
      if (!sp.marker.collapsed) { continue }
      if (sp.from == null) { return true }
      if (sp.marker.widgetNode) { continue }
      if (sp.from == 0 && sp.marker.inclusiveLeft && lineIsHiddenInner(doc, line, sp))
        { return true }
    } }
  }
  function lineIsHiddenInner(doc, line, span) {
    if (span.to == null) {
      var end = span.marker.find(1, true);
      return lineIsHiddenInner(doc, end.line, getMarkedSpanFor(end.line.markedSpans, span.marker))
    }
    if (span.marker.inclusiveRight && span.to == line.text.length)
      { return true }
    for (var sp = (void 0), i = 0; i < line.markedSpans.length; ++i) {
      sp = line.markedSpans[i];
      if (sp.marker.collapsed && !sp.marker.widgetNode && sp.from == span.to &&
          (sp.to == null || sp.to != span.from) &&
          (sp.marker.inclusiveLeft || span.marker.inclusiveRight) &&
          lineIsHiddenInner(doc, line, sp)) { return true }
    }
  }

  // Find the height above the given line.
  function heightAtLine(lineObj) {
    lineObj = visualLine(lineObj);

    var h = 0, chunk = lineObj.parent;
    for (var i = 0; i < chunk.lines.length; ++i) {
      var line = chunk.lines[i];
      if (line == lineObj) { break }
      else { h += line.height; }
    }
    for (var p = chunk.parent; p; chunk = p, p = chunk.parent) {
      for (var i$1 = 0; i$1 < p.children.length; ++i$1) {
        var cur = p.children[i$1];
        if (cur == chunk) { break }
        else { h += cur.height; }
      }
    }
    return h
  }

  // Compute the character length of a line, taking into account
  // collapsed ranges (see markText) that might hide parts, and join
  // other lines onto it.
  function lineLength(line) {
    if (line.height == 0) { return 0 }
    var len = line.text.length, merged, cur = line;
    while (merged = collapsedSpanAtStart(cur)) {
      var found = merged.find(0, true);
      cur = found.from.line;
      len += found.from.ch - found.to.ch;
    }
    cur = line;
    while (merged = collapsedSpanAtEnd(cur)) {
      var found$1 = merged.find(0, true);
      len -= cur.text.length - found$1.from.ch;
      cur = found$1.to.line;
      len += cur.text.length - found$1.to.ch;
    }
    return len
  }

  // Find the longest line in the document.
  function findMaxLine(cm) {
    var d = cm.display, doc = cm.doc;
    d.maxLine = getLine(doc, doc.first);
    d.maxLineLength = lineLength(d.maxLine);
    d.maxLineChanged = true;
    doc.iter(function (line) {
      var len = lineLength(line);
      if (len > d.maxLineLength) {
        d.maxLineLength = len;
        d.maxLine = line;
      }
    });
  }

  // LINE DATA STRUCTURE

  // Line objects. These hold state related to a line, including
  // highlighting info (the styles array).
  var Line = function(text, markedSpans, estimateHeight) {
    this.text = text;
    attachMarkedSpans(this, markedSpans);
    this.height = estimateHeight ? estimateHeight(this) : 1;
  };

  Line.prototype.lineNo = function () { return lineNo(this) };
  eventMixin(Line);

  // Change the content (text, markers) of a line. Automatically
  // invalidates cached information and tries to re-estimate the
  // line's height.
  function updateLine(line, text, markedSpans, estimateHeight) {
    line.text = text;
    if (line.stateAfter) { line.stateAfter = null; }
    if (line.styles) { line.styles = null; }
    if (line.order != null) { line.order = null; }
    detachMarkedSpans(line);
    attachMarkedSpans(line, markedSpans);
    var estHeight = estimateHeight ? estimateHeight(line) : 1;
    if (estHeight != line.height) { updateLineHeight(line, estHeight); }
  }

  // Detach a line from the document tree and its markers.
  function cleanUpLine(line) {
    line.parent = null;
    detachMarkedSpans(line);
  }

  // Convert a style as returned by a mode (either null, or a string
  // containing one or more styles) to a CSS style. This is cached,
  // and also looks for line-wide styles.
  var styleToClassCache = {}, styleToClassCacheWithMode = {};
  function interpretTokenStyle(style, options) {
    if (!style || /^\s*$/.test(style)) { return null }
    var cache = options.addModeClass ? styleToClassCacheWithMode : styleToClassCache;
    return cache[style] ||
      (cache[style] = style.replace(/\S+/g, "cm-$&"))
  }

  // Render the DOM representation of the text of a line. Also builds
  // up a 'line map', which points at the DOM nodes that represent
  // specific stretches of text, and is used by the measuring code.
  // The returned object contains the DOM node, this map, and
  // information about line-wide styles that were set by the mode.
  function buildLineContent(cm, lineView) {
    // The padding-right forces the element to have a 'border', which
    // is needed on Webkit to be able to get line-level bounding
    // rectangles for it (in measureChar).
    var content = eltP("span", null, null, webkit ? "padding-right: .1px" : null);
    var builder = {pre: eltP("pre", [content], "CodeMirror-line"), content: content,
                   col: 0, pos: 0, cm: cm,
                   trailingSpace: false,
                   splitSpaces: cm.getOption("lineWrapping")};
    lineView.measure = {};

    // Iterate over the logical lines that make up this visual line.
    for (var i = 0; i <= (lineView.rest ? lineView.rest.length : 0); i++) {
      var line = i ? lineView.rest[i - 1] : lineView.line, order = (void 0);
      builder.pos = 0;
      builder.addToken = buildToken;
      // Optionally wire in some hacks into the token-rendering
      // algorithm, to deal with browser quirks.
      if (hasBadBidiRects(cm.display.measure) && (order = getOrder(line, cm.doc.direction)))
        { builder.addToken = buildTokenBadBidi(builder.addToken, order); }
      builder.map = [];
      var allowFrontierUpdate = lineView != cm.display.externalMeasured && lineNo(line);
      insertLineContent(line, builder, getLineStyles(cm, line, allowFrontierUpdate));
      if (line.styleClasses) {
        if (line.styleClasses.bgClass)
          { builder.bgClass = joinClasses(line.styleClasses.bgClass, builder.bgClass || ""); }
        if (line.styleClasses.textClass)
          { builder.textClass = joinClasses(line.styleClasses.textClass, builder.textClass || ""); }
      }

      // Ensure at least a single node is present, for measuring.
      if (builder.map.length == 0)
        { builder.map.push(0, 0, builder.content.appendChild(zeroWidthElement(cm.display.measure))); }

      // Store the map and a cache object for the current logical line
      if (i == 0) {
        lineView.measure.map = builder.map;
        lineView.measure.cache = {};
      } else {
  (lineView.measure.maps || (lineView.measure.maps = [])).push(builder.map)
        ;(lineView.measure.caches || (lineView.measure.caches = [])).push({});
      }
    }

    // See issue #2901
    if (webkit) {
      var last = builder.content.lastChild;
      if (/\bcm-tab\b/.test(last.className) || (last.querySelector && last.querySelector(".cm-tab")))
        { builder.content.className = "cm-tab-wrap-hack"; }
    }

    signal(cm, "renderLine", cm, lineView.line, builder.pre);
    if (builder.pre.className)
      { builder.textClass = joinClasses(builder.pre.className, builder.textClass || ""); }

    return builder
  }

  function defaultSpecialCharPlaceholder(ch) {
    var token = elt("span", "\u2022", "cm-invalidchar");
    token.title = "\\u" + ch.charCodeAt(0).toString(16);
    token.setAttribute("aria-label", token.title);
    return token
  }

  // Build up the DOM representation for a single token, and add it to
  // the line map. Takes care to render special characters separately.
  function buildToken(builder, text, style, startStyle, endStyle, css, attributes) {
    if (!text) { return }
    var displayText = builder.splitSpaces ? splitSpaces(text, builder.trailingSpace) : text;
    var special = builder.cm.state.specialChars, mustWrap = false;
    var content;
    if (!special.test(text)) {
      builder.col += text.length;
      content = document.createTextNode(displayText);
      builder.map.push(builder.pos, builder.pos + text.length, content);
      if (ie && ie_version < 9) { mustWrap = true; }
      builder.pos += text.length;
    } else {
      content = document.createDocumentFragment();
      var pos = 0;
      while (true) {
        special.lastIndex = pos;
        var m = special.exec(text);
        var skipped = m ? m.index - pos : text.length - pos;
        if (skipped) {
          var txt = document.createTextNode(displayText.slice(pos, pos + skipped));
          if (ie && ie_version < 9) { content.appendChild(elt("span", [txt])); }
          else { content.appendChild(txt); }
          builder.map.push(builder.pos, builder.pos + skipped, txt);
          builder.col += skipped;
          builder.pos += skipped;
        }
        if (!m) { break }
        pos += skipped + 1;
        var txt$1 = (void 0);
        if (m[0] == "\t") {
          var tabSize = builder.cm.options.tabSize, tabWidth = tabSize - builder.col % tabSize;
          txt$1 = content.appendChild(elt("span", spaceStr(tabWidth), "cm-tab"));
          txt$1.setAttribute("role", "presentation");
          txt$1.setAttribute("cm-text", "\t");
          builder.col += tabWidth;
        } else if (m[0] == "\r" || m[0] == "\n") {
          txt$1 = content.appendChild(elt("span", m[0] == "\r" ? "\u240d" : "\u2424", "cm-invalidchar"));
          txt$1.setAttribute("cm-text", m[0]);
          builder.col += 1;
        } else {
          txt$1 = builder.cm.options.specialCharPlaceholder(m[0]);
          txt$1.setAttribute("cm-text", m[0]);
          if (ie && ie_version < 9) { content.appendChild(elt("span", [txt$1])); }
          else { content.appendChild(txt$1); }
          builder.col += 1;
        }
        builder.map.push(builder.pos, builder.pos + 1, txt$1);
        builder.pos++;
      }
    }
    builder.trailingSpace = displayText.charCodeAt(text.length - 1) == 32;
    if (style || startStyle || endStyle || mustWrap || css || attributes) {
      var fullStyle = style || "";
      if (startStyle) { fullStyle += startStyle; }
      if (endStyle) { fullStyle += endStyle; }
      var token = elt("span", [content], fullStyle, css);
      if (attributes) {
        for (var attr in attributes) { if (attributes.hasOwnProperty(attr) && attr != "style" && attr != "class")
          { token.setAttribute(attr, attributes[attr]); } }
      }
      return builder.content.appendChild(token)
    }
    builder.content.appendChild(content);
  }

  // Change some spaces to NBSP to prevent the browser from collapsing
  // trailing spaces at the end of a line when rendering text (issue #1362).
  function splitSpaces(text, trailingBefore) {
    if (text.length > 1 && !/  /.test(text)) { return text }
    var spaceBefore = trailingBefore, result = "";
    for (var i = 0; i < text.length; i++) {
      var ch = text.charAt(i);
      if (ch == " " && spaceBefore && (i == text.length - 1 || text.charCodeAt(i + 1) == 32))
        { ch = "\u00a0"; }
      result += ch;
      spaceBefore = ch == " ";
    }
    return result
  }

  // Work around nonsense dimensions being reported for stretches of
  // right-to-left text.
  function buildTokenBadBidi(inner, order) {
    return function (builder, text, style, startStyle, endStyle, css, attributes) {
      style = style ? style + " cm-force-border" : "cm-force-border";
      var start = builder.pos, end = start + text.length;
      for (;;) {
        // Find the part that overlaps with the start of this text
        var part = (void 0);
        for (var i = 0; i < order.length; i++) {
          part = order[i];
          if (part.to > start && part.from <= start) { break }
        }
        if (part.to >= end) { return inner(builder, text, style, startStyle, endStyle, css, attributes) }
        inner(builder, text.slice(0, part.to - start), style, startStyle, null, css, attributes);
        startStyle = null;
        text = text.slice(part.to - start);
        start = part.to;
      }
    }
  }

  function buildCollapsedSpan(builder, size, marker, ignoreWidget) {
    var widget = !ignoreWidget && marker.widgetNode;
    if (widget) { builder.map.push(builder.pos, builder.pos + size, widget); }
    if (!ignoreWidget && builder.cm.display.input.needsContentAttribute) {
      if (!widget)
        { widget = builder.content.appendChild(document.createElement("span")); }
      widget.setAttribute("cm-marker", marker.id);
    }
    if (widget) {
      builder.cm.display.input.setUneditable(widget);
      builder.content.appendChild(widget);
    }
    builder.pos += size;
    builder.trailingSpace = false;
  }

  // Outputs a number of spans to make up a line, taking highlighting
  // and marked text into account.
  function insertLineContent(line, builder, styles) {
    var spans = line.markedSpans, allText = line.text, at = 0;
    if (!spans) {
      for (var i$1 = 1; i$1 < styles.length; i$1+=2)
        { builder.addToken(builder, allText.slice(at, at = styles[i$1]), interpretTokenStyle(styles[i$1+1], builder.cm.options)); }
      return
    }

    var len = allText.length, pos = 0, i = 1, text = "", style, css;
    var nextChange = 0, spanStyle, spanEndStyle, spanStartStyle, collapsed, attributes;
    for (;;) {
      if (nextChange == pos) { // Update current marker set
        spanStyle = spanEndStyle = spanStartStyle = css = "";
        attributes = null;
        collapsed = null; nextChange = Infinity;
        var foundBookmarks = [], endStyles = (void 0);
        for (var j = 0; j < spans.length; ++j) {
          var sp = spans[j], m = sp.marker;
          if (m.type == "bookmark" && sp.from == pos && m.widgetNode) {
            foundBookmarks.push(m);
          } else if (sp.from <= pos && (sp.to == null || sp.to > pos || m.collapsed && sp.to == pos && sp.from == pos)) {
            if (sp.to != null && sp.to != pos && nextChange > sp.to) {
              nextChange = sp.to;
              spanEndStyle = "";
            }
            if (m.className) { spanStyle += " " + m.className; }
            if (m.css) { css = (css ? css + ";" : "") + m.css; }
            if (m.startStyle && sp.from == pos) { spanStartStyle += " " + m.startStyle; }
            if (m.endStyle && sp.to == nextChange) { (endStyles || (endStyles = [])).push(m.endStyle, sp.to); }
            // support for the old title property
            // https://github.com/codemirror/CodeMirror/pull/5673
            if (m.title) { (attributes || (attributes = {})).title = m.title; }
            if (m.attributes) {
              for (var attr in m.attributes)
                { (attributes || (attributes = {}))[attr] = m.attributes[attr]; }
            }
            if (m.collapsed && (!collapsed || compareCollapsedMarkers(collapsed.marker, m) < 0))
              { collapsed = sp; }
          } else if (sp.from > pos && nextChange > sp.from) {
            nextChange = sp.from;
          }
        }
        if (endStyles) { for (var j$1 = 0; j$1 < endStyles.length; j$1 += 2)
          { if (endStyles[j$1 + 1] == nextChange) { spanEndStyle += " " + endStyles[j$1]; } } }

        if (!collapsed || collapsed.from == pos) { for (var j$2 = 0; j$2 < foundBookmarks.length; ++j$2)
          { buildCollapsedSpan(builder, 0, foundBookmarks[j$2]); } }
        if (collapsed && (collapsed.from || 0) == pos) {
          buildCollapsedSpan(builder, (collapsed.to == null ? len + 1 : collapsed.to) - pos,
                             collapsed.marker, collapsed.from == null);
          if (collapsed.to == null) { return }
          if (collapsed.to == pos) { collapsed = false; }
        }
      }
      if (pos >= len) { break }

      var upto = Math.min(len, nextChange);
      while (true) {
        if (text) {
          var end = pos + text.length;
          if (!collapsed) {
            var tokenText = end > upto ? text.slice(0, upto - pos) : text;
            builder.addToken(builder, tokenText, style ? style + spanStyle : spanStyle,
                             spanStartStyle, pos + tokenText.length == nextChange ? spanEndStyle : "", css, attributes);
          }
          if (end >= upto) {text = text.slice(upto - pos); pos = upto; break}
          pos = end;
          spanStartStyle = "";
        }
        text = allText.slice(at, at = styles[i++]);
        style = interpretTokenStyle(styles[i++], builder.cm.options);
      }
    }
  }


  // These objects are used to represent the visible (currently drawn)
  // part of the document. A LineView may correspond to multiple
  // logical lines, if those are connected by collapsed ranges.
  function LineView(doc, line, lineN) {
    // The starting line
    this.line = line;
    // Continuing lines, if any
    this.rest = visualLineContinued(line);
    // Number of logical lines in this visual line
    this.size = this.rest ? lineNo(lst(this.rest)) - lineN + 1 : 1;
    this.node = this.text = null;
    this.hidden = lineIsHidden(doc, line);
  }

  // Create a range of LineView objects for the given lines.
  function buildViewArray(cm, from, to) {
    var array = [], nextPos;
    for (var pos = from; pos < to; pos = nextPos) {
      var view = new LineView(cm.doc, getLine(cm.doc, pos), pos);
      nextPos = pos + view.size;
      array.push(view);
    }
    return array
  }

  var operationGroup = null;

  function pushOperation(op) {
    if (operationGroup) {
      operationGroup.ops.push(op);
    } else {
      op.ownsGroup = operationGroup = {
        ops: [op],
        delayedCallbacks: []
      };
    }
  }

  function fireCallbacksForOps(group) {
    // Calls delayed callbacks and cursorActivity handlers until no
    // new ones appear
    var callbacks = group.delayedCallbacks, i = 0;
    do {
      for (; i < callbacks.length; i++)
        { callbacks[i].call(null); }
      for (var j = 0; j < group.ops.length; j++) {
        var op = group.ops[j];
        if (op.cursorActivityHandlers)
          { while (op.cursorActivityCalled < op.cursorActivityHandlers.length)
            { op.cursorActivityHandlers[op.cursorActivityCalled++].call(null, op.cm); } }
      }
    } while (i < callbacks.length)
  }

  function finishOperation(op, endCb) {
    var group = op.ownsGroup;
    if (!group) { return }

    try { fireCallbacksForOps(group); }
    finally {
      operationGroup = null;
      endCb(group);
    }
  }

  var orphanDelayedCallbacks = null;

  // Often, we want to signal events at a point where we are in the
  // middle of some work, but don't want the handler to start calling
  // other methods on the editor, which might be in an inconsistent
  // state or simply not expect any other events to happen.
  // signalLater looks whether there are any handlers, and schedules
  // them to be executed when the last operation ends, or, if no
  // operation is active, when a timeout fires.
  function signalLater(emitter, type /*, values...*/) {
    var arr = getHandlers(emitter, type);
    if (!arr.length) { return }
    var args = Array.prototype.slice.call(arguments, 2), list;
    if (operationGroup) {
      list = operationGroup.delayedCallbacks;
    } else if (orphanDelayedCallbacks) {
      list = orphanDelayedCallbacks;
    } else {
      list = orphanDelayedCallbacks = [];
      setTimeout(fireOrphanDelayed, 0);
    }
    var loop = function ( i ) {
      list.push(function () { return arr[i].apply(null, args); });
    };

    for (var i = 0; i < arr.length; ++i)
      loop( i );
  }

  function fireOrphanDelayed() {
    var delayed = orphanDelayedCallbacks;
    orphanDelayedCallbacks = null;
    for (var i = 0; i < delayed.length; ++i) { delayed[i](); }
  }

  // When an aspect of a line changes, a string is added to
  // lineView.changes. This updates the relevant part of the line's
  // DOM structure.
  function updateLineForChanges(cm, lineView, lineN, dims) {
    for (var j = 0; j < lineView.changes.length; j++) {
      var type = lineView.changes[j];
      if (type == "text") { updateLineText(cm, lineView); }
      else if (type == "gutter") { updateLineGutter(cm, lineView, lineN, dims); }
      else if (type == "class") { updateLineClasses(cm, lineView); }
      else if (type == "widget") { updateLineWidgets(cm, lineView, dims); }
    }
    lineView.changes = null;
  }

  // Lines with gutter elements, widgets or a background class need to
  // be wrapped, and have the extra elements added to the wrapper div
  function ensureLineWrapped(lineView) {
    if (lineView.node == lineView.text) {
      lineView.node = elt("div", null, null, "position: relative");
      if (lineView.text.parentNode)
        { lineView.text.parentNode.replaceChild(lineView.node, lineView.text); }
      lineView.node.appendChild(lineView.text);
      if (ie && ie_version < 8) { lineView.node.style.zIndex = 2; }
    }
    return lineView.node
  }

  function updateLineBackground(cm, lineView) {
    var cls = lineView.bgClass ? lineView.bgClass + " " + (lineView.line.bgClass || "") : lineView.line.bgClass;
    if (cls) { cls += " CodeMirror-linebackground"; }
    if (lineView.background) {
      if (cls) { lineView.background.className = cls; }
      else { lineView.background.parentNode.removeChild(lineView.background); lineView.background = null; }
    } else if (cls) {
      var wrap = ensureLineWrapped(lineView);
      lineView.background = wrap.insertBefore(elt("div", null, cls), wrap.firstChild);
      cm.display.input.setUneditable(lineView.background);
    }
  }

  // Wrapper around buildLineContent which will reuse the structure
  // in display.externalMeasured when possible.
  function getLineContent(cm, lineView) {
    var ext = cm.display.externalMeasured;
    if (ext && ext.line == lineView.line) {
      cm.display.externalMeasured = null;
      lineView.measure = ext.measure;
      return ext.built
    }
    return buildLineContent(cm, lineView)
  }

  // Redraw the line's text. Interacts with the background and text
  // classes because the mode may output tokens that influence these
  // classes.
  function updateLineText(cm, lineView) {
    var cls = lineView.text.className;
    var built = getLineContent(cm, lineView);
    if (lineView.text == lineView.node) { lineView.node = built.pre; }
    lineView.text.parentNode.replaceChild(built.pre, lineView.text);
    lineView.text = built.pre;
    if (built.bgClass != lineView.bgClass || built.textClass != lineView.textClass) {
      lineView.bgClass = built.bgClass;
      lineView.textClass = built.textClass;
      updateLineClasses(cm, lineView);
    } else if (cls) {
      lineView.text.className = cls;
    }
  }

  function updateLineClasses(cm, lineView) {
    updateLineBackground(cm, lineView);
    if (lineView.line.wrapClass)
      { ensureLineWrapped(lineView).className = lineView.line.wrapClass; }
    else if (lineView.node != lineView.text)
      { lineView.node.className = ""; }
    var textClass = lineView.textClass ? lineView.textClass + " " + (lineView.line.textClass || "") : lineView.line.textClass;
    lineView.text.className = textClass || "";
  }

  function updateLineGutter(cm, lineView, lineN, dims) {
    if (lineView.gutter) {
      lineView.node.removeChild(lineView.gutter);
      lineView.gutter = null;
    }
    if (lineView.gutterBackground) {
      lineView.node.removeChild(lineView.gutterBackground);
      lineView.gutterBackground = null;
    }
    if (lineView.line.gutterClass) {
      var wrap = ensureLineWrapped(lineView);
      lineView.gutterBackground = elt("div", null, "CodeMirror-gutter-background " + lineView.line.gutterClass,
                                      ("left: " + (cm.options.fixedGutter ? dims.fixedPos : -dims.gutterTotalWidth) + "px; width: " + (dims.gutterTotalWidth) + "px"));
      cm.display.input.setUneditable(lineView.gutterBackground);
      wrap.insertBefore(lineView.gutterBackground, lineView.text);
    }
    var markers = lineView.line.gutterMarkers;
    if (cm.options.lineNumbers || markers) {
      var wrap$1 = ensureLineWrapped(lineView);
      var gutterWrap = lineView.gutter = elt("div", null, "CodeMirror-gutter-wrapper", ("left: " + (cm.options.fixedGutter ? dims.fixedPos : -dims.gutterTotalWidth) + "px"));
      gutterWrap.setAttribute("aria-hidden", "true");
      cm.display.input.setUneditable(gutterWrap);
      wrap$1.insertBefore(gutterWrap, lineView.text);
      if (lineView.line.gutterClass)
        { gutterWrap.className += " " + lineView.line.gutterClass; }
      if (cm.options.lineNumbers && (!markers || !markers["CodeMirror-linenumbers"]))
        { lineView.lineNumber = gutterWrap.appendChild(
          elt("div", lineNumberFor(cm.options, lineN),
              "CodeMirror-linenumber CodeMirror-gutter-elt",
              ("left: " + (dims.gutterLeft["CodeMirror-linenumbers"]) + "px; width: " + (cm.display.lineNumInnerWidth) + "px"))); }
      if (markers) { for (var k = 0; k < cm.display.gutterSpecs.length; ++k) {
        var id = cm.display.gutterSpecs[k].className, found = markers.hasOwnProperty(id) && markers[id];
        if (found)
          { gutterWrap.appendChild(elt("div", [found], "CodeMirror-gutter-elt",
                                     ("left: " + (dims.gutterLeft[id]) + "px; width: " + (dims.gutterWidth[id]) + "px"))); }
      } }
    }
  }

  function updateLineWidgets(cm, lineView, dims) {
    if (lineView.alignable) { lineView.alignable = null; }
    var isWidget = classTest("CodeMirror-linewidget");
    for (var node = lineView.node.firstChild, next = (void 0); node; node = next) {
      next = node.nextSibling;
      if (isWidget.test(node.className)) { lineView.node.removeChild(node); }
    }
    insertLineWidgets(cm, lineView, dims);
  }

  // Build a line's DOM representation from scratch
  function buildLineElement(cm, lineView, lineN, dims) {
    var built = getLineContent(cm, lineView);
    lineView.text = lineView.node = built.pre;
    if (built.bgClass) { lineView.bgClass = built.bgClass; }
    if (built.textClass) { lineView.textClass = built.textClass; }

    updateLineClasses(cm, lineView);
    updateLineGutter(cm, lineView, lineN, dims);
    insertLineWidgets(cm, lineView, dims);
    return lineView.node
  }

  // A lineView may contain multiple logical lines (when merged by
  // collapsed spans). The widgets for all of them need to be drawn.
  function insertLineWidgets(cm, lineView, dims) {
    insertLineWidgetsFor(cm, lineView.line, lineView, dims, true);
    if (lineView.rest) { for (var i = 0; i < lineView.rest.length; i++)
      { insertLineWidgetsFor(cm, lineView.rest[i], lineView, dims, false); } }
  }

  function insertLineWidgetsFor(cm, line, lineView, dims, allowAbove) {
    if (!line.widgets) { return }
    var wrap = ensureLineWrapped(lineView);
    for (var i = 0, ws = line.widgets; i < ws.length; ++i) {
      var widget = ws[i], node = elt("div", [widget.node], "CodeMirror-linewidget" + (widget.className ? " " + widget.className : ""));
      if (!widget.handleMouseEvents) { node.setAttribute("cm-ignore-events", "true"); }
      positionLineWidget(widget, node, lineView, dims);
      cm.display.input.setUneditable(node);
      if (allowAbove && widget.above)
        { wrap.insertBefore(node, lineView.gutter || lineView.text); }
      else
        { wrap.appendChild(node); }
      signalLater(widget, "redraw");
    }
  }

  function positionLineWidget(widget, node, lineView, dims) {
    if (widget.noHScroll) {
  (lineView.alignable || (lineView.alignable = [])).push(node);
      var width = dims.wrapperWidth;
      node.style.left = dims.fixedPos + "px";
      if (!widget.coverGutter) {
        width -= dims.gutterTotalWidth;
        node.style.paddingLeft = dims.gutterTotalWidth + "px";
      }
      node.style.width = width + "px";
    }
    if (widget.coverGutter) {
      node.style.zIndex = 5;
      node.style.position = "relative";
      if (!widget.noHScroll) { node.style.marginLeft = -dims.gutterTotalWidth + "px"; }
    }
  }

  function widgetHeight(widget) {
    if (widget.height != null) { return widget.height }
    var cm = widget.doc.cm;
    if (!cm) { return 0 }
    if (!contains(document.body, widget.node)) {
      var parentStyle = "position: relative;";
      if (widget.coverGutter)
        { parentStyle += "margin-left: -" + cm.display.gutters.offsetWidth + "px;"; }
      if (widget.noHScroll)
        { parentStyle += "width: " + cm.display.wrapper.clientWidth + "px;"; }
      removeChildrenAndAdd(cm.display.measure, elt("div", [widget.node], null, parentStyle));
    }
    return widget.height = widget.node.parentNode.offsetHeight
  }

  // Return true when the given mouse event happened in a widget
  function eventInWidget(display, e) {
    for (var n = e_target(e); n != display.wrapper; n = n.parentNode) {
      if (!n || (n.nodeType == 1 && n.getAttribute("cm-ignore-events") == "true") ||
          (n.parentNode == display.sizer && n != display.mover))
        { return true }
    }
  }

  // POSITION MEASUREMENT

  function paddingTop(display) {return display.lineSpace.offsetTop}
  function paddingVert(display) {return display.mover.offsetHeight - display.lineSpace.offsetHeight}
  function paddingH(display) {
    if (display.cachedPaddingH) { return display.cachedPaddingH }
    var e = removeChildrenAndAdd(display.measure, elt("pre", "x", "CodeMirror-line-like"));
    var style = window.getComputedStyle ? window.getComputedStyle(e) : e.currentStyle;
    var data = {left: parseInt(style.paddingLeft), right: parseInt(style.paddingRight)};
    if (!isNaN(data.left) && !isNaN(data.right)) { display.cachedPaddingH = data; }
    return data
  }

  function scrollGap(cm) { return scrollerGap - cm.display.nativeBarWidth }
  function displayWidth(cm) {
    return cm.display.scroller.clientWidth - scrollGap(cm) - cm.display.barWidth
  }
  function displayHeight(cm) {
    return cm.display.scroller.clientHeight - scrollGap(cm) - cm.display.barHeight
  }

  // Ensure the lineView.wrapping.heights array is populated. This is
  // an array of bottom offsets for the lines that make up a drawn
  // line. When lineWrapping is on, there might be more than one
  // height.
  function ensureLineHeights(cm, lineView, rect) {
    var wrapping = cm.options.lineWrapping;
    var curWidth = wrapping && displayWidth(cm);
    if (!lineView.measure.heights || wrapping && lineView.measure.width != curWidth) {
      var heights = lineView.measure.heights = [];
      if (wrapping) {
        lineView.measure.width = curWidth;
        var rects = lineView.text.firstChild.getClientRects();
        for (var i = 0; i < rects.length - 1; i++) {
          var cur = rects[i], next = rects[i + 1];
          if (Math.abs(cur.bottom - next.bottom) > 2)
            { heights.push((cur.bottom + next.top) / 2 - rect.top); }
        }
      }
      heights.push(rect.bottom - rect.top);
    }
  }

  // Find a line map (mapping character offsets to text nodes) and a
  // measurement cache for the given line number. (A line view might
  // contain multiple lines when collapsed ranges are present.)
  function mapFromLineView(lineView, line, lineN) {
    if (lineView.line == line)
      { return {map: lineView.measure.map, cache: lineView.measure.cache} }
    if (lineView.rest) {
      for (var i = 0; i < lineView.rest.length; i++)
        { if (lineView.rest[i] == line)
          { return {map: lineView.measure.maps[i], cache: lineView.measure.caches[i]} } }
      for (var i$1 = 0; i$1 < lineView.rest.length; i$1++)
        { if (lineNo(lineView.rest[i$1]) > lineN)
          { return {map: lineView.measure.maps[i$1], cache: lineView.measure.caches[i$1], before: true} } }
    }
  }

  // Render a line into the hidden node display.externalMeasured. Used
  // when measurement is needed for a line that's not in the viewport.
  function updateExternalMeasurement(cm, line) {
    line = visualLine(line);
    var lineN = lineNo(line);
    var view = cm.display.externalMeasured = new LineView(cm.doc, line, lineN);
    view.lineN = lineN;
    var built = view.built = buildLineContent(cm, view);
    view.text = built.pre;
    removeChildrenAndAdd(cm.display.lineMeasure, built.pre);
    return view
  }

  // Get a {top, bottom, left, right} box (in line-local coordinates)
  // for a given character.
  function measureChar(cm, line, ch, bias) {
    return measureCharPrepared(cm, prepareMeasureForLine(cm, line), ch, bias)
  }

  // Find a line view that corresponds to the given line number.
  function findViewForLine(cm, lineN) {
    if (lineN >= cm.display.viewFrom && lineN < cm.display.viewTo)
      { return cm.display.view[findViewIndex(cm, lineN)] }
    var ext = cm.display.externalMeasured;
    if (ext && lineN >= ext.lineN && lineN < ext.lineN + ext.size)
      { return ext }
  }

  // Measurement can be split in two steps, the set-up work that
  // applies to the whole line, and the measurement of the actual
  // character. Functions like coordsChar, that need to do a lot of
  // measurements in a row, can thus ensure that the set-up work is
  // only done once.
  function prepareMeasureForLine(cm, line) {
    var lineN = lineNo(line);
    var view = findViewForLine(cm, lineN);
    if (view && !view.text) {
      view = null;
    } else if (view && view.changes) {
      updateLineForChanges(cm, view, lineN, getDimensions(cm));
      cm.curOp.forceUpdate = true;
    }
    if (!view)
      { view = updateExternalMeasurement(cm, line); }

    var info = mapFromLineView(view, line, lineN);
    return {
      line: line, view: view, rect: null,
      map: info.map, cache: info.cache, before: info.before,
      hasHeights: false
    }
  }

  // Given a prepared measurement object, measures the position of an
  // actual character (or fetches it from the cache).
  function measureCharPrepared(cm, prepared, ch, bias, varHeight) {
    if (prepared.before) { ch = -1; }
    var key = ch + (bias || ""), found;
    if (prepared.cache.hasOwnProperty(key)) {
      found = prepared.cache[key];
    } else {
      if (!prepared.rect)
        { prepared.rect = prepared.view.text.getBoundingClientRect(); }
      if (!prepared.hasHeights) {
        ensureLineHeights(cm, prepared.view, prepared.rect);
        prepared.hasHeights = true;
      }
      found = measureCharInner(cm, prepared, ch, bias);
      if (!found.bogus) { prepared.cache[key] = found; }
    }
    return {left: found.left, right: found.right,
            top: varHeight ? found.rtop : found.top,
            bottom: varHeight ? found.rbottom : found.bottom}
  }

  var nullRect = {left: 0, right: 0, top: 0, bottom: 0};

  function nodeAndOffsetInLineMap(map, ch, bias) {
    var node, start, end, collapse, mStart, mEnd;
    // First, search the line map for the text node corresponding to,
    // or closest to, the target character.
    for (var i = 0; i < map.length; i += 3) {
      mStart = map[i];
      mEnd = map[i + 1];
      if (ch < mStart) {
        start = 0; end = 1;
        collapse = "left";
      } else if (ch < mEnd) {
        start = ch - mStart;
        end = start + 1;
      } else if (i == map.length - 3 || ch == mEnd && map[i + 3] > ch) {
        end = mEnd - mStart;
        start = end - 1;
        if (ch >= mEnd) { collapse = "right"; }
      }
      if (start != null) {
        node = map[i + 2];
        if (mStart == mEnd && bias == (node.insertLeft ? "left" : "right"))
          { collapse = bias; }
        if (bias == "left" && start == 0)
          { while (i && map[i - 2] == map[i - 3] && map[i - 1].insertLeft) {
            node = map[(i -= 3) + 2];
            collapse = "left";
          } }
        if (bias == "right" && start == mEnd - mStart)
          { while (i < map.length - 3 && map[i + 3] == map[i + 4] && !map[i + 5].insertLeft) {
            node = map[(i += 3) + 2];
            collapse = "right";
          } }
        break
      }
    }
    return {node: node, start: start, end: end, collapse: collapse, coverStart: mStart, coverEnd: mEnd}
  }

  function getUsefulRect(rects, bias) {
    var rect = nullRect;
    if (bias == "left") { for (var i = 0; i < rects.length; i++) {
      if ((rect = rects[i]).left != rect.right) { break }
    } } else { for (var i$1 = rects.length - 1; i$1 >= 0; i$1--) {
      if ((rect = rects[i$1]).left != rect.right) { break }
    } }
    return rect
  }

  function measureCharInner(cm, prepared, ch, bias) {
    var place = nodeAndOffsetInLineMap(prepared.map, ch, bias);
    var node = place.node, start = place.start, end = place.end, collapse = place.collapse;

    var rect;
    if (node.nodeType == 3) { // If it is a text node, use a range to retrieve the coordinates.
      for (var i$1 = 0; i$1 < 4; i$1++) { // Retry a maximum of 4 times when nonsense rectangles are returned
        while (start && isExtendingChar(prepared.line.text.charAt(place.coverStart + start))) { --start; }
        while (place.coverStart + end < place.coverEnd && isExtendingChar(prepared.line.text.charAt(place.coverStart + end))) { ++end; }
        if (ie && ie_version < 9 && start == 0 && end == place.coverEnd - place.coverStart)
          { rect = node.parentNode.getBoundingClientRect(); }
        else
          { rect = getUsefulRect(range(node, start, end).getClientRects(), bias); }
        if (rect.left || rect.right || start == 0) { break }
        end = start;
        start = start - 1;
        collapse = "right";
      }
      if (ie && ie_version < 11) { rect = maybeUpdateRectForZooming(cm.display.measure, rect); }
    } else { // If it is a widget, simply get the box for the whole widget.
      if (start > 0) { collapse = bias = "right"; }
      var rects;
      if (cm.options.lineWrapping && (rects = node.getClientRects()).length > 1)
        { rect = rects[bias == "right" ? rects.length - 1 : 0]; }
      else
        { rect = node.getBoundingClientRect(); }
    }
    if (ie && ie_version < 9 && !start && (!rect || !rect.left && !rect.right)) {
      var rSpan = node.parentNode.getClientRects()[0];
      if (rSpan)
        { rect = {left: rSpan.left, right: rSpan.left + charWidth(cm.display), top: rSpan.top, bottom: rSpan.bottom}; }
      else
        { rect = nullRect; }
    }

    var rtop = rect.top - prepared.rect.top, rbot = rect.bottom - prepared.rect.top;
    var mid = (rtop + rbot) / 2;
    var heights = prepared.view.measure.heights;
    var i = 0;
    for (; i < heights.length - 1; i++)
      { if (mid < heights[i]) { break } }
    var top = i ? heights[i - 1] : 0, bot = heights[i];
    var result = {left: (collapse == "right" ? rect.right : rect.left) - prepared.rect.left,
                  right: (collapse == "left" ? rect.left : rect.right) - prepared.rect.left,
                  top: top, bottom: bot};
    if (!rect.left && !rect.right) { result.bogus = true; }
    if (!cm.options.singleCursorHeightPerLine) { result.rtop = rtop; result.rbottom = rbot; }

    return result
  }

  // Work around problem with bounding client rects on ranges being
  // returned incorrectly when zoomed on IE10 and below.
  function maybeUpdateRectForZooming(measure, rect) {
    if (!window.screen || screen.logicalXDPI == null ||
        screen.logicalXDPI == screen.deviceXDPI || !hasBadZoomedRects(measure))
      { return rect }
    var scaleX = screen.logicalXDPI / screen.deviceXDPI;
    var scaleY = screen.logicalYDPI / screen.deviceYDPI;
    return {left: rect.left * scaleX, right: rect.right * scaleX,
            top: rect.top * scaleY, bottom: rect.bottom * scaleY}
  }

  function clearLineMeasurementCacheFor(lineView) {
    if (lineView.measure) {
      lineView.measure.cache = {};
      lineView.measure.heights = null;
      if (lineView.rest) { for (var i = 0; i < lineView.rest.length; i++)
        { lineView.measure.caches[i] = {}; } }
    }
  }

  function clearLineMeasurementCache(cm) {
    cm.display.externalMeasure = null;
    removeChildren(cm.display.lineMeasure);
    for (var i = 0; i < cm.display.view.length; i++)
      { clearLineMeasurementCacheFor(cm.display.view[i]); }
  }

  function clearCaches(cm) {
    clearLineMeasurementCache(cm);
    cm.display.cachedCharWidth = cm.display.cachedTextHeight = cm.display.cachedPaddingH = null;
    if (!cm.options.lineWrapping) { cm.display.maxLineChanged = true; }
    cm.display.lineNumChars = null;
  }

  function pageScrollX() {
    // Work around https://bugs.chromium.org/p/chromium/issues/detail?id=489206
    // which causes page_Offset and bounding client rects to use
    // different reference viewports and invalidate our calculations.
    if (chrome && android) { return -(document.body.getBoundingClientRect().left - parseInt(getComputedStyle(document.body).marginLeft)) }
    return window.pageXOffset || (document.documentElement || document.body).scrollLeft
  }
  function pageScrollY() {
    if (chrome && android) { return -(document.body.getBoundingClientRect().top - parseInt(getComputedStyle(document.body).marginTop)) }
    return window.pageYOffset || (document.documentElement || document.body).scrollTop
  }

  function widgetTopHeight(lineObj) {
    var ref = visualLine(lineObj);
    var widgets = ref.widgets;
    var height = 0;
    if (widgets) { for (var i = 0; i < widgets.length; ++i) { if (widgets[i].above)
      { height += widgetHeight(widgets[i]); } } }
    return height
  }

  // Converts a {top, bottom, left, right} box from line-local
  // coordinates into another coordinate system. Context may be one of
  // "line", "div" (display.lineDiv), "local"./null (editor), "window",
  // or "page".
  function intoCoordSystem(cm, lineObj, rect, context, includeWidgets) {
    if (!includeWidgets) {
      var height = widgetTopHeight(lineObj);
      rect.top += height; rect.bottom += height;
    }
    if (context == "line") { return rect }
    if (!context) { context = "local"; }
    var yOff = heightAtLine(lineObj);
    if (context == "local") { yOff += paddingTop(cm.display); }
    else { yOff -= cm.display.viewOffset; }
    if (context == "page" || context == "window") {
      var lOff = cm.display.lineSpace.getBoundingClientRect();
      yOff += lOff.top + (context == "window" ? 0 : pageScrollY());
      var xOff = lOff.left + (context == "window" ? 0 : pageScrollX());
      rect.left += xOff; rect.right += xOff;
    }
    rect.top += yOff; rect.bottom += yOff;
    return rect
  }

  // Coverts a box from "div" coords to another coordinate system.
  // Context may be "window", "page", "div", or "local"./null.
  function fromCoordSystem(cm, coords, context) {
    if (context == "div") { return coords }
    var left = coords.left, top = coords.top;
    // First move into "page" coordinate system
    if (context == "page") {
      left -= pageScrollX();
      top -= pageScrollY();
    } else if (context == "local" || !context) {
      var localBox = cm.display.sizer.getBoundingClientRect();
      left += localBox.left;
      top += localBox.top;
    }

    var lineSpaceBox = cm.display.lineSpace.getBoundingClientRect();
    return {left: left - lineSpaceBox.left, top: top - lineSpaceBox.top}
  }

  function charCoords(cm, pos, context, lineObj, bias) {
    if (!lineObj) { lineObj = getLine(cm.doc, pos.line); }
    return intoCoordSystem(cm, lineObj, measureChar(cm, lineObj, pos.ch, bias), context)
  }

  // Returns a box for a given cursor position, which may have an
  // 'other' property containing the position of the secondary cursor
  // on a bidi boundary.
  // A cursor Pos(line, char, "before") is on the same visual line as `char - 1`
  // and after `char - 1` in writing order of `char - 1`
  // A cursor Pos(line, char, "after") is on the same visual line as `char`
  // and before `char` in writing order of `char`
  // Examples (upper-case letters are RTL, lower-case are LTR):
  //     Pos(0, 1, ...)
  //     before   after
  // ab     a|b     a|b
  // aB     a|B     aB|
  // Ab     |Ab     A|b
  // AB     B|A     B|A
  // Every position after the last character on a line is considered to stick
  // to the last character on the line.
  function cursorCoords(cm, pos, context, lineObj, preparedMeasure, varHeight) {
    lineObj = lineObj || getLine(cm.doc, pos.line);
    if (!preparedMeasure) { preparedMeasure = prepareMeasureForLine(cm, lineObj); }
    function get(ch, right) {
      var m = measureCharPrepared(cm, preparedMeasure, ch, right ? "right" : "left", varHeight);
      if (right) { m.left = m.right; } else { m.right = m.left; }
      return intoCoordSystem(cm, lineObj, m, context)
    }
    var order = getOrder(lineObj, cm.doc.direction), ch = pos.ch, sticky = pos.sticky;
    if (ch >= lineObj.text.length) {
      ch = lineObj.text.length;
      sticky = "before";
    } else if (ch <= 0) {
      ch = 0;
      sticky = "after";
    }
    if (!order) { return get(sticky == "before" ? ch - 1 : ch, sticky == "before") }

    function getBidi(ch, partPos, invert) {
      var part = order[partPos], right = part.level == 1;
      return get(invert ? ch - 1 : ch, right != invert)
    }
    var partPos = getBidiPartAt(order, ch, sticky);
    var other = bidiOther;
    var val = getBidi(ch, partPos, sticky == "before");
    if (other != null) { val.other = getBidi(ch, other, sticky != "before"); }
    return val
  }

  // Used to cheaply estimate the coordinates for a position. Used for
  // intermediate scroll updates.
  function estimateCoords(cm, pos) {
    var left = 0;
    pos = clipPos(cm.doc, pos);
    if (!cm.options.lineWrapping) { left = charWidth(cm.display) * pos.ch; }
    var lineObj = getLine(cm.doc, pos.line);
    var top = heightAtLine(lineObj) + paddingTop(cm.display);
    return {left: left, right: left, top: top, bottom: top + lineObj.height}
  }

  // Positions returned by coordsChar contain some extra information.
  // xRel is the relative x position of the input coordinates compared
  // to the found position (so xRel > 0 means the coordinates are to
  // the right of the character position, for example). When outside
  // is true, that means the coordinates lie outside the line's
  // vertical range.
  function PosWithInfo(line, ch, sticky, outside, xRel) {
    var pos = Pos(line, ch, sticky);
    pos.xRel = xRel;
    if (outside) { pos.outside = outside; }
    return pos
  }

  // Compute the character position closest to the given coordinates.
  // Input must be lineSpace-local ("div" coordinate system).
  function coordsChar(cm, x, y) {
    var doc = cm.doc;
    y += cm.display.viewOffset;
    if (y < 0) { return PosWithInfo(doc.first, 0, null, -1, -1) }
    var lineN = lineAtHeight(doc, y), last = doc.first + doc.size - 1;
    if (lineN > last)
      { return PosWithInfo(doc.first + doc.size - 1, getLine(doc, last).text.length, null, 1, 1) }
    if (x < 0) { x = 0; }

    var lineObj = getLine(doc, lineN);
    for (;;) {
      var found = coordsCharInner(cm, lineObj, lineN, x, y);
      var collapsed = collapsedSpanAround(lineObj, found.ch + (found.xRel > 0 || found.outside > 0 ? 1 : 0));
      if (!collapsed) { return found }
      var rangeEnd = collapsed.find(1);
      if (rangeEnd.line == lineN) { return rangeEnd }
      lineObj = getLine(doc, lineN = rangeEnd.line);
    }
  }

  function wrappedLineExtent(cm, lineObj, preparedMeasure, y) {
    y -= widgetTopHeight(lineObj);
    var end = lineObj.text.length;
    var begin = findFirst(function (ch) { return measureCharPrepared(cm, preparedMeasure, ch - 1).bottom <= y; }, end, 0);
    end = findFirst(function (ch) { return measureCharPrepared(cm, preparedMeasure, ch).top > y; }, begin, end);
    return {begin: begin, end: end}
  }

  function wrappedLineExtentChar(cm, lineObj, preparedMeasure, target) {
    if (!preparedMeasure) { preparedMeasure = prepareMeasureForLine(cm, lineObj); }
    var targetTop = intoCoordSystem(cm, lineObj, measureCharPrepared(cm, preparedMeasure, target), "line").top;
    return wrappedLineExtent(cm, lineObj, preparedMeasure, targetTop)
  }

  // Returns true if the given side of a box is after the given
  // coordinates, in top-to-bottom, left-to-right order.
  function boxIsAfter(box, x, y, left) {
    return box.bottom <= y ? false : box.top > y ? true : (left ? box.left : box.right) > x
  }

  function coordsCharInner(cm, lineObj, lineNo, x, y) {
    // Move y into line-local coordinate space
    y -= heightAtLine(lineObj);
    var preparedMeasure = prepareMeasureForLine(cm, lineObj);
    // When directly calling `measureCharPrepared`, we have to adjust
    // for the widgets at this line.
    var widgetHeight = widgetTopHeight(lineObj);
    var begin = 0, end = lineObj.text.length, ltr = true;

    var order = getOrder(lineObj, cm.doc.direction);
    // If the line isn't plain left-to-right text, first figure out
    // which bidi section the coordinates fall into.
    if (order) {
      var part = (cm.options.lineWrapping ? coordsBidiPartWrapped : coordsBidiPart)
                   (cm, lineObj, lineNo, preparedMeasure, order, x, y);
      ltr = part.level != 1;
      // The awkward -1 offsets are needed because findFirst (called
      // on these below) will treat its first bound as inclusive,
      // second as exclusive, but we want to actually address the
      // characters in the part's range
      begin = ltr ? part.from : part.to - 1;
      end = ltr ? part.to : part.from - 1;
    }

    // A binary search to find the first character whose bounding box
    // starts after the coordinates. If we run across any whose box wrap
    // the coordinates, store that.
    var chAround = null, boxAround = null;
    var ch = findFirst(function (ch) {
      var box = measureCharPrepared(cm, preparedMeasure, ch);
      box.top += widgetHeight; box.bottom += widgetHeight;
      if (!boxIsAfter(box, x, y, false)) { return false }
      if (box.top <= y && box.left <= x) {
        chAround = ch;
        boxAround = box;
      }
      return true
    }, begin, end);

    var baseX, sticky, outside = false;
    // If a box around the coordinates was found, use that
    if (boxAround) {
      // Distinguish coordinates nearer to the left or right side of the box
      var atLeft = x - boxAround.left < boxAround.right - x, atStart = atLeft == ltr;
      ch = chAround + (atStart ? 0 : 1);
      sticky = atStart ? "after" : "before";
      baseX = atLeft ? boxAround.left : boxAround.right;
    } else {
      // (Adjust for extended bound, if necessary.)
      if (!ltr && (ch == end || ch == begin)) { ch++; }
      // To determine which side to associate with, get the box to the
      // left of the character and compare it's vertical position to the
      // coordinates
      sticky = ch == 0 ? "after" : ch == lineObj.text.length ? "before" :
        (measureCharPrepared(cm, preparedMeasure, ch - (ltr ? 1 : 0)).bottom + widgetHeight <= y) == ltr ?
        "after" : "before";
      // Now get accurate coordinates for this place, in order to get a
      // base X position
      var coords = cursorCoords(cm, Pos(lineNo, ch, sticky), "line", lineObj, preparedMeasure);
      baseX = coords.left;
      outside = y < coords.top ? -1 : y >= coords.bottom ? 1 : 0;
    }

    ch = skipExtendingChars(lineObj.text, ch, 1);
    return PosWithInfo(lineNo, ch, sticky, outside, x - baseX)
  }

  function coordsBidiPart(cm, lineObj, lineNo, preparedMeasure, order, x, y) {
    // Bidi parts are sorted left-to-right, and in a non-line-wrapping
    // situation, we can take this ordering to correspond to the visual
    // ordering. This finds the first part whose end is after the given
    // coordinates.
    var index = findFirst(function (i) {
      var part = order[i], ltr = part.level != 1;
      return boxIsAfter(cursorCoords(cm, Pos(lineNo, ltr ? part.to : part.from, ltr ? "before" : "after"),
                                     "line", lineObj, preparedMeasure), x, y, true)
    }, 0, order.length - 1);
    var part = order[index];
    // If this isn't the first part, the part's start is also after
    // the coordinates, and the coordinates aren't on the same line as
    // that start, move one part back.
    if (index > 0) {
      var ltr = part.level != 1;
      var start = cursorCoords(cm, Pos(lineNo, ltr ? part.from : part.to, ltr ? "after" : "before"),
                               "line", lineObj, preparedMeasure);
      if (boxIsAfter(start, x, y, true) && start.top > y)
        { part = order[index - 1]; }
    }
    return part
  }

  function coordsBidiPartWrapped(cm, lineObj, _lineNo, preparedMeasure, order, x, y) {
    // In a wrapped line, rtl text on wrapping boundaries can do things
    // that don't correspond to the ordering in our `order` array at
    // all, so a binary search doesn't work, and we want to return a
    // part that only spans one line so that the binary search in
    // coordsCharInner is safe. As such, we first find the extent of the
    // wrapped line, and then do a flat search in which we discard any
    // spans that aren't on the line.
    var ref = wrappedLineExtent(cm, lineObj, preparedMeasure, y);
    var begin = ref.begin;
    var end = ref.end;
    if (/\s/.test(lineObj.text.charAt(end - 1))) { end--; }
    var part = null, closestDist = null;
    for (var i = 0; i < order.length; i++) {
      var p = order[i];
      if (p.from >= end || p.to <= begin) { continue }
      var ltr = p.level != 1;
      var endX = measureCharPrepared(cm, preparedMeasure, ltr ? Math.min(end, p.to) - 1 : Math.max(begin, p.from)).right;
      // Weigh against spans ending before this, so that they are only
      // picked if nothing ends after
      var dist = endX < x ? x - endX + 1e9 : endX - x;
      if (!part || closestDist > dist) {
        part = p;
        closestDist = dist;
      }
    }
    if (!part) { part = order[order.length - 1]; }
    // Clip the part to the wrapped line.
    if (part.from < begin) { part = {from: begin, to: part.to, level: part.level}; }
    if (part.to > end) { part = {from: part.from, to: end, level: part.level}; }
    return part
  }

  var measureText;
  // Compute the default text height.
  function textHeight(display) {
    if (display.cachedTextHeight != null) { return display.cachedTextHeight }
    if (measureText == null) {
      measureText = elt("pre", null, "CodeMirror-line-like");
      // Measure a bunch of lines, for browsers that compute
      // fractional heights.
      for (var i = 0; i < 49; ++i) {
        measureText.appendChild(document.createTextNode("x"));
        measureText.appendChild(elt("br"));
      }
      measureText.appendChild(document.createTextNode("x"));
    }
    removeChildrenAndAdd(display.measure, measureText);
    var height = measureText.offsetHeight / 50;
    if (height > 3) { display.cachedTextHeight = height; }
    removeChildren(display.measure);
    return height || 1
  }

  // Compute the default character width.
  function charWidth(display) {
    if (display.cachedCharWidth != null) { return display.cachedCharWidth }
    var anchor = elt("span", "xxxxxxxxxx");
    var pre = elt("pre", [anchor], "CodeMirror-line-like");
    removeChildrenAndAdd(display.measure, pre);
    var rect = anchor.getBoundingClientRect(), width = (rect.right - rect.left) / 10;
    if (width > 2) { display.cachedCharWidth = width; }
    return width || 10
  }

  // Do a bulk-read of the DOM positions and sizes needed to draw the
  // view, so that we don't interleave reading and writing to the DOM.
  function getDimensions(cm) {
    var d = cm.display, left = {}, width = {};
    var gutterLeft = d.gutters.clientLeft;
    for (var n = d.gutters.firstChild, i = 0; n; n = n.nextSibling, ++i) {
      var id = cm.display.gutterSpecs[i].className;
      left[id] = n.offsetLeft + n.clientLeft + gutterLeft;
      width[id] = n.clientWidth;
    }
    return {fixedPos: compensateForHScroll(d),
            gutterTotalWidth: d.gutters.offsetWidth,
            gutterLeft: left,
            gutterWidth: width,
            wrapperWidth: d.wrapper.clientWidth}
  }

  // Computes display.scroller.scrollLeft + display.gutters.offsetWidth,
  // but using getBoundingClientRect to get a sub-pixel-accurate
  // result.
  function compensateForHScroll(display) {
    return display.scroller.getBoundingClientRect().left - display.sizer.getBoundingClientRect().left
  }

  // Returns a function that estimates the height of a line, to use as
  // first approximation until the line becomes visible (and is thus
  // properly measurable).
  function estimateHeight(cm) {
    var th = textHeight(cm.display), wrapping = cm.options.lineWrapping;
    var perLine = wrapping && Math.max(5, cm.display.scroller.clientWidth / charWidth(cm.display) - 3);
    return function (line) {
      if (lineIsHidden(cm.doc, line)) { return 0 }

      var widgetsHeight = 0;
      if (line.widgets) { for (var i = 0; i < line.widgets.length; i++) {
        if (line.widgets[i].height) { widgetsHeight += line.widgets[i].height; }
      } }

      if (wrapping)
        { return widgetsHeight + (Math.ceil(line.text.length / perLine) || 1) * th }
      else
        { return widgetsHeight + th }
    }
  }

  function estimateLineHeights(cm) {
    var doc = cm.doc, est = estimateHeight(cm);
    doc.iter(function (line) {
      var estHeight = est(line);
      if (estHeight != line.height) { updateLineHeight(line, estHeight); }
    });
  }

  // Given a mouse event, find the corresponding position. If liberal
  // is false, it checks whether a gutter or scrollbar was clicked,
  // and returns null if it was. forRect is used by rectangular
  // selections, and tries to estimate a character position even for
  // coordinates beyond the right of the text.
  function posFromMouse(cm, e, liberal, forRect) {
    var display = cm.display;
    if (!liberal && e_target(e).getAttribute("cm-not-content") == "true") { return null }

    var x, y, space = display.lineSpace.getBoundingClientRect();
    // Fails unpredictably on IE[67] when mouse is dragged around quickly.
    try { x = e.clientX - space.left; y = e.clientY - space.top; }
    catch (e$1) { return null }
    var coords = coordsChar(cm, x, y), line;
    if (forRect && coords.xRel > 0 && (line = getLine(cm.doc, coords.line).text).length == coords.ch) {
      var colDiff = countColumn(line, line.length, cm.options.tabSize) - line.length;
      coords = Pos(coords.line, Math.max(0, Math.round((x - paddingH(cm.display).left) / charWidth(cm.display)) - colDiff));
    }
    return coords
  }

  // Find the view element corresponding to a given line. Return null
  // when the line isn't visible.
  function findViewIndex(cm, n) {
    if (n >= cm.display.viewTo) { return null }
    n -= cm.display.viewFrom;
    if (n < 0) { return null }
    var view = cm.display.view;
    for (var i = 0; i < view.length; i++) {
      n -= view[i].size;
      if (n < 0) { return i }
    }
  }

  // Updates the display.view data structure for a given change to the
  // document. From and to are in pre-change coordinates. Lendiff is
  // the amount of lines added or subtracted by the change. This is
  // used for changes that span multiple lines, or change the way
  // lines are divided into visual lines. regLineChange (below)
  // registers single-line changes.
  function regChange(cm, from, to, lendiff) {
    if (from == null) { from = cm.doc.first; }
    if (to == null) { to = cm.doc.first + cm.doc.size; }
    if (!lendiff) { lendiff = 0; }

    var display = cm.display;
    if (lendiff && to < display.viewTo &&
        (display.updateLineNumbers == null || display.updateLineNumbers > from))
      { display.updateLineNumbers = from; }

    cm.curOp.viewChanged = true;

    if (from >= display.viewTo) { // Change after
      if (sawCollapsedSpans && visualLineNo(cm.doc, from) < display.viewTo)
        { resetView(cm); }
    } else if (to <= display.viewFrom) { // Change before
      if (sawCollapsedSpans && visualLineEndNo(cm.doc, to + lendiff) > display.viewFrom) {
        resetView(cm);
      } else {
        display.viewFrom += lendiff;
        display.viewTo += lendiff;
      }
    } else if (from <= display.viewFrom && to >= display.viewTo) { // Full overlap
      resetView(cm);
    } else if (from <= display.viewFrom) { // Top overlap
      var cut = viewCuttingPoint(cm, to, to + lendiff, 1);
      if (cut) {
        display.view = display.view.slice(cut.index);
        display.viewFrom = cut.lineN;
        display.viewTo += lendiff;
      } else {
        resetView(cm);
      }
    } else if (to >= display.viewTo) { // Bottom overlap
      var cut$1 = viewCuttingPoint(cm, from, from, -1);
      if (cut$1) {
        display.view = display.view.slice(0, cut$1.index);
        display.viewTo = cut$1.lineN;
      } else {
        resetView(cm);
      }
    } else { // Gap in the middle
      var cutTop = viewCuttingPoint(cm, from, from, -1);
      var cutBot = viewCuttingPoint(cm, to, to + lendiff, 1);
      if (cutTop && cutBot) {
        display.view = display.view.slice(0, cutTop.index)
          .concat(buildViewArray(cm, cutTop.lineN, cutBot.lineN))
          .concat(display.view.slice(cutBot.index));
        display.viewTo += lendiff;
      } else {
        resetView(cm);
      }
    }

    var ext = display.externalMeasured;
    if (ext) {
      if (to < ext.lineN)
        { ext.lineN += lendiff; }
      else if (from < ext.lineN + ext.size)
        { display.externalMeasured = null; }
    }
  }

  // Register a change to a single line. Type must be one of "text",
  // "gutter", "class", "widget"
  function regLineChange(cm, line, type) {
    cm.curOp.viewChanged = true;
    var display = cm.display, ext = cm.display.externalMeasured;
    if (ext && line >= ext.lineN && line < ext.lineN + ext.size)
      { display.externalMeasured = null; }

    if (line < display.viewFrom || line >= display.viewTo) { return }
    var lineView = display.view[findViewIndex(cm, line)];
    if (lineView.node == null) { return }
    var arr = lineView.changes || (lineView.changes = []);
    if (indexOf(arr, type) == -1) { arr.push(type); }
  }

  // Clear the view.
  function resetView(cm) {
    cm.display.viewFrom = cm.display.viewTo = cm.doc.first;
    cm.display.view = [];
    cm.display.viewOffset = 0;
  }

  function viewCuttingPoint(cm, oldN, newN, dir) {
    var index = findViewIndex(cm, oldN), diff, view = cm.display.view;
    if (!sawCollapsedSpans || newN == cm.doc.first + cm.doc.size)
      { return {index: index, lineN: newN} }
    var n = cm.display.viewFrom;
    for (var i = 0; i < index; i++)
      { n += view[i].size; }
    if (n != oldN) {
      if (dir > 0) {
        if (index == view.length - 1) { return null }
        diff = (n + view[index].size) - oldN;
        index++;
      } else {
        diff = n - oldN;
      }
      oldN += diff; newN += diff;
    }
    while (visualLineNo(cm.doc, newN) != newN) {
      if (index == (dir < 0 ? 0 : view.length - 1)) { return null }
      newN += dir * view[index - (dir < 0 ? 1 : 0)].size;
      index += dir;
    }
    return {index: index, lineN: newN}
  }

  // Force the view to cover a given range, adding empty view element
  // or clipping off existing ones as needed.
  function adjustView(cm, from, to) {
    var display = cm.display, view = display.view;
    if (view.length == 0 || from >= display.viewTo || to <= display.viewFrom) {
      display.view = buildViewArray(cm, from, to);
      display.viewFrom = from;
    } else {
      if (display.viewFrom > from)
        { display.view = buildViewArray(cm, from, display.viewFrom).concat(display.view); }
      else if (display.viewFrom < from)
        { display.view = display.view.slice(findViewIndex(cm, from)); }
      display.viewFrom = from;
      if (display.viewTo < to)
        { display.view = display.view.concat(buildViewArray(cm, display.viewTo, to)); }
      else if (display.viewTo > to)
        { display.view = display.view.slice(0, findViewIndex(cm, to)); }
    }
    display.viewTo = to;
  }

  // Count the number of lines in the view whose DOM representation is
  // out of date (or nonexistent).
  function countDirtyView(cm) {
    var view = cm.display.view, dirty = 0;
    for (var i = 0; i < view.length; i++) {
      var lineView = view[i];
      if (!lineView.hidden && (!lineView.node || lineView.changes)) { ++dirty; }
    }
    return dirty
  }

  function updateSelection(cm) {
    cm.display.input.showSelection(cm.display.input.prepareSelection());
  }

  function prepareSelection(cm, primary) {
    if ( primary === void 0 ) primary = true;

    var doc = cm.doc, result = {};
    var curFragment = result.cursors = document.createDocumentFragment();
    var selFragment = result.selection = document.createDocumentFragment();

    var customCursor = cm.options.$customCursor;
    if (customCursor) { primary = true; }
    for (var i = 0; i < doc.sel.ranges.length; i++) {
      if (!primary && i == doc.sel.primIndex) { continue }
      var range = doc.sel.ranges[i];
      if (range.from().line >= cm.display.viewTo || range.to().line < cm.display.viewFrom) { continue }
      var collapsed = range.empty();
      if (customCursor) {
        var head = customCursor(cm, range);
        if (head) { drawSelectionCursor(cm, head, curFragment); }
      } else if (collapsed || cm.options.showCursorWhenSelecting) {
        drawSelectionCursor(cm, range.head, curFragment);
      }
      if (!collapsed)
        { drawSelectionRange(cm, range, selFragment); }
    }
    return result
  }

  // Draws a cursor for the given range
  function drawSelectionCursor(cm, head, output) {
    var pos = cursorCoords(cm, head, "div", null, null, !cm.options.singleCursorHeightPerLine);

    var cursor = output.appendChild(elt("div", "\u00a0", "CodeMirror-cursor"));
    cursor.style.left = pos.left + "px";
    cursor.style.top = pos.top + "px";
    cursor.style.height = Math.max(0, pos.bottom - pos.top) * cm.options.cursorHeight + "px";

    if (/\bcm-fat-cursor\b/.test(cm.getWrapperElement().className)) {
      var charPos = charCoords(cm, head, "div", null, null);
      var width = charPos.right - charPos.left;
      cursor.style.width = (width > 0 ? width : cm.defaultCharWidth()) + "px";
    }

    if (pos.other) {
      // Secondary cursor, shown when on a 'jump' in bi-directional text
      var otherCursor = output.appendChild(elt("div", "\u00a0", "CodeMirror-cursor CodeMirror-secondarycursor"));
      otherCursor.style.display = "";
      otherCursor.style.left = pos.other.left + "px";
      otherCursor.style.top = pos.other.top + "px";
      otherCursor.style.height = (pos.other.bottom - pos.other.top) * .85 + "px";
    }
  }

  function cmpCoords(a, b) { return a.top - b.top || a.left - b.left }

  // Draws the given range as a highlighted selection
  function drawSelectionRange(cm, range, output) {
    var display = cm.display, doc = cm.doc;
    var fragment = document.createDocumentFragment();
    var padding = paddingH(cm.display), leftSide = padding.left;
    var rightSide = Math.max(display.sizerWidth, displayWidth(cm) - display.sizer.offsetLeft) - padding.right;
    var docLTR = doc.direction == "ltr";

    function add(left, top, width, bottom) {
      if (top < 0) { top = 0; }
      top = Math.round(top);
      bottom = Math.round(bottom);
      fragment.appendChild(elt("div", null, "CodeMirror-selected", ("position: absolute; left: " + left + "px;\n                             top: " + top + "px; width: " + (width == null ? rightSide - left : width) + "px;\n                             height: " + (bottom - top) + "px")));
    }

    function drawForLine(line, fromArg, toArg) {
      var lineObj = getLine(doc, line);
      var lineLen = lineObj.text.length;
      var start, end;
      function coords(ch, bias) {
        return charCoords(cm, Pos(line, ch), "div", lineObj, bias)
      }

      function wrapX(pos, dir, side) {
        var extent = wrappedLineExtentChar(cm, lineObj, null, pos);
        var prop = (dir == "ltr") == (side == "after") ? "left" : "right";
        var ch = side == "after" ? extent.begin : extent.end - (/\s/.test(lineObj.text.charAt(extent.end - 1)) ? 2 : 1);
        return coords(ch, prop)[prop]
      }

      var order = getOrder(lineObj, doc.direction);
      iterateBidiSections(order, fromArg || 0, toArg == null ? lineLen : toArg, function (from, to, dir, i) {
        var ltr = dir == "ltr";
        var fromPos = coords(from, ltr ? "left" : "right");
        var toPos = coords(to - 1, ltr ? "right" : "left");

        var openStart = fromArg == null && from == 0, openEnd = toArg == null && to == lineLen;
        var first = i == 0, last = !order || i == order.length - 1;
        if (toPos.top - fromPos.top <= 3) { // Single line
          var openLeft = (docLTR ? openStart : openEnd) && first;
          var openRight = (docLTR ? openEnd : openStart) && last;
          var left = openLeft ? leftSide : (ltr ? fromPos : toPos).left;
          var right = openRight ? rightSide : (ltr ? toPos : fromPos).right;
          add(left, fromPos.top, right - left, fromPos.bottom);
        } else { // Multiple lines
          var topLeft, topRight, botLeft, botRight;
          if (ltr) {
            topLeft = docLTR && openStart && first ? leftSide : fromPos.left;
            topRight = docLTR ? rightSide : wrapX(from, dir, "before");
            botLeft = docLTR ? leftSide : wrapX(to, dir, "after");
            botRight = docLTR && openEnd && last ? rightSide : toPos.right;
          } else {
            topLeft = !docLTR ? leftSide : wrapX(from, dir, "before");
            topRight = !docLTR && openStart && first ? rightSide : fromPos.right;
            botLeft = !docLTR && openEnd && last ? leftSide : toPos.left;
            botRight = !docLTR ? rightSide : wrapX(to, dir, "after");
          }
          add(topLeft, fromPos.top, topRight - topLeft, fromPos.bottom);
          if (fromPos.bottom < toPos.top) { add(leftSide, fromPos.bottom, null, toPos.top); }
          add(botLeft, toPos.top, botRight - botLeft, toPos.bottom);
        }

        if (!start || cmpCoords(fromPos, start) < 0) { start = fromPos; }
        if (cmpCoords(toPos, start) < 0) { start = toPos; }
        if (!end || cmpCoords(fromPos, end) < 0) { end = fromPos; }
        if (cmpCoords(toPos, end) < 0) { end = toPos; }
      });
      return {start: start, end: end}
    }

    var sFrom = range.from(), sTo = range.to();
    if (sFrom.line == sTo.line) {
      drawForLine(sFrom.line, sFrom.ch, sTo.ch);
    } else {
      var fromLine = getLine(doc, sFrom.line), toLine = getLine(doc, sTo.line);
      var singleVLine = visualLine(fromLine) == visualLine(toLine);
      var leftEnd = drawForLine(sFrom.line, sFrom.ch, singleVLine ? fromLine.text.length + 1 : null).end;
      var rightStart = drawForLine(sTo.line, singleVLine ? 0 : null, sTo.ch).start;
      if (singleVLine) {
        if (leftEnd.top < rightStart.top - 2) {
          add(leftEnd.right, leftEnd.top, null, leftEnd.bottom);
          add(leftSide, rightStart.top, rightStart.left, rightStart.bottom);
        } else {
          add(leftEnd.right, leftEnd.top, rightStart.left - leftEnd.right, leftEnd.bottom);
        }
      }
      if (leftEnd.bottom < rightStart.top)
        { add(leftSide, leftEnd.bottom, null, rightStart.top); }
    }

    output.appendChild(fragment);
  }

  // Cursor-blinking
  function restartBlink(cm) {
    if (!cm.state.focused) { return }
    var display = cm.display;
    clearInterval(display.blinker);
    var on = true;
    display.cursorDiv.style.visibility = "";
    if (cm.options.cursorBlinkRate > 0)
      { display.blinker = setInterval(function () {
        if (!cm.hasFocus()) { onBlur(cm); }
        display.cursorDiv.style.visibility = (on = !on) ? "" : "hidden";
      }, cm.options.cursorBlinkRate); }
    else if (cm.options.cursorBlinkRate < 0)
      { display.cursorDiv.style.visibility = "hidden"; }
  }

  function ensureFocus(cm) {
    if (!cm.hasFocus()) {
      cm.display.input.focus();
      if (!cm.state.focused) { onFocus(cm); }
    }
  }

  function delayBlurEvent(cm) {
    cm.state.delayingBlurEvent = true;
    setTimeout(function () { if (cm.state.delayingBlurEvent) {
      cm.state.delayingBlurEvent = false;
      if (cm.state.focused) { onBlur(cm); }
    } }, 100);
  }

  function onFocus(cm, e) {
    if (cm.state.delayingBlurEvent && !cm.state.draggingText) { cm.state.delayingBlurEvent = false; }

    if (cm.options.readOnly == "nocursor") { return }
    if (!cm.state.focused) {
      signal(cm, "focus", cm, e);
      cm.state.focused = true;
      addClass(cm.display.wrapper, "CodeMirror-focused");
      // This test prevents this from firing when a context
      // menu is closed (since the input reset would kill the
      // select-all detection hack)
      if (!cm.curOp && cm.display.selForContextMenu != cm.doc.sel) {
        cm.display.input.reset();
        if (webkit) { setTimeout(function () { return cm.display.input.reset(true); }, 20); } // Issue #1730
      }
      cm.display.input.receivedFocus();
    }
    restartBlink(cm);
  }
  function onBlur(cm, e) {
    if (cm.state.delayingBlurEvent) { return }

    if (cm.state.focused) {
      signal(cm, "blur", cm, e);
      cm.state.focused = false;
      rmClass(cm.display.wrapper, "CodeMirror-focused");
    }
    clearInterval(cm.display.blinker);
    setTimeout(function () { if (!cm.state.focused) { cm.display.shift = false; } }, 150);
  }

  // Read the actual heights of the rendered lines, and update their
  // stored heights to match.
  function updateHeightsInViewport(cm) {
    var display = cm.display;
    var prevBottom = display.lineDiv.offsetTop;
    var viewTop = Math.max(0, display.scroller.getBoundingClientRect().top);
    var oldHeight = display.lineDiv.getBoundingClientRect().top;
    var mustScroll = 0;
    for (var i = 0; i < display.view.length; i++) {
      var cur = display.view[i], wrapping = cm.options.lineWrapping;
      var height = (void 0), width = 0;
      if (cur.hidden) { continue }
      oldHeight += cur.line.height;
      if (ie && ie_version < 8) {
        var bot = cur.node.offsetTop + cur.node.offsetHeight;
        height = bot - prevBottom;
        prevBottom = bot;
      } else {
        var box = cur.node.getBoundingClientRect();
        height = box.bottom - box.top;
        // Check that lines don't extend past the right of the current
        // editor width
        if (!wrapping && cur.text.firstChild)
          { width = cur.text.firstChild.getBoundingClientRect().right - box.left - 1; }
      }
      var diff = cur.line.height - height;
      if (diff > .005 || diff < -.005) {
        if (oldHeight < viewTop) { mustScroll -= diff; }
        updateLineHeight(cur.line, height);
        updateWidgetHeight(cur.line);
        if (cur.rest) { for (var j = 0; j < cur.rest.length; j++)
          { updateWidgetHeight(cur.rest[j]); } }
      }
      if (width > cm.display.sizerWidth) {
        var chWidth = Math.ceil(width / charWidth(cm.display));
        if (chWidth > cm.display.maxLineLength) {
          cm.display.maxLineLength = chWidth;
          cm.display.maxLine = cur.line;
          cm.display.maxLineChanged = true;
        }
      }
    }
    if (Math.abs(mustScroll) > 2) { display.scroller.scrollTop += mustScroll; }
  }

  // Read and store the height of line widgets associated with the
  // given line.
  function updateWidgetHeight(line) {
    if (line.widgets) { for (var i = 0; i < line.widgets.length; ++i) {
      var w = line.widgets[i], parent = w.node.parentNode;
      if (parent) { w.height = parent.offsetHeight; }
    } }
  }

  // Compute the lines that are visible in a given viewport (defaults
  // the the current scroll position). viewport may contain top,
  // height, and ensure (see op.scrollToPos) properties.
  function visibleLines(display, doc, viewport) {
    var top = viewport && viewport.top != null ? Math.max(0, viewport.top) : display.scroller.scrollTop;
    top = Math.floor(top - paddingTop(display));
    var bottom = viewport && viewport.bottom != null ? viewport.bottom : top + display.wrapper.clientHeight;

    var from = lineAtHeight(doc, top), to = lineAtHeight(doc, bottom);
    // Ensure is a {from: {line, ch}, to: {line, ch}} object, and
    // forces those lines into the viewport (if possible).
    if (viewport && viewport.ensure) {
      var ensureFrom = viewport.ensure.from.line, ensureTo = viewport.ensure.to.line;
      if (ensureFrom < from) {
        from = ensureFrom;
        to = lineAtHeight(doc, heightAtLine(getLine(doc, ensureFrom)) + display.wrapper.clientHeight);
      } else if (Math.min(ensureTo, doc.lastLine()) >= to) {
        from = lineAtHeight(doc, heightAtLine(getLine(doc, ensureTo)) - display.wrapper.clientHeight);
        to = ensureTo;
      }
    }
    return {from: from, to: Math.max(to, from + 1)}
  }

  // SCROLLING THINGS INTO VIEW

  // If an editor sits on the top or bottom of the window, partially
  // scrolled out of view, this ensures that the cursor is visible.
  function maybeScrollWindow(cm, rect) {
    if (signalDOMEvent(cm, "scrollCursorIntoView")) { return }

    var display = cm.display, box = display.sizer.getBoundingClientRect(), doScroll = null;
    if (rect.top + box.top < 0) { doScroll = true; }
    else if (rect.bottom + box.top > (window.innerHeight || document.documentElement.clientHeight)) { doScroll = false; }
    if (doScroll != null && !phantom) {
      var scrollNode = elt("div", "\u200b", null, ("position: absolute;\n                         top: " + (rect.top - display.viewOffset - paddingTop(cm.display)) + "px;\n                         height: " + (rect.bottom - rect.top + scrollGap(cm) + display.barHeight) + "px;\n                         left: " + (rect.left) + "px; width: " + (Math.max(2, rect.right - rect.left)) + "px;"));
      cm.display.lineSpace.appendChild(scrollNode);
      scrollNode.scrollIntoView(doScroll);
      cm.display.lineSpace.removeChild(scrollNode);
    }
  }

  // Scroll a given position into view (immediately), verifying that
  // it actually became visible (as line heights are accurately
  // measured, the position of something may 'drift' during drawing).
  function scrollPosIntoView(cm, pos, end, margin) {
    if (margin == null) { margin = 0; }
    var rect;
    if (!cm.options.lineWrapping && pos == end) {
      // Set pos and end to the cursor positions around the character pos sticks to
      // If pos.sticky == "before", that is around pos.ch - 1, otherwise around pos.ch
      // If pos == Pos(_, 0, "before"), pos and end are unchanged
      end = pos.sticky == "before" ? Pos(pos.line, pos.ch + 1, "before") : pos;
      pos = pos.ch ? Pos(pos.line, pos.sticky == "before" ? pos.ch - 1 : pos.ch, "after") : pos;
    }
    for (var limit = 0; limit < 5; limit++) {
      var changed = false;
      var coords = cursorCoords(cm, pos);
      var endCoords = !end || end == pos ? coords : cursorCoords(cm, end);
      rect = {left: Math.min(coords.left, endCoords.left),
              top: Math.min(coords.top, endCoords.top) - margin,
              right: Math.max(coords.left, endCoords.left),
              bottom: Math.max(coords.bottom, endCoords.bottom) + margin};
      var scrollPos = calculateScrollPos(cm, rect);
      var startTop = cm.doc.scrollTop, startLeft = cm.doc.scrollLeft;
      if (scrollPos.scrollTop != null) {
        updateScrollTop(cm, scrollPos.scrollTop);
        if (Math.abs(cm.doc.scrollTop - startTop) > 1) { changed = true; }
      }
      if (scrollPos.scrollLeft != null) {
        setScrollLeft(cm, scrollPos.scrollLeft);
        if (Math.abs(cm.doc.scrollLeft - startLeft) > 1) { changed = true; }
      }
      if (!changed) { break }
    }
    return rect
  }

  // Scroll a given set of coordinates into view (immediately).
  function scrollIntoView(cm, rect) {
    var scrollPos = calculateScrollPos(cm, rect);
    if (scrollPos.scrollTop != null) { updateScrollTop(cm, scrollPos.scrollTop); }
    if (scrollPos.scrollLeft != null) { setScrollLeft(cm, scrollPos.scrollLeft); }
  }

  // Calculate a new scroll position needed to scroll the given
  // rectangle into view. Returns an object with scrollTop and
  // scrollLeft properties. When these are undefined, the
  // vertical/horizontal position does not need to be adjusted.
  function calculateScrollPos(cm, rect) {
    var display = cm.display, snapMargin = textHeight(cm.display);
    if (rect.top < 0) { rect.top = 0; }
    var screentop = cm.curOp && cm.curOp.scrollTop != null ? cm.curOp.scrollTop : display.scroller.scrollTop;
    var screen = displayHeight(cm), result = {};
    if (rect.bottom - rect.top > screen) { rect.bottom = rect.top + screen; }
    var docBottom = cm.doc.height + paddingVert(display);
    var atTop = rect.top < snapMargin, atBottom = rect.bottom > docBottom - snapMargin;
    if (rect.top < screentop) {
      result.scrollTop = atTop ? 0 : rect.top;
    } else if (rect.bottom > screentop + screen) {
      var newTop = Math.min(rect.top, (atBottom ? docBottom : rect.bottom) - screen);
      if (newTop != screentop) { result.scrollTop = newTop; }
    }

    var gutterSpace = cm.options.fixedGutter ? 0 : display.gutters.offsetWidth;
    var screenleft = cm.curOp && cm.curOp.scrollLeft != null ? cm.curOp.scrollLeft : display.scroller.scrollLeft - gutterSpace;
    var screenw = displayWidth(cm) - display.gutters.offsetWidth;
    var tooWide = rect.right - rect.left > screenw;
    if (tooWide) { rect.right = rect.left + screenw; }
    if (rect.left < 10)
      { result.scrollLeft = 0; }
    else if (rect.left < screenleft)
      { result.scrollLeft = Math.max(0, rect.left + gutterSpace - (tooWide ? 0 : 10)); }
    else if (rect.right > screenw + screenleft - 3)
      { result.scrollLeft = rect.right + (tooWide ? 0 : 10) - screenw; }
    return result
  }

  // Store a relative adjustment to the scroll position in the current
  // operation (to be applied when the operation finishes).
  function addToScrollTop(cm, top) {
    if (top == null) { return }
    resolveScrollToPos(cm);
    cm.curOp.scrollTop = (cm.curOp.scrollTop == null ? cm.doc.scrollTop : cm.curOp.scrollTop) + top;
  }

  // Make sure that at the end of the operation the current cursor is
  // shown.
  function ensureCursorVisible(cm) {
    resolveScrollToPos(cm);
    var cur = cm.getCursor();
    cm.curOp.scrollToPos = {from: cur, to: cur, margin: cm.options.cursorScrollMargin};
  }

  function scrollToCoords(cm, x, y) {
    if (x != null || y != null) { resolveScrollToPos(cm); }
    if (x != null) { cm.curOp.scrollLeft = x; }
    if (y != null) { cm.curOp.scrollTop = y; }
  }

  function scrollToRange(cm, range) {
    resolveScrollToPos(cm);
    cm.curOp.scrollToPos = range;
  }

  // When an operation has its scrollToPos property set, and another
  // scroll action is applied before the end of the operation, this
  // 'simulates' scrolling that position into view in a cheap way, so
  // that the effect of intermediate scroll commands is not ignored.
  function resolveScrollToPos(cm) {
    var range = cm.curOp.scrollToPos;
    if (range) {
      cm.curOp.scrollToPos = null;
      var from = estimateCoords(cm, range.from), to = estimateCoords(cm, range.to);
      scrollToCoordsRange(cm, from, to, range.margin);
    }
  }

  function scrollToCoordsRange(cm, from, to, margin) {
    var sPos = calculateScrollPos(cm, {
      left: Math.min(from.left, to.left),
      top: Math.min(from.top, to.top) - margin,
      right: Math.max(from.right, to.right),
      bottom: Math.max(from.bottom, to.bottom) + margin
    });
    scrollToCoords(cm, sPos.scrollLeft, sPos.scrollTop);
  }

  // Sync the scrollable area and scrollbars, ensure the viewport
  // covers the visible area.
  function updateScrollTop(cm, val) {
    if (Math.abs(cm.doc.scrollTop - val) < 2) { return }
    if (!gecko) { updateDisplaySimple(cm, {top: val}); }
    setScrollTop(cm, val, true);
    if (gecko) { updateDisplaySimple(cm); }
    startWorker(cm, 100);
  }

  function setScrollTop(cm, val, forceScroll) {
    val = Math.max(0, Math.min(cm.display.scroller.scrollHeight - cm.display.scroller.clientHeight, val));
    if (cm.display.scroller.scrollTop == val && !forceScroll) { return }
    cm.doc.scrollTop = val;
    cm.display.scrollbars.setScrollTop(val);
    if (cm.display.scroller.scrollTop != val) { cm.display.scroller.scrollTop = val; }
  }

  // Sync scroller and scrollbar, ensure the gutter elements are
  // aligned.
  function setScrollLeft(cm, val, isScroller, forceScroll) {
    val = Math.max(0, Math.min(val, cm.display.scroller.scrollWidth - cm.display.scroller.clientWidth));
    if ((isScroller ? val == cm.doc.scrollLeft : Math.abs(cm.doc.scrollLeft - val) < 2) && !forceScroll) { return }
    cm.doc.scrollLeft = val;
    alignHorizontally(cm);
    if (cm.display.scroller.scrollLeft != val) { cm.display.scroller.scrollLeft = val; }
    cm.display.scrollbars.setScrollLeft(val);
  }

  // SCROLLBARS

  // Prepare DOM reads needed to update the scrollbars. Done in one
  // shot to minimize update/measure roundtrips.
  function measureForScrollbars(cm) {
    var d = cm.display, gutterW = d.gutters.offsetWidth;
    var docH = Math.round(cm.doc.height + paddingVert(cm.display));
    return {
      clientHeight: d.scroller.clientHeight,
      viewHeight: d.wrapper.clientHeight,
      scrollWidth: d.scroller.scrollWidth, clientWidth: d.scroller.clientWidth,
      viewWidth: d.wrapper.clientWidth,
      barLeft: cm.options.fixedGutter ? gutterW : 0,
      docHeight: docH,
      scrollHeight: docH + scrollGap(cm) + d.barHeight,
      nativeBarWidth: d.nativeBarWidth,
      gutterWidth: gutterW
    }
  }

  var NativeScrollbars = function(place, scroll, cm) {
    this.cm = cm;
    var vert = this.vert = elt("div", [elt("div", null, null, "min-width: 1px")], "CodeMirror-vscrollbar");
    var horiz = this.horiz = elt("div", [elt("div", null, null, "height: 100%; min-height: 1px")], "CodeMirror-hscrollbar");
    vert.tabIndex = horiz.tabIndex = -1;
    place(vert); place(horiz);

    on(vert, "scroll", function () {
      if (vert.clientHeight) { scroll(vert.scrollTop, "vertical"); }
    });
    on(horiz, "scroll", function () {
      if (horiz.clientWidth) { scroll(horiz.scrollLeft, "horizontal"); }
    });

    this.checkedZeroWidth = false;
    // Need to set a minimum width to see the scrollbar on IE7 (but must not set it on IE8).
    if (ie && ie_version < 8) { this.horiz.style.minHeight = this.vert.style.minWidth = "18px"; }
  };

  NativeScrollbars.prototype.update = function (measure) {
    var needsH = measure.scrollWidth > measure.clientWidth + 1;
    var needsV = measure.scrollHeight > measure.clientHeight + 1;
    var sWidth = measure.nativeBarWidth;

    if (needsV) {
      this.vert.style.display = "block";
      this.vert.style.bottom = needsH ? sWidth + "px" : "0";
      var totalHeight = measure.viewHeight - (needsH ? sWidth : 0);
      // A bug in IE8 can cause this value to be negative, so guard it.
      this.vert.firstChild.style.height =
        Math.max(0, measure.scrollHeight - measure.clientHeight + totalHeight) + "px";
    } else {
      this.vert.scrollTop = 0;
      this.vert.style.display = "";
      this.vert.firstChild.style.height = "0";
    }

    if (needsH) {
      this.horiz.style.display = "block";
      this.horiz.style.right = needsV ? sWidth + "px" : "0";
      this.horiz.style.left = measure.barLeft + "px";
      var totalWidth = measure.viewWidth - measure.barLeft - (needsV ? sWidth : 0);
      this.horiz.firstChild.style.width =
        Math.max(0, measure.scrollWidth - measure.clientWidth + totalWidth) + "px";
    } else {
      this.horiz.style.display = "";
      this.horiz.firstChild.style.width = "0";
    }

    if (!this.checkedZeroWidth && measure.clientHeight > 0) {
      if (sWidth == 0) { this.zeroWidthHack(); }
      this.checkedZeroWidth = true;
    }

    return {right: needsV ? sWidth : 0, bottom: needsH ? sWidth : 0}
  };

  NativeScrollbars.prototype.setScrollLeft = function (pos) {
    if (this.horiz.scrollLeft != pos) { this.horiz.scrollLeft = pos; }
    if (this.disableHoriz) { this.enableZeroWidthBar(this.horiz, this.disableHoriz, "horiz"); }
  };

  NativeScrollbars.prototype.setScrollTop = function (pos) {
    if (this.vert.scrollTop != pos) { this.vert.scrollTop = pos; }
    if (this.disableVert) { this.enableZeroWidthBar(this.vert, this.disableVert, "vert"); }
  };

  NativeScrollbars.prototype.zeroWidthHack = function () {
    var w = mac && !mac_geMountainLion ? "12px" : "18px";
    this.horiz.style.height = this.vert.style.width = w;
    this.horiz.style.pointerEvents = this.vert.style.pointerEvents = "none";
    this.disableHoriz = new Delayed;
    this.disableVert = new Delayed;
  };

  NativeScrollbars.prototype.enableZeroWidthBar = function (bar, delay, type) {
    bar.style.pointerEvents = "auto";
    function maybeDisable() {
      // To find out whether the scrollbar is still visible, we
      // check whether the element under the pixel in the bottom
      // right corner of the scrollbar box is the scrollbar box
      // itself (when the bar is still visible) or its filler child
      // (when the bar is hidden). If it is still visible, we keep
      // it enabled, if it's hidden, we disable pointer events.
      var box = bar.getBoundingClientRect();
      var elt = type == "vert" ? document.elementFromPoint(box.right - 1, (box.top + box.bottom) / 2)
          : document.elementFromPoint((box.right + box.left) / 2, box.bottom - 1);
      if (elt != bar) { bar.style.pointerEvents = "none"; }
      else { delay.set(1000, maybeDisable); }
    }
    delay.set(1000, maybeDisable);
  };

  NativeScrollbars.prototype.clear = function () {
    var parent = this.horiz.parentNode;
    parent.removeChild(this.horiz);
    parent.removeChild(this.vert);
  };

  var NullScrollbars = function () {};

  NullScrollbars.prototype.update = function () { return {bottom: 0, right: 0} };
  NullScrollbars.prototype.setScrollLeft = function () {};
  NullScrollbars.prototype.setScrollTop = function () {};
  NullScrollbars.prototype.clear = function () {};

  function updateScrollbars(cm, measure) {
    if (!measure) { measure = measureForScrollbars(cm); }
    var startWidth = cm.display.barWidth, startHeight = cm.display.barHeight;
    updateScrollbarsInner(cm, measure);
    for (var i = 0; i < 4 && startWidth != cm.display.barWidth || startHeight != cm.display.barHeight; i++) {
      if (startWidth != cm.display.barWidth && cm.options.lineWrapping)
        { updateHeightsInViewport(cm); }
      updateScrollbarsInner(cm, measureForScrollbars(cm));
      startWidth = cm.display.barWidth; startHeight = cm.display.barHeight;
    }
  }

  // Re-synchronize the fake scrollbars with the actual size of the
  // content.
  function updateScrollbarsInner(cm, measure) {
    var d = cm.display;
    var sizes = d.scrollbars.update(measure);

    d.sizer.style.paddingRight = (d.barWidth = sizes.right) + "px";
    d.sizer.style.paddingBottom = (d.barHeight = sizes.bottom) + "px";
    d.heightForcer.style.borderBottom = sizes.bottom + "px solid transparent";

    if (sizes.right && sizes.bottom) {
      d.scrollbarFiller.style.display = "block";
      d.scrollbarFiller.style.height = sizes.bottom + "px";
      d.scrollbarFiller.style.width = sizes.right + "px";
    } else { d.scrollbarFiller.style.display = ""; }
    if (sizes.bottom && cm.options.coverGutterNextToScrollbar && cm.options.fixedGutter) {
      d.gutterFiller.style.display = "block";
      d.gutterFiller.style.height = sizes.bottom + "px";
      d.gutterFiller.style.width = measure.gutterWidth + "px";
    } else { d.gutterFiller.style.display = ""; }
  }

  var scrollbarModel = {"native": NativeScrollbars, "null": NullScrollbars};

  function initScrollbars(cm) {
    if (cm.display.scrollbars) {
      cm.display.scrollbars.clear();
      if (cm.display.scrollbars.addClass)
        { rmClass(cm.display.wrapper, cm.display.scrollbars.addClass); }
    }

    cm.display.scrollbars = new scrollbarModel[cm.options.scrollbarStyle](function (node) {
      cm.display.wrapper.insertBefore(node, cm.display.scrollbarFiller);
      // Prevent clicks in the scrollbars from killing focus
      on(node, "mousedown", function () {
        if (cm.state.focused) { setTimeout(function () { return cm.display.input.focus(); }, 0); }
      });
      node.setAttribute("cm-not-content", "true");
    }, function (pos, axis) {
      if (axis == "horizontal") { setScrollLeft(cm, pos); }
      else { updateScrollTop(cm, pos); }
    }, cm);
    if (cm.display.scrollbars.addClass)
      { addClass(cm.display.wrapper, cm.display.scrollbars.addClass); }
  }

  // Operations are used to wrap a series of changes to the editor
  // state in such a way that each change won't have to update the
  // cursor and display (which would be awkward, slow, and
  // error-prone). Instead, display updates are batched and then all
  // combined and executed at once.

  var nextOpId = 0;
  // Start a new operation.
  function startOperation(cm) {
    cm.curOp = {
      cm: cm,
      viewChanged: false,      // Flag that indicates that lines might need to be redrawn
      startHeight: cm.doc.height, // Used to detect need to update scrollbar
      forceUpdate: false,      // Used to force a redraw
      updateInput: 0,       // Whether to reset the input textarea
      typing: false,           // Whether this reset should be careful to leave existing text (for compositing)
      changeObjs: null,        // Accumulated changes, for firing change events
      cursorActivityHandlers: null, // Set of handlers to fire cursorActivity on
      cursorActivityCalled: 0, // Tracks which cursorActivity handlers have been called already
      selectionChanged: false, // Whether the selection needs to be redrawn
      updateMaxLine: false,    // Set when the widest line needs to be determined anew
      scrollLeft: null, scrollTop: null, // Intermediate scroll position, not pushed to DOM yet
      scrollToPos: null,       // Used to scroll to a specific position
      focus: false,
      id: ++nextOpId,          // Unique ID
      markArrays: null         // Used by addMarkedSpan
    };
    pushOperation(cm.curOp);
  }

  // Finish an operation, updating the display and signalling delayed events
  function endOperation(cm) {
    var op = cm.curOp;
    if (op) { finishOperation(op, function (group) {
      for (var i = 0; i < group.ops.length; i++)
        { group.ops[i].cm.curOp = null; }
      endOperations(group);
    }); }
  }

  // The DOM updates done when an operation finishes are batched so
  // that the minimum number of relayouts are required.
  function endOperations(group) {
    var ops = group.ops;
    for (var i = 0; i < ops.length; i++) // Read DOM
      { endOperation_R1(ops[i]); }
    for (var i$1 = 0; i$1 < ops.length; i$1++) // Write DOM (maybe)
      { endOperation_W1(ops[i$1]); }
    for (var i$2 = 0; i$2 < ops.length; i$2++) // Read DOM
      { endOperation_R2(ops[i$2]); }
    for (var i$3 = 0; i$3 < ops.length; i$3++) // Write DOM (maybe)
      { endOperation_W2(ops[i$3]); }
    for (var i$4 = 0; i$4 < ops.length; i$4++) // Read DOM
      { endOperation_finish(ops[i$4]); }
  }

  function endOperation_R1(op) {
    var cm = op.cm, display = cm.display;
    maybeClipScrollbars(cm);
    if (op.updateMaxLine) { findMaxLine(cm); }

    op.mustUpdate = op.viewChanged || op.forceUpdate || op.scrollTop != null ||
      op.scrollToPos && (op.scrollToPos.from.line < display.viewFrom ||
                         op.scrollToPos.to.line >= display.viewTo) ||
      display.maxLineChanged && cm.options.lineWrapping;
    op.update = op.mustUpdate &&
      new DisplayUpdate(cm, op.mustUpdate && {top: op.scrollTop, ensure: op.scrollToPos}, op.forceUpdate);
  }

  function endOperation_W1(op) {
    op.updatedDisplay = op.mustUpdate && updateDisplayIfNeeded(op.cm, op.update);
  }

  function endOperation_R2(op) {
    var cm = op.cm, display = cm.display;
    if (op.updatedDisplay) { updateHeightsInViewport(cm); }

    op.barMeasure = measureForScrollbars(cm);

    // If the max line changed since it was last measured, measure it,
    // and ensure the document's width matches it.
    // updateDisplay_W2 will use these properties to do the actual resizing
    if (display.maxLineChanged && !cm.options.lineWrapping) {
      op.adjustWidthTo = measureChar(cm, display.maxLine, display.maxLine.text.length).left + 3;
      cm.display.sizerWidth = op.adjustWidthTo;
      op.barMeasure.scrollWidth =
        Math.max(display.scroller.clientWidth, display.sizer.offsetLeft + op.adjustWidthTo + scrollGap(cm) + cm.display.barWidth);
      op.maxScrollLeft = Math.max(0, display.sizer.offsetLeft + op.adjustWidthTo - displayWidth(cm));
    }

    if (op.updatedDisplay || op.selectionChanged)
      { op.preparedSelection = display.input.prepareSelection(); }
  }

  function endOperation_W2(op) {
    var cm = op.cm;

    if (op.adjustWidthTo != null) {
      cm.display.sizer.style.minWidth = op.adjustWidthTo + "px";
      if (op.maxScrollLeft < cm.doc.scrollLeft)
        { setScrollLeft(cm, Math.min(cm.display.scroller.scrollLeft, op.maxScrollLeft), true); }
      cm.display.maxLineChanged = false;
    }

    var takeFocus = op.focus && op.focus == activeElt();
    if (op.preparedSelection)
      { cm.display.input.showSelection(op.preparedSelection, takeFocus); }
    if (op.updatedDisplay || op.startHeight != cm.doc.height)
      { updateScrollbars(cm, op.barMeasure); }
    if (op.updatedDisplay)
      { setDocumentHeight(cm, op.barMeasure); }

    if (op.selectionChanged) { restartBlink(cm); }

    if (cm.state.focused && op.updateInput)
      { cm.display.input.reset(op.typing); }
    if (takeFocus) { ensureFocus(op.cm); }
  }

  function endOperation_finish(op) {
    var cm = op.cm, display = cm.display, doc = cm.doc;

    if (op.updatedDisplay) { postUpdateDisplay(cm, op.update); }

    // Abort mouse wheel delta measurement, when scrolling explicitly
    if (display.wheelStartX != null && (op.scrollTop != null || op.scrollLeft != null || op.scrollToPos))
      { display.wheelStartX = display.wheelStartY = null; }

    // Propagate the scroll position to the actual DOM scroller
    if (op.scrollTop != null) { setScrollTop(cm, op.scrollTop, op.forceScroll); }

    if (op.scrollLeft != null) { setScrollLeft(cm, op.scrollLeft, true, true); }
    // If we need to scroll a specific position into view, do so.
    if (op.scrollToPos) {
      var rect = scrollPosIntoView(cm, clipPos(doc, op.scrollToPos.from),
                                   clipPos(doc, op.scrollToPos.to), op.scrollToPos.margin);
      maybeScrollWindow(cm, rect);
    }

    // Fire events for markers that are hidden/unidden by editing or
    // undoing
    var hidden = op.maybeHiddenMarkers, unhidden = op.maybeUnhiddenMarkers;
    if (hidden) { for (var i = 0; i < hidden.length; ++i)
      { if (!hidden[i].lines.length) { signal(hidden[i], "hide"); } } }
    if (unhidden) { for (var i$1 = 0; i$1 < unhidden.length; ++i$1)
      { if (unhidden[i$1].lines.length) { signal(unhidden[i$1], "unhide"); } } }

    if (display.wrapper.offsetHeight)
      { doc.scrollTop = cm.display.scroller.scrollTop; }

    // Fire change events, and delayed event handlers
    if (op.changeObjs)
      { signal(cm, "changes", cm, op.changeObjs); }
    if (op.update)
      { op.update.finish(); }
  }

  // Run the given function in an operation
  function runInOp(cm, f) {
    if (cm.curOp) { return f() }
    startOperation(cm);
    try { return f() }
    finally { endOperation(cm); }
  }
  // Wraps a function in an operation. Returns the wrapped function.
  function operation(cm, f) {
    return function() {
      if (cm.curOp) { return f.apply(cm, arguments) }
      startOperation(cm);
      try { return f.apply(cm, arguments) }
      finally { endOperation(cm); }
    }
  }
  // Used to add methods to editor and doc instances, wrapping them in
  // operations.
  function methodOp(f) {
    return function() {
      if (this.curOp) { return f.apply(this, arguments) }
      startOperation(this);
      try { return f.apply(this, arguments) }
      finally { endOperation(this); }
    }
  }
  function docMethodOp(f) {
    return function() {
      var cm = this.cm;
      if (!cm || cm.curOp) { return f.apply(this, arguments) }
      startOperation(cm);
      try { return f.apply(this, arguments) }
      finally { endOperation(cm); }
    }
  }

  // HIGHLIGHT WORKER

  function startWorker(cm, time) {
    if (cm.doc.highlightFrontier < cm.display.viewTo)
      { cm.state.highlight.set(time, bind(highlightWorker, cm)); }
  }

  function highlightWorker(cm) {
    var doc = cm.doc;
    if (doc.highlightFrontier >= cm.display.viewTo) { return }
    var end = +new Date + cm.options.workTime;
    var context = getContextBefore(cm, doc.highlightFrontier);
    var changedLines = [];

    doc.iter(context.line, Math.min(doc.first + doc.size, cm.display.viewTo + 500), function (line) {
      if (context.line >= cm.display.viewFrom) { // Visible
        var oldStyles = line.styles;
        var resetState = line.text.length > cm.options.maxHighlightLength ? copyState(doc.mode, context.state) : null;
        var highlighted = highlightLine(cm, line, context, true);
        if (resetState) { context.state = resetState; }
        line.styles = highlighted.styles;
        var oldCls = line.styleClasses, newCls = highlighted.classes;
        if (newCls) { line.styleClasses = newCls; }
        else if (oldCls) { line.styleClasses = null; }
        var ischange = !oldStyles || oldStyles.length != line.styles.length ||
          oldCls != newCls && (!oldCls || !newCls || oldCls.bgClass != newCls.bgClass || oldCls.textClass != newCls.textClass);
        for (var i = 0; !ischange && i < oldStyles.length; ++i) { ischange = oldStyles[i] != line.styles[i]; }
        if (ischange) { changedLines.push(context.line); }
        line.stateAfter = context.save();
        context.nextLine();
      } else {
        if (line.text.length <= cm.options.maxHighlightLength)
          { processLine(cm, line.text, context); }
        line.stateAfter = context.line % 5 == 0 ? context.save() : null;
        context.nextLine();
      }
      if (+new Date > end) {
        startWorker(cm, cm.options.workDelay);
        return true
      }
    });
    doc.highlightFrontier = context.line;
    doc.modeFrontier = Math.max(doc.modeFrontier, context.line);
    if (changedLines.length) { runInOp(cm, function () {
      for (var i = 0; i < changedLines.length; i++)
        { regLineChange(cm, changedLines[i], "text"); }
    }); }
  }

  // DISPLAY DRAWING

  var DisplayUpdate = function(cm, viewport, force) {
    var display = cm.display;

    this.viewport = viewport;
    // Store some values that we'll need later (but don't want to force a relayout for)
    this.visible = visibleLines(display, cm.doc, viewport);
    this.editorIsHidden = !display.wrapper.offsetWidth;
    this.wrapperHeight = display.wrapper.clientHeight;
    this.wrapperWidth = display.wrapper.clientWidth;
    this.oldDisplayWidth = displayWidth(cm);
    this.force = force;
    this.dims = getDimensions(cm);
    this.events = [];
  };

  DisplayUpdate.prototype.signal = function (emitter, type) {
    if (hasHandler(emitter, type))
      { this.events.push(arguments); }
  };
  DisplayUpdate.prototype.finish = function () {
    for (var i = 0; i < this.events.length; i++)
      { signal.apply(null, this.events[i]); }
  };

  function maybeClipScrollbars(cm) {
    var display = cm.display;
    if (!display.scrollbarsClipped && display.scroller.offsetWidth) {
      display.nativeBarWidth = display.scroller.offsetWidth - display.scroller.clientWidth;
      display.heightForcer.style.height = scrollGap(cm) + "px";
      display.sizer.style.marginBottom = -display.nativeBarWidth + "px";
      display.sizer.style.borderRightWidth = scrollGap(cm) + "px";
      display.scrollbarsClipped = true;
    }
  }

  function selectionSnapshot(cm) {
    if (cm.hasFocus()) { return null }
    var active = activeElt();
    if (!active || !contains(cm.display.lineDiv, active)) { return null }
    var result = {activeElt: active};
    if (window.getSelection) {
      var sel = window.getSelection();
      if (sel.anchorNode && sel.extend && contains(cm.display.lineDiv, sel.anchorNode)) {
        result.anchorNode = sel.anchorNode;
        result.anchorOffset = sel.anchorOffset;
        result.focusNode = sel.focusNode;
        result.focusOffset = sel.focusOffset;
      }
    }
    return result
  }

  function restoreSelection(snapshot) {
    if (!snapshot || !snapshot.activeElt || snapshot.activeElt == activeElt()) { return }
    snapshot.activeElt.focus();
    if (!/^(INPUT|TEXTAREA)$/.test(snapshot.activeElt.nodeName) &&
        snapshot.anchorNode && contains(document.body, snapshot.anchorNode) && contains(document.body, snapshot.focusNode)) {
      var sel = window.getSelection(), range = document.createRange();
      range.setEnd(snapshot.anchorNode, snapshot.anchorOffset);
      range.collapse(false);
      sel.removeAllRanges();
      sel.addRange(range);
      sel.extend(snapshot.focusNode, snapshot.focusOffset);
    }
  }

  // Does the actual updating of the line display. Bails out
  // (returning false) when there is nothing to be done and forced is
  // false.
  function updateDisplayIfNeeded(cm, update) {
    var display = cm.display, doc = cm.doc;

    if (update.editorIsHidden) {
      resetView(cm);
      return false
    }

    // Bail out if the visible area is already rendered and nothing changed.
    if (!update.force &&
        update.visible.from >= display.viewFrom && update.visible.to <= display.viewTo &&
        (display.updateLineNumbers == null || display.updateLineNumbers >= display.viewTo) &&
        display.renderedView == display.view && countDirtyView(cm) == 0)
      { return false }

    if (maybeUpdateLineNumberWidth(cm)) {
      resetView(cm);
      update.dims = getDimensions(cm);
    }

    // Compute a suitable new viewport (from & to)
    var end = doc.first + doc.size;
    var from = Math.max(update.visible.from - cm.options.viewportMargin, doc.first);
    var to = Math.min(end, update.visible.to + cm.options.viewportMargin);
    if (display.viewFrom < from && from - display.viewFrom < 20) { from = Math.max(doc.first, display.viewFrom); }
    if (display.viewTo > to && display.viewTo - to < 20) { to = Math.min(end, display.viewTo); }
    if (sawCollapsedSpans) {
      from = visualLineNo(cm.doc, from);
      to = visualLineEndNo(cm.doc, to);
    }

    var different = from != display.viewFrom || to != display.viewTo ||
      display.lastWrapHeight != update.wrapperHeight || display.lastWrapWidth != update.wrapperWidth;
    adjustView(cm, from, to);

    display.viewOffset = heightAtLine(getLine(cm.doc, display.viewFrom));
    // Position the mover div to align with the current scroll position
    cm.display.mover.style.top = display.viewOffset + "px";

    var toUpdate = countDirtyView(cm);
    if (!different && toUpdate == 0 && !update.force && display.renderedView == display.view &&
        (display.updateLineNumbers == null || display.updateLineNumbers >= display.viewTo))
      { return false }

    // For big changes, we hide the enclosing element during the
    // update, since that speeds up the operations on most browsers.
    var selSnapshot = selectionSnapshot(cm);
    if (toUpdate > 4) { display.lineDiv.style.display = "none"; }
    patchDisplay(cm, display.updateLineNumbers, update.dims);
    if (toUpdate > 4) { display.lineDiv.style.display = ""; }
    display.renderedView = display.view;
    // There might have been a widget with a focused element that got
    // hidden or updated, if so re-focus it.
    restoreSelection(selSnapshot);

    // Prevent selection and cursors from interfering with the scroll
    // width and height.
    removeChildren(display.cursorDiv);
    removeChildren(display.selectionDiv);
    display.gutters.style.height = display.sizer.style.minHeight = 0;

    if (different) {
      display.lastWrapHeight = update.wrapperHeight;
      display.lastWrapWidth = update.wrapperWidth;
      startWorker(cm, 400);
    }

    display.updateLineNumbers = null;

    return true
  }

  function postUpdateDisplay(cm, update) {
    var viewport = update.viewport;

    for (var first = true;; first = false) {
      if (!first || !cm.options.lineWrapping || update.oldDisplayWidth == displayWidth(cm)) {
        // Clip forced viewport to actual scrollable area.
        if (viewport && viewport.top != null)
          { viewport = {top: Math.min(cm.doc.height + paddingVert(cm.display) - displayHeight(cm), viewport.top)}; }
        // Updated line heights might result in the drawn area not
        // actually covering the viewport. Keep looping until it does.
        update.visible = visibleLines(cm.display, cm.doc, viewport);
        if (update.visible.from >= cm.display.viewFrom && update.visible.to <= cm.display.viewTo)
          { break }
      } else if (first) {
        update.visible = visibleLines(cm.display, cm.doc, viewport);
      }
      if (!updateDisplayIfNeeded(cm, update)) { break }
      updateHeightsInViewport(cm);
      var barMeasure = measureForScrollbars(cm);
      updateSelection(cm);
      updateScrollbars(cm, barMeasure);
      setDocumentHeight(cm, barMeasure);
      update.force = false;
    }

    update.signal(cm, "update", cm);
    if (cm.display.viewFrom != cm.display.reportedViewFrom || cm.display.viewTo != cm.display.reportedViewTo) {
      update.signal(cm, "viewportChange", cm, cm.display.viewFrom, cm.display.viewTo);
      cm.display.reportedViewFrom = cm.display.viewFrom; cm.display.reportedViewTo = cm.display.viewTo;
    }
  }

  function updateDisplaySimple(cm, viewport) {
    var update = new DisplayUpdate(cm, viewport);
    if (updateDisplayIfNeeded(cm, update)) {
      updateHeightsInViewport(cm);
      postUpdateDisplay(cm, update);
      var barMeasure = measureForScrollbars(cm);
      updateSelection(cm);
      updateScrollbars(cm, barMeasure);
      setDocumentHeight(cm, barMeasure);
      update.finish();
    }
  }

  // Sync the actual display DOM structure with display.view, removing
  // nodes for lines that are no longer in view, and creating the ones
  // that are not there yet, and updating the ones that are out of
  // date.
  function patchDisplay(cm, updateNumbersFrom, dims) {
    var display = cm.display, lineNumbers = cm.options.lineNumbers;
    var container = display.lineDiv, cur = container.firstChild;

    function rm(node) {
      var next = node.nextSibling;
      // Works around a throw-scroll bug in OS X Webkit
      if (webkit && mac && cm.display.currentWheelTarget == node)
        { node.style.display = "none"; }
      else
        { node.parentNode.removeChild(node); }
      return next
    }

    var view = display.view, lineN = display.viewFrom;
    // Loop over the elements in the view, syncing cur (the DOM nodes
    // in display.lineDiv) with the view as we go.
    for (var i = 0; i < view.length; i++) {
      var lineView = view[i];
      if (lineView.hidden) ; else if (!lineView.node || lineView.node.parentNode != container) { // Not drawn yet
        var node = buildLineElement(cm, lineView, lineN, dims);
        container.insertBefore(node, cur);
      } else { // Already drawn
        while (cur != lineView.node) { cur = rm(cur); }
        var updateNumber = lineNumbers && updateNumbersFrom != null &&
          updateNumbersFrom <= lineN && lineView.lineNumber;
        if (lineView.changes) {
          if (indexOf(lineView.changes, "gutter") > -1) { updateNumber = false; }
          updateLineForChanges(cm, lineView, lineN, dims);
        }
        if (updateNumber) {
          removeChildren(lineView.lineNumber);
          lineView.lineNumber.appendChild(document.createTextNode(lineNumberFor(cm.options, lineN)));
        }
        cur = lineView.node.nextSibling;
      }
      lineN += lineView.size;
    }
    while (cur) { cur = rm(cur); }
  }

  function updateGutterSpace(display) {
    var width = display.gutters.offsetWidth;
    display.sizer.style.marginLeft = width + "px";
    // Send an event to consumers responding to changes in gutter width.
    signalLater(display, "gutterChanged", display);
  }

  function setDocumentHeight(cm, measure) {
    cm.display.sizer.style.minHeight = measure.docHeight + "px";
    cm.display.heightForcer.style.top = measure.docHeight + "px";
    cm.display.gutters.style.height = (measure.docHeight + cm.display.barHeight + scrollGap(cm)) + "px";
  }

  // Re-align line numbers and gutter marks to compensate for
  // horizontal scrolling.
  function alignHorizontally(cm) {
    var display = cm.display, view = display.view;
    if (!display.alignWidgets && (!display.gutters.firstChild || !cm.options.fixedGutter)) { return }
    var comp = compensateForHScroll(display) - display.scroller.scrollLeft + cm.doc.scrollLeft;
    var gutterW = display.gutters.offsetWidth, left = comp + "px";
    for (var i = 0; i < view.length; i++) { if (!view[i].hidden) {
      if (cm.options.fixedGutter) {
        if (view[i].gutter)
          { view[i].gutter.style.left = left; }
        if (view[i].gutterBackground)
          { view[i].gutterBackground.style.left = left; }
      }
      var align = view[i].alignable;
      if (align) { for (var j = 0; j < align.length; j++)
        { align[j].style.left = left; } }
    } }
    if (cm.options.fixedGutter)
      { display.gutters.style.left = (comp + gutterW) + "px"; }
  }

  // Used to ensure that the line number gutter is still the right
  // size for the current document size. Returns true when an update
  // is needed.
  function maybeUpdateLineNumberWidth(cm) {
    if (!cm.options.lineNumbers) { return false }
    var doc = cm.doc, last = lineNumberFor(cm.options, doc.first + doc.size - 1), display = cm.display;
    if (last.length != display.lineNumChars) {
      var test = display.measure.appendChild(elt("div", [elt("div", last)],
                                                 "CodeMirror-linenumber CodeMirror-gutter-elt"));
      var innerW = test.firstChild.offsetWidth, padding = test.offsetWidth - innerW;
      display.lineGutter.style.width = "";
      display.lineNumInnerWidth = Math.max(innerW, display.lineGutter.offsetWidth - padding) + 1;
      display.lineNumWidth = display.lineNumInnerWidth + padding;
      display.lineNumChars = display.lineNumInnerWidth ? last.length : -1;
      display.lineGutter.style.width = display.lineNumWidth + "px";
      updateGutterSpace(cm.display);
      return true
    }
    return false
  }

  function getGutters(gutters, lineNumbers) {
    var result = [], sawLineNumbers = false;
    for (var i = 0; i < gutters.length; i++) {
      var name = gutters[i], style = null;
      if (typeof name != "string") { style = name.style; name = name.className; }
      if (name == "CodeMirror-linenumbers") {
        if (!lineNumbers) { continue }
        else { sawLineNumbers = true; }
      }
      result.push({className: name, style: style});
    }
    if (lineNumbers && !sawLineNumbers) { result.push({className: "CodeMirror-linenumbers", style: null}); }
    return result
  }

  // Rebuild the gutter elements, ensure the margin to the left of the
  // code matches their width.
  function renderGutters(display) {
    var gutters = display.gutters, specs = display.gutterSpecs;
    removeChildren(gutters);
    display.lineGutter = null;
    for (var i = 0; i < specs.length; ++i) {
      var ref = specs[i];
      var className = ref.className;
      var style = ref.style;
      var gElt = gutters.appendChild(elt("div", null, "CodeMirror-gutter " + className));
      if (style) { gElt.style.cssText = style; }
      if (className == "CodeMirror-linenumbers") {
        display.lineGutter = gElt;
        gElt.style.width = (display.lineNumWidth || 1) + "px";
      }
    }
    gutters.style.display = specs.length ? "" : "none";
    updateGutterSpace(display);
  }

  function updateGutters(cm) {
    renderGutters(cm.display);
    regChange(cm);
    alignHorizontally(cm);
  }

  // The display handles the DOM integration, both for input reading
  // and content drawing. It holds references to DOM nodes and
  // display-related state.

  function Display(place, doc, input, options) {
    var d = this;
    this.input = input;

    // Covers bottom-right square when both scrollbars are present.
    d.scrollbarFiller = elt("div", null, "CodeMirror-scrollbar-filler");
    d.scrollbarFiller.setAttribute("cm-not-content", "true");
    // Covers bottom of gutter when coverGutterNextToScrollbar is on
    // and h scrollbar is present.
    d.gutterFiller = elt("div", null, "CodeMirror-gutter-filler");
    d.gutterFiller.setAttribute("cm-not-content", "true");
    // Will contain the actual code, positioned to cover the viewport.
    d.lineDiv = eltP("div", null, "CodeMirror-code");
    // Elements are added to these to represent selection and cursors.
    d.selectionDiv = elt("div", null, null, "position: relative; z-index: 1");
    d.cursorDiv = elt("div", null, "CodeMirror-cursors");
    // A visibility: hidden element used to find the size of things.
    d.measure = elt("div", null, "CodeMirror-measure");
    // When lines outside of the viewport are measured, they are drawn in this.
    d.lineMeasure = elt("div", null, "CodeMirror-measure");
    // Wraps everything that needs to exist inside the vertically-padded coordinate system
    d.lineSpace = eltP("div", [d.measure, d.lineMeasure, d.selectionDiv, d.cursorDiv, d.lineDiv],
                      null, "position: relative; outline: none");
    var lines = eltP("div", [d.lineSpace], "CodeMirror-lines");
    // Moved around its parent to cover visible view.
    d.mover = elt("div", [lines], null, "position: relative");
    // Set to the height of the document, allowing scrolling.
    d.sizer = elt("div", [d.mover], "CodeMirror-sizer");
    d.sizerWidth = null;
    // Behavior of elts with overflow: auto and padding is
    // inconsistent across browsers. This is used to ensure the
    // scrollable area is big enough.
    d.heightForcer = elt("div", null, null, "position: absolute; height: " + scrollerGap + "px; width: 1px;");
    // Will contain the gutters, if any.
    d.gutters = elt("div", null, "CodeMirror-gutters");
    d.lineGutter = null;
    // Actual scrollable element.
    d.scroller = elt("div", [d.sizer, d.heightForcer, d.gutters], "CodeMirror-scroll");
    d.scroller.setAttribute("tabIndex", "-1");
    // The element in which the editor lives.
    d.wrapper = elt("div", [d.scrollbarFiller, d.gutterFiller, d.scroller], "CodeMirror");

    // This attribute is respected by automatic translation systems such as Google Translate,
    // and may also be respected by tools used by human translators.
    d.wrapper.setAttribute('translate', 'no');

    // Work around IE7 z-index bug (not perfect, hence IE7 not really being supported)
    if (ie && ie_version < 8) { d.gutters.style.zIndex = -1; d.scroller.style.paddingRight = 0; }
    if (!webkit && !(gecko && mobile)) { d.scroller.draggable = true; }

    if (place) {
      if (place.appendChild) { place.appendChild(d.wrapper); }
      else { place(d.wrapper); }
    }

    // Current rendered range (may be bigger than the view window).
    d.viewFrom = d.viewTo = doc.first;
    d.reportedViewFrom = d.reportedViewTo = doc.first;
    // Information about the rendered lines.
    d.view = [];
    d.renderedView = null;
    // Holds info about a single rendered line when it was rendered
    // for measurement, while not in view.
    d.externalMeasured = null;
    // Empty space (in pixels) above the view
    d.viewOffset = 0;
    d.lastWrapHeight = d.lastWrapWidth = 0;
    d.updateLineNumbers = null;

    d.nativeBarWidth = d.barHeight = d.barWidth = 0;
    d.scrollbarsClipped = false;

    // Used to only resize the line number gutter when necessary (when
    // the amount of lines crosses a boundary that makes its width change)
    d.lineNumWidth = d.lineNumInnerWidth = d.lineNumChars = null;
    // Set to true when a non-horizontal-scrolling line widget is
    // added. As an optimization, line widget aligning is skipped when
    // this is false.
    d.alignWidgets = false;

    d.cachedCharWidth = d.cachedTextHeight = d.cachedPaddingH = null;

    // Tracks the maximum line length so that the horizontal scrollbar
    // can be kept static when scrolling.
    d.maxLine = null;
    d.maxLineLength = 0;
    d.maxLineChanged = false;

    // Used for measuring wheel scrolling granularity
    d.wheelDX = d.wheelDY = d.wheelStartX = d.wheelStartY = null;

    // True when shift is held down.
    d.shift = false;

    // Used to track whether anything happened since the context menu
    // was opened.
    d.selForContextMenu = null;

    d.activeTouch = null;

    d.gutterSpecs = getGutters(options.gutters, options.lineNumbers);
    renderGutters(d);

    input.init(d);
  }

  // Since the delta values reported on mouse wheel events are
  // unstandardized between browsers and even browser versions, and
  // generally horribly unpredictable, this code starts by measuring
  // the scroll effect that the first few mouse wheel events have,
  // and, from that, detects the way it can convert deltas to pixel
  // offsets afterwards.
  //
  // The reason we want to know the amount a wheel event will scroll
  // is that it gives us a chance to update the display before the
  // actual scrolling happens, reducing flickering.

  var wheelSamples = 0, wheelPixelsPerUnit = null;
  // Fill in a browser-detected starting value on browsers where we
  // know one. These don't have to be accurate -- the result of them
  // being wrong would just be a slight flicker on the first wheel
  // scroll (if it is large enough).
  if (ie) { wheelPixelsPerUnit = -.53; }
  else if (gecko) { wheelPixelsPerUnit = 15; }
  else if (chrome) { wheelPixelsPerUnit = -.7; }
  else if (safari) { wheelPixelsPerUnit = -1/3; }

  function wheelEventDelta(e) {
    var dx = e.wheelDeltaX, dy = e.wheelDeltaY;
    if (dx == null && e.detail && e.axis == e.HORIZONTAL_AXIS) { dx = e.detail; }
    if (dy == null && e.detail && e.axis == e.VERTICAL_AXIS) { dy = e.detail; }
    else if (dy == null) { dy = e.wheelDelta; }
    return {x: dx, y: dy}
  }
  function wheelEventPixels(e) {
    var delta = wheelEventDelta(e);
    delta.x *= wheelPixelsPerUnit;
    delta.y *= wheelPixelsPerUnit;
    return delta
  }

  function onScrollWheel(cm, e) {
    var delta = wheelEventDelta(e), dx = delta.x, dy = delta.y;
    var pixelsPerUnit = wheelPixelsPerUnit;
    if (e.deltaMode === 0) {
      dx = e.deltaX;
      dy = e.deltaY;
      pixelsPerUnit = 1;
    }

    var display = cm.display, scroll = display.scroller;
    // Quit if there's nothing to scroll here
    var canScrollX = scroll.scrollWidth > scroll.clientWidth;
    var canScrollY = scroll.scrollHeight > scroll.clientHeight;
    if (!(dx && canScrollX || dy && canScrollY)) { return }

    // Webkit browsers on OS X abort momentum scrolls when the target
    // of the scroll event is removed from the scrollable element.
    // This hack (see related code in patchDisplay) makes sure the
    // element is kept around.
    if (dy && mac && webkit) {
      outer: for (var cur = e.target, view = display.view; cur != scroll; cur = cur.parentNode) {
        for (var i = 0; i < view.length; i++) {
          if (view[i].node == cur) {
            cm.display.currentWheelTarget = cur;
            break outer
          }
        }
      }
    }

    // On some browsers, horizontal scrolling will cause redraws to
    // happen before the gutter has been realigned, causing it to
    // wriggle around in a most unseemly way. When we have an
    // estimated pixels/delta value, we just handle horizontal
    // scrolling entirely here. It'll be slightly off from native, but
    // better than glitching out.
    if (dx && !gecko && !presto && pixelsPerUnit != null) {
      if (dy && canScrollY)
        { updateScrollTop(cm, Math.max(0, scroll.scrollTop + dy * pixelsPerUnit)); }
      setScrollLeft(cm, Math.max(0, scroll.scrollLeft + dx * pixelsPerUnit));
      // Only prevent default scrolling if vertical scrolling is
      // actually possible. Otherwise, it causes vertical scroll
      // jitter on OSX trackpads when deltaX is small and deltaY
      // is large (issue #3579)
      if (!dy || (dy && canScrollY))
        { e_preventDefault(e); }
      display.wheelStartX = null; // Abort measurement, if in progress
      return
    }

    // 'Project' the visible viewport to cover the area that is being
    // scrolled into view (if we know enough to estimate it).
    if (dy && pixelsPerUnit != null) {
      var pixels = dy * pixelsPerUnit;
      var top = cm.doc.scrollTop, bot = top + display.wrapper.clientHeight;
      if (pixels < 0) { top = Math.max(0, top + pixels - 50); }
      else { bot = Math.min(cm.doc.height, bot + pixels + 50); }
      updateDisplaySimple(cm, {top: top, bottom: bot});
    }

    if (wheelSamples < 20 && e.deltaMode !== 0) {
      if (display.wheelStartX == null) {
        display.wheelStartX = scroll.scrollLeft; display.wheelStartY = scroll.scrollTop;
        display.wheelDX = dx; display.wheelDY = dy;
        setTimeout(function () {
          if (display.wheelStartX == null) { return }
          var movedX = scroll.scrollLeft - display.wheelStartX;
          var movedY = scroll.scrollTop - display.wheelStartY;
          var sample = (movedY && display.wheelDY && movedY / display.wheelDY) ||
            (movedX && display.wheelDX && movedX / display.wheelDX);
          display.wheelStartX = display.wheelStartY = null;
          if (!sample) { return }
          wheelPixelsPerUnit = (wheelPixelsPerUnit * wheelSamples + sample) / (wheelSamples + 1);
          ++wheelSamples;
        }, 200);
      } else {
        display.wheelDX += dx; display.wheelDY += dy;
      }
    }
  }

  // Selection objects are immutable. A new one is created every time
  // the selection changes. A selection is one or more non-overlapping
  // (and non-touching) ranges, sorted, and an integer that indicates
  // which one is the primary selection (the one that's scrolled into
  // view, that getCursor returns, etc).
  var Selection = function(ranges, primIndex) {
    this.ranges = ranges;
    this.primIndex = primIndex;
  };

  Selection.prototype.primary = function () { return this.ranges[this.primIndex] };

  Selection.prototype.equals = function (other) {
    if (other == this) { return true }
    if (other.primIndex != this.primIndex || other.ranges.length != this.ranges.length) { return false }
    for (var i = 0; i < this.ranges.length; i++) {
      var here = this.ranges[i], there = other.ranges[i];
      if (!equalCursorPos(here.anchor, there.anchor) || !equalCursorPos(here.head, there.head)) { return false }
    }
    return true
  };

  Selection.prototype.deepCopy = function () {
    var out = [];
    for (var i = 0; i < this.ranges.length; i++)
      { out[i] = new Range(copyPos(this.ranges[i].anchor), copyPos(this.ranges[i].head)); }
    return new Selection(out, this.primIndex)
  };

  Selection.prototype.somethingSelected = function () {
    for (var i = 0; i < this.ranges.length; i++)
      { if (!this.ranges[i].empty()) { return true } }
    return false
  };

  Selection.prototype.contains = function (pos, end) {
    if (!end) { end = pos; }
    for (var i = 0; i < this.ranges.length; i++) {
      var range = this.ranges[i];
      if (cmp(end, range.from()) >= 0 && cmp(pos, range.to()) <= 0)
        { return i }
    }
    return -1
  };

  var Range = function(anchor, head) {
    this.anchor = anchor; this.head = head;
  };

  Range.prototype.from = function () { return minPos(this.anchor, this.head) };
  Range.prototype.to = function () { return maxPos(this.anchor, this.head) };
  Range.prototype.empty = function () { return this.head.line == this.anchor.line && this.head.ch == this.anchor.ch };

  // Take an unsorted, potentially overlapping set of ranges, and
  // build a selection out of it. 'Consumes' ranges array (modifying
  // it).
  function normalizeSelection(cm, ranges, primIndex) {
    var mayTouch = cm && cm.options.selectionsMayTouch;
    var prim = ranges[primIndex];
    ranges.sort(function (a, b) { return cmp(a.from(), b.from()); });
    primIndex = indexOf(ranges, prim);
    for (var i = 1; i < ranges.length; i++) {
      var cur = ranges[i], prev = ranges[i - 1];
      var diff = cmp(prev.to(), cur.from());
      if (mayTouch && !cur.empty() ? diff > 0 : diff >= 0) {
        var from = minPos(prev.from(), cur.from()), to = maxPos(prev.to(), cur.to());
        var inv = prev.empty() ? cur.from() == cur.head : prev.from() == prev.head;
        if (i <= primIndex) { --primIndex; }
        ranges.splice(--i, 2, new Range(inv ? to : from, inv ? from : to));
      }
    }
    return new Selection(ranges, primIndex)
  }

  function simpleSelection(anchor, head) {
    return new Selection([new Range(anchor, head || anchor)], 0)
  }

  // Compute the position of the end of a change (its 'to' property
  // refers to the pre-change end).
  function changeEnd(change) {
    if (!change.text) { return change.to }
    return Pos(change.from.line + change.text.length - 1,
               lst(change.text).length + (change.text.length == 1 ? change.from.ch : 0))
  }

  // Adjust a position to refer to the post-change position of the
  // same text, or the end of the change if the change covers it.
  function adjustForChange(pos, change) {
    if (cmp(pos, change.from) < 0) { return pos }
    if (cmp(pos, change.to) <= 0) { return changeEnd(change) }

    var line = pos.line + change.text.length - (change.to.line - change.from.line) - 1, ch = pos.ch;
    if (pos.line == change.to.line) { ch += changeEnd(change).ch - change.to.ch; }
    return Pos(line, ch)
  }

  function computeSelAfterChange(doc, change) {
    var out = [];
    for (var i = 0; i < doc.sel.ranges.length; i++) {
      var range = doc.sel.ranges[i];
      out.push(new Range(adjustForChange(range.anchor, change),
                         adjustForChange(range.head, change)));
    }
    return normalizeSelection(doc.cm, out, doc.sel.primIndex)
  }

  function offsetPos(pos, old, nw) {
    if (pos.line == old.line)
      { return Pos(nw.line, pos.ch - old.ch + nw.ch) }
    else
      { return Pos(nw.line + (pos.line - old.line), pos.ch) }
  }

  // Used by replaceSelections to allow moving the selection to the
  // start or around the replaced test. Hint may be "start" or "around".
  function computeReplacedSel(doc, changes, hint) {
    var out = [];
    var oldPrev = Pos(doc.first, 0), newPrev = oldPrev;
    for (var i = 0; i < changes.length; i++) {
      var change = changes[i];
      var from = offsetPos(change.from, oldPrev, newPrev);
      var to = offsetPos(changeEnd(change), oldPrev, newPrev);
      oldPrev = change.to;
      newPrev = to;
      if (hint == "around") {
        var range = doc.sel.ranges[i], inv = cmp(range.head, range.anchor) < 0;
        out[i] = new Range(inv ? to : from, inv ? from : to);
      } else {
        out[i] = new Range(from, from);
      }
    }
    return new Selection(out, doc.sel.primIndex)
  }

  // Used to get the editor into a consistent state again when options change.

  function loadMode(cm) {
    cm.doc.mode = getMode(cm.options, cm.doc.modeOption);
    resetModeState(cm);
  }

  function resetModeState(cm) {
    cm.doc.iter(function (line) {
      if (line.stateAfter) { line.stateAfter = null; }
      if (line.styles) { line.styles = null; }
    });
    cm.doc.modeFrontier = cm.doc.highlightFrontier = cm.doc.first;
    startWorker(cm, 100);
    cm.state.modeGen++;
    if (cm.curOp) { regChange(cm); }
  }

  // DOCUMENT DATA STRUCTURE

  // By default, updates that start and end at the beginning of a line
  // are treated specially, in order to make the association of line
  // widgets and marker elements with the text behave more intuitive.
  function isWholeLineUpdate(doc, change) {
    return change.from.ch == 0 && change.to.ch == 0 && lst(change.text) == "" &&
      (!doc.cm || doc.cm.options.wholeLineUpdateBefore)
  }

  // Perform a change on the document data structure.
  function updateDoc(doc, change, markedSpans, estimateHeight) {
    function spansFor(n) {return markedSpans ? markedSpans[n] : null}
    function update(line, text, spans) {
      updateLine(line, text, spans, estimateHeight);
      signalLater(line, "change", line, change);
    }
    function linesFor(start, end) {
      var result = [];
      for (var i = start; i < end; ++i)
        { result.push(new Line(text[i], spansFor(i), estimateHeight)); }
      return result
    }

    var from = change.from, to = change.to, text = change.text;
    var firstLine = getLine(doc, from.line), lastLine = getLine(doc, to.line);
    var lastText = lst(text), lastSpans = spansFor(text.length - 1), nlines = to.line - from.line;

    // Adjust the line structure
    if (change.full) {
      doc.insert(0, linesFor(0, text.length));
      doc.remove(text.length, doc.size - text.length);
    } else if (isWholeLineUpdate(doc, change)) {
      // This is a whole-line replace. Treated specially to make
      // sure line objects move the way they are supposed to.
      var added = linesFor(0, text.length - 1);
      update(lastLine, lastLine.text, lastSpans);
      if (nlines) { doc.remove(from.line, nlines); }
      if (added.length) { doc.insert(from.line, added); }
    } else if (firstLine == lastLine) {
      if (text.length == 1) {
        update(firstLine, firstLine.text.slice(0, from.ch) + lastText + firstLine.text.slice(to.ch), lastSpans);
      } else {
        var added$1 = linesFor(1, text.length - 1);
        added$1.push(new Line(lastText + firstLine.text.slice(to.ch), lastSpans, estimateHeight));
        update(firstLine, firstLine.text.slice(0, from.ch) + text[0], spansFor(0));
        doc.insert(from.line + 1, added$1);
      }
    } else if (text.length == 1) {
      update(firstLine, firstLine.text.slice(0, from.ch) + text[0] + lastLine.text.slice(to.ch), spansFor(0));
      doc.remove(from.line + 1, nlines);
    } else {
      update(firstLine, firstLine.text.slice(0, from.ch) + text[0], spansFor(0));
      update(lastLine, lastText + lastLine.text.slice(to.ch), lastSpans);
      var added$2 = linesFor(1, text.length - 1);
      if (nlines > 1) { doc.remove(from.line + 1, nlines - 1); }
      doc.insert(from.line + 1, added$2);
    }

    signalLater(doc, "change", doc, change);
  }

  // Call f for all linked documents.
  function linkedDocs(doc, f, sharedHistOnly) {
    function propagate(doc, skip, sharedHist) {
      if (doc.linked) { for (var i = 0; i < doc.linked.length; ++i) {
        var rel = doc.linked[i];
        if (rel.doc == skip) { continue }
        var shared = sharedHist && rel.sharedHist;
        if (sharedHistOnly && !shared) { continue }
        f(rel.doc, shared);
        propagate(rel.doc, doc, shared);
      } }
    }
    propagate(doc, null, true);
  }

  // Attach a document to an editor.
  function attachDoc(cm, doc) {
    if (doc.cm) { throw new Error("This document is already in use.") }
    cm.doc = doc;
    doc.cm = cm;
    estimateLineHeights(cm);
    loadMode(cm);
    setDirectionClass(cm);
    cm.options.direction = doc.direction;
    if (!cm.options.lineWrapping) { findMaxLine(cm); }
    cm.options.mode = doc.modeOption;
    regChange(cm);
  }

  function setDirectionClass(cm) {
  (cm.doc.direction == "rtl" ? addClass : rmClass)(cm.display.lineDiv, "CodeMirror-rtl");
  }

  function directionChanged(cm) {
    runInOp(cm, function () {
      setDirectionClass(cm);
      regChange(cm);
    });
  }

  function History(prev) {
    // Arrays of change events and selections. Doing something adds an
    // event to done and clears undo. Undoing moves events from done
    // to undone, redoing moves them in the other direction.
    this.done = []; this.undone = [];
    this.undoDepth = prev ? prev.undoDepth : Infinity;
    // Used to track when changes can be merged into a single undo
    // event
    this.lastModTime = this.lastSelTime = 0;
    this.lastOp = this.lastSelOp = null;
    this.lastOrigin = this.lastSelOrigin = null;
    // Used by the isClean() method
    this.generation = this.maxGeneration = prev ? prev.maxGeneration : 1;
  }

  // Create a history change event from an updateDoc-style change
  // object.
  function historyChangeFromChange(doc, change) {
    var histChange = {from: copyPos(change.from), to: changeEnd(change), text: getBetween(doc, change.from, change.to)};
    attachLocalSpans(doc, histChange, change.from.line, change.to.line + 1);
    linkedDocs(doc, function (doc) { return attachLocalSpans(doc, histChange, change.from.line, change.to.line + 1); }, true);
    return histChange
  }

  // Pop all selection events off the end of a history array. Stop at
  // a change event.
  function clearSelectionEvents(array) {
    while (array.length) {
      var last = lst(array);
      if (last.ranges) { array.pop(); }
      else { break }
    }
  }

  // Find the top change event in the history. Pop off selection
  // events that are in the way.
  function lastChangeEvent(hist, force) {
    if (force) {
      clearSelectionEvents(hist.done);
      return lst(hist.done)
    } else if (hist.done.length && !lst(hist.done).ranges) {
      return lst(hist.done)
    } else if (hist.done.length > 1 && !hist.done[hist.done.length - 2].ranges) {
      hist.done.pop();
      return lst(hist.done)
    }
  }

  // Register a change in the history. Merges changes that are within
  // a single operation, or are close together with an origin that
  // allows merging (starting with "+") into a single event.
  function addChangeToHistory(doc, change, selAfter, opId) {
    var hist = doc.history;
    hist.undone.length = 0;
    var time = +new Date, cur;
    var last;

    if ((hist.lastOp == opId ||
         hist.lastOrigin == change.origin && change.origin &&
         ((change.origin.charAt(0) == "+" && hist.lastModTime > time - (doc.cm ? doc.cm.options.historyEventDelay : 500)) ||
          change.origin.charAt(0) == "*")) &&
        (cur = lastChangeEvent(hist, hist.lastOp == opId))) {
      // Merge this change into the last event
      last = lst(cur.changes);
      if (cmp(change.from, change.to) == 0 && cmp(change.from, last.to) == 0) {
        // Optimized case for simple insertion -- don't want to add
        // new changesets for every character typed
        last.to = changeEnd(change);
      } else {
        // Add new sub-event
        cur.changes.push(historyChangeFromChange(doc, change));
      }
    } else {
      // Can not be merged, start a new event.
      var before = lst(hist.done);
      if (!before || !before.ranges)
        { pushSelectionToHistory(doc.sel, hist.done); }
      cur = {changes: [historyChangeFromChange(doc, change)],
             generation: hist.generation};
      hist.done.push(cur);
      while (hist.done.length > hist.undoDepth) {
        hist.done.shift();
        if (!hist.done[0].ranges) { hist.done.shift(); }
      }
    }
    hist.done.push(selAfter);
    hist.generation = ++hist.maxGeneration;
    hist.lastModTime = hist.lastSelTime = time;
    hist.lastOp = hist.lastSelOp = opId;
    hist.lastOrigin = hist.lastSelOrigin = change.origin;

    if (!last) { signal(doc, "historyAdded"); }
  }

  function selectionEventCanBeMerged(doc, origin, prev, sel) {
    var ch = origin.charAt(0);
    return ch == "*" ||
      ch == "+" &&
      prev.ranges.length == sel.ranges.length &&
      prev.somethingSelected() == sel.somethingSelected() &&
      new Date - doc.history.lastSelTime <= (doc.cm ? doc.cm.options.historyEventDelay : 500)
  }

  // Called whenever the selection changes, sets the new selection as
  // the pending selection in the history, and pushes the old pending
  // selection into the 'done' array when it was significantly
  // different (in number of selected ranges, emptiness, or time).
  function addSelectionToHistory(doc, sel, opId, options) {
    var hist = doc.history, origin = options && options.origin;

    // A new event is started when the previous origin does not match
    // the current, or the origins don't allow matching. Origins
    // starting with * are always merged, those starting with + are
    // merged when similar and close together in time.
    if (opId == hist.lastSelOp ||
        (origin && hist.lastSelOrigin == origin &&
         (hist.lastModTime == hist.lastSelTime && hist.lastOrigin == origin ||
          selectionEventCanBeMerged(doc, origin, lst(hist.done), sel))))
      { hist.done[hist.done.length - 1] = sel; }
    else
      { pushSelectionToHistory(sel, hist.done); }

    hist.lastSelTime = +new Date;
    hist.lastSelOrigin = origin;
    hist.lastSelOp = opId;
    if (options && options.clearRedo !== false)
      { clearSelectionEvents(hist.undone); }
  }

  function pushSelectionToHistory(sel, dest) {
    var top = lst(dest);
    if (!(top && top.ranges && top.equals(sel)))
      { dest.push(sel); }
  }

  // Used to store marked span information in the history.
  function attachLocalSpans(doc, change, from, to) {
    var existing = change["spans_" + doc.id], n = 0;
    doc.iter(Math.max(doc.first, from), Math.min(doc.first + doc.size, to), function (line) {
      if (line.markedSpans)
        { (existing || (existing = change["spans_" + doc.id] = {}))[n] = line.markedSpans; }
      ++n;
    });
  }

  // When un/re-doing restores text containing marked spans, those
  // that have been explicitly cleared should not be restored.
  function removeClearedSpans(spans) {
    if (!spans) { return null }
    var out;
    for (var i = 0; i < spans.length; ++i) {
      if (spans[i].marker.explicitlyCleared) { if (!out) { out = spans.slice(0, i); } }
      else if (out) { out.push(spans[i]); }
    }
    return !out ? spans : out.length ? out : null
  }

  // Retrieve and filter the old marked spans stored in a change event.
  function getOldSpans(doc, change) {
    var found = change["spans_" + doc.id];
    if (!found) { return null }
    var nw = [];
    for (var i = 0; i < change.text.length; ++i)
      { nw.push(removeClearedSpans(found[i])); }
    return nw
  }

  // Used for un/re-doing changes from the history. Combines the
  // result of computing the existing spans with the set of spans that
  // existed in the history (so that deleting around a span and then
  // undoing brings back the span).
  function mergeOldSpans(doc, change) {
    var old = getOldSpans(doc, change);
    var stretched = stretchSpansOverChange(doc, change);
    if (!old) { return stretched }
    if (!stretched) { return old }

    for (var i = 0; i < old.length; ++i) {
      var oldCur = old[i], stretchCur = stretched[i];
      if (oldCur && stretchCur) {
        spans: for (var j = 0; j < stretchCur.length; ++j) {
          var span = stretchCur[j];
          for (var k = 0; k < oldCur.length; ++k)
            { if (oldCur[k].marker == span.marker) { continue spans } }
          oldCur.push(span);
        }
      } else if (stretchCur) {
        old[i] = stretchCur;
      }
    }
    return old
  }

  // Used both to provide a JSON-safe object in .getHistory, and, when
  // detaching a document, to split the history in two
  function copyHistoryArray(events, newGroup, instantiateSel) {
    var copy = [];
    for (var i = 0; i < events.length; ++i) {
      var event = events[i];
      if (event.ranges) {
        copy.push(instantiateSel ? Selection.prototype.deepCopy.call(event) : event);
        continue
      }
      var changes = event.changes, newChanges = [];
      copy.push({changes: newChanges});
      for (var j = 0; j < changes.length; ++j) {
        var change = changes[j], m = (void 0);
        newChanges.push({from: change.from, to: change.to, text: change.text});
        if (newGroup) { for (var prop in change) { if (m = prop.match(/^spans_(\d+)$/)) {
          if (indexOf(newGroup, Number(m[1])) > -1) {
            lst(newChanges)[prop] = change[prop];
            delete change[prop];
          }
        } } }
      }
    }
    return copy
  }

  // The 'scroll' parameter given to many of these indicated whether
  // the new cursor position should be scrolled into view after
  // modifying the selection.

  // If shift is held or the extend flag is set, extends a range to
  // include a given position (and optionally a second position).
  // Otherwise, simply returns the range between the given positions.
  // Used for cursor motion and such.
  function extendRange(range, head, other, extend) {
    if (extend) {
      var anchor = range.anchor;
      if (other) {
        var posBefore = cmp(head, anchor) < 0;
        if (posBefore != (cmp(other, anchor) < 0)) {
          anchor = head;
          head = other;
        } else if (posBefore != (cmp(head, other) < 0)) {
          head = other;
        }
      }
      return new Range(anchor, head)
    } else {
      return new Range(other || head, head)
    }
  }

  // Extend the primary selection range, discard the rest.
  function extendSelection(doc, head, other, options, extend) {
    if (extend == null) { extend = doc.cm && (doc.cm.display.shift || doc.extend); }
    setSelection(doc, new Selection([extendRange(doc.sel.primary(), head, other, extend)], 0), options);
  }

  // Extend all selections (pos is an array of selections with length
  // equal the number of selections)
  function extendSelections(doc, heads, options) {
    var out = [];
    var extend = doc.cm && (doc.cm.display.shift || doc.extend);
    for (var i = 0; i < doc.sel.ranges.length; i++)
      { out[i] = extendRange(doc.sel.ranges[i], heads[i], null, extend); }
    var newSel = normalizeSelection(doc.cm, out, doc.sel.primIndex);
    setSelection(doc, newSel, options);
  }

  // Updates a single range in the selection.
  function replaceOneSelection(doc, i, range, options) {
    var ranges = doc.sel.ranges.slice(0);
    ranges[i] = range;
    setSelection(doc, normalizeSelection(doc.cm, ranges, doc.sel.primIndex), options);
  }

  // Reset the selection to a single range.
  function setSimpleSelection(doc, anchor, head, options) {
    setSelection(doc, simpleSelection(anchor, head), options);
  }

  // Give beforeSelectionChange handlers a change to influence a
  // selection update.
  function filterSelectionChange(doc, sel, options) {
    var obj = {
      ranges: sel.ranges,
      update: function(ranges) {
        this.ranges = [];
        for (var i = 0; i < ranges.length; i++)
          { this.ranges[i] = new Range(clipPos(doc, ranges[i].anchor),
                                     clipPos(doc, ranges[i].head)); }
      },
      origin: options && options.origin
    };
    signal(doc, "beforeSelectionChange", doc, obj);
    if (doc.cm) { signal(doc.cm, "beforeSelectionChange", doc.cm, obj); }
    if (obj.ranges != sel.ranges) { return normalizeSelection(doc.cm, obj.ranges, obj.ranges.length - 1) }
    else { return sel }
  }

  function setSelectionReplaceHistory(doc, sel, options) {
    var done = doc.history.done, last = lst(done);
    if (last && last.ranges) {
      done[done.length - 1] = sel;
      setSelectionNoUndo(doc, sel, options);
    } else {
      setSelection(doc, sel, options);
    }
  }

  // Set a new selection.
  function setSelection(doc, sel, options) {
    setSelectionNoUndo(doc, sel, options);
    addSelectionToHistory(doc, doc.sel, doc.cm ? doc.cm.curOp.id : NaN, options);
  }

  function setSelectionNoUndo(doc, sel, options) {
    if (hasHandler(doc, "beforeSelectionChange") || doc.cm && hasHandler(doc.cm, "beforeSelectionChange"))
      { sel = filterSelectionChange(doc, sel, options); }

    var bias = options && options.bias ||
      (cmp(sel.primary().head, doc.sel.primary().head) < 0 ? -1 : 1);
    setSelectionInner(doc, skipAtomicInSelection(doc, sel, bias, true));

    if (!(options && options.scroll === false) && doc.cm && doc.cm.getOption("readOnly") != "nocursor")
      { ensureCursorVisible(doc.cm); }
  }

  function setSelectionInner(doc, sel) {
    if (sel.equals(doc.sel)) { return }

    doc.sel = sel;

    if (doc.cm) {
      doc.cm.curOp.updateInput = 1;
      doc.cm.curOp.selectionChanged = true;
      signalCursorActivity(doc.cm);
    }
    signalLater(doc, "cursorActivity", doc);
  }

  // Verify that the selection does not partially select any atomic
  // marked ranges.
  function reCheckSelection(doc) {
    setSelectionInner(doc, skipAtomicInSelection(doc, doc.sel, null, false));
  }

  // Return a selection that does not partially select any atomic
  // ranges.
  function skipAtomicInSelection(doc, sel, bias, mayClear) {
    var out;
    for (var i = 0; i < sel.ranges.length; i++) {
      var range = sel.ranges[i];
      var old = sel.ranges.length == doc.sel.ranges.length && doc.sel.ranges[i];
      var newAnchor = skipAtomic(doc, range.anchor, old && old.anchor, bias, mayClear);
      var newHead = skipAtomic(doc, range.head, old && old.head, bias, mayClear);
      if (out || newAnchor != range.anchor || newHead != range.head) {
        if (!out) { out = sel.ranges.slice(0, i); }
        out[i] = new Range(newAnchor, newHead);
      }
    }
    return out ? normalizeSelection(doc.cm, out, sel.primIndex) : sel
  }

  function skipAtomicInner(doc, pos, oldPos, dir, mayClear) {
    var line = getLine(doc, pos.line);
    if (line.markedSpans) { for (var i = 0; i < line.markedSpans.length; ++i) {
      var sp = line.markedSpans[i], m = sp.marker;

      // Determine if we should prevent the cursor being placed to the left/right of an atomic marker
      // Historically this was determined using the inclusiveLeft/Right option, but the new way to control it
      // is with selectLeft/Right
      var preventCursorLeft = ("selectLeft" in m) ? !m.selectLeft : m.inclusiveLeft;
      var preventCursorRight = ("selectRight" in m) ? !m.selectRight : m.inclusiveRight;

      if ((sp.from == null || (preventCursorLeft ? sp.from <= pos.ch : sp.from < pos.ch)) &&
          (sp.to == null || (preventCursorRight ? sp.to >= pos.ch : sp.to > pos.ch))) {
        if (mayClear) {
          signal(m, "beforeCursorEnter");
          if (m.explicitlyCleared) {
            if (!line.markedSpans) { break }
            else {--i; continue}
          }
        }
        if (!m.atomic) { continue }

        if (oldPos) {
          var near = m.find(dir < 0 ? 1 : -1), diff = (void 0);
          if (dir < 0 ? preventCursorRight : preventCursorLeft)
            { near = movePos(doc, near, -dir, near && near.line == pos.line ? line : null); }
          if (near && near.line == pos.line && (diff = cmp(near, oldPos)) && (dir < 0 ? diff < 0 : diff > 0))
            { return skipAtomicInner(doc, near, pos, dir, mayClear) }
        }

        var far = m.find(dir < 0 ? -1 : 1);
        if (dir < 0 ? preventCursorLeft : preventCursorRight)
          { far = movePos(doc, far, dir, far.line == pos.line ? line : null); }
        return far ? skipAtomicInner(doc, far, pos, dir, mayClear) : null
      }
    } }
    return pos
  }

  // Ensure a given position is not inside an atomic range.
  function skipAtomic(doc, pos, oldPos, bias, mayClear) {
    var dir = bias || 1;
    var found = skipAtomicInner(doc, pos, oldPos, dir, mayClear) ||
        (!mayClear && skipAtomicInner(doc, pos, oldPos, dir, true)) ||
        skipAtomicInner(doc, pos, oldPos, -dir, mayClear) ||
        (!mayClear && skipAtomicInner(doc, pos, oldPos, -dir, true));
    if (!found) {
      doc.cantEdit = true;
      return Pos(doc.first, 0)
    }
    return found
  }

  function movePos(doc, pos, dir, line) {
    if (dir < 0 && pos.ch == 0) {
      if (pos.line > doc.first) { return clipPos(doc, Pos(pos.line - 1)) }
      else { return null }
    } else if (dir > 0 && pos.ch == (line || getLine(doc, pos.line)).text.length) {
      if (pos.line < doc.first + doc.size - 1) { return Pos(pos.line + 1, 0) }
      else { return null }
    } else {
      return new Pos(pos.line, pos.ch + dir)
    }
  }

  function selectAll(cm) {
    cm.setSelection(Pos(cm.firstLine(), 0), Pos(cm.lastLine()), sel_dontScroll);
  }

  // UPDATING

  // Allow "beforeChange" event handlers to influence a change
  function filterChange(doc, change, update) {
    var obj = {
      canceled: false,
      from: change.from,
      to: change.to,
      text: change.text,
      origin: change.origin,
      cancel: function () { return obj.canceled = true; }
    };
    if (update) { obj.update = function (from, to, text, origin) {
      if (from) { obj.from = clipPos(doc, from); }
      if (to) { obj.to = clipPos(doc, to); }
      if (text) { obj.text = text; }
      if (origin !== undefined) { obj.origin = origin; }
    }; }
    signal(doc, "beforeChange", doc, obj);
    if (doc.cm) { signal(doc.cm, "beforeChange", doc.cm, obj); }

    if (obj.canceled) {
      if (doc.cm) { doc.cm.curOp.updateInput = 2; }
      return null
    }
    return {from: obj.from, to: obj.to, text: obj.text, origin: obj.origin}
  }

  // Apply a change to a document, and add it to the document's
  // history, and propagating it to all linked documents.
  function makeChange(doc, change, ignoreReadOnly) {
    if (doc.cm) {
      if (!doc.cm.curOp) { return operation(doc.cm, makeChange)(doc, change, ignoreReadOnly) }
      if (doc.cm.state.suppressEdits) { return }
    }

    if (hasHandler(doc, "beforeChange") || doc.cm && hasHandler(doc.cm, "beforeChange")) {
      change = filterChange(doc, change, true);
      if (!change) { return }
    }

    // Possibly split or suppress the update based on the presence
    // of read-only spans in its range.
    var split = sawReadOnlySpans && !ignoreReadOnly && removeReadOnlyRanges(doc, change.from, change.to);
    if (split) {
      for (var i = split.length - 1; i >= 0; --i)
        { makeChangeInner(doc, {from: split[i].from, to: split[i].to, text: i ? [""] : change.text, origin: change.origin}); }
    } else {
      makeChangeInner(doc, change);
    }
  }

  function makeChangeInner(doc, change) {
    if (change.text.length == 1 && change.text[0] == "" && cmp(change.from, change.to) == 0) { return }
    var selAfter = computeSelAfterChange(doc, change);
    addChangeToHistory(doc, change, selAfter, doc.cm ? doc.cm.curOp.id : NaN);

    makeChangeSingleDoc(doc, change, selAfter, stretchSpansOverChange(doc, change));
    var rebased = [];

    linkedDocs(doc, function (doc, sharedHist) {
      if (!sharedHist && indexOf(rebased, doc.history) == -1) {
        rebaseHist(doc.history, change);
        rebased.push(doc.history);
      }
      makeChangeSingleDoc(doc, change, null, stretchSpansOverChange(doc, change));
    });
  }

  // Revert a change stored in a document's history.
  function makeChangeFromHistory(doc, type, allowSelectionOnly) {
    var suppress = doc.cm && doc.cm.state.suppressEdits;
    if (suppress && !allowSelectionOnly) { return }

    var hist = doc.history, event, selAfter = doc.sel;
    var source = type == "undo" ? hist.done : hist.undone, dest = type == "undo" ? hist.undone : hist.done;

    // Verify that there is a useable event (so that ctrl-z won't
    // needlessly clear selection events)
    var i = 0;
    for (; i < source.length; i++) {
      event = source[i];
      if (allowSelectionOnly ? event.ranges && !event.equals(doc.sel) : !event.ranges)
        { break }
    }
    if (i == source.length) { return }
    hist.lastOrigin = hist.lastSelOrigin = null;

    for (;;) {
      event = source.pop();
      if (event.ranges) {
        pushSelectionToHistory(event, dest);
        if (allowSelectionOnly && !event.equals(doc.sel)) {
          setSelection(doc, event, {clearRedo: false});
          return
        }
        selAfter = event;
      } else if (suppress) {
        source.push(event);
        return
      } else { break }
    }

    // Build up a reverse change object to add to the opposite history
    // stack (redo when undoing, and vice versa).
    var antiChanges = [];
    pushSelectionToHistory(selAfter, dest);
    dest.push({changes: antiChanges, generation: hist.generation});
    hist.generation = event.generation || ++hist.maxGeneration;

    var filter = hasHandler(doc, "beforeChange") || doc.cm && hasHandler(doc.cm, "beforeChange");

    var loop = function ( i ) {
      var change = event.changes[i];
      change.origin = type;
      if (filter && !filterChange(doc, change, false)) {
        source.length = 0;
        return {}
      }

      antiChanges.push(historyChangeFromChange(doc, change));

      var after = i ? computeSelAfterChange(doc, change) : lst(source);
      makeChangeSingleDoc(doc, change, after, mergeOldSpans(doc, change));
      if (!i && doc.cm) { doc.cm.scrollIntoView({from: change.from, to: changeEnd(change)}); }
      var rebased = [];

      // Propagate to the linked documents
      linkedDocs(doc, function (doc, sharedHist) {
        if (!sharedHist && indexOf(rebased, doc.history) == -1) {
          rebaseHist(doc.history, change);
          rebased.push(doc.history);
        }
        makeChangeSingleDoc(doc, change, null, mergeOldSpans(doc, change));
      });
    };

    for (var i$1 = event.changes.length - 1; i$1 >= 0; --i$1) {
      var returned = loop( i$1 );

      if ( returned ) return returned.v;
    }
  }

  // Sub-views need their line numbers shifted when text is added
  // above or below them in the parent document.
  function shiftDoc(doc, distance) {
    if (distance == 0) { return }
    doc.first += distance;
    doc.sel = new Selection(map(doc.sel.ranges, function (range) { return new Range(
      Pos(range.anchor.line + distance, range.anchor.ch),
      Pos(range.head.line + distance, range.head.ch)
    ); }), doc.sel.primIndex);
    if (doc.cm) {
      regChange(doc.cm, doc.first, doc.first - distance, distance);
      for (var d = doc.cm.display, l = d.viewFrom; l < d.viewTo; l++)
        { regLineChange(doc.cm, l, "gutter"); }
    }
  }

  // More lower-level change function, handling only a single document
  // (not linked ones).
  function makeChangeSingleDoc(doc, change, selAfter, spans) {
    if (doc.cm && !doc.cm.curOp)
      { return operation(doc.cm, makeChangeSingleDoc)(doc, change, selAfter, spans) }

    if (change.to.line < doc.first) {
      shiftDoc(doc, change.text.length - 1 - (change.to.line - change.from.line));
      return
    }
    if (change.from.line > doc.lastLine()) { return }

    // Clip the change to the size of this doc
    if (change.from.line < doc.first) {
      var shift = change.text.length - 1 - (doc.first - change.from.line);
      shiftDoc(doc, shift);
      change = {from: Pos(doc.first, 0), to: Pos(change.to.line + shift, change.to.ch),
                text: [lst(change.text)], origin: change.origin};
    }
    var last = doc.lastLine();
    if (change.to.line > last) {
      change = {from: change.from, to: Pos(last, getLine(doc, last).text.length),
                text: [change.text[0]], origin: change.origin};
    }

    change.removed = getBetween(doc, change.from, change.to);

    if (!selAfter) { selAfter = computeSelAfterChange(doc, change); }
    if (doc.cm) { makeChangeSingleDocInEditor(doc.cm, change, spans); }
    else { updateDoc(doc, change, spans); }
    setSelectionNoUndo(doc, selAfter, sel_dontScroll);

    if (doc.cantEdit && skipAtomic(doc, Pos(doc.firstLine(), 0)))
      { doc.cantEdit = false; }
  }

  // Handle the interaction of a change to a document with the editor
  // that this document is part of.
  function makeChangeSingleDocInEditor(cm, change, spans) {
    var doc = cm.doc, display = cm.display, from = change.from, to = change.to;

    var recomputeMaxLength = false, checkWidthStart = from.line;
    if (!cm.options.lineWrapping) {
      checkWidthStart = lineNo(visualLine(getLine(doc, from.line)));
      doc.iter(checkWidthStart, to.line + 1, function (line) {
        if (line == display.maxLine) {
          recomputeMaxLength = true;
          return true
        }
      });
    }

    if (doc.sel.contains(change.from, change.to) > -1)
      { signalCursorActivity(cm); }

    updateDoc(doc, change, spans, estimateHeight(cm));

    if (!cm.options.lineWrapping) {
      doc.iter(checkWidthStart, from.line + change.text.length, function (line) {
        var len = lineLength(line);
        if (len > display.maxLineLength) {
          display.maxLine = line;
          display.maxLineLength = len;
          display.maxLineChanged = true;
          recomputeMaxLength = false;
        }
      });
      if (recomputeMaxLength) { cm.curOp.updateMaxLine = true; }
    }

    retreatFrontier(doc, from.line);
    startWorker(cm, 400);

    var lendiff = change.text.length - (to.line - from.line) - 1;
    // Remember that these lines changed, for updating the display
    if (change.full)
      { regChange(cm); }
    else if (from.line == to.line && change.text.length == 1 && !isWholeLineUpdate(cm.doc, change))
      { regLineChange(cm, from.line, "text"); }
    else
      { regChange(cm, from.line, to.line + 1, lendiff); }

    var changesHandler = hasHandler(cm, "changes"), changeHandler = hasHandler(cm, "change");
    if (changeHandler || changesHandler) {
      var obj = {
        from: from, to: to,
        text: change.text,
        removed: change.removed,
        origin: change.origin
      };
      if (changeHandler) { signalLater(cm, "change", cm, obj); }
      if (changesHandler) { (cm.curOp.changeObjs || (cm.curOp.changeObjs = [])).push(obj); }
    }
    cm.display.selForContextMenu = null;
  }

  function replaceRange(doc, code, from, to, origin) {
    var assign;

    if (!to) { to = from; }
    if (cmp(to, from) < 0) { (assign = [to, from], from = assign[0], to = assign[1]); }
    if (typeof code == "string") { code = doc.splitLines(code); }
    makeChange(doc, {from: from, to: to, text: code, origin: origin});
  }

  // Rebasing/resetting history to deal with externally-sourced changes

  function rebaseHistSelSingle(pos, from, to, diff) {
    if (to < pos.line) {
      pos.line += diff;
    } else if (from < pos.line) {
      pos.line = from;
      pos.ch = 0;
    }
  }

  // Tries to rebase an array of history events given a change in the
  // document. If the change touches the same lines as the event, the
  // event, and everything 'behind' it, is discarded. If the change is
  // before the event, the event's positions are updated. Uses a
  // copy-on-write scheme for the positions, to avoid having to
  // reallocate them all on every rebase, but also avoid problems with
  // shared position objects being unsafely updated.
  function rebaseHistArray(array, from, to, diff) {
    for (var i = 0; i < array.length; ++i) {
      var sub = array[i], ok = true;
      if (sub.ranges) {
        if (!sub.copied) { sub = array[i] = sub.deepCopy(); sub.copied = true; }
        for (var j = 0; j < sub.ranges.length; j++) {
          rebaseHistSelSingle(sub.ranges[j].anchor, from, to, diff);
          rebaseHistSelSingle(sub.ranges[j].head, from, to, diff);
        }
        continue
      }
      for (var j$1 = 0; j$1 < sub.changes.length; ++j$1) {
        var cur = sub.changes[j$1];
        if (to < cur.from.line) {
          cur.from = Pos(cur.from.line + diff, cur.from.ch);
          cur.to = Pos(cur.to.line + diff, cur.to.ch);
        } else if (from <= cur.to.line) {
          ok = false;
          break
        }
      }
      if (!ok) {
        array.splice(0, i + 1);
        i = 0;
      }
    }
  }

  function rebaseHist(hist, change) {
    var from = change.from.line, to = change.to.line, diff = change.text.length - (to - from) - 1;
    rebaseHistArray(hist.done, from, to, diff);
    rebaseHistArray(hist.undone, from, to, diff);
  }

  // Utility for applying a change to a line by handle or number,
  // returning the number and optionally registering the line as
  // changed.
  function changeLine(doc, handle, changeType, op) {
    var no = handle, line = handle;
    if (typeof handle == "number") { line = getLine(doc, clipLine(doc, handle)); }
    else { no = lineNo(handle); }
    if (no == null) { return null }
    if (op(line, no) && doc.cm) { regLineChange(doc.cm, no, changeType); }
    return line
  }

  // The document is represented as a BTree consisting of leaves, with
  // chunk of lines in them, and branches, with up to ten leaves or
  // other branch nodes below them. The top node is always a branch
  // node, and is the document object itself (meaning it has
  // additional methods and properties).
  //
  // All nodes have parent links. The tree is used both to go from
  // line numbers to line objects, and to go from objects to numbers.
  // It also indexes by height, and is used to convert between height
  // and line object, and to find the total height of the document.
  //
  // See also http://marijnhaverbeke.nl/blog/codemirror-line-tree.html

  function LeafChunk(lines) {
    this.lines = lines;
    this.parent = null;
    var height = 0;
    for (var i = 0; i < lines.length; ++i) {
      lines[i].parent = this;
      height += lines[i].height;
    }
    this.height = height;
  }

  LeafChunk.prototype = {
    chunkSize: function() { return this.lines.length },

    // Remove the n lines at offset 'at'.
    removeInner: function(at, n) {
      for (var i = at, e = at + n; i < e; ++i) {
        var line = this.lines[i];
        this.height -= line.height;
        cleanUpLine(line);
        signalLater(line, "delete");
      }
      this.lines.splice(at, n);
    },

    // Helper used to collapse a small branch into a single leaf.
    collapse: function(lines) {
      lines.push.apply(lines, this.lines);
    },

    // Insert the given array of lines at offset 'at', count them as
    // having the given height.
    insertInner: function(at, lines, height) {
      this.height += height;
      this.lines = this.lines.slice(0, at).concat(lines).concat(this.lines.slice(at));
      for (var i = 0; i < lines.length; ++i) { lines[i].parent = this; }
    },

    // Used to iterate over a part of the tree.
    iterN: function(at, n, op) {
      for (var e = at + n; at < e; ++at)
        { if (op(this.lines[at])) { return true } }
    }
  };

  function BranchChunk(children) {
    this.children = children;
    var size = 0, height = 0;
    for (var i = 0; i < children.length; ++i) {
      var ch = children[i];
      size += ch.chunkSize(); height += ch.height;
      ch.parent = this;
    }
    this.size = size;
    this.height = height;
    this.parent = null;
  }

  BranchChunk.prototype = {
    chunkSize: function() { return this.size },

    removeInner: function(at, n) {
      this.size -= n;
      for (var i = 0; i < this.children.length; ++i) {
        var child = this.children[i], sz = child.chunkSize();
        if (at < sz) {
          var rm = Math.min(n, sz - at), oldHeight = child.height;
          child.removeInner(at, rm);
          this.height -= oldHeight - child.height;
          if (sz == rm) { this.children.splice(i--, 1); child.parent = null; }
          if ((n -= rm) == 0) { break }
          at = 0;
        } else { at -= sz; }
      }
      // If the result is smaller than 25 lines, ensure that it is a
      // single leaf node.
      if (this.size - n < 25 &&
          (this.children.length > 1 || !(this.children[0] instanceof LeafChunk))) {
        var lines = [];
        this.collapse(lines);
        this.children = [new LeafChunk(lines)];
        this.children[0].parent = this;
      }
    },

    collapse: function(lines) {
      for (var i = 0; i < this.children.length; ++i) { this.children[i].collapse(lines); }
    },

    insertInner: function(at, lines, height) {
      this.size += lines.length;
      this.height += height;
      for (var i = 0; i < this.children.length; ++i) {
        var child = this.children[i], sz = child.chunkSize();
        if (at <= sz) {
          child.insertInner(at, lines, height);
          if (child.lines && child.lines.length > 50) {
            // To avoid memory thrashing when child.lines is huge (e.g. first view of a large file), it's never spliced.
            // Instead, small slices are taken. They're taken in order because sequential memory accesses are fastest.
            var remaining = child.lines.length % 25 + 25;
            for (var pos = remaining; pos < child.lines.length;) {
              var leaf = new LeafChunk(child.lines.slice(pos, pos += 25));
              child.height -= leaf.height;
              this.children.splice(++i, 0, leaf);
              leaf.parent = this;
            }
            child.lines = child.lines.slice(0, remaining);
            this.maybeSpill();
          }
          break
        }
        at -= sz;
      }
    },

    // When a node has grown, check whether it should be split.
    maybeSpill: function() {
      if (this.children.length <= 10) { return }
      var me = this;
      do {
        var spilled = me.children.splice(me.children.length - 5, 5);
        var sibling = new BranchChunk(spilled);
        if (!me.parent) { // Become the parent node
          var copy = new BranchChunk(me.children);
          copy.parent = me;
          me.children = [copy, sibling];
          me = copy;
       } else {
          me.size -= sibling.size;
          me.height -= sibling.height;
          var myIndex = indexOf(me.parent.children, me);
          me.parent.children.splice(myIndex + 1, 0, sibling);
        }
        sibling.parent = me.parent;
      } while (me.children.length > 10)
      me.parent.maybeSpill();
    },

    iterN: function(at, n, op) {
      for (var i = 0; i < this.children.length; ++i) {
        var child = this.children[i], sz = child.chunkSize();
        if (at < sz) {
          var used = Math.min(n, sz - at);
          if (child.iterN(at, used, op)) { return true }
          if ((n -= used) == 0) { break }
          at = 0;
        } else { at -= sz; }
      }
    }
  };

  // Line widgets are block elements displayed above or below a line.

  var LineWidget = function(doc, node, options) {
    if (options) { for (var opt in options) { if (options.hasOwnProperty(opt))
      { this[opt] = options[opt]; } } }
    this.doc = doc;
    this.node = node;
  };

  LineWidget.prototype.clear = function () {
    var cm = this.doc.cm, ws = this.line.widgets, line = this.line, no = lineNo(line);
    if (no == null || !ws) { return }
    for (var i = 0; i < ws.length; ++i) { if (ws[i] == this) { ws.splice(i--, 1); } }
    if (!ws.length) { line.widgets = null; }
    var height = widgetHeight(this);
    updateLineHeight(line, Math.max(0, line.height - height));
    if (cm) {
      runInOp(cm, function () {
        adjustScrollWhenAboveVisible(cm, line, -height);
        regLineChange(cm, no, "widget");
      });
      signalLater(cm, "lineWidgetCleared", cm, this, no);
    }
  };

  LineWidget.prototype.changed = function () {
      var this$1 = this;

    var oldH = this.height, cm = this.doc.cm, line = this.line;
    this.height = null;
    var diff = widgetHeight(this) - oldH;
    if (!diff) { return }
    if (!lineIsHidden(this.doc, line)) { updateLineHeight(line, line.height + diff); }
    if (cm) {
      runInOp(cm, function () {
        cm.curOp.forceUpdate = true;
        adjustScrollWhenAboveVisible(cm, line, diff);
        signalLater(cm, "lineWidgetChanged", cm, this$1, lineNo(line));
      });
    }
  };
  eventMixin(LineWidget);

  function adjustScrollWhenAboveVisible(cm, line, diff) {
    if (heightAtLine(line) < ((cm.curOp && cm.curOp.scrollTop) || cm.doc.scrollTop))
      { addToScrollTop(cm, diff); }
  }

  function addLineWidget(doc, handle, node, options) {
    var widget = new LineWidget(doc, node, options);
    var cm = doc.cm;
    if (cm && widget.noHScroll) { cm.display.alignWidgets = true; }
    changeLine(doc, handle, "widget", function (line) {
      var widgets = line.widgets || (line.widgets = []);
      if (widget.insertAt == null) { widgets.push(widget); }
      else { widgets.splice(Math.min(widgets.length, Math.max(0, widget.insertAt)), 0, widget); }
      widget.line = line;
      if (cm && !lineIsHidden(doc, line)) {
        var aboveVisible = heightAtLine(line) < doc.scrollTop;
        updateLineHeight(line, line.height + widgetHeight(widget));
        if (aboveVisible) { addToScrollTop(cm, widget.height); }
        cm.curOp.forceUpdate = true;
      }
      return true
    });
    if (cm) { signalLater(cm, "lineWidgetAdded", cm, widget, typeof handle == "number" ? handle : lineNo(handle)); }
    return widget
  }

  // TEXTMARKERS

  // Created with markText and setBookmark methods. A TextMarker is a
  // handle that can be used to clear or find a marked position in the
  // document. Line objects hold arrays (markedSpans) containing
  // {from, to, marker} object pointing to such marker objects, and
  // indicating that such a marker is present on that line. Multiple
  // lines may point to the same marker when it spans across lines.
  // The spans will have null for their from/to properties when the
  // marker continues beyond the start/end of the line. Markers have
  // links back to the lines they currently touch.

  // Collapsed markers have unique ids, in order to be able to order
  // them, which is needed for uniquely determining an outer marker
  // when they overlap (they may nest, but not partially overlap).
  var nextMarkerId = 0;

  var TextMarker = function(doc, type) {
    this.lines = [];
    this.type = type;
    this.doc = doc;
    this.id = ++nextMarkerId;
  };

  // Clear the marker.
  TextMarker.prototype.clear = function () {
    if (this.explicitlyCleared) { return }
    var cm = this.doc.cm, withOp = cm && !cm.curOp;
    if (withOp) { startOperation(cm); }
    if (hasHandler(this, "clear")) {
      var found = this.find();
      if (found) { signalLater(this, "clear", found.from, found.to); }
    }
    var min = null, max = null;
    for (var i = 0; i < this.lines.length; ++i) {
      var line = this.lines[i];
      var span = getMarkedSpanFor(line.markedSpans, this);
      if (cm && !this.collapsed) { regLineChange(cm, lineNo(line), "text"); }
      else if (cm) {
        if (span.to != null) { max = lineNo(line); }
        if (span.from != null) { min = lineNo(line); }
      }
      line.markedSpans = removeMarkedSpan(line.markedSpans, span);
      if (span.from == null && this.collapsed && !lineIsHidden(this.doc, line) && cm)
        { updateLineHeight(line, textHeight(cm.display)); }
    }
    if (cm && this.collapsed && !cm.options.lineWrapping) { for (var i$1 = 0; i$1 < this.lines.length; ++i$1) {
      var visual = visualLine(this.lines[i$1]), len = lineLength(visual);
      if (len > cm.display.maxLineLength) {
        cm.display.maxLine = visual;
        cm.display.maxLineLength = len;
        cm.display.maxLineChanged = true;
      }
    } }

    if (min != null && cm && this.collapsed) { regChange(cm, min, max + 1); }
    this.lines.length = 0;
    this.explicitlyCleared = true;
    if (this.atomic && this.doc.cantEdit) {
      this.doc.cantEdit = false;
      if (cm) { reCheckSelection(cm.doc); }
    }
    if (cm) { signalLater(cm, "markerCleared", cm, this, min, max); }
    if (withOp) { endOperation(cm); }
    if (this.parent) { this.parent.clear(); }
  };

  // Find the position of the marker in the document. Returns a {from,
  // to} object by default. Side can be passed to get a specific side
  // -- 0 (both), -1 (left), or 1 (right). When lineObj is true, the
  // Pos objects returned contain a line object, rather than a line
  // number (used to prevent looking up the same line twice).
  TextMarker.prototype.find = function (side, lineObj) {
    if (side == null && this.type == "bookmark") { side = 1; }
    var from, to;
    for (var i = 0; i < this.lines.length; ++i) {
      var line = this.lines[i];
      var span = getMarkedSpanFor(line.markedSpans, this);
      if (span.from != null) {
        from = Pos(lineObj ? line : lineNo(line), span.from);
        if (side == -1) { return from }
      }
      if (span.to != null) {
        to = Pos(lineObj ? line : lineNo(line), span.to);
        if (side == 1) { return to }
      }
    }
    return from && {from: from, to: to}
  };

  // Signals that the marker's widget changed, and surrounding layout
  // should be recomputed.
  TextMarker.prototype.changed = function () {
      var this$1 = this;

    var pos = this.find(-1, true), widget = this, cm = this.doc.cm;
    if (!pos || !cm) { return }
    runInOp(cm, function () {
      var line = pos.line, lineN = lineNo(pos.line);
      var view = findViewForLine(cm, lineN);
      if (view) {
        clearLineMeasurementCacheFor(view);
        cm.curOp.selectionChanged = cm.curOp.forceUpdate = true;
      }
      cm.curOp.updateMaxLine = true;
      if (!lineIsHidden(widget.doc, line) && widget.height != null) {
        var oldHeight = widget.height;
        widget.height = null;
        var dHeight = widgetHeight(widget) - oldHeight;
        if (dHeight)
          { updateLineHeight(line, line.height + dHeight); }
      }
      signalLater(cm, "markerChanged", cm, this$1);
    });
  };

  TextMarker.prototype.attachLine = function (line) {
    if (!this.lines.length && this.doc.cm) {
      var op = this.doc.cm.curOp;
      if (!op.maybeHiddenMarkers || indexOf(op.maybeHiddenMarkers, this) == -1)
        { (op.maybeUnhiddenMarkers || (op.maybeUnhiddenMarkers = [])).push(this); }
    }
    this.lines.push(line);
  };

  TextMarker.prototype.detachLine = function (line) {
    this.lines.splice(indexOf(this.lines, line), 1);
    if (!this.lines.length && this.doc.cm) {
      var op = this.doc.cm.curOp
      ;(op.maybeHiddenMarkers || (op.maybeHiddenMarkers = [])).push(this);
    }
  };
  eventMixin(TextMarker);

  // Create a marker, wire it up to the right lines, and
  function markText(doc, from, to, options, type) {
    // Shared markers (across linked documents) are handled separately
    // (markTextShared will call out to this again, once per
    // document).
    if (options && options.shared) { return markTextShared(doc, from, to, options, type) }
    // Ensure we are in an operation.
    if (doc.cm && !doc.cm.curOp) { return operation(doc.cm, markText)(doc, from, to, options, type) }

    var marker = new TextMarker(doc, type), diff = cmp(from, to);
    if (options) { copyObj(options, marker, false); }
    // Don't connect empty markers unless clearWhenEmpty is false
    if (diff > 0 || diff == 0 && marker.clearWhenEmpty !== false)
      { return marker }
    if (marker.replacedWith) {
      // Showing up as a widget implies collapsed (widget replaces text)
      marker.collapsed = true;
      marker.widgetNode = eltP("span", [marker.replacedWith], "CodeMirror-widget");
      if (!options.handleMouseEvents) { marker.widgetNode.setAttribute("cm-ignore-events", "true"); }
      if (options.insertLeft) { marker.widgetNode.insertLeft = true; }
    }
    if (marker.collapsed) {
      if (conflictingCollapsedRange(doc, from.line, from, to, marker) ||
          from.line != to.line && conflictingCollapsedRange(doc, to.line, from, to, marker))
        { throw new Error("Inserting collapsed marker partially overlapping an existing one") }
      seeCollapsedSpans();
    }

    if (marker.addToHistory)
      { addChangeToHistory(doc, {from: from, to: to, origin: "markText"}, doc.sel, NaN); }

    var curLine = from.line, cm = doc.cm, updateMaxLine;
    doc.iter(curLine, to.line + 1, function (line) {
      if (cm && marker.collapsed && !cm.options.lineWrapping && visualLine(line) == cm.display.maxLine)
        { updateMaxLine = true; }
      if (marker.collapsed && curLine != from.line) { updateLineHeight(line, 0); }
      addMarkedSpan(line, new MarkedSpan(marker,
                                         curLine == from.line ? from.ch : null,
                                         curLine == to.line ? to.ch : null), doc.cm && doc.cm.curOp);
      ++curLine;
    });
    // lineIsHidden depends on the presence of the spans, so needs a second pass
    if (marker.collapsed) { doc.iter(from.line, to.line + 1, function (line) {
      if (lineIsHidden(doc, line)) { updateLineHeight(line, 0); }
    }); }

    if (marker.clearOnEnter) { on(marker, "beforeCursorEnter", function () { return marker.clear(); }); }

    if (marker.readOnly) {
      seeReadOnlySpans();
      if (doc.history.done.length || doc.history.undone.length)
        { doc.clearHistory(); }
    }
    if (marker.collapsed) {
      marker.id = ++nextMarkerId;
      marker.atomic = true;
    }
    if (cm) {
      // Sync editor state
      if (updateMaxLine) { cm.curOp.updateMaxLine = true; }
      if (marker.collapsed)
        { regChange(cm, from.line, to.line + 1); }
      else if (marker.className || marker.startStyle || marker.endStyle || marker.css ||
               marker.attributes || marker.title)
        { for (var i = from.line; i <= to.line; i++) { regLineChange(cm, i, "text"); } }
      if (marker.atomic) { reCheckSelection(cm.doc); }
      signalLater(cm, "markerAdded", cm, marker);
    }
    return marker
  }

  // SHARED TEXTMARKERS

  // A shared marker spans multiple linked documents. It is
  // implemented as a meta-marker-object controlling multiple normal
  // markers.
  var SharedTextMarker = function(markers, primary) {
    this.markers = markers;
    this.primary = primary;
    for (var i = 0; i < markers.length; ++i)
      { markers[i].parent = this; }
  };

  SharedTextMarker.prototype.clear = function () {
    if (this.explicitlyCleared) { return }
    this.explicitlyCleared = true;
    for (var i = 0; i < this.markers.length; ++i)
      { this.markers[i].clear(); }
    signalLater(this, "clear");
  };

  SharedTextMarker.prototype.find = function (side, lineObj) {
    return this.primary.find(side, lineObj)
  };
  eventMixin(SharedTextMarker);

  function markTextShared(doc, from, to, options, type) {
    options = copyObj(options);
    options.shared = false;
    var markers = [markText(doc, from, to, options, type)], primary = markers[0];
    var widget = options.widgetNode;
    linkedDocs(doc, function (doc) {
      if (widget) { options.widgetNode = widget.cloneNode(true); }
      markers.push(markText(doc, clipPos(doc, from), clipPos(doc, to), options, type));
      for (var i = 0; i < doc.linked.length; ++i)
        { if (doc.linked[i].isParent) { return } }
      primary = lst(markers);
    });
    return new SharedTextMarker(markers, primary)
  }

  function findSharedMarkers(doc) {
    return doc.findMarks(Pos(doc.first, 0), doc.clipPos(Pos(doc.lastLine())), function (m) { return m.parent; })
  }

  function copySharedMarkers(doc, markers) {
    for (var i = 0; i < markers.length; i++) {
      var marker = markers[i], pos = marker.find();
      var mFrom = doc.clipPos(pos.from), mTo = doc.clipPos(pos.to);
      if (cmp(mFrom, mTo)) {
        var subMark = markText(doc, mFrom, mTo, marker.primary, marker.primary.type);
        marker.markers.push(subMark);
        subMark.parent = marker;
      }
    }
  }

  function detachSharedMarkers(markers) {
    var loop = function ( i ) {
      var marker = markers[i], linked = [marker.primary.doc];
      linkedDocs(marker.primary.doc, function (d) { return linked.push(d); });
      for (var j = 0; j < marker.markers.length; j++) {
        var subMarker = marker.markers[j];
        if (indexOf(linked, subMarker.doc) == -1) {
          subMarker.parent = null;
          marker.markers.splice(j--, 1);
        }
      }
    };

    for (var i = 0; i < markers.length; i++) loop( i );
  }

  var nextDocId = 0;
  var Doc = function(text, mode, firstLine, lineSep, direction) {
    if (!(this instanceof Doc)) { return new Doc(text, mode, firstLine, lineSep, direction) }
    if (firstLine == null) { firstLine = 0; }

    BranchChunk.call(this, [new LeafChunk([new Line("", null)])]);
    this.first = firstLine;
    this.scrollTop = this.scrollLeft = 0;
    this.cantEdit = false;
    this.cleanGeneration = 1;
    this.modeFrontier = this.highlightFrontier = firstLine;
    var start = Pos(firstLine, 0);
    this.sel = simpleSelection(start);
    this.history = new History(null);
    this.id = ++nextDocId;
    this.modeOption = mode;
    this.lineSep = lineSep;
    this.direction = (direction == "rtl") ? "rtl" : "ltr";
    this.extend = false;

    if (typeof text == "string") { text = this.splitLines(text); }
    updateDoc(this, {from: start, to: start, text: text});
    setSelection(this, simpleSelection(start), sel_dontScroll);
  };

  Doc.prototype = createObj(BranchChunk.prototype, {
    constructor: Doc,
    // Iterate over the document. Supports two forms -- with only one
    // argument, it calls that for each line in the document. With
    // three, it iterates over the range given by the first two (with
    // the second being non-inclusive).
    iter: function(from, to, op) {
      if (op) { this.iterN(from - this.first, to - from, op); }
      else { this.iterN(this.first, this.first + this.size, from); }
    },

    // Non-public interface for adding and removing lines.
    insert: function(at, lines) {
      var height = 0;
      for (var i = 0; i < lines.length; ++i) { height += lines[i].height; }
      this.insertInner(at - this.first, lines, height);
    },
    remove: function(at, n) { this.removeInner(at - this.first, n); },

    // From here, the methods are part of the public interface. Most
    // are also available from CodeMirror (editor) instances.

    getValue: function(lineSep) {
      var lines = getLines(this, this.first, this.first + this.size);
      if (lineSep === false) { return lines }
      return lines.join(lineSep || this.lineSeparator())
    },
    setValue: docMethodOp(function(code) {
      var top = Pos(this.first, 0), last = this.first + this.size - 1;
      makeChange(this, {from: top, to: Pos(last, getLine(this, last).text.length),
                        text: this.splitLines(code), origin: "setValue", full: true}, true);
      if (this.cm) { scrollToCoords(this.cm, 0, 0); }
      setSelection(this, simpleSelection(top), sel_dontScroll);
    }),
    replaceRange: function(code, from, to, origin) {
      from = clipPos(this, from);
      to = to ? clipPos(this, to) : from;
      replaceRange(this, code, from, to, origin);
    },
    getRange: function(from, to, lineSep) {
      var lines = getBetween(this, clipPos(this, from), clipPos(this, to));
      if (lineSep === false) { return lines }
      if (lineSep === '') { return lines.join('') }
      return lines.join(lineSep || this.lineSeparator())
    },

    getLine: function(line) {var l = this.getLineHandle(line); return l && l.text},

    getLineHandle: function(line) {if (isLine(this, line)) { return getLine(this, line) }},
    getLineNumber: function(line) {return lineNo(line)},

    getLineHandleVisualStart: function(line) {
      if (typeof line == "number") { line = getLine(this, line); }
      return visualLine(line)
    },

    lineCount: function() {return this.size},
    firstLine: function() {return this.first},
    lastLine: function() {return this.first + this.size - 1},

    clipPos: function(pos) {return clipPos(this, pos)},

    getCursor: function(start) {
      var range = this.sel.primary(), pos;
      if (start == null || start == "head") { pos = range.head; }
      else if (start == "anchor") { pos = range.anchor; }
      else if (start == "end" || start == "to" || start === false) { pos = range.to(); }
      else { pos = range.from(); }
      return pos
    },
    listSelections: function() { return this.sel.ranges },
    somethingSelected: function() {return this.sel.somethingSelected()},

    setCursor: docMethodOp(function(line, ch, options) {
      setSimpleSelection(this, clipPos(this, typeof line == "number" ? Pos(line, ch || 0) : line), null, options);
    }),
    setSelection: docMethodOp(function(anchor, head, options) {
      setSimpleSelection(this, clipPos(this, anchor), clipPos(this, head || anchor), options);
    }),
    extendSelection: docMethodOp(function(head, other, options) {
      extendSelection(this, clipPos(this, head), other && clipPos(this, other), options);
    }),
    extendSelections: docMethodOp(function(heads, options) {
      extendSelections(this, clipPosArray(this, heads), options);
    }),
    extendSelectionsBy: docMethodOp(function(f, options) {
      var heads = map(this.sel.ranges, f);
      extendSelections(this, clipPosArray(this, heads), options);
    }),
    setSelections: docMethodOp(function(ranges, primary, options) {
      if (!ranges.length) { return }
      var out = [];
      for (var i = 0; i < ranges.length; i++)
        { out[i] = new Range(clipPos(this, ranges[i].anchor),
                           clipPos(this, ranges[i].head || ranges[i].anchor)); }
      if (primary == null) { primary = Math.min(ranges.length - 1, this.sel.primIndex); }
      setSelection(this, normalizeSelection(this.cm, out, primary), options);
    }),
    addSelection: docMethodOp(function(anchor, head, options) {
      var ranges = this.sel.ranges.slice(0);
      ranges.push(new Range(clipPos(this, anchor), clipPos(this, head || anchor)));
      setSelection(this, normalizeSelection(this.cm, ranges, ranges.length - 1), options);
    }),

    getSelection: function(lineSep) {
      var ranges = this.sel.ranges, lines;
      for (var i = 0; i < ranges.length; i++) {
        var sel = getBetween(this, ranges[i].from(), ranges[i].to());
        lines = lines ? lines.concat(sel) : sel;
      }
      if (lineSep === false) { return lines }
      else { return lines.join(lineSep || this.lineSeparator()) }
    },
    getSelections: function(lineSep) {
      var parts = [], ranges = this.sel.ranges;
      for (var i = 0; i < ranges.length; i++) {
        var sel = getBetween(this, ranges[i].from(), ranges[i].to());
        if (lineSep !== false) { sel = sel.join(lineSep || this.lineSeparator()); }
        parts[i] = sel;
      }
      return parts
    },
    replaceSelection: function(code, collapse, origin) {
      var dup = [];
      for (var i = 0; i < this.sel.ranges.length; i++)
        { dup[i] = code; }
      this.replaceSelections(dup, collapse, origin || "+input");
    },
    replaceSelections: docMethodOp(function(code, collapse, origin) {
      var changes = [], sel = this.sel;
      for (var i = 0; i < sel.ranges.length; i++) {
        var range = sel.ranges[i];
        changes[i] = {from: range.from(), to: range.to(), text: this.splitLines(code[i]), origin: origin};
      }
      var newSel = collapse && collapse != "end" && computeReplacedSel(this, changes, collapse);
      for (var i$1 = changes.length - 1; i$1 >= 0; i$1--)
        { makeChange(this, changes[i$1]); }
      if (newSel) { setSelectionReplaceHistory(this, newSel); }
      else if (this.cm) { ensureCursorVisible(this.cm); }
    }),
    undo: docMethodOp(function() {makeChangeFromHistory(this, "undo");}),
    redo: docMethodOp(function() {makeChangeFromHistory(this, "redo");}),
    undoSelection: docMethodOp(function() {makeChangeFromHistory(this, "undo", true);}),
    redoSelection: docMethodOp(function() {makeChangeFromHistory(this, "redo", true);}),

    setExtending: function(val) {this.extend = val;},
    getExtending: function() {return this.extend},

    historySize: function() {
      var hist = this.history, done = 0, undone = 0;
      for (var i = 0; i < hist.done.length; i++) { if (!hist.done[i].ranges) { ++done; } }
      for (var i$1 = 0; i$1 < hist.undone.length; i$1++) { if (!hist.undone[i$1].ranges) { ++undone; } }
      return {undo: done, redo: undone}
    },
    clearHistory: function() {
      var this$1 = this;

      this.history = new History(this.history);
      linkedDocs(this, function (doc) { return doc.history = this$1.history; }, true);
    },

    markClean: function() {
      this.cleanGeneration = this.changeGeneration(true);
    },
    changeGeneration: function(forceSplit) {
      if (forceSplit)
        { this.history.lastOp = this.history.lastSelOp = this.history.lastOrigin = null; }
      return this.history.generation
    },
    isClean: function (gen) {
      return this.history.generation == (gen || this.cleanGeneration)
    },

    getHistory: function() {
      return {done: copyHistoryArray(this.history.done),
              undone: copyHistoryArray(this.history.undone)}
    },
    setHistory: function(histData) {
      var hist = this.history = new History(this.history);
      hist.done = copyHistoryArray(histData.done.slice(0), null, true);
      hist.undone = copyHistoryArray(histData.undone.slice(0), null, true);
    },

    setGutterMarker: docMethodOp(function(line, gutterID, value) {
      return changeLine(this, line, "gutter", function (line) {
        var markers = line.gutterMarkers || (line.gutterMarkers = {});
        markers[gutterID] = value;
        if (!value && isEmpty(markers)) { line.gutterMarkers = null; }
        return true
      })
    }),

    clearGutter: docMethodOp(function(gutterID) {
      var this$1 = this;

      this.iter(function (line) {
        if (line.gutterMarkers && line.gutterMarkers[gutterID]) {
          changeLine(this$1, line, "gutter", function () {
            line.gutterMarkers[gutterID] = null;
            if (isEmpty(line.gutterMarkers)) { line.gutterMarkers = null; }
            return true
          });
        }
      });
    }),

    lineInfo: function(line) {
      var n;
      if (typeof line == "number") {
        if (!isLine(this, line)) { return null }
        n = line;
        line = getLine(this, line);
        if (!line) { return null }
      } else {
        n = lineNo(line);
        if (n == null) { return null }
      }
      return {line: n, handle: line, text: line.text, gutterMarkers: line.gutterMarkers,
              textClass: line.textClass, bgClass: line.bgClass, wrapClass: line.wrapClass,
              widgets: line.widgets}
    },

    addLineClass: docMethodOp(function(handle, where, cls) {
      return changeLine(this, handle, where == "gutter" ? "gutter" : "class", function (line) {
        var prop = where == "text" ? "textClass"
                 : where == "background" ? "bgClass"
                 : where == "gutter" ? "gutterClass" : "wrapClass";
        if (!line[prop]) { line[prop] = cls; }
        else if (classTest(cls).test(line[prop])) { return false }
        else { line[prop] += " " + cls; }
        return true
      })
    }),
    removeLineClass: docMethodOp(function(handle, where, cls) {
      return changeLine(this, handle, where == "gutter" ? "gutter" : "class", function (line) {
        var prop = where == "text" ? "textClass"
                 : where == "background" ? "bgClass"
                 : where == "gutter" ? "gutterClass" : "wrapClass";
        var cur = line[prop];
        if (!cur) { return false }
        else if (cls == null) { line[prop] = null; }
        else {
          var found = cur.match(classTest(cls));
          if (!found) { return false }
          var end = found.index + found[0].length;
          line[prop] = cur.slice(0, found.index) + (!found.index || end == cur.length ? "" : " ") + cur.slice(end) || null;
        }
        return true
      })
    }),

    addLineWidget: docMethodOp(function(handle, node, options) {
      return addLineWidget(this, handle, node, options)
    }),
    removeLineWidget: function(widget) { widget.clear(); },

    markText: function(from, to, options) {
      return markText(this, clipPos(this, from), clipPos(this, to), options, options && options.type || "range")
    },
    setBookmark: function(pos, options) {
      var realOpts = {replacedWith: options && (options.nodeType == null ? options.widget : options),
                      insertLeft: options && options.insertLeft,
                      clearWhenEmpty: false, shared: options && options.shared,
                      handleMouseEvents: options && options.handleMouseEvents};
      pos = clipPos(this, pos);
      return markText(this, pos, pos, realOpts, "bookmark")
    },
    findMarksAt: function(pos) {
      pos = clipPos(this, pos);
      var markers = [], spans = getLine(this, pos.line).markedSpans;
      if (spans) { for (var i = 0; i < spans.length; ++i) {
        var span = spans[i];
        if ((span.from == null || span.from <= pos.ch) &&
            (span.to == null || span.to >= pos.ch))
          { markers.push(span.marker.parent || span.marker); }
      } }
      return markers
    },
    findMarks: function(from, to, filter) {
      from = clipPos(this, from); to = clipPos(this, to);
      var found = [], lineNo = from.line;
      this.iter(from.line, to.line + 1, function (line) {
        var spans = line.markedSpans;
        if (spans) { for (var i = 0; i < spans.length; i++) {
          var span = spans[i];
          if (!(span.to != null && lineNo == from.line && from.ch >= span.to ||
                span.from == null && lineNo != from.line ||
                span.from != null && lineNo == to.line && span.from >= to.ch) &&
              (!filter || filter(span.marker)))
            { found.push(span.marker.parent || span.marker); }
        } }
        ++lineNo;
      });
      return found
    },
    getAllMarks: function() {
      var markers = [];
      this.iter(function (line) {
        var sps = line.markedSpans;
        if (sps) { for (var i = 0; i < sps.length; ++i)
          { if (sps[i].from != null) { markers.push(sps[i].marker); } } }
      });
      return markers
    },

    posFromIndex: function(off) {
      var ch, lineNo = this.first, sepSize = this.lineSeparator().length;
      this.iter(function (line) {
        var sz = line.text.length + sepSize;
        if (sz > off) { ch = off; return true }
        off -= sz;
        ++lineNo;
      });
      return clipPos(this, Pos(lineNo, ch))
    },
    indexFromPos: function (coords) {
      coords = clipPos(this, coords);
      var index = coords.ch;
      if (coords.line < this.first || coords.ch < 0) { return 0 }
      var sepSize = this.lineSeparator().length;
      this.iter(this.first, coords.line, function (line) { // iter aborts when callback returns a truthy value
        index += line.text.length + sepSize;
      });
      return index
    },

    copy: function(copyHistory) {
      var doc = new Doc(getLines(this, this.first, this.first + this.size),
                        this.modeOption, this.first, this.lineSep, this.direction);
      doc.scrollTop = this.scrollTop; doc.scrollLeft = this.scrollLeft;
      doc.sel = this.sel;
      doc.extend = false;
      if (copyHistory) {
        doc.history.undoDepth = this.history.undoDepth;
        doc.setHistory(this.getHistory());
      }
      return doc
    },

    linkedDoc: function(options) {
      if (!options) { options = {}; }
      var from = this.first, to = this.first + this.size;
      if (options.from != null && options.from > from) { from = options.from; }
      if (options.to != null && options.to < to) { to = options.to; }
      var copy = new Doc(getLines(this, from, to), options.mode || this.modeOption, from, this.lineSep, this.direction);
      if (options.sharedHist) { copy.history = this.history
      ; }(this.linked || (this.linked = [])).push({doc: copy, sharedHist: options.sharedHist});
      copy.linked = [{doc: this, isParent: true, sharedHist: options.sharedHist}];
      copySharedMarkers(copy, findSharedMarkers(this));
      return copy
    },
    unlinkDoc: function(other) {
      if (other instanceof CodeMirror) { other = other.doc; }
      if (this.linked) { for (var i = 0; i < this.linked.length; ++i) {
        var link = this.linked[i];
        if (link.doc != other) { continue }
        this.linked.splice(i, 1);
        other.unlinkDoc(this);
        detachSharedMarkers(findSharedMarkers(this));
        break
      } }
      // If the histories were shared, split them again
      if (other.history == this.history) {
        var splitIds = [other.id];
        linkedDocs(other, function (doc) { return splitIds.push(doc.id); }, true);
        other.history = new History(null);
        other.history.done = copyHistoryArray(this.history.done, splitIds);
        other.history.undone = copyHistoryArray(this.history.undone, splitIds);
      }
    },
    iterLinkedDocs: function(f) {linkedDocs(this, f);},

    getMode: function() {return this.mode},
    getEditor: function() {return this.cm},

    splitLines: function(str) {
      if (this.lineSep) { return str.split(this.lineSep) }
      return splitLinesAuto(str)
    },
    lineSeparator: function() { return this.lineSep || "\n" },

    setDirection: docMethodOp(function (dir) {
      if (dir != "rtl") { dir = "ltr"; }
      if (dir == this.direction) { return }
      this.direction = dir;
      this.iter(function (line) { return line.order = null; });
      if (this.cm) { directionChanged(this.cm); }
    })
  });

  // Public alias.
  Doc.prototype.eachLine = Doc.prototype.iter;

  // Kludge to work around strange IE behavior where it'll sometimes
  // re-fire a series of drag-related events right after the drop (#1551)
  var lastDrop = 0;

  function onDrop(e) {
    var cm = this;
    clearDragCursor(cm);
    if (signalDOMEvent(cm, e) || eventInWidget(cm.display, e))
      { return }
    e_preventDefault(e);
    if (ie) { lastDrop = +new Date; }
    var pos = posFromMouse(cm, e, true), files = e.dataTransfer.files;
    if (!pos || cm.isReadOnly()) { return }
    // Might be a file drop, in which case we simply extract the text
    // and insert it.
    if (files && files.length && window.FileReader && window.File) {
      var n = files.length, text = Array(n), read = 0;
      var markAsReadAndPasteIfAllFilesAreRead = function () {
        if (++read == n) {
          operation(cm, function () {
            pos = clipPos(cm.doc, pos);
            var change = {from: pos, to: pos,
                          text: cm.doc.splitLines(
                              text.filter(function (t) { return t != null; }).join(cm.doc.lineSeparator())),
                          origin: "paste"};
            makeChange(cm.doc, change);
            setSelectionReplaceHistory(cm.doc, simpleSelection(clipPos(cm.doc, pos), clipPos(cm.doc, changeEnd(change))));
          })();
        }
      };
      var readTextFromFile = function (file, i) {
        if (cm.options.allowDropFileTypes &&
            indexOf(cm.options.allowDropFileTypes, file.type) == -1) {
          markAsReadAndPasteIfAllFilesAreRead();
          return
        }
        var reader = new FileReader;
        reader.onerror = function () { return markAsReadAndPasteIfAllFilesAreRead(); };
        reader.onload = function () {
          var content = reader.result;
          if (/[\x00-\x08\x0e-\x1f]{2}/.test(content)) {
            markAsReadAndPasteIfAllFilesAreRead();
            return
          }
          text[i] = content;
          markAsReadAndPasteIfAllFilesAreRead();
        };
        reader.readAsText(file);
      };
      for (var i = 0; i < files.length; i++) { readTextFromFile(files[i], i); }
    } else { // Normal drop
      // Don't do a replace if the drop happened inside of the selected text.
      if (cm.state.draggingText && cm.doc.sel.contains(pos) > -1) {
        cm.state.draggingText(e);
        // Ensure the editor is re-focused
        setTimeout(function () { return cm.display.input.focus(); }, 20);
        return
      }
      try {
        var text$1 = e.dataTransfer.getData("Text");
        if (text$1) {
          var selected;
          if (cm.state.draggingText && !cm.state.draggingText.copy)
            { selected = cm.listSelections(); }
          setSelectionNoUndo(cm.doc, simpleSelection(pos, pos));
          if (selected) { for (var i$1 = 0; i$1 < selected.length; ++i$1)
            { replaceRange(cm.doc, "", selected[i$1].anchor, selected[i$1].head, "drag"); } }
          cm.replaceSelection(text$1, "around", "paste");
          cm.display.input.focus();
        }
      }
      catch(e$1){}
    }
  }

  function onDragStart(cm, e) {
    if (ie && (!cm.state.draggingText || +new Date - lastDrop < 100)) { e_stop(e); return }
    if (signalDOMEvent(cm, e) || eventInWidget(cm.display, e)) { return }

    e.dataTransfer.setData("Text", cm.getSelection());
    e.dataTransfer.effectAllowed = "copyMove";

    // Use dummy image instead of default browsers image.
    // Recent Safari (~6.0.2) have a tendency to segfault when this happens, so we don't do it there.
    if (e.dataTransfer.setDragImage && !safari) {
      var img = elt("img", null, null, "position: fixed; left: 0; top: 0;");
      img.src = "data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==";
      if (presto) {
        img.width = img.height = 1;
        cm.display.wrapper.appendChild(img);
        // Force a relayout, or Opera won't use our image for some obscure reason
        img._top = img.offsetTop;
      }
      e.dataTransfer.setDragImage(img, 0, 0);
      if (presto) { img.parentNode.removeChild(img); }
    }
  }

  function onDragOver(cm, e) {
    var pos = posFromMouse(cm, e);
    if (!pos) { return }
    var frag = document.createDocumentFragment();
    drawSelectionCursor(cm, pos, frag);
    if (!cm.display.dragCursor) {
      cm.display.dragCursor = elt("div", null, "CodeMirror-cursors CodeMirror-dragcursors");
      cm.display.lineSpace.insertBefore(cm.display.dragCursor, cm.display.cursorDiv);
    }
    removeChildrenAndAdd(cm.display.dragCursor, frag);
  }

  function clearDragCursor(cm) {
    if (cm.display.dragCursor) {
      cm.display.lineSpace.removeChild(cm.display.dragCursor);
      cm.display.dragCursor = null;
    }
  }

  // These must be handled carefully, because naively registering a
  // handler for each editor will cause the editors to never be
  // garbage collected.

  function forEachCodeMirror(f) {
    if (!document.getElementsByClassName) { return }
    var byClass = document.getElementsByClassName("CodeMirror"), editors = [];
    for (var i = 0; i < byClass.length; i++) {
      var cm = byClass[i].CodeMirror;
      if (cm) { editors.push(cm); }
    }
    if (editors.length) { editors[0].operation(function () {
      for (var i = 0; i < editors.length; i++) { f(editors[i]); }
    }); }
  }

  var globalsRegistered = false;
  function ensureGlobalHandlers() {
    if (globalsRegistered) { return }
    registerGlobalHandlers();
    globalsRegistered = true;
  }
  function registerGlobalHandlers() {
    // When the window resizes, we need to refresh active editors.
    var resizeTimer;
    on(window, "resize", function () {
      if (resizeTimer == null) { resizeTimer = setTimeout(function () {
        resizeTimer = null;
        forEachCodeMirror(onResize);
      }, 100); }
    });
    // When the window loses focus, we want to show the editor as blurred
    on(window, "blur", function () { return forEachCodeMirror(onBlur); });
  }
  // Called when the window resizes
  function onResize(cm) {
    var d = cm.display;
    // Might be a text scaling operation, clear size caches.
    d.cachedCharWidth = d.cachedTextHeight = d.cachedPaddingH = null;
    d.scrollbarsClipped = false;
    cm.setSize();
  }

  var keyNames = {
    3: "Pause", 8: "Backspace", 9: "Tab", 13: "Enter", 16: "Shift", 17: "Ctrl", 18: "Alt",
    19: "Pause", 20: "CapsLock", 27: "Esc", 32: "Space", 33: "PageUp", 34: "PageDown", 35: "End",
    36: "Home", 37: "Left", 38: "Up", 39: "Right", 40: "Down", 44: "PrintScrn", 45: "Insert",
    46: "Delete", 59: ";", 61: "=", 91: "Mod", 92: "Mod", 93: "Mod",
    106: "*", 107: "=", 109: "-", 110: ".", 111: "/", 145: "ScrollLock",
    173: "-", 186: ";", 187: "=", 188: ",", 189: "-", 190: ".", 191: "/", 192: "`", 219: "[", 220: "\\",
    221: "]", 222: "'", 224: "Mod", 63232: "Up", 63233: "Down", 63234: "Left", 63235: "Right", 63272: "Delete",
    63273: "Home", 63275: "End", 63276: "PageUp", 63277: "PageDown", 63302: "Insert"
  };

  // Number keys
  for (var i = 0; i < 10; i++) { keyNames[i + 48] = keyNames[i + 96] = String(i); }
  // Alphabetic keys
  for (var i$1 = 65; i$1 <= 90; i$1++) { keyNames[i$1] = String.fromCharCode(i$1); }
  // Function keys
  for (var i$2 = 1; i$2 <= 12; i$2++) { keyNames[i$2 + 111] = keyNames[i$2 + 63235] = "F" + i$2; }

  var keyMap = {};

  keyMap.basic = {
    "Left": "goCharLeft", "Right": "goCharRight", "Up": "goLineUp", "Down": "goLineDown",
    "End": "goLineEnd", "Home": "goLineStartSmart", "PageUp": "goPageUp", "PageDown": "goPageDown",
    "Delete": "delCharAfter", "Backspace": "delCharBefore", "Shift-Backspace": "delCharBefore",
    "Tab": "defaultTab", "Shift-Tab": "indentAuto",
    "Enter": "newlineAndIndent", "Insert": "toggleOverwrite",
    "Esc": "singleSelection"
  };
  // Note that the save and find-related commands aren't defined by
  // default. User code or addons can define them. Unknown commands
  // are simply ignored.
  keyMap.pcDefault = {
    "Ctrl-A": "selectAll", "Ctrl-D": "deleteLine", "Ctrl-Z": "undo", "Shift-Ctrl-Z": "redo", "Ctrl-Y": "redo",
    "Ctrl-Home": "goDocStart", "Ctrl-End": "goDocEnd", "Ctrl-Up": "goLineUp", "Ctrl-Down": "goLineDown",
    "Ctrl-Left": "goGroupLeft", "Ctrl-Right": "goGroupRight", "Alt-Left": "goLineStart", "Alt-Right": "goLineEnd",
    "Ctrl-Backspace": "delGroupBefore", "Ctrl-Delete": "delGroupAfter", "Ctrl-S": "save", "Ctrl-F": "find",
    "Ctrl-G": "findNext", "Shift-Ctrl-G": "findPrev", "Shift-Ctrl-F": "replace", "Shift-Ctrl-R": "replaceAll",
    "Ctrl-[": "indentLess", "Ctrl-]": "indentMore",
    "Ctrl-U": "undoSelection", "Shift-Ctrl-U": "redoSelection", "Alt-U": "redoSelection",
    "fallthrough": "basic"
  };
  // Very basic readline/emacs-style bindings, which are standard on Mac.
  keyMap.emacsy = {
    "Ctrl-F": "goCharRight", "Ctrl-B": "goCharLeft", "Ctrl-P": "goLineUp", "Ctrl-N": "goLineDown",
    "Ctrl-A": "goLineStart", "Ctrl-E": "goLineEnd", "Ctrl-V": "goPageDown", "Shift-Ctrl-V": "goPageUp",
    "Ctrl-D": "delCharAfter", "Ctrl-H": "delCharBefore", "Alt-Backspace": "delWordBefore", "Ctrl-K": "killLine",
    "Ctrl-T": "transposeChars", "Ctrl-O": "openLine"
  };
  keyMap.macDefault = {
    "Cmd-A": "selectAll", "Cmd-D": "deleteLine", "Cmd-Z": "undo", "Shift-Cmd-Z": "redo", "Cmd-Y": "redo",
    "Cmd-Home": "goDocStart", "Cmd-Up": "goDocStart", "Cmd-End": "goDocEnd", "Cmd-Down": "goDocEnd", "Alt-Left": "goGroupLeft",
    "Alt-Right": "goGroupRight", "Cmd-Left": "goLineLeft", "Cmd-Right": "goLineRight", "Alt-Backspace": "delGroupBefore",
    "Ctrl-Alt-Backspace": "delGroupAfter", "Alt-Delete": "delGroupAfter", "Cmd-S": "save", "Cmd-F": "find",
    "Cmd-G": "findNext", "Shift-Cmd-G": "findPrev", "Cmd-Alt-F": "replace", "Shift-Cmd-Alt-F": "replaceAll",
    "Cmd-[": "indentLess", "Cmd-]": "indentMore", "Cmd-Backspace": "delWrappedLineLeft", "Cmd-Delete": "delWrappedLineRight",
    "Cmd-U": "undoSelection", "Shift-Cmd-U": "redoSelection", "Ctrl-Up": "goDocStart", "Ctrl-Down": "goDocEnd",
    "fallthrough": ["basic", "emacsy"]
  };
  keyMap["default"] = mac ? keyMap.macDefault : keyMap.pcDefault;

  // KEYMAP DISPATCH

  function normalizeKeyName(name) {
    var parts = name.split(/-(?!$)/);
    name = parts[parts.length - 1];
    var alt, ctrl, shift, cmd;
    for (var i = 0; i < parts.length - 1; i++) {
      var mod = parts[i];
      if (/^(cmd|meta|m)$/i.test(mod)) { cmd = true; }
      else if (/^a(lt)?$/i.test(mod)) { alt = true; }
      else if (/^(c|ctrl|control)$/i.test(mod)) { ctrl = true; }
      else if (/^s(hift)?$/i.test(mod)) { shift = true; }
      else { throw new Error("Unrecognized modifier name: " + mod) }
    }
    if (alt) { name = "Alt-" + name; }
    if (ctrl) { name = "Ctrl-" + name; }
    if (cmd) { name = "Cmd-" + name; }
    if (shift) { name = "Shift-" + name; }
    return name
  }

  // This is a kludge to keep keymaps mostly working as raw objects
  // (backwards compatibility) while at the same time support features
  // like normalization and multi-stroke key bindings. It compiles a
  // new normalized keymap, and then updates the old object to reflect
  // this.
  function normalizeKeyMap(keymap) {
    var copy = {};
    for (var keyname in keymap) { if (keymap.hasOwnProperty(keyname)) {
      var value = keymap[keyname];
      if (/^(name|fallthrough|(de|at)tach)$/.test(keyname)) { continue }
      if (value == "...") { delete keymap[keyname]; continue }

      var keys = map(keyname.split(" "), normalizeKeyName);
      for (var i = 0; i < keys.length; i++) {
        var val = (void 0), name = (void 0);
        if (i == keys.length - 1) {
          name = keys.join(" ");
          val = value;
        } else {
          name = keys.slice(0, i + 1).join(" ");
          val = "...";
        }
        var prev = copy[name];
        if (!prev) { copy[name] = val; }
        else if (prev != val) { throw new Error("Inconsistent bindings for " + name) }
      }
      delete keymap[keyname];
    } }
    for (var prop in copy) { keymap[prop] = copy[prop]; }
    return keymap
  }

  function lookupKey(key, map, handle, context) {
    map = getKeyMap(map);
    var found = map.call ? map.call(key, context) : map[key];
    if (found === false) { return "nothing" }
    if (found === "...") { return "multi" }
    if (found != null && handle(found)) { return "handled" }

    if (map.fallthrough) {
      if (Object.prototype.toString.call(map.fallthrough) != "[object Array]")
        { return lookupKey(key, map.fallthrough, handle, context) }
      for (var i = 0; i < map.fallthrough.length; i++) {
        var result = lookupKey(key, map.fallthrough[i], handle, context);
        if (result) { return result }
      }
    }
  }

  // Modifier key presses don't count as 'real' key presses for the
  // purpose of keymap fallthrough.
  function isModifierKey(value) {
    var name = typeof value == "string" ? value : keyNames[value.keyCode];
    return name == "Ctrl" || name == "Alt" || name == "Shift" || name == "Mod"
  }

  function addModifierNames(name, event, noShift) {
    var base = name;
    if (event.altKey && base != "Alt") { name = "Alt-" + name; }
    if ((flipCtrlCmd ? event.metaKey : event.ctrlKey) && base != "Ctrl") { name = "Ctrl-" + name; }
    if ((flipCtrlCmd ? event.ctrlKey : event.metaKey) && base != "Mod") { name = "Cmd-" + name; }
    if (!noShift && event.shiftKey && base != "Shift") { name = "Shift-" + name; }
    return name
  }

  // Look up the name of a key as indicated by an event object.
  function keyName(event, noShift) {
    if (presto && event.keyCode == 34 && event["char"]) { return false }
    var name = keyNames[event.keyCode];
    if (name == null || event.altGraphKey) { return false }
    // Ctrl-ScrollLock has keyCode 3, same as Ctrl-Pause,
    // so we'll use event.code when available (Chrome 48+, FF 38+, Safari 10.1+)
    if (event.keyCode == 3 && event.code) { name = event.code; }
    return addModifierNames(name, event, noShift)
  }

  function getKeyMap(val) {
    return typeof val == "string" ? keyMap[val] : val
  }

  // Helper for deleting text near the selection(s), used to implement
  // backspace, delete, and similar functionality.
  function deleteNearSelection(cm, compute) {
    var ranges = cm.doc.sel.ranges, kill = [];
    // Build up a set of ranges to kill first, merging overlapping
    // ranges.
    for (var i = 0; i < ranges.length; i++) {
      var toKill = compute(ranges[i]);
      while (kill.length && cmp(toKill.from, lst(kill).to) <= 0) {
        var replaced = kill.pop();
        if (cmp(replaced.from, toKill.from) < 0) {
          toKill.from = replaced.from;
          break
        }
      }
      kill.push(toKill);
    }
    // Next, remove those actual ranges.
    runInOp(cm, function () {
      for (var i = kill.length - 1; i >= 0; i--)
        { replaceRange(cm.doc, "", kill[i].from, kill[i].to, "+delete"); }
      ensureCursorVisible(cm);
    });
  }

  function moveCharLogically(line, ch, dir) {
    var target = skipExtendingChars(line.text, ch + dir, dir);
    return target < 0 || target > line.text.length ? null : target
  }

  function moveLogically(line, start, dir) {
    var ch = moveCharLogically(line, start.ch, dir);
    return ch == null ? null : new Pos(start.line, ch, dir < 0 ? "after" : "before")
  }

  function endOfLine(visually, cm, lineObj, lineNo, dir) {
    if (visually) {
      if (cm.doc.direction == "rtl") { dir = -dir; }
      var order = getOrder(lineObj, cm.doc.direction);
      if (order) {
        var part = dir < 0 ? lst(order) : order[0];
        var moveInStorageOrder = (dir < 0) == (part.level == 1);
        var sticky = moveInStorageOrder ? "after" : "before";
        var ch;
        // With a wrapped rtl chunk (possibly spanning multiple bidi parts),
        // it could be that the last bidi part is not on the last visual line,
        // since visual lines contain content order-consecutive chunks.
        // Thus, in rtl, we are looking for the first (content-order) character
        // in the rtl chunk that is on the last line (that is, the same line
        // as the last (content-order) character).
        if (part.level > 0 || cm.doc.direction == "rtl") {
          var prep = prepareMeasureForLine(cm, lineObj);
          ch = dir < 0 ? lineObj.text.length - 1 : 0;
          var targetTop = measureCharPrepared(cm, prep, ch).top;
          ch = findFirst(function (ch) { return measureCharPrepared(cm, prep, ch).top == targetTop; }, (dir < 0) == (part.level == 1) ? part.from : part.to - 1, ch);
          if (sticky == "before") { ch = moveCharLogically(lineObj, ch, 1); }
        } else { ch = dir < 0 ? part.to : part.from; }
        return new Pos(lineNo, ch, sticky)
      }
    }
    return new Pos(lineNo, dir < 0 ? lineObj.text.length : 0, dir < 0 ? "before" : "after")
  }

  function moveVisually(cm, line, start, dir) {
    var bidi = getOrder(line, cm.doc.direction);
    if (!bidi) { return moveLogically(line, start, dir) }
    if (start.ch >= line.text.length) {
      start.ch = line.text.length;
      start.sticky = "before";
    } else if (start.ch <= 0) {
      start.ch = 0;
      start.sticky = "after";
    }
    var partPos = getBidiPartAt(bidi, start.ch, start.sticky), part = bidi[partPos];
    if (cm.doc.direction == "ltr" && part.level % 2 == 0 && (dir > 0 ? part.to > start.ch : part.from < start.ch)) {
      // Case 1: We move within an ltr part in an ltr editor. Even with wrapped lines,
      // nothing interesting happens.
      return moveLogically(line, start, dir)
    }

    var mv = function (pos, dir) { return moveCharLogically(line, pos instanceof Pos ? pos.ch : pos, dir); };
    var prep;
    var getWrappedLineExtent = function (ch) {
      if (!cm.options.lineWrapping) { return {begin: 0, end: line.text.length} }
      prep = prep || prepareMeasureForLine(cm, line);
      return wrappedLineExtentChar(cm, line, prep, ch)
    };
    var wrappedLineExtent = getWrappedLineExtent(start.sticky == "before" ? mv(start, -1) : start.ch);

    if (cm.doc.direction == "rtl" || part.level == 1) {
      var moveInStorageOrder = (part.level == 1) == (dir < 0);
      var ch = mv(start, moveInStorageOrder ? 1 : -1);
      if (ch != null && (!moveInStorageOrder ? ch >= part.from && ch >= wrappedLineExtent.begin : ch <= part.to && ch <= wrappedLineExtent.end)) {
        // Case 2: We move within an rtl part or in an rtl editor on the same visual line
        var sticky = moveInStorageOrder ? "before" : "after";
        return new Pos(start.line, ch, sticky)
      }
    }

    // Case 3: Could not move within this bidi part in this visual line, so leave
    // the current bidi part

    var searchInVisualLine = function (partPos, dir, wrappedLineExtent) {
      var getRes = function (ch, moveInStorageOrder) { return moveInStorageOrder
        ? new Pos(start.line, mv(ch, 1), "before")
        : new Pos(start.line, ch, "after"); };

      for (; partPos >= 0 && partPos < bidi.length; partPos += dir) {
        var part = bidi[partPos];
        var moveInStorageOrder = (dir > 0) == (part.level != 1);
        var ch = moveInStorageOrder ? wrappedLineExtent.begin : mv(wrappedLineExtent.end, -1);
        if (part.from <= ch && ch < part.to) { return getRes(ch, moveInStorageOrder) }
        ch = moveInStorageOrder ? part.from : mv(part.to, -1);
        if (wrappedLineExtent.begin <= ch && ch < wrappedLineExtent.end) { return getRes(ch, moveInStorageOrder) }
      }
    };

    // Case 3a: Look for other bidi parts on the same visual line
    var res = searchInVisualLine(partPos + dir, dir, wrappedLineExtent);
    if (res) { return res }

    // Case 3b: Look for other bidi parts on the next visual line
    var nextCh = dir > 0 ? wrappedLineExtent.end : mv(wrappedLineExtent.begin, -1);
    if (nextCh != null && !(dir > 0 && nextCh == line.text.length)) {
      res = searchInVisualLine(dir > 0 ? 0 : bidi.length - 1, dir, getWrappedLineExtent(nextCh));
      if (res) { return res }
    }

    // Case 4: Nowhere to move
    return null
  }

  // Commands are parameter-less actions that can be performed on an
  // editor, mostly used for keybindings.
  var commands = {
    selectAll: selectAll,
    singleSelection: function (cm) { return cm.setSelection(cm.getCursor("anchor"), cm.getCursor("head"), sel_dontScroll); },
    killLine: function (cm) { return deleteNearSelection(cm, function (range) {
      if (range.empty()) {
        var len = getLine(cm.doc, range.head.line).text.length;
        if (range.head.ch == len && range.head.line < cm.lastLine())
          { return {from: range.head, to: Pos(range.head.line + 1, 0)} }
        else
          { return {from: range.head, to: Pos(range.head.line, len)} }
      } else {
        return {from: range.from(), to: range.to()}
      }
    }); },
    deleteLine: function (cm) { return deleteNearSelection(cm, function (range) { return ({
      from: Pos(range.from().line, 0),
      to: clipPos(cm.doc, Pos(range.to().line + 1, 0))
    }); }); },
    delLineLeft: function (cm) { return deleteNearSelection(cm, function (range) { return ({
      from: Pos(range.from().line, 0), to: range.from()
    }); }); },
    delWrappedLineLeft: function (cm) { return deleteNearSelection(cm, function (range) {
      var top = cm.charCoords(range.head, "div").top + 5;
      var leftPos = cm.coordsChar({left: 0, top: top}, "div");
      return {from: leftPos, to: range.from()}
    }); },
    delWrappedLineRight: function (cm) { return deleteNearSelection(cm, function (range) {
      var top = cm.charCoords(range.head, "div").top + 5;
      var rightPos = cm.coordsChar({left: cm.display.lineDiv.offsetWidth + 100, top: top}, "div");
      return {from: range.from(), to: rightPos }
    }); },
    undo: function (cm) { return cm.undo(); },
    redo: function (cm) { return cm.redo(); },
    undoSelection: function (cm) { return cm.undoSelection(); },
    redoSelection: function (cm) { return cm.redoSelection(); },
    goDocStart: function (cm) { return cm.extendSelection(Pos(cm.firstLine(), 0)); },
    goDocEnd: function (cm) { return cm.extendSelection(Pos(cm.lastLine())); },
    goLineStart: function (cm) { return cm.extendSelectionsBy(function (range) { return lineStart(cm, range.head.line); },
      {origin: "+move", bias: 1}
    ); },
    goLineStartSmart: function (cm) { return cm.extendSelectionsBy(function (range) { return lineStartSmart(cm, range.head); },
      {origin: "+move", bias: 1}
    ); },
    goLineEnd: function (cm) { return cm.extendSelectionsBy(function (range) { return lineEnd(cm, range.head.line); },
      {origin: "+move", bias: -1}
    ); },
    goLineRight: function (cm) { return cm.extendSelectionsBy(function (range) {
      var top = cm.cursorCoords(range.head, "div").top + 5;
      return cm.coordsChar({left: cm.display.lineDiv.offsetWidth + 100, top: top}, "div")
    }, sel_move); },
    goLineLeft: function (cm) { return cm.extendSelectionsBy(function (range) {
      var top = cm.cursorCoords(range.head, "div").top + 5;
      return cm.coordsChar({left: 0, top: top}, "div")
    }, sel_move); },
    goLineLeftSmart: function (cm) { return cm.extendSelectionsBy(function (range) {
      var top = cm.cursorCoords(range.head, "div").top + 5;
      var pos = cm.coordsChar({left: 0, top: top}, "div");
      if (pos.ch < cm.getLine(pos.line).search(/\S/)) { return lineStartSmart(cm, range.head) }
      return pos
    }, sel_move); },
    goLineUp: function (cm) { return cm.moveV(-1, "line"); },
    goLineDown: function (cm) { return cm.moveV(1, "line"); },
    goPageUp: function (cm) { return cm.moveV(-1, "page"); },
    goPageDown: function (cm) { return cm.moveV(1, "page"); },
    goCharLeft: function (cm) { return cm.moveH(-1, "char"); },
    goCharRight: function (cm) { return cm.moveH(1, "char"); },
    goColumnLeft: function (cm) { return cm.moveH(-1, "column"); },
    goColumnRight: function (cm) { return cm.moveH(1, "column"); },
    goWordLeft: function (cm) { return cm.moveH(-1, "word"); },
    goGroupRight: function (cm) { return cm.moveH(1, "group"); },
    goGroupLeft: function (cm) { return cm.moveH(-1, "group"); },
    goWordRight: function (cm) { return cm.moveH(1, "word"); },
    delCharBefore: function (cm) { return cm.deleteH(-1, "codepoint"); },
    delCharAfter: function (cm) { return cm.deleteH(1, "char"); },
    delWordBefore: function (cm) { return cm.deleteH(-1, "word"); },
    delWordAfter: function (cm) { return cm.deleteH(1, "word"); },
    delGroupBefore: function (cm) { return cm.deleteH(-1, "group"); },
    delGroupAfter: function (cm) { return cm.deleteH(1, "group"); },
    indentAuto: function (cm) { return cm.indentSelection("smart"); },
    indentMore: function (cm) { return cm.indentSelection("add"); },
    indentLess: function (cm) { return cm.indentSelection("subtract"); },
    insertTab: function (cm) { return cm.replaceSelection("\t"); },
    insertSoftTab: function (cm) {
      var spaces = [], ranges = cm.listSelections(), tabSize = cm.options.tabSize;
      for (var i = 0; i < ranges.length; i++) {
        var pos = ranges[i].from();
        var col = countColumn(cm.getLine(pos.line), pos.ch, tabSize);
        spaces.push(spaceStr(tabSize - col % tabSize));
      }
      cm.replaceSelections(spaces);
    },
    defaultTab: function (cm) {
      if (cm.somethingSelected()) { cm.indentSelection("add"); }
      else { cm.execCommand("insertTab"); }
    },
    // Swap the two chars left and right of each selection's head.
    // Move cursor behind the two swapped characters afterwards.
    //
    // Doesn't consider line feeds a character.
    // Doesn't scan more than one line above to find a character.
    // Doesn't do anything on an empty line.
    // Doesn't do anything with non-empty selections.
    transposeChars: function (cm) { return runInOp(cm, function () {
      var ranges = cm.listSelections(), newSel = [];
      for (var i = 0; i < ranges.length; i++) {
        if (!ranges[i].empty()) { continue }
        var cur = ranges[i].head, line = getLine(cm.doc, cur.line).text;
        if (line) {
          if (cur.ch == line.length) { cur = new Pos(cur.line, cur.ch - 1); }
          if (cur.ch > 0) {
            cur = new Pos(cur.line, cur.ch + 1);
            cm.replaceRange(line.charAt(cur.ch - 1) + line.charAt(cur.ch - 2),
                            Pos(cur.line, cur.ch - 2), cur, "+transpose");
          } else if (cur.line > cm.doc.first) {
            var prev = getLine(cm.doc, cur.line - 1).text;
            if (prev) {
              cur = new Pos(cur.line, 1);
              cm.replaceRange(line.charAt(0) + cm.doc.lineSeparator() +
                              prev.charAt(prev.length - 1),
                              Pos(cur.line - 1, prev.length - 1), cur, "+transpose");
            }
          }
        }
        newSel.push(new Range(cur, cur));
      }
      cm.setSelections(newSel);
    }); },
    newlineAndIndent: function (cm) { return runInOp(cm, function () {
      var sels = cm.listSelections();
      for (var i = sels.length - 1; i >= 0; i--)
        { cm.replaceRange(cm.doc.lineSeparator(), sels[i].anchor, sels[i].head, "+input"); }
      sels = cm.listSelections();
      for (var i$1 = 0; i$1 < sels.length; i$1++)
        { cm.indentLine(sels[i$1].from().line, null, true); }
      ensureCursorVisible(cm);
    }); },
    openLine: function (cm) { return cm.replaceSelection("\n", "start"); },
    toggleOverwrite: function (cm) { return cm.toggleOverwrite(); }
  };


  function lineStart(cm, lineN) {
    var line = getLine(cm.doc, lineN);
    var visual = visualLine(line);
    if (visual != line) { lineN = lineNo(visual); }
    return endOfLine(true, cm, visual, lineN, 1)
  }
  function lineEnd(cm, lineN) {
    var line = getLine(cm.doc, lineN);
    var visual = visualLineEnd(line);
    if (visual != line) { lineN = lineNo(visual); }
    return endOfLine(true, cm, line, lineN, -1)
  }
  function lineStartSmart(cm, pos) {
    var start = lineStart(cm, pos.line);
    var line = getLine(cm.doc, start.line);
    var order = getOrder(line, cm.doc.direction);
    if (!order || order[0].level == 0) {
      var firstNonWS = Math.max(start.ch, line.text.search(/\S/));
      var inWS = pos.line == start.line && pos.ch <= firstNonWS && pos.ch;
      return Pos(start.line, inWS ? 0 : firstNonWS, start.sticky)
    }
    return start
  }

  // Run a handler that was bound to a key.
  function doHandleBinding(cm, bound, dropShift) {
    if (typeof bound == "string") {
      bound = commands[bound];
      if (!bound) { return false }
    }
    // Ensure previous input has been read, so that the handler sees a
    // consistent view of the document
    cm.display.input.ensurePolled();
    var prevShift = cm.display.shift, done = false;
    try {
      if (cm.isReadOnly()) { cm.state.suppressEdits = true; }
      if (dropShift) { cm.display.shift = false; }
      done = bound(cm) != Pass;
    } finally {
      cm.display.shift = prevShift;
      cm.state.suppressEdits = false;
    }
    return done
  }

  function lookupKeyForEditor(cm, name, handle) {
    for (var i = 0; i < cm.state.keyMaps.length; i++) {
      var result = lookupKey(name, cm.state.keyMaps[i], handle, cm);
      if (result) { return result }
    }
    return (cm.options.extraKeys && lookupKey(name, cm.options.extraKeys, handle, cm))
      || lookupKey(name, cm.options.keyMap, handle, cm)
  }

  // Note that, despite the name, this function is also used to check
  // for bound mouse clicks.

  var stopSeq = new Delayed;

  function dispatchKey(cm, name, e, handle) {
    var seq = cm.state.keySeq;
    if (seq) {
      if (isModifierKey(name)) { return "handled" }
      if (/\'$/.test(name))
        { cm.state.keySeq = null; }
      else
        { stopSeq.set(50, function () {
          if (cm.state.keySeq == seq) {
            cm.state.keySeq = null;
            cm.display.input.reset();
          }
        }); }
      if (dispatchKeyInner(cm, seq + " " + name, e, handle)) { return true }
    }
    return dispatchKeyInner(cm, name, e, handle)
  }

  function dispatchKeyInner(cm, name, e, handle) {
    var result = lookupKeyForEditor(cm, name, handle);

    if (result == "multi")
      { cm.state.keySeq = name; }
    if (result == "handled")
      { signalLater(cm, "keyHandled", cm, name, e); }

    if (result == "handled" || result == "multi") {
      e_preventDefault(e);
      restartBlink(cm);
    }

    return !!result
  }

  // Handle a key from the keydown event.
  function handleKeyBinding(cm, e) {
    var name = keyName(e, true);
    if (!name) { return false }

    if (e.shiftKey && !cm.state.keySeq) {
      // First try to resolve full name (including 'Shift-'). Failing
      // that, see if there is a cursor-motion command (starting with
      // 'go') bound to the keyname without 'Shift-'.
      return dispatchKey(cm, "Shift-" + name, e, function (b) { return doHandleBinding(cm, b, true); })
          || dispatchKey(cm, name, e, function (b) {
               if (typeof b == "string" ? /^go[A-Z]/.test(b) : b.motion)
                 { return doHandleBinding(cm, b) }
             })
    } else {
      return dispatchKey(cm, name, e, function (b) { return doHandleBinding(cm, b); })
    }
  }

  // Handle a key from the keypress event
  function handleCharBinding(cm, e, ch) {
    return dispatchKey(cm, "'" + ch + "'", e, function (b) { return doHandleBinding(cm, b, true); })
  }

  var lastStoppedKey = null;
  function onKeyDown(e) {
    var cm = this;
    if (e.target && e.target != cm.display.input.getField()) { return }
    cm.curOp.focus = activeElt();
    if (signalDOMEvent(cm, e)) { return }
    // IE does strange things with escape.
    if (ie && ie_version < 11 && e.keyCode == 27) { e.returnValue = false; }
    var code = e.keyCode;
    cm.display.shift = code == 16 || e.shiftKey;
    var handled = handleKeyBinding(cm, e);
    if (presto) {
      lastStoppedKey = handled ? code : null;
      // Opera has no cut event... we try to at least catch the key combo
      if (!handled && code == 88 && !hasCopyEvent && (mac ? e.metaKey : e.ctrlKey))
        { cm.replaceSelection("", null, "cut"); }
    }
    if (gecko && !mac && !handled && code == 46 && e.shiftKey && !e.ctrlKey && document.execCommand)
      { document.execCommand("cut"); }

    // Turn mouse into crosshair when Alt is held on Mac.
    if (code == 18 && !/\bCodeMirror-crosshair\b/.test(cm.display.lineDiv.className))
      { showCrossHair(cm); }
  }

  function showCrossHair(cm) {
    var lineDiv = cm.display.lineDiv;
    addClass(lineDiv, "CodeMirror-crosshair");

    function up(e) {
      if (e.keyCode == 18 || !e.altKey) {
        rmClass(lineDiv, "CodeMirror-crosshair");
        off(document, "keyup", up);
        off(document, "mouseover", up);
      }
    }
    on(document, "keyup", up);
    on(document, "mouseover", up);
  }

  function onKeyUp(e) {
    if (e.keyCode == 16) { this.doc.sel.shift = false; }
    signalDOMEvent(this, e);
  }

  function onKeyPress(e) {
    var cm = this;
    if (e.target && e.target != cm.display.input.getField()) { return }
    if (eventInWidget(cm.display, e) || signalDOMEvent(cm, e) || e.ctrlKey && !e.altKey || mac && e.metaKey) { return }
    var keyCode = e.keyCode, charCode = e.charCode;
    if (presto && keyCode == lastStoppedKey) {lastStoppedKey = null; e_preventDefault(e); return}
    if ((presto && (!e.which || e.which < 10)) && handleKeyBinding(cm, e)) { return }
    var ch = String.fromCharCode(charCode == null ? keyCode : charCode);
    // Some browsers fire keypress events for backspace
    if (ch == "\x08") { return }
    if (handleCharBinding(cm, e, ch)) { return }
    cm.display.input.onKeyPress(e);
  }

  var DOUBLECLICK_DELAY = 400;

  var PastClick = function(time, pos, button) {
    this.time = time;
    this.pos = pos;
    this.button = button;
  };

  PastClick.prototype.compare = function (time, pos, button) {
    return this.time + DOUBLECLICK_DELAY > time &&
      cmp(pos, this.pos) == 0 && button == this.button
  };

  var lastClick, lastDoubleClick;
  function clickRepeat(pos, button) {
    var now = +new Date;
    if (lastDoubleClick && lastDoubleClick.compare(now, pos, button)) {
      lastClick = lastDoubleClick = null;
      return "triple"
    } else if (lastClick && lastClick.compare(now, pos, button)) {
      lastDoubleClick = new PastClick(now, pos, button);
      lastClick = null;
      return "double"
    } else {
      lastClick = new PastClick(now, pos, button);
      lastDoubleClick = null;
      return "single"
    }
  }

  // A mouse down can be a single click, double click, triple click,
  // start of selection drag, start of text drag, new cursor
  // (ctrl-click), rectangle drag (alt-drag), or xwin
  // middle-click-paste. Or it might be a click on something we should
  // not interfere with, such as a scrollbar or widget.
  function onMouseDown(e) {
    var cm = this, display = cm.display;
    if (signalDOMEvent(cm, e) || display.activeTouch && display.input.supportsTouch()) { return }
    display.input.ensurePolled();
    display.shift = e.shiftKey;

    if (eventInWidget(display, e)) {
      if (!webkit) {
        // Briefly turn off draggability, to allow widgets to do
        // normal dragging things.
        display.scroller.draggable = false;
        setTimeout(function () { return display.scroller.draggable = true; }, 100);
      }
      return
    }
    if (clickInGutter(cm, e)) { return }
    var pos = posFromMouse(cm, e), button = e_button(e), repeat = pos ? clickRepeat(pos, button) : "single";
    window.focus();

    // #3261: make sure, that we're not starting a second selection
    if (button == 1 && cm.state.selectingText)
      { cm.state.selectingText(e); }

    if (pos && handleMappedButton(cm, button, pos, repeat, e)) { return }

    if (button == 1) {
      if (pos) { leftButtonDown(cm, pos, repeat, e); }
      else if (e_target(e) == display.scroller) { e_preventDefault(e); }
    } else if (button == 2) {
      if (pos) { extendSelection(cm.doc, pos); }
      setTimeout(function () { return display.input.focus(); }, 20);
    } else if (button == 3) {
      if (captureRightClick) { cm.display.input.onContextMenu(e); }
      else { delayBlurEvent(cm); }
    }
  }

  function handleMappedButton(cm, button, pos, repeat, event) {
    var name = "Click";
    if (repeat == "double") { name = "Double" + name; }
    else if (repeat == "triple") { name = "Triple" + name; }
    name = (button == 1 ? "Left" : button == 2 ? "Middle" : "Right") + name;

    return dispatchKey(cm,  addModifierNames(name, event), event, function (bound) {
      if (typeof bound == "string") { bound = commands[bound]; }
      if (!bound) { return false }
      var done = false;
      try {
        if (cm.isReadOnly()) { cm.state.suppressEdits = true; }
        done = bound(cm, pos) != Pass;
      } finally {
        cm.state.suppressEdits = false;
      }
      return done
    })
  }

  function configureMouse(cm, repeat, event) {
    var option = cm.getOption("configureMouse");
    var value = option ? option(cm, repeat, event) : {};
    if (value.unit == null) {
      var rect = chromeOS ? event.shiftKey && event.metaKey : event.altKey;
      value.unit = rect ? "rectangle" : repeat == "single" ? "char" : repeat == "double" ? "word" : "line";
    }
    if (value.extend == null || cm.doc.extend) { value.extend = cm.doc.extend || event.shiftKey; }
    if (value.addNew == null) { value.addNew = mac ? event.metaKey : event.ctrlKey; }
    if (value.moveOnDrag == null) { value.moveOnDrag = !(mac ? event.altKey : event.ctrlKey); }
    return value
  }

  function leftButtonDown(cm, pos, repeat, event) {
    if (ie) { setTimeout(bind(ensureFocus, cm), 0); }
    else { cm.curOp.focus = activeElt(); }

    var behavior = configureMouse(cm, repeat, event);

    var sel = cm.doc.sel, contained;
    if (cm.options.dragDrop && dragAndDrop && !cm.isReadOnly() &&
        repeat == "single" && (contained = sel.contains(pos)) > -1 &&
        (cmp((contained = sel.ranges[contained]).from(), pos) < 0 || pos.xRel > 0) &&
        (cmp(contained.to(), pos) > 0 || pos.xRel < 0))
      { leftButtonStartDrag(cm, event, pos, behavior); }
    else
      { leftButtonSelect(cm, event, pos, behavior); }
  }

  // Start a text drag. When it ends, see if any dragging actually
  // happen, and treat as a click if it didn't.
  function leftButtonStartDrag(cm, event, pos, behavior) {
    var display = cm.display, moved = false;
    var dragEnd = operation(cm, function (e) {
      if (webkit) { display.scroller.draggable = false; }
      cm.state.draggingText = false;
      if (cm.state.delayingBlurEvent) {
        if (cm.hasFocus()) { cm.state.delayingBlurEvent = false; }
        else { delayBlurEvent(cm); }
      }
      off(display.wrapper.ownerDocument, "mouseup", dragEnd);
      off(display.wrapper.ownerDocument, "mousemove", mouseMove);
      off(display.scroller, "dragstart", dragStart);
      off(display.scroller, "drop", dragEnd);
      if (!moved) {
        e_preventDefault(e);
        if (!behavior.addNew)
          { extendSelection(cm.doc, pos, null, null, behavior.extend); }
        // Work around unexplainable focus problem in IE9 (#2127) and Chrome (#3081)
        if ((webkit && !safari) || ie && ie_version == 9)
          { setTimeout(function () {display.wrapper.ownerDocument.body.focus({preventScroll: true}); display.input.focus();}, 20); }
        else
          { display.input.focus(); }
      }
    });
    var mouseMove = function(e2) {
      moved = moved || Math.abs(event.clientX - e2.clientX) + Math.abs(event.clientY - e2.clientY) >= 10;
    };
    var dragStart = function () { return moved = true; };
    // Let the drag handler handle this.
    if (webkit) { display.scroller.draggable = true; }
    cm.state.draggingText = dragEnd;
    dragEnd.copy = !behavior.moveOnDrag;
    on(display.wrapper.ownerDocument, "mouseup", dragEnd);
    on(display.wrapper.ownerDocument, "mousemove", mouseMove);
    on(display.scroller, "dragstart", dragStart);
    on(display.scroller, "drop", dragEnd);

    cm.state.delayingBlurEvent = true;
    setTimeout(function () { return display.input.focus(); }, 20);
    // IE's approach to draggable
    if (display.scroller.dragDrop) { display.scroller.dragDrop(); }
  }

  function rangeForUnit(cm, pos, unit) {
    if (unit == "char") { return new Range(pos, pos) }
    if (unit == "word") { return cm.findWordAt(pos) }
    if (unit == "line") { return new Range(Pos(pos.line, 0), clipPos(cm.doc, Pos(pos.line + 1, 0))) }
    var result = unit(cm, pos);
    return new Range(result.from, result.to)
  }

  // Normal selection, as opposed to text dragging.
  function leftButtonSelect(cm, event, start, behavior) {
    if (ie) { delayBlurEvent(cm); }
    var display = cm.display, doc = cm.doc;
    e_preventDefault(event);

    var ourRange, ourIndex, startSel = doc.sel, ranges = startSel.ranges;
    if (behavior.addNew && !behavior.extend) {
      ourIndex = doc.sel.contains(start);
      if (ourIndex > -1)
        { ourRange = ranges[ourIndex]; }
      else
        { ourRange = new Range(start, start); }
    } else {
      ourRange = doc.sel.primary();
      ourIndex = doc.sel.primIndex;
    }

    if (behavior.unit == "rectangle") {
      if (!behavior.addNew) { ourRange = new Range(start, start); }
      start = posFromMouse(cm, event, true, true);
      ourIndex = -1;
    } else {
      var range = rangeForUnit(cm, start, behavior.unit);
      if (behavior.extend)
        { ourRange = extendRange(ourRange, range.anchor, range.head, behavior.extend); }
      else
        { ourRange = range; }
    }

    if (!behavior.addNew) {
      ourIndex = 0;
      setSelection(doc, new Selection([ourRange], 0), sel_mouse);
      startSel = doc.sel;
    } else if (ourIndex == -1) {
      ourIndex = ranges.length;
      setSelection(doc, normalizeSelection(cm, ranges.concat([ourRange]), ourIndex),
                   {scroll: false, origin: "*mouse"});
    } else if (ranges.length > 1 && ranges[ourIndex].empty() && behavior.unit == "char" && !behavior.extend) {
      setSelection(doc, normalizeSelection(cm, ranges.slice(0, ourIndex).concat(ranges.slice(ourIndex + 1)), 0),
                   {scroll: false, origin: "*mouse"});
      startSel = doc.sel;
    } else {
      replaceOneSelection(doc, ourIndex, ourRange, sel_mouse);
    }

    var lastPos = start;
    function extendTo(pos) {
      if (cmp(lastPos, pos) == 0) { return }
      lastPos = pos;

      if (behavior.unit == "rectangle") {
        var ranges = [], tabSize = cm.options.tabSize;
        var startCol = countColumn(getLine(doc, start.line).text, start.ch, tabSize);
        var posCol = countColumn(getLine(doc, pos.line).text, pos.ch, tabSize);
        var left = Math.min(startCol, posCol), right = Math.max(startCol, posCol);
        for (var line = Math.min(start.line, pos.line), end = Math.min(cm.lastLine(), Math.max(start.line, pos.line));
             line <= end; line++) {
          var text = getLine(doc, line).text, leftPos = findColumn(text, left, tabSize);
          if (left == right)
            { ranges.push(new Range(Pos(line, leftPos), Pos(line, leftPos))); }
          else if (text.length > leftPos)
            { ranges.push(new Range(Pos(line, leftPos), Pos(line, findColumn(text, right, tabSize)))); }
        }
        if (!ranges.length) { ranges.push(new Range(start, start)); }
        setSelection(doc, normalizeSelection(cm, startSel.ranges.slice(0, ourIndex).concat(ranges), ourIndex),
                     {origin: "*mouse", scroll: false});
        cm.scrollIntoView(pos);
      } else {
        var oldRange = ourRange;
        var range = rangeForUnit(cm, pos, behavior.unit);
        var anchor = oldRange.anchor, head;
        if (cmp(range.anchor, anchor) > 0) {
          head = range.head;
          anchor = minPos(oldRange.from(), range.anchor);
        } else {
          head = range.anchor;
          anchor = maxPos(oldRange.to(), range.head);
        }
        var ranges$1 = startSel.ranges.slice(0);
        ranges$1[ourIndex] = bidiSimplify(cm, new Range(clipPos(doc, anchor), head));
        setSelection(doc, normalizeSelection(cm, ranges$1, ourIndex), sel_mouse);
      }
    }

    var editorSize = display.wrapper.getBoundingClientRect();
    // Used to ensure timeout re-tries don't fire when another extend
    // happened in the meantime (clearTimeout isn't reliable -- at
    // least on Chrome, the timeouts still happen even when cleared,
    // if the clear happens after their scheduled firing time).
    var counter = 0;

    function extend(e) {
      var curCount = ++counter;
      var cur = posFromMouse(cm, e, true, behavior.unit == "rectangle");
      if (!cur) { return }
      if (cmp(cur, lastPos) != 0) {
        cm.curOp.focus = activeElt();
        extendTo(cur);
        var visible = visibleLines(display, doc);
        if (cur.line >= visible.to || cur.line < visible.from)
          { setTimeout(operation(cm, function () {if (counter == curCount) { extend(e); }}), 150); }
      } else {
        var outside = e.clientY < editorSize.top ? -20 : e.clientY > editorSize.bottom ? 20 : 0;
        if (outside) { setTimeout(operation(cm, function () {
          if (counter != curCount) { return }
          display.scroller.scrollTop += outside;
          extend(e);
        }), 50); }
      }
    }

    function done(e) {
      cm.state.selectingText = false;
      counter = Infinity;
      // If e is null or undefined we interpret this as someone trying
      // to explicitly cancel the selection rather than the user
      // letting go of the mouse button.
      if (e) {
        e_preventDefault(e);
        display.input.focus();
      }
      off(display.wrapper.ownerDocument, "mousemove", move);
      off(display.wrapper.ownerDocument, "mouseup", up);
      doc.history.lastSelOrigin = null;
    }

    var move = operation(cm, function (e) {
      if (e.buttons === 0 || !e_button(e)) { done(e); }
      else { extend(e); }
    });
    var up = operation(cm, done);
    cm.state.selectingText = up;
    on(display.wrapper.ownerDocument, "mousemove", move);
    on(display.wrapper.ownerDocument, "mouseup", up);
  }

  // Used when mouse-selecting to adjust the anchor to the proper side
  // of a bidi jump depending on the visual position of the head.
  function bidiSimplify(cm, range) {
    var anchor = range.anchor;
    var head = range.head;
    var anchorLine = getLine(cm.doc, anchor.line);
    if (cmp(anchor, head) == 0 && anchor.sticky == head.sticky) { return range }
    var order = getOrder(anchorLine);
    if (!order) { return range }
    var index = getBidiPartAt(order, anchor.ch, anchor.sticky), part = order[index];
    if (part.from != anchor.ch && part.to != anchor.ch) { return range }
    var boundary = index + ((part.from == anchor.ch) == (part.level != 1) ? 0 : 1);
    if (boundary == 0 || boundary == order.length) { return range }

    // Compute the relative visual position of the head compared to the
    // anchor (<0 is to the left, >0 to the right)
    var leftSide;
    if (head.line != anchor.line) {
      leftSide = (head.line - anchor.line) * (cm.doc.direction == "ltr" ? 1 : -1) > 0;
    } else {
      var headIndex = getBidiPartAt(order, head.ch, head.sticky);
      var dir = headIndex - index || (head.ch - anchor.ch) * (part.level == 1 ? -1 : 1);
      if (headIndex == boundary - 1 || headIndex == boundary)
        { leftSide = dir < 0; }
      else
        { leftSide = dir > 0; }
    }

    var usePart = order[boundary + (leftSide ? -1 : 0)];
    var from = leftSide == (usePart.level == 1);
    var ch = from ? usePart.from : usePart.to, sticky = from ? "after" : "before";
    return anchor.ch == ch && anchor.sticky == sticky ? range : new Range(new Pos(anchor.line, ch, sticky), head)
  }


  // Determines whether an event happened in the gutter, and fires the
  // handlers for the corresponding event.
  function gutterEvent(cm, e, type, prevent) {
    var mX, mY;
    if (e.touches) {
      mX = e.touches[0].clientX;
      mY = e.touches[0].clientY;
    } else {
      try { mX = e.clientX; mY = e.clientY; }
      catch(e$1) { return false }
    }
    if (mX >= Math.floor(cm.display.gutters.getBoundingClientRect().right)) { return false }
    if (prevent) { e_preventDefault(e); }

    var display = cm.display;
    var lineBox = display.lineDiv.getBoundingClientRect();

    if (mY > lineBox.bottom || !hasHandler(cm, type)) { return e_defaultPrevented(e) }
    mY -= lineBox.top - display.viewOffset;

    for (var i = 0; i < cm.display.gutterSpecs.length; ++i) {
      var g = display.gutters.childNodes[i];
      if (g && g.getBoundingClientRect().right >= mX) {
        var line = lineAtHeight(cm.doc, mY);
        var gutter = cm.display.gutterSpecs[i];
        signal(cm, type, cm, line, gutter.className, e);
        return e_defaultPrevented(e)
      }
    }
  }

  function clickInGutter(cm, e) {
    return gutterEvent(cm, e, "gutterClick", true)
  }

  // CONTEXT MENU HANDLING

  // To make the context menu work, we need to briefly unhide the
  // textarea (making it as unobtrusive as possible) to let the
  // right-click take effect on it.
  function onContextMenu(cm, e) {
    if (eventInWidget(cm.display, e) || contextMenuInGutter(cm, e)) { return }
    if (signalDOMEvent(cm, e, "contextmenu")) { return }
    if (!captureRightClick) { cm.display.input.onContextMenu(e); }
  }

  function contextMenuInGutter(cm, e) {
    if (!hasHandler(cm, "gutterContextMenu")) { return false }
    return gutterEvent(cm, e, "gutterContextMenu", false)
  }

  function themeChanged(cm) {
    cm.display.wrapper.className = cm.display.wrapper.className.replace(/\s*cm-s-\S+/g, "") +
      cm.options.theme.replace(/(^|\s)\s*/g, " cm-s-");
    clearCaches(cm);
  }

  var Init = {toString: function(){return "CodeMirror.Init"}};

  var defaults = {};
  var optionHandlers = {};

  function defineOptions(CodeMirror) {
    var optionHandlers = CodeMirror.optionHandlers;

    function option(name, deflt, handle, notOnInit) {
      CodeMirror.defaults[name] = deflt;
      if (handle) { optionHandlers[name] =
        notOnInit ? function (cm, val, old) {if (old != Init) { handle(cm, val, old); }} : handle; }
    }

    CodeMirror.defineOption = option;

    // Passed to option handlers when there is no old value.
    CodeMirror.Init = Init;

    // These two are, on init, called from the constructor because they
    // have to be initialized before the editor can start at all.
    option("value", "", function (cm, val) { return cm.setValue(val); }, true);
    option("mode", null, function (cm, val) {
      cm.doc.modeOption = val;
      loadMode(cm);
    }, true);

    option("indentUnit", 2, loadMode, true);
    option("indentWithTabs", false);
    option("smartIndent", true);
    option("tabSize", 4, function (cm) {
      resetModeState(cm);
      clearCaches(cm);
      regChange(cm);
    }, true);

    option("lineSeparator", null, function (cm, val) {
      cm.doc.lineSep = val;
      if (!val) { return }
      var newBreaks = [], lineNo = cm.doc.first;
      cm.doc.iter(function (line) {
        for (var pos = 0;;) {
          var found = line.text.indexOf(val, pos);
          if (found == -1) { break }
          pos = found + val.length;
          newBreaks.push(Pos(lineNo, found));
        }
        lineNo++;
      });
      for (var i = newBreaks.length - 1; i >= 0; i--)
        { replaceRange(cm.doc, val, newBreaks[i], Pos(newBreaks[i].line, newBreaks[i].ch + val.length)); }
    });
    option("specialChars", /[\u0000-\u001f\u007f-\u009f\u00ad\u061c\u200b\u200e\u200f\u2028\u2029\ufeff\ufff9-\ufffc]/g, function (cm, val, old) {
      cm.state.specialChars = new RegExp(val.source + (val.test("\t") ? "" : "|\t"), "g");
      if (old != Init) { cm.refresh(); }
    });
    option("specialCharPlaceholder", defaultSpecialCharPlaceholder, function (cm) { return cm.refresh(); }, true);
    option("electricChars", true);
    option("inputStyle", mobile ? "contenteditable" : "textarea", function () {
      throw new Error("inputStyle can not (yet) be changed in a running editor") // FIXME
    }, true);
    option("spellcheck", false, function (cm, val) { return cm.getInputField().spellcheck = val; }, true);
    option("autocorrect", false, function (cm, val) { return cm.getInputField().autocorrect = val; }, true);
    option("autocapitalize", false, function (cm, val) { return cm.getInputField().autocapitalize = val; }, true);
    option("rtlMoveVisually", !windows);
    option("wholeLineUpdateBefore", true);

    option("theme", "default", function (cm) {
      themeChanged(cm);
      updateGutters(cm);
    }, true);
    option("keyMap", "default", function (cm, val, old) {
      var next = getKeyMap(val);
      var prev = old != Init && getKeyMap(old);
      if (prev && prev.detach) { prev.detach(cm, next); }
      if (next.attach) { next.attach(cm, prev || null); }
    });
    option("extraKeys", null);
    option("configureMouse", null);

    option("lineWrapping", false, wrappingChanged, true);
    option("gutters", [], function (cm, val) {
      cm.display.gutterSpecs = getGutters(val, cm.options.lineNumbers);
      updateGutters(cm);
    }, true);
    option("fixedGutter", true, function (cm, val) {
      cm.display.gutters.style.left = val ? compensateForHScroll(cm.display) + "px" : "0";
      cm.refresh();
    }, true);
    option("coverGutterNextToScrollbar", false, function (cm) { return updateScrollbars(cm); }, true);
    option("scrollbarStyle", "native", function (cm) {
      initScrollbars(cm);
      updateScrollbars(cm);
      cm.display.scrollbars.setScrollTop(cm.doc.scrollTop);
      cm.display.scrollbars.setScrollLeft(cm.doc.scrollLeft);
    }, true);
    option("lineNumbers", false, function (cm, val) {
      cm.display.gutterSpecs = getGutters(cm.options.gutters, val);
      updateGutters(cm);
    }, true);
    option("firstLineNumber", 1, updateGutters, true);
    option("lineNumberFormatter", function (integer) { return integer; }, updateGutters, true);
    option("showCursorWhenSelecting", false, updateSelection, true);

    option("resetSelectionOnContextMenu", true);
    option("lineWiseCopyCut", true);
    option("pasteLinesPerSelection", true);
    option("selectionsMayTouch", false);

    option("readOnly", false, function (cm, val) {
      if (val == "nocursor") {
        onBlur(cm);
        cm.display.input.blur();
      }
      cm.display.input.readOnlyChanged(val);
    });

    option("screenReaderLabel", null, function (cm, val) {
      val = (val === '') ? null : val;
      cm.display.input.screenReaderLabelChanged(val);
    });

    option("disableInput", false, function (cm, val) {if (!val) { cm.display.input.reset(); }}, true);
    option("dragDrop", true, dragDropChanged);
    option("allowDropFileTypes", null);

    option("cursorBlinkRate", 530);
    option("cursorScrollMargin", 0);
    option("cursorHeight", 1, updateSelection, true);
    option("singleCursorHeightPerLine", true, updateSelection, true);
    option("workTime", 100);
    option("workDelay", 100);
    option("flattenSpans", true, resetModeState, true);
    option("addModeClass", false, resetModeState, true);
    option("pollInterval", 100);
    option("undoDepth", 200, function (cm, val) { return cm.doc.history.undoDepth = val; });
    option("historyEventDelay", 1250);
    option("viewportMargin", 10, function (cm) { return cm.refresh(); }, true);
    option("maxHighlightLength", 10000, resetModeState, true);
    option("moveInputWithCursor", true, function (cm, val) {
      if (!val) { cm.display.input.resetPosition(); }
    });

    option("tabindex", null, function (cm, val) { return cm.display.input.getField().tabIndex = val || ""; });
    option("autofocus", null);
    option("direction", "ltr", function (cm, val) { return cm.doc.setDirection(val); }, true);
    option("phrases", null);
  }

  function dragDropChanged(cm, value, old) {
    var wasOn = old && old != Init;
    if (!value != !wasOn) {
      var funcs = cm.display.dragFunctions;
      var toggle = value ? on : off;
      toggle(cm.display.scroller, "dragstart", funcs.start);
      toggle(cm.display.scroller, "dragenter", funcs.enter);
      toggle(cm.display.scroller, "dragover", funcs.over);
      toggle(cm.display.scroller, "dragleave", funcs.leave);
      toggle(cm.display.scroller, "drop", funcs.drop);
    }
  }

  function wrappingChanged(cm) {
    if (cm.options.lineWrapping) {
      addClass(cm.display.wrapper, "CodeMirror-wrap");
      cm.display.sizer.style.minWidth = "";
      cm.display.sizerWidth = null;
    } else {
      rmClass(cm.display.wrapper, "CodeMirror-wrap");
      findMaxLine(cm);
    }
    estimateLineHeights(cm);
    regChange(cm);
    clearCaches(cm);
    setTimeout(function () { return updateScrollbars(cm); }, 100);
  }

  // A CodeMirror instance represents an editor. This is the object
  // that user code is usually dealing with.

  function CodeMirror(place, options) {
    var this$1 = this;

    if (!(this instanceof CodeMirror)) { return new CodeMirror(place, options) }

    this.options = options = options ? copyObj(options) : {};
    // Determine effective options based on given values and defaults.
    copyObj(defaults, options, false);

    var doc = options.value;
    if (typeof doc == "string") { doc = new Doc(doc, options.mode, null, options.lineSeparator, options.direction); }
    else if (options.mode) { doc.modeOption = options.mode; }
    this.doc = doc;

    var input = new CodeMirror.inputStyles[options.inputStyle](this);
    var display = this.display = new Display(place, doc, input, options);
    display.wrapper.CodeMirror = this;
    themeChanged(this);
    if (options.lineWrapping)
      { this.display.wrapper.className += " CodeMirror-wrap"; }
    initScrollbars(this);

    this.state = {
      keyMaps: [],  // stores maps added by addKeyMap
      overlays: [], // highlighting overlays, as added by addOverlay
      modeGen: 0,   // bumped when mode/overlay changes, used to invalidate highlighting info
      overwrite: false,
      delayingBlurEvent: false,
      focused: false,
      suppressEdits: false, // used to disable editing during key handlers when in readOnly mode
      pasteIncoming: -1, cutIncoming: -1, // help recognize paste/cut edits in input.poll
      selectingText: false,
      draggingText: false,
      highlight: new Delayed(), // stores highlight worker timeout
      keySeq: null,  // Unfinished key sequence
      specialChars: null
    };

    if (options.autofocus && !mobile) { display.input.focus(); }

    // Override magic textarea content restore that IE sometimes does
    // on our hidden textarea on reload
    if (ie && ie_version < 11) { setTimeout(function () { return this$1.display.input.reset(true); }, 20); }

    registerEventHandlers(this);
    ensureGlobalHandlers();

    startOperation(this);
    this.curOp.forceUpdate = true;
    attachDoc(this, doc);

    if ((options.autofocus && !mobile) || this.hasFocus())
      { setTimeout(function () {
        if (this$1.hasFocus() && !this$1.state.focused) { onFocus(this$1); }
      }, 20); }
    else
      { onBlur(this); }

    for (var opt in optionHandlers) { if (optionHandlers.hasOwnProperty(opt))
      { optionHandlers[opt](this, options[opt], Init); } }
    maybeUpdateLineNumberWidth(this);
    if (options.finishInit) { options.finishInit(this); }
    for (var i = 0; i < initHooks.length; ++i) { initHooks[i](this); }
    endOperation(this);
    // Suppress optimizelegibility in Webkit, since it breaks text
    // measuring on line wrapping boundaries.
    if (webkit && options.lineWrapping &&
        getComputedStyle(display.lineDiv).textRendering == "optimizelegibility")
      { display.lineDiv.style.textRendering = "auto"; }
  }

  // The default configuration options.
  CodeMirror.defaults = defaults;
  // Functions to run when options are changed.
  CodeMirror.optionHandlers = optionHandlers;

  // Attach the necessary event handlers when initializing the editor
  function registerEventHandlers(cm) {
    var d = cm.display;
    on(d.scroller, "mousedown", operation(cm, onMouseDown));
    // Older IE's will not fire a second mousedown for a double click
    if (ie && ie_version < 11)
      { on(d.scroller, "dblclick", operation(cm, function (e) {
        if (signalDOMEvent(cm, e)) { return }
        var pos = posFromMouse(cm, e);
        if (!pos || clickInGutter(cm, e) || eventInWidget(cm.display, e)) { return }
        e_preventDefault(e);
        var word = cm.findWordAt(pos);
        extendSelection(cm.doc, word.anchor, word.head);
      })); }
    else
      { on(d.scroller, "dblclick", function (e) { return signalDOMEvent(cm, e) || e_preventDefault(e); }); }
    // Some browsers fire contextmenu *after* opening the menu, at
    // which point we can't mess with it anymore. Context menu is
    // handled in onMouseDown for these browsers.
    on(d.scroller, "contextmenu", function (e) { return onContextMenu(cm, e); });
    on(d.input.getField(), "contextmenu", function (e) {
      if (!d.scroller.contains(e.target)) { onContextMenu(cm, e); }
    });

    // Used to suppress mouse event handling when a touch happens
    var touchFinished, prevTouch = {end: 0};
    function finishTouch() {
      if (d.activeTouch) {
        touchFinished = setTimeout(function () { return d.activeTouch = null; }, 1000);
        prevTouch = d.activeTouch;
        prevTouch.end = +new Date;
      }
    }
    function isMouseLikeTouchEvent(e) {
      if (e.touches.length != 1) { return false }
      var touch = e.touches[0];
      return touch.radiusX <= 1 && touch.radiusY <= 1
    }
    function farAway(touch, other) {
      if (other.left == null) { return true }
      var dx = other.left - touch.left, dy = other.top - touch.top;
      return dx * dx + dy * dy > 20 * 20
    }
    on(d.scroller, "touchstart", function (e) {
      if (!signalDOMEvent(cm, e) && !isMouseLikeTouchEvent(e) && !clickInGutter(cm, e)) {
        d.input.ensurePolled();
        clearTimeout(touchFinished);
        var now = +new Date;
        d.activeTouch = {start: now, moved: false,
                         prev: now - prevTouch.end <= 300 ? prevTouch : null};
        if (e.touches.length == 1) {
          d.activeTouch.left = e.touches[0].pageX;
          d.activeTouch.top = e.touches[0].pageY;
        }
      }
    });
    on(d.scroller, "touchmove", function () {
      if (d.activeTouch) { d.activeTouch.moved = true; }
    });
    on(d.scroller, "touchend", function (e) {
      var touch = d.activeTouch;
      if (touch && !eventInWidget(d, e) && touch.left != null &&
          !touch.moved && new Date - touch.start < 300) {
        var pos = cm.coordsChar(d.activeTouch, "page"), range;
        if (!touch.prev || farAway(touch, touch.prev)) // Single tap
          { range = new Range(pos, pos); }
        else if (!touch.prev.prev || farAway(touch, touch.prev.prev)) // Double tap
          { range = cm.findWordAt(pos); }
        else // Triple tap
          { range = new Range(Pos(pos.line, 0), clipPos(cm.doc, Pos(pos.line + 1, 0))); }
        cm.setSelection(range.anchor, range.head);
        cm.focus();
        e_preventDefault(e);
      }
      finishTouch();
    });
    on(d.scroller, "touchcancel", finishTouch);

    // Sync scrolling between fake scrollbars and real scrollable
    // area, ensure viewport is updated when scrolling.
    on(d.scroller, "scroll", function () {
      if (d.scroller.clientHeight) {
        updateScrollTop(cm, d.scroller.scrollTop);
        setScrollLeft(cm, d.scroller.scrollLeft, true);
        signal(cm, "scroll", cm);
      }
    });

    // Listen to wheel events in order to try and update the viewport on time.
    on(d.scroller, "mousewheel", function (e) { return onScrollWheel(cm, e); });
    on(d.scroller, "DOMMouseScroll", function (e) { return onScrollWheel(cm, e); });

    // Prevent wrapper from ever scrolling
    on(d.wrapper, "scroll", function () { return d.wrapper.scrollTop = d.wrapper.scrollLeft = 0; });

    d.dragFunctions = {
      enter: function (e) {if (!signalDOMEvent(cm, e)) { e_stop(e); }},
      over: function (e) {if (!signalDOMEvent(cm, e)) { onDragOver(cm, e); e_stop(e); }},
      start: function (e) { return onDragStart(cm, e); },
      drop: operation(cm, onDrop),
      leave: function (e) {if (!signalDOMEvent(cm, e)) { clearDragCursor(cm); }}
    };

    var inp = d.input.getField();
    on(inp, "keyup", function (e) { return onKeyUp.call(cm, e); });
    on(inp, "keydown", operation(cm, onKeyDown));
    on(inp, "keypress", operation(cm, onKeyPress));
    on(inp, "focus", function (e) { return onFocus(cm, e); });
    on(inp, "blur", function (e) { return onBlur(cm, e); });
  }

  var initHooks = [];
  CodeMirror.defineInitHook = function (f) { return initHooks.push(f); };

  // Indent the given line. The how parameter can be "smart",
  // "add"/null, "subtract", or "prev". When aggressive is false
  // (typically set to true for forced single-line indents), empty
  // lines are not indented, and places where the mode returns Pass
  // are left alone.
  function indentLine(cm, n, how, aggressive) {
    var doc = cm.doc, state;
    if (how == null) { how = "add"; }
    if (how == "smart") {
      // Fall back to "prev" when the mode doesn't have an indentation
      // method.
      if (!doc.mode.indent) { how = "prev"; }
      else { state = getContextBefore(cm, n).state; }
    }

    var tabSize = cm.options.tabSize;
    var line = getLine(doc, n), curSpace = countColumn(line.text, null, tabSize);
    if (line.stateAfter) { line.stateAfter = null; }
    var curSpaceString = line.text.match(/^\s*/)[0], indentation;
    if (!aggressive && !/\S/.test(line.text)) {
      indentation = 0;
      how = "not";
    } else if (how == "smart") {
      indentation = doc.mode.indent(state, line.text.slice(curSpaceString.length), line.text);
      if (indentation == Pass || indentation > 150) {
        if (!aggressive) { return }
        how = "prev";
      }
    }
    if (how == "prev") {
      if (n > doc.first) { indentation = countColumn(getLine(doc, n-1).text, null, tabSize); }
      else { indentation = 0; }
    } else if (how == "add") {
      indentation = curSpace + cm.options.indentUnit;
    } else if (how == "subtract") {
      indentation = curSpace - cm.options.indentUnit;
    } else if (typeof how == "number") {
      indentation = curSpace + how;
    }
    indentation = Math.max(0, indentation);

    var indentString = "", pos = 0;
    if (cm.options.indentWithTabs)
      { for (var i = Math.floor(indentation / tabSize); i; --i) {pos += tabSize; indentString += "\t";} }
    if (pos < indentation) { indentString += spaceStr(indentation - pos); }

    if (indentString != curSpaceString) {
      replaceRange(doc, indentString, Pos(n, 0), Pos(n, curSpaceString.length), "+input");
      line.stateAfter = null;
      return true
    } else {
      // Ensure that, if the cursor was in the whitespace at the start
      // of the line, it is moved to the end of that space.
      for (var i$1 = 0; i$1 < doc.sel.ranges.length; i$1++) {
        var range = doc.sel.ranges[i$1];
        if (range.head.line == n && range.head.ch < curSpaceString.length) {
          var pos$1 = Pos(n, curSpaceString.length);
          replaceOneSelection(doc, i$1, new Range(pos$1, pos$1));
          break
        }
      }
    }
  }

  // This will be set to a {lineWise: bool, text: [string]} object, so
  // that, when pasting, we know what kind of selections the copied
  // text was made out of.
  var lastCopied = null;

  function setLastCopied(newLastCopied) {
    lastCopied = newLastCopied;
  }

  function applyTextInput(cm, inserted, deleted, sel, origin) {
    var doc = cm.doc;
    cm.display.shift = false;
    if (!sel) { sel = doc.sel; }

    var recent = +new Date - 200;
    var paste = origin == "paste" || cm.state.pasteIncoming > recent;
    var textLines = splitLinesAuto(inserted), multiPaste = null;
    // When pasting N lines into N selections, insert one line per selection
    if (paste && sel.ranges.length > 1) {
      if (lastCopied && lastCopied.text.join("\n") == inserted) {
        if (sel.ranges.length % lastCopied.text.length == 0) {
          multiPaste = [];
          for (var i = 0; i < lastCopied.text.length; i++)
            { multiPaste.push(doc.splitLines(lastCopied.text[i])); }
        }
      } else if (textLines.length == sel.ranges.length && cm.options.pasteLinesPerSelection) {
        multiPaste = map(textLines, function (l) { return [l]; });
      }
    }

    var updateInput = cm.curOp.updateInput;
    // Normal behavior is to insert the new text into every selection
    for (var i$1 = sel.ranges.length - 1; i$1 >= 0; i$1--) {
      var range = sel.ranges[i$1];
      var from = range.from(), to = range.to();
      if (range.empty()) {
        if (deleted && deleted > 0) // Handle deletion
          { from = Pos(from.line, from.ch - deleted); }
        else if (cm.state.overwrite && !paste) // Handle overwrite
          { to = Pos(to.line, Math.min(getLine(doc, to.line).text.length, to.ch + lst(textLines).length)); }
        else if (paste && lastCopied && lastCopied.lineWise && lastCopied.text.join("\n") == textLines.join("\n"))
          { from = to = Pos(from.line, 0); }
      }
      var changeEvent = {from: from, to: to, text: multiPaste ? multiPaste[i$1 % multiPaste.length] : textLines,
                         origin: origin || (paste ? "paste" : cm.state.cutIncoming > recent ? "cut" : "+input")};
      makeChange(cm.doc, changeEvent);
      signalLater(cm, "inputRead", cm, changeEvent);
    }
    if (inserted && !paste)
      { triggerElectric(cm, inserted); }

    ensureCursorVisible(cm);
    if (cm.curOp.updateInput < 2) { cm.curOp.updateInput = updateInput; }
    cm.curOp.typing = true;
    cm.state.pasteIncoming = cm.state.cutIncoming = -1;
  }

  function handlePaste(e, cm) {
    var pasted = e.clipboardData && e.clipboardData.getData("Text");
    if (pasted) {
      e.preventDefault();
      if (!cm.isReadOnly() && !cm.options.disableInput)
        { runInOp(cm, function () { return applyTextInput(cm, pasted, 0, null, "paste"); }); }
      return true
    }
  }

  function triggerElectric(cm, inserted) {
    // When an 'electric' character is inserted, immediately trigger a reindent
    if (!cm.options.electricChars || !cm.options.smartIndent) { return }
    var sel = cm.doc.sel;

    for (var i = sel.ranges.length - 1; i >= 0; i--) {
      var range = sel.ranges[i];
      if (range.head.ch > 100 || (i && sel.ranges[i - 1].head.line == range.head.line)) { continue }
      var mode = cm.getModeAt(range.head);
      var indented = false;
      if (mode.electricChars) {
        for (var j = 0; j < mode.electricChars.length; j++)
          { if (inserted.indexOf(mode.electricChars.charAt(j)) > -1) {
            indented = indentLine(cm, range.head.line, "smart");
            break
          } }
      } else if (mode.electricInput) {
        if (mode.electricInput.test(getLine(cm.doc, range.head.line).text.slice(0, range.head.ch)))
          { indented = indentLine(cm, range.head.line, "smart"); }
      }
      if (indented) { signalLater(cm, "electricInput", cm, range.head.line); }
    }
  }

  function copyableRanges(cm) {
    var text = [], ranges = [];
    for (var i = 0; i < cm.doc.sel.ranges.length; i++) {
      var line = cm.doc.sel.ranges[i].head.line;
      var lineRange = {anchor: Pos(line, 0), head: Pos(line + 1, 0)};
      ranges.push(lineRange);
      text.push(cm.getRange(lineRange.anchor, lineRange.head));
    }
    return {text: text, ranges: ranges}
  }

  function disableBrowserMagic(field, spellcheck, autocorrect, autocapitalize) {
    field.setAttribute("autocorrect", autocorrect ? "" : "off");
    field.setAttribute("autocapitalize", autocapitalize ? "" : "off");
    field.setAttribute("spellcheck", !!spellcheck);
  }

  function hiddenTextarea() {
    var te = elt("textarea", null, null, "position: absolute; bottom: -1em; padding: 0; width: 1px; height: 1em; min-height: 1em; outline: none");
    var div = elt("div", [te], null, "overflow: hidden; position: relative; width: 3px; height: 0px;");
    // The textarea is kept positioned near the cursor to prevent the
    // fact that it'll be scrolled into view on input from scrolling
    // our fake cursor out of view. On webkit, when wrap=off, paste is
    // very slow. So make the area wide instead.
    if (webkit) { te.style.width = "1000px"; }
    else { te.setAttribute("wrap", "off"); }
    // If border: 0; -- iOS fails to open keyboard (issue #1287)
    if (ios) { te.style.border = "1px solid black"; }
    disableBrowserMagic(te);
    return div
  }

  // The publicly visible API. Note that methodOp(f) means
  // 'wrap f in an operation, performed on its `this` parameter'.

  // This is not the complete set of editor methods. Most of the
  // methods defined on the Doc type are also injected into
  // CodeMirror.prototype, for backwards compatibility and
  // convenience.

  function addEditorMethods(CodeMirror) {
    var optionHandlers = CodeMirror.optionHandlers;

    var helpers = CodeMirror.helpers = {};

    CodeMirror.prototype = {
      constructor: CodeMirror,
      focus: function(){window.focus(); this.display.input.focus();},

      setOption: function(option, value) {
        var options = this.options, old = options[option];
        if (options[option] == value && option != "mode") { return }
        options[option] = value;
        if (optionHandlers.hasOwnProperty(option))
          { operation(this, optionHandlers[option])(this, value, old); }
        signal(this, "optionChange", this, option);
      },

      getOption: function(option) {return this.options[option]},
      getDoc: function() {return this.doc},

      addKeyMap: function(map, bottom) {
        this.state.keyMaps[bottom ? "push" : "unshift"](getKeyMap(map));
      },
      removeKeyMap: function(map) {
        var maps = this.state.keyMaps;
        for (var i = 0; i < maps.length; ++i)
          { if (maps[i] == map || maps[i].name == map) {
            maps.splice(i, 1);
            return true
          } }
      },

      addOverlay: methodOp(function(spec, options) {
        var mode = spec.token ? spec : CodeMirror.getMode(this.options, spec);
        if (mode.startState) { throw new Error("Overlays may not be stateful.") }
        insertSorted(this.state.overlays,
                     {mode: mode, modeSpec: spec, opaque: options && options.opaque,
                      priority: (options && options.priority) || 0},
                     function (overlay) { return overlay.priority; });
        this.state.modeGen++;
        regChange(this);
      }),
      removeOverlay: methodOp(function(spec) {
        var overlays = this.state.overlays;
        for (var i = 0; i < overlays.length; ++i) {
          var cur = overlays[i].modeSpec;
          if (cur == spec || typeof spec == "string" && cur.name == spec) {
            overlays.splice(i, 1);
            this.state.modeGen++;
            regChange(this);
            return
          }
        }
      }),

      indentLine: methodOp(function(n, dir, aggressive) {
        if (typeof dir != "string" && typeof dir != "number") {
          if (dir == null) { dir = this.options.smartIndent ? "smart" : "prev"; }
          else { dir = dir ? "add" : "subtract"; }
        }
        if (isLine(this.doc, n)) { indentLine(this, n, dir, aggressive); }
      }),
      indentSelection: methodOp(function(how) {
        var ranges = this.doc.sel.ranges, end = -1;
        for (var i = 0; i < ranges.length; i++) {
          var range = ranges[i];
          if (!range.empty()) {
            var from = range.from(), to = range.to();
            var start = Math.max(end, from.line);
            end = Math.min(this.lastLine(), to.line - (to.ch ? 0 : 1)) + 1;
            for (var j = start; j < end; ++j)
              { indentLine(this, j, how); }
            var newRanges = this.doc.sel.ranges;
            if (from.ch == 0 && ranges.length == newRanges.length && newRanges[i].from().ch > 0)
              { replaceOneSelection(this.doc, i, new Range(from, newRanges[i].to()), sel_dontScroll); }
          } else if (range.head.line > end) {
            indentLine(this, range.head.line, how, true);
            end = range.head.line;
            if (i == this.doc.sel.primIndex) { ensureCursorVisible(this); }
          }
        }
      }),

      // Fetch the parser token for a given character. Useful for hacks
      // that want to inspect the mode state (say, for completion).
      getTokenAt: function(pos, precise) {
        return takeToken(this, pos, precise)
      },

      getLineTokens: function(line, precise) {
        return takeToken(this, Pos(line), precise, true)
      },

      getTokenTypeAt: function(pos) {
        pos = clipPos(this.doc, pos);
        var styles = getLineStyles(this, getLine(this.doc, pos.line));
        var before = 0, after = (styles.length - 1) / 2, ch = pos.ch;
        var type;
        if (ch == 0) { type = styles[2]; }
        else { for (;;) {
          var mid = (before + after) >> 1;
          if ((mid ? styles[mid * 2 - 1] : 0) >= ch) { after = mid; }
          else if (styles[mid * 2 + 1] < ch) { before = mid + 1; }
          else { type = styles[mid * 2 + 2]; break }
        } }
        var cut = type ? type.indexOf("overlay ") : -1;
        return cut < 0 ? type : cut == 0 ? null : type.slice(0, cut - 1)
      },

      getModeAt: function(pos) {
        var mode = this.doc.mode;
        if (!mode.innerMode) { return mode }
        return CodeMirror.innerMode(mode, this.getTokenAt(pos).state).mode
      },

      getHelper: function(pos, type) {
        return this.getHelpers(pos, type)[0]
      },

      getHelpers: function(pos, type) {
        var found = [];
        if (!helpers.hasOwnProperty(type)) { return found }
        var help = helpers[type], mode = this.getModeAt(pos);
        if (typeof mode[type] == "string") {
          if (help[mode[type]]) { found.push(help[mode[type]]); }
        } else if (mode[type]) {
          for (var i = 0; i < mode[type].length; i++) {
            var val = help[mode[type][i]];
            if (val) { found.push(val); }
          }
        } else if (mode.helperType && help[mode.helperType]) {
          found.push(help[mode.helperType]);
        } else if (help[mode.name]) {
          found.push(help[mode.name]);
        }
        for (var i$1 = 0; i$1 < help._global.length; i$1++) {
          var cur = help._global[i$1];
          if (cur.pred(mode, this) && indexOf(found, cur.val) == -1)
            { found.push(cur.val); }
        }
        return found
      },

      getStateAfter: function(line, precise) {
        var doc = this.doc;
        line = clipLine(doc, line == null ? doc.first + doc.size - 1: line);
        return getContextBefore(this, line + 1, precise).state
      },

      cursorCoords: function(start, mode) {
        var pos, range = this.doc.sel.primary();
        if (start == null) { pos = range.head; }
        else if (typeof start == "object") { pos = clipPos(this.doc, start); }
        else { pos = start ? range.from() : range.to(); }
        return cursorCoords(this, pos, mode || "page")
      },

      charCoords: function(pos, mode) {
        return charCoords(this, clipPos(this.doc, pos), mode || "page")
      },

      coordsChar: function(coords, mode) {
        coords = fromCoordSystem(this, coords, mode || "page");
        return coordsChar(this, coords.left, coords.top)
      },

      lineAtHeight: function(height, mode) {
        height = fromCoordSystem(this, {top: height, left: 0}, mode || "page").top;
        return lineAtHeight(this.doc, height + this.display.viewOffset)
      },
      heightAtLine: function(line, mode, includeWidgets) {
        var end = false, lineObj;
        if (typeof line == "number") {
          var last = this.doc.first + this.doc.size - 1;
          if (line < this.doc.first) { line = this.doc.first; }
          else if (line > last) { line = last; end = true; }
          lineObj = getLine(this.doc, line);
        } else {
          lineObj = line;
        }
        return intoCoordSystem(this, lineObj, {top: 0, left: 0}, mode || "page", includeWidgets || end).top +
          (end ? this.doc.height - heightAtLine(lineObj) : 0)
      },

      defaultTextHeight: function() { return textHeight(this.display) },
      defaultCharWidth: function() { return charWidth(this.display) },

      getViewport: function() { return {from: this.display.viewFrom, to: this.display.viewTo}},

      addWidget: function(pos, node, scroll, vert, horiz) {
        var display = this.display;
        pos = cursorCoords(this, clipPos(this.doc, pos));
        var top = pos.bottom, left = pos.left;
        node.style.position = "absolute";
        node.setAttribute("cm-ignore-events", "true");
        this.display.input.setUneditable(node);
        display.sizer.appendChild(node);
        if (vert == "over") {
          top = pos.top;
        } else if (vert == "above" || vert == "near") {
          var vspace = Math.max(display.wrapper.clientHeight, this.doc.height),
          hspace = Math.max(display.sizer.clientWidth, display.lineSpace.clientWidth);
          // Default to positioning above (if specified and possible); otherwise default to positioning below
          if ((vert == 'above' || pos.bottom + node.offsetHeight > vspace) && pos.top > node.offsetHeight)
            { top = pos.top - node.offsetHeight; }
          else if (pos.bottom + node.offsetHeight <= vspace)
            { top = pos.bottom; }
          if (left + node.offsetWidth > hspace)
            { left = hspace - node.offsetWidth; }
        }
        node.style.top = top + "px";
        node.style.left = node.style.right = "";
        if (horiz == "right") {
          left = display.sizer.clientWidth - node.offsetWidth;
          node.style.right = "0px";
        } else {
          if (horiz == "left") { left = 0; }
          else if (horiz == "middle") { left = (display.sizer.clientWidth - node.offsetWidth) / 2; }
          node.style.left = left + "px";
        }
        if (scroll)
          { scrollIntoView(this, {left: left, top: top, right: left + node.offsetWidth, bottom: top + node.offsetHeight}); }
      },

      triggerOnKeyDown: methodOp(onKeyDown),
      triggerOnKeyPress: methodOp(onKeyPress),
      triggerOnKeyUp: onKeyUp,
      triggerOnMouseDown: methodOp(onMouseDown),

      execCommand: function(cmd) {
        if (commands.hasOwnProperty(cmd))
          { return commands[cmd].call(null, this) }
      },

      triggerElectric: methodOp(function(text) { triggerElectric(this, text); }),

      findPosH: function(from, amount, unit, visually) {
        var dir = 1;
        if (amount < 0) { dir = -1; amount = -amount; }
        var cur = clipPos(this.doc, from);
        for (var i = 0; i < amount; ++i) {
          cur = findPosH(this.doc, cur, dir, unit, visually);
          if (cur.hitSide) { break }
        }
        return cur
      },

      moveH: methodOp(function(dir, unit) {
        var this$1 = this;

        this.extendSelectionsBy(function (range) {
          if (this$1.display.shift || this$1.doc.extend || range.empty())
            { return findPosH(this$1.doc, range.head, dir, unit, this$1.options.rtlMoveVisually) }
          else
            { return dir < 0 ? range.from() : range.to() }
        }, sel_move);
      }),

      deleteH: methodOp(function(dir, unit) {
        var sel = this.doc.sel, doc = this.doc;
        if (sel.somethingSelected())
          { doc.replaceSelection("", null, "+delete"); }
        else
          { deleteNearSelection(this, function (range) {
            var other = findPosH(doc, range.head, dir, unit, false);
            return dir < 0 ? {from: other, to: range.head} : {from: range.head, to: other}
          }); }
      }),

      findPosV: function(from, amount, unit, goalColumn) {
        var dir = 1, x = goalColumn;
        if (amount < 0) { dir = -1; amount = -amount; }
        var cur = clipPos(this.doc, from);
        for (var i = 0; i < amount; ++i) {
          var coords = cursorCoords(this, cur, "div");
          if (x == null) { x = coords.left; }
          else { coords.left = x; }
          cur = findPosV(this, coords, dir, unit);
          if (cur.hitSide) { break }
        }
        return cur
      },

      moveV: methodOp(function(dir, unit) {
        var this$1 = this;

        var doc = this.doc, goals = [];
        var collapse = !this.display.shift && !doc.extend && doc.sel.somethingSelected();
        doc.extendSelectionsBy(function (range) {
          if (collapse)
            { return dir < 0 ? range.from() : range.to() }
          var headPos = cursorCoords(this$1, range.head, "div");
          if (range.goalColumn != null) { headPos.left = range.goalColumn; }
          goals.push(headPos.left);
          var pos = findPosV(this$1, headPos, dir, unit);
          if (unit == "page" && range == doc.sel.primary())
            { addToScrollTop(this$1, charCoords(this$1, pos, "div").top - headPos.top); }
          return pos
        }, sel_move);
        if (goals.length) { for (var i = 0; i < doc.sel.ranges.length; i++)
          { doc.sel.ranges[i].goalColumn = goals[i]; } }
      }),

      // Find the word at the given position (as returned by coordsChar).
      findWordAt: function(pos) {
        var doc = this.doc, line = getLine(doc, pos.line).text;
        var start = pos.ch, end = pos.ch;
        if (line) {
          var helper = this.getHelper(pos, "wordChars");
          if ((pos.sticky == "before" || end == line.length) && start) { --start; } else { ++end; }
          var startChar = line.charAt(start);
          var check = isWordChar(startChar, helper)
            ? function (ch) { return isWordChar(ch, helper); }
            : /\s/.test(startChar) ? function (ch) { return /\s/.test(ch); }
            : function (ch) { return (!/\s/.test(ch) && !isWordChar(ch)); };
          while (start > 0 && check(line.charAt(start - 1))) { --start; }
          while (end < line.length && check(line.charAt(end))) { ++end; }
        }
        return new Range(Pos(pos.line, start), Pos(pos.line, end))
      },

      toggleOverwrite: function(value) {
        if (value != null && value == this.state.overwrite) { return }
        if (this.state.overwrite = !this.state.overwrite)
          { addClass(this.display.cursorDiv, "CodeMirror-overwrite"); }
        else
          { rmClass(this.display.cursorDiv, "CodeMirror-overwrite"); }

        signal(this, "overwriteToggle", this, this.state.overwrite);
      },
      hasFocus: function() { return this.display.input.getField() == activeElt() },
      isReadOnly: function() { return !!(this.options.readOnly || this.doc.cantEdit) },

      scrollTo: methodOp(function (x, y) { scrollToCoords(this, x, y); }),
      getScrollInfo: function() {
        var scroller = this.display.scroller;
        return {left: scroller.scrollLeft, top: scroller.scrollTop,
                height: scroller.scrollHeight - scrollGap(this) - this.display.barHeight,
                width: scroller.scrollWidth - scrollGap(this) - this.display.barWidth,
                clientHeight: displayHeight(this), clientWidth: displayWidth(this)}
      },

      scrollIntoView: methodOp(function(range, margin) {
        if (range == null) {
          range = {from: this.doc.sel.primary().head, to: null};
          if (margin == null) { margin = this.options.cursorScrollMargin; }
        } else if (typeof range == "number") {
          range = {from: Pos(range, 0), to: null};
        } else if (range.from == null) {
          range = {from: range, to: null};
        }
        if (!range.to) { range.to = range.from; }
        range.margin = margin || 0;

        if (range.from.line != null) {
          scrollToRange(this, range);
        } else {
          scrollToCoordsRange(this, range.from, range.to, range.margin);
        }
      }),

      setSize: methodOp(function(width, height) {
        var this$1 = this;

        var interpret = function (val) { return typeof val == "number" || /^\d+$/.test(String(val)) ? val + "px" : val; };
        if (width != null) { this.display.wrapper.style.width = interpret(width); }
        if (height != null) { this.display.wrapper.style.height = interpret(height); }
        if (this.options.lineWrapping) { clearLineMeasurementCache(this); }
        var lineNo = this.display.viewFrom;
        this.doc.iter(lineNo, this.display.viewTo, function (line) {
          if (line.widgets) { for (var i = 0; i < line.widgets.length; i++)
            { if (line.widgets[i].noHScroll) { regLineChange(this$1, lineNo, "widget"); break } } }
          ++lineNo;
        });
        this.curOp.forceUpdate = true;
        signal(this, "refresh", this);
      }),

      operation: function(f){return runInOp(this, f)},
      startOperation: function(){return startOperation(this)},
      endOperation: function(){return endOperation(this)},

      refresh: methodOp(function() {
        var oldHeight = this.display.cachedTextHeight;
        regChange(this);
        this.curOp.forceUpdate = true;
        clearCaches(this);
        scrollToCoords(this, this.doc.scrollLeft, this.doc.scrollTop);
        updateGutterSpace(this.display);
        if (oldHeight == null || Math.abs(oldHeight - textHeight(this.display)) > .5 || this.options.lineWrapping)
          { estimateLineHeights(this); }
        signal(this, "refresh", this);
      }),

      swapDoc: methodOp(function(doc) {
        var old = this.doc;
        old.cm = null;
        // Cancel the current text selection if any (#5821)
        if (this.state.selectingText) { this.state.selectingText(); }
        attachDoc(this, doc);
        clearCaches(this);
        this.display.input.reset();
        scrollToCoords(this, doc.scrollLeft, doc.scrollTop);
        this.curOp.forceScroll = true;
        signalLater(this, "swapDoc", this, old);
        return old
      }),

      phrase: function(phraseText) {
        var phrases = this.options.phrases;
        return phrases && Object.prototype.hasOwnProperty.call(phrases, phraseText) ? phrases[phraseText] : phraseText
      },

      getInputField: function(){return this.display.input.getField()},
      getWrapperElement: function(){return this.display.wrapper},
      getScrollerElement: function(){return this.display.scroller},
      getGutterElement: function(){return this.display.gutters}
    };
    eventMixin(CodeMirror);

    CodeMirror.registerHelper = function(type, name, value) {
      if (!helpers.hasOwnProperty(type)) { helpers[type] = CodeMirror[type] = {_global: []}; }
      helpers[type][name] = value;
    };
    CodeMirror.registerGlobalHelper = function(type, name, predicate, value) {
      CodeMirror.registerHelper(type, name, value);
      helpers[type]._global.push({pred: predicate, val: value});
    };
  }

  // Used for horizontal relative motion. Dir is -1 or 1 (left or
  // right), unit can be "codepoint", "char", "column" (like char, but
  // doesn't cross line boundaries), "word" (across next word), or
  // "group" (to the start of next group of word or
  // non-word-non-whitespace chars). The visually param controls
  // whether, in right-to-left text, direction 1 means to move towards
  // the next index in the string, or towards the character to the right
  // of the current position. The resulting position will have a
  // hitSide=true property if it reached the end of the document.
  function findPosH(doc, pos, dir, unit, visually) {
    var oldPos = pos;
    var origDir = dir;
    var lineObj = getLine(doc, pos.line);
    var lineDir = visually && doc.direction == "rtl" ? -dir : dir;
    function findNextLine() {
      var l = pos.line + lineDir;
      if (l < doc.first || l >= doc.first + doc.size) { return false }
      pos = new Pos(l, pos.ch, pos.sticky);
      return lineObj = getLine(doc, l)
    }
    function moveOnce(boundToLine) {
      var next;
      if (unit == "codepoint") {
        var ch = lineObj.text.charCodeAt(pos.ch + (dir > 0 ? 0 : -1));
        if (isNaN(ch)) {
          next = null;
        } else {
          var astral = dir > 0 ? ch >= 0xD800 && ch < 0xDC00 : ch >= 0xDC00 && ch < 0xDFFF;
          next = new Pos(pos.line, Math.max(0, Math.min(lineObj.text.length, pos.ch + dir * (astral ? 2 : 1))), -dir);
        }
      } else if (visually) {
        next = moveVisually(doc.cm, lineObj, pos, dir);
      } else {
        next = moveLogically(lineObj, pos, dir);
      }
      if (next == null) {
        if (!boundToLine && findNextLine())
          { pos = endOfLine(visually, doc.cm, lineObj, pos.line, lineDir); }
        else
          { return false }
      } else {
        pos = next;
      }
      return true
    }

    if (unit == "char" || unit == "codepoint") {
      moveOnce();
    } else if (unit == "column") {
      moveOnce(true);
    } else if (unit == "word" || unit == "group") {
      var sawType = null, group = unit == "group";
      var helper = doc.cm && doc.cm.getHelper(pos, "wordChars");
      for (var first = true;; first = false) {
        if (dir < 0 && !moveOnce(!first)) { break }
        var cur = lineObj.text.charAt(pos.ch) || "\n";
        var type = isWordChar(cur, helper) ? "w"
          : group && cur == "\n" ? "n"
          : !group || /\s/.test(cur) ? null
          : "p";
        if (group && !first && !type) { type = "s"; }
        if (sawType && sawType != type) {
          if (dir < 0) {dir = 1; moveOnce(); pos.sticky = "after";}
          break
        }

        if (type) { sawType = type; }
        if (dir > 0 && !moveOnce(!first)) { break }
      }
    }
    var result = skipAtomic(doc, pos, oldPos, origDir, true);
    if (equalCursorPos(oldPos, result)) { result.hitSide = true; }
    return result
  }

  // For relative vertical movement. Dir may be -1 or 1. Unit can be
  // "page" or "line". The resulting position will have a hitSide=true
  // property if it reached the end of the document.
  function findPosV(cm, pos, dir, unit) {
    var doc = cm.doc, x = pos.left, y;
    if (unit == "page") {
      var pageSize = Math.min(cm.display.wrapper.clientHeight, window.innerHeight || document.documentElement.clientHeight);
      var moveAmount = Math.max(pageSize - .5 * textHeight(cm.display), 3);
      y = (dir > 0 ? pos.bottom : pos.top) + dir * moveAmount;

    } else if (unit == "line") {
      y = dir > 0 ? pos.bottom + 3 : pos.top - 3;
    }
    var target;
    for (;;) {
      target = coordsChar(cm, x, y);
      if (!target.outside) { break }
      if (dir < 0 ? y <= 0 : y >= doc.height) { target.hitSide = true; break }
      y += dir * 5;
    }
    return target
  }

  // CONTENTEDITABLE INPUT STYLE

  var ContentEditableInput = function(cm) {
    this.cm = cm;
    this.lastAnchorNode = this.lastAnchorOffset = this.lastFocusNode = this.lastFocusOffset = null;
    this.polling = new Delayed();
    this.composing = null;
    this.gracePeriod = false;
    this.readDOMTimeout = null;
  };

  ContentEditableInput.prototype.init = function (display) {
      var this$1 = this;

    var input = this, cm = input.cm;
    var div = input.div = display.lineDiv;
    div.contentEditable = true;
    disableBrowserMagic(div, cm.options.spellcheck, cm.options.autocorrect, cm.options.autocapitalize);

    function belongsToInput(e) {
      for (var t = e.target; t; t = t.parentNode) {
        if (t == div) { return true }
        if (/\bCodeMirror-(?:line)?widget\b/.test(t.className)) { break }
      }
      return false
    }

    on(div, "paste", function (e) {
      if (!belongsToInput(e) || signalDOMEvent(cm, e) || handlePaste(e, cm)) { return }
      // IE doesn't fire input events, so we schedule a read for the pasted content in this way
      if (ie_version <= 11) { setTimeout(operation(cm, function () { return this$1.updateFromDOM(); }), 20); }
    });

    on(div, "compositionstart", function (e) {
      this$1.composing = {data: e.data, done: false};
    });
    on(div, "compositionupdate", function (e) {
      if (!this$1.composing) { this$1.composing = {data: e.data, done: false}; }
    });
    on(div, "compositionend", function (e) {
      if (this$1.composing) {
        if (e.data != this$1.composing.data) { this$1.readFromDOMSoon(); }
        this$1.composing.done = true;
      }
    });

    on(div, "touchstart", function () { return input.forceCompositionEnd(); });

    on(div, "input", function () {
      if (!this$1.composing) { this$1.readFromDOMSoon(); }
    });

    function onCopyCut(e) {
      if (!belongsToInput(e) || signalDOMEvent(cm, e)) { return }
      if (cm.somethingSelected()) {
        setLastCopied({lineWise: false, text: cm.getSelections()});
        if (e.type == "cut") { cm.replaceSelection("", null, "cut"); }
      } else if (!cm.options.lineWiseCopyCut) {
        return
      } else {
        var ranges = copyableRanges(cm);
        setLastCopied({lineWise: true, text: ranges.text});
        if (e.type == "cut") {
          cm.operation(function () {
            cm.setSelections(ranges.ranges, 0, sel_dontScroll);
            cm.replaceSelection("", null, "cut");
          });
        }
      }
      if (e.clipboardData) {
        e.clipboardData.clearData();
        var content = lastCopied.text.join("\n");
        // iOS exposes the clipboard API, but seems to discard content inserted into it
        e.clipboardData.setData("Text", content);
        if (e.clipboardData.getData("Text") == content) {
          e.preventDefault();
          return
        }
      }
      // Old-fashioned briefly-focus-a-textarea hack
      var kludge = hiddenTextarea(), te = kludge.firstChild;
      cm.display.lineSpace.insertBefore(kludge, cm.display.lineSpace.firstChild);
      te.value = lastCopied.text.join("\n");
      var hadFocus = activeElt();
      selectInput(te);
      setTimeout(function () {
        cm.display.lineSpace.removeChild(kludge);
        hadFocus.focus();
        if (hadFocus == div) { input.showPrimarySelection(); }
      }, 50);
    }
    on(div, "copy", onCopyCut);
    on(div, "cut", onCopyCut);
  };

  ContentEditableInput.prototype.screenReaderLabelChanged = function (label) {
    // Label for screenreaders, accessibility
    if(label) {
      this.div.setAttribute('aria-label', label);
    } else {
      this.div.removeAttribute('aria-label');
    }
  };

  ContentEditableInput.prototype.prepareSelection = function () {
    var result = prepareSelection(this.cm, false);
    result.focus = activeElt() == this.div;
    return result
  };

  ContentEditableInput.prototype.showSelection = function (info, takeFocus) {
    if (!info || !this.cm.display.view.length) { return }
    if (info.focus || takeFocus) { this.showPrimarySelection(); }
    this.showMultipleSelections(info);
  };

  ContentEditableInput.prototype.getSelection = function () {
    return this.cm.display.wrapper.ownerDocument.getSelection()
  };

  ContentEditableInput.prototype.showPrimarySelection = function () {
    var sel = this.getSelection(), cm = this.cm, prim = cm.doc.sel.primary();
    var from = prim.from(), to = prim.to();

    if (cm.display.viewTo == cm.display.viewFrom || from.line >= cm.display.viewTo || to.line < cm.display.viewFrom) {
      sel.removeAllRanges();
      return
    }

    var curAnchor = domToPos(cm, sel.anchorNode, sel.anchorOffset);
    var curFocus = domToPos(cm, sel.focusNode, sel.focusOffset);
    if (curAnchor && !curAnchor.bad && curFocus && !curFocus.bad &&
        cmp(minPos(curAnchor, curFocus), from) == 0 &&
        cmp(maxPos(curAnchor, curFocus), to) == 0)
      { return }

    var view = cm.display.view;
    var start = (from.line >= cm.display.viewFrom && posToDOM(cm, from)) ||
        {node: view[0].measure.map[2], offset: 0};
    var end = to.line < cm.display.viewTo && posToDOM(cm, to);
    if (!end) {
      var measure = view[view.length - 1].measure;
      var map = measure.maps ? measure.maps[measure.maps.length - 1] : measure.map;
      end = {node: map[map.length - 1], offset: map[map.length - 2] - map[map.length - 3]};
    }

    if (!start || !end) {
      sel.removeAllRanges();
      return
    }

    var old = sel.rangeCount && sel.getRangeAt(0), rng;
    try { rng = range(start.node, start.offset, end.offset, end.node); }
    catch(e) {} // Our model of the DOM might be outdated, in which case the range we try to set can be impossible
    if (rng) {
      if (!gecko && cm.state.focused) {
        sel.collapse(start.node, start.offset);
        if (!rng.collapsed) {
          sel.removeAllRanges();
          sel.addRange(rng);
        }
      } else {
        sel.removeAllRanges();
        sel.addRange(rng);
      }
      if (old && sel.anchorNode == null) { sel.addRange(old); }
      else if (gecko) { this.startGracePeriod(); }
    }
    this.rememberSelection();
  };

  ContentEditableInput.prototype.startGracePeriod = function () {
      var this$1 = this;

    clearTimeout(this.gracePeriod);
    this.gracePeriod = setTimeout(function () {
      this$1.gracePeriod = false;
      if (this$1.selectionChanged())
        { this$1.cm.operation(function () { return this$1.cm.curOp.selectionChanged = true; }); }
    }, 20);
  };

  ContentEditableInput.prototype.showMultipleSelections = function (info) {
    removeChildrenAndAdd(this.cm.display.cursorDiv, info.cursors);
    removeChildrenAndAdd(this.cm.display.selectionDiv, info.selection);
  };

  ContentEditableInput.prototype.rememberSelection = function () {
    var sel = this.getSelection();
    this.lastAnchorNode = sel.anchorNode; this.lastAnchorOffset = sel.anchorOffset;
    this.lastFocusNode = sel.focusNode; this.lastFocusOffset = sel.focusOffset;
  };

  ContentEditableInput.prototype.selectionInEditor = function () {
    var sel = this.getSelection();
    if (!sel.rangeCount) { return false }
    var node = sel.getRangeAt(0).commonAncestorContainer;
    return contains(this.div, node)
  };

  ContentEditableInput.prototype.focus = function () {
    if (this.cm.options.readOnly != "nocursor") {
      if (!this.selectionInEditor() || activeElt() != this.div)
        { this.showSelection(this.prepareSelection(), true); }
      this.div.focus();
    }
  };
  ContentEditableInput.prototype.blur = function () { this.div.blur(); };
  ContentEditableInput.prototype.getField = function () { return this.div };

  ContentEditableInput.prototype.supportsTouch = function () { return true };

  ContentEditableInput.prototype.receivedFocus = function () {
      var this$1 = this;

    var input = this;
    if (this.selectionInEditor())
      { setTimeout(function () { return this$1.pollSelection(); }, 20); }
    else
      { runInOp(this.cm, function () { return input.cm.curOp.selectionChanged = true; }); }

    function poll() {
      if (input.cm.state.focused) {
        input.pollSelection();
        input.polling.set(input.cm.options.pollInterval, poll);
      }
    }
    this.polling.set(this.cm.options.pollInterval, poll);
  };

  ContentEditableInput.prototype.selectionChanged = function () {
    var sel = this.getSelection();
    return sel.anchorNode != this.lastAnchorNode || sel.anchorOffset != this.lastAnchorOffset ||
      sel.focusNode != this.lastFocusNode || sel.focusOffset != this.lastFocusOffset
  };

  ContentEditableInput.prototype.pollSelection = function () {
    if (this.readDOMTimeout != null || this.gracePeriod || !this.selectionChanged()) { return }
    var sel = this.getSelection(), cm = this.cm;
    // On Android Chrome (version 56, at least), backspacing into an
    // uneditable block element will put the cursor in that element,
    // and then, because it's not editable, hide the virtual keyboard.
    // Because Android doesn't allow us to actually detect backspace
    // presses in a sane way, this code checks for when that happens
    // and simulates a backspace press in this case.
    if (android && chrome && this.cm.display.gutterSpecs.length && isInGutter(sel.anchorNode)) {
      this.cm.triggerOnKeyDown({type: "keydown", keyCode: 8, preventDefault: Math.abs});
      this.blur();
      this.focus();
      return
    }
    if (this.composing) { return }
    this.rememberSelection();
    var anchor = domToPos(cm, sel.anchorNode, sel.anchorOffset);
    var head = domToPos(cm, sel.focusNode, sel.focusOffset);
    if (anchor && head) { runInOp(cm, function () {
      setSelection(cm.doc, simpleSelection(anchor, head), sel_dontScroll);
      if (anchor.bad || head.bad) { cm.curOp.selectionChanged = true; }
    }); }
  };

  ContentEditableInput.prototype.pollContent = function () {
    if (this.readDOMTimeout != null) {
      clearTimeout(this.readDOMTimeout);
      this.readDOMTimeout = null;
    }

    var cm = this.cm, display = cm.display, sel = cm.doc.sel.primary();
    var from = sel.from(), to = sel.to();
    if (from.ch == 0 && from.line > cm.firstLine())
      { from = Pos(from.line - 1, getLine(cm.doc, from.line - 1).length); }
    if (to.ch == getLine(cm.doc, to.line).text.length && to.line < cm.lastLine())
      { to = Pos(to.line + 1, 0); }
    if (from.line < display.viewFrom || to.line > display.viewTo - 1) { return false }

    var fromIndex, fromLine, fromNode;
    if (from.line == display.viewFrom || (fromIndex = findViewIndex(cm, from.line)) == 0) {
      fromLine = lineNo(display.view[0].line);
      fromNode = display.view[0].node;
    } else {
      fromLine = lineNo(display.view[fromIndex].line);
      fromNode = display.view[fromIndex - 1].node.nextSibling;
    }
    var toIndex = findViewIndex(cm, to.line);
    var toLine, toNode;
    if (toIndex == display.view.length - 1) {
      toLine = display.viewTo - 1;
      toNode = display.lineDiv.lastChild;
    } else {
      toLine = lineNo(display.view[toIndex + 1].line) - 1;
      toNode = display.view[toIndex + 1].node.previousSibling;
    }

    if (!fromNode) { return false }
    var newText = cm.doc.splitLines(domTextBetween(cm, fromNode, toNode, fromLine, toLine));
    var oldText = getBetween(cm.doc, Pos(fromLine, 0), Pos(toLine, getLine(cm.doc, toLine).text.length));
    while (newText.length > 1 && oldText.length > 1) {
      if (lst(newText) == lst(oldText)) { newText.pop(); oldText.pop(); toLine--; }
      else if (newText[0] == oldText[0]) { newText.shift(); oldText.shift(); fromLine++; }
      else { break }
    }

    var cutFront = 0, cutEnd = 0;
    var newTop = newText[0], oldTop = oldText[0], maxCutFront = Math.min(newTop.length, oldTop.length);
    while (cutFront < maxCutFront && newTop.charCodeAt(cutFront) == oldTop.charCodeAt(cutFront))
      { ++cutFront; }
    var newBot = lst(newText), oldBot = lst(oldText);
    var maxCutEnd = Math.min(newBot.length - (newText.length == 1 ? cutFront : 0),
                             oldBot.length - (oldText.length == 1 ? cutFront : 0));
    while (cutEnd < maxCutEnd &&
           newBot.charCodeAt(newBot.length - cutEnd - 1) == oldBot.charCodeAt(oldBot.length - cutEnd - 1))
      { ++cutEnd; }
    // Try to move start of change to start of selection if ambiguous
    if (newText.length == 1 && oldText.length == 1 && fromLine == from.line) {
      while (cutFront && cutFront > from.ch &&
             newBot.charCodeAt(newBot.length - cutEnd - 1) == oldBot.charCodeAt(oldBot.length - cutEnd - 1)) {
        cutFront--;
        cutEnd++;
      }
    }

    newText[newText.length - 1] = newBot.slice(0, newBot.length - cutEnd).replace(/^\u200b+/, "");
    newText[0] = newText[0].slice(cutFront).replace(/\u200b+$/, "");

    var chFrom = Pos(fromLine, cutFront);
    var chTo = Pos(toLine, oldText.length ? lst(oldText).length - cutEnd : 0);
    if (newText.length > 1 || newText[0] || cmp(chFrom, chTo)) {
      replaceRange(cm.doc, newText, chFrom, chTo, "+input");
      return true
    }
  };

  ContentEditableInput.prototype.ensurePolled = function () {
    this.forceCompositionEnd();
  };
  ContentEditableInput.prototype.reset = function () {
    this.forceCompositionEnd();
  };
  ContentEditableInput.prototype.forceCompositionEnd = function () {
    if (!this.composing) { return }
    clearTimeout(this.readDOMTimeout);
    this.composing = null;
    this.updateFromDOM();
    this.div.blur();
    this.div.focus();
  };
  ContentEditableInput.prototype.readFromDOMSoon = function () {
      var this$1 = this;

    if (this.readDOMTimeout != null) { return }
    this.readDOMTimeout = setTimeout(function () {
      this$1.readDOMTimeout = null;
      if (this$1.composing) {
        if (this$1.composing.done) { this$1.composing = null; }
        else { return }
      }
      this$1.updateFromDOM();
    }, 80);
  };

  ContentEditableInput.prototype.updateFromDOM = function () {
      var this$1 = this;

    if (this.cm.isReadOnly() || !this.pollContent())
      { runInOp(this.cm, function () { return regChange(this$1.cm); }); }
  };

  ContentEditableInput.prototype.setUneditable = function (node) {
    node.contentEditable = "false";
  };

  ContentEditableInput.prototype.onKeyPress = function (e) {
    if (e.charCode == 0 || this.composing) { return }
    e.preventDefault();
    if (!this.cm.isReadOnly())
      { operation(this.cm, applyTextInput)(this.cm, String.fromCharCode(e.charCode == null ? e.keyCode : e.charCode), 0); }
  };

  ContentEditableInput.prototype.readOnlyChanged = function (val) {
    this.div.contentEditable = String(val != "nocursor");
  };

  ContentEditableInput.prototype.onContextMenu = function () {};
  ContentEditableInput.prototype.resetPosition = function () {};

  ContentEditableInput.prototype.needsContentAttribute = true;

  function posToDOM(cm, pos) {
    var view = findViewForLine(cm, pos.line);
    if (!view || view.hidden) { return null }
    var line = getLine(cm.doc, pos.line);
    var info = mapFromLineView(view, line, pos.line);

    var order = getOrder(line, cm.doc.direction), side = "left";
    if (order) {
      var partPos = getBidiPartAt(order, pos.ch);
      side = partPos % 2 ? "right" : "left";
    }
    var result = nodeAndOffsetInLineMap(info.map, pos.ch, side);
    result.offset = result.collapse == "right" ? result.end : result.start;
    return result
  }

  function isInGutter(node) {
    for (var scan = node; scan; scan = scan.parentNode)
      { if (/CodeMirror-gutter-wrapper/.test(scan.className)) { return true } }
    return false
  }

  function badPos(pos, bad) { if (bad) { pos.bad = true; } return pos }

  function domTextBetween(cm, from, to, fromLine, toLine) {
    var text = "", closing = false, lineSep = cm.doc.lineSeparator(), extraLinebreak = false;
    function recognizeMarker(id) { return function (marker) { return marker.id == id; } }
    function close() {
      if (closing) {
        text += lineSep;
        if (extraLinebreak) { text += lineSep; }
        closing = extraLinebreak = false;
      }
    }
    function addText(str) {
      if (str) {
        close();
        text += str;
      }
    }
    function walk(node) {
      if (node.nodeType == 1) {
        var cmText = node.getAttribute("cm-text");
        if (cmText) {
          addText(cmText);
          return
        }
        var markerID = node.getAttribute("cm-marker"), range;
        if (markerID) {
          var found = cm.findMarks(Pos(fromLine, 0), Pos(toLine + 1, 0), recognizeMarker(+markerID));
          if (found.length && (range = found[0].find(0)))
            { addText(getBetween(cm.doc, range.from, range.to).join(lineSep)); }
          return
        }
        if (node.getAttribute("contenteditable") == "false") { return }
        var isBlock = /^(pre|div|p|li|table|br)$/i.test(node.nodeName);
        if (!/^br$/i.test(node.nodeName) && node.textContent.length == 0) { return }

        if (isBlock) { close(); }
        for (var i = 0; i < node.childNodes.length; i++)
          { walk(node.childNodes[i]); }

        if (/^(pre|p)$/i.test(node.nodeName)) { extraLinebreak = true; }
        if (isBlock) { closing = true; }
      } else if (node.nodeType == 3) {
        addText(node.nodeValue.replace(/\u200b/g, "").replace(/\u00a0/g, " "));
      }
    }
    for (;;) {
      walk(from);
      if (from == to) { break }
      from = from.nextSibling;
      extraLinebreak = false;
    }
    return text
  }

  function domToPos(cm, node, offset) {
    var lineNode;
    if (node == cm.display.lineDiv) {
      lineNode = cm.display.lineDiv.childNodes[offset];
      if (!lineNode) { return badPos(cm.clipPos(Pos(cm.display.viewTo - 1)), true) }
      node = null; offset = 0;
    } else {
      for (lineNode = node;; lineNode = lineNode.parentNode) {
        if (!lineNode || lineNode == cm.display.lineDiv) { return null }
        if (lineNode.parentNode && lineNode.parentNode == cm.display.lineDiv) { break }
      }
    }
    for (var i = 0; i < cm.display.view.length; i++) {
      var lineView = cm.display.view[i];
      if (lineView.node == lineNode)
        { return locateNodeInLineView(lineView, node, offset) }
    }
  }

  function locateNodeInLineView(lineView, node, offset) {
    var wrapper = lineView.text.firstChild, bad = false;
    if (!node || !contains(wrapper, node)) { return badPos(Pos(lineNo(lineView.line), 0), true) }
    if (node == wrapper) {
      bad = true;
      node = wrapper.childNodes[offset];
      offset = 0;
      if (!node) {
        var line = lineView.rest ? lst(lineView.rest) : lineView.line;
        return badPos(Pos(lineNo(line), line.text.length), bad)
      }
    }

    var textNode = node.nodeType == 3 ? node : null, topNode = node;
    if (!textNode && node.childNodes.length == 1 && node.firstChild.nodeType == 3) {
      textNode = node.firstChild;
      if (offset) { offset = textNode.nodeValue.length; }
    }
    while (topNode.parentNode != wrapper) { topNode = topNode.parentNode; }
    var measure = lineView.measure, maps = measure.maps;

    function find(textNode, topNode, offset) {
      for (var i = -1; i < (maps ? maps.length : 0); i++) {
        var map = i < 0 ? measure.map : maps[i];
        for (var j = 0; j < map.length; j += 3) {
          var curNode = map[j + 2];
          if (curNode == textNode || curNode == topNode) {
            var line = lineNo(i < 0 ? lineView.line : lineView.rest[i]);
            var ch = map[j] + offset;
            if (offset < 0 || curNode != textNode) { ch = map[j + (offset ? 1 : 0)]; }
            return Pos(line, ch)
          }
        }
      }
    }
    var found = find(textNode, topNode, offset);
    if (found) { return badPos(found, bad) }

    // FIXME this is all really shaky. might handle the few cases it needs to handle, but likely to cause problems
    for (var after = topNode.nextSibling, dist = textNode ? textNode.nodeValue.length - offset : 0; after; after = after.nextSibling) {
      found = find(after, after.firstChild, 0);
      if (found)
        { return badPos(Pos(found.line, found.ch - dist), bad) }
      else
        { dist += after.textContent.length; }
    }
    for (var before = topNode.previousSibling, dist$1 = offset; before; before = before.previousSibling) {
      found = find(before, before.firstChild, -1);
      if (found)
        { return badPos(Pos(found.line, found.ch + dist$1), bad) }
      else
        { dist$1 += before.textContent.length; }
    }
  }

  // TEXTAREA INPUT STYLE

  var TextareaInput = function(cm) {
    this.cm = cm;
    // See input.poll and input.reset
    this.prevInput = "";

    // Flag that indicates whether we expect input to appear real soon
    // now (after some event like 'keypress' or 'input') and are
    // polling intensively.
    this.pollingFast = false;
    // Self-resetting timeout for the poller
    this.polling = new Delayed();
    // Used to work around IE issue with selection being forgotten when focus moves away from textarea
    this.hasSelection = false;
    this.composing = null;
  };

  TextareaInput.prototype.init = function (display) {
      var this$1 = this;

    var input = this, cm = this.cm;
    this.createField(display);
    var te = this.textarea;

    display.wrapper.insertBefore(this.wrapper, display.wrapper.firstChild);

    // Needed to hide big blue blinking cursor on Mobile Safari (doesn't seem to work in iOS 8 anymore)
    if (ios) { te.style.width = "0px"; }

    on(te, "input", function () {
      if (ie && ie_version >= 9 && this$1.hasSelection) { this$1.hasSelection = null; }
      input.poll();
    });

    on(te, "paste", function (e) {
      if (signalDOMEvent(cm, e) || handlePaste(e, cm)) { return }

      cm.state.pasteIncoming = +new Date;
      input.fastPoll();
    });

    function prepareCopyCut(e) {
      if (signalDOMEvent(cm, e)) { return }
      if (cm.somethingSelected()) {
        setLastCopied({lineWise: false, text: cm.getSelections()});
      } else if (!cm.options.lineWiseCopyCut) {
        return
      } else {
        var ranges = copyableRanges(cm);
        setLastCopied({lineWise: true, text: ranges.text});
        if (e.type == "cut") {
          cm.setSelections(ranges.ranges, null, sel_dontScroll);
        } else {
          input.prevInput = "";
          te.value = ranges.text.join("\n");
          selectInput(te);
        }
      }
      if (e.type == "cut") { cm.state.cutIncoming = +new Date; }
    }
    on(te, "cut", prepareCopyCut);
    on(te, "copy", prepareCopyCut);

    on(display.scroller, "paste", function (e) {
      if (eventInWidget(display, e) || signalDOMEvent(cm, e)) { return }
      if (!te.dispatchEvent) {
        cm.state.pasteIncoming = +new Date;
        input.focus();
        return
      }

      // Pass the `paste` event to the textarea so it's handled by its event listener.
      var event = new Event("paste");
      event.clipboardData = e.clipboardData;
      te.dispatchEvent(event);
    });

    // Prevent normal selection in the editor (we handle our own)
    on(display.lineSpace, "selectstart", function (e) {
      if (!eventInWidget(display, e)) { e_preventDefault(e); }
    });

    on(te, "compositionstart", function () {
      var start = cm.getCursor("from");
      if (input.composing) { input.composing.range.clear(); }
      input.composing = {
        start: start,
        range: cm.markText(start, cm.getCursor("to"), {className: "CodeMirror-composing"})
      };
    });
    on(te, "compositionend", function () {
      if (input.composing) {
        input.poll();
        input.composing.range.clear();
        input.composing = null;
      }
    });
  };

  TextareaInput.prototype.createField = function (_display) {
    // Wraps and hides input textarea
    this.wrapper = hiddenTextarea();
    // The semihidden textarea that is focused when the editor is
    // focused, and receives input.
    this.textarea = this.wrapper.firstChild;
  };

  TextareaInput.prototype.screenReaderLabelChanged = function (label) {
    // Label for screenreaders, accessibility
    if(label) {
      this.textarea.setAttribute('aria-label', label);
    } else {
      this.textarea.removeAttribute('aria-label');
    }
  };

  TextareaInput.prototype.prepareSelection = function () {
    // Redraw the selection and/or cursor
    var cm = this.cm, display = cm.display, doc = cm.doc;
    var result = prepareSelection(cm);

    // Move the hidden textarea near the cursor to prevent scrolling artifacts
    if (cm.options.moveInputWithCursor) {
      var headPos = cursorCoords(cm, doc.sel.primary().head, "div");
      var wrapOff = display.wrapper.getBoundingClientRect(), lineOff = display.lineDiv.getBoundingClientRect();
      result.teTop = Math.max(0, Math.min(display.wrapper.clientHeight - 10,
                                          headPos.top + lineOff.top - wrapOff.top));
      result.teLeft = Math.max(0, Math.min(display.wrapper.clientWidth - 10,
                                           headPos.left + lineOff.left - wrapOff.left));
    }

    return result
  };

  TextareaInput.prototype.showSelection = function (drawn) {
    var cm = this.cm, display = cm.display;
    removeChildrenAndAdd(display.cursorDiv, drawn.cursors);
    removeChildrenAndAdd(display.selectionDiv, drawn.selection);
    if (drawn.teTop != null) {
      this.wrapper.style.top = drawn.teTop + "px";
      this.wrapper.style.left = drawn.teLeft + "px";
    }
  };

  // Reset the input to correspond to the selection (or to be empty,
  // when not typing and nothing is selected)
  TextareaInput.prototype.reset = function (typing) {
    if (this.contextMenuPending || this.composing) { return }
    var cm = this.cm;
    if (cm.somethingSelected()) {
      this.prevInput = "";
      var content = cm.getSelection();
      this.textarea.value = content;
      if (cm.state.focused) { selectInput(this.textarea); }
      if (ie && ie_version >= 9) { this.hasSelection = content; }
    } else if (!typing) {
      this.prevInput = this.textarea.value = "";
      if (ie && ie_version >= 9) { this.hasSelection = null; }
    }
  };

  TextareaInput.prototype.getField = function () { return this.textarea };

  TextareaInput.prototype.supportsTouch = function () { return false };

  TextareaInput.prototype.focus = function () {
    if (this.cm.options.readOnly != "nocursor" && (!mobile || activeElt() != this.textarea)) {
      try { this.textarea.focus(); }
      catch (e) {} // IE8 will throw if the textarea is display: none or not in DOM
    }
  };

  TextareaInput.prototype.blur = function () { this.textarea.blur(); };

  TextareaInput.prototype.resetPosition = function () {
    this.wrapper.style.top = this.wrapper.style.left = 0;
  };

  TextareaInput.prototype.receivedFocus = function () { this.slowPoll(); };

  // Poll for input changes, using the normal rate of polling. This
  // runs as long as the editor is focused.
  TextareaInput.prototype.slowPoll = function () {
      var this$1 = this;

    if (this.pollingFast) { return }
    this.polling.set(this.cm.options.pollInterval, function () {
      this$1.poll();
      if (this$1.cm.state.focused) { this$1.slowPoll(); }
    });
  };

  // When an event has just come in that is likely to add or change
  // something in the input textarea, we poll faster, to ensure that
  // the change appears on the screen quickly.
  TextareaInput.prototype.fastPoll = function () {
    var missed = false, input = this;
    input.pollingFast = true;
    function p() {
      var changed = input.poll();
      if (!changed && !missed) {missed = true; input.polling.set(60, p);}
      else {input.pollingFast = false; input.slowPoll();}
    }
    input.polling.set(20, p);
  };

  // Read input from the textarea, and update the document to match.
  // When something is selected, it is present in the textarea, and
  // selected (unless it is huge, in which case a placeholder is
  // used). When nothing is selected, the cursor sits after previously
  // seen text (can be empty), which is stored in prevInput (we must
  // not reset the textarea when typing, because that breaks IME).
  TextareaInput.prototype.poll = function () {
      var this$1 = this;

    var cm = this.cm, input = this.textarea, prevInput = this.prevInput;
    // Since this is called a *lot*, try to bail out as cheaply as
    // possible when it is clear that nothing happened. hasSelection
    // will be the case when there is a lot of text in the textarea,
    // in which case reading its value would be expensive.
    if (this.contextMenuPending || !cm.state.focused ||
        (hasSelection(input) && !prevInput && !this.composing) ||
        cm.isReadOnly() || cm.options.disableInput || cm.state.keySeq)
      { return false }

    var text = input.value;
    // If nothing changed, bail.
    if (text == prevInput && !cm.somethingSelected()) { return false }
    // Work around nonsensical selection resetting in IE9/10, and
    // inexplicable appearance of private area unicode characters on
    // some key combos in Mac (#2689).
    if (ie && ie_version >= 9 && this.hasSelection === text ||
        mac && /[\uf700-\uf7ff]/.test(text)) {
      cm.display.input.reset();
      return false
    }

    if (cm.doc.sel == cm.display.selForContextMenu) {
      var first = text.charCodeAt(0);
      if (first == 0x200b && !prevInput) { prevInput = "\u200b"; }
      if (first == 0x21da) { this.reset(); return this.cm.execCommand("undo") }
    }
    // Find the part of the input that is actually new
    var same = 0, l = Math.min(prevInput.length, text.length);
    while (same < l && prevInput.charCodeAt(same) == text.charCodeAt(same)) { ++same; }

    runInOp(cm, function () {
      applyTextInput(cm, text.slice(same), prevInput.length - same,
                     null, this$1.composing ? "*compose" : null);

      // Don't leave long text in the textarea, since it makes further polling slow
      if (text.length > 1000 || text.indexOf("\n") > -1) { input.value = this$1.prevInput = ""; }
      else { this$1.prevInput = text; }

      if (this$1.composing) {
        this$1.composing.range.clear();
        this$1.composing.range = cm.markText(this$1.composing.start, cm.getCursor("to"),
                                           {className: "CodeMirror-composing"});
      }
    });
    return true
  };

  TextareaInput.prototype.ensurePolled = function () {
    if (this.pollingFast && this.poll()) { this.pollingFast = false; }
  };

  TextareaInput.prototype.onKeyPress = function () {
    if (ie && ie_version >= 9) { this.hasSelection = null; }
    this.fastPoll();
  };

  TextareaInput.prototype.onContextMenu = function (e) {
    var input = this, cm = input.cm, display = cm.display, te = input.textarea;
    if (input.contextMenuPending) { input.contextMenuPending(); }
    var pos = posFromMouse(cm, e), scrollPos = display.scroller.scrollTop;
    if (!pos || presto) { return } // Opera is difficult.

    // Reset the current text selection only if the click is done outside of the selection
    // and 'resetSelectionOnContextMenu' option is true.
    var reset = cm.options.resetSelectionOnContextMenu;
    if (reset && cm.doc.sel.contains(pos) == -1)
      { operation(cm, setSelection)(cm.doc, simpleSelection(pos), sel_dontScroll); }

    var oldCSS = te.style.cssText, oldWrapperCSS = input.wrapper.style.cssText;
    var wrapperBox = input.wrapper.offsetParent.getBoundingClientRect();
    input.wrapper.style.cssText = "position: static";
    te.style.cssText = "position: absolute; width: 30px; height: 30px;\n      top: " + (e.clientY - wrapperBox.top - 5) + "px; left: " + (e.clientX - wrapperBox.left - 5) + "px;\n      z-index: 1000; background: " + (ie ? "rgba(255, 255, 255, .05)" : "transparent") + ";\n      outline: none; border-width: 0; outline: none; overflow: hidden; opacity: .05; filter: alpha(opacity=5);";
    var oldScrollY;
    if (webkit) { oldScrollY = window.scrollY; } // Work around Chrome issue (#2712)
    display.input.focus();
    if (webkit) { window.scrollTo(null, oldScrollY); }
    display.input.reset();
    // Adds "Select all" to context menu in FF
    if (!cm.somethingSelected()) { te.value = input.prevInput = " "; }
    input.contextMenuPending = rehide;
    display.selForContextMenu = cm.doc.sel;
    clearTimeout(display.detectingSelectAll);

    // Select-all will be greyed out if there's nothing to select, so
    // this adds a zero-width space so that we can later check whether
    // it got selected.
    function prepareSelectAllHack() {
      if (te.selectionStart != null) {
        var selected = cm.somethingSelected();
        var extval = "\u200b" + (selected ? te.value : "");
        te.value = "\u21da"; // Used to catch context-menu undo
        te.value = extval;
        input.prevInput = selected ? "" : "\u200b";
        te.selectionStart = 1; te.selectionEnd = extval.length;
        // Re-set this, in case some other handler touched the
        // selection in the meantime.
        display.selForContextMenu = cm.doc.sel;
      }
    }
    function rehide() {
      if (input.contextMenuPending != rehide) { return }
      input.contextMenuPending = false;
      input.wrapper.style.cssText = oldWrapperCSS;
      te.style.cssText = oldCSS;
      if (ie && ie_version < 9) { display.scrollbars.setScrollTop(display.scroller.scrollTop = scrollPos); }

      // Try to detect the user choosing select-all
      if (te.selectionStart != null) {
        if (!ie || (ie && ie_version < 9)) { prepareSelectAllHack(); }
        var i = 0, poll = function () {
          if (display.selForContextMenu == cm.doc.sel && te.selectionStart == 0 &&
              te.selectionEnd > 0 && input.prevInput == "\u200b") {
            operation(cm, selectAll)(cm);
          } else if (i++ < 10) {
            display.detectingSelectAll = setTimeout(poll, 500);
          } else {
            display.selForContextMenu = null;
            display.input.reset();
          }
        };
        display.detectingSelectAll = setTimeout(poll, 200);
      }
    }

    if (ie && ie_version >= 9) { prepareSelectAllHack(); }
    if (captureRightClick) {
      e_stop(e);
      var mouseup = function () {
        off(window, "mouseup", mouseup);
        setTimeout(rehide, 20);
      };
      on(window, "mouseup", mouseup);
    } else {
      setTimeout(rehide, 50);
    }
  };

  TextareaInput.prototype.readOnlyChanged = function (val) {
    if (!val) { this.reset(); }
    this.textarea.disabled = val == "nocursor";
    this.textarea.readOnly = !!val;
  };

  TextareaInput.prototype.setUneditable = function () {};

  TextareaInput.prototype.needsContentAttribute = false;

  function fromTextArea(textarea, options) {
    options = options ? copyObj(options) : {};
    options.value = textarea.value;
    if (!options.tabindex && textarea.tabIndex)
      { options.tabindex = textarea.tabIndex; }
    if (!options.placeholder && textarea.placeholder)
      { options.placeholder = textarea.placeholder; }
    // Set autofocus to true if this textarea is focused, or if it has
    // autofocus and no other element is focused.
    if (options.autofocus == null) {
      var hasFocus = activeElt();
      options.autofocus = hasFocus == textarea ||
        textarea.getAttribute("autofocus") != null && hasFocus == document.body;
    }

    function save() {textarea.value = cm.getValue();}

    var realSubmit;
    if (textarea.form) {
      on(textarea.form, "submit", save);
      // Deplorable hack to make the submit method do the right thing.
      if (!options.leaveSubmitMethodAlone) {
        var form = textarea.form;
        realSubmit = form.submit;
        try {
          var wrappedSubmit = form.submit = function () {
            save();
            form.submit = realSubmit;
            form.submit();
            form.submit = wrappedSubmit;
          };
        } catch(e) {}
      }
    }

    options.finishInit = function (cm) {
      cm.save = save;
      cm.getTextArea = function () { return textarea; };
      cm.toTextArea = function () {
        cm.toTextArea = isNaN; // Prevent this from being ran twice
        save();
        textarea.parentNode.removeChild(cm.getWrapperElement());
        textarea.style.display = "";
        if (textarea.form) {
          off(textarea.form, "submit", save);
          if (!options.leaveSubmitMethodAlone && typeof textarea.form.submit == "function")
            { textarea.form.submit = realSubmit; }
        }
      };
    };

    textarea.style.display = "none";
    var cm = CodeMirror(function (node) { return textarea.parentNode.insertBefore(node, textarea.nextSibling); },
      options);
    return cm
  }

  function addLegacyProps(CodeMirror) {
    CodeMirror.off = off;
    CodeMirror.on = on;
    CodeMirror.wheelEventPixels = wheelEventPixels;
    CodeMirror.Doc = Doc;
    CodeMirror.splitLines = splitLinesAuto;
    CodeMirror.countColumn = countColumn;
    CodeMirror.findColumn = findColumn;
    CodeMirror.isWordChar = isWordCharBasic;
    CodeMirror.Pass = Pass;
    CodeMirror.signal = signal;
    CodeMirror.Line = Line;
    CodeMirror.changeEnd = changeEnd;
    CodeMirror.scrollbarModel = scrollbarModel;
    CodeMirror.Pos = Pos;
    CodeMirror.cmpPos = cmp;
    CodeMirror.modes = modes;
    CodeMirror.mimeModes = mimeModes;
    CodeMirror.resolveMode = resolveMode;
    CodeMirror.getMode = getMode;
    CodeMirror.modeExtensions = modeExtensions;
    CodeMirror.extendMode = extendMode;
    CodeMirror.copyState = copyState;
    CodeMirror.startState = startState;
    CodeMirror.innerMode = innerMode;
    CodeMirror.commands = commands;
    CodeMirror.keyMap = keyMap;
    CodeMirror.keyName = keyName;
    CodeMirror.isModifierKey = isModifierKey;
    CodeMirror.lookupKey = lookupKey;
    CodeMirror.normalizeKeyMap = normalizeKeyMap;
    CodeMirror.StringStream = StringStream;
    CodeMirror.SharedTextMarker = SharedTextMarker;
    CodeMirror.TextMarker = TextMarker;
    CodeMirror.LineWidget = LineWidget;
    CodeMirror.e_preventDefault = e_preventDefault;
    CodeMirror.e_stopPropagation = e_stopPropagation;
    CodeMirror.e_stop = e_stop;
    CodeMirror.addClass = addClass;
    CodeMirror.contains = contains;
    CodeMirror.rmClass = rmClass;
    CodeMirror.keyNames = keyNames;
  }

  // EDITOR CONSTRUCTOR

  defineOptions(CodeMirror);

  addEditorMethods(CodeMirror);

  // Set up methods on CodeMirror's prototype to redirect to the editor's document.
  var dontDelegate = "iter insert remove copy getEditor constructor".split(" ");
  for (var prop in Doc.prototype) { if (Doc.prototype.hasOwnProperty(prop) && indexOf(dontDelegate, prop) < 0)
    { CodeMirror.prototype[prop] = (function(method) {
      return function() {return method.apply(this.doc, arguments)}
    })(Doc.prototype[prop]); } }

  eventMixin(Doc);
  CodeMirror.inputStyles = {"textarea": TextareaInput, "contenteditable": ContentEditableInput};

  // Extra arguments are stored as the mode's dependencies, which is
  // used by (legacy) mechanisms like loadmode.js to automatically
  // load a mode. (Preferred mechanism is the require/define calls.)
  CodeMirror.defineMode = function(name/*, mode, …*/) {
    if (!CodeMirror.defaults.mode && name != "null") { CodeMirror.defaults.mode = name; }
    defineMode.apply(this, arguments);
  };

  CodeMirror.defineMIME = defineMIME;

  // Minimal default mode.
  CodeMirror.defineMode("null", function () { return ({token: function (stream) { return stream.skipToEnd(); }}); });
  CodeMirror.defineMIME("text/plain", "null");

  // EXTENSIONS

  CodeMirror.defineExtension = function (name, func) {
    CodeMirror.prototype[name] = func;
  };
  CodeMirror.defineDocExtension = function (name, func) {
    Doc.prototype[name] = func;
  };

  CodeMirror.fromTextArea = fromTextArea;

  addLegacyProps(CodeMirror);

  CodeMirror.version = "5.65.3";

  return CodeMirror;

})));


/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/codemirror/mode/javascript/javascript.js":
/*!**********************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/codemirror/mode/javascript/javascript.js ***!
  \**********************************************************************************************/
/***/ ((__unused_webpack_module, __unused_webpack_exports, __webpack_require__) => {

// CodeMirror, copyright (c) by Marijn Haverbeke and others
// Distributed under an MIT license: https://codemirror.net/LICENSE

(function(mod) {
  if (true) // CommonJS
    mod(__webpack_require__(/*! ../../lib/codemirror */ "../../node_modules/@elyra/canvas/node_modules/codemirror/lib/codemirror.js"));
  else {}
})(function(CodeMirror) {
"use strict";

CodeMirror.defineMode("javascript", function(config, parserConfig) {
  var indentUnit = config.indentUnit;
  var statementIndent = parserConfig.statementIndent;
  var jsonldMode = parserConfig.jsonld;
  var jsonMode = parserConfig.json || jsonldMode;
  var trackScope = parserConfig.trackScope !== false
  var isTS = parserConfig.typescript;
  var wordRE = parserConfig.wordCharacters || /[\w$\xa1-\uffff]/;

  // Tokenizer

  var keywords = function(){
    function kw(type) {return {type: type, style: "keyword"};}
    var A = kw("keyword a"), B = kw("keyword b"), C = kw("keyword c"), D = kw("keyword d");
    var operator = kw("operator"), atom = {type: "atom", style: "atom"};

    return {
      "if": kw("if"), "while": A, "with": A, "else": B, "do": B, "try": B, "finally": B,
      "return": D, "break": D, "continue": D, "new": kw("new"), "delete": C, "void": C, "throw": C,
      "debugger": kw("debugger"), "var": kw("var"), "const": kw("var"), "let": kw("var"),
      "function": kw("function"), "catch": kw("catch"),
      "for": kw("for"), "switch": kw("switch"), "case": kw("case"), "default": kw("default"),
      "in": operator, "typeof": operator, "instanceof": operator,
      "true": atom, "false": atom, "null": atom, "undefined": atom, "NaN": atom, "Infinity": atom,
      "this": kw("this"), "class": kw("class"), "super": kw("atom"),
      "yield": C, "export": kw("export"), "import": kw("import"), "extends": C,
      "await": C
    };
  }();

  var isOperatorChar = /[+\-*&%=<>!?|~^@]/;
  var isJsonldKeyword = /^@(context|id|value|language|type|container|list|set|reverse|index|base|vocab|graph)"/;

  function readRegexp(stream) {
    var escaped = false, next, inSet = false;
    while ((next = stream.next()) != null) {
      if (!escaped) {
        if (next == "/" && !inSet) return;
        if (next == "[") inSet = true;
        else if (inSet && next == "]") inSet = false;
      }
      escaped = !escaped && next == "\\";
    }
  }

  // Used as scratch variables to communicate multiple values without
  // consing up tons of objects.
  var type, content;
  function ret(tp, style, cont) {
    type = tp; content = cont;
    return style;
  }
  function tokenBase(stream, state) {
    var ch = stream.next();
    if (ch == '"' || ch == "'") {
      state.tokenize = tokenString(ch);
      return state.tokenize(stream, state);
    } else if (ch == "." && stream.match(/^\d[\d_]*(?:[eE][+\-]?[\d_]+)?/)) {
      return ret("number", "number");
    } else if (ch == "." && stream.match("..")) {
      return ret("spread", "meta");
    } else if (/[\[\]{}\(\),;\:\.]/.test(ch)) {
      return ret(ch);
    } else if (ch == "=" && stream.eat(">")) {
      return ret("=>", "operator");
    } else if (ch == "0" && stream.match(/^(?:x[\dA-Fa-f_]+|o[0-7_]+|b[01_]+)n?/)) {
      return ret("number", "number");
    } else if (/\d/.test(ch)) {
      stream.match(/^[\d_]*(?:n|(?:\.[\d_]*)?(?:[eE][+\-]?[\d_]+)?)?/);
      return ret("number", "number");
    } else if (ch == "/") {
      if (stream.eat("*")) {
        state.tokenize = tokenComment;
        return tokenComment(stream, state);
      } else if (stream.eat("/")) {
        stream.skipToEnd();
        return ret("comment", "comment");
      } else if (expressionAllowed(stream, state, 1)) {
        readRegexp(stream);
        stream.match(/^\b(([gimyus])(?![gimyus]*\2))+\b/);
        return ret("regexp", "string-2");
      } else {
        stream.eat("=");
        return ret("operator", "operator", stream.current());
      }
    } else if (ch == "`") {
      state.tokenize = tokenQuasi;
      return tokenQuasi(stream, state);
    } else if (ch == "#" && stream.peek() == "!") {
      stream.skipToEnd();
      return ret("meta", "meta");
    } else if (ch == "#" && stream.eatWhile(wordRE)) {
      return ret("variable", "property")
    } else if (ch == "<" && stream.match("!--") ||
               (ch == "-" && stream.match("->") && !/\S/.test(stream.string.slice(0, stream.start)))) {
      stream.skipToEnd()
      return ret("comment", "comment")
    } else if (isOperatorChar.test(ch)) {
      if (ch != ">" || !state.lexical || state.lexical.type != ">") {
        if (stream.eat("=")) {
          if (ch == "!" || ch == "=") stream.eat("=")
        } else if (/[<>*+\-|&?]/.test(ch)) {
          stream.eat(ch)
          if (ch == ">") stream.eat(ch)
        }
      }
      if (ch == "?" && stream.eat(".")) return ret(".")
      return ret("operator", "operator", stream.current());
    } else if (wordRE.test(ch)) {
      stream.eatWhile(wordRE);
      var word = stream.current()
      if (state.lastType != ".") {
        if (keywords.propertyIsEnumerable(word)) {
          var kw = keywords[word]
          return ret(kw.type, kw.style, word)
        }
        if (word == "async" && stream.match(/^(\s|\/\*([^*]|\*(?!\/))*?\*\/)*[\[\(\w]/, false))
          return ret("async", "keyword", word)
      }
      return ret("variable", "variable", word)
    }
  }

  function tokenString(quote) {
    return function(stream, state) {
      var escaped = false, next;
      if (jsonldMode && stream.peek() == "@" && stream.match(isJsonldKeyword)){
        state.tokenize = tokenBase;
        return ret("jsonld-keyword", "meta");
      }
      while ((next = stream.next()) != null) {
        if (next == quote && !escaped) break;
        escaped = !escaped && next == "\\";
      }
      if (!escaped) state.tokenize = tokenBase;
      return ret("string", "string");
    };
  }

  function tokenComment(stream, state) {
    var maybeEnd = false, ch;
    while (ch = stream.next()) {
      if (ch == "/" && maybeEnd) {
        state.tokenize = tokenBase;
        break;
      }
      maybeEnd = (ch == "*");
    }
    return ret("comment", "comment");
  }

  function tokenQuasi(stream, state) {
    var escaped = false, next;
    while ((next = stream.next()) != null) {
      if (!escaped && (next == "`" || next == "$" && stream.eat("{"))) {
        state.tokenize = tokenBase;
        break;
      }
      escaped = !escaped && next == "\\";
    }
    return ret("quasi", "string-2", stream.current());
  }

  var brackets = "([{}])";
  // This is a crude lookahead trick to try and notice that we're
  // parsing the argument patterns for a fat-arrow function before we
  // actually hit the arrow token. It only works if the arrow is on
  // the same line as the arguments and there's no strange noise
  // (comments) in between. Fallback is to only notice when we hit the
  // arrow, and not declare the arguments as locals for the arrow
  // body.
  function findFatArrow(stream, state) {
    if (state.fatArrowAt) state.fatArrowAt = null;
    var arrow = stream.string.indexOf("=>", stream.start);
    if (arrow < 0) return;

    if (isTS) { // Try to skip TypeScript return type declarations after the arguments
      var m = /:\s*(?:\w+(?:<[^>]*>|\[\])?|\{[^}]*\})\s*$/.exec(stream.string.slice(stream.start, arrow))
      if (m) arrow = m.index
    }

    var depth = 0, sawSomething = false;
    for (var pos = arrow - 1; pos >= 0; --pos) {
      var ch = stream.string.charAt(pos);
      var bracket = brackets.indexOf(ch);
      if (bracket >= 0 && bracket < 3) {
        if (!depth) { ++pos; break; }
        if (--depth == 0) { if (ch == "(") sawSomething = true; break; }
      } else if (bracket >= 3 && bracket < 6) {
        ++depth;
      } else if (wordRE.test(ch)) {
        sawSomething = true;
      } else if (/["'\/`]/.test(ch)) {
        for (;; --pos) {
          if (pos == 0) return
          var next = stream.string.charAt(pos - 1)
          if (next == ch && stream.string.charAt(pos - 2) != "\\") { pos--; break }
        }
      } else if (sawSomething && !depth) {
        ++pos;
        break;
      }
    }
    if (sawSomething && !depth) state.fatArrowAt = pos;
  }

  // Parser

  var atomicTypes = {"atom": true, "number": true, "variable": true, "string": true,
                     "regexp": true, "this": true, "import": true, "jsonld-keyword": true};

  function JSLexical(indented, column, type, align, prev, info) {
    this.indented = indented;
    this.column = column;
    this.type = type;
    this.prev = prev;
    this.info = info;
    if (align != null) this.align = align;
  }

  function inScope(state, varname) {
    if (!trackScope) return false
    for (var v = state.localVars; v; v = v.next)
      if (v.name == varname) return true;
    for (var cx = state.context; cx; cx = cx.prev) {
      for (var v = cx.vars; v; v = v.next)
        if (v.name == varname) return true;
    }
  }

  function parseJS(state, style, type, content, stream) {
    var cc = state.cc;
    // Communicate our context to the combinators.
    // (Less wasteful than consing up a hundred closures on every call.)
    cx.state = state; cx.stream = stream; cx.marked = null, cx.cc = cc; cx.style = style;

    if (!state.lexical.hasOwnProperty("align"))
      state.lexical.align = true;

    while(true) {
      var combinator = cc.length ? cc.pop() : jsonMode ? expression : statement;
      if (combinator(type, content)) {
        while(cc.length && cc[cc.length - 1].lex)
          cc.pop()();
        if (cx.marked) return cx.marked;
        if (type == "variable" && inScope(state, content)) return "variable-2";
        return style;
      }
    }
  }

  // Combinator utils

  var cx = {state: null, column: null, marked: null, cc: null};
  function pass() {
    for (var i = arguments.length - 1; i >= 0; i--) cx.cc.push(arguments[i]);
  }
  function cont() {
    pass.apply(null, arguments);
    return true;
  }
  function inList(name, list) {
    for (var v = list; v; v = v.next) if (v.name == name) return true
    return false;
  }
  function register(varname) {
    var state = cx.state;
    cx.marked = "def";
    if (!trackScope) return
    if (state.context) {
      if (state.lexical.info == "var" && state.context && state.context.block) {
        // FIXME function decls are also not block scoped
        var newContext = registerVarScoped(varname, state.context)
        if (newContext != null) {
          state.context = newContext
          return
        }
      } else if (!inList(varname, state.localVars)) {
        state.localVars = new Var(varname, state.localVars)
        return
      }
    }
    // Fall through means this is global
    if (parserConfig.globalVars && !inList(varname, state.globalVars))
      state.globalVars = new Var(varname, state.globalVars)
  }
  function registerVarScoped(varname, context) {
    if (!context) {
      return null
    } else if (context.block) {
      var inner = registerVarScoped(varname, context.prev)
      if (!inner) return null
      if (inner == context.prev) return context
      return new Context(inner, context.vars, true)
    } else if (inList(varname, context.vars)) {
      return context
    } else {
      return new Context(context.prev, new Var(varname, context.vars), false)
    }
  }

  function isModifier(name) {
    return name == "public" || name == "private" || name == "protected" || name == "abstract" || name == "readonly"
  }

  // Combinators

  function Context(prev, vars, block) { this.prev = prev; this.vars = vars; this.block = block }
  function Var(name, next) { this.name = name; this.next = next }

  var defaultVars = new Var("this", new Var("arguments", null))
  function pushcontext() {
    cx.state.context = new Context(cx.state.context, cx.state.localVars, false)
    cx.state.localVars = defaultVars
  }
  function pushblockcontext() {
    cx.state.context = new Context(cx.state.context, cx.state.localVars, true)
    cx.state.localVars = null
  }
  pushcontext.lex = pushblockcontext.lex = true
  function popcontext() {
    cx.state.localVars = cx.state.context.vars
    cx.state.context = cx.state.context.prev
  }
  popcontext.lex = true
  function pushlex(type, info) {
    var result = function() {
      var state = cx.state, indent = state.indented;
      if (state.lexical.type == "stat") indent = state.lexical.indented;
      else for (var outer = state.lexical; outer && outer.type == ")" && outer.align; outer = outer.prev)
        indent = outer.indented;
      state.lexical = new JSLexical(indent, cx.stream.column(), type, null, state.lexical, info);
    };
    result.lex = true;
    return result;
  }
  function poplex() {
    var state = cx.state;
    if (state.lexical.prev) {
      if (state.lexical.type == ")")
        state.indented = state.lexical.indented;
      state.lexical = state.lexical.prev;
    }
  }
  poplex.lex = true;

  function expect(wanted) {
    function exp(type) {
      if (type == wanted) return cont();
      else if (wanted == ";" || type == "}" || type == ")" || type == "]") return pass();
      else return cont(exp);
    };
    return exp;
  }

  function statement(type, value) {
    if (type == "var") return cont(pushlex("vardef", value), vardef, expect(";"), poplex);
    if (type == "keyword a") return cont(pushlex("form"), parenExpr, statement, poplex);
    if (type == "keyword b") return cont(pushlex("form"), statement, poplex);
    if (type == "keyword d") return cx.stream.match(/^\s*$/, false) ? cont() : cont(pushlex("stat"), maybeexpression, expect(";"), poplex);
    if (type == "debugger") return cont(expect(";"));
    if (type == "{") return cont(pushlex("}"), pushblockcontext, block, poplex, popcontext);
    if (type == ";") return cont();
    if (type == "if") {
      if (cx.state.lexical.info == "else" && cx.state.cc[cx.state.cc.length - 1] == poplex)
        cx.state.cc.pop()();
      return cont(pushlex("form"), parenExpr, statement, poplex, maybeelse);
    }
    if (type == "function") return cont(functiondef);
    if (type == "for") return cont(pushlex("form"), pushblockcontext, forspec, statement, popcontext, poplex);
    if (type == "class" || (isTS && value == "interface")) {
      cx.marked = "keyword"
      return cont(pushlex("form", type == "class" ? type : value), className, poplex)
    }
    if (type == "variable") {
      if (isTS && value == "declare") {
        cx.marked = "keyword"
        return cont(statement)
      } else if (isTS && (value == "module" || value == "enum" || value == "type") && cx.stream.match(/^\s*\w/, false)) {
        cx.marked = "keyword"
        if (value == "enum") return cont(enumdef);
        else if (value == "type") return cont(typename, expect("operator"), typeexpr, expect(";"));
        else return cont(pushlex("form"), pattern, expect("{"), pushlex("}"), block, poplex, poplex)
      } else if (isTS && value == "namespace") {
        cx.marked = "keyword"
        return cont(pushlex("form"), expression, statement, poplex)
      } else if (isTS && value == "abstract") {
        cx.marked = "keyword"
        return cont(statement)
      } else {
        return cont(pushlex("stat"), maybelabel);
      }
    }
    if (type == "switch") return cont(pushlex("form"), parenExpr, expect("{"), pushlex("}", "switch"), pushblockcontext,
                                      block, poplex, poplex, popcontext);
    if (type == "case") return cont(expression, expect(":"));
    if (type == "default") return cont(expect(":"));
    if (type == "catch") return cont(pushlex("form"), pushcontext, maybeCatchBinding, statement, poplex, popcontext);
    if (type == "export") return cont(pushlex("stat"), afterExport, poplex);
    if (type == "import") return cont(pushlex("stat"), afterImport, poplex);
    if (type == "async") return cont(statement)
    if (value == "@") return cont(expression, statement)
    return pass(pushlex("stat"), expression, expect(";"), poplex);
  }
  function maybeCatchBinding(type) {
    if (type == "(") return cont(funarg, expect(")"))
  }
  function expression(type, value) {
    return expressionInner(type, value, false);
  }
  function expressionNoComma(type, value) {
    return expressionInner(type, value, true);
  }
  function parenExpr(type) {
    if (type != "(") return pass()
    return cont(pushlex(")"), maybeexpression, expect(")"), poplex)
  }
  function expressionInner(type, value, noComma) {
    if (cx.state.fatArrowAt == cx.stream.start) {
      var body = noComma ? arrowBodyNoComma : arrowBody;
      if (type == "(") return cont(pushcontext, pushlex(")"), commasep(funarg, ")"), poplex, expect("=>"), body, popcontext);
      else if (type == "variable") return pass(pushcontext, pattern, expect("=>"), body, popcontext);
    }

    var maybeop = noComma ? maybeoperatorNoComma : maybeoperatorComma;
    if (atomicTypes.hasOwnProperty(type)) return cont(maybeop);
    if (type == "function") return cont(functiondef, maybeop);
    if (type == "class" || (isTS && value == "interface")) { cx.marked = "keyword"; return cont(pushlex("form"), classExpression, poplex); }
    if (type == "keyword c" || type == "async") return cont(noComma ? expressionNoComma : expression);
    if (type == "(") return cont(pushlex(")"), maybeexpression, expect(")"), poplex, maybeop);
    if (type == "operator" || type == "spread") return cont(noComma ? expressionNoComma : expression);
    if (type == "[") return cont(pushlex("]"), arrayLiteral, poplex, maybeop);
    if (type == "{") return contCommasep(objprop, "}", null, maybeop);
    if (type == "quasi") return pass(quasi, maybeop);
    if (type == "new") return cont(maybeTarget(noComma));
    return cont();
  }
  function maybeexpression(type) {
    if (type.match(/[;\}\)\],]/)) return pass();
    return pass(expression);
  }

  function maybeoperatorComma(type, value) {
    if (type == ",") return cont(maybeexpression);
    return maybeoperatorNoComma(type, value, false);
  }
  function maybeoperatorNoComma(type, value, noComma) {
    var me = noComma == false ? maybeoperatorComma : maybeoperatorNoComma;
    var expr = noComma == false ? expression : expressionNoComma;
    if (type == "=>") return cont(pushcontext, noComma ? arrowBodyNoComma : arrowBody, popcontext);
    if (type == "operator") {
      if (/\+\+|--/.test(value) || isTS && value == "!") return cont(me);
      if (isTS && value == "<" && cx.stream.match(/^([^<>]|<[^<>]*>)*>\s*\(/, false))
        return cont(pushlex(">"), commasep(typeexpr, ">"), poplex, me);
      if (value == "?") return cont(expression, expect(":"), expr);
      return cont(expr);
    }
    if (type == "quasi") { return pass(quasi, me); }
    if (type == ";") return;
    if (type == "(") return contCommasep(expressionNoComma, ")", "call", me);
    if (type == ".") return cont(property, me);
    if (type == "[") return cont(pushlex("]"), maybeexpression, expect("]"), poplex, me);
    if (isTS && value == "as") { cx.marked = "keyword"; return cont(typeexpr, me) }
    if (type == "regexp") {
      cx.state.lastType = cx.marked = "operator"
      cx.stream.backUp(cx.stream.pos - cx.stream.start - 1)
      return cont(expr)
    }
  }
  function quasi(type, value) {
    if (type != "quasi") return pass();
    if (value.slice(value.length - 2) != "${") return cont(quasi);
    return cont(maybeexpression, continueQuasi);
  }
  function continueQuasi(type) {
    if (type == "}") {
      cx.marked = "string-2";
      cx.state.tokenize = tokenQuasi;
      return cont(quasi);
    }
  }
  function arrowBody(type) {
    findFatArrow(cx.stream, cx.state);
    return pass(type == "{" ? statement : expression);
  }
  function arrowBodyNoComma(type) {
    findFatArrow(cx.stream, cx.state);
    return pass(type == "{" ? statement : expressionNoComma);
  }
  function maybeTarget(noComma) {
    return function(type) {
      if (type == ".") return cont(noComma ? targetNoComma : target);
      else if (type == "variable" && isTS) return cont(maybeTypeArgs, noComma ? maybeoperatorNoComma : maybeoperatorComma)
      else return pass(noComma ? expressionNoComma : expression);
    };
  }
  function target(_, value) {
    if (value == "target") { cx.marked = "keyword"; return cont(maybeoperatorComma); }
  }
  function targetNoComma(_, value) {
    if (value == "target") { cx.marked = "keyword"; return cont(maybeoperatorNoComma); }
  }
  function maybelabel(type) {
    if (type == ":") return cont(poplex, statement);
    return pass(maybeoperatorComma, expect(";"), poplex);
  }
  function property(type) {
    if (type == "variable") {cx.marked = "property"; return cont();}
  }
  function objprop(type, value) {
    if (type == "async") {
      cx.marked = "property";
      return cont(objprop);
    } else if (type == "variable" || cx.style == "keyword") {
      cx.marked = "property";
      if (value == "get" || value == "set") return cont(getterSetter);
      var m // Work around fat-arrow-detection complication for detecting typescript typed arrow params
      if (isTS && cx.state.fatArrowAt == cx.stream.start && (m = cx.stream.match(/^\s*:\s*/, false)))
        cx.state.fatArrowAt = cx.stream.pos + m[0].length
      return cont(afterprop);
    } else if (type == "number" || type == "string") {
      cx.marked = jsonldMode ? "property" : (cx.style + " property");
      return cont(afterprop);
    } else if (type == "jsonld-keyword") {
      return cont(afterprop);
    } else if (isTS && isModifier(value)) {
      cx.marked = "keyword"
      return cont(objprop)
    } else if (type == "[") {
      return cont(expression, maybetype, expect("]"), afterprop);
    } else if (type == "spread") {
      return cont(expressionNoComma, afterprop);
    } else if (value == "*") {
      cx.marked = "keyword";
      return cont(objprop);
    } else if (type == ":") {
      return pass(afterprop)
    }
  }
  function getterSetter(type) {
    if (type != "variable") return pass(afterprop);
    cx.marked = "property";
    return cont(functiondef);
  }
  function afterprop(type) {
    if (type == ":") return cont(expressionNoComma);
    if (type == "(") return pass(functiondef);
  }
  function commasep(what, end, sep) {
    function proceed(type, value) {
      if (sep ? sep.indexOf(type) > -1 : type == ",") {
        var lex = cx.state.lexical;
        if (lex.info == "call") lex.pos = (lex.pos || 0) + 1;
        return cont(function(type, value) {
          if (type == end || value == end) return pass()
          return pass(what)
        }, proceed);
      }
      if (type == end || value == end) return cont();
      if (sep && sep.indexOf(";") > -1) return pass(what)
      return cont(expect(end));
    }
    return function(type, value) {
      if (type == end || value == end) return cont();
      return pass(what, proceed);
    };
  }
  function contCommasep(what, end, info) {
    for (var i = 3; i < arguments.length; i++)
      cx.cc.push(arguments[i]);
    return cont(pushlex(end, info), commasep(what, end), poplex);
  }
  function block(type) {
    if (type == "}") return cont();
    return pass(statement, block);
  }
  function maybetype(type, value) {
    if (isTS) {
      if (type == ":") return cont(typeexpr);
      if (value == "?") return cont(maybetype);
    }
  }
  function maybetypeOrIn(type, value) {
    if (isTS && (type == ":" || value == "in")) return cont(typeexpr)
  }
  function mayberettype(type) {
    if (isTS && type == ":") {
      if (cx.stream.match(/^\s*\w+\s+is\b/, false)) return cont(expression, isKW, typeexpr)
      else return cont(typeexpr)
    }
  }
  function isKW(_, value) {
    if (value == "is") {
      cx.marked = "keyword"
      return cont()
    }
  }
  function typeexpr(type, value) {
    if (value == "keyof" || value == "typeof" || value == "infer" || value == "readonly") {
      cx.marked = "keyword"
      return cont(value == "typeof" ? expressionNoComma : typeexpr)
    }
    if (type == "variable" || value == "void") {
      cx.marked = "type"
      return cont(afterType)
    }
    if (value == "|" || value == "&") return cont(typeexpr)
    if (type == "string" || type == "number" || type == "atom") return cont(afterType);
    if (type == "[") return cont(pushlex("]"), commasep(typeexpr, "]", ","), poplex, afterType)
    if (type == "{") return cont(pushlex("}"), typeprops, poplex, afterType)
    if (type == "(") return cont(commasep(typearg, ")"), maybeReturnType, afterType)
    if (type == "<") return cont(commasep(typeexpr, ">"), typeexpr)
    if (type == "quasi") { return pass(quasiType, afterType); }
  }
  function maybeReturnType(type) {
    if (type == "=>") return cont(typeexpr)
  }
  function typeprops(type) {
    if (type.match(/[\}\)\]]/)) return cont()
    if (type == "," || type == ";") return cont(typeprops)
    return pass(typeprop, typeprops)
  }
  function typeprop(type, value) {
    if (type == "variable" || cx.style == "keyword") {
      cx.marked = "property"
      return cont(typeprop)
    } else if (value == "?" || type == "number" || type == "string") {
      return cont(typeprop)
    } else if (type == ":") {
      return cont(typeexpr)
    } else if (type == "[") {
      return cont(expect("variable"), maybetypeOrIn, expect("]"), typeprop)
    } else if (type == "(") {
      return pass(functiondecl, typeprop)
    } else if (!type.match(/[;\}\)\],]/)) {
      return cont()
    }
  }
  function quasiType(type, value) {
    if (type != "quasi") return pass();
    if (value.slice(value.length - 2) != "${") return cont(quasiType);
    return cont(typeexpr, continueQuasiType);
  }
  function continueQuasiType(type) {
    if (type == "}") {
      cx.marked = "string-2";
      cx.state.tokenize = tokenQuasi;
      return cont(quasiType);
    }
  }
  function typearg(type, value) {
    if (type == "variable" && cx.stream.match(/^\s*[?:]/, false) || value == "?") return cont(typearg)
    if (type == ":") return cont(typeexpr)
    if (type == "spread") return cont(typearg)
    return pass(typeexpr)
  }
  function afterType(type, value) {
    if (value == "<") return cont(pushlex(">"), commasep(typeexpr, ">"), poplex, afterType)
    if (value == "|" || type == "." || value == "&") return cont(typeexpr)
    if (type == "[") return cont(typeexpr, expect("]"), afterType)
    if (value == "extends" || value == "implements") { cx.marked = "keyword"; return cont(typeexpr) }
    if (value == "?") return cont(typeexpr, expect(":"), typeexpr)
  }
  function maybeTypeArgs(_, value) {
    if (value == "<") return cont(pushlex(">"), commasep(typeexpr, ">"), poplex, afterType)
  }
  function typeparam() {
    return pass(typeexpr, maybeTypeDefault)
  }
  function maybeTypeDefault(_, value) {
    if (value == "=") return cont(typeexpr)
  }
  function vardef(_, value) {
    if (value == "enum") {cx.marked = "keyword"; return cont(enumdef)}
    return pass(pattern, maybetype, maybeAssign, vardefCont);
  }
  function pattern(type, value) {
    if (isTS && isModifier(value)) { cx.marked = "keyword"; return cont(pattern) }
    if (type == "variable") { register(value); return cont(); }
    if (type == "spread") return cont(pattern);
    if (type == "[") return contCommasep(eltpattern, "]");
    if (type == "{") return contCommasep(proppattern, "}");
  }
  function proppattern(type, value) {
    if (type == "variable" && !cx.stream.match(/^\s*:/, false)) {
      register(value);
      return cont(maybeAssign);
    }
    if (type == "variable") cx.marked = "property";
    if (type == "spread") return cont(pattern);
    if (type == "}") return pass();
    if (type == "[") return cont(expression, expect(']'), expect(':'), proppattern);
    return cont(expect(":"), pattern, maybeAssign);
  }
  function eltpattern() {
    return pass(pattern, maybeAssign)
  }
  function maybeAssign(_type, value) {
    if (value == "=") return cont(expressionNoComma);
  }
  function vardefCont(type) {
    if (type == ",") return cont(vardef);
  }
  function maybeelse(type, value) {
    if (type == "keyword b" && value == "else") return cont(pushlex("form", "else"), statement, poplex);
  }
  function forspec(type, value) {
    if (value == "await") return cont(forspec);
    if (type == "(") return cont(pushlex(")"), forspec1, poplex);
  }
  function forspec1(type) {
    if (type == "var") return cont(vardef, forspec2);
    if (type == "variable") return cont(forspec2);
    return pass(forspec2)
  }
  function forspec2(type, value) {
    if (type == ")") return cont()
    if (type == ";") return cont(forspec2)
    if (value == "in" || value == "of") { cx.marked = "keyword"; return cont(expression, forspec2) }
    return pass(expression, forspec2)
  }
  function functiondef(type, value) {
    if (value == "*") {cx.marked = "keyword"; return cont(functiondef);}
    if (type == "variable") {register(value); return cont(functiondef);}
    if (type == "(") return cont(pushcontext, pushlex(")"), commasep(funarg, ")"), poplex, mayberettype, statement, popcontext);
    if (isTS && value == "<") return cont(pushlex(">"), commasep(typeparam, ">"), poplex, functiondef)
  }
  function functiondecl(type, value) {
    if (value == "*") {cx.marked = "keyword"; return cont(functiondecl);}
    if (type == "variable") {register(value); return cont(functiondecl);}
    if (type == "(") return cont(pushcontext, pushlex(")"), commasep(funarg, ")"), poplex, mayberettype, popcontext);
    if (isTS && value == "<") return cont(pushlex(">"), commasep(typeparam, ">"), poplex, functiondecl)
  }
  function typename(type, value) {
    if (type == "keyword" || type == "variable") {
      cx.marked = "type"
      return cont(typename)
    } else if (value == "<") {
      return cont(pushlex(">"), commasep(typeparam, ">"), poplex)
    }
  }
  function funarg(type, value) {
    if (value == "@") cont(expression, funarg)
    if (type == "spread") return cont(funarg);
    if (isTS && isModifier(value)) { cx.marked = "keyword"; return cont(funarg); }
    if (isTS && type == "this") return cont(maybetype, maybeAssign)
    return pass(pattern, maybetype, maybeAssign);
  }
  function classExpression(type, value) {
    // Class expressions may have an optional name.
    if (type == "variable") return className(type, value);
    return classNameAfter(type, value);
  }
  function className(type, value) {
    if (type == "variable") {register(value); return cont(classNameAfter);}
  }
  function classNameAfter(type, value) {
    if (value == "<") return cont(pushlex(">"), commasep(typeparam, ">"), poplex, classNameAfter)
    if (value == "extends" || value == "implements" || (isTS && type == ",")) {
      if (value == "implements") cx.marked = "keyword";
      return cont(isTS ? typeexpr : expression, classNameAfter);
    }
    if (type == "{") return cont(pushlex("}"), classBody, poplex);
  }
  function classBody(type, value) {
    if (type == "async" ||
        (type == "variable" &&
         (value == "static" || value == "get" || value == "set" || (isTS && isModifier(value))) &&
         cx.stream.match(/^\s+[\w$\xa1-\uffff]/, false))) {
      cx.marked = "keyword";
      return cont(classBody);
    }
    if (type == "variable" || cx.style == "keyword") {
      cx.marked = "property";
      return cont(classfield, classBody);
    }
    if (type == "number" || type == "string") return cont(classfield, classBody);
    if (type == "[")
      return cont(expression, maybetype, expect("]"), classfield, classBody)
    if (value == "*") {
      cx.marked = "keyword";
      return cont(classBody);
    }
    if (isTS && type == "(") return pass(functiondecl, classBody)
    if (type == ";" || type == ",") return cont(classBody);
    if (type == "}") return cont();
    if (value == "@") return cont(expression, classBody)
  }
  function classfield(type, value) {
    if (value == "!") return cont(classfield)
    if (value == "?") return cont(classfield)
    if (type == ":") return cont(typeexpr, maybeAssign)
    if (value == "=") return cont(expressionNoComma)
    var context = cx.state.lexical.prev, isInterface = context && context.info == "interface"
    return pass(isInterface ? functiondecl : functiondef)
  }
  function afterExport(type, value) {
    if (value == "*") { cx.marked = "keyword"; return cont(maybeFrom, expect(";")); }
    if (value == "default") { cx.marked = "keyword"; return cont(expression, expect(";")); }
    if (type == "{") return cont(commasep(exportField, "}"), maybeFrom, expect(";"));
    return pass(statement);
  }
  function exportField(type, value) {
    if (value == "as") { cx.marked = "keyword"; return cont(expect("variable")); }
    if (type == "variable") return pass(expressionNoComma, exportField);
  }
  function afterImport(type) {
    if (type == "string") return cont();
    if (type == "(") return pass(expression);
    if (type == ".") return pass(maybeoperatorComma);
    return pass(importSpec, maybeMoreImports, maybeFrom);
  }
  function importSpec(type, value) {
    if (type == "{") return contCommasep(importSpec, "}");
    if (type == "variable") register(value);
    if (value == "*") cx.marked = "keyword";
    return cont(maybeAs);
  }
  function maybeMoreImports(type) {
    if (type == ",") return cont(importSpec, maybeMoreImports)
  }
  function maybeAs(_type, value) {
    if (value == "as") { cx.marked = "keyword"; return cont(importSpec); }
  }
  function maybeFrom(_type, value) {
    if (value == "from") { cx.marked = "keyword"; return cont(expression); }
  }
  function arrayLiteral(type) {
    if (type == "]") return cont();
    return pass(commasep(expressionNoComma, "]"));
  }
  function enumdef() {
    return pass(pushlex("form"), pattern, expect("{"), pushlex("}"), commasep(enummember, "}"), poplex, poplex)
  }
  function enummember() {
    return pass(pattern, maybeAssign);
  }

  function isContinuedStatement(state, textAfter) {
    return state.lastType == "operator" || state.lastType == "," ||
      isOperatorChar.test(textAfter.charAt(0)) ||
      /[,.]/.test(textAfter.charAt(0));
  }

  function expressionAllowed(stream, state, backUp) {
    return state.tokenize == tokenBase &&
      /^(?:operator|sof|keyword [bcd]|case|new|export|default|spread|[\[{}\(,;:]|=>)$/.test(state.lastType) ||
      (state.lastType == "quasi" && /\{\s*$/.test(stream.string.slice(0, stream.pos - (backUp || 0))))
  }

  // Interface

  return {
    startState: function(basecolumn) {
      var state = {
        tokenize: tokenBase,
        lastType: "sof",
        cc: [],
        lexical: new JSLexical((basecolumn || 0) - indentUnit, 0, "block", false),
        localVars: parserConfig.localVars,
        context: parserConfig.localVars && new Context(null, null, false),
        indented: basecolumn || 0
      };
      if (parserConfig.globalVars && typeof parserConfig.globalVars == "object")
        state.globalVars = parserConfig.globalVars;
      return state;
    },

    token: function(stream, state) {
      if (stream.sol()) {
        if (!state.lexical.hasOwnProperty("align"))
          state.lexical.align = false;
        state.indented = stream.indentation();
        findFatArrow(stream, state);
      }
      if (state.tokenize != tokenComment && stream.eatSpace()) return null;
      var style = state.tokenize(stream, state);
      if (type == "comment") return style;
      state.lastType = type == "operator" && (content == "++" || content == "--") ? "incdec" : type;
      return parseJS(state, style, type, content, stream);
    },

    indent: function(state, textAfter) {
      if (state.tokenize == tokenComment || state.tokenize == tokenQuasi) return CodeMirror.Pass;
      if (state.tokenize != tokenBase) return 0;
      var firstChar = textAfter && textAfter.charAt(0), lexical = state.lexical, top
      // Kludge to prevent 'maybelse' from blocking lexical scope pops
      if (!/^\s*else\b/.test(textAfter)) for (var i = state.cc.length - 1; i >= 0; --i) {
        var c = state.cc[i];
        if (c == poplex) lexical = lexical.prev;
        else if (c != maybeelse && c != popcontext) break;
      }
      while ((lexical.type == "stat" || lexical.type == "form") &&
             (firstChar == "}" || ((top = state.cc[state.cc.length - 1]) &&
                                   (top == maybeoperatorComma || top == maybeoperatorNoComma) &&
                                   !/^[,\.=+\-*:?[\(]/.test(textAfter))))
        lexical = lexical.prev;
      if (statementIndent && lexical.type == ")" && lexical.prev.type == "stat")
        lexical = lexical.prev;
      var type = lexical.type, closing = firstChar == type;

      if (type == "vardef") return lexical.indented + (state.lastType == "operator" || state.lastType == "," ? lexical.info.length + 1 : 0);
      else if (type == "form" && firstChar == "{") return lexical.indented;
      else if (type == "form") return lexical.indented + indentUnit;
      else if (type == "stat")
        return lexical.indented + (isContinuedStatement(state, textAfter) ? statementIndent || indentUnit : 0);
      else if (lexical.info == "switch" && !closing && parserConfig.doubleIndentSwitch != false)
        return lexical.indented + (/^(?:case|default)\b/.test(textAfter) ? indentUnit : 2 * indentUnit);
      else if (lexical.align) return lexical.column + (closing ? 0 : 1);
      else return lexical.indented + (closing ? 0 : indentUnit);
    },

    electricInput: /^\s*(?:case .*?:|default:|\{|\})$/,
    blockCommentStart: jsonMode ? null : "/*",
    blockCommentEnd: jsonMode ? null : "*/",
    blockCommentContinue: jsonMode ? null : " * ",
    lineComment: jsonMode ? null : "//",
    fold: "brace",
    closeBrackets: "()[]{}''\"\"``",

    helperType: jsonMode ? "json" : "javascript",
    jsonldMode: jsonldMode,
    jsonMode: jsonMode,

    expressionAllowed: expressionAllowed,

    skipExpression: function(state) {
      parseJS(state, "atom", "atom", "true", new CodeMirror.StringStream("", 2, null))
    }
  };
});

CodeMirror.registerHelper("wordChars", "javascript", /[\w$]/);

CodeMirror.defineMIME("text/javascript", "javascript");
CodeMirror.defineMIME("text/ecmascript", "javascript");
CodeMirror.defineMIME("application/javascript", "javascript");
CodeMirror.defineMIME("application/x-javascript", "javascript");
CodeMirror.defineMIME("application/ecmascript", "javascript");
CodeMirror.defineMIME("application/json", { name: "javascript", json: true });
CodeMirror.defineMIME("application/x-json", { name: "javascript", json: true });
CodeMirror.defineMIME("application/manifest+json", { name: "javascript", json: true })
CodeMirror.defineMIME("application/ld+json", { name: "javascript", jsonld: true });
CodeMirror.defineMIME("text/typescript", { name: "javascript", typescript: true });
CodeMirror.defineMIME("application/typescript", { name: "javascript", typescript: true });

});


/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/codemirror/mode/python/python.js":
/*!**************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/codemirror/mode/python/python.js ***!
  \**************************************************************************************/
/***/ ((__unused_webpack_module, __unused_webpack_exports, __webpack_require__) => {

// CodeMirror, copyright (c) by Marijn Haverbeke and others
// Distributed under an MIT license: https://codemirror.net/LICENSE

(function(mod) {
  if (true) // CommonJS
    mod(__webpack_require__(/*! ../../lib/codemirror */ "../../node_modules/@elyra/canvas/node_modules/codemirror/lib/codemirror.js"));
  else {}
})(function(CodeMirror) {
  "use strict";

  function wordRegexp(words) {
    return new RegExp("^((" + words.join(")|(") + "))\\b");
  }

  var wordOperators = wordRegexp(["and", "or", "not", "is"]);
  var commonKeywords = ["as", "assert", "break", "class", "continue",
                        "def", "del", "elif", "else", "except", "finally",
                        "for", "from", "global", "if", "import",
                        "lambda", "pass", "raise", "return",
                        "try", "while", "with", "yield", "in"];
  var commonBuiltins = ["abs", "all", "any", "bin", "bool", "bytearray", "callable", "chr",
                        "classmethod", "compile", "complex", "delattr", "dict", "dir", "divmod",
                        "enumerate", "eval", "filter", "float", "format", "frozenset",
                        "getattr", "globals", "hasattr", "hash", "help", "hex", "id",
                        "input", "int", "isinstance", "issubclass", "iter", "len",
                        "list", "locals", "map", "max", "memoryview", "min", "next",
                        "object", "oct", "open", "ord", "pow", "property", "range",
                        "repr", "reversed", "round", "set", "setattr", "slice",
                        "sorted", "staticmethod", "str", "sum", "super", "tuple",
                        "type", "vars", "zip", "__import__", "NotImplemented",
                        "Ellipsis", "__debug__"];
  CodeMirror.registerHelper("hintWords", "python", commonKeywords.concat(commonBuiltins));

  function top(state) {
    return state.scopes[state.scopes.length - 1];
  }

  CodeMirror.defineMode("python", function(conf, parserConf) {
    var ERRORCLASS = "error";

    var delimiters = parserConf.delimiters || parserConf.singleDelimiters || /^[\(\)\[\]\{\}@,:`=;\.\\]/;
    //               (Backwards-compatibility with old, cumbersome config system)
    var operators = [parserConf.singleOperators, parserConf.doubleOperators, parserConf.doubleDelimiters, parserConf.tripleDelimiters,
                     parserConf.operators || /^([-+*/%\/&|^]=?|[<>=]+|\/\/=?|\*\*=?|!=|[~!@]|\.\.\.)/]
    for (var i = 0; i < operators.length; i++) if (!operators[i]) operators.splice(i--, 1)

    var hangingIndent = parserConf.hangingIndent || conf.indentUnit;

    var myKeywords = commonKeywords, myBuiltins = commonBuiltins;
    if (parserConf.extra_keywords != undefined)
      myKeywords = myKeywords.concat(parserConf.extra_keywords);

    if (parserConf.extra_builtins != undefined)
      myBuiltins = myBuiltins.concat(parserConf.extra_builtins);

    var py3 = !(parserConf.version && Number(parserConf.version) < 3)
    if (py3) {
      // since http://legacy.python.org/dev/peps/pep-0465/ @ is also an operator
      var identifiers = parserConf.identifiers|| /^[_A-Za-z\u00A1-\uFFFF][_A-Za-z0-9\u00A1-\uFFFF]*/;
      myKeywords = myKeywords.concat(["nonlocal", "False", "True", "None", "async", "await"]);
      myBuiltins = myBuiltins.concat(["ascii", "bytes", "exec", "print"]);
      var stringPrefixes = new RegExp("^(([rbuf]|(br)|(rb)|(fr)|(rf))?('{3}|\"{3}|['\"]))", "i");
    } else {
      var identifiers = parserConf.identifiers|| /^[_A-Za-z][_A-Za-z0-9]*/;
      myKeywords = myKeywords.concat(["exec", "print"]);
      myBuiltins = myBuiltins.concat(["apply", "basestring", "buffer", "cmp", "coerce", "execfile",
                                      "file", "intern", "long", "raw_input", "reduce", "reload",
                                      "unichr", "unicode", "xrange", "False", "True", "None"]);
      var stringPrefixes = new RegExp("^(([rubf]|(ur)|(br))?('{3}|\"{3}|['\"]))", "i");
    }
    var keywords = wordRegexp(myKeywords);
    var builtins = wordRegexp(myBuiltins);

    // tokenizers
    function tokenBase(stream, state) {
      var sol = stream.sol() && state.lastToken != "\\"
      if (sol) state.indent = stream.indentation()
      // Handle scope changes
      if (sol && top(state).type == "py") {
        var scopeOffset = top(state).offset;
        if (stream.eatSpace()) {
          var lineOffset = stream.indentation();
          if (lineOffset > scopeOffset)
            pushPyScope(state);
          else if (lineOffset < scopeOffset && dedent(stream, state) && stream.peek() != "#")
            state.errorToken = true;
          return null;
        } else {
          var style = tokenBaseInner(stream, state);
          if (scopeOffset > 0 && dedent(stream, state))
            style += " " + ERRORCLASS;
          return style;
        }
      }
      return tokenBaseInner(stream, state);
    }

    function tokenBaseInner(stream, state, inFormat) {
      if (stream.eatSpace()) return null;

      // Handle Comments
      if (!inFormat && stream.match(/^#.*/)) return "comment";

      // Handle Number Literals
      if (stream.match(/^[0-9\.]/, false)) {
        var floatLiteral = false;
        // Floats
        if (stream.match(/^[\d_]*\.\d+(e[\+\-]?\d+)?/i)) { floatLiteral = true; }
        if (stream.match(/^[\d_]+\.\d*/)) { floatLiteral = true; }
        if (stream.match(/^\.\d+/)) { floatLiteral = true; }
        if (floatLiteral) {
          // Float literals may be "imaginary"
          stream.eat(/J/i);
          return "number";
        }
        // Integers
        var intLiteral = false;
        // Hex
        if (stream.match(/^0x[0-9a-f_]+/i)) intLiteral = true;
        // Binary
        if (stream.match(/^0b[01_]+/i)) intLiteral = true;
        // Octal
        if (stream.match(/^0o[0-7_]+/i)) intLiteral = true;
        // Decimal
        if (stream.match(/^[1-9][\d_]*(e[\+\-]?[\d_]+)?/)) {
          // Decimal literals may be "imaginary"
          stream.eat(/J/i);
          // TODO - Can you have imaginary longs?
          intLiteral = true;
        }
        // Zero by itself with no other piece of number.
        if (stream.match(/^0(?![\dx])/i)) intLiteral = true;
        if (intLiteral) {
          // Integer literals may be "long"
          stream.eat(/L/i);
          return "number";
        }
      }

      // Handle Strings
      if (stream.match(stringPrefixes)) {
        var isFmtString = stream.current().toLowerCase().indexOf('f') !== -1;
        if (!isFmtString) {
          state.tokenize = tokenStringFactory(stream.current(), state.tokenize);
          return state.tokenize(stream, state);
        } else {
          state.tokenize = formatStringFactory(stream.current(), state.tokenize);
          return state.tokenize(stream, state);
        }
      }

      for (var i = 0; i < operators.length; i++)
        if (stream.match(operators[i])) return "operator"

      if (stream.match(delimiters)) return "punctuation";

      if (state.lastToken == "." && stream.match(identifiers))
        return "property";

      if (stream.match(keywords) || stream.match(wordOperators))
        return "keyword";

      if (stream.match(builtins))
        return "builtin";

      if (stream.match(/^(self|cls)\b/))
        return "variable-2";

      if (stream.match(identifiers)) {
        if (state.lastToken == "def" || state.lastToken == "class")
          return "def";
        return "variable";
      }

      // Handle non-detected items
      stream.next();
      return inFormat ? null :ERRORCLASS;
    }

    function formatStringFactory(delimiter, tokenOuter) {
      while ("rubf".indexOf(delimiter.charAt(0).toLowerCase()) >= 0)
        delimiter = delimiter.substr(1);

      var singleline = delimiter.length == 1;
      var OUTCLASS = "string";

      function tokenNestedExpr(depth) {
        return function(stream, state) {
          var inner = tokenBaseInner(stream, state, true)
          if (inner == "punctuation") {
            if (stream.current() == "{") {
              state.tokenize = tokenNestedExpr(depth + 1)
            } else if (stream.current() == "}") {
              if (depth > 1) state.tokenize = tokenNestedExpr(depth - 1)
              else state.tokenize = tokenString
            }
          }
          return inner
        }
      }

      function tokenString(stream, state) {
        while (!stream.eol()) {
          stream.eatWhile(/[^'"\{\}\\]/);
          if (stream.eat("\\")) {
            stream.next();
            if (singleline && stream.eol())
              return OUTCLASS;
          } else if (stream.match(delimiter)) {
            state.tokenize = tokenOuter;
            return OUTCLASS;
          } else if (stream.match('{{')) {
            // ignore {{ in f-str
            return OUTCLASS;
          } else if (stream.match('{', false)) {
            // switch to nested mode
            state.tokenize = tokenNestedExpr(0)
            if (stream.current()) return OUTCLASS;
            else return state.tokenize(stream, state)
          } else if (stream.match('}}')) {
            return OUTCLASS;
          } else if (stream.match('}')) {
            // single } in f-string is an error
            return ERRORCLASS;
          } else {
            stream.eat(/['"]/);
          }
        }
        if (singleline) {
          if (parserConf.singleLineStringErrors)
            return ERRORCLASS;
          else
            state.tokenize = tokenOuter;
        }
        return OUTCLASS;
      }
      tokenString.isString = true;
      return tokenString;
    }

    function tokenStringFactory(delimiter, tokenOuter) {
      while ("rubf".indexOf(delimiter.charAt(0).toLowerCase()) >= 0)
        delimiter = delimiter.substr(1);

      var singleline = delimiter.length == 1;
      var OUTCLASS = "string";

      function tokenString(stream, state) {
        while (!stream.eol()) {
          stream.eatWhile(/[^'"\\]/);
          if (stream.eat("\\")) {
            stream.next();
            if (singleline && stream.eol())
              return OUTCLASS;
          } else if (stream.match(delimiter)) {
            state.tokenize = tokenOuter;
            return OUTCLASS;
          } else {
            stream.eat(/['"]/);
          }
        }
        if (singleline) {
          if (parserConf.singleLineStringErrors)
            return ERRORCLASS;
          else
            state.tokenize = tokenOuter;
        }
        return OUTCLASS;
      }
      tokenString.isString = true;
      return tokenString;
    }

    function pushPyScope(state) {
      while (top(state).type != "py") state.scopes.pop()
      state.scopes.push({offset: top(state).offset + conf.indentUnit,
                         type: "py",
                         align: null})
    }

    function pushBracketScope(stream, state, type) {
      var align = stream.match(/^[\s\[\{\(]*(?:#|$)/, false) ? null : stream.column() + 1
      state.scopes.push({offset: state.indent + hangingIndent,
                         type: type,
                         align: align})
    }

    function dedent(stream, state) {
      var indented = stream.indentation();
      while (state.scopes.length > 1 && top(state).offset > indented) {
        if (top(state).type != "py") return true;
        state.scopes.pop();
      }
      return top(state).offset != indented;
    }

    function tokenLexer(stream, state) {
      if (stream.sol()) {
        state.beginningOfLine = true;
        state.dedent = false;
      }

      var style = state.tokenize(stream, state);
      var current = stream.current();

      // Handle decorators
      if (state.beginningOfLine && current == "@")
        return stream.match(identifiers, false) ? "meta" : py3 ? "operator" : ERRORCLASS;

      if (/\S/.test(current)) state.beginningOfLine = false;

      if ((style == "variable" || style == "builtin")
          && state.lastToken == "meta")
        style = "meta";

      // Handle scope changes.
      if (current == "pass" || current == "return")
        state.dedent = true;

      if (current == "lambda") state.lambda = true;
      if (current == ":" && !state.lambda && top(state).type == "py" && stream.match(/^\s*(?:#|$)/, false))
        pushPyScope(state);

      if (current.length == 1 && !/string|comment/.test(style)) {
        var delimiter_index = "[({".indexOf(current);
        if (delimiter_index != -1)
          pushBracketScope(stream, state, "])}".slice(delimiter_index, delimiter_index+1));

        delimiter_index = "])}".indexOf(current);
        if (delimiter_index != -1) {
          if (top(state).type == current) state.indent = state.scopes.pop().offset - hangingIndent
          else return ERRORCLASS;
        }
      }
      if (state.dedent && stream.eol() && top(state).type == "py" && state.scopes.length > 1)
        state.scopes.pop();

      return style;
    }

    var external = {
      startState: function(basecolumn) {
        return {
          tokenize: tokenBase,
          scopes: [{offset: basecolumn || 0, type: "py", align: null}],
          indent: basecolumn || 0,
          lastToken: null,
          lambda: false,
          dedent: 0
        };
      },

      token: function(stream, state) {
        var addErr = state.errorToken;
        if (addErr) state.errorToken = false;
        var style = tokenLexer(stream, state);

        if (style && style != "comment")
          state.lastToken = (style == "keyword" || style == "punctuation") ? stream.current() : style;
        if (style == "punctuation") style = null;

        if (stream.eol() && state.lambda)
          state.lambda = false;
        return addErr ? style + " " + ERRORCLASS : style;
      },

      indent: function(state, textAfter) {
        if (state.tokenize != tokenBase)
          return state.tokenize.isString ? CodeMirror.Pass : 0;

        var scope = top(state)
        var closing = scope.type == textAfter.charAt(0) ||
            scope.type == "py" && !state.dedent && /^(else:|elif |except |finally:)/.test(textAfter)
        if (scope.align != null)
          return scope.align - (closing ? 1 : 0)
        else
          return scope.offset - (closing ? hangingIndent : 0)
      },

      electricInput: /^\s*([\}\]\)]|else:|elif |except |finally:)$/,
      closeBrackets: {triples: "'\""},
      lineComment: "#",
      fold: "indent"
    };
    return external;
  });

  CodeMirror.defineMIME("text/x-python", "python");

  var words = function(str) { return str.split(" "); };

  CodeMirror.defineMIME("text/x-cython", {
    name: "python",
    extra_keywords: words("by cdef cimport cpdef ctypedef enum except "+
                          "extern gil include nogil property public "+
                          "readonly struct union DEF IF ELIF ELSE")
  });

});


/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/codemirror/mode/r/r.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/codemirror/mode/r/r.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __unused_webpack_exports, __webpack_require__) => {

// CodeMirror, copyright (c) by Marijn Haverbeke and others
// Distributed under an MIT license: https://codemirror.net/LICENSE

(function(mod) {
  if (true) // CommonJS
    mod(__webpack_require__(/*! ../../lib/codemirror */ "../../node_modules/@elyra/canvas/node_modules/codemirror/lib/codemirror.js"));
  else {}
})(function(CodeMirror) {
"use strict";

CodeMirror.registerHelper("wordChars", "r", /[\w.]/);

CodeMirror.defineMode("r", function(config) {
  function wordObj(words) {
    var res = {};
    for (var i = 0; i < words.length; ++i) res[words[i]] = true;
    return res;
  }
  var commonAtoms = ["NULL", "NA", "Inf", "NaN", "NA_integer_", "NA_real_", "NA_complex_", "NA_character_", "TRUE", "FALSE"];
  var commonBuiltins = ["list", "quote", "bquote", "eval", "return", "call", "parse", "deparse"];
  var commonKeywords = ["if", "else", "repeat", "while", "function", "for", "in", "next", "break"];
  var commonBlockKeywords = ["if", "else", "repeat", "while", "function", "for"];

  CodeMirror.registerHelper("hintWords", "r", commonAtoms.concat(commonBuiltins, commonKeywords));

  var atoms = wordObj(commonAtoms);
  var builtins = wordObj(commonBuiltins);
  var keywords = wordObj(commonKeywords);
  var blockkeywords = wordObj(commonBlockKeywords);
  var opChars = /[+\-*\/^<>=!&|~$:]/;
  var curPunc;

  function tokenBase(stream, state) {
    curPunc = null;
    var ch = stream.next();
    if (ch == "#") {
      stream.skipToEnd();
      return "comment";
    } else if (ch == "0" && stream.eat("x")) {
      stream.eatWhile(/[\da-f]/i);
      return "number";
    } else if (ch == "." && stream.eat(/\d/)) {
      stream.match(/\d*(?:e[+\-]?\d+)?/);
      return "number";
    } else if (/\d/.test(ch)) {
      stream.match(/\d*(?:\.\d+)?(?:e[+\-]\d+)?L?/);
      return "number";
    } else if (ch == "'" || ch == '"') {
      state.tokenize = tokenString(ch);
      return "string";
    } else if (ch == "`") {
      stream.match(/[^`]+`/);
      return "variable-3";
    } else if (ch == "." && stream.match(/.(?:[.]|\d+)/)) {
      return "keyword";
    } else if (/[a-zA-Z\.]/.test(ch)) {
      stream.eatWhile(/[\w\.]/);
      var word = stream.current();
      if (atoms.propertyIsEnumerable(word)) return "atom";
      if (keywords.propertyIsEnumerable(word)) {
        // Block keywords start new blocks, except 'else if', which only starts
        // one new block for the 'if', no block for the 'else'.
        if (blockkeywords.propertyIsEnumerable(word) &&
            !stream.match(/\s*if(\s+|$)/, false))
          curPunc = "block";
        return "keyword";
      }
      if (builtins.propertyIsEnumerable(word)) return "builtin";
      return "variable";
    } else if (ch == "%") {
      if (stream.skipTo("%")) stream.next();
      return "operator variable-2";
    } else if (
        (ch == "<" && stream.eat("-")) ||
        (ch == "<" && stream.match("<-")) ||
        (ch == "-" && stream.match(/>>?/))
      ) {
      return "operator arrow";
    } else if (ch == "=" && state.ctx.argList) {
      return "arg-is";
    } else if (opChars.test(ch)) {
      if (ch == "$") return "operator dollar";
      stream.eatWhile(opChars);
      return "operator";
    } else if (/[\(\){}\[\];]/.test(ch)) {
      curPunc = ch;
      if (ch == ";") return "semi";
      return null;
    } else {
      return null;
    }
  }

  function tokenString(quote) {
    return function(stream, state) {
      if (stream.eat("\\")) {
        var ch = stream.next();
        if (ch == "x") stream.match(/^[a-f0-9]{2}/i);
        else if ((ch == "u" || ch == "U") && stream.eat("{") && stream.skipTo("}")) stream.next();
        else if (ch == "u") stream.match(/^[a-f0-9]{4}/i);
        else if (ch == "U") stream.match(/^[a-f0-9]{8}/i);
        else if (/[0-7]/.test(ch)) stream.match(/^[0-7]{1,2}/);
        return "string-2";
      } else {
        var next;
        while ((next = stream.next()) != null) {
          if (next == quote) { state.tokenize = tokenBase; break; }
          if (next == "\\") { stream.backUp(1); break; }
        }
        return "string";
      }
    };
  }

  var ALIGN_YES = 1, ALIGN_NO = 2, BRACELESS = 4

  function push(state, type, stream) {
    state.ctx = {type: type,
                 indent: state.indent,
                 flags: 0,
                 column: stream.column(),
                 prev: state.ctx};
  }
  function setFlag(state, flag) {
    var ctx = state.ctx
    state.ctx = {type: ctx.type,
                 indent: ctx.indent,
                 flags: ctx.flags | flag,
                 column: ctx.column,
                 prev: ctx.prev}
  }
  function pop(state) {
    state.indent = state.ctx.indent;
    state.ctx = state.ctx.prev;
  }

  return {
    startState: function() {
      return {tokenize: tokenBase,
              ctx: {type: "top",
                    indent: -config.indentUnit,
                    flags: ALIGN_NO},
              indent: 0,
              afterIdent: false};
    },

    token: function(stream, state) {
      if (stream.sol()) {
        if ((state.ctx.flags & 3) == 0) state.ctx.flags |= ALIGN_NO
        if (state.ctx.flags & BRACELESS) pop(state)
        state.indent = stream.indentation();
      }
      if (stream.eatSpace()) return null;
      var style = state.tokenize(stream, state);
      if (style != "comment" && (state.ctx.flags & ALIGN_NO) == 0) setFlag(state, ALIGN_YES)

      if ((curPunc == ";" || curPunc == "{" || curPunc == "}") && state.ctx.type == "block") pop(state);
      if (curPunc == "{") push(state, "}", stream);
      else if (curPunc == "(") {
        push(state, ")", stream);
        if (state.afterIdent) state.ctx.argList = true;
      }
      else if (curPunc == "[") push(state, "]", stream);
      else if (curPunc == "block") push(state, "block", stream);
      else if (curPunc == state.ctx.type) pop(state);
      else if (state.ctx.type == "block" && style != "comment") setFlag(state, BRACELESS)
      state.afterIdent = style == "variable" || style == "keyword";
      return style;
    },

    indent: function(state, textAfter) {
      if (state.tokenize != tokenBase) return 0;
      var firstChar = textAfter && textAfter.charAt(0), ctx = state.ctx,
          closing = firstChar == ctx.type;
      if (ctx.flags & BRACELESS) ctx = ctx.prev
      if (ctx.type == "block") return ctx.indent + (firstChar == "{" ? 0 : config.indentUnit);
      else if (ctx.flags & ALIGN_YES) return ctx.column + (closing ? 0 : 1);
      else return ctx.indent + (closing ? 0 : config.indentUnit);
    },

    lineComment: "#"
  };
});

CodeMirror.defineMIME("text/x-rsrc", "r");

});


/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/codemirror/mode/sql/sql.js":
/*!********************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/codemirror/mode/sql/sql.js ***!
  \********************************************************************************/
/***/ ((__unused_webpack_module, __unused_webpack_exports, __webpack_require__) => {

// CodeMirror, copyright (c) by Marijn Haverbeke and others
// Distributed under an MIT license: https://codemirror.net/LICENSE

(function(mod) {
  if (true) // CommonJS
    mod(__webpack_require__(/*! ../../lib/codemirror */ "../../node_modules/@elyra/canvas/node_modules/codemirror/lib/codemirror.js"));
  else {}
})(function(CodeMirror) {
"use strict";

CodeMirror.defineMode("sql", function(config, parserConfig) {
  var client         = parserConfig.client || {},
      atoms          = parserConfig.atoms || {"false": true, "true": true, "null": true},
      builtin        = parserConfig.builtin || set(defaultBuiltin),
      keywords       = parserConfig.keywords || set(sqlKeywords),
      operatorChars  = parserConfig.operatorChars || /^[*+\-%<>!=&|~^\/]/,
      support        = parserConfig.support || {},
      hooks          = parserConfig.hooks || {},
      dateSQL        = parserConfig.dateSQL || {"date" : true, "time" : true, "timestamp" : true},
      backslashStringEscapes = parserConfig.backslashStringEscapes !== false,
      brackets       = parserConfig.brackets || /^[\{}\(\)\[\]]/,
      punctuation    = parserConfig.punctuation || /^[;.,:]/

  function tokenBase(stream, state) {
    var ch = stream.next();

    // call hooks from the mime type
    if (hooks[ch]) {
      var result = hooks[ch](stream, state);
      if (result !== false) return result;
    }

    if (support.hexNumber &&
      ((ch == "0" && stream.match(/^[xX][0-9a-fA-F]+/))
      || (ch == "x" || ch == "X") && stream.match(/^'[0-9a-fA-F]+'/))) {
      // hex
      // ref: http://dev.mysql.com/doc/refman/5.5/en/hexadecimal-literals.html
      return "number";
    } else if (support.binaryNumber &&
      (((ch == "b" || ch == "B") && stream.match(/^'[01]+'/))
      || (ch == "0" && stream.match(/^b[01]+/)))) {
      // bitstring
      // ref: http://dev.mysql.com/doc/refman/5.5/en/bit-field-literals.html
      return "number";
    } else if (ch.charCodeAt(0) > 47 && ch.charCodeAt(0) < 58) {
      // numbers
      // ref: http://dev.mysql.com/doc/refman/5.5/en/number-literals.html
      stream.match(/^[0-9]*(\.[0-9]+)?([eE][-+]?[0-9]+)?/);
      support.decimallessFloat && stream.match(/^\.(?!\.)/);
      return "number";
    } else if (ch == "?" && (stream.eatSpace() || stream.eol() || stream.eat(";"))) {
      // placeholders
      return "variable-3";
    } else if (ch == "'" || (ch == '"' && support.doubleQuote)) {
      // strings
      // ref: http://dev.mysql.com/doc/refman/5.5/en/string-literals.html
      state.tokenize = tokenLiteral(ch);
      return state.tokenize(stream, state);
    } else if ((((support.nCharCast && (ch == "n" || ch == "N"))
        || (support.charsetCast && ch == "_" && stream.match(/[a-z][a-z0-9]*/i)))
        && (stream.peek() == "'" || stream.peek() == '"'))) {
      // charset casting: _utf8'str', N'str', n'str'
      // ref: http://dev.mysql.com/doc/refman/5.5/en/string-literals.html
      return "keyword";
    } else if (support.escapeConstant && (ch == "e" || ch == "E")
        && (stream.peek() == "'" || (stream.peek() == '"' && support.doubleQuote))) {
      // escape constant: E'str', e'str'
      // ref: https://www.postgresql.org/docs/current/sql-syntax-lexical.html#SQL-SYNTAX-STRINGS-ESCAPE
      state.tokenize = function(stream, state) {
        return (state.tokenize = tokenLiteral(stream.next(), true))(stream, state);
      }
      return "keyword";
    } else if (support.commentSlashSlash && ch == "/" && stream.eat("/")) {
      // 1-line comment
      stream.skipToEnd();
      return "comment";
    } else if ((support.commentHash && ch == "#")
        || (ch == "-" && stream.eat("-") && (!support.commentSpaceRequired || stream.eat(" ")))) {
      // 1-line comments
      // ref: https://kb.askmonty.org/en/comment-syntax/
      stream.skipToEnd();
      return "comment";
    } else if (ch == "/" && stream.eat("*")) {
      // multi-line comments
      // ref: https://kb.askmonty.org/en/comment-syntax/
      state.tokenize = tokenComment(1);
      return state.tokenize(stream, state);
    } else if (ch == ".") {
      // .1 for 0.1
      if (support.zerolessFloat && stream.match(/^(?:\d+(?:e[+-]?\d+)?)/i))
        return "number";
      if (stream.match(/^\.+/))
        return null
      // .table_name (ODBC)
      // // ref: http://dev.mysql.com/doc/refman/5.6/en/identifier-qualifiers.html
      if (support.ODBCdotTable && stream.match(/^[\w\d_$#]+/))
        return "variable-2";
    } else if (operatorChars.test(ch)) {
      // operators
      stream.eatWhile(operatorChars);
      return "operator";
    } else if (brackets.test(ch)) {
      // brackets
      return "bracket";
    } else if (punctuation.test(ch)) {
      // punctuation
      stream.eatWhile(punctuation);
      return "punctuation";
    } else if (ch == '{' &&
        (stream.match(/^( )*(d|D|t|T|ts|TS)( )*'[^']*'( )*}/) || stream.match(/^( )*(d|D|t|T|ts|TS)( )*"[^"]*"( )*}/))) {
      // dates (weird ODBC syntax)
      // ref: http://dev.mysql.com/doc/refman/5.5/en/date-and-time-literals.html
      return "number";
    } else {
      stream.eatWhile(/^[_\w\d]/);
      var word = stream.current().toLowerCase();
      // dates (standard SQL syntax)
      // ref: http://dev.mysql.com/doc/refman/5.5/en/date-and-time-literals.html
      if (dateSQL.hasOwnProperty(word) && (stream.match(/^( )+'[^']*'/) || stream.match(/^( )+"[^"]*"/)))
        return "number";
      if (atoms.hasOwnProperty(word)) return "atom";
      if (builtin.hasOwnProperty(word)) return "type";
      if (keywords.hasOwnProperty(word)) return "keyword";
      if (client.hasOwnProperty(word)) return "builtin";
      return null;
    }
  }

  // 'string', with char specified in quote escaped by '\'
  function tokenLiteral(quote, backslashEscapes) {
    return function(stream, state) {
      var escaped = false, ch;
      while ((ch = stream.next()) != null) {
        if (ch == quote && !escaped) {
          state.tokenize = tokenBase;
          break;
        }
        escaped = (backslashStringEscapes || backslashEscapes) && !escaped && ch == "\\";
      }
      return "string";
    };
  }
  function tokenComment(depth) {
    return function(stream, state) {
      var m = stream.match(/^.*?(\/\*|\*\/)/)
      if (!m) stream.skipToEnd()
      else if (m[1] == "/*") state.tokenize = tokenComment(depth + 1)
      else if (depth > 1) state.tokenize = tokenComment(depth - 1)
      else state.tokenize = tokenBase
      return "comment"
    }
  }

  function pushContext(stream, state, type) {
    state.context = {
      prev: state.context,
      indent: stream.indentation(),
      col: stream.column(),
      type: type
    };
  }

  function popContext(state) {
    state.indent = state.context.indent;
    state.context = state.context.prev;
  }

  return {
    startState: function() {
      return {tokenize: tokenBase, context: null};
    },

    token: function(stream, state) {
      if (stream.sol()) {
        if (state.context && state.context.align == null)
          state.context.align = false;
      }
      if (state.tokenize == tokenBase && stream.eatSpace()) return null;

      var style = state.tokenize(stream, state);
      if (style == "comment") return style;

      if (state.context && state.context.align == null)
        state.context.align = true;

      var tok = stream.current();
      if (tok == "(")
        pushContext(stream, state, ")");
      else if (tok == "[")
        pushContext(stream, state, "]");
      else if (state.context && state.context.type == tok)
        popContext(state);
      return style;
    },

    indent: function(state, textAfter) {
      var cx = state.context;
      if (!cx) return CodeMirror.Pass;
      var closing = textAfter.charAt(0) == cx.type;
      if (cx.align) return cx.col + (closing ? 0 : 1);
      else return cx.indent + (closing ? 0 : config.indentUnit);
    },

    blockCommentStart: "/*",
    blockCommentEnd: "*/",
    lineComment: support.commentSlashSlash ? "//" : support.commentHash ? "#" : "--",
    closeBrackets: "()[]{}''\"\"``"
  };
});

  // `identifier`
  function hookIdentifier(stream) {
    // MySQL/MariaDB identifiers
    // ref: http://dev.mysql.com/doc/refman/5.6/en/identifier-qualifiers.html
    var ch;
    while ((ch = stream.next()) != null) {
      if (ch == "`" && !stream.eat("`")) return "variable-2";
    }
    stream.backUp(stream.current().length - 1);
    return stream.eatWhile(/\w/) ? "variable-2" : null;
  }

  // "identifier"
  function hookIdentifierDoublequote(stream) {
    // Standard SQL /SQLite identifiers
    // ref: http://web.archive.org/web/20160813185132/http://savage.net.au/SQL/sql-99.bnf.html#delimited%20identifier
    // ref: http://sqlite.org/lang_keywords.html
    var ch;
    while ((ch = stream.next()) != null) {
      if (ch == "\"" && !stream.eat("\"")) return "variable-2";
    }
    stream.backUp(stream.current().length - 1);
    return stream.eatWhile(/\w/) ? "variable-2" : null;
  }

  // variable token
  function hookVar(stream) {
    // variables
    // @@prefix.varName @varName
    // varName can be quoted with ` or ' or "
    // ref: http://dev.mysql.com/doc/refman/5.5/en/user-variables.html
    if (stream.eat("@")) {
      stream.match('session.');
      stream.match('local.');
      stream.match('global.');
    }

    if (stream.eat("'")) {
      stream.match(/^.*'/);
      return "variable-2";
    } else if (stream.eat('"')) {
      stream.match(/^.*"/);
      return "variable-2";
    } else if (stream.eat("`")) {
      stream.match(/^.*`/);
      return "variable-2";
    } else if (stream.match(/^[0-9a-zA-Z$\.\_]+/)) {
      return "variable-2";
    }
    return null;
  };

  // short client keyword token
  function hookClient(stream) {
    // \N means NULL
    // ref: http://dev.mysql.com/doc/refman/5.5/en/null-values.html
    if (stream.eat("N")) {
        return "atom";
    }
    // \g, etc
    // ref: http://dev.mysql.com/doc/refman/5.5/en/mysql-commands.html
    return stream.match(/^[a-zA-Z.#!?]/) ? "variable-2" : null;
  }

  // these keywords are used by all SQL dialects (however, a mode can still overwrite it)
  var sqlKeywords = "alter and as asc between by count create delete desc distinct drop from group having in insert into is join like not on or order select set table union update values where limit ";

  // turn a space-separated list into an array
  function set(str) {
    var obj = {}, words = str.split(" ");
    for (var i = 0; i < words.length; ++i) obj[words[i]] = true;
    return obj;
  }

  var defaultBuiltin = "bool boolean bit blob enum long longblob longtext medium mediumblob mediumint mediumtext time timestamp tinyblob tinyint tinytext text bigint int int1 int2 int3 int4 int8 integer float float4 float8 double char varbinary varchar varcharacter precision real date datetime year unsigned signed decimal numeric"

  // A generic SQL Mode. It's not a standard, it just try to support what is generally supported
  CodeMirror.defineMIME("text/x-sql", {
    name: "sql",
    keywords: set(sqlKeywords + "begin"),
    builtin: set(defaultBuiltin),
    atoms: set("false true null unknown"),
    dateSQL: set("date time timestamp"),
    support: set("ODBCdotTable doubleQuote binaryNumber hexNumber")
  });

  CodeMirror.defineMIME("text/x-mssql", {
    name: "sql",
    client: set("$partition binary_checksum checksum connectionproperty context_info current_request_id error_line error_message error_number error_procedure error_severity error_state formatmessage get_filestream_transaction_context getansinull host_id host_name isnull isnumeric min_active_rowversion newid newsequentialid rowcount_big xact_state object_id"),
    keywords: set(sqlKeywords + "begin trigger proc view index for add constraint key primary foreign collate clustered nonclustered declare exec go if use index holdlock nolock nowait paglock readcommitted readcommittedlock readpast readuncommitted repeatableread rowlock serializable snapshot tablock tablockx updlock with"),
    builtin: set("bigint numeric bit smallint decimal smallmoney int tinyint money float real char varchar text nchar nvarchar ntext binary varbinary image cursor timestamp hierarchyid uniqueidentifier sql_variant xml table "),
    atoms: set("is not null like and or in left right between inner outer join all any some cross unpivot pivot exists"),
    operatorChars: /^[*+\-%<>!=^\&|\/]/,
    brackets: /^[\{}\(\)]/,
    punctuation: /^[;.,:/]/,
    backslashStringEscapes: false,
    dateSQL: set("date datetimeoffset datetime2 smalldatetime datetime time"),
    hooks: {
      "@":   hookVar
    }
  });

  CodeMirror.defineMIME("text/x-mysql", {
    name: "sql",
    client: set("charset clear connect edit ego exit go help nopager notee nowarning pager print prompt quit rehash source status system tee"),
    keywords: set(sqlKeywords + "accessible action add after algorithm all analyze asensitive at authors auto_increment autocommit avg avg_row_length before binary binlog both btree cache call cascade cascaded case catalog_name chain change changed character check checkpoint checksum class_origin client_statistics close coalesce code collate collation collations column columns comment commit committed completion concurrent condition connection consistent constraint contains continue contributors convert cross current current_date current_time current_timestamp current_user cursor data database databases day_hour day_microsecond day_minute day_second deallocate dec declare default delay_key_write delayed delimiter des_key_file describe deterministic dev_pop dev_samp deviance diagnostics directory disable discard distinctrow div dual dumpfile each elseif enable enclosed end ends engine engines enum errors escape escaped even event events every execute exists exit explain extended fast fetch field fields first flush for force foreign found_rows full fulltext function general get global grant grants group group_concat handler hash help high_priority hosts hour_microsecond hour_minute hour_second if ignore ignore_server_ids import index index_statistics infile inner innodb inout insensitive insert_method install interval invoker isolation iterate key keys kill language last leading leave left level limit linear lines list load local localtime localtimestamp lock logs low_priority master master_heartbeat_period master_ssl_verify_server_cert masters match max max_rows maxvalue message_text middleint migrate min min_rows minute_microsecond minute_second mod mode modifies modify mutex mysql_errno natural next no no_write_to_binlog offline offset one online open optimize option optionally out outer outfile pack_keys parser partition partitions password phase plugin plugins prepare preserve prev primary privileges procedure processlist profile profiles purge query quick range read read_write reads real rebuild recover references regexp relaylog release remove rename reorganize repair repeatable replace require resignal restrict resume return returns revoke right rlike rollback rollup row row_format rtree savepoint schedule schema schema_name schemas second_microsecond security sensitive separator serializable server session share show signal slave slow smallint snapshot soname spatial specific sql sql_big_result sql_buffer_result sql_cache sql_calc_found_rows sql_no_cache sql_small_result sqlexception sqlstate sqlwarning ssl start starting starts status std stddev stddev_pop stddev_samp storage straight_join subclass_origin sum suspend table_name table_statistics tables tablespace temporary terminated to trailing transaction trigger triggers truncate uncommitted undo uninstall unique unlock upgrade usage use use_frm user user_resources user_statistics using utc_date utc_time utc_timestamp value variables varying view views warnings when while with work write xa xor year_month zerofill begin do then else loop repeat"),
    builtin: set("bool boolean bit blob decimal double float long longblob longtext medium mediumblob mediumint mediumtext time timestamp tinyblob tinyint tinytext text bigint int int1 int2 int3 int4 int8 integer float float4 float8 double char varbinary varchar varcharacter precision date datetime year unsigned signed numeric"),
    atoms: set("false true null unknown"),
    operatorChars: /^[*+\-%<>!=&|^]/,
    dateSQL: set("date time timestamp"),
    support: set("ODBCdotTable decimallessFloat zerolessFloat binaryNumber hexNumber doubleQuote nCharCast charsetCast commentHash commentSpaceRequired"),
    hooks: {
      "@":   hookVar,
      "`":   hookIdentifier,
      "\\":  hookClient
    }
  });

  CodeMirror.defineMIME("text/x-mariadb", {
    name: "sql",
    client: set("charset clear connect edit ego exit go help nopager notee nowarning pager print prompt quit rehash source status system tee"),
    keywords: set(sqlKeywords + "accessible action add after algorithm all always analyze asensitive at authors auto_increment autocommit avg avg_row_length before binary binlog both btree cache call cascade cascaded case catalog_name chain change changed character check checkpoint checksum class_origin client_statistics close coalesce code collate collation collations column columns comment commit committed completion concurrent condition connection consistent constraint contains continue contributors convert cross current current_date current_time current_timestamp current_user cursor data database databases day_hour day_microsecond day_minute day_second deallocate dec declare default delay_key_write delayed delimiter des_key_file describe deterministic dev_pop dev_samp deviance diagnostics directory disable discard distinctrow div dual dumpfile each elseif enable enclosed end ends engine engines enum errors escape escaped even event events every execute exists exit explain extended fast fetch field fields first flush for force foreign found_rows full fulltext function general generated get global grant grants group group_concat handler hard hash help high_priority hosts hour_microsecond hour_minute hour_second if ignore ignore_server_ids import index index_statistics infile inner innodb inout insensitive insert_method install interval invoker isolation iterate key keys kill language last leading leave left level limit linear lines list load local localtime localtimestamp lock logs low_priority master master_heartbeat_period master_ssl_verify_server_cert masters match max max_rows maxvalue message_text middleint migrate min min_rows minute_microsecond minute_second mod mode modifies modify mutex mysql_errno natural next no no_write_to_binlog offline offset one online open optimize option optionally out outer outfile pack_keys parser partition partitions password persistent phase plugin plugins prepare preserve prev primary privileges procedure processlist profile profiles purge query quick range read read_write reads real rebuild recover references regexp relaylog release remove rename reorganize repair repeatable replace require resignal restrict resume return returns revoke right rlike rollback rollup row row_format rtree savepoint schedule schema schema_name schemas second_microsecond security sensitive separator serializable server session share show shutdown signal slave slow smallint snapshot soft soname spatial specific sql sql_big_result sql_buffer_result sql_cache sql_calc_found_rows sql_no_cache sql_small_result sqlexception sqlstate sqlwarning ssl start starting starts status std stddev stddev_pop stddev_samp storage straight_join subclass_origin sum suspend table_name table_statistics tables tablespace temporary terminated to trailing transaction trigger triggers truncate uncommitted undo uninstall unique unlock upgrade usage use use_frm user user_resources user_statistics using utc_date utc_time utc_timestamp value variables varying view views virtual warnings when while with work write xa xor year_month zerofill begin do then else loop repeat"),
    builtin: set("bool boolean bit blob decimal double float long longblob longtext medium mediumblob mediumint mediumtext time timestamp tinyblob tinyint tinytext text bigint int int1 int2 int3 int4 int8 integer float float4 float8 double char varbinary varchar varcharacter precision date datetime year unsigned signed numeric"),
    atoms: set("false true null unknown"),
    operatorChars: /^[*+\-%<>!=&|^]/,
    dateSQL: set("date time timestamp"),
    support: set("ODBCdotTable decimallessFloat zerolessFloat binaryNumber hexNumber doubleQuote nCharCast charsetCast commentHash commentSpaceRequired"),
    hooks: {
      "@":   hookVar,
      "`":   hookIdentifier,
      "\\":  hookClient
    }
  });

  // provided by the phpLiteAdmin project - phpliteadmin.org
  CodeMirror.defineMIME("text/x-sqlite", {
    name: "sql",
    // commands of the official SQLite client, ref: https://www.sqlite.org/cli.html#dotcmd
    client: set("auth backup bail binary changes check clone databases dbinfo dump echo eqp exit explain fullschema headers help import imposter indexes iotrace limit lint load log mode nullvalue once open output print prompt quit read restore save scanstats schema separator session shell show stats system tables testcase timeout timer trace vfsinfo vfslist vfsname width"),
    // ref: http://sqlite.org/lang_keywords.html
    keywords: set(sqlKeywords + "abort action add after all analyze attach autoincrement before begin cascade case cast check collate column commit conflict constraint cross current_date current_time current_timestamp database default deferrable deferred detach each else end escape except exclusive exists explain fail for foreign full glob if ignore immediate index indexed initially inner instead intersect isnull key left limit match natural no notnull null of offset outer plan pragma primary query raise recursive references regexp reindex release rename replace restrict right rollback row savepoint temp temporary then to transaction trigger unique using vacuum view virtual when with without"),
    // SQLite is weakly typed, ref: http://sqlite.org/datatype3.html. This is just a list of some common types.
    builtin: set("bool boolean bit blob decimal double float long longblob longtext medium mediumblob mediumint mediumtext time timestamp tinyblob tinyint tinytext text clob bigint int int2 int8 integer float double char varchar date datetime year unsigned signed numeric real"),
    // ref: http://sqlite.org/syntax/literal-value.html
    atoms: set("null current_date current_time current_timestamp"),
    // ref: http://sqlite.org/lang_expr.html#binaryops
    operatorChars: /^[*+\-%<>!=&|/~]/,
    // SQLite is weakly typed, ref: http://sqlite.org/datatype3.html. This is just a list of some common types.
    dateSQL: set("date time timestamp datetime"),
    support: set("decimallessFloat zerolessFloat"),
    identifierQuote: "\"",  //ref: http://sqlite.org/lang_keywords.html
    hooks: {
      // bind-parameters ref:http://sqlite.org/lang_expr.html#varparam
      "@":   hookVar,
      ":":   hookVar,
      "?":   hookVar,
      "$":   hookVar,
      // The preferred way to escape Identifiers is using double quotes, ref: http://sqlite.org/lang_keywords.html
      "\"":   hookIdentifierDoublequote,
      // there is also support for backticks, ref: http://sqlite.org/lang_keywords.html
      "`":   hookIdentifier
    }
  });

  // the query language used by Apache Cassandra is called CQL, but this mime type
  // is called Cassandra to avoid confusion with Contextual Query Language
  CodeMirror.defineMIME("text/x-cassandra", {
    name: "sql",
    client: { },
    keywords: set("add all allow alter and any apply as asc authorize batch begin by clustering columnfamily compact consistency count create custom delete desc distinct drop each_quorum exists filtering from grant if in index insert into key keyspace keyspaces level limit local_one local_quorum modify nan norecursive nosuperuser not of on one order password permission permissions primary quorum rename revoke schema select set storage superuser table three to token truncate ttl two type unlogged update use user users using values where with writetime"),
    builtin: set("ascii bigint blob boolean counter decimal double float frozen inet int list map static text timestamp timeuuid tuple uuid varchar varint"),
    atoms: set("false true infinity NaN"),
    operatorChars: /^[<>=]/,
    dateSQL: { },
    support: set("commentSlashSlash decimallessFloat"),
    hooks: { }
  });

  // this is based on Peter Raganitsch's 'plsql' mode
  CodeMirror.defineMIME("text/x-plsql", {
    name:       "sql",
    client:     set("appinfo arraysize autocommit autoprint autorecovery autotrace blockterminator break btitle cmdsep colsep compatibility compute concat copycommit copytypecheck define describe echo editfile embedded escape exec execute feedback flagger flush heading headsep instance linesize lno loboffset logsource long longchunksize markup native newpage numformat numwidth pagesize pause pno recsep recsepchar release repfooter repheader serveroutput shiftinout show showmode size spool sqlblanklines sqlcase sqlcode sqlcontinue sqlnumber sqlpluscompatibility sqlprefix sqlprompt sqlterminator suffix tab term termout time timing trimout trimspool ttitle underline verify version wrap"),
    keywords:   set("abort accept access add all alter and any array arraylen as asc assert assign at attributes audit authorization avg base_table begin between binary_integer body boolean by case cast char char_base check close cluster clusters colauth column comment commit compress connect connected constant constraint crash create current currval cursor data_base database date dba deallocate debugoff debugon decimal declare default definition delay delete desc digits dispose distinct do drop else elseif elsif enable end entry escape exception exception_init exchange exclusive exists exit external fast fetch file for force form from function generic goto grant group having identified if immediate in increment index indexes indicator initial initrans insert interface intersect into is key level library like limited local lock log logging long loop master maxextents maxtrans member minextents minus mislabel mode modify multiset new next no noaudit nocompress nologging noparallel not nowait number_base object of off offline on online only open option or order out package parallel partition pctfree pctincrease pctused pls_integer positive positiven pragma primary prior private privileges procedure public raise range raw read rebuild record ref references refresh release rename replace resource restrict return returning returns reverse revoke rollback row rowid rowlabel rownum rows run savepoint schema segment select separate session set share snapshot some space split sql start statement storage subtype successful synonym tabauth table tables tablespace task terminate then to trigger truncate type union unique unlimited unrecoverable unusable update use using validate value values variable view views when whenever where while with work"),
    builtin:    set("abs acos add_months ascii asin atan atan2 average bfile bfilename bigserial bit blob ceil character chartorowid chr clob concat convert cos cosh count dec decode deref dual dump dup_val_on_index empty error exp false float floor found glb greatest hextoraw initcap instr instrb int integer isopen last_day least length lengthb ln lower lpad ltrim lub make_ref max min mlslabel mod months_between natural naturaln nchar nclob new_time next_day nextval nls_charset_decl_len nls_charset_id nls_charset_name nls_initcap nls_lower nls_sort nls_upper nlssort no_data_found notfound null number numeric nvarchar2 nvl others power rawtohex real reftohex round rowcount rowidtochar rowtype rpad rtrim serial sign signtype sin sinh smallint soundex sqlcode sqlerrm sqrt stddev string substr substrb sum sysdate tan tanh to_char text to_date to_label to_multi_byte to_number to_single_byte translate true trunc uid unlogged upper user userenv varchar varchar2 variance varying vsize xml"),
    operatorChars: /^[*\/+\-%<>!=~]/,
    dateSQL:    set("date time timestamp"),
    support:    set("doubleQuote nCharCast zerolessFloat binaryNumber hexNumber")
  });

  // Created to support specific hive keywords
  CodeMirror.defineMIME("text/x-hive", {
    name: "sql",
    keywords: set("select alter $elem$ $key$ $value$ add after all analyze and archive as asc before between binary both bucket buckets by cascade case cast change cluster clustered clusterstatus collection column columns comment compute concatenate continue create cross cursor data database databases dbproperties deferred delete delimited desc describe directory disable distinct distribute drop else enable end escaped exclusive exists explain export extended external fetch fields fileformat first format formatted from full function functions grant group having hold_ddltime idxproperties if import in index indexes inpath inputdriver inputformat insert intersect into is items join keys lateral left like limit lines load local location lock locks mapjoin materialized minus msck no_drop nocompress not of offline on option or order out outer outputdriver outputformat overwrite partition partitioned partitions percent plus preserve procedure purge range rcfile read readonly reads rebuild recordreader recordwriter recover reduce regexp rename repair replace restrict revoke right rlike row schema schemas semi sequencefile serde serdeproperties set shared show show_database sort sorted ssl statistics stored streamtable table tables tablesample tblproperties temporary terminated textfile then tmp to touch transform trigger unarchive undo union uniquejoin unlock update use using utc utc_tmestamp view when where while with admin authorization char compact compactions conf cube current current_date current_timestamp day decimal defined dependency directories elem_type exchange file following for grouping hour ignore inner interval jar less logical macro minute month more none noscan over owner partialscan preceding pretty principals protection reload rewrite role roles rollup rows second server sets skewed transactions truncate unbounded unset uri user values window year"),
    builtin: set("bool boolean long timestamp tinyint smallint bigint int float double date datetime unsigned string array struct map uniontype key_type utctimestamp value_type varchar"),
    atoms: set("false true null unknown"),
    operatorChars: /^[*+\-%<>!=]/,
    dateSQL: set("date timestamp"),
    support: set("ODBCdotTable doubleQuote binaryNumber hexNumber")
  });

  CodeMirror.defineMIME("text/x-pgsql", {
    name: "sql",
    client: set("source"),
    // For PostgreSQL - https://www.postgresql.org/docs/11/sql-keywords-appendix.html
    // For pl/pgsql lang - https://github.com/postgres/postgres/blob/REL_11_2/src/pl/plpgsql/src/pl_scanner.c
    keywords: set(sqlKeywords + "a abort abs absent absolute access according action ada add admin after aggregate alias all allocate also alter always analyse analyze and any are array array_agg array_max_cardinality as asc asensitive assert assertion assignment asymmetric at atomic attach attribute attributes authorization avg backward base64 before begin begin_frame begin_partition bernoulli between bigint binary bit bit_length blob blocked bom boolean both breadth by c cache call called cardinality cascade cascaded case cast catalog catalog_name ceil ceiling chain char char_length character character_length character_set_catalog character_set_name character_set_schema characteristics characters check checkpoint class class_origin clob close cluster coalesce cobol collate collation collation_catalog collation_name collation_schema collect column column_name columns command_function command_function_code comment comments commit committed concurrently condition condition_number configuration conflict connect connection connection_name constant constraint constraint_catalog constraint_name constraint_schema constraints constructor contains content continue control conversion convert copy corr corresponding cost count covar_pop covar_samp create cross csv cube cume_dist current current_catalog current_date current_default_transform_group current_path current_role current_row current_schema current_time current_timestamp current_transform_group_for_type current_user cursor cursor_name cycle data database datalink datatype date datetime_interval_code datetime_interval_precision day db deallocate debug dec decimal declare default defaults deferrable deferred defined definer degree delete delimiter delimiters dense_rank depends depth deref derived desc describe descriptor detach detail deterministic diagnostics dictionary disable discard disconnect dispatch distinct dlnewcopy dlpreviouscopy dlurlcomplete dlurlcompleteonly dlurlcompletewrite dlurlpath dlurlpathonly dlurlpathwrite dlurlscheme dlurlserver dlvalue do document domain double drop dump dynamic dynamic_function dynamic_function_code each element else elseif elsif empty enable encoding encrypted end end_frame end_partition endexec enforced enum equals errcode error escape event every except exception exclude excluding exclusive exec execute exists exit exp explain expression extension external extract false family fetch file filter final first first_value flag float floor following for force foreach foreign fortran forward found frame_row free freeze from fs full function functions fusion g general generated get global go goto grant granted greatest group grouping groups handler having header hex hierarchy hint hold hour id identity if ignore ilike immediate immediately immutable implementation implicit import in include including increment indent index indexes indicator info inherit inherits initially inline inner inout input insensitive insert instance instantiable instead int integer integrity intersect intersection interval into invoker is isnull isolation join k key key_member key_type label lag language large last last_value lateral lead leading leakproof least left length level library like like_regex limit link listen ln load local localtime localtimestamp location locator lock locked log logged loop lower m map mapping match matched materialized max max_cardinality maxvalue member merge message message_length message_octet_length message_text method min minute minvalue mod mode modifies module month more move multiset mumps name names namespace national natural nchar nclob nesting new next nfc nfd nfkc nfkd nil no none normalize normalized not nothing notice notify notnull nowait nth_value ntile null nullable nullif nulls number numeric object occurrences_regex octet_length octets of off offset oids old on only open operator option options or order ordering ordinality others out outer output over overlaps overlay overriding owned owner p pad parallel parameter parameter_mode parameter_name parameter_ordinal_position parameter_specific_catalog parameter_specific_name parameter_specific_schema parser partial partition pascal passing passthrough password path percent percent_rank percentile_cont percentile_disc perform period permission pg_context pg_datatype_name pg_exception_context pg_exception_detail pg_exception_hint placing plans pli policy portion position position_regex power precedes preceding precision prepare prepared preserve primary print_strict_params prior privileges procedural procedure procedures program public publication query quote raise range rank read reads real reassign recheck recovery recursive ref references referencing refresh regr_avgx regr_avgy regr_count regr_intercept regr_r2 regr_slope regr_sxx regr_sxy regr_syy reindex relative release rename repeatable replace replica requiring reset respect restart restore restrict result result_oid return returned_cardinality returned_length returned_octet_length returned_sqlstate returning returns reverse revoke right role rollback rollup routine routine_catalog routine_name routine_schema routines row row_count row_number rows rowtype rule savepoint scale schema schema_name schemas scope scope_catalog scope_name scope_schema scroll search second section security select selective self sensitive sequence sequences serializable server server_name session session_user set setof sets share show similar simple size skip slice smallint snapshot some source space specific specific_name specifictype sql sqlcode sqlerror sqlexception sqlstate sqlwarning sqrt stable stacked standalone start state statement static statistics stddev_pop stddev_samp stdin stdout storage strict strip structure style subclass_origin submultiset subscription substring substring_regex succeeds sum symmetric sysid system system_time system_user t table table_name tables tablesample tablespace temp template temporary text then ties time timestamp timezone_hour timezone_minute to token top_level_count trailing transaction transaction_active transactions_committed transactions_rolled_back transform transforms translate translate_regex translation treat trigger trigger_catalog trigger_name trigger_schema trim trim_array true truncate trusted type types uescape unbounded uncommitted under unencrypted union unique unknown unlink unlisten unlogged unnamed unnest until untyped update upper uri usage use_column use_variable user user_defined_type_catalog user_defined_type_code user_defined_type_name user_defined_type_schema using vacuum valid validate validator value value_of values var_pop var_samp varbinary varchar variable_conflict variadic varying verbose version versioning view views volatile warning when whenever where while whitespace width_bucket window with within without work wrapper write xml xmlagg xmlattributes xmlbinary xmlcast xmlcomment xmlconcat xmldeclaration xmldocument xmlelement xmlexists xmlforest xmliterate xmlnamespaces xmlparse xmlpi xmlquery xmlroot xmlschema xmlserialize xmltable xmltext xmlvalidate year yes zone"),
    // https://www.postgresql.org/docs/11/datatype.html
    builtin: set("bigint int8 bigserial serial8 bit varying varbit boolean bool box bytea character char varchar cidr circle date double precision float8 inet integer int int4 interval json jsonb line lseg macaddr macaddr8 money numeric decimal path pg_lsn point polygon real float4 smallint int2 smallserial serial2 serial serial4 text time without zone with timetz timestamp timestamptz tsquery tsvector txid_snapshot uuid xml"),
    atoms: set("false true null unknown"),
    operatorChars: /^[*\/+\-%<>!=&|^\/#@?~]/,
    backslashStringEscapes: false,
    dateSQL: set("date time timestamp"),
    support: set("ODBCdotTable decimallessFloat zerolessFloat binaryNumber hexNumber nCharCast charsetCast escapeConstant")
  });

  // Google's SQL-like query language, GQL
  CodeMirror.defineMIME("text/x-gql", {
    name: "sql",
    keywords: set("ancestor and asc by contains desc descendant distinct from group has in is limit offset on order select superset where"),
    atoms: set("false true"),
    builtin: set("blob datetime first key __key__ string integer double boolean null"),
    operatorChars: /^[*+\-%<>!=]/
  });

  // Greenplum
  CodeMirror.defineMIME("text/x-gpsql", {
    name: "sql",
    client: set("source"),
    //https://github.com/greenplum-db/gpdb/blob/master/src/include/parser/kwlist.h
    keywords: set("abort absolute access action active add admin after aggregate all also alter always analyse analyze and any array as asc assertion assignment asymmetric at authorization backward before begin between bigint binary bit boolean both by cache called cascade cascaded case cast chain char character characteristics check checkpoint class close cluster coalesce codegen collate column comment commit committed concurrency concurrently configuration connection constraint constraints contains content continue conversion copy cost cpu_rate_limit create createdb createexttable createrole createuser cross csv cube current current_catalog current_date current_role current_schema current_time current_timestamp current_user cursor cycle data database day deallocate dec decimal declare decode default defaults deferrable deferred definer delete delimiter delimiters deny desc dictionary disable discard distinct distributed do document domain double drop dxl each else enable encoding encrypted end enum errors escape every except exchange exclude excluding exclusive execute exists explain extension external extract false family fetch fields filespace fill filter first float following for force foreign format forward freeze from full function global grant granted greatest group group_id grouping handler hash having header hold host hour identity if ignore ilike immediate immutable implicit in including inclusive increment index indexes inherit inherits initially inline inner inout input insensitive insert instead int integer intersect interval into invoker is isnull isolation join key language large last leading least left level like limit list listen load local localtime localtimestamp location lock log login mapping master match maxvalue median merge minute minvalue missing mode modifies modify month move name names national natural nchar new newline next no nocreatedb nocreateexttable nocreaterole nocreateuser noinherit nologin none noovercommit nosuperuser not nothing notify notnull nowait null nullif nulls numeric object of off offset oids old on only operator option options or order ordered others out outer over overcommit overlaps overlay owned owner parser partial partition partitions passing password percent percentile_cont percentile_disc placing plans position preceding precision prepare prepared preserve primary prior privileges procedural procedure protocol queue quote randomly range read readable reads real reassign recheck recursive ref references reindex reject relative release rename repeatable replace replica reset resource restart restrict returning returns revoke right role rollback rollup rootpartition row rows rule savepoint scatter schema scroll search second security segment select sequence serializable session session_user set setof sets share show similar simple smallint some split sql stable standalone start statement statistics stdin stdout storage strict strip subpartition subpartitions substring superuser symmetric sysid system table tablespace temp template temporary text then threshold ties time timestamp to trailing transaction treat trigger trim true truncate trusted type unbounded uncommitted unencrypted union unique unknown unlisten until update user using vacuum valid validation validator value values varchar variadic varying verbose version view volatile web when where whitespace window with within without work writable write xml xmlattributes xmlconcat xmlelement xmlexists xmlforest xmlparse xmlpi xmlroot xmlserialize year yes zone"),
    builtin: set("bigint int8 bigserial serial8 bit varying varbit boolean bool box bytea character char varchar cidr circle date double precision float float8 inet integer int int4 interval json jsonb line lseg macaddr macaddr8 money numeric decimal path pg_lsn point polygon real float4 smallint int2 smallserial serial2 serial serial4 text time without zone with timetz timestamp timestamptz tsquery tsvector txid_snapshot uuid xml"),
    atoms: set("false true null unknown"),
    operatorChars: /^[*+\-%<>!=&|^\/#@?~]/,
    dateSQL: set("date time timestamp"),
    support: set("ODBCdotTable decimallessFloat zerolessFloat binaryNumber hexNumber nCharCast charsetCast")
  });

  // Spark SQL
  CodeMirror.defineMIME("text/x-sparksql", {
    name: "sql",
    keywords: set("add after all alter analyze and anti archive array as asc at between bucket buckets by cache cascade case cast change clear cluster clustered codegen collection column columns comment commit compact compactions compute concatenate cost create cross cube current current_date current_timestamp database databases data dbproperties defined delete delimited deny desc describe dfs directories distinct distribute drop else end escaped except exchange exists explain export extended external false fields fileformat first following for format formatted from full function functions global grant group grouping having if ignore import in index indexes inner inpath inputformat insert intersect interval into is items join keys last lateral lazy left like limit lines list load local location lock locks logical macro map minus msck natural no not null nulls of on optimize option options or order out outer outputformat over overwrite partition partitioned partitions percent preceding principals purge range recordreader recordwriter recover reduce refresh regexp rename repair replace reset restrict revoke right rlike role roles rollback rollup row rows schema schemas select semi separated serde serdeproperties set sets show skewed sort sorted start statistics stored stratify struct table tables tablesample tblproperties temp temporary terminated then to touch transaction transactions transform true truncate unarchive unbounded uncache union unlock unset use using values view when where window with"),
    builtin: set("abs acos acosh add_months aggregate and any approx_count_distinct approx_percentile array array_contains array_distinct array_except array_intersect array_join array_max array_min array_position array_remove array_repeat array_sort array_union arrays_overlap arrays_zip ascii asin asinh assert_true atan atan2 atanh avg base64 between bigint bin binary bit_and bit_count bit_get bit_length bit_or bit_xor bool_and bool_or boolean bround btrim cardinality case cast cbrt ceil ceiling char char_length character_length chr coalesce collect_list collect_set concat concat_ws conv corr cos cosh cot count count_if count_min_sketch covar_pop covar_samp crc32 cume_dist current_catalog current_database current_date current_timestamp current_timezone current_user date date_add date_format date_from_unix_date date_part date_sub date_trunc datediff day dayofmonth dayofweek dayofyear decimal decode degrees delimited dense_rank div double e element_at elt encode every exists exp explode explode_outer expm1 extract factorial filter find_in_set first first_value flatten float floor forall format_number format_string from_csv from_json from_unixtime from_utc_timestamp get_json_object getbit greatest grouping grouping_id hash hex hour hypot if ifnull in initcap inline inline_outer input_file_block_length input_file_block_start input_file_name inputformat instr int isnan isnotnull isnull java_method json_array_length json_object_keys json_tuple kurtosis lag last last_day last_value lcase lead least left length levenshtein like ln locate log log10 log1p log2 lower lpad ltrim make_date make_dt_interval make_interval make_timestamp make_ym_interval map map_concat map_entries map_filter map_from_arrays map_from_entries map_keys map_values map_zip_with max max_by md5 mean min min_by minute mod monotonically_increasing_id month months_between named_struct nanvl negative next_day not now nth_value ntile nullif nvl nvl2 octet_length or outputformat overlay parse_url percent_rank percentile percentile_approx pi pmod posexplode posexplode_outer position positive pow power printf quarter radians raise_error rand randn random rank rcfile reflect regexp regexp_extract regexp_extract_all regexp_like regexp_replace repeat replace reverse right rint rlike round row_number rpad rtrim schema_of_csv schema_of_json second sentences sequence sequencefile serde session_window sha sha1 sha2 shiftleft shiftright shiftrightunsigned shuffle sign signum sin sinh size skewness slice smallint some sort_array soundex space spark_partition_id split sqrt stack std stddev stddev_pop stddev_samp str_to_map string struct substr substring substring_index sum tan tanh textfile timestamp timestamp_micros timestamp_millis timestamp_seconds tinyint to_csv to_date to_json to_timestamp to_unix_timestamp to_utc_timestamp transform transform_keys transform_values translate trim trunc try_add try_divide typeof ucase unbase64 unhex uniontype unix_date unix_micros unix_millis unix_seconds unix_timestamp upper uuid var_pop var_samp variance version weekday weekofyear when width_bucket window xpath xpath_boolean xpath_double xpath_float xpath_int xpath_long xpath_number xpath_short xpath_string xxhash64 year zip_with"),
    atoms: set("false true null"),
    operatorChars: /^[*\/+\-%<>!=~&|^]/,
    dateSQL: set("date time timestamp"),
    support: set("ODBCdotTable doubleQuote zerolessFloat")
  });

  // Esper
  CodeMirror.defineMIME("text/x-esper", {
    name: "sql",
    client: set("source"),
    // http://www.espertech.com/esper/release-5.5.0/esper-reference/html/appendix_keywords.html
    keywords: set("alter and as asc between by count create delete desc distinct drop from group having in insert into is join like not on or order select set table union update values where limit after all and as at asc avedev avg between by case cast coalesce count create current_timestamp day days delete define desc distinct else end escape events every exists false first from full group having hour hours in inner insert instanceof into irstream is istream join last lastweekday left limit like max match_recognize matches median measures metadatasql min minute minutes msec millisecond milliseconds not null offset on or order outer output partition pattern prev prior regexp retain-union retain-intersection right rstream sec second seconds select set some snapshot sql stddev sum then true unidirectional until update variable weekday when where window"),
    builtin: {},
    atoms: set("false true null"),
    operatorChars: /^[*+\-%<>!=&|^\/#@?~]/,
    dateSQL: set("time"),
    support: set("decimallessFloat zerolessFloat binaryNumber hexNumber")
  });
});

/*
  How Properties of Mime Types are used by SQL Mode
  =================================================

  keywords:
    A list of keywords you want to be highlighted.
  builtin:
    A list of builtin types you want to be highlighted (if you want types to be of class "builtin" instead of "keyword").
  operatorChars:
    All characters that must be handled as operators.
  client:
    Commands parsed and executed by the client (not the server).
  support:
    A list of supported syntaxes which are not common, but are supported by more than 1 DBMS.
    * ODBCdotTable: .tableName
    * zerolessFloat: .1
    * doubleQuote
    * nCharCast: N'string'
    * charsetCast: _utf8'string'
    * commentHash: use # char for comments
    * commentSlashSlash: use // for comments
    * commentSpaceRequired: require a space after -- for comments
  atoms:
    Keywords that must be highlighted as atoms,. Some DBMS's support more atoms than others:
    UNKNOWN, INFINITY, UNDERFLOW, NaN...
  dateSQL:
    Used for date/time SQL standard syntax, because not all DBMS's support same temporal types.
*/


/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/addLeadingZeros/index.js":
/*!************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/addLeadingZeros/index.js ***!
  \************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ addLeadingZeros)
/* harmony export */ });
function addLeadingZeros(number, targetLength) {
  var sign = number < 0 ? '-' : '';
  var output = Math.abs(number).toString();

  while (output.length < targetLength) {
    output = '0' + output;
  }

  return sign + output;
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/assign/index.js":
/*!***************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/assign/index.js ***!
  \***************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ assign)
/* harmony export */ });
function assign(target, dirtyObject) {
  if (target == null) {
    throw new TypeError('assign requires that input parameter not be null or undefined');
  }

  dirtyObject = dirtyObject || {};

  for (var property in dirtyObject) {
    if (Object.prototype.hasOwnProperty.call(dirtyObject, property)) {
      target[property] = dirtyObject[property];
    }
  }

  return target;
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/format/formatters/index.js":
/*!**************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/format/formatters/index.js ***!
  \**************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _lib_getUTCDayOfYear_index_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../../_lib/getUTCDayOfYear/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCDayOfYear/index.js");
/* harmony import */ var _lib_getUTCISOWeek_index_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../../_lib/getUTCISOWeek/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCISOWeek/index.js");
/* harmony import */ var _lib_getUTCISOWeekYear_index_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../../_lib/getUTCISOWeekYear/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCISOWeekYear/index.js");
/* harmony import */ var _lib_getUTCWeek_index_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../../_lib/getUTCWeek/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCWeek/index.js");
/* harmony import */ var _lib_getUTCWeekYear_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../_lib/getUTCWeekYear/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCWeekYear/index.js");
/* harmony import */ var _addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../addLeadingZeros/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/addLeadingZeros/index.js");
/* harmony import */ var _lightFormatters_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../lightFormatters/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/format/lightFormatters/index.js");







var dayPeriodEnum = {
  am: 'am',
  pm: 'pm',
  midnight: 'midnight',
  noon: 'noon',
  morning: 'morning',
  afternoon: 'afternoon',
  evening: 'evening',
  night: 'night'
};
/*
 * |     | Unit                           |     | Unit                           |
 * |-----|--------------------------------|-----|--------------------------------|
 * |  a  | AM, PM                         |  A* | Milliseconds in day            |
 * |  b  | AM, PM, noon, midnight         |  B  | Flexible day period            |
 * |  c  | Stand-alone local day of week  |  C* | Localized hour w/ day period   |
 * |  d  | Day of month                   |  D  | Day of year                    |
 * |  e  | Local day of week              |  E  | Day of week                    |
 * |  f  |                                |  F* | Day of week in month           |
 * |  g* | Modified Julian day            |  G  | Era                            |
 * |  h  | Hour [1-12]                    |  H  | Hour [0-23]                    |
 * |  i! | ISO day of week                |  I! | ISO week of year               |
 * |  j* | Localized hour w/ day period   |  J* | Localized hour w/o day period  |
 * |  k  | Hour [1-24]                    |  K  | Hour [0-11]                    |
 * |  l* | (deprecated)                   |  L  | Stand-alone month              |
 * |  m  | Minute                         |  M  | Month                          |
 * |  n  |                                |  N  |                                |
 * |  o! | Ordinal number modifier        |  O  | Timezone (GMT)                 |
 * |  p! | Long localized time            |  P! | Long localized date            |
 * |  q  | Stand-alone quarter            |  Q  | Quarter                        |
 * |  r* | Related Gregorian year         |  R! | ISO week-numbering year        |
 * |  s  | Second                         |  S  | Fraction of second             |
 * |  t! | Seconds timestamp              |  T! | Milliseconds timestamp         |
 * |  u  | Extended year                  |  U* | Cyclic year                    |
 * |  v* | Timezone (generic non-locat.)  |  V* | Timezone (location)            |
 * |  w  | Local week of year             |  W* | Week of month                  |
 * |  x  | Timezone (ISO-8601 w/o Z)      |  X  | Timezone (ISO-8601)            |
 * |  y  | Year (abs)                     |  Y  | Local week-numbering year      |
 * |  z  | Timezone (specific non-locat.) |  Z* | Timezone (aliases)             |
 *
 * Letters marked by * are not implemented but reserved by Unicode standard.
 *
 * Letters marked by ! are non-standard, but implemented by date-fns:
 * - `o` modifies the previous token to turn it into an ordinal (see `format` docs)
 * - `i` is ISO day of week. For `i` and `ii` is returns numeric ISO week days,
 *   i.e. 7 for Sunday, 1 for Monday, etc.
 * - `I` is ISO week of year, as opposed to `w` which is local week of year.
 * - `R` is ISO week-numbering year, as opposed to `Y` which is local week-numbering year.
 *   `R` is supposed to be used in conjunction with `I` and `i`
 *   for universal ISO week-numbering date, whereas
 *   `Y` is supposed to be used in conjunction with `w` and `e`
 *   for week-numbering date specific to the locale.
 * - `P` is long localized date format
 * - `p` is long localized time format
 */

var formatters = {
  // Era
  G: function (date, token, localize) {
    var era = date.getUTCFullYear() > 0 ? 1 : 0;

    switch (token) {
      // AD, BC
      case 'G':
      case 'GG':
      case 'GGG':
        return localize.era(era, {
          width: 'abbreviated'
        });
      // A, B

      case 'GGGGG':
        return localize.era(era, {
          width: 'narrow'
        });
      // Anno Domini, Before Christ

      case 'GGGG':
      default:
        return localize.era(era, {
          width: 'wide'
        });
    }
  },
  // Year
  y: function (date, token, localize) {
    // Ordinal number
    if (token === 'yo') {
      var signedYear = date.getUTCFullYear(); // Returns 1 for 1 BC (which is year 0 in JavaScript)

      var year = signedYear > 0 ? signedYear : 1 - signedYear;
      return localize.ordinalNumber(year, {
        unit: 'year'
      });
    }

    return _lightFormatters_index_js__WEBPACK_IMPORTED_MODULE_0__["default"].y(date, token);
  },
  // Local week-numbering year
  Y: function (date, token, localize, options) {
    var signedWeekYear = (0,_lib_getUTCWeekYear_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(date, options); // Returns 1 for 1 BC (which is year 0 in JavaScript)

    var weekYear = signedWeekYear > 0 ? signedWeekYear : 1 - signedWeekYear; // Two digit year

    if (token === 'YY') {
      var twoDigitYear = weekYear % 100;
      return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(twoDigitYear, 2);
    } // Ordinal number


    if (token === 'Yo') {
      return localize.ordinalNumber(weekYear, {
        unit: 'year'
      });
    } // Padding


    return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(weekYear, token.length);
  },
  // ISO week-numbering year
  R: function (date, token) {
    var isoWeekYear = (0,_lib_getUTCISOWeekYear_index_js__WEBPACK_IMPORTED_MODULE_3__["default"])(date); // Padding

    return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(isoWeekYear, token.length);
  },
  // Extended year. This is a single number designating the year of this calendar system.
  // The main difference between `y` and `u` localizers are B.C. years:
  // | Year | `y` | `u` |
  // |------|-----|-----|
  // | AC 1 |   1 |   1 |
  // | BC 1 |   1 |   0 |
  // | BC 2 |   2 |  -1 |
  // Also `yy` always returns the last two digits of a year,
  // while `uu` pads single digit years to 2 characters and returns other years unchanged.
  u: function (date, token) {
    var year = date.getUTCFullYear();
    return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(year, token.length);
  },
  // Quarter
  Q: function (date, token, localize) {
    var quarter = Math.ceil((date.getUTCMonth() + 1) / 3);

    switch (token) {
      // 1, 2, 3, 4
      case 'Q':
        return String(quarter);
      // 01, 02, 03, 04

      case 'QQ':
        return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(quarter, 2);
      // 1st, 2nd, 3rd, 4th

      case 'Qo':
        return localize.ordinalNumber(quarter, {
          unit: 'quarter'
        });
      // Q1, Q2, Q3, Q4

      case 'QQQ':
        return localize.quarter(quarter, {
          width: 'abbreviated',
          context: 'formatting'
        });
      // 1, 2, 3, 4 (narrow quarter; could be not numerical)

      case 'QQQQQ':
        return localize.quarter(quarter, {
          width: 'narrow',
          context: 'formatting'
        });
      // 1st quarter, 2nd quarter, ...

      case 'QQQQ':
      default:
        return localize.quarter(quarter, {
          width: 'wide',
          context: 'formatting'
        });
    }
  },
  // Stand-alone quarter
  q: function (date, token, localize) {
    var quarter = Math.ceil((date.getUTCMonth() + 1) / 3);

    switch (token) {
      // 1, 2, 3, 4
      case 'q':
        return String(quarter);
      // 01, 02, 03, 04

      case 'qq':
        return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(quarter, 2);
      // 1st, 2nd, 3rd, 4th

      case 'qo':
        return localize.ordinalNumber(quarter, {
          unit: 'quarter'
        });
      // Q1, Q2, Q3, Q4

      case 'qqq':
        return localize.quarter(quarter, {
          width: 'abbreviated',
          context: 'standalone'
        });
      // 1, 2, 3, 4 (narrow quarter; could be not numerical)

      case 'qqqqq':
        return localize.quarter(quarter, {
          width: 'narrow',
          context: 'standalone'
        });
      // 1st quarter, 2nd quarter, ...

      case 'qqqq':
      default:
        return localize.quarter(quarter, {
          width: 'wide',
          context: 'standalone'
        });
    }
  },
  // Month
  M: function (date, token, localize) {
    var month = date.getUTCMonth();

    switch (token) {
      case 'M':
      case 'MM':
        return _lightFormatters_index_js__WEBPACK_IMPORTED_MODULE_0__["default"].M(date, token);
      // 1st, 2nd, ..., 12th

      case 'Mo':
        return localize.ordinalNumber(month + 1, {
          unit: 'month'
        });
      // Jan, Feb, ..., Dec

      case 'MMM':
        return localize.month(month, {
          width: 'abbreviated',
          context: 'formatting'
        });
      // J, F, ..., D

      case 'MMMMM':
        return localize.month(month, {
          width: 'narrow',
          context: 'formatting'
        });
      // January, February, ..., December

      case 'MMMM':
      default:
        return localize.month(month, {
          width: 'wide',
          context: 'formatting'
        });
    }
  },
  // Stand-alone month
  L: function (date, token, localize) {
    var month = date.getUTCMonth();

    switch (token) {
      // 1, 2, ..., 12
      case 'L':
        return String(month + 1);
      // 01, 02, ..., 12

      case 'LL':
        return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(month + 1, 2);
      // 1st, 2nd, ..., 12th

      case 'Lo':
        return localize.ordinalNumber(month + 1, {
          unit: 'month'
        });
      // Jan, Feb, ..., Dec

      case 'LLL':
        return localize.month(month, {
          width: 'abbreviated',
          context: 'standalone'
        });
      // J, F, ..., D

      case 'LLLLL':
        return localize.month(month, {
          width: 'narrow',
          context: 'standalone'
        });
      // January, February, ..., December

      case 'LLLL':
      default:
        return localize.month(month, {
          width: 'wide',
          context: 'standalone'
        });
    }
  },
  // Local week of year
  w: function (date, token, localize, options) {
    var week = (0,_lib_getUTCWeek_index_js__WEBPACK_IMPORTED_MODULE_4__["default"])(date, options);

    if (token === 'wo') {
      return localize.ordinalNumber(week, {
        unit: 'week'
      });
    }

    return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(week, token.length);
  },
  // ISO week of year
  I: function (date, token, localize) {
    var isoWeek = (0,_lib_getUTCISOWeek_index_js__WEBPACK_IMPORTED_MODULE_5__["default"])(date);

    if (token === 'Io') {
      return localize.ordinalNumber(isoWeek, {
        unit: 'week'
      });
    }

    return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(isoWeek, token.length);
  },
  // Day of the month
  d: function (date, token, localize) {
    if (token === 'do') {
      return localize.ordinalNumber(date.getUTCDate(), {
        unit: 'date'
      });
    }

    return _lightFormatters_index_js__WEBPACK_IMPORTED_MODULE_0__["default"].d(date, token);
  },
  // Day of year
  D: function (date, token, localize) {
    var dayOfYear = (0,_lib_getUTCDayOfYear_index_js__WEBPACK_IMPORTED_MODULE_6__["default"])(date);

    if (token === 'Do') {
      return localize.ordinalNumber(dayOfYear, {
        unit: 'dayOfYear'
      });
    }

    return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(dayOfYear, token.length);
  },
  // Day of week
  E: function (date, token, localize) {
    var dayOfWeek = date.getUTCDay();

    switch (token) {
      // Tue
      case 'E':
      case 'EE':
      case 'EEE':
        return localize.day(dayOfWeek, {
          width: 'abbreviated',
          context: 'formatting'
        });
      // T

      case 'EEEEE':
        return localize.day(dayOfWeek, {
          width: 'narrow',
          context: 'formatting'
        });
      // Tu

      case 'EEEEEE':
        return localize.day(dayOfWeek, {
          width: 'short',
          context: 'formatting'
        });
      // Tuesday

      case 'EEEE':
      default:
        return localize.day(dayOfWeek, {
          width: 'wide',
          context: 'formatting'
        });
    }
  },
  // Local day of week
  e: function (date, token, localize, options) {
    var dayOfWeek = date.getUTCDay();
    var localDayOfWeek = (dayOfWeek - options.weekStartsOn + 8) % 7 || 7;

    switch (token) {
      // Numerical value (Nth day of week with current locale or weekStartsOn)
      case 'e':
        return String(localDayOfWeek);
      // Padded numerical value

      case 'ee':
        return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(localDayOfWeek, 2);
      // 1st, 2nd, ..., 7th

      case 'eo':
        return localize.ordinalNumber(localDayOfWeek, {
          unit: 'day'
        });

      case 'eee':
        return localize.day(dayOfWeek, {
          width: 'abbreviated',
          context: 'formatting'
        });
      // T

      case 'eeeee':
        return localize.day(dayOfWeek, {
          width: 'narrow',
          context: 'formatting'
        });
      // Tu

      case 'eeeeee':
        return localize.day(dayOfWeek, {
          width: 'short',
          context: 'formatting'
        });
      // Tuesday

      case 'eeee':
      default:
        return localize.day(dayOfWeek, {
          width: 'wide',
          context: 'formatting'
        });
    }
  },
  // Stand-alone local day of week
  c: function (date, token, localize, options) {
    var dayOfWeek = date.getUTCDay();
    var localDayOfWeek = (dayOfWeek - options.weekStartsOn + 8) % 7 || 7;

    switch (token) {
      // Numerical value (same as in `e`)
      case 'c':
        return String(localDayOfWeek);
      // Padded numerical value

      case 'cc':
        return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(localDayOfWeek, token.length);
      // 1st, 2nd, ..., 7th

      case 'co':
        return localize.ordinalNumber(localDayOfWeek, {
          unit: 'day'
        });

      case 'ccc':
        return localize.day(dayOfWeek, {
          width: 'abbreviated',
          context: 'standalone'
        });
      // T

      case 'ccccc':
        return localize.day(dayOfWeek, {
          width: 'narrow',
          context: 'standalone'
        });
      // Tu

      case 'cccccc':
        return localize.day(dayOfWeek, {
          width: 'short',
          context: 'standalone'
        });
      // Tuesday

      case 'cccc':
      default:
        return localize.day(dayOfWeek, {
          width: 'wide',
          context: 'standalone'
        });
    }
  },
  // ISO day of week
  i: function (date, token, localize) {
    var dayOfWeek = date.getUTCDay();
    var isoDayOfWeek = dayOfWeek === 0 ? 7 : dayOfWeek;

    switch (token) {
      // 2
      case 'i':
        return String(isoDayOfWeek);
      // 02

      case 'ii':
        return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(isoDayOfWeek, token.length);
      // 2nd

      case 'io':
        return localize.ordinalNumber(isoDayOfWeek, {
          unit: 'day'
        });
      // Tue

      case 'iii':
        return localize.day(dayOfWeek, {
          width: 'abbreviated',
          context: 'formatting'
        });
      // T

      case 'iiiii':
        return localize.day(dayOfWeek, {
          width: 'narrow',
          context: 'formatting'
        });
      // Tu

      case 'iiiiii':
        return localize.day(dayOfWeek, {
          width: 'short',
          context: 'formatting'
        });
      // Tuesday

      case 'iiii':
      default:
        return localize.day(dayOfWeek, {
          width: 'wide',
          context: 'formatting'
        });
    }
  },
  // AM or PM
  a: function (date, token, localize) {
    var hours = date.getUTCHours();
    var dayPeriodEnumValue = hours / 12 >= 1 ? 'pm' : 'am';

    switch (token) {
      case 'a':
      case 'aa':
        return localize.dayPeriod(dayPeriodEnumValue, {
          width: 'abbreviated',
          context: 'formatting'
        });

      case 'aaa':
        return localize.dayPeriod(dayPeriodEnumValue, {
          width: 'abbreviated',
          context: 'formatting'
        }).toLowerCase();

      case 'aaaaa':
        return localize.dayPeriod(dayPeriodEnumValue, {
          width: 'narrow',
          context: 'formatting'
        });

      case 'aaaa':
      default:
        return localize.dayPeriod(dayPeriodEnumValue, {
          width: 'wide',
          context: 'formatting'
        });
    }
  },
  // AM, PM, midnight, noon
  b: function (date, token, localize) {
    var hours = date.getUTCHours();
    var dayPeriodEnumValue;

    if (hours === 12) {
      dayPeriodEnumValue = dayPeriodEnum.noon;
    } else if (hours === 0) {
      dayPeriodEnumValue = dayPeriodEnum.midnight;
    } else {
      dayPeriodEnumValue = hours / 12 >= 1 ? 'pm' : 'am';
    }

    switch (token) {
      case 'b':
      case 'bb':
        return localize.dayPeriod(dayPeriodEnumValue, {
          width: 'abbreviated',
          context: 'formatting'
        });

      case 'bbb':
        return localize.dayPeriod(dayPeriodEnumValue, {
          width: 'abbreviated',
          context: 'formatting'
        }).toLowerCase();

      case 'bbbbb':
        return localize.dayPeriod(dayPeriodEnumValue, {
          width: 'narrow',
          context: 'formatting'
        });

      case 'bbbb':
      default:
        return localize.dayPeriod(dayPeriodEnumValue, {
          width: 'wide',
          context: 'formatting'
        });
    }
  },
  // in the morning, in the afternoon, in the evening, at night
  B: function (date, token, localize) {
    var hours = date.getUTCHours();
    var dayPeriodEnumValue;

    if (hours >= 17) {
      dayPeriodEnumValue = dayPeriodEnum.evening;
    } else if (hours >= 12) {
      dayPeriodEnumValue = dayPeriodEnum.afternoon;
    } else if (hours >= 4) {
      dayPeriodEnumValue = dayPeriodEnum.morning;
    } else {
      dayPeriodEnumValue = dayPeriodEnum.night;
    }

    switch (token) {
      case 'B':
      case 'BB':
      case 'BBB':
        return localize.dayPeriod(dayPeriodEnumValue, {
          width: 'abbreviated',
          context: 'formatting'
        });

      case 'BBBBB':
        return localize.dayPeriod(dayPeriodEnumValue, {
          width: 'narrow',
          context: 'formatting'
        });

      case 'BBBB':
      default:
        return localize.dayPeriod(dayPeriodEnumValue, {
          width: 'wide',
          context: 'formatting'
        });
    }
  },
  // Hour [1-12]
  h: function (date, token, localize) {
    if (token === 'ho') {
      var hours = date.getUTCHours() % 12;
      if (hours === 0) hours = 12;
      return localize.ordinalNumber(hours, {
        unit: 'hour'
      });
    }

    return _lightFormatters_index_js__WEBPACK_IMPORTED_MODULE_0__["default"].h(date, token);
  },
  // Hour [0-23]
  H: function (date, token, localize) {
    if (token === 'Ho') {
      return localize.ordinalNumber(date.getUTCHours(), {
        unit: 'hour'
      });
    }

    return _lightFormatters_index_js__WEBPACK_IMPORTED_MODULE_0__["default"].H(date, token);
  },
  // Hour [0-11]
  K: function (date, token, localize) {
    var hours = date.getUTCHours() % 12;

    if (token === 'Ko') {
      return localize.ordinalNumber(hours, {
        unit: 'hour'
      });
    }

    return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(hours, token.length);
  },
  // Hour [1-24]
  k: function (date, token, localize) {
    var hours = date.getUTCHours();
    if (hours === 0) hours = 24;

    if (token === 'ko') {
      return localize.ordinalNumber(hours, {
        unit: 'hour'
      });
    }

    return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(hours, token.length);
  },
  // Minute
  m: function (date, token, localize) {
    if (token === 'mo') {
      return localize.ordinalNumber(date.getUTCMinutes(), {
        unit: 'minute'
      });
    }

    return _lightFormatters_index_js__WEBPACK_IMPORTED_MODULE_0__["default"].m(date, token);
  },
  // Second
  s: function (date, token, localize) {
    if (token === 'so') {
      return localize.ordinalNumber(date.getUTCSeconds(), {
        unit: 'second'
      });
    }

    return _lightFormatters_index_js__WEBPACK_IMPORTED_MODULE_0__["default"].s(date, token);
  },
  // Fraction of second
  S: function (date, token) {
    return _lightFormatters_index_js__WEBPACK_IMPORTED_MODULE_0__["default"].S(date, token);
  },
  // Timezone (ISO-8601. If offset is 0, output is always `'Z'`)
  X: function (date, token, _localize, options) {
    var originalDate = options._originalDate || date;
    var timezoneOffset = originalDate.getTimezoneOffset();

    if (timezoneOffset === 0) {
      return 'Z';
    }

    switch (token) {
      // Hours and optional minutes
      case 'X':
        return formatTimezoneWithOptionalMinutes(timezoneOffset);
      // Hours, minutes and optional seconds without `:` delimiter
      // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
      // so this token always has the same output as `XX`

      case 'XXXX':
      case 'XX':
        // Hours and minutes without `:` delimiter
        return formatTimezone(timezoneOffset);
      // Hours, minutes and optional seconds with `:` delimiter
      // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
      // so this token always has the same output as `XXX`

      case 'XXXXX':
      case 'XXX': // Hours and minutes with `:` delimiter

      default:
        return formatTimezone(timezoneOffset, ':');
    }
  },
  // Timezone (ISO-8601. If offset is 0, output is `'+00:00'` or equivalent)
  x: function (date, token, _localize, options) {
    var originalDate = options._originalDate || date;
    var timezoneOffset = originalDate.getTimezoneOffset();

    switch (token) {
      // Hours and optional minutes
      case 'x':
        return formatTimezoneWithOptionalMinutes(timezoneOffset);
      // Hours, minutes and optional seconds without `:` delimiter
      // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
      // so this token always has the same output as `xx`

      case 'xxxx':
      case 'xx':
        // Hours and minutes without `:` delimiter
        return formatTimezone(timezoneOffset);
      // Hours, minutes and optional seconds with `:` delimiter
      // Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
      // so this token always has the same output as `xxx`

      case 'xxxxx':
      case 'xxx': // Hours and minutes with `:` delimiter

      default:
        return formatTimezone(timezoneOffset, ':');
    }
  },
  // Timezone (GMT)
  O: function (date, token, _localize, options) {
    var originalDate = options._originalDate || date;
    var timezoneOffset = originalDate.getTimezoneOffset();

    switch (token) {
      // Short
      case 'O':
      case 'OO':
      case 'OOO':
        return 'GMT' + formatTimezoneShort(timezoneOffset, ':');
      // Long

      case 'OOOO':
      default:
        return 'GMT' + formatTimezone(timezoneOffset, ':');
    }
  },
  // Timezone (specific non-location)
  z: function (date, token, _localize, options) {
    var originalDate = options._originalDate || date;
    var timezoneOffset = originalDate.getTimezoneOffset();

    switch (token) {
      // Short
      case 'z':
      case 'zz':
      case 'zzz':
        return 'GMT' + formatTimezoneShort(timezoneOffset, ':');
      // Long

      case 'zzzz':
      default:
        return 'GMT' + formatTimezone(timezoneOffset, ':');
    }
  },
  // Seconds timestamp
  t: function (date, token, _localize, options) {
    var originalDate = options._originalDate || date;
    var timestamp = Math.floor(originalDate.getTime() / 1000);
    return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(timestamp, token.length);
  },
  // Milliseconds timestamp
  T: function (date, token, _localize, options) {
    var originalDate = options._originalDate || date;
    var timestamp = originalDate.getTime();
    return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(timestamp, token.length);
  }
};

function formatTimezoneShort(offset, dirtyDelimiter) {
  var sign = offset > 0 ? '-' : '+';
  var absOffset = Math.abs(offset);
  var hours = Math.floor(absOffset / 60);
  var minutes = absOffset % 60;

  if (minutes === 0) {
    return sign + String(hours);
  }

  var delimiter = dirtyDelimiter || '';
  return sign + String(hours) + delimiter + (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(minutes, 2);
}

function formatTimezoneWithOptionalMinutes(offset, dirtyDelimiter) {
  if (offset % 60 === 0) {
    var sign = offset > 0 ? '-' : '+';
    return sign + (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(Math.abs(offset) / 60, 2);
  }

  return formatTimezone(offset, dirtyDelimiter);
}

function formatTimezone(offset, dirtyDelimiter) {
  var delimiter = dirtyDelimiter || '';
  var sign = offset > 0 ? '-' : '+';
  var absOffset = Math.abs(offset);
  var hours = (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(Math.floor(absOffset / 60), 2);
  var minutes = (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(absOffset % 60, 2);
  return sign + hours + delimiter + minutes;
}

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (formatters);

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/format/lightFormatters/index.js":
/*!*******************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/format/lightFormatters/index.js ***!
  \*******************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../addLeadingZeros/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/addLeadingZeros/index.js");

/*
 * |     | Unit                           |     | Unit                           |
 * |-----|--------------------------------|-----|--------------------------------|
 * |  a  | AM, PM                         |  A* |                                |
 * |  d  | Day of month                   |  D  |                                |
 * |  h  | Hour [1-12]                    |  H  | Hour [0-23]                    |
 * |  m  | Minute                         |  M  | Month                          |
 * |  s  | Second                         |  S  | Fraction of second             |
 * |  y  | Year (abs)                     |  Y  |                                |
 *
 * Letters marked by * are not implemented but reserved by Unicode standard.
 */

var formatters = {
  // Year
  y: function (date, token) {
    // From http://www.unicode.org/reports/tr35/tr35-31/tr35-dates.html#Date_Format_tokens
    // | Year     |     y | yy |   yyy |  yyyy | yyyyy |
    // |----------|-------|----|-------|-------|-------|
    // | AD 1     |     1 | 01 |   001 |  0001 | 00001 |
    // | AD 12    |    12 | 12 |   012 |  0012 | 00012 |
    // | AD 123   |   123 | 23 |   123 |  0123 | 00123 |
    // | AD 1234  |  1234 | 34 |  1234 |  1234 | 01234 |
    // | AD 12345 | 12345 | 45 | 12345 | 12345 | 12345 |
    var signedYear = date.getUTCFullYear(); // Returns 1 for 1 BC (which is year 0 in JavaScript)

    var year = signedYear > 0 ? signedYear : 1 - signedYear;
    return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(token === 'yy' ? year % 100 : year, token.length);
  },
  // Month
  M: function (date, token) {
    var month = date.getUTCMonth();
    return token === 'M' ? String(month + 1) : (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(month + 1, 2);
  },
  // Day of the month
  d: function (date, token) {
    return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(date.getUTCDate(), token.length);
  },
  // AM or PM
  a: function (date, token) {
    var dayPeriodEnumValue = date.getUTCHours() / 12 >= 1 ? 'pm' : 'am';

    switch (token) {
      case 'a':
      case 'aa':
        return dayPeriodEnumValue.toUpperCase();

      case 'aaa':
        return dayPeriodEnumValue;

      case 'aaaaa':
        return dayPeriodEnumValue[0];

      case 'aaaa':
      default:
        return dayPeriodEnumValue === 'am' ? 'a.m.' : 'p.m.';
    }
  },
  // Hour [1-12]
  h: function (date, token) {
    return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(date.getUTCHours() % 12 || 12, token.length);
  },
  // Hour [0-23]
  H: function (date, token) {
    return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(date.getUTCHours(), token.length);
  },
  // Minute
  m: function (date, token) {
    return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(date.getUTCMinutes(), token.length);
  },
  // Second
  s: function (date, token) {
    return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(date.getUTCSeconds(), token.length);
  },
  // Fraction of second
  S: function (date, token) {
    var numberOfDigits = token.length;
    var milliseconds = date.getUTCMilliseconds();
    var fractionalSeconds = Math.floor(milliseconds * Math.pow(10, numberOfDigits - 3));
    return (0,_addLeadingZeros_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(fractionalSeconds, token.length);
  }
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (formatters);

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/format/longFormatters/index.js":
/*!******************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/format/longFormatters/index.js ***!
  \******************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
function dateLongFormatter(pattern, formatLong) {
  switch (pattern) {
    case 'P':
      return formatLong.date({
        width: 'short'
      });

    case 'PP':
      return formatLong.date({
        width: 'medium'
      });

    case 'PPP':
      return formatLong.date({
        width: 'long'
      });

    case 'PPPP':
    default:
      return formatLong.date({
        width: 'full'
      });
  }
}

function timeLongFormatter(pattern, formatLong) {
  switch (pattern) {
    case 'p':
      return formatLong.time({
        width: 'short'
      });

    case 'pp':
      return formatLong.time({
        width: 'medium'
      });

    case 'ppp':
      return formatLong.time({
        width: 'long'
      });

    case 'pppp':
    default:
      return formatLong.time({
        width: 'full'
      });
  }
}

function dateTimeLongFormatter(pattern, formatLong) {
  var matchResult = pattern.match(/(P+)(p+)?/) || [];
  var datePattern = matchResult[1];
  var timePattern = matchResult[2];

  if (!timePattern) {
    return dateLongFormatter(pattern, formatLong);
  }

  var dateTimeFormat;

  switch (datePattern) {
    case 'P':
      dateTimeFormat = formatLong.dateTime({
        width: 'short'
      });
      break;

    case 'PP':
      dateTimeFormat = formatLong.dateTime({
        width: 'medium'
      });
      break;

    case 'PPP':
      dateTimeFormat = formatLong.dateTime({
        width: 'long'
      });
      break;

    case 'PPPP':
    default:
      dateTimeFormat = formatLong.dateTime({
        width: 'full'
      });
      break;
  }

  return dateTimeFormat.replace('{{date}}', dateLongFormatter(datePattern, formatLong)).replace('{{time}}', timeLongFormatter(timePattern, formatLong));
}

var longFormatters = {
  p: timeLongFormatter,
  P: dateTimeLongFormatter
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (longFormatters);

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getTimezoneOffsetInMilliseconds/index.js":
/*!****************************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getTimezoneOffsetInMilliseconds/index.js ***!
  \****************************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ getTimezoneOffsetInMilliseconds)
/* harmony export */ });
/**
 * Google Chrome as of 67.0.3396.87 introduced timezones with offset that includes seconds.
 * They usually appear for dates that denote time before the timezones were introduced
 * (e.g. for 'Europe/Prague' timezone the offset is GMT+00:57:44 before 1 October 1891
 * and GMT+01:00:00 after that date)
 *
 * Date#getTimezoneOffset returns the offset in minutes and would return 57 for the example above,
 * which would lead to incorrect calculations.
 *
 * This function returns the timezone offset in milliseconds that takes seconds in account.
 */
function getTimezoneOffsetInMilliseconds(date) {
  var utcDate = new Date(Date.UTC(date.getFullYear(), date.getMonth(), date.getDate(), date.getHours(), date.getMinutes(), date.getSeconds(), date.getMilliseconds()));
  utcDate.setUTCFullYear(date.getFullYear());
  return date.getTime() - utcDate.getTime();
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCDayOfYear/index.js":
/*!************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCDayOfYear/index.js ***!
  \************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ getUTCDayOfYear)
/* harmony export */ });
/* harmony import */ var _toDate_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../toDate/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/toDate/index.js");
/* harmony import */ var _requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");


var MILLISECONDS_IN_DAY = 86400000; // This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376

function getUTCDayOfYear(dirtyDate) {
  (0,_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(1, arguments);
  var date = (0,_toDate_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(dirtyDate);
  var timestamp = date.getTime();
  date.setUTCMonth(0, 1);
  date.setUTCHours(0, 0, 0, 0);
  var startOfYearTimestamp = date.getTime();
  var difference = timestamp - startOfYearTimestamp;
  return Math.floor(difference / MILLISECONDS_IN_DAY) + 1;
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCISOWeek/index.js":
/*!**********************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCISOWeek/index.js ***!
  \**********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ getUTCISOWeek)
/* harmony export */ });
/* harmony import */ var _toDate_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../toDate/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/toDate/index.js");
/* harmony import */ var _startOfUTCISOWeek_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../startOfUTCISOWeek/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCISOWeek/index.js");
/* harmony import */ var _startOfUTCISOWeekYear_index_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../startOfUTCISOWeekYear/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCISOWeekYear/index.js");
/* harmony import */ var _requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");




var MILLISECONDS_IN_WEEK = 604800000; // This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376

function getUTCISOWeek(dirtyDate) {
  (0,_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(1, arguments);
  var date = (0,_toDate_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(dirtyDate);
  var diff = (0,_startOfUTCISOWeek_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(date).getTime() - (0,_startOfUTCISOWeekYear_index_js__WEBPACK_IMPORTED_MODULE_3__["default"])(date).getTime(); // Round the number of days to the nearest integer
  // because the number of milliseconds in a week is not constant
  // (e.g. it's different in the week of the daylight saving time clock shift)

  return Math.round(diff / MILLISECONDS_IN_WEEK) + 1;
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCISOWeekYear/index.js":
/*!**************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCISOWeekYear/index.js ***!
  \**************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ getUTCISOWeekYear)
/* harmony export */ });
/* harmony import */ var _toDate_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../toDate/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/toDate/index.js");
/* harmony import */ var _requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");
/* harmony import */ var _startOfUTCISOWeek_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../startOfUTCISOWeek/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCISOWeek/index.js");


 // This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376

function getUTCISOWeekYear(dirtyDate) {
  (0,_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(1, arguments);
  var date = (0,_toDate_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(dirtyDate);
  var year = date.getUTCFullYear();
  var fourthOfJanuaryOfNextYear = new Date(0);
  fourthOfJanuaryOfNextYear.setUTCFullYear(year + 1, 0, 4);
  fourthOfJanuaryOfNextYear.setUTCHours(0, 0, 0, 0);
  var startOfNextYear = (0,_startOfUTCISOWeek_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(fourthOfJanuaryOfNextYear);
  var fourthOfJanuaryOfThisYear = new Date(0);
  fourthOfJanuaryOfThisYear.setUTCFullYear(year, 0, 4);
  fourthOfJanuaryOfThisYear.setUTCHours(0, 0, 0, 0);
  var startOfThisYear = (0,_startOfUTCISOWeek_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(fourthOfJanuaryOfThisYear);

  if (date.getTime() >= startOfNextYear.getTime()) {
    return year + 1;
  } else if (date.getTime() >= startOfThisYear.getTime()) {
    return year;
  } else {
    return year - 1;
  }
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCWeek/index.js":
/*!*******************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCWeek/index.js ***!
  \*******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ getUTCWeek)
/* harmony export */ });
/* harmony import */ var _toDate_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../toDate/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/toDate/index.js");
/* harmony import */ var _startOfUTCWeek_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../startOfUTCWeek/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCWeek/index.js");
/* harmony import */ var _startOfUTCWeekYear_index_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../startOfUTCWeekYear/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCWeekYear/index.js");
/* harmony import */ var _requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");




var MILLISECONDS_IN_WEEK = 604800000; // This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376

function getUTCWeek(dirtyDate, options) {
  (0,_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(1, arguments);
  var date = (0,_toDate_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(dirtyDate);
  var diff = (0,_startOfUTCWeek_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(date, options).getTime() - (0,_startOfUTCWeekYear_index_js__WEBPACK_IMPORTED_MODULE_3__["default"])(date, options).getTime(); // Round the number of days to the nearest integer
  // because the number of milliseconds in a week is not constant
  // (e.g. it's different in the week of the daylight saving time clock shift)

  return Math.round(diff / MILLISECONDS_IN_WEEK) + 1;
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCWeekYear/index.js":
/*!***********************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCWeekYear/index.js ***!
  \***********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ getUTCWeekYear)
/* harmony export */ });
/* harmony import */ var _toDate_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../toDate/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/toDate/index.js");
/* harmony import */ var _requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");
/* harmony import */ var _startOfUTCWeek_index_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../startOfUTCWeek/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCWeek/index.js");
/* harmony import */ var _toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../toInteger/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/toInteger/index.js");



 // This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376

function getUTCWeekYear(dirtyDate, dirtyOptions) {
  (0,_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(1, arguments);
  var date = (0,_toDate_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(dirtyDate);
  var year = date.getUTCFullYear();
  var options = dirtyOptions || {};
  var locale = options.locale;
  var localeFirstWeekContainsDate = locale && locale.options && locale.options.firstWeekContainsDate;
  var defaultFirstWeekContainsDate = localeFirstWeekContainsDate == null ? 1 : (0,_toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(localeFirstWeekContainsDate);
  var firstWeekContainsDate = options.firstWeekContainsDate == null ? defaultFirstWeekContainsDate : (0,_toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(options.firstWeekContainsDate); // Test if weekStartsOn is between 1 and 7 _and_ is not NaN

  if (!(firstWeekContainsDate >= 1 && firstWeekContainsDate <= 7)) {
    throw new RangeError('firstWeekContainsDate must be between 1 and 7 inclusively');
  }

  var firstWeekOfNextYear = new Date(0);
  firstWeekOfNextYear.setUTCFullYear(year + 1, 0, firstWeekContainsDate);
  firstWeekOfNextYear.setUTCHours(0, 0, 0, 0);
  var startOfNextYear = (0,_startOfUTCWeek_index_js__WEBPACK_IMPORTED_MODULE_3__["default"])(firstWeekOfNextYear, dirtyOptions);
  var firstWeekOfThisYear = new Date(0);
  firstWeekOfThisYear.setUTCFullYear(year, 0, firstWeekContainsDate);
  firstWeekOfThisYear.setUTCHours(0, 0, 0, 0);
  var startOfThisYear = (0,_startOfUTCWeek_index_js__WEBPACK_IMPORTED_MODULE_3__["default"])(firstWeekOfThisYear, dirtyOptions);

  if (date.getTime() >= startOfNextYear.getTime()) {
    return year + 1;
  } else if (date.getTime() >= startOfThisYear.getTime()) {
    return year;
  } else {
    return year - 1;
  }
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/protectedTokens/index.js":
/*!************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/protectedTokens/index.js ***!
  \************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "isProtectedDayOfYearToken": () => (/* binding */ isProtectedDayOfYearToken),
/* harmony export */   "isProtectedWeekYearToken": () => (/* binding */ isProtectedWeekYearToken),
/* harmony export */   "throwProtectedError": () => (/* binding */ throwProtectedError)
/* harmony export */ });
var protectedDayOfYearTokens = ['D', 'DD'];
var protectedWeekYearTokens = ['YY', 'YYYY'];
function isProtectedDayOfYearToken(token) {
  return protectedDayOfYearTokens.indexOf(token) !== -1;
}
function isProtectedWeekYearToken(token) {
  return protectedWeekYearTokens.indexOf(token) !== -1;
}
function throwProtectedError(token, format, input) {
  if (token === 'YYYY') {
    throw new RangeError("Use `yyyy` instead of `YYYY` (in `".concat(format, "`) for formatting years to the input `").concat(input, "`; see: https://git.io/fxCyr"));
  } else if (token === 'YY') {
    throw new RangeError("Use `yy` instead of `YY` (in `".concat(format, "`) for formatting years to the input `").concat(input, "`; see: https://git.io/fxCyr"));
  } else if (token === 'D') {
    throw new RangeError("Use `d` instead of `D` (in `".concat(format, "`) for formatting days of the month to the input `").concat(input, "`; see: https://git.io/fxCyr"));
  } else if (token === 'DD') {
    throw new RangeError("Use `dd` instead of `DD` (in `".concat(format, "`) for formatting days of the month to the input `").concat(input, "`; see: https://git.io/fxCyr"));
  }
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js":
/*!*********************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js ***!
  \*********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ requiredArgs)
/* harmony export */ });
function requiredArgs(required, args) {
  if (args.length < required) {
    throw new TypeError(required + ' argument' + (required > 1 ? 's' : '') + ' required, but only ' + args.length + ' present');
  }
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/setUTCDay/index.js":
/*!******************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/setUTCDay/index.js ***!
  \******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ setUTCDay)
/* harmony export */ });
/* harmony import */ var _toDate_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../toDate/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/toDate/index.js");
/* harmony import */ var _requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");
/* harmony import */ var _toInteger_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../toInteger/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/toInteger/index.js");


 // This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376

function setUTCDay(dirtyDate, dirtyDay, dirtyOptions) {
  (0,_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(2, arguments);
  var options = dirtyOptions || {};
  var locale = options.locale;
  var localeWeekStartsOn = locale && locale.options && locale.options.weekStartsOn;
  var defaultWeekStartsOn = localeWeekStartsOn == null ? 0 : (0,_toInteger_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(localeWeekStartsOn);
  var weekStartsOn = options.weekStartsOn == null ? defaultWeekStartsOn : (0,_toInteger_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(options.weekStartsOn); // Test if weekStartsOn is between 0 and 6 _and_ is not NaN

  if (!(weekStartsOn >= 0 && weekStartsOn <= 6)) {
    throw new RangeError('weekStartsOn must be between 0 and 6 inclusively');
  }

  var date = (0,_toDate_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(dirtyDate);
  var day = (0,_toInteger_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(dirtyDay);
  var currentDay = date.getUTCDay();
  var remainder = day % 7;
  var dayIndex = (remainder + 7) % 7;
  var diff = (dayIndex < weekStartsOn ? 7 : 0) + day - currentDay;
  date.setUTCDate(date.getUTCDate() + diff);
  return date;
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/setUTCISODay/index.js":
/*!*********************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/setUTCISODay/index.js ***!
  \*********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ setUTCISODay)
/* harmony export */ });
/* harmony import */ var _toDate_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../toDate/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/toDate/index.js");
/* harmony import */ var _requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");
/* harmony import */ var _toInteger_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../toInteger/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/toInteger/index.js");


 // This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376

function setUTCISODay(dirtyDate, dirtyDay) {
  (0,_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(2, arguments);
  var day = (0,_toInteger_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(dirtyDay);

  if (day % 7 === 0) {
    day = day - 7;
  }

  var weekStartsOn = 1;
  var date = (0,_toDate_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(dirtyDate);
  var currentDay = date.getUTCDay();
  var remainder = day % 7;
  var dayIndex = (remainder + 7) % 7;
  var diff = (dayIndex < weekStartsOn ? 7 : 0) + day - currentDay;
  date.setUTCDate(date.getUTCDate() + diff);
  return date;
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/setUTCISOWeek/index.js":
/*!**********************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/setUTCISOWeek/index.js ***!
  \**********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ setUTCISOWeek)
/* harmony export */ });
/* harmony import */ var _toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../toInteger/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/toInteger/index.js");
/* harmony import */ var _toDate_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../toDate/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/toDate/index.js");
/* harmony import */ var _getUTCISOWeek_index_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../getUTCISOWeek/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCISOWeek/index.js");
/* harmony import */ var _requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");



 // This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376

function setUTCISOWeek(dirtyDate, dirtyISOWeek) {
  (0,_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(2, arguments);
  var date = (0,_toDate_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(dirtyDate);
  var isoWeek = (0,_toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(dirtyISOWeek);
  var diff = (0,_getUTCISOWeek_index_js__WEBPACK_IMPORTED_MODULE_3__["default"])(date) - isoWeek;
  date.setUTCDate(date.getUTCDate() - diff * 7);
  return date;
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/setUTCWeek/index.js":
/*!*******************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/setUTCWeek/index.js ***!
  \*******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ setUTCWeek)
/* harmony export */ });
/* harmony import */ var _toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../toInteger/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/toInteger/index.js");
/* harmony import */ var _toDate_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../toDate/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/toDate/index.js");
/* harmony import */ var _getUTCWeek_index_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../getUTCWeek/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCWeek/index.js");
/* harmony import */ var _requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");



 // This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376

function setUTCWeek(dirtyDate, dirtyWeek, options) {
  (0,_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(2, arguments);
  var date = (0,_toDate_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(dirtyDate);
  var week = (0,_toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(dirtyWeek);
  var diff = (0,_getUTCWeek_index_js__WEBPACK_IMPORTED_MODULE_3__["default"])(date, options) - week;
  date.setUTCDate(date.getUTCDate() - diff * 7);
  return date;
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCISOWeek/index.js":
/*!**************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCISOWeek/index.js ***!
  \**************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ startOfUTCISOWeek)
/* harmony export */ });
/* harmony import */ var _toDate_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../toDate/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/toDate/index.js");
/* harmony import */ var _requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");

 // This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376

function startOfUTCISOWeek(dirtyDate) {
  (0,_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(1, arguments);
  var weekStartsOn = 1;
  var date = (0,_toDate_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(dirtyDate);
  var day = date.getUTCDay();
  var diff = (day < weekStartsOn ? 7 : 0) + day - weekStartsOn;
  date.setUTCDate(date.getUTCDate() - diff);
  date.setUTCHours(0, 0, 0, 0);
  return date;
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCISOWeekYear/index.js":
/*!******************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCISOWeekYear/index.js ***!
  \******************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ startOfUTCISOWeekYear)
/* harmony export */ });
/* harmony import */ var _getUTCISOWeekYear_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../getUTCISOWeekYear/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCISOWeekYear/index.js");
/* harmony import */ var _startOfUTCISOWeek_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../startOfUTCISOWeek/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCISOWeek/index.js");
/* harmony import */ var _requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");


 // This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376

function startOfUTCISOWeekYear(dirtyDate) {
  (0,_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(1, arguments);
  var year = (0,_getUTCISOWeekYear_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(dirtyDate);
  var fourthOfJanuary = new Date(0);
  fourthOfJanuary.setUTCFullYear(year, 0, 4);
  fourthOfJanuary.setUTCHours(0, 0, 0, 0);
  var date = (0,_startOfUTCISOWeek_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(fourthOfJanuary);
  return date;
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCWeek/index.js":
/*!***********************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCWeek/index.js ***!
  \***********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ startOfUTCWeek)
/* harmony export */ });
/* harmony import */ var _toDate_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../toDate/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/toDate/index.js");
/* harmony import */ var _requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");
/* harmony import */ var _toInteger_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../toInteger/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/toInteger/index.js");


 // This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376

function startOfUTCWeek(dirtyDate, dirtyOptions) {
  (0,_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(1, arguments);
  var options = dirtyOptions || {};
  var locale = options.locale;
  var localeWeekStartsOn = locale && locale.options && locale.options.weekStartsOn;
  var defaultWeekStartsOn = localeWeekStartsOn == null ? 0 : (0,_toInteger_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(localeWeekStartsOn);
  var weekStartsOn = options.weekStartsOn == null ? defaultWeekStartsOn : (0,_toInteger_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(options.weekStartsOn); // Test if weekStartsOn is between 0 and 6 _and_ is not NaN

  if (!(weekStartsOn >= 0 && weekStartsOn <= 6)) {
    throw new RangeError('weekStartsOn must be between 0 and 6 inclusively');
  }

  var date = (0,_toDate_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(dirtyDate);
  var day = date.getUTCDay();
  var diff = (day < weekStartsOn ? 7 : 0) + day - weekStartsOn;
  date.setUTCDate(date.getUTCDate() - diff);
  date.setUTCHours(0, 0, 0, 0);
  return date;
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCWeekYear/index.js":
/*!***************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCWeekYear/index.js ***!
  \***************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ startOfUTCWeekYear)
/* harmony export */ });
/* harmony import */ var _getUTCWeekYear_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../getUTCWeekYear/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCWeekYear/index.js");
/* harmony import */ var _requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");
/* harmony import */ var _startOfUTCWeek_index_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../startOfUTCWeek/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCWeek/index.js");
/* harmony import */ var _toInteger_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../toInteger/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/toInteger/index.js");



 // This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376

function startOfUTCWeekYear(dirtyDate, dirtyOptions) {
  (0,_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(1, arguments);
  var options = dirtyOptions || {};
  var locale = options.locale;
  var localeFirstWeekContainsDate = locale && locale.options && locale.options.firstWeekContainsDate;
  var defaultFirstWeekContainsDate = localeFirstWeekContainsDate == null ? 1 : (0,_toInteger_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(localeFirstWeekContainsDate);
  var firstWeekContainsDate = options.firstWeekContainsDate == null ? defaultFirstWeekContainsDate : (0,_toInteger_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(options.firstWeekContainsDate);
  var year = (0,_getUTCWeekYear_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(dirtyDate, dirtyOptions);
  var firstWeek = new Date(0);
  firstWeek.setUTCFullYear(year, 0, firstWeekContainsDate);
  firstWeek.setUTCHours(0, 0, 0, 0);
  var date = (0,_startOfUTCWeek_index_js__WEBPACK_IMPORTED_MODULE_3__["default"])(firstWeek, dirtyOptions);
  return date;
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/toInteger/index.js":
/*!******************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/toInteger/index.js ***!
  \******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ toInteger)
/* harmony export */ });
function toInteger(dirtyNumber) {
  if (dirtyNumber === null || dirtyNumber === true || dirtyNumber === false) {
    return NaN;
  }

  var number = Number(dirtyNumber);

  if (isNaN(number)) {
    return number;
  }

  return number < 0 ? Math.ceil(number) : Math.floor(number);
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/addMilliseconds/index.js":
/*!*******************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/addMilliseconds/index.js ***!
  \*******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ addMilliseconds)
/* harmony export */ });
/* harmony import */ var _lib_toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../_lib/toInteger/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/toInteger/index.js");
/* harmony import */ var _toDate_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../toDate/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/toDate/index.js");
/* harmony import */ var _lib_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../_lib/requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");



/**
 * @name addMilliseconds
 * @category Millisecond Helpers
 * @summary Add the specified number of milliseconds to the given date.
 *
 * @description
 * Add the specified number of milliseconds to the given date.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} date - the date to be changed
 * @param {Number} amount - the amount of milliseconds to be added. Positive decimals will be rounded using `Math.floor`, decimals less than zero will be rounded using `Math.ceil`.
 * @returns {Date} the new date with the milliseconds added
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // Add 750 milliseconds to 10 July 2014 12:45:30.000:
 * const result = addMilliseconds(new Date(2014, 6, 10, 12, 45, 30, 0), 750)
 * //=> Thu Jul 10 2014 12:45:30.750
 */

function addMilliseconds(dirtyDate, dirtyAmount) {
  (0,_lib_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(2, arguments);
  var timestamp = (0,_toDate_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(dirtyDate).getTime();
  var amount = (0,_lib_toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(dirtyAmount);
  return new Date(timestamp + amount);
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/format/index.js":
/*!**********************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/format/index.js ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ format)
/* harmony export */ });
/* harmony import */ var _isValid_index_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../isValid/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/isValid/index.js");
/* harmony import */ var _locale_en_US_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../locale/en-US/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/index.js");
/* harmony import */ var _subMilliseconds_index_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../subMilliseconds/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/subMilliseconds/index.js");
/* harmony import */ var _toDate_index_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../toDate/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/toDate/index.js");
/* harmony import */ var _lib_format_formatters_index_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../_lib/format/formatters/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/format/formatters/index.js");
/* harmony import */ var _lib_format_longFormatters_index_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../_lib/format/longFormatters/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/format/longFormatters/index.js");
/* harmony import */ var _lib_getTimezoneOffsetInMilliseconds_index_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../_lib/getTimezoneOffsetInMilliseconds/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getTimezoneOffsetInMilliseconds/index.js");
/* harmony import */ var _lib_protectedTokens_index_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../_lib/protectedTokens/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/protectedTokens/index.js");
/* harmony import */ var _lib_toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../_lib/toInteger/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/toInteger/index.js");
/* harmony import */ var _lib_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../_lib/requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");









 // This RegExp consists of three parts separated by `|`:
// - [yYQqMLwIdDecihHKkms]o matches any available ordinal number token
//   (one of the certain letters followed by `o`)
// - (\w)\1* matches any sequences of the same letter
// - '' matches two quote characters in a row
// - '(''|[^'])+('|$) matches anything surrounded by two quote characters ('),
//   except a single quote symbol, which ends the sequence.
//   Two quote characters do not end the sequence.
//   If there is no matching single quote
//   then the sequence will continue until the end of the string.
// - . matches any single character unmatched by previous parts of the RegExps

var formattingTokensRegExp = /[yYQqMLwIdDecihHKkms]o|(\w)\1*|''|'(''|[^'])+('|$)|./g; // This RegExp catches symbols escaped by quotes, and also
// sequences of symbols P, p, and the combinations like `PPPPPPPppppp`

var longFormattingTokensRegExp = /P+p+|P+|p+|''|'(''|[^'])+('|$)|./g;
var escapedStringRegExp = /^'([^]*?)'?$/;
var doubleQuoteRegExp = /''/g;
var unescapedLatinCharacterRegExp = /[a-zA-Z]/;
/**
 * @name format
 * @category Common Helpers
 * @summary Format the date.
 *
 * @description
 * Return the formatted date string in the given format. The result may vary by locale.
 *
 * > ⚠️ Please note that the `format` tokens differ from Moment.js and other libraries.
 * > See: https://git.io/fxCyr
 *
 * The characters wrapped between two single quotes characters (') are escaped.
 * Two single quotes in a row, whether inside or outside a quoted sequence, represent a 'real' single quote.
 * (see the last example)
 *
 * Format of the string is based on Unicode Technical Standard #35:
 * https://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table
 * with a few additions (see note 7 below the table).
 *
 * Accepted patterns:
 * | Unit                            | Pattern | Result examples                   | Notes |
 * |---------------------------------|---------|-----------------------------------|-------|
 * | Era                             | G..GGG  | AD, BC                            |       |
 * |                                 | GGGG    | Anno Domini, Before Christ        | 2     |
 * |                                 | GGGGG   | A, B                              |       |
 * | Calendar year                   | y       | 44, 1, 1900, 2017                 | 5     |
 * |                                 | yo      | 44th, 1st, 0th, 17th              | 5,7   |
 * |                                 | yy      | 44, 01, 00, 17                    | 5     |
 * |                                 | yyy     | 044, 001, 1900, 2017              | 5     |
 * |                                 | yyyy    | 0044, 0001, 1900, 2017            | 5     |
 * |                                 | yyyyy   | ...                               | 3,5   |
 * | Local week-numbering year       | Y       | 44, 1, 1900, 2017                 | 5     |
 * |                                 | Yo      | 44th, 1st, 1900th, 2017th         | 5,7   |
 * |                                 | YY      | 44, 01, 00, 17                    | 5,8   |
 * |                                 | YYY     | 044, 001, 1900, 2017              | 5     |
 * |                                 | YYYY    | 0044, 0001, 1900, 2017            | 5,8   |
 * |                                 | YYYYY   | ...                               | 3,5   |
 * | ISO week-numbering year         | R       | -43, 0, 1, 1900, 2017             | 5,7   |
 * |                                 | RR      | -43, 00, 01, 1900, 2017           | 5,7   |
 * |                                 | RRR     | -043, 000, 001, 1900, 2017        | 5,7   |
 * |                                 | RRRR    | -0043, 0000, 0001, 1900, 2017     | 5,7   |
 * |                                 | RRRRR   | ...                               | 3,5,7 |
 * | Extended year                   | u       | -43, 0, 1, 1900, 2017             | 5     |
 * |                                 | uu      | -43, 01, 1900, 2017               | 5     |
 * |                                 | uuu     | -043, 001, 1900, 2017             | 5     |
 * |                                 | uuuu    | -0043, 0001, 1900, 2017           | 5     |
 * |                                 | uuuuu   | ...                               | 3,5   |
 * | Quarter (formatting)            | Q       | 1, 2, 3, 4                        |       |
 * |                                 | Qo      | 1st, 2nd, 3rd, 4th                | 7     |
 * |                                 | QQ      | 01, 02, 03, 04                    |       |
 * |                                 | QQQ     | Q1, Q2, Q3, Q4                    |       |
 * |                                 | QQQQ    | 1st quarter, 2nd quarter, ...     | 2     |
 * |                                 | QQQQQ   | 1, 2, 3, 4                        | 4     |
 * | Quarter (stand-alone)           | q       | 1, 2, 3, 4                        |       |
 * |                                 | qo      | 1st, 2nd, 3rd, 4th                | 7     |
 * |                                 | qq      | 01, 02, 03, 04                    |       |
 * |                                 | qqq     | Q1, Q2, Q3, Q4                    |       |
 * |                                 | qqqq    | 1st quarter, 2nd quarter, ...     | 2     |
 * |                                 | qqqqq   | 1, 2, 3, 4                        | 4     |
 * | Month (formatting)              | M       | 1, 2, ..., 12                     |       |
 * |                                 | Mo      | 1st, 2nd, ..., 12th               | 7     |
 * |                                 | MM      | 01, 02, ..., 12                   |       |
 * |                                 | MMM     | Jan, Feb, ..., Dec                |       |
 * |                                 | MMMM    | January, February, ..., December  | 2     |
 * |                                 | MMMMM   | J, F, ..., D                      |       |
 * | Month (stand-alone)             | L       | 1, 2, ..., 12                     |       |
 * |                                 | Lo      | 1st, 2nd, ..., 12th               | 7     |
 * |                                 | LL      | 01, 02, ..., 12                   |       |
 * |                                 | LLL     | Jan, Feb, ..., Dec                |       |
 * |                                 | LLLL    | January, February, ..., December  | 2     |
 * |                                 | LLLLL   | J, F, ..., D                      |       |
 * | Local week of year              | w       | 1, 2, ..., 53                     |       |
 * |                                 | wo      | 1st, 2nd, ..., 53th               | 7     |
 * |                                 | ww      | 01, 02, ..., 53                   |       |
 * | ISO week of year                | I       | 1, 2, ..., 53                     | 7     |
 * |                                 | Io      | 1st, 2nd, ..., 53th               | 7     |
 * |                                 | II      | 01, 02, ..., 53                   | 7     |
 * | Day of month                    | d       | 1, 2, ..., 31                     |       |
 * |                                 | do      | 1st, 2nd, ..., 31st               | 7     |
 * |                                 | dd      | 01, 02, ..., 31                   |       |
 * | Day of year                     | D       | 1, 2, ..., 365, 366               | 9     |
 * |                                 | Do      | 1st, 2nd, ..., 365th, 366th       | 7     |
 * |                                 | DD      | 01, 02, ..., 365, 366             | 9     |
 * |                                 | DDD     | 001, 002, ..., 365, 366           |       |
 * |                                 | DDDD    | ...                               | 3     |
 * | Day of week (formatting)        | E..EEE  | Mon, Tue, Wed, ..., Sun           |       |
 * |                                 | EEEE    | Monday, Tuesday, ..., Sunday      | 2     |
 * |                                 | EEEEE   | M, T, W, T, F, S, S               |       |
 * |                                 | EEEEEE  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
 * | ISO day of week (formatting)    | i       | 1, 2, 3, ..., 7                   | 7     |
 * |                                 | io      | 1st, 2nd, ..., 7th                | 7     |
 * |                                 | ii      | 01, 02, ..., 07                   | 7     |
 * |                                 | iii     | Mon, Tue, Wed, ..., Sun           | 7     |
 * |                                 | iiii    | Monday, Tuesday, ..., Sunday      | 2,7   |
 * |                                 | iiiii   | M, T, W, T, F, S, S               | 7     |
 * |                                 | iiiiii  | Mo, Tu, We, Th, Fr, Sa, Su        | 7     |
 * | Local day of week (formatting)  | e       | 2, 3, 4, ..., 1                   |       |
 * |                                 | eo      | 2nd, 3rd, ..., 1st                | 7     |
 * |                                 | ee      | 02, 03, ..., 01                   |       |
 * |                                 | eee     | Mon, Tue, Wed, ..., Sun           |       |
 * |                                 | eeee    | Monday, Tuesday, ..., Sunday      | 2     |
 * |                                 | eeeee   | M, T, W, T, F, S, S               |       |
 * |                                 | eeeeee  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
 * | Local day of week (stand-alone) | c       | 2, 3, 4, ..., 1                   |       |
 * |                                 | co      | 2nd, 3rd, ..., 1st                | 7     |
 * |                                 | cc      | 02, 03, ..., 01                   |       |
 * |                                 | ccc     | Mon, Tue, Wed, ..., Sun           |       |
 * |                                 | cccc    | Monday, Tuesday, ..., Sunday      | 2     |
 * |                                 | ccccc   | M, T, W, T, F, S, S               |       |
 * |                                 | cccccc  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
 * | AM, PM                          | a..aa   | AM, PM                            |       |
 * |                                 | aaa     | am, pm                            |       |
 * |                                 | aaaa    | a.m., p.m.                        | 2     |
 * |                                 | aaaaa   | a, p                              |       |
 * | AM, PM, noon, midnight          | b..bb   | AM, PM, noon, midnight            |       |
 * |                                 | bbb     | am, pm, noon, midnight            |       |
 * |                                 | bbbb    | a.m., p.m., noon, midnight        | 2     |
 * |                                 | bbbbb   | a, p, n, mi                       |       |
 * | Flexible day period             | B..BBB  | at night, in the morning, ...     |       |
 * |                                 | BBBB    | at night, in the morning, ...     | 2     |
 * |                                 | BBBBB   | at night, in the morning, ...     |       |
 * | Hour [1-12]                     | h       | 1, 2, ..., 11, 12                 |       |
 * |                                 | ho      | 1st, 2nd, ..., 11th, 12th         | 7     |
 * |                                 | hh      | 01, 02, ..., 11, 12               |       |
 * | Hour [0-23]                     | H       | 0, 1, 2, ..., 23                  |       |
 * |                                 | Ho      | 0th, 1st, 2nd, ..., 23rd          | 7     |
 * |                                 | HH      | 00, 01, 02, ..., 23               |       |
 * | Hour [0-11]                     | K       | 1, 2, ..., 11, 0                  |       |
 * |                                 | Ko      | 1st, 2nd, ..., 11th, 0th          | 7     |
 * |                                 | KK      | 01, 02, ..., 11, 00               |       |
 * | Hour [1-24]                     | k       | 24, 1, 2, ..., 23                 |       |
 * |                                 | ko      | 24th, 1st, 2nd, ..., 23rd         | 7     |
 * |                                 | kk      | 24, 01, 02, ..., 23               |       |
 * | Minute                          | m       | 0, 1, ..., 59                     |       |
 * |                                 | mo      | 0th, 1st, ..., 59th               | 7     |
 * |                                 | mm      | 00, 01, ..., 59                   |       |
 * | Second                          | s       | 0, 1, ..., 59                     |       |
 * |                                 | so      | 0th, 1st, ..., 59th               | 7     |
 * |                                 | ss      | 00, 01, ..., 59                   |       |
 * | Fraction of second              | S       | 0, 1, ..., 9                      |       |
 * |                                 | SS      | 00, 01, ..., 99                   |       |
 * |                                 | SSS     | 000, 001, ..., 999                |       |
 * |                                 | SSSS    | ...                               | 3     |
 * | Timezone (ISO-8601 w/ Z)        | X       | -08, +0530, Z                     |       |
 * |                                 | XX      | -0800, +0530, Z                   |       |
 * |                                 | XXX     | -08:00, +05:30, Z                 |       |
 * |                                 | XXXX    | -0800, +0530, Z, +123456          | 2     |
 * |                                 | XXXXX   | -08:00, +05:30, Z, +12:34:56      |       |
 * | Timezone (ISO-8601 w/o Z)       | x       | -08, +0530, +00                   |       |
 * |                                 | xx      | -0800, +0530, +0000               |       |
 * |                                 | xxx     | -08:00, +05:30, +00:00            | 2     |
 * |                                 | xxxx    | -0800, +0530, +0000, +123456      |       |
 * |                                 | xxxxx   | -08:00, +05:30, +00:00, +12:34:56 |       |
 * | Timezone (GMT)                  | O...OOO | GMT-8, GMT+5:30, GMT+0            |       |
 * |                                 | OOOO    | GMT-08:00, GMT+05:30, GMT+00:00   | 2     |
 * | Timezone (specific non-locat.)  | z...zzz | GMT-8, GMT+5:30, GMT+0            | 6     |
 * |                                 | zzzz    | GMT-08:00, GMT+05:30, GMT+00:00   | 2,6   |
 * | Seconds timestamp               | t       | 512969520                         | 7     |
 * |                                 | tt      | ...                               | 3,7   |
 * | Milliseconds timestamp          | T       | 512969520900                      | 7     |
 * |                                 | TT      | ...                               | 3,7   |
 * | Long localized date             | P       | 04/29/1453                        | 7     |
 * |                                 | PP      | Apr 29, 1453                      | 7     |
 * |                                 | PPP     | April 29th, 1453                  | 7     |
 * |                                 | PPPP    | Friday, April 29th, 1453          | 2,7   |
 * | Long localized time             | p       | 12:00 AM                          | 7     |
 * |                                 | pp      | 12:00:00 AM                       | 7     |
 * |                                 | ppp     | 12:00:00 AM GMT+2                 | 7     |
 * |                                 | pppp    | 12:00:00 AM GMT+02:00             | 2,7   |
 * | Combination of date and time    | Pp      | 04/29/1453, 12:00 AM              | 7     |
 * |                                 | PPpp    | Apr 29, 1453, 12:00:00 AM         | 7     |
 * |                                 | PPPppp  | April 29th, 1453 at ...           | 7     |
 * |                                 | PPPPpppp| Friday, April 29th, 1453 at ...   | 2,7   |
 * Notes:
 * 1. "Formatting" units (e.g. formatting quarter) in the default en-US locale
 *    are the same as "stand-alone" units, but are different in some languages.
 *    "Formatting" units are declined according to the rules of the language
 *    in the context of a date. "Stand-alone" units are always nominative singular:
 *
 *    `format(new Date(2017, 10, 6), 'do LLLL', {locale: cs}) //=> '6. listopad'`
 *
 *    `format(new Date(2017, 10, 6), 'do MMMM', {locale: cs}) //=> '6. listopadu'`
 *
 * 2. Any sequence of the identical letters is a pattern, unless it is escaped by
 *    the single quote characters (see below).
 *    If the sequence is longer than listed in table (e.g. `EEEEEEEEEEE`)
 *    the output will be the same as default pattern for this unit, usually
 *    the longest one (in case of ISO weekdays, `EEEE`). Default patterns for units
 *    are marked with "2" in the last column of the table.
 *
 *    `format(new Date(2017, 10, 6), 'MMM') //=> 'Nov'`
 *
 *    `format(new Date(2017, 10, 6), 'MMMM') //=> 'November'`
 *
 *    `format(new Date(2017, 10, 6), 'MMMMM') //=> 'N'`
 *
 *    `format(new Date(2017, 10, 6), 'MMMMMM') //=> 'November'`
 *
 *    `format(new Date(2017, 10, 6), 'MMMMMMM') //=> 'November'`
 *
 * 3. Some patterns could be unlimited length (such as `yyyyyyyy`).
 *    The output will be padded with zeros to match the length of the pattern.
 *
 *    `format(new Date(2017, 10, 6), 'yyyyyyyy') //=> '00002017'`
 *
 * 4. `QQQQQ` and `qqqqq` could be not strictly numerical in some locales.
 *    These tokens represent the shortest form of the quarter.
 *
 * 5. The main difference between `y` and `u` patterns are B.C. years:
 *
 *    | Year | `y` | `u` |
 *    |------|-----|-----|
 *    | AC 1 |   1 |   1 |
 *    | BC 1 |   1 |   0 |
 *    | BC 2 |   2 |  -1 |
 *
 *    Also `yy` always returns the last two digits of a year,
 *    while `uu` pads single digit years to 2 characters and returns other years unchanged:
 *
 *    | Year | `yy` | `uu` |
 *    |------|------|------|
 *    | 1    |   01 |   01 |
 *    | 14   |   14 |   14 |
 *    | 376  |   76 |  376 |
 *    | 1453 |   53 | 1453 |
 *
 *    The same difference is true for local and ISO week-numbering years (`Y` and `R`),
 *    except local week-numbering years are dependent on `options.weekStartsOn`
 *    and `options.firstWeekContainsDate` (compare [getISOWeekYear]{@link https://date-fns.org/docs/getISOWeekYear}
 *    and [getWeekYear]{@link https://date-fns.org/docs/getWeekYear}).
 *
 * 6. Specific non-location timezones are currently unavailable in `date-fns`,
 *    so right now these tokens fall back to GMT timezones.
 *
 * 7. These patterns are not in the Unicode Technical Standard #35:
 *    - `i`: ISO day of week
 *    - `I`: ISO week of year
 *    - `R`: ISO week-numbering year
 *    - `t`: seconds timestamp
 *    - `T`: milliseconds timestamp
 *    - `o`: ordinal number modifier
 *    - `P`: long localized date
 *    - `p`: long localized time
 *
 * 8. `YY` and `YYYY` tokens represent week-numbering years but they are often confused with years.
 *    You should enable `options.useAdditionalWeekYearTokens` to use them. See: https://git.io/fxCyr
 *
 * 9. `D` and `DD` tokens represent days of the year but they are often confused with days of the month.
 *    You should enable `options.useAdditionalDayOfYearTokens` to use them. See: https://git.io/fxCyr
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * - The second argument is now required for the sake of explicitness.
 *
 *   ```javascript
 *   // Before v2.0.0
 *   format(new Date(2016, 0, 1))
 *
 *   // v2.0.0 onward
 *   format(new Date(2016, 0, 1), "yyyy-MM-dd'T'HH:mm:ss.SSSxxx")
 *   ```
 *
 * - New format string API for `format` function
 *   which is based on [Unicode Technical Standard #35](https://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table).
 *   See [this post](https://blog.date-fns.org/post/unicode-tokens-in-date-fns-v2-sreatyki91jg) for more details.
 *
 * - Characters are now escaped using single quote symbols (`'`) instead of square brackets.
 *
 * @param {Date|Number} date - the original date
 * @param {String} format - the string of tokens
 * @param {Object} [options] - an object with options.
 * @param {Locale} [options.locale=defaultLocale] - the locale object. See [Locale]{@link https://date-fns.org/docs/Locale}
 * @param {0|1|2|3|4|5|6} [options.weekStartsOn=0] - the index of the first day of the week (0 - Sunday)
 * @param {Number} [options.firstWeekContainsDate=1] - the day of January, which is
 * @param {Boolean} [options.useAdditionalWeekYearTokens=false] - if true, allows usage of the week-numbering year tokens `YY` and `YYYY`;
 *   see: https://git.io/fxCyr
 * @param {Boolean} [options.useAdditionalDayOfYearTokens=false] - if true, allows usage of the day of year tokens `D` and `DD`;
 *   see: https://git.io/fxCyr
 * @returns {String} the formatted date string
 * @throws {TypeError} 2 arguments required
 * @throws {RangeError} `date` must not be Invalid Date
 * @throws {RangeError} `options.locale` must contain `localize` property
 * @throws {RangeError} `options.locale` must contain `formatLong` property
 * @throws {RangeError} `options.weekStartsOn` must be between 0 and 6
 * @throws {RangeError} `options.firstWeekContainsDate` must be between 1 and 7
 * @throws {RangeError} use `yyyy` instead of `YYYY` for formatting years using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} use `yy` instead of `YY` for formatting years using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} use `d` instead of `D` for formatting days of the month using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} use `dd` instead of `DD` for formatting days of the month using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} format string contains an unescaped latin alphabet character
 *
 * @example
 * // Represent 11 February 2014 in middle-endian format:
 * var result = format(new Date(2014, 1, 11), 'MM/dd/yyyy')
 * //=> '02/11/2014'
 *
 * @example
 * // Represent 2 July 2014 in Esperanto:
 * import { eoLocale } from 'date-fns/locale/eo'
 * var result = format(new Date(2014, 6, 2), "do 'de' MMMM yyyy", {
 *   locale: eoLocale
 * })
 * //=> '2-a de julio 2014'
 *
 * @example
 * // Escape string by single quote characters:
 * var result = format(new Date(2014, 6, 2, 15), "h 'o''clock'")
 * //=> "3 o'clock"
 */

function format(dirtyDate, dirtyFormatStr, dirtyOptions) {
  (0,_lib_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(2, arguments);
  var formatStr = String(dirtyFormatStr);
  var options = dirtyOptions || {};
  var locale = options.locale || _locale_en_US_index_js__WEBPACK_IMPORTED_MODULE_1__["default"];
  var localeFirstWeekContainsDate = locale.options && locale.options.firstWeekContainsDate;
  var defaultFirstWeekContainsDate = localeFirstWeekContainsDate == null ? 1 : (0,_lib_toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(localeFirstWeekContainsDate);
  var firstWeekContainsDate = options.firstWeekContainsDate == null ? defaultFirstWeekContainsDate : (0,_lib_toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(options.firstWeekContainsDate); // Test if weekStartsOn is between 1 and 7 _and_ is not NaN

  if (!(firstWeekContainsDate >= 1 && firstWeekContainsDate <= 7)) {
    throw new RangeError('firstWeekContainsDate must be between 1 and 7 inclusively');
  }

  var localeWeekStartsOn = locale.options && locale.options.weekStartsOn;
  var defaultWeekStartsOn = localeWeekStartsOn == null ? 0 : (0,_lib_toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(localeWeekStartsOn);
  var weekStartsOn = options.weekStartsOn == null ? defaultWeekStartsOn : (0,_lib_toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(options.weekStartsOn); // Test if weekStartsOn is between 0 and 6 _and_ is not NaN

  if (!(weekStartsOn >= 0 && weekStartsOn <= 6)) {
    throw new RangeError('weekStartsOn must be between 0 and 6 inclusively');
  }

  if (!locale.localize) {
    throw new RangeError('locale must contain localize property');
  }

  if (!locale.formatLong) {
    throw new RangeError('locale must contain formatLong property');
  }

  var originalDate = (0,_toDate_index_js__WEBPACK_IMPORTED_MODULE_3__["default"])(dirtyDate);

  if (!(0,_isValid_index_js__WEBPACK_IMPORTED_MODULE_4__["default"])(originalDate)) {
    throw new RangeError('Invalid time value');
  } // Convert the date in system timezone to the same date in UTC+00:00 timezone.
  // This ensures that when UTC functions will be implemented, locales will be compatible with them.
  // See an issue about UTC functions: https://github.com/date-fns/date-fns/issues/376


  var timezoneOffset = (0,_lib_getTimezoneOffsetInMilliseconds_index_js__WEBPACK_IMPORTED_MODULE_5__["default"])(originalDate);
  var utcDate = (0,_subMilliseconds_index_js__WEBPACK_IMPORTED_MODULE_6__["default"])(originalDate, timezoneOffset);
  var formatterOptions = {
    firstWeekContainsDate: firstWeekContainsDate,
    weekStartsOn: weekStartsOn,
    locale: locale,
    _originalDate: originalDate
  };
  var result = formatStr.match(longFormattingTokensRegExp).map(function (substring) {
    var firstCharacter = substring[0];

    if (firstCharacter === 'p' || firstCharacter === 'P') {
      var longFormatter = _lib_format_longFormatters_index_js__WEBPACK_IMPORTED_MODULE_7__["default"][firstCharacter];
      return longFormatter(substring, locale.formatLong, formatterOptions);
    }

    return substring;
  }).join('').match(formattingTokensRegExp).map(function (substring) {
    // Replace two single quote characters with one single quote character
    if (substring === "''") {
      return "'";
    }

    var firstCharacter = substring[0];

    if (firstCharacter === "'") {
      return cleanEscapedString(substring);
    }

    var formatter = _lib_format_formatters_index_js__WEBPACK_IMPORTED_MODULE_8__["default"][firstCharacter];

    if (formatter) {
      if (!options.useAdditionalWeekYearTokens && (0,_lib_protectedTokens_index_js__WEBPACK_IMPORTED_MODULE_9__.isProtectedWeekYearToken)(substring)) {
        (0,_lib_protectedTokens_index_js__WEBPACK_IMPORTED_MODULE_9__.throwProtectedError)(substring, dirtyFormatStr, dirtyDate);
      }

      if (!options.useAdditionalDayOfYearTokens && (0,_lib_protectedTokens_index_js__WEBPACK_IMPORTED_MODULE_9__.isProtectedDayOfYearToken)(substring)) {
        (0,_lib_protectedTokens_index_js__WEBPACK_IMPORTED_MODULE_9__.throwProtectedError)(substring, dirtyFormatStr, dirtyDate);
      }

      return formatter(utcDate, substring, locale.localize, formatterOptions);
    }

    if (firstCharacter.match(unescapedLatinCharacterRegExp)) {
      throw new RangeError('Format string contains an unescaped latin alphabet character `' + firstCharacter + '`');
    }

    return substring;
  }).join('');
  return result;
}

function cleanEscapedString(input) {
  return input.match(escapedStringRegExp)[1].replace(doubleQuoteRegExp, "'");
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/isDate/index.js":
/*!**********************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/isDate/index.js ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ isDate)
/* harmony export */ });
/* harmony import */ var _lib_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../_lib/requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");

/**
 * @name isDate
 * @category Common Helpers
 * @summary Is the given value a date?
 *
 * @description
 * Returns true if the given value is an instance of Date. The function works for dates transferred across iframes.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {*} value - the value to check
 * @returns {boolean} true if the given value is a date
 * @throws {TypeError} 1 arguments required
 *
 * @example
 * // For a valid date:
 * const result = isDate(new Date())
 * //=> true
 *
 * @example
 * // For an invalid date:
 * const result = isDate(new Date(NaN))
 * //=> true
 *
 * @example
 * // For some value:
 * const result = isDate('2014-02-31')
 * //=> false
 *
 * @example
 * // For an object:
 * const result = isDate({})
 * //=> false
 */

function isDate(value) {
  (0,_lib_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(1, arguments);
  return value instanceof Date || typeof value === 'object' && Object.prototype.toString.call(value) === '[object Date]';
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/isValid/index.js":
/*!***********************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/isValid/index.js ***!
  \***********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ isValid)
/* harmony export */ });
/* harmony import */ var _isDate_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../isDate/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/isDate/index.js");
/* harmony import */ var _toDate_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../toDate/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/toDate/index.js");
/* harmony import */ var _lib_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../_lib/requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");



/**
 * @name isValid
 * @category Common Helpers
 * @summary Is the given date valid?
 *
 * @description
 * Returns false if argument is Invalid Date and true otherwise.
 * Argument is converted to Date using `toDate`. See [toDate]{@link https://date-fns.org/docs/toDate}
 * Invalid Date is a Date, whose time value is NaN.
 *
 * Time value of Date: http://es5.github.io/#x15.9.1.1
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * - Now `isValid` doesn't throw an exception
 *   if the first argument is not an instance of Date.
 *   Instead, argument is converted beforehand using `toDate`.
 *
 *   Examples:
 *
 *   | `isValid` argument        | Before v2.0.0 | v2.0.0 onward |
 *   |---------------------------|---------------|---------------|
 *   | `new Date()`              | `true`        | `true`        |
 *   | `new Date('2016-01-01')`  | `true`        | `true`        |
 *   | `new Date('')`            | `false`       | `false`       |
 *   | `new Date(1488370835081)` | `true`        | `true`        |
 *   | `new Date(NaN)`           | `false`       | `false`       |
 *   | `'2016-01-01'`            | `TypeError`   | `false`       |
 *   | `''`                      | `TypeError`   | `false`       |
 *   | `1488370835081`           | `TypeError`   | `true`        |
 *   | `NaN`                     | `TypeError`   | `false`       |
 *
 *   We introduce this change to make *date-fns* consistent with ECMAScript behavior
 *   that try to coerce arguments to the expected type
 *   (which is also the case with other *date-fns* functions).
 *
 * @param {*} date - the date to check
 * @returns {Boolean} the date is valid
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // For the valid date:
 * const result = isValid(new Date(2014, 1, 31))
 * //=> true
 *
 * @example
 * // For the value, convertable into a date:
 * const result = isValid(1393804800000)
 * //=> true
 *
 * @example
 * // For the invalid date:
 * const result = isValid(new Date(''))
 * //=> false
 */

function isValid(dirtyDate) {
  (0,_lib_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(1, arguments);

  if (!(0,_isDate_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(dirtyDate) && typeof dirtyDate !== 'number') {
    return false;
  }

  var date = (0,_toDate_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(dirtyDate);
  return !isNaN(Number(date));
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/_lib/buildFormatLongFn/index.js":
/*!*********************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/_lib/buildFormatLongFn/index.js ***!
  \*********************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ buildFormatLongFn)
/* harmony export */ });
function buildFormatLongFn(args) {
  return function () {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    // TODO: Remove String()
    var width = options.width ? String(options.width) : args.defaultWidth;
    var format = args.formats[width] || args.formats[args.defaultWidth];
    return format;
  };
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/_lib/buildLocalizeFn/index.js":
/*!*******************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/_lib/buildLocalizeFn/index.js ***!
  \*******************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ buildLocalizeFn)
/* harmony export */ });
function buildLocalizeFn(args) {
  return function (dirtyIndex, dirtyOptions) {
    var options = dirtyOptions || {};
    var context = options.context ? String(options.context) : 'standalone';
    var valuesArray;

    if (context === 'formatting' && args.formattingValues) {
      var defaultWidth = args.defaultFormattingWidth || args.defaultWidth;
      var width = options.width ? String(options.width) : defaultWidth;
      valuesArray = args.formattingValues[width] || args.formattingValues[defaultWidth];
    } else {
      var _defaultWidth = args.defaultWidth;

      var _width = options.width ? String(options.width) : args.defaultWidth;

      valuesArray = args.values[_width] || args.values[_defaultWidth];
    }

    var index = args.argumentCallback ? args.argumentCallback(dirtyIndex) : dirtyIndex; // @ts-ignore: For some reason TypeScript just don't want to match it, no matter how hard we try. I challenge you to try to remove it!

    return valuesArray[index];
  };
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/_lib/buildMatchFn/index.js":
/*!****************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/_lib/buildMatchFn/index.js ***!
  \****************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ buildMatchFn)
/* harmony export */ });
function buildMatchFn(args) {
  return function (string) {
    var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var width = options.width;
    var matchPattern = width && args.matchPatterns[width] || args.matchPatterns[args.defaultMatchWidth];
    var matchResult = string.match(matchPattern);

    if (!matchResult) {
      return null;
    }

    var matchedString = matchResult[0];
    var parsePatterns = width && args.parsePatterns[width] || args.parsePatterns[args.defaultParseWidth];
    var key = Array.isArray(parsePatterns) ? findIndex(parsePatterns, function (pattern) {
      return pattern.test(matchedString);
    }) : findKey(parsePatterns, function (pattern) {
      return pattern.test(matchedString);
    });
    var value;
    value = args.valueCallback ? args.valueCallback(key) : key;
    value = options.valueCallback ? options.valueCallback(value) : value;
    var rest = string.slice(matchedString.length);
    return {
      value: value,
      rest: rest
    };
  };
}

function findKey(object, predicate) {
  for (var key in object) {
    if (object.hasOwnProperty(key) && predicate(object[key])) {
      return key;
    }
  }

  return undefined;
}

function findIndex(array, predicate) {
  for (var key = 0; key < array.length; key++) {
    if (predicate(array[key])) {
      return key;
    }
  }

  return undefined;
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/_lib/buildMatchPatternFn/index.js":
/*!***********************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/_lib/buildMatchPatternFn/index.js ***!
  \***********************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ buildMatchPatternFn)
/* harmony export */ });
function buildMatchPatternFn(args) {
  return function (string) {
    var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var matchResult = string.match(args.matchPattern);
    if (!matchResult) return null;
    var matchedString = matchResult[0];
    var parseResult = string.match(args.parsePattern);
    if (!parseResult) return null;
    var value = args.valueCallback ? args.valueCallback(parseResult[0]) : parseResult[0];
    value = options.valueCallback ? options.valueCallback(value) : value;
    var rest = string.slice(matchedString.length);
    return {
      value: value,
      rest: rest
    };
  };
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/_lib/formatDistance/index.js":
/*!************************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/_lib/formatDistance/index.js ***!
  \************************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
var formatDistanceLocale = {
  lessThanXSeconds: {
    one: 'less than a second',
    other: 'less than {{count}} seconds'
  },
  xSeconds: {
    one: '1 second',
    other: '{{count}} seconds'
  },
  halfAMinute: 'half a minute',
  lessThanXMinutes: {
    one: 'less than a minute',
    other: 'less than {{count}} minutes'
  },
  xMinutes: {
    one: '1 minute',
    other: '{{count}} minutes'
  },
  aboutXHours: {
    one: 'about 1 hour',
    other: 'about {{count}} hours'
  },
  xHours: {
    one: '1 hour',
    other: '{{count}} hours'
  },
  xDays: {
    one: '1 day',
    other: '{{count}} days'
  },
  aboutXWeeks: {
    one: 'about 1 week',
    other: 'about {{count}} weeks'
  },
  xWeeks: {
    one: '1 week',
    other: '{{count}} weeks'
  },
  aboutXMonths: {
    one: 'about 1 month',
    other: 'about {{count}} months'
  },
  xMonths: {
    one: '1 month',
    other: '{{count}} months'
  },
  aboutXYears: {
    one: 'about 1 year',
    other: 'about {{count}} years'
  },
  xYears: {
    one: '1 year',
    other: '{{count}} years'
  },
  overXYears: {
    one: 'over 1 year',
    other: 'over {{count}} years'
  },
  almostXYears: {
    one: 'almost 1 year',
    other: 'almost {{count}} years'
  }
};

var formatDistance = function (token, count, options) {
  var result;
  var tokenValue = formatDistanceLocale[token];

  if (typeof tokenValue === 'string') {
    result = tokenValue;
  } else if (count === 1) {
    result = tokenValue.one;
  } else {
    result = tokenValue.other.replace('{{count}}', count.toString());
  }

  if (options !== null && options !== void 0 && options.addSuffix) {
    if (options.comparison && options.comparison > 0) {
      return 'in ' + result;
    } else {
      return result + ' ago';
    }
  }

  return result;
};

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (formatDistance);

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/_lib/formatLong/index.js":
/*!********************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/_lib/formatLong/index.js ***!
  \********************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _lib_buildFormatLongFn_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../../_lib/buildFormatLongFn/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/_lib/buildFormatLongFn/index.js");

var dateFormats = {
  full: 'EEEE, MMMM do, y',
  long: 'MMMM do, y',
  medium: 'MMM d, y',
  short: 'MM/dd/yyyy'
};
var timeFormats = {
  full: 'h:mm:ss a zzzz',
  long: 'h:mm:ss a z',
  medium: 'h:mm:ss a',
  short: 'h:mm a'
};
var dateTimeFormats = {
  full: "{{date}} 'at' {{time}}",
  long: "{{date}} 'at' {{time}}",
  medium: '{{date}}, {{time}}',
  short: '{{date}}, {{time}}'
};
var formatLong = {
  date: (0,_lib_buildFormatLongFn_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])({
    formats: dateFormats,
    defaultWidth: 'full'
  }),
  time: (0,_lib_buildFormatLongFn_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])({
    formats: timeFormats,
    defaultWidth: 'full'
  }),
  dateTime: (0,_lib_buildFormatLongFn_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])({
    formats: dateTimeFormats,
    defaultWidth: 'full'
  })
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (formatLong);

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/_lib/formatRelative/index.js":
/*!************************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/_lib/formatRelative/index.js ***!
  \************************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
var formatRelativeLocale = {
  lastWeek: "'last' eeee 'at' p",
  yesterday: "'yesterday at' p",
  today: "'today at' p",
  tomorrow: "'tomorrow at' p",
  nextWeek: "eeee 'at' p",
  other: 'P'
};

var formatRelative = function (token, _date, _baseDate, _options) {
  return formatRelativeLocale[token];
};

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (formatRelative);

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/_lib/localize/index.js":
/*!******************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/_lib/localize/index.js ***!
  \******************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _lib_buildLocalizeFn_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../../_lib/buildLocalizeFn/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/_lib/buildLocalizeFn/index.js");

var eraValues = {
  narrow: ['B', 'A'],
  abbreviated: ['BC', 'AD'],
  wide: ['Before Christ', 'Anno Domini']
};
var quarterValues = {
  narrow: ['1', '2', '3', '4'],
  abbreviated: ['Q1', 'Q2', 'Q3', 'Q4'],
  wide: ['1st quarter', '2nd quarter', '3rd quarter', '4th quarter']
}; // Note: in English, the names of days of the week and months are capitalized.
// If you are making a new locale based on this one, check if the same is true for the language you're working on.
// Generally, formatted dates should look like they are in the middle of a sentence,
// e.g. in Spanish language the weekdays and months should be in the lowercase.

var monthValues = {
  narrow: ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'],
  abbreviated: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
  wide: ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December']
};
var dayValues = {
  narrow: ['S', 'M', 'T', 'W', 'T', 'F', 'S'],
  short: ['Su', 'Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa'],
  abbreviated: ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
  wide: ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday']
};
var dayPeriodValues = {
  narrow: {
    am: 'a',
    pm: 'p',
    midnight: 'mi',
    noon: 'n',
    morning: 'morning',
    afternoon: 'afternoon',
    evening: 'evening',
    night: 'night'
  },
  abbreviated: {
    am: 'AM',
    pm: 'PM',
    midnight: 'midnight',
    noon: 'noon',
    morning: 'morning',
    afternoon: 'afternoon',
    evening: 'evening',
    night: 'night'
  },
  wide: {
    am: 'a.m.',
    pm: 'p.m.',
    midnight: 'midnight',
    noon: 'noon',
    morning: 'morning',
    afternoon: 'afternoon',
    evening: 'evening',
    night: 'night'
  }
};
var formattingDayPeriodValues = {
  narrow: {
    am: 'a',
    pm: 'p',
    midnight: 'mi',
    noon: 'n',
    morning: 'in the morning',
    afternoon: 'in the afternoon',
    evening: 'in the evening',
    night: 'at night'
  },
  abbreviated: {
    am: 'AM',
    pm: 'PM',
    midnight: 'midnight',
    noon: 'noon',
    morning: 'in the morning',
    afternoon: 'in the afternoon',
    evening: 'in the evening',
    night: 'at night'
  },
  wide: {
    am: 'a.m.',
    pm: 'p.m.',
    midnight: 'midnight',
    noon: 'noon',
    morning: 'in the morning',
    afternoon: 'in the afternoon',
    evening: 'in the evening',
    night: 'at night'
  }
};

var ordinalNumber = function (dirtyNumber, _options) {
  var number = Number(dirtyNumber); // If ordinal numbers depend on context, for example,
  // if they are different for different grammatical genders,
  // use `options.unit`.
  //
  // `unit` can be 'year', 'quarter', 'month', 'week', 'date', 'dayOfYear',
  // 'day', 'hour', 'minute', 'second'.

  var rem100 = number % 100;

  if (rem100 > 20 || rem100 < 10) {
    switch (rem100 % 10) {
      case 1:
        return number + 'st';

      case 2:
        return number + 'nd';

      case 3:
        return number + 'rd';
    }
  }

  return number + 'th';
};

var localize = {
  ordinalNumber: ordinalNumber,
  era: (0,_lib_buildLocalizeFn_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])({
    values: eraValues,
    defaultWidth: 'wide'
  }),
  quarter: (0,_lib_buildLocalizeFn_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])({
    values: quarterValues,
    defaultWidth: 'wide',
    argumentCallback: function (quarter) {
      return quarter - 1;
    }
  }),
  month: (0,_lib_buildLocalizeFn_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])({
    values: monthValues,
    defaultWidth: 'wide'
  }),
  day: (0,_lib_buildLocalizeFn_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])({
    values: dayValues,
    defaultWidth: 'wide'
  }),
  dayPeriod: (0,_lib_buildLocalizeFn_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])({
    values: dayPeriodValues,
    defaultWidth: 'wide',
    formattingValues: formattingDayPeriodValues,
    defaultFormattingWidth: 'wide'
  })
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (localize);

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/_lib/match/index.js":
/*!***************************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/_lib/match/index.js ***!
  \***************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _lib_buildMatchFn_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../_lib/buildMatchFn/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/_lib/buildMatchFn/index.js");
/* harmony import */ var _lib_buildMatchPatternFn_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../../_lib/buildMatchPatternFn/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/_lib/buildMatchPatternFn/index.js");


var matchOrdinalNumberPattern = /^(\d+)(th|st|nd|rd)?/i;
var parseOrdinalNumberPattern = /\d+/i;
var matchEraPatterns = {
  narrow: /^(b|a)/i,
  abbreviated: /^(b\.?\s?c\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?)/i,
  wide: /^(before christ|before common era|anno domini|common era)/i
};
var parseEraPatterns = {
  any: [/^b/i, /^(a|c)/i]
};
var matchQuarterPatterns = {
  narrow: /^[1234]/i,
  abbreviated: /^q[1234]/i,
  wide: /^[1234](th|st|nd|rd)? quarter/i
};
var parseQuarterPatterns = {
  any: [/1/i, /2/i, /3/i, /4/i]
};
var matchMonthPatterns = {
  narrow: /^[jfmasond]/i,
  abbreviated: /^(jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec)/i,
  wide: /^(january|february|march|april|may|june|july|august|september|october|november|december)/i
};
var parseMonthPatterns = {
  narrow: [/^j/i, /^f/i, /^m/i, /^a/i, /^m/i, /^j/i, /^j/i, /^a/i, /^s/i, /^o/i, /^n/i, /^d/i],
  any: [/^ja/i, /^f/i, /^mar/i, /^ap/i, /^may/i, /^jun/i, /^jul/i, /^au/i, /^s/i, /^o/i, /^n/i, /^d/i]
};
var matchDayPatterns = {
  narrow: /^[smtwf]/i,
  short: /^(su|mo|tu|we|th|fr|sa)/i,
  abbreviated: /^(sun|mon|tue|wed|thu|fri|sat)/i,
  wide: /^(sunday|monday|tuesday|wednesday|thursday|friday|saturday)/i
};
var parseDayPatterns = {
  narrow: [/^s/i, /^m/i, /^t/i, /^w/i, /^t/i, /^f/i, /^s/i],
  any: [/^su/i, /^m/i, /^tu/i, /^w/i, /^th/i, /^f/i, /^sa/i]
};
var matchDayPeriodPatterns = {
  narrow: /^(a|p|mi|n|(in the|at) (morning|afternoon|evening|night))/i,
  any: /^([ap]\.?\s?m\.?|midnight|noon|(in the|at) (morning|afternoon|evening|night))/i
};
var parseDayPeriodPatterns = {
  any: {
    am: /^a/i,
    pm: /^p/i,
    midnight: /^mi/i,
    noon: /^no/i,
    morning: /morning/i,
    afternoon: /afternoon/i,
    evening: /evening/i,
    night: /night/i
  }
};
var match = {
  ordinalNumber: (0,_lib_buildMatchPatternFn_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])({
    matchPattern: matchOrdinalNumberPattern,
    parsePattern: parseOrdinalNumberPattern,
    valueCallback: function (value) {
      return parseInt(value, 10);
    }
  }),
  era: (0,_lib_buildMatchFn_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])({
    matchPatterns: matchEraPatterns,
    defaultMatchWidth: 'wide',
    parsePatterns: parseEraPatterns,
    defaultParseWidth: 'any'
  }),
  quarter: (0,_lib_buildMatchFn_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])({
    matchPatterns: matchQuarterPatterns,
    defaultMatchWidth: 'wide',
    parsePatterns: parseQuarterPatterns,
    defaultParseWidth: 'any',
    valueCallback: function (index) {
      return index + 1;
    }
  }),
  month: (0,_lib_buildMatchFn_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])({
    matchPatterns: matchMonthPatterns,
    defaultMatchWidth: 'wide',
    parsePatterns: parseMonthPatterns,
    defaultParseWidth: 'any'
  }),
  day: (0,_lib_buildMatchFn_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])({
    matchPatterns: matchDayPatterns,
    defaultMatchWidth: 'wide',
    parsePatterns: parseDayPatterns,
    defaultParseWidth: 'any'
  }),
  dayPeriod: (0,_lib_buildMatchFn_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])({
    matchPatterns: matchDayPeriodPatterns,
    defaultMatchWidth: 'any',
    parsePatterns: parseDayPeriodPatterns,
    defaultParseWidth: 'any'
  })
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (match);

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/index.js":
/*!****************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/index.js ***!
  \****************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _lib_formatDistance_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_lib/formatDistance/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/_lib/formatDistance/index.js");
/* harmony import */ var _lib_formatLong_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_lib/formatLong/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/_lib/formatLong/index.js");
/* harmony import */ var _lib_formatRelative_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./_lib/formatRelative/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/_lib/formatRelative/index.js");
/* harmony import */ var _lib_localize_index_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./_lib/localize/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/_lib/localize/index.js");
/* harmony import */ var _lib_match_index_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./_lib/match/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/_lib/match/index.js");






/**
 * @type {Locale}
 * @category Locales
 * @summary English locale (United States).
 * @language English
 * @iso-639-2 eng
 * @author Sasha Koss [@kossnocorp]{@link https://github.com/kossnocorp}
 * @author Lesha Koss [@leshakoss]{@link https://github.com/leshakoss}
 */
var locale = {
  code: 'en-US',
  formatDistance: _lib_formatDistance_index_js__WEBPACK_IMPORTED_MODULE_0__["default"],
  formatLong: _lib_formatLong_index_js__WEBPACK_IMPORTED_MODULE_1__["default"],
  formatRelative: _lib_formatRelative_index_js__WEBPACK_IMPORTED_MODULE_2__["default"],
  localize: _lib_localize_index_js__WEBPACK_IMPORTED_MODULE_3__["default"],
  match: _lib_match_index_js__WEBPACK_IMPORTED_MODULE_4__["default"],
  options: {
    weekStartsOn: 0
    /* Sunday */
    ,
    firstWeekContainsDate: 1
  }
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (locale);

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/parse/_lib/parsers/index.js":
/*!**********************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/parse/_lib/parsers/index.js ***!
  \**********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _lib_getUTCWeekYear_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../../_lib/getUTCWeekYear/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getUTCWeekYear/index.js");
/* harmony import */ var _lib_setUTCDay_index_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../../_lib/setUTCDay/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/setUTCDay/index.js");
/* harmony import */ var _lib_setUTCISODay_index_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../../_lib/setUTCISODay/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/setUTCISODay/index.js");
/* harmony import */ var _lib_setUTCISOWeek_index_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../../_lib/setUTCISOWeek/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/setUTCISOWeek/index.js");
/* harmony import */ var _lib_setUTCWeek_index_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../../_lib/setUTCWeek/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/setUTCWeek/index.js");
/* harmony import */ var _lib_startOfUTCISOWeek_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../../_lib/startOfUTCISOWeek/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCISOWeek/index.js");
/* harmony import */ var _lib_startOfUTCWeek_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../_lib/startOfUTCWeek/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/startOfUTCWeek/index.js");







var MILLISECONDS_IN_HOUR = 3600000;
var MILLISECONDS_IN_MINUTE = 60000;
var MILLISECONDS_IN_SECOND = 1000;
var numericPatterns = {
  month: /^(1[0-2]|0?\d)/,
  // 0 to 12
  date: /^(3[0-1]|[0-2]?\d)/,
  // 0 to 31
  dayOfYear: /^(36[0-6]|3[0-5]\d|[0-2]?\d?\d)/,
  // 0 to 366
  week: /^(5[0-3]|[0-4]?\d)/,
  // 0 to 53
  hour23h: /^(2[0-3]|[0-1]?\d)/,
  // 0 to 23
  hour24h: /^(2[0-4]|[0-1]?\d)/,
  // 0 to 24
  hour11h: /^(1[0-1]|0?\d)/,
  // 0 to 11
  hour12h: /^(1[0-2]|0?\d)/,
  // 0 to 12
  minute: /^[0-5]?\d/,
  // 0 to 59
  second: /^[0-5]?\d/,
  // 0 to 59
  singleDigit: /^\d/,
  // 0 to 9
  twoDigits: /^\d{1,2}/,
  // 0 to 99
  threeDigits: /^\d{1,3}/,
  // 0 to 999
  fourDigits: /^\d{1,4}/,
  // 0 to 9999
  anyDigitsSigned: /^-?\d+/,
  singleDigitSigned: /^-?\d/,
  // 0 to 9, -0 to -9
  twoDigitsSigned: /^-?\d{1,2}/,
  // 0 to 99, -0 to -99
  threeDigitsSigned: /^-?\d{1,3}/,
  // 0 to 999, -0 to -999
  fourDigitsSigned: /^-?\d{1,4}/ // 0 to 9999, -0 to -9999

};
var timezonePatterns = {
  basicOptionalMinutes: /^([+-])(\d{2})(\d{2})?|Z/,
  basic: /^([+-])(\d{2})(\d{2})|Z/,
  basicOptionalSeconds: /^([+-])(\d{2})(\d{2})((\d{2}))?|Z/,
  extended: /^([+-])(\d{2}):(\d{2})|Z/,
  extendedOptionalSeconds: /^([+-])(\d{2}):(\d{2})(:(\d{2}))?|Z/
};

function parseNumericPattern(pattern, string, valueCallback) {
  var matchResult = string.match(pattern);

  if (!matchResult) {
    return null;
  }

  var value = parseInt(matchResult[0], 10);
  return {
    value: valueCallback ? valueCallback(value) : value,
    rest: string.slice(matchResult[0].length)
  };
}

function parseTimezonePattern(pattern, string) {
  var matchResult = string.match(pattern);

  if (!matchResult) {
    return null;
  } // Input is 'Z'


  if (matchResult[0] === 'Z') {
    return {
      value: 0,
      rest: string.slice(1)
    };
  }

  var sign = matchResult[1] === '+' ? 1 : -1;
  var hours = matchResult[2] ? parseInt(matchResult[2], 10) : 0;
  var minutes = matchResult[3] ? parseInt(matchResult[3], 10) : 0;
  var seconds = matchResult[5] ? parseInt(matchResult[5], 10) : 0;
  return {
    value: sign * (hours * MILLISECONDS_IN_HOUR + minutes * MILLISECONDS_IN_MINUTE + seconds * MILLISECONDS_IN_SECOND),
    rest: string.slice(matchResult[0].length)
  };
}

function parseAnyDigitsSigned(string, valueCallback) {
  return parseNumericPattern(numericPatterns.anyDigitsSigned, string, valueCallback);
}

function parseNDigits(n, string, valueCallback) {
  switch (n) {
    case 1:
      return parseNumericPattern(numericPatterns.singleDigit, string, valueCallback);

    case 2:
      return parseNumericPattern(numericPatterns.twoDigits, string, valueCallback);

    case 3:
      return parseNumericPattern(numericPatterns.threeDigits, string, valueCallback);

    case 4:
      return parseNumericPattern(numericPatterns.fourDigits, string, valueCallback);

    default:
      return parseNumericPattern(new RegExp('^\\d{1,' + n + '}'), string, valueCallback);
  }
}

function parseNDigitsSigned(n, string, valueCallback) {
  switch (n) {
    case 1:
      return parseNumericPattern(numericPatterns.singleDigitSigned, string, valueCallback);

    case 2:
      return parseNumericPattern(numericPatterns.twoDigitsSigned, string, valueCallback);

    case 3:
      return parseNumericPattern(numericPatterns.threeDigitsSigned, string, valueCallback);

    case 4:
      return parseNumericPattern(numericPatterns.fourDigitsSigned, string, valueCallback);

    default:
      return parseNumericPattern(new RegExp('^-?\\d{1,' + n + '}'), string, valueCallback);
  }
}

function dayPeriodEnumToHours(enumValue) {
  switch (enumValue) {
    case 'morning':
      return 4;

    case 'evening':
      return 17;

    case 'pm':
    case 'noon':
    case 'afternoon':
      return 12;

    case 'am':
    case 'midnight':
    case 'night':
    default:
      return 0;
  }
}

function normalizeTwoDigitYear(twoDigitYear, currentYear) {
  var isCommonEra = currentYear > 0; // Absolute number of the current year:
  // 1 -> 1 AC
  // 0 -> 1 BC
  // -1 -> 2 BC

  var absCurrentYear = isCommonEra ? currentYear : 1 - currentYear;
  var result;

  if (absCurrentYear <= 50) {
    result = twoDigitYear || 100;
  } else {
    var rangeEnd = absCurrentYear + 50;
    var rangeEndCentury = Math.floor(rangeEnd / 100) * 100;
    var isPreviousCentury = twoDigitYear >= rangeEnd % 100;
    result = twoDigitYear + rangeEndCentury - (isPreviousCentury ? 100 : 0);
  }

  return isCommonEra ? result : 1 - result;
}

var DAYS_IN_MONTH = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
var DAYS_IN_MONTH_LEAP_YEAR = [31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31]; // User for validation

function isLeapYearIndex(year) {
  return year % 400 === 0 || year % 4 === 0 && year % 100 !== 0;
}
/*
 * |     | Unit                           |     | Unit                           |
 * |-----|--------------------------------|-----|--------------------------------|
 * |  a  | AM, PM                         |  A* | Milliseconds in day            |
 * |  b  | AM, PM, noon, midnight         |  B  | Flexible day period            |
 * |  c  | Stand-alone local day of week  |  C* | Localized hour w/ day period   |
 * |  d  | Day of month                   |  D  | Day of year                    |
 * |  e  | Local day of week              |  E  | Day of week                    |
 * |  f  |                                |  F* | Day of week in month           |
 * |  g* | Modified Julian day            |  G  | Era                            |
 * |  h  | Hour [1-12]                    |  H  | Hour [0-23]                    |
 * |  i! | ISO day of week                |  I! | ISO week of year               |
 * |  j* | Localized hour w/ day period   |  J* | Localized hour w/o day period  |
 * |  k  | Hour [1-24]                    |  K  | Hour [0-11]                    |
 * |  l* | (deprecated)                   |  L  | Stand-alone month              |
 * |  m  | Minute                         |  M  | Month                          |
 * |  n  |                                |  N  |                                |
 * |  o! | Ordinal number modifier        |  O* | Timezone (GMT)                 |
 * |  p  |                                |  P  |                                |
 * |  q  | Stand-alone quarter            |  Q  | Quarter                        |
 * |  r* | Related Gregorian year         |  R! | ISO week-numbering year        |
 * |  s  | Second                         |  S  | Fraction of second             |
 * |  t! | Seconds timestamp              |  T! | Milliseconds timestamp         |
 * |  u  | Extended year                  |  U* | Cyclic year                    |
 * |  v* | Timezone (generic non-locat.)  |  V* | Timezone (location)            |
 * |  w  | Local week of year             |  W* | Week of month                  |
 * |  x  | Timezone (ISO-8601 w/o Z)      |  X  | Timezone (ISO-8601)            |
 * |  y  | Year (abs)                     |  Y  | Local week-numbering year      |
 * |  z* | Timezone (specific non-locat.) |  Z* | Timezone (aliases)             |
 *
 * Letters marked by * are not implemented but reserved by Unicode standard.
 *
 * Letters marked by ! are non-standard, but implemented by date-fns:
 * - `o` modifies the previous token to turn it into an ordinal (see `parse` docs)
 * - `i` is ISO day of week. For `i` and `ii` is returns numeric ISO week days,
 *   i.e. 7 for Sunday, 1 for Monday, etc.
 * - `I` is ISO week of year, as opposed to `w` which is local week of year.
 * - `R` is ISO week-numbering year, as opposed to `Y` which is local week-numbering year.
 *   `R` is supposed to be used in conjunction with `I` and `i`
 *   for universal ISO week-numbering date, whereas
 *   `Y` is supposed to be used in conjunction with `w` and `e`
 *   for week-numbering date specific to the locale.
 */


var parsers = {
  // Era
  G: {
    priority: 140,
    parse: function (string, token, match, _options) {
      switch (token) {
        // AD, BC
        case 'G':
        case 'GG':
        case 'GGG':
          return match.era(string, {
            width: 'abbreviated'
          }) || match.era(string, {
            width: 'narrow'
          });
        // A, B

        case 'GGGGG':
          return match.era(string, {
            width: 'narrow'
          });
        // Anno Domini, Before Christ

        case 'GGGG':
        default:
          return match.era(string, {
            width: 'wide'
          }) || match.era(string, {
            width: 'abbreviated'
          }) || match.era(string, {
            width: 'narrow'
          });
      }
    },
    set: function (date, flags, value, _options) {
      flags.era = value;
      date.setUTCFullYear(value, 0, 1);
      date.setUTCHours(0, 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['R', 'u', 't', 'T']
  },
  // Year
  y: {
    // From http://www.unicode.org/reports/tr35/tr35-31/tr35-dates.html#Date_Format_Patterns
    // | Year     |     y | yy |   yyy |  yyyy | yyyyy |
    // |----------|-------|----|-------|-------|-------|
    // | AD 1     |     1 | 01 |   001 |  0001 | 00001 |
    // | AD 12    |    12 | 12 |   012 |  0012 | 00012 |
    // | AD 123   |   123 | 23 |   123 |  0123 | 00123 |
    // | AD 1234  |  1234 | 34 |  1234 |  1234 | 01234 |
    // | AD 12345 | 12345 | 45 | 12345 | 12345 | 12345 |
    priority: 130,
    parse: function (string, token, match, _options) {
      var valueCallback = function (year) {
        return {
          year: year,
          isTwoDigitYear: token === 'yy'
        };
      };

      switch (token) {
        case 'y':
          return parseNDigits(4, string, valueCallback);

        case 'yo':
          return match.ordinalNumber(string, {
            unit: 'year',
            valueCallback: valueCallback
          });

        default:
          return parseNDigits(token.length, string, valueCallback);
      }
    },
    validate: function (_date, value, _options) {
      return value.isTwoDigitYear || value.year > 0;
    },
    set: function (date, flags, value, _options) {
      var currentYear = date.getUTCFullYear();

      if (value.isTwoDigitYear) {
        var normalizedTwoDigitYear = normalizeTwoDigitYear(value.year, currentYear);
        date.setUTCFullYear(normalizedTwoDigitYear, 0, 1);
        date.setUTCHours(0, 0, 0, 0);
        return date;
      }

      var year = !('era' in flags) || flags.era === 1 ? value.year : 1 - value.year;
      date.setUTCFullYear(year, 0, 1);
      date.setUTCHours(0, 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['Y', 'R', 'u', 'w', 'I', 'i', 'e', 'c', 't', 'T']
  },
  // Local week-numbering year
  Y: {
    priority: 130,
    parse: function (string, token, match, _options) {
      var valueCallback = function (year) {
        return {
          year: year,
          isTwoDigitYear: token === 'YY'
        };
      };

      switch (token) {
        case 'Y':
          return parseNDigits(4, string, valueCallback);

        case 'Yo':
          return match.ordinalNumber(string, {
            unit: 'year',
            valueCallback: valueCallback
          });

        default:
          return parseNDigits(token.length, string, valueCallback);
      }
    },
    validate: function (_date, value, _options) {
      return value.isTwoDigitYear || value.year > 0;
    },
    set: function (date, flags, value, options) {
      var currentYear = (0,_lib_getUTCWeekYear_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(date, options);

      if (value.isTwoDigitYear) {
        var normalizedTwoDigitYear = normalizeTwoDigitYear(value.year, currentYear);
        date.setUTCFullYear(normalizedTwoDigitYear, 0, options.firstWeekContainsDate);
        date.setUTCHours(0, 0, 0, 0);
        return (0,_lib_startOfUTCWeek_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(date, options);
      }

      var year = !('era' in flags) || flags.era === 1 ? value.year : 1 - value.year;
      date.setUTCFullYear(year, 0, options.firstWeekContainsDate);
      date.setUTCHours(0, 0, 0, 0);
      return (0,_lib_startOfUTCWeek_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(date, options);
    },
    incompatibleTokens: ['y', 'R', 'u', 'Q', 'q', 'M', 'L', 'I', 'd', 'D', 'i', 't', 'T']
  },
  // ISO week-numbering year
  R: {
    priority: 130,
    parse: function (string, token, _match, _options) {
      if (token === 'R') {
        return parseNDigitsSigned(4, string);
      }

      return parseNDigitsSigned(token.length, string);
    },
    set: function (_date, _flags, value, _options) {
      var firstWeekOfYear = new Date(0);
      firstWeekOfYear.setUTCFullYear(value, 0, 4);
      firstWeekOfYear.setUTCHours(0, 0, 0, 0);
      return (0,_lib_startOfUTCISOWeek_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(firstWeekOfYear);
    },
    incompatibleTokens: ['G', 'y', 'Y', 'u', 'Q', 'q', 'M', 'L', 'w', 'd', 'D', 'e', 'c', 't', 'T']
  },
  // Extended year
  u: {
    priority: 130,
    parse: function (string, token, _match, _options) {
      if (token === 'u') {
        return parseNDigitsSigned(4, string);
      }

      return parseNDigitsSigned(token.length, string);
    },
    set: function (date, _flags, value, _options) {
      date.setUTCFullYear(value, 0, 1);
      date.setUTCHours(0, 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['G', 'y', 'Y', 'R', 'w', 'I', 'i', 'e', 'c', 't', 'T']
  },
  // Quarter
  Q: {
    priority: 120,
    parse: function (string, token, match, _options) {
      switch (token) {
        // 1, 2, 3, 4
        case 'Q':
        case 'QQ':
          // 01, 02, 03, 04
          return parseNDigits(token.length, string);
        // 1st, 2nd, 3rd, 4th

        case 'Qo':
          return match.ordinalNumber(string, {
            unit: 'quarter'
          });
        // Q1, Q2, Q3, Q4

        case 'QQQ':
          return match.quarter(string, {
            width: 'abbreviated',
            context: 'formatting'
          }) || match.quarter(string, {
            width: 'narrow',
            context: 'formatting'
          });
        // 1, 2, 3, 4 (narrow quarter; could be not numerical)

        case 'QQQQQ':
          return match.quarter(string, {
            width: 'narrow',
            context: 'formatting'
          });
        // 1st quarter, 2nd quarter, ...

        case 'QQQQ':
        default:
          return match.quarter(string, {
            width: 'wide',
            context: 'formatting'
          }) || match.quarter(string, {
            width: 'abbreviated',
            context: 'formatting'
          }) || match.quarter(string, {
            width: 'narrow',
            context: 'formatting'
          });
      }
    },
    validate: function (_date, value, _options) {
      return value >= 1 && value <= 4;
    },
    set: function (date, _flags, value, _options) {
      date.setUTCMonth((value - 1) * 3, 1);
      date.setUTCHours(0, 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['Y', 'R', 'q', 'M', 'L', 'w', 'I', 'd', 'D', 'i', 'e', 'c', 't', 'T']
  },
  // Stand-alone quarter
  q: {
    priority: 120,
    parse: function (string, token, match, _options) {
      switch (token) {
        // 1, 2, 3, 4
        case 'q':
        case 'qq':
          // 01, 02, 03, 04
          return parseNDigits(token.length, string);
        // 1st, 2nd, 3rd, 4th

        case 'qo':
          return match.ordinalNumber(string, {
            unit: 'quarter'
          });
        // Q1, Q2, Q3, Q4

        case 'qqq':
          return match.quarter(string, {
            width: 'abbreviated',
            context: 'standalone'
          }) || match.quarter(string, {
            width: 'narrow',
            context: 'standalone'
          });
        // 1, 2, 3, 4 (narrow quarter; could be not numerical)

        case 'qqqqq':
          return match.quarter(string, {
            width: 'narrow',
            context: 'standalone'
          });
        // 1st quarter, 2nd quarter, ...

        case 'qqqq':
        default:
          return match.quarter(string, {
            width: 'wide',
            context: 'standalone'
          }) || match.quarter(string, {
            width: 'abbreviated',
            context: 'standalone'
          }) || match.quarter(string, {
            width: 'narrow',
            context: 'standalone'
          });
      }
    },
    validate: function (_date, value, _options) {
      return value >= 1 && value <= 4;
    },
    set: function (date, _flags, value, _options) {
      date.setUTCMonth((value - 1) * 3, 1);
      date.setUTCHours(0, 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['Y', 'R', 'Q', 'M', 'L', 'w', 'I', 'd', 'D', 'i', 'e', 'c', 't', 'T']
  },
  // Month
  M: {
    priority: 110,
    parse: function (string, token, match, _options) {
      var valueCallback = function (value) {
        return value - 1;
      };

      switch (token) {
        // 1, 2, ..., 12
        case 'M':
          return parseNumericPattern(numericPatterns.month, string, valueCallback);
        // 01, 02, ..., 12

        case 'MM':
          return parseNDigits(2, string, valueCallback);
        // 1st, 2nd, ..., 12th

        case 'Mo':
          return match.ordinalNumber(string, {
            unit: 'month',
            valueCallback: valueCallback
          });
        // Jan, Feb, ..., Dec

        case 'MMM':
          return match.month(string, {
            width: 'abbreviated',
            context: 'formatting'
          }) || match.month(string, {
            width: 'narrow',
            context: 'formatting'
          });
        // J, F, ..., D

        case 'MMMMM':
          return match.month(string, {
            width: 'narrow',
            context: 'formatting'
          });
        // January, February, ..., December

        case 'MMMM':
        default:
          return match.month(string, {
            width: 'wide',
            context: 'formatting'
          }) || match.month(string, {
            width: 'abbreviated',
            context: 'formatting'
          }) || match.month(string, {
            width: 'narrow',
            context: 'formatting'
          });
      }
    },
    validate: function (_date, value, _options) {
      return value >= 0 && value <= 11;
    },
    set: function (date, _flags, value, _options) {
      date.setUTCMonth(value, 1);
      date.setUTCHours(0, 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['Y', 'R', 'q', 'Q', 'L', 'w', 'I', 'D', 'i', 'e', 'c', 't', 'T']
  },
  // Stand-alone month
  L: {
    priority: 110,
    parse: function (string, token, match, _options) {
      var valueCallback = function (value) {
        return value - 1;
      };

      switch (token) {
        // 1, 2, ..., 12
        case 'L':
          return parseNumericPattern(numericPatterns.month, string, valueCallback);
        // 01, 02, ..., 12

        case 'LL':
          return parseNDigits(2, string, valueCallback);
        // 1st, 2nd, ..., 12th

        case 'Lo':
          return match.ordinalNumber(string, {
            unit: 'month',
            valueCallback: valueCallback
          });
        // Jan, Feb, ..., Dec

        case 'LLL':
          return match.month(string, {
            width: 'abbreviated',
            context: 'standalone'
          }) || match.month(string, {
            width: 'narrow',
            context: 'standalone'
          });
        // J, F, ..., D

        case 'LLLLL':
          return match.month(string, {
            width: 'narrow',
            context: 'standalone'
          });
        // January, February, ..., December

        case 'LLLL':
        default:
          return match.month(string, {
            width: 'wide',
            context: 'standalone'
          }) || match.month(string, {
            width: 'abbreviated',
            context: 'standalone'
          }) || match.month(string, {
            width: 'narrow',
            context: 'standalone'
          });
      }
    },
    validate: function (_date, value, _options) {
      return value >= 0 && value <= 11;
    },
    set: function (date, _flags, value, _options) {
      date.setUTCMonth(value, 1);
      date.setUTCHours(0, 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['Y', 'R', 'q', 'Q', 'M', 'w', 'I', 'D', 'i', 'e', 'c', 't', 'T']
  },
  // Local week of year
  w: {
    priority: 100,
    parse: function (string, token, match, _options) {
      switch (token) {
        case 'w':
          return parseNumericPattern(numericPatterns.week, string);

        case 'wo':
          return match.ordinalNumber(string, {
            unit: 'week'
          });

        default:
          return parseNDigits(token.length, string);
      }
    },
    validate: function (_date, value, _options) {
      return value >= 1 && value <= 53;
    },
    set: function (date, _flags, value, options) {
      return (0,_lib_startOfUTCWeek_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])((0,_lib_setUTCWeek_index_js__WEBPACK_IMPORTED_MODULE_3__["default"])(date, value, options), options);
    },
    incompatibleTokens: ['y', 'R', 'u', 'q', 'Q', 'M', 'L', 'I', 'd', 'D', 'i', 't', 'T']
  },
  // ISO week of year
  I: {
    priority: 100,
    parse: function (string, token, match, _options) {
      switch (token) {
        case 'I':
          return parseNumericPattern(numericPatterns.week, string);

        case 'Io':
          return match.ordinalNumber(string, {
            unit: 'week'
          });

        default:
          return parseNDigits(token.length, string);
      }
    },
    validate: function (_date, value, _options) {
      return value >= 1 && value <= 53;
    },
    set: function (date, _flags, value, options) {
      return (0,_lib_startOfUTCISOWeek_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])((0,_lib_setUTCISOWeek_index_js__WEBPACK_IMPORTED_MODULE_4__["default"])(date, value, options), options);
    },
    incompatibleTokens: ['y', 'Y', 'u', 'q', 'Q', 'M', 'L', 'w', 'd', 'D', 'e', 'c', 't', 'T']
  },
  // Day of the month
  d: {
    priority: 90,
    subPriority: 1,
    parse: function (string, token, match, _options) {
      switch (token) {
        case 'd':
          return parseNumericPattern(numericPatterns.date, string);

        case 'do':
          return match.ordinalNumber(string, {
            unit: 'date'
          });

        default:
          return parseNDigits(token.length, string);
      }
    },
    validate: function (date, value, _options) {
      var year = date.getUTCFullYear();
      var isLeapYear = isLeapYearIndex(year);
      var month = date.getUTCMonth();

      if (isLeapYear) {
        return value >= 1 && value <= DAYS_IN_MONTH_LEAP_YEAR[month];
      } else {
        return value >= 1 && value <= DAYS_IN_MONTH[month];
      }
    },
    set: function (date, _flags, value, _options) {
      date.setUTCDate(value);
      date.setUTCHours(0, 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['Y', 'R', 'q', 'Q', 'w', 'I', 'D', 'i', 'e', 'c', 't', 'T']
  },
  // Day of year
  D: {
    priority: 90,
    subPriority: 1,
    parse: function (string, token, match, _options) {
      switch (token) {
        case 'D':
        case 'DD':
          return parseNumericPattern(numericPatterns.dayOfYear, string);

        case 'Do':
          return match.ordinalNumber(string, {
            unit: 'date'
          });

        default:
          return parseNDigits(token.length, string);
      }
    },
    validate: function (date, value, _options) {
      var year = date.getUTCFullYear();
      var isLeapYear = isLeapYearIndex(year);

      if (isLeapYear) {
        return value >= 1 && value <= 366;
      } else {
        return value >= 1 && value <= 365;
      }
    },
    set: function (date, _flags, value, _options) {
      date.setUTCMonth(0, value);
      date.setUTCHours(0, 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['Y', 'R', 'q', 'Q', 'M', 'L', 'w', 'I', 'd', 'E', 'i', 'e', 'c', 't', 'T']
  },
  // Day of week
  E: {
    priority: 90,
    parse: function (string, token, match, _options) {
      switch (token) {
        // Tue
        case 'E':
        case 'EE':
        case 'EEE':
          return match.day(string, {
            width: 'abbreviated',
            context: 'formatting'
          }) || match.day(string, {
            width: 'short',
            context: 'formatting'
          }) || match.day(string, {
            width: 'narrow',
            context: 'formatting'
          });
        // T

        case 'EEEEE':
          return match.day(string, {
            width: 'narrow',
            context: 'formatting'
          });
        // Tu

        case 'EEEEEE':
          return match.day(string, {
            width: 'short',
            context: 'formatting'
          }) || match.day(string, {
            width: 'narrow',
            context: 'formatting'
          });
        // Tuesday

        case 'EEEE':
        default:
          return match.day(string, {
            width: 'wide',
            context: 'formatting'
          }) || match.day(string, {
            width: 'abbreviated',
            context: 'formatting'
          }) || match.day(string, {
            width: 'short',
            context: 'formatting'
          }) || match.day(string, {
            width: 'narrow',
            context: 'formatting'
          });
      }
    },
    validate: function (_date, value, _options) {
      return value >= 0 && value <= 6;
    },
    set: function (date, _flags, value, options) {
      date = (0,_lib_setUTCDay_index_js__WEBPACK_IMPORTED_MODULE_5__["default"])(date, value, options);
      date.setUTCHours(0, 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['D', 'i', 'e', 'c', 't', 'T']
  },
  // Local day of week
  e: {
    priority: 90,
    parse: function (string, token, match, options) {
      var valueCallback = function (value) {
        var wholeWeekDays = Math.floor((value - 1) / 7) * 7;
        return (value + options.weekStartsOn + 6) % 7 + wholeWeekDays;
      };

      switch (token) {
        // 3
        case 'e':
        case 'ee':
          // 03
          return parseNDigits(token.length, string, valueCallback);
        // 3rd

        case 'eo':
          return match.ordinalNumber(string, {
            unit: 'day',
            valueCallback: valueCallback
          });
        // Tue

        case 'eee':
          return match.day(string, {
            width: 'abbreviated',
            context: 'formatting'
          }) || match.day(string, {
            width: 'short',
            context: 'formatting'
          }) || match.day(string, {
            width: 'narrow',
            context: 'formatting'
          });
        // T

        case 'eeeee':
          return match.day(string, {
            width: 'narrow',
            context: 'formatting'
          });
        // Tu

        case 'eeeeee':
          return match.day(string, {
            width: 'short',
            context: 'formatting'
          }) || match.day(string, {
            width: 'narrow',
            context: 'formatting'
          });
        // Tuesday

        case 'eeee':
        default:
          return match.day(string, {
            width: 'wide',
            context: 'formatting'
          }) || match.day(string, {
            width: 'abbreviated',
            context: 'formatting'
          }) || match.day(string, {
            width: 'short',
            context: 'formatting'
          }) || match.day(string, {
            width: 'narrow',
            context: 'formatting'
          });
      }
    },
    validate: function (_date, value, _options) {
      return value >= 0 && value <= 6;
    },
    set: function (date, _flags, value, options) {
      date = (0,_lib_setUTCDay_index_js__WEBPACK_IMPORTED_MODULE_5__["default"])(date, value, options);
      date.setUTCHours(0, 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['y', 'R', 'u', 'q', 'Q', 'M', 'L', 'I', 'd', 'D', 'E', 'i', 'c', 't', 'T']
  },
  // Stand-alone local day of week
  c: {
    priority: 90,
    parse: function (string, token, match, options) {
      var valueCallback = function (value) {
        var wholeWeekDays = Math.floor((value - 1) / 7) * 7;
        return (value + options.weekStartsOn + 6) % 7 + wholeWeekDays;
      };

      switch (token) {
        // 3
        case 'c':
        case 'cc':
          // 03
          return parseNDigits(token.length, string, valueCallback);
        // 3rd

        case 'co':
          return match.ordinalNumber(string, {
            unit: 'day',
            valueCallback: valueCallback
          });
        // Tue

        case 'ccc':
          return match.day(string, {
            width: 'abbreviated',
            context: 'standalone'
          }) || match.day(string, {
            width: 'short',
            context: 'standalone'
          }) || match.day(string, {
            width: 'narrow',
            context: 'standalone'
          });
        // T

        case 'ccccc':
          return match.day(string, {
            width: 'narrow',
            context: 'standalone'
          });
        // Tu

        case 'cccccc':
          return match.day(string, {
            width: 'short',
            context: 'standalone'
          }) || match.day(string, {
            width: 'narrow',
            context: 'standalone'
          });
        // Tuesday

        case 'cccc':
        default:
          return match.day(string, {
            width: 'wide',
            context: 'standalone'
          }) || match.day(string, {
            width: 'abbreviated',
            context: 'standalone'
          }) || match.day(string, {
            width: 'short',
            context: 'standalone'
          }) || match.day(string, {
            width: 'narrow',
            context: 'standalone'
          });
      }
    },
    validate: function (_date, value, _options) {
      return value >= 0 && value <= 6;
    },
    set: function (date, _flags, value, options) {
      date = (0,_lib_setUTCDay_index_js__WEBPACK_IMPORTED_MODULE_5__["default"])(date, value, options);
      date.setUTCHours(0, 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['y', 'R', 'u', 'q', 'Q', 'M', 'L', 'I', 'd', 'D', 'E', 'i', 'e', 't', 'T']
  },
  // ISO day of week
  i: {
    priority: 90,
    parse: function (string, token, match, _options) {
      var valueCallback = function (value) {
        if (value === 0) {
          return 7;
        }

        return value;
      };

      switch (token) {
        // 2
        case 'i':
        case 'ii':
          // 02
          return parseNDigits(token.length, string);
        // 2nd

        case 'io':
          return match.ordinalNumber(string, {
            unit: 'day'
          });
        // Tue

        case 'iii':
          return match.day(string, {
            width: 'abbreviated',
            context: 'formatting',
            valueCallback: valueCallback
          }) || match.day(string, {
            width: 'short',
            context: 'formatting',
            valueCallback: valueCallback
          }) || match.day(string, {
            width: 'narrow',
            context: 'formatting',
            valueCallback: valueCallback
          });
        // T

        case 'iiiii':
          return match.day(string, {
            width: 'narrow',
            context: 'formatting',
            valueCallback: valueCallback
          });
        // Tu

        case 'iiiiii':
          return match.day(string, {
            width: 'short',
            context: 'formatting',
            valueCallback: valueCallback
          }) || match.day(string, {
            width: 'narrow',
            context: 'formatting',
            valueCallback: valueCallback
          });
        // Tuesday

        case 'iiii':
        default:
          return match.day(string, {
            width: 'wide',
            context: 'formatting',
            valueCallback: valueCallback
          }) || match.day(string, {
            width: 'abbreviated',
            context: 'formatting',
            valueCallback: valueCallback
          }) || match.day(string, {
            width: 'short',
            context: 'formatting',
            valueCallback: valueCallback
          }) || match.day(string, {
            width: 'narrow',
            context: 'formatting',
            valueCallback: valueCallback
          });
      }
    },
    validate: function (_date, value, _options) {
      return value >= 1 && value <= 7;
    },
    set: function (date, _flags, value, options) {
      date = (0,_lib_setUTCISODay_index_js__WEBPACK_IMPORTED_MODULE_6__["default"])(date, value, options);
      date.setUTCHours(0, 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['y', 'Y', 'u', 'q', 'Q', 'M', 'L', 'w', 'd', 'D', 'E', 'e', 'c', 't', 'T']
  },
  // AM or PM
  a: {
    priority: 80,
    parse: function (string, token, match, _options) {
      switch (token) {
        case 'a':
        case 'aa':
        case 'aaa':
          return match.dayPeriod(string, {
            width: 'abbreviated',
            context: 'formatting'
          }) || match.dayPeriod(string, {
            width: 'narrow',
            context: 'formatting'
          });

        case 'aaaaa':
          return match.dayPeriod(string, {
            width: 'narrow',
            context: 'formatting'
          });

        case 'aaaa':
        default:
          return match.dayPeriod(string, {
            width: 'wide',
            context: 'formatting'
          }) || match.dayPeriod(string, {
            width: 'abbreviated',
            context: 'formatting'
          }) || match.dayPeriod(string, {
            width: 'narrow',
            context: 'formatting'
          });
      }
    },
    set: function (date, _flags, value, _options) {
      date.setUTCHours(dayPeriodEnumToHours(value), 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['b', 'B', 'H', 'k', 't', 'T']
  },
  // AM, PM, midnight
  b: {
    priority: 80,
    parse: function (string, token, match, _options) {
      switch (token) {
        case 'b':
        case 'bb':
        case 'bbb':
          return match.dayPeriod(string, {
            width: 'abbreviated',
            context: 'formatting'
          }) || match.dayPeriod(string, {
            width: 'narrow',
            context: 'formatting'
          });

        case 'bbbbb':
          return match.dayPeriod(string, {
            width: 'narrow',
            context: 'formatting'
          });

        case 'bbbb':
        default:
          return match.dayPeriod(string, {
            width: 'wide',
            context: 'formatting'
          }) || match.dayPeriod(string, {
            width: 'abbreviated',
            context: 'formatting'
          }) || match.dayPeriod(string, {
            width: 'narrow',
            context: 'formatting'
          });
      }
    },
    set: function (date, _flags, value, _options) {
      date.setUTCHours(dayPeriodEnumToHours(value), 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['a', 'B', 'H', 'k', 't', 'T']
  },
  // in the morning, in the afternoon, in the evening, at night
  B: {
    priority: 80,
    parse: function (string, token, match, _options) {
      switch (token) {
        case 'B':
        case 'BB':
        case 'BBB':
          return match.dayPeriod(string, {
            width: 'abbreviated',
            context: 'formatting'
          }) || match.dayPeriod(string, {
            width: 'narrow',
            context: 'formatting'
          });

        case 'BBBBB':
          return match.dayPeriod(string, {
            width: 'narrow',
            context: 'formatting'
          });

        case 'BBBB':
        default:
          return match.dayPeriod(string, {
            width: 'wide',
            context: 'formatting'
          }) || match.dayPeriod(string, {
            width: 'abbreviated',
            context: 'formatting'
          }) || match.dayPeriod(string, {
            width: 'narrow',
            context: 'formatting'
          });
      }
    },
    set: function (date, _flags, value, _options) {
      date.setUTCHours(dayPeriodEnumToHours(value), 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['a', 'b', 't', 'T']
  },
  // Hour [1-12]
  h: {
    priority: 70,
    parse: function (string, token, match, _options) {
      switch (token) {
        case 'h':
          return parseNumericPattern(numericPatterns.hour12h, string);

        case 'ho':
          return match.ordinalNumber(string, {
            unit: 'hour'
          });

        default:
          return parseNDigits(token.length, string);
      }
    },
    validate: function (_date, value, _options) {
      return value >= 1 && value <= 12;
    },
    set: function (date, _flags, value, _options) {
      var isPM = date.getUTCHours() >= 12;

      if (isPM && value < 12) {
        date.setUTCHours(value + 12, 0, 0, 0);
      } else if (!isPM && value === 12) {
        date.setUTCHours(0, 0, 0, 0);
      } else {
        date.setUTCHours(value, 0, 0, 0);
      }

      return date;
    },
    incompatibleTokens: ['H', 'K', 'k', 't', 'T']
  },
  // Hour [0-23]
  H: {
    priority: 70,
    parse: function (string, token, match, _options) {
      switch (token) {
        case 'H':
          return parseNumericPattern(numericPatterns.hour23h, string);

        case 'Ho':
          return match.ordinalNumber(string, {
            unit: 'hour'
          });

        default:
          return parseNDigits(token.length, string);
      }
    },
    validate: function (_date, value, _options) {
      return value >= 0 && value <= 23;
    },
    set: function (date, _flags, value, _options) {
      date.setUTCHours(value, 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['a', 'b', 'h', 'K', 'k', 't', 'T']
  },
  // Hour [0-11]
  K: {
    priority: 70,
    parse: function (string, token, match, _options) {
      switch (token) {
        case 'K':
          return parseNumericPattern(numericPatterns.hour11h, string);

        case 'Ko':
          return match.ordinalNumber(string, {
            unit: 'hour'
          });

        default:
          return parseNDigits(token.length, string);
      }
    },
    validate: function (_date, value, _options) {
      return value >= 0 && value <= 11;
    },
    set: function (date, _flags, value, _options) {
      var isPM = date.getUTCHours() >= 12;

      if (isPM && value < 12) {
        date.setUTCHours(value + 12, 0, 0, 0);
      } else {
        date.setUTCHours(value, 0, 0, 0);
      }

      return date;
    },
    incompatibleTokens: ['h', 'H', 'k', 't', 'T']
  },
  // Hour [1-24]
  k: {
    priority: 70,
    parse: function (string, token, match, _options) {
      switch (token) {
        case 'k':
          return parseNumericPattern(numericPatterns.hour24h, string);

        case 'ko':
          return match.ordinalNumber(string, {
            unit: 'hour'
          });

        default:
          return parseNDigits(token.length, string);
      }
    },
    validate: function (_date, value, _options) {
      return value >= 1 && value <= 24;
    },
    set: function (date, _flags, value, _options) {
      var hours = value <= 24 ? value % 24 : value;
      date.setUTCHours(hours, 0, 0, 0);
      return date;
    },
    incompatibleTokens: ['a', 'b', 'h', 'H', 'K', 't', 'T']
  },
  // Minute
  m: {
    priority: 60,
    parse: function (string, token, match, _options) {
      switch (token) {
        case 'm':
          return parseNumericPattern(numericPatterns.minute, string);

        case 'mo':
          return match.ordinalNumber(string, {
            unit: 'minute'
          });

        default:
          return parseNDigits(token.length, string);
      }
    },
    validate: function (_date, value, _options) {
      return value >= 0 && value <= 59;
    },
    set: function (date, _flags, value, _options) {
      date.setUTCMinutes(value, 0, 0);
      return date;
    },
    incompatibleTokens: ['t', 'T']
  },
  // Second
  s: {
    priority: 50,
    parse: function (string, token, match, _options) {
      switch (token) {
        case 's':
          return parseNumericPattern(numericPatterns.second, string);

        case 'so':
          return match.ordinalNumber(string, {
            unit: 'second'
          });

        default:
          return parseNDigits(token.length, string);
      }
    },
    validate: function (_date, value, _options) {
      return value >= 0 && value <= 59;
    },
    set: function (date, _flags, value, _options) {
      date.setUTCSeconds(value, 0);
      return date;
    },
    incompatibleTokens: ['t', 'T']
  },
  // Fraction of second
  S: {
    priority: 30,
    parse: function (string, token, _match, _options) {
      var valueCallback = function (value) {
        return Math.floor(value * Math.pow(10, -token.length + 3));
      };

      return parseNDigits(token.length, string, valueCallback);
    },
    set: function (date, _flags, value, _options) {
      date.setUTCMilliseconds(value);
      return date;
    },
    incompatibleTokens: ['t', 'T']
  },
  // Timezone (ISO-8601. +00:00 is `'Z'`)
  X: {
    priority: 10,
    parse: function (string, token, _match, _options) {
      switch (token) {
        case 'X':
          return parseTimezonePattern(timezonePatterns.basicOptionalMinutes, string);

        case 'XX':
          return parseTimezonePattern(timezonePatterns.basic, string);

        case 'XXXX':
          return parseTimezonePattern(timezonePatterns.basicOptionalSeconds, string);

        case 'XXXXX':
          return parseTimezonePattern(timezonePatterns.extendedOptionalSeconds, string);

        case 'XXX':
        default:
          return parseTimezonePattern(timezonePatterns.extended, string);
      }
    },
    set: function (date, flags, value, _options) {
      if (flags.timestampIsSet) {
        return date;
      }

      return new Date(date.getTime() - value);
    },
    incompatibleTokens: ['t', 'T', 'x']
  },
  // Timezone (ISO-8601)
  x: {
    priority: 10,
    parse: function (string, token, _match, _options) {
      switch (token) {
        case 'x':
          return parseTimezonePattern(timezonePatterns.basicOptionalMinutes, string);

        case 'xx':
          return parseTimezonePattern(timezonePatterns.basic, string);

        case 'xxxx':
          return parseTimezonePattern(timezonePatterns.basicOptionalSeconds, string);

        case 'xxxxx':
          return parseTimezonePattern(timezonePatterns.extendedOptionalSeconds, string);

        case 'xxx':
        default:
          return parseTimezonePattern(timezonePatterns.extended, string);
      }
    },
    set: function (date, flags, value, _options) {
      if (flags.timestampIsSet) {
        return date;
      }

      return new Date(date.getTime() - value);
    },
    incompatibleTokens: ['t', 'T', 'X']
  },
  // Seconds timestamp
  t: {
    priority: 40,
    parse: function (string, _token, _match, _options) {
      return parseAnyDigitsSigned(string);
    },
    set: function (_date, _flags, value, _options) {
      return [new Date(value * 1000), {
        timestampIsSet: true
      }];
    },
    incompatibleTokens: '*'
  },
  // Milliseconds timestamp
  T: {
    priority: 20,
    parse: function (string, _token, _match, _options) {
      return parseAnyDigitsSigned(string);
    },
    set: function (_date, _flags, value, _options) {
      return [new Date(value), {
        timestampIsSet: true
      }];
    },
    incompatibleTokens: '*'
  }
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (parsers);

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/parse/index.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/parse/index.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ parse)
/* harmony export */ });
/* harmony import */ var _locale_en_US_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../locale/en-US/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/locale/en-US/index.js");
/* harmony import */ var _subMilliseconds_index_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../subMilliseconds/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/subMilliseconds/index.js");
/* harmony import */ var _toDate_index_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../toDate/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/toDate/index.js");
/* harmony import */ var _lib_assign_index_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../_lib/assign/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/assign/index.js");
/* harmony import */ var _lib_format_longFormatters_index_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../_lib/format/longFormatters/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/format/longFormatters/index.js");
/* harmony import */ var _lib_getTimezoneOffsetInMilliseconds_index_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../_lib/getTimezoneOffsetInMilliseconds/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/getTimezoneOffsetInMilliseconds/index.js");
/* harmony import */ var _lib_protectedTokens_index_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../_lib/protectedTokens/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/protectedTokens/index.js");
/* harmony import */ var _lib_toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../_lib/toInteger/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/toInteger/index.js");
/* harmony import */ var _lib_parsers_index_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./_lib/parsers/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/parse/_lib/parsers/index.js");
/* harmony import */ var _lib_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../_lib/requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");










var TIMEZONE_UNIT_PRIORITY = 10; // This RegExp consists of three parts separated by `|`:
// - [yYQqMLwIdDecihHKkms]o matches any available ordinal number token
//   (one of the certain letters followed by `o`)
// - (\w)\1* matches any sequences of the same letter
// - '' matches two quote characters in a row
// - '(''|[^'])+('|$) matches anything surrounded by two quote characters ('),
//   except a single quote symbol, which ends the sequence.
//   Two quote characters do not end the sequence.
//   If there is no matching single quote
//   then the sequence will continue until the end of the string.
// - . matches any single character unmatched by previous parts of the RegExps

var formattingTokensRegExp = /[yYQqMLwIdDecihHKkms]o|(\w)\1*|''|'(''|[^'])+('|$)|./g; // This RegExp catches symbols escaped by quotes, and also
// sequences of symbols P, p, and the combinations like `PPPPPPPppppp`

var longFormattingTokensRegExp = /P+p+|P+|p+|''|'(''|[^'])+('|$)|./g;
var escapedStringRegExp = /^'([^]*?)'?$/;
var doubleQuoteRegExp = /''/g;
var notWhitespaceRegExp = /\S/;
var unescapedLatinCharacterRegExp = /[a-zA-Z]/;
/**
 * @name parse
 * @category Common Helpers
 * @summary Parse the date.
 *
 * @description
 * Return the date parsed from string using the given format string.
 *
 * > ⚠️ Please note that the `format` tokens differ from Moment.js and other libraries.
 * > See: https://git.io/fxCyr
 *
 * The characters in the format string wrapped between two single quotes characters (') are escaped.
 * Two single quotes in a row, whether inside or outside a quoted sequence, represent a 'real' single quote.
 *
 * Format of the format string is based on Unicode Technical Standard #35:
 * https://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table
 * with a few additions (see note 5 below the table).
 *
 * Not all tokens are compatible. Combinations that don't make sense or could lead to bugs are prohibited
 * and will throw `RangeError`. For example usage of 24-hour format token with AM/PM token will throw an exception:
 *
 * ```javascript
 * parse('23 AM', 'HH a', new Date())
 * //=> RangeError: The format string mustn't contain `HH` and `a` at the same time
 * ```
 *
 * See the compatibility table: https://docs.google.com/spreadsheets/d/e/2PACX-1vQOPU3xUhplll6dyoMmVUXHKl_8CRDs6_ueLmex3SoqwhuolkuN3O05l4rqx5h1dKX8eb46Ul-CCSrq/pubhtml?gid=0&single=true
 *
 * Accepted format string patterns:
 * | Unit                            |Prior| Pattern | Result examples                   | Notes |
 * |---------------------------------|-----|---------|-----------------------------------|-------|
 * | Era                             | 140 | G..GGG  | AD, BC                            |       |
 * |                                 |     | GGGG    | Anno Domini, Before Christ        | 2     |
 * |                                 |     | GGGGG   | A, B                              |       |
 * | Calendar year                   | 130 | y       | 44, 1, 1900, 2017, 9999           | 4     |
 * |                                 |     | yo      | 44th, 1st, 1900th, 9999999th      | 4,5   |
 * |                                 |     | yy      | 44, 01, 00, 17                    | 4     |
 * |                                 |     | yyy     | 044, 001, 123, 999                | 4     |
 * |                                 |     | yyyy    | 0044, 0001, 1900, 2017            | 4     |
 * |                                 |     | yyyyy   | ...                               | 2,4   |
 * | Local week-numbering year       | 130 | Y       | 44, 1, 1900, 2017, 9000           | 4     |
 * |                                 |     | Yo      | 44th, 1st, 1900th, 9999999th      | 4,5   |
 * |                                 |     | YY      | 44, 01, 00, 17                    | 4,6   |
 * |                                 |     | YYY     | 044, 001, 123, 999                | 4     |
 * |                                 |     | YYYY    | 0044, 0001, 1900, 2017            | 4,6   |
 * |                                 |     | YYYYY   | ...                               | 2,4   |
 * | ISO week-numbering year         | 130 | R       | -43, 1, 1900, 2017, 9999, -9999   | 4,5   |
 * |                                 |     | RR      | -43, 01, 00, 17                   | 4,5   |
 * |                                 |     | RRR     | -043, 001, 123, 999, -999         | 4,5   |
 * |                                 |     | RRRR    | -0043, 0001, 2017, 9999, -9999    | 4,5   |
 * |                                 |     | RRRRR   | ...                               | 2,4,5 |
 * | Extended year                   | 130 | u       | -43, 1, 1900, 2017, 9999, -999    | 4     |
 * |                                 |     | uu      | -43, 01, 99, -99                  | 4     |
 * |                                 |     | uuu     | -043, 001, 123, 999, -999         | 4     |
 * |                                 |     | uuuu    | -0043, 0001, 2017, 9999, -9999    | 4     |
 * |                                 |     | uuuuu   | ...                               | 2,4   |
 * | Quarter (formatting)            | 120 | Q       | 1, 2, 3, 4                        |       |
 * |                                 |     | Qo      | 1st, 2nd, 3rd, 4th                | 5     |
 * |                                 |     | QQ      | 01, 02, 03, 04                    |       |
 * |                                 |     | QQQ     | Q1, Q2, Q3, Q4                    |       |
 * |                                 |     | QQQQ    | 1st quarter, 2nd quarter, ...     | 2     |
 * |                                 |     | QQQQQ   | 1, 2, 3, 4                        | 4     |
 * | Quarter (stand-alone)           | 120 | q       | 1, 2, 3, 4                        |       |
 * |                                 |     | qo      | 1st, 2nd, 3rd, 4th                | 5     |
 * |                                 |     | qq      | 01, 02, 03, 04                    |       |
 * |                                 |     | qqq     | Q1, Q2, Q3, Q4                    |       |
 * |                                 |     | qqqq    | 1st quarter, 2nd quarter, ...     | 2     |
 * |                                 |     | qqqqq   | 1, 2, 3, 4                        | 3     |
 * | Month (formatting)              | 110 | M       | 1, 2, ..., 12                     |       |
 * |                                 |     | Mo      | 1st, 2nd, ..., 12th               | 5     |
 * |                                 |     | MM      | 01, 02, ..., 12                   |       |
 * |                                 |     | MMM     | Jan, Feb, ..., Dec                |       |
 * |                                 |     | MMMM    | January, February, ..., December  | 2     |
 * |                                 |     | MMMMM   | J, F, ..., D                      |       |
 * | Month (stand-alone)             | 110 | L       | 1, 2, ..., 12                     |       |
 * |                                 |     | Lo      | 1st, 2nd, ..., 12th               | 5     |
 * |                                 |     | LL      | 01, 02, ..., 12                   |       |
 * |                                 |     | LLL     | Jan, Feb, ..., Dec                |       |
 * |                                 |     | LLLL    | January, February, ..., December  | 2     |
 * |                                 |     | LLLLL   | J, F, ..., D                      |       |
 * | Local week of year              | 100 | w       | 1, 2, ..., 53                     |       |
 * |                                 |     | wo      | 1st, 2nd, ..., 53th               | 5     |
 * |                                 |     | ww      | 01, 02, ..., 53                   |       |
 * | ISO week of year                | 100 | I       | 1, 2, ..., 53                     | 5     |
 * |                                 |     | Io      | 1st, 2nd, ..., 53th               | 5     |
 * |                                 |     | II      | 01, 02, ..., 53                   | 5     |
 * | Day of month                    |  90 | d       | 1, 2, ..., 31                     |       |
 * |                                 |     | do      | 1st, 2nd, ..., 31st               | 5     |
 * |                                 |     | dd      | 01, 02, ..., 31                   |       |
 * | Day of year                     |  90 | D       | 1, 2, ..., 365, 366               | 7     |
 * |                                 |     | Do      | 1st, 2nd, ..., 365th, 366th       | 5     |
 * |                                 |     | DD      | 01, 02, ..., 365, 366             | 7     |
 * |                                 |     | DDD     | 001, 002, ..., 365, 366           |       |
 * |                                 |     | DDDD    | ...                               | 2     |
 * | Day of week (formatting)        |  90 | E..EEE  | Mon, Tue, Wed, ..., Sun           |       |
 * |                                 |     | EEEE    | Monday, Tuesday, ..., Sunday      | 2     |
 * |                                 |     | EEEEE   | M, T, W, T, F, S, S               |       |
 * |                                 |     | EEEEEE  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
 * | ISO day of week (formatting)    |  90 | i       | 1, 2, 3, ..., 7                   | 5     |
 * |                                 |     | io      | 1st, 2nd, ..., 7th                | 5     |
 * |                                 |     | ii      | 01, 02, ..., 07                   | 5     |
 * |                                 |     | iii     | Mon, Tue, Wed, ..., Sun           | 5     |
 * |                                 |     | iiii    | Monday, Tuesday, ..., Sunday      | 2,5   |
 * |                                 |     | iiiii   | M, T, W, T, F, S, S               | 5     |
 * |                                 |     | iiiiii  | Mo, Tu, We, Th, Fr, Sa, Su        | 5     |
 * | Local day of week (formatting)  |  90 | e       | 2, 3, 4, ..., 1                   |       |
 * |                                 |     | eo      | 2nd, 3rd, ..., 1st                | 5     |
 * |                                 |     | ee      | 02, 03, ..., 01                   |       |
 * |                                 |     | eee     | Mon, Tue, Wed, ..., Sun           |       |
 * |                                 |     | eeee    | Monday, Tuesday, ..., Sunday      | 2     |
 * |                                 |     | eeeee   | M, T, W, T, F, S, S               |       |
 * |                                 |     | eeeeee  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
 * | Local day of week (stand-alone) |  90 | c       | 2, 3, 4, ..., 1                   |       |
 * |                                 |     | co      | 2nd, 3rd, ..., 1st                | 5     |
 * |                                 |     | cc      | 02, 03, ..., 01                   |       |
 * |                                 |     | ccc     | Mon, Tue, Wed, ..., Sun           |       |
 * |                                 |     | cccc    | Monday, Tuesday, ..., Sunday      | 2     |
 * |                                 |     | ccccc   | M, T, W, T, F, S, S               |       |
 * |                                 |     | cccccc  | Mo, Tu, We, Th, Fr, Sa, Su        |       |
 * | AM, PM                          |  80 | a..aaa  | AM, PM                            |       |
 * |                                 |     | aaaa    | a.m., p.m.                        | 2     |
 * |                                 |     | aaaaa   | a, p                              |       |
 * | AM, PM, noon, midnight          |  80 | b..bbb  | AM, PM, noon, midnight            |       |
 * |                                 |     | bbbb    | a.m., p.m., noon, midnight        | 2     |
 * |                                 |     | bbbbb   | a, p, n, mi                       |       |
 * | Flexible day period             |  80 | B..BBB  | at night, in the morning, ...     |       |
 * |                                 |     | BBBB    | at night, in the morning, ...     | 2     |
 * |                                 |     | BBBBB   | at night, in the morning, ...     |       |
 * | Hour [1-12]                     |  70 | h       | 1, 2, ..., 11, 12                 |       |
 * |                                 |     | ho      | 1st, 2nd, ..., 11th, 12th         | 5     |
 * |                                 |     | hh      | 01, 02, ..., 11, 12               |       |
 * | Hour [0-23]                     |  70 | H       | 0, 1, 2, ..., 23                  |       |
 * |                                 |     | Ho      | 0th, 1st, 2nd, ..., 23rd          | 5     |
 * |                                 |     | HH      | 00, 01, 02, ..., 23               |       |
 * | Hour [0-11]                     |  70 | K       | 1, 2, ..., 11, 0                  |       |
 * |                                 |     | Ko      | 1st, 2nd, ..., 11th, 0th          | 5     |
 * |                                 |     | KK      | 01, 02, ..., 11, 00               |       |
 * | Hour [1-24]                     |  70 | k       | 24, 1, 2, ..., 23                 |       |
 * |                                 |     | ko      | 24th, 1st, 2nd, ..., 23rd         | 5     |
 * |                                 |     | kk      | 24, 01, 02, ..., 23               |       |
 * | Minute                          |  60 | m       | 0, 1, ..., 59                     |       |
 * |                                 |     | mo      | 0th, 1st, ..., 59th               | 5     |
 * |                                 |     | mm      | 00, 01, ..., 59                   |       |
 * | Second                          |  50 | s       | 0, 1, ..., 59                     |       |
 * |                                 |     | so      | 0th, 1st, ..., 59th               | 5     |
 * |                                 |     | ss      | 00, 01, ..., 59                   |       |
 * | Seconds timestamp               |  40 | t       | 512969520                         |       |
 * |                                 |     | tt      | ...                               | 2     |
 * | Fraction of second              |  30 | S       | 0, 1, ..., 9                      |       |
 * |                                 |     | SS      | 00, 01, ..., 99                   |       |
 * |                                 |     | SSS     | 000, 001, ..., 999                |       |
 * |                                 |     | SSSS    | ...                               | 2     |
 * | Milliseconds timestamp          |  20 | T       | 512969520900                      |       |
 * |                                 |     | TT      | ...                               | 2     |
 * | Timezone (ISO-8601 w/ Z)        |  10 | X       | -08, +0530, Z                     |       |
 * |                                 |     | XX      | -0800, +0530, Z                   |       |
 * |                                 |     | XXX     | -08:00, +05:30, Z                 |       |
 * |                                 |     | XXXX    | -0800, +0530, Z, +123456          | 2     |
 * |                                 |     | XXXXX   | -08:00, +05:30, Z, +12:34:56      |       |
 * | Timezone (ISO-8601 w/o Z)       |  10 | x       | -08, +0530, +00                   |       |
 * |                                 |     | xx      | -0800, +0530, +0000               |       |
 * |                                 |     | xxx     | -08:00, +05:30, +00:00            | 2     |
 * |                                 |     | xxxx    | -0800, +0530, +0000, +123456      |       |
 * |                                 |     | xxxxx   | -08:00, +05:30, +00:00, +12:34:56 |       |
 * | Long localized date             |  NA | P       | 05/29/1453                        | 5,8   |
 * |                                 |     | PP      | May 29, 1453                      |       |
 * |                                 |     | PPP     | May 29th, 1453                    |       |
 * |                                 |     | PPPP    | Sunday, May 29th, 1453            | 2,5,8 |
 * | Long localized time             |  NA | p       | 12:00 AM                          | 5,8   |
 * |                                 |     | pp      | 12:00:00 AM                       |       |
 * | Combination of date and time    |  NA | Pp      | 05/29/1453, 12:00 AM              |       |
 * |                                 |     | PPpp    | May 29, 1453, 12:00:00 AM         |       |
 * |                                 |     | PPPpp   | May 29th, 1453 at ...             |       |
 * |                                 |     | PPPPpp  | Sunday, May 29th, 1453 at ...     | 2,5,8 |
 * Notes:
 * 1. "Formatting" units (e.g. formatting quarter) in the default en-US locale
 *    are the same as "stand-alone" units, but are different in some languages.
 *    "Formatting" units are declined according to the rules of the language
 *    in the context of a date. "Stand-alone" units are always nominative singular.
 *    In `format` function, they will produce different result:
 *
 *    `format(new Date(2017, 10, 6), 'do LLLL', {locale: cs}) //=> '6. listopad'`
 *
 *    `format(new Date(2017, 10, 6), 'do MMMM', {locale: cs}) //=> '6. listopadu'`
 *
 *    `parse` will try to match both formatting and stand-alone units interchangably.
 *
 * 2. Any sequence of the identical letters is a pattern, unless it is escaped by
 *    the single quote characters (see below).
 *    If the sequence is longer than listed in table:
 *    - for numerical units (`yyyyyyyy`) `parse` will try to match a number
 *      as wide as the sequence
 *    - for text units (`MMMMMMMM`) `parse` will try to match the widest variation of the unit.
 *      These variations are marked with "2" in the last column of the table.
 *
 * 3. `QQQQQ` and `qqqqq` could be not strictly numerical in some locales.
 *    These tokens represent the shortest form of the quarter.
 *
 * 4. The main difference between `y` and `u` patterns are B.C. years:
 *
 *    | Year | `y` | `u` |
 *    |------|-----|-----|
 *    | AC 1 |   1 |   1 |
 *    | BC 1 |   1 |   0 |
 *    | BC 2 |   2 |  -1 |
 *
 *    Also `yy` will try to guess the century of two digit year by proximity with `referenceDate`:
 *
 *    `parse('50', 'yy', new Date(2018, 0, 1)) //=> Sat Jan 01 2050 00:00:00`
 *
 *    `parse('75', 'yy', new Date(2018, 0, 1)) //=> Wed Jan 01 1975 00:00:00`
 *
 *    while `uu` will just assign the year as is:
 *
 *    `parse('50', 'uu', new Date(2018, 0, 1)) //=> Sat Jan 01 0050 00:00:00`
 *
 *    `parse('75', 'uu', new Date(2018, 0, 1)) //=> Tue Jan 01 0075 00:00:00`
 *
 *    The same difference is true for local and ISO week-numbering years (`Y` and `R`),
 *    except local week-numbering years are dependent on `options.weekStartsOn`
 *    and `options.firstWeekContainsDate` (compare [setISOWeekYear]{@link https://date-fns.org/docs/setISOWeekYear}
 *    and [setWeekYear]{@link https://date-fns.org/docs/setWeekYear}).
 *
 * 5. These patterns are not in the Unicode Technical Standard #35:
 *    - `i`: ISO day of week
 *    - `I`: ISO week of year
 *    - `R`: ISO week-numbering year
 *    - `o`: ordinal number modifier
 *    - `P`: long localized date
 *    - `p`: long localized time
 *
 * 6. `YY` and `YYYY` tokens represent week-numbering years but they are often confused with years.
 *    You should enable `options.useAdditionalWeekYearTokens` to use them. See: https://git.io/fxCyr
 *
 * 7. `D` and `DD` tokens represent days of the year but they are ofthen confused with days of the month.
 *    You should enable `options.useAdditionalDayOfYearTokens` to use them. See: https://git.io/fxCyr
 *
 * 8. `P+` tokens do not have a defined priority since they are merely aliases to other tokens based
 *    on the given locale.
 *
 *    using `en-US` locale: `P` => `MM/dd/yyyy`
 *    using `en-US` locale: `p` => `hh:mm a`
 *    using `pt-BR` locale: `P` => `dd/MM/yyyy`
 *    using `pt-BR` locale: `p` => `HH:mm`
 *
 * Values will be assigned to the date in the descending order of its unit's priority.
 * Units of an equal priority overwrite each other in the order of appearance.
 *
 * If no values of higher priority are parsed (e.g. when parsing string 'January 1st' without a year),
 * the values will be taken from 3rd argument `referenceDate` which works as a context of parsing.
 *
 * `referenceDate` must be passed for correct work of the function.
 * If you're not sure which `referenceDate` to supply, create a new instance of Date:
 * `parse('02/11/2014', 'MM/dd/yyyy', new Date())`
 * In this case parsing will be done in the context of the current date.
 * If `referenceDate` is `Invalid Date` or a value not convertible to valid `Date`,
 * then `Invalid Date` will be returned.
 *
 * The result may vary by locale.
 *
 * If `formatString` matches with `dateString` but does not provides tokens, `referenceDate` will be returned.
 *
 * If parsing failed, `Invalid Date` will be returned.
 * Invalid Date is a Date, whose time value is NaN.
 * Time value of Date: http://es5.github.io/#x15.9.1.1
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * - Old `parse` was renamed to `toDate`.
 *   Now `parse` is a new function which parses a string using a provided format.
 *
 *   ```javascript
 *   // Before v2.0.0
 *   parse('2016-01-01')
 *
 *   // v2.0.0 onward (toDate no longer accepts a string)
 *   toDate(1392098430000) // Unix to timestamp
 *   toDate(new Date(2014, 1, 11, 11, 30, 30)) // Cloning the date
 *   parse('2016-01-01', 'yyyy-MM-dd', new Date())
 *   ```
 *
 * @param {String} dateString - the string to parse
 * @param {String} formatString - the string of tokens
 * @param {Date|Number} referenceDate - defines values missing from the parsed dateString
 * @param {Object} [options] - an object with options.
 * @param {Locale} [options.locale=defaultLocale] - the locale object. See [Locale]{@link https://date-fns.org/docs/Locale}
 * @param {0|1|2|3|4|5|6} [options.weekStartsOn=0] - the index of the first day of the week (0 - Sunday)
 * @param {1|2|3|4|5|6|7} [options.firstWeekContainsDate=1] - the day of January, which is always in the first week of the year
 * @param {Boolean} [options.useAdditionalWeekYearTokens=false] - if true, allows usage of the week-numbering year tokens `YY` and `YYYY`;
 *   see: https://git.io/fxCyr
 * @param {Boolean} [options.useAdditionalDayOfYearTokens=false] - if true, allows usage of the day of year tokens `D` and `DD`;
 *   see: https://git.io/fxCyr
 * @returns {Date} the parsed date
 * @throws {TypeError} 3 arguments required
 * @throws {RangeError} `options.weekStartsOn` must be between 0 and 6
 * @throws {RangeError} `options.firstWeekContainsDate` must be between 1 and 7
 * @throws {RangeError} `options.locale` must contain `match` property
 * @throws {RangeError} use `yyyy` instead of `YYYY` for formatting years using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} use `yy` instead of `YY` for formatting years using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} use `d` instead of `D` for formatting days of the month using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} use `dd` instead of `DD` for formatting days of the month using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} format string contains an unescaped latin alphabet character
 *
 * @example
 * // Parse 11 February 2014 from middle-endian format:
 * var result = parse('02/11/2014', 'MM/dd/yyyy', new Date())
 * //=> Tue Feb 11 2014 00:00:00
 *
 * @example
 * // Parse 28th of February in Esperanto locale in the context of 2010 year:
 * import eo from 'date-fns/locale/eo'
 * var result = parse('28-a de februaro', "do 'de' MMMM", new Date(2010, 0, 1), {
 *   locale: eo
 * })
 * //=> Sun Feb 28 2010 00:00:00
 */

function parse(dirtyDateString, dirtyFormatString, dirtyReferenceDate, dirtyOptions) {
  (0,_lib_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(3, arguments);
  var dateString = String(dirtyDateString);
  var formatString = String(dirtyFormatString);
  var options = dirtyOptions || {};
  var locale = options.locale || _locale_en_US_index_js__WEBPACK_IMPORTED_MODULE_1__["default"];

  if (!locale.match) {
    throw new RangeError('locale must contain match property');
  }

  var localeFirstWeekContainsDate = locale.options && locale.options.firstWeekContainsDate;
  var defaultFirstWeekContainsDate = localeFirstWeekContainsDate == null ? 1 : (0,_lib_toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(localeFirstWeekContainsDate);
  var firstWeekContainsDate = options.firstWeekContainsDate == null ? defaultFirstWeekContainsDate : (0,_lib_toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(options.firstWeekContainsDate); // Test if weekStartsOn is between 1 and 7 _and_ is not NaN

  if (!(firstWeekContainsDate >= 1 && firstWeekContainsDate <= 7)) {
    throw new RangeError('firstWeekContainsDate must be between 1 and 7 inclusively');
  }

  var localeWeekStartsOn = locale.options && locale.options.weekStartsOn;
  var defaultWeekStartsOn = localeWeekStartsOn == null ? 0 : (0,_lib_toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(localeWeekStartsOn);
  var weekStartsOn = options.weekStartsOn == null ? defaultWeekStartsOn : (0,_lib_toInteger_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(options.weekStartsOn); // Test if weekStartsOn is between 0 and 6 _and_ is not NaN

  if (!(weekStartsOn >= 0 && weekStartsOn <= 6)) {
    throw new RangeError('weekStartsOn must be between 0 and 6 inclusively');
  }

  if (formatString === '') {
    if (dateString === '') {
      return (0,_toDate_index_js__WEBPACK_IMPORTED_MODULE_3__["default"])(dirtyReferenceDate);
    } else {
      return new Date(NaN);
    }
  }

  var subFnOptions = {
    firstWeekContainsDate: firstWeekContainsDate,
    weekStartsOn: weekStartsOn,
    locale: locale
  }; // If timezone isn't specified, it will be set to the system timezone

  var setters = [{
    priority: TIMEZONE_UNIT_PRIORITY,
    subPriority: -1,
    set: dateToSystemTimezone,
    index: 0
  }];
  var i;
  var tokens = formatString.match(longFormattingTokensRegExp).map(function (substring) {
    var firstCharacter = substring[0];

    if (firstCharacter === 'p' || firstCharacter === 'P') {
      var longFormatter = _lib_format_longFormatters_index_js__WEBPACK_IMPORTED_MODULE_4__["default"][firstCharacter];
      return longFormatter(substring, locale.formatLong, subFnOptions);
    }

    return substring;
  }).join('').match(formattingTokensRegExp);
  var usedTokens = [];

  for (i = 0; i < tokens.length; i++) {
    var token = tokens[i];

    if (!options.useAdditionalWeekYearTokens && (0,_lib_protectedTokens_index_js__WEBPACK_IMPORTED_MODULE_5__.isProtectedWeekYearToken)(token)) {
      (0,_lib_protectedTokens_index_js__WEBPACK_IMPORTED_MODULE_5__.throwProtectedError)(token, formatString, dirtyDateString);
    }

    if (!options.useAdditionalDayOfYearTokens && (0,_lib_protectedTokens_index_js__WEBPACK_IMPORTED_MODULE_5__.isProtectedDayOfYearToken)(token)) {
      (0,_lib_protectedTokens_index_js__WEBPACK_IMPORTED_MODULE_5__.throwProtectedError)(token, formatString, dirtyDateString);
    }

    var firstCharacter = token[0];
    var parser = _lib_parsers_index_js__WEBPACK_IMPORTED_MODULE_6__["default"][firstCharacter];

    if (parser) {
      var incompatibleTokens = parser.incompatibleTokens;

      if (Array.isArray(incompatibleTokens)) {
        var incompatibleToken = void 0;

        for (var _i = 0; _i < usedTokens.length; _i++) {
          var usedToken = usedTokens[_i].token;

          if (incompatibleTokens.indexOf(usedToken) !== -1 || usedToken === firstCharacter) {
            incompatibleToken = usedTokens[_i];
            break;
          }
        }

        if (incompatibleToken) {
          throw new RangeError("The format string mustn't contain `".concat(incompatibleToken.fullToken, "` and `").concat(token, "` at the same time"));
        }
      } else if (parser.incompatibleTokens === '*' && usedTokens.length) {
        throw new RangeError("The format string mustn't contain `".concat(token, "` and any other token at the same time"));
      }

      usedTokens.push({
        token: firstCharacter,
        fullToken: token
      });
      var parseResult = parser.parse(dateString, token, locale.match, subFnOptions);

      if (!parseResult) {
        return new Date(NaN);
      }

      setters.push({
        priority: parser.priority,
        subPriority: parser.subPriority || 0,
        set: parser.set,
        validate: parser.validate,
        value: parseResult.value,
        index: setters.length
      });
      dateString = parseResult.rest;
    } else {
      if (firstCharacter.match(unescapedLatinCharacterRegExp)) {
        throw new RangeError('Format string contains an unescaped latin alphabet character `' + firstCharacter + '`');
      } // Replace two single quote characters with one single quote character


      if (token === "''") {
        token = "'";
      } else if (firstCharacter === "'") {
        token = cleanEscapedString(token);
      } // Cut token from string, or, if string doesn't match the token, return Invalid Date


      if (dateString.indexOf(token) === 0) {
        dateString = dateString.slice(token.length);
      } else {
        return new Date(NaN);
      }
    }
  } // Check if the remaining input contains something other than whitespace


  if (dateString.length > 0 && notWhitespaceRegExp.test(dateString)) {
    return new Date(NaN);
  }

  var uniquePrioritySetters = setters.map(function (setter) {
    return setter.priority;
  }).sort(function (a, b) {
    return b - a;
  }).filter(function (priority, index, array) {
    return array.indexOf(priority) === index;
  }).map(function (priority) {
    return setters.filter(function (setter) {
      return setter.priority === priority;
    }).sort(function (a, b) {
      return b.subPriority - a.subPriority;
    });
  }).map(function (setterArray) {
    return setterArray[0];
  });
  var date = (0,_toDate_index_js__WEBPACK_IMPORTED_MODULE_3__["default"])(dirtyReferenceDate);

  if (isNaN(date)) {
    return new Date(NaN);
  } // Convert the date in system timezone to the same date in UTC+00:00 timezone.
  // This ensures that when UTC functions will be implemented, locales will be compatible with them.
  // See an issue about UTC functions: https://github.com/date-fns/date-fns/issues/37


  var utcDate = (0,_subMilliseconds_index_js__WEBPACK_IMPORTED_MODULE_7__["default"])(date, (0,_lib_getTimezoneOffsetInMilliseconds_index_js__WEBPACK_IMPORTED_MODULE_8__["default"])(date));
  var flags = {};

  for (i = 0; i < uniquePrioritySetters.length; i++) {
    var setter = uniquePrioritySetters[i];

    if (setter.validate && !setter.validate(utcDate, setter.value, subFnOptions)) {
      return new Date(NaN);
    }

    var result = setter.set(utcDate, flags, setter.value, subFnOptions); // Result is tuple (date, flags)

    if (result[0]) {
      utcDate = result[0];
      (0,_lib_assign_index_js__WEBPACK_IMPORTED_MODULE_9__["default"])(flags, result[1]); // Result is date
    } else {
      utcDate = result;
    }
  }

  return utcDate;
}

function dateToSystemTimezone(date, flags) {
  if (flags.timestampIsSet) {
    return date;
  }

  var convertedDate = new Date(0);
  convertedDate.setFullYear(date.getUTCFullYear(), date.getUTCMonth(), date.getUTCDate());
  convertedDate.setHours(date.getUTCHours(), date.getUTCMinutes(), date.getUTCSeconds(), date.getUTCMilliseconds());
  return convertedDate;
}

function cleanEscapedString(input) {
  return input.match(escapedStringRegExp)[1].replace(doubleQuoteRegExp, "'");
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/subMilliseconds/index.js":
/*!*******************************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/subMilliseconds/index.js ***!
  \*******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ subMilliseconds)
/* harmony export */ });
/* harmony import */ var _lib_toInteger_index_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../_lib/toInteger/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/toInteger/index.js");
/* harmony import */ var _addMilliseconds_index_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../addMilliseconds/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/addMilliseconds/index.js");
/* harmony import */ var _lib_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../_lib/requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");



/**
 * @name subMilliseconds
 * @category Millisecond Helpers
 * @summary Subtract the specified number of milliseconds from the given date.
 *
 * @description
 * Subtract the specified number of milliseconds from the given date.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} date - the date to be changed
 * @param {Number} amount - the amount of milliseconds to be subtracted. Positive decimals will be rounded using `Math.floor`, decimals less than zero will be rounded using `Math.ceil`.
 * @returns {Date} the new date with the milliseconds subtracted
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // Subtract 750 milliseconds from 10 July 2014 12:45:30.000:
 * const result = subMilliseconds(new Date(2014, 6, 10, 12, 45, 30, 0), 750)
 * //=> Thu Jul 10 2014 12:45:29.250
 */

function subMilliseconds(dirtyDate, dirtyAmount) {
  (0,_lib_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(2, arguments);
  var amount = (0,_lib_toInteger_index_js__WEBPACK_IMPORTED_MODULE_1__["default"])(dirtyAmount);
  return (0,_addMilliseconds_index_js__WEBPACK_IMPORTED_MODULE_2__["default"])(dirtyDate, -amount);
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/toDate/index.js":
/*!**********************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/date-fns/esm/toDate/index.js ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ toDate)
/* harmony export */ });
/* harmony import */ var _lib_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../_lib/requiredArgs/index.js */ "../../node_modules/@elyra/canvas/node_modules/date-fns/esm/_lib/requiredArgs/index.js");

/**
 * @name toDate
 * @category Common Helpers
 * @summary Convert the given argument to an instance of Date.
 *
 * @description
 * Convert the given argument to an instance of Date.
 *
 * If the argument is an instance of Date, the function returns its clone.
 *
 * If the argument is a number, it is treated as a timestamp.
 *
 * If the argument is none of the above, the function returns Invalid Date.
 *
 * **Note**: *all* Date arguments passed to any *date-fns* function is processed by `toDate`.
 *
 * @param {Date|Number} argument - the value to convert
 * @returns {Date} the parsed date in the local time zone
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // Clone the date:
 * const result = toDate(new Date(2014, 1, 11, 11, 30, 30))
 * //=> Tue Feb 11 2014 11:30:30
 *
 * @example
 * // Convert the timestamp to date:
 * const result = toDate(1392098430000)
 * //=> Tue Feb 11 2014 11:30:30
 */

function toDate(argument) {
  (0,_lib_requiredArgs_index_js__WEBPACK_IMPORTED_MODULE_0__["default"])(1, arguments);
  var argStr = Object.prototype.toString.call(argument); // Clone the date

  if (argument instanceof Date || typeof argument === 'object' && argStr === '[object Date]') {
    // Prevent the date to lose the milliseconds when passed to new Date() in IE10
    return new Date(argument.getTime());
  } else if (typeof argument === 'number' || argStr === '[object Number]') {
    return new Date(argument);
  } else {
    if ((typeof argument === 'string' || argStr === '[object String]') && typeof console !== 'undefined') {
      // eslint-disable-next-line no-console
      console.warn("Starting with v2.0.0-beta.1 date-fns doesn't accept strings as date arguments. Please use `parseISO` to parse strings. See: https://git.io/fjule"); // eslint-disable-next-line no-console

      console.warn(new Error().stack);
    }

    return new Date(NaN);
  }
}

/***/ }),

/***/ "../../node_modules/@elyra/canvas/node_modules/react-codemirror2/index.js":
/*!********************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/node_modules/react-codemirror2/index.js ***!
  \********************************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


function _extends() {
  _extends = Object.assign || function(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}

function _typeof(obj) {
  "@babel/helpers - typeof";
  if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
    _typeof = function _typeof(obj) {
      return typeof obj;
    };
  } else {
    _typeof = function _typeof(obj) {
      return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    };
  }
  return _typeof(obj);
}

var __extends = void 0 && (void 0).__extends || function() {
  var _extendStatics = function extendStatics(d, b) {
    _extendStatics = Object.setPrototypeOf || {
      __proto__: []
    }
    instanceof Array && function(d, b) {
      d.__proto__ = b;
    } || function(d, b) {
      for (var p in b) {
        if (b.hasOwnProperty(p)) d[p] = b[p];
      }
    };

    return _extendStatics(d, b);
  };

  return function(d, b) {
    _extendStatics(d, b);

    function __() {
      this.constructor = d;
    }

    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
  };
}();

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports.UnControlled = exports.Controlled = void 0;

var React = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");

var SERVER_RENDERED = typeof navigator === 'undefined' || __webpack_require__.g['PREVENT_CODEMIRROR_RENDER'] === true;
var cm;

if (!SERVER_RENDERED) {
  cm = __webpack_require__(/*! codemirror */ "../../node_modules/@elyra/canvas/node_modules/codemirror/lib/codemirror.js");
}

var Helper = function() {
  function Helper() {}

  Helper.equals = function(x, y) {
    var _this = this;

    var ok = Object.keys,
      tx = _typeof(x),
      ty = _typeof(y);

    return x && y && tx === 'object' && tx === ty ? ok(x).length === ok(y).length && ok(x).every(function(key) {
      return _this.equals(x[key], y[key]);
    }) : x === y;
  };

  return Helper;
}();

var Shared = function() {
  function Shared(editor, props) {
    this.editor = editor;
    this.props = props;
  }

  Shared.prototype.delegateCursor = function(position, scroll, focus) {
    var doc = this.editor.getDoc();

    if (focus) {
      this.editor.focus();
    }

    scroll ? doc.setCursor(position) : doc.setCursor(position, null, {
      scroll: false
    });
  };

  Shared.prototype.delegateScroll = function(coordinates) {
    this.editor.scrollTo(coordinates.x, coordinates.y);
  };

  Shared.prototype.delegateSelection = function(ranges, focus) {
    var doc = this.editor.getDoc();
    doc.setSelections(ranges);

    if (focus) {
      this.editor.focus();
    }
  };

  Shared.prototype.apply = function(props) {
    if (props && props.selection && props.selection.ranges) {
      this.delegateSelection(props.selection.ranges, props.selection.focus || false);
    }

    if (props && props.cursor) {
      this.delegateCursor(props.cursor, props.autoScroll || false, this.editor.getOption('autofocus') || false);
    }

    if (props && props.scroll) {
      this.delegateScroll(props.scroll);
    }
  };

  Shared.prototype.applyNext = function(props, next, preserved) {
    if (props && props.selection && props.selection.ranges) {
      if (next && next.selection && next.selection.ranges && !Helper.equals(props.selection.ranges, next.selection.ranges)) {
        this.delegateSelection(next.selection.ranges, next.selection.focus || false);
      }
    }

    if (props && props.cursor) {
      if (next && next.cursor && !Helper.equals(props.cursor, next.cursor)) {
        this.delegateCursor(preserved.cursor || next.cursor, next.autoScroll || false, next.autoCursor || false);
      }
    }

    if (props && props.scroll) {
      if (next && next.scroll && !Helper.equals(props.scroll, next.scroll)) {
        this.delegateScroll(next.scroll);
      }
    }
  };

  Shared.prototype.applyUserDefined = function(props, preserved) {
    if (preserved && preserved.cursor) {
      this.delegateCursor(preserved.cursor, props.autoScroll || false, this.editor.getOption('autofocus') || false);
    }
  };

  Shared.prototype.wire = function(props) {
    var _this = this;

    Object.keys(props || {}).filter(function(p) {
      return /^on/.test(p);
    }).forEach(function(prop) {
      switch (prop) {
        case 'onBlur': {
          _this.editor.on('blur', function(cm, event) {
            _this.props.onBlur(_this.editor, event);
          });
        }
        break;

      case 'onContextMenu': {
        _this.editor.on('contextmenu', function(cm, event) {
          _this.props.onContextMenu(_this.editor, event);
        });

        break;
      }

      case 'onCopy': {
        _this.editor.on('copy', function(cm, event) {
          _this.props.onCopy(_this.editor, event);
        });

        break;
      }

      case 'onCursor': {
        _this.editor.on('cursorActivity', function(cm) {
          _this.props.onCursor(_this.editor, _this.editor.getDoc().getCursor());
        });
      }
      break;

      case 'onCursorActivity': {
        _this.editor.on('cursorActivity', function(cm) {
          _this.props.onCursorActivity(_this.editor);
        });
      }
      break;

      case 'onCut': {
        _this.editor.on('cut', function(cm, event) {
          _this.props.onCut(_this.editor, event);
        });

        break;
      }

      case 'onDblClick': {
        _this.editor.on('dblclick', function(cm, event) {
          _this.props.onDblClick(_this.editor, event);
        });

        break;
      }

      case 'onDragEnter': {
        _this.editor.on('dragenter', function(cm, event) {
          _this.props.onDragEnter(_this.editor, event);
        });
      }
      break;

      case 'onDragLeave': {
        _this.editor.on('dragleave', function(cm, event) {
          _this.props.onDragLeave(_this.editor, event);
        });

        break;
      }

      case 'onDragOver': {
        _this.editor.on('dragover', function(cm, event) {
          _this.props.onDragOver(_this.editor, event);
        });
      }
      break;

      case 'onDragStart': {
        _this.editor.on('dragstart', function(cm, event) {
          _this.props.onDragStart(_this.editor, event);
        });

        break;
      }

      case 'onDrop': {
        _this.editor.on('drop', function(cm, event) {
          _this.props.onDrop(_this.editor, event);
        });
      }
      break;

      case 'onFocus': {
        _this.editor.on('focus', function(cm, event) {
          _this.props.onFocus(_this.editor, event);
        });
      }
      break;

      case 'onGutterClick': {
        _this.editor.on('gutterClick', function(cm, lineNumber, gutter, event) {
          _this.props.onGutterClick(_this.editor, lineNumber, gutter, event);
        });
      }
      break;

      case 'onInputRead': {
        _this.editor.on('inputRead', function(cm, EditorChangeEvent) {
          _this.props.onInputRead(_this.editor, EditorChangeEvent);
        });
      }
      break;

      case 'onKeyDown': {
        _this.editor.on('keydown', function(cm, event) {
          _this.props.onKeyDown(_this.editor, event);
        });
      }
      break;

      case 'onKeyHandled': {
        _this.editor.on('keyHandled', function(cm, key, event) {
          _this.props.onKeyHandled(_this.editor, key, event);
        });
      }
      break;

      case 'onKeyPress': {
        _this.editor.on('keypress', function(cm, event) {
          _this.props.onKeyPress(_this.editor, event);
        });
      }
      break;

      case 'onKeyUp': {
        _this.editor.on('keyup', function(cm, event) {
          _this.props.onKeyUp(_this.editor, event);
        });
      }
      break;

      case 'onMouseDown': {
        _this.editor.on('mousedown', function(cm, event) {
          _this.props.onMouseDown(_this.editor, event);
        });

        break;
      }

      case 'onPaste': {
        _this.editor.on('paste', function(cm, event) {
          _this.props.onPaste(_this.editor, event);
        });

        break;
      }

      case 'onRenderLine': {
        _this.editor.on('renderLine', function(cm, line, element) {
          _this.props.onRenderLine(_this.editor, line, element);
        });

        break;
      }

      case 'onScroll': {
        _this.editor.on('scroll', function(cm) {
          _this.props.onScroll(_this.editor, _this.editor.getScrollInfo());
        });
      }
      break;

      case 'onSelection': {
        _this.editor.on('beforeSelectionChange', function(cm, data) {
          _this.props.onSelection(_this.editor, data);
        });
      }
      break;

      case 'onTouchStart': {
        _this.editor.on('touchstart', function(cm, event) {
          _this.props.onTouchStart(_this.editor, event);
        });

        break;
      }

      case 'onUpdate': {
        _this.editor.on('update', function(cm) {
          _this.props.onUpdate(_this.editor);
        });
      }
      break;

      case 'onViewportChange': {
        _this.editor.on('viewportChange', function(cm, from, to) {
          _this.props.onViewportChange(_this.editor, from, to);
        });
      }
      break;
      }
    });
  };

  return Shared;
}();

var Controlled = function(_super) {
  __extends(Controlled, _super);

  function Controlled(props) {
    var _this = _super.call(this, props) || this;

    if (SERVER_RENDERED) return _this;
    _this.applied = false;
    _this.appliedNext = false;
    _this.appliedUserDefined = false;
    _this.deferred = null;
    _this.emulating = false;
    _this.hydrated = false;

    _this.initCb = function() {
      if (_this.props.editorDidConfigure) {
        _this.props.editorDidConfigure(_this.editor);
      }
    };

    _this.mounted = false;
    return _this;
  }

  Controlled.prototype.hydrate = function(props) {
    var _this = this;

    var _options = props && props.options ? props.options : {};

    var userDefinedOptions = _extends({}, cm.defaults, this.editor.options, _options);

    var optionDelta = Object.keys(userDefinedOptions).some(function(key) {
      return _this.editor.getOption(key) !== userDefinedOptions[key];
    });

    if (optionDelta) {
      Object.keys(userDefinedOptions).forEach(function(key) {
        if (_options.hasOwnProperty(key)) {
          if (_this.editor.getOption(key) !== userDefinedOptions[key]) {
            _this.editor.setOption(key, userDefinedOptions[key]);

            _this.mirror.setOption(key, userDefinedOptions[key]);
          }
        }
      });
    }

    if (!this.hydrated) {
      this.deferred ? this.resolveChange(props.value) : this.initChange(props.value || '');
    }

    this.hydrated = true;
  };

  Controlled.prototype.initChange = function(value) {
    this.emulating = true;
    var doc = this.editor.getDoc();
    var lastLine = doc.lastLine();
    var lastChar = doc.getLine(doc.lastLine()).length;
    doc.replaceRange(value || '', {
      line: 0,
      ch: 0
    }, {
      line: lastLine,
      ch: lastChar
    });
    this.mirror.setValue(value);
    doc.clearHistory();
    this.mirror.clearHistory();
    this.emulating = false;
  };

  Controlled.prototype.resolveChange = function(value) {
    this.emulating = true;
    var doc = this.editor.getDoc();

    if (this.deferred.origin === 'undo') {
      doc.undo();
    } else if (this.deferred.origin === 'redo') {
      doc.redo();
    } else {
      doc.replaceRange(this.deferred.text, this.deferred.from, this.deferred.to, this.deferred.origin);
    }

    if (value && value !== doc.getValue()) {
      var cursor = doc.getCursor();
      doc.setValue(value);
      doc.setCursor(cursor);
    }

    this.emulating = false;
    this.deferred = null;
  };

  Controlled.prototype.mirrorChange = function(deferred) {
    var doc = this.editor.getDoc();

    if (deferred.origin === 'undo') {
      doc.setHistory(this.mirror.getHistory());
      this.mirror.undo();
    } else if (deferred.origin === 'redo') {
      doc.setHistory(this.mirror.getHistory());
      this.mirror.redo();
    } else {
      this.mirror.replaceRange(deferred.text, deferred.from, deferred.to, deferred.origin);
    }

    return this.mirror.getValue();
  };

  Controlled.prototype.componentDidMount = function() {
    var _this = this;

    if (SERVER_RENDERED) return;

    if (this.props.defineMode) {
      if (this.props.defineMode.name && this.props.defineMode.fn) {
        cm.defineMode(this.props.defineMode.name, this.props.defineMode.fn);
      }
    }

    this.editor = cm(this.ref, this.props.options);
    this.shared = new Shared(this.editor, this.props);
    this.mirror = cm(function() {}, this.props.options);
    this.editor.on('electricInput', function() {
      _this.mirror.setHistory(_this.editor.getDoc().getHistory());
    });
    this.editor.on('cursorActivity', function() {
      _this.mirror.setCursor(_this.editor.getDoc().getCursor());
    });
    this.editor.on('beforeChange', function(cm, data) {
      if (_this.emulating) {
        return;
      }

      data.cancel();
      _this.deferred = data;

      var phantomChange = _this.mirrorChange(_this.deferred);

      if (_this.props.onBeforeChange) _this.props.onBeforeChange(_this.editor, _this.deferred, phantomChange);
    });
    this.editor.on('change', function(cm, data) {
      if (!_this.mounted) {
        return;
      }

      if (_this.props.onChange) {
        _this.props.onChange(_this.editor, data, _this.editor.getValue());
      }
    });
    this.hydrate(this.props);
    this.shared.apply(this.props);
    this.applied = true;
    this.mounted = true;
    this.shared.wire(this.props);

    if (this.editor.getOption('autofocus')) {
      this.editor.focus();
    }

    if (this.props.editorDidMount) {
      this.props.editorDidMount(this.editor, this.editor.getValue(), this.initCb);
    }
  };

  Controlled.prototype.componentDidUpdate = function(prevProps) {
    if (SERVER_RENDERED) return;
    var preserved = {
      cursor: null
    };

    if (this.props.value !== prevProps.value) {
      this.hydrated = false;
    }

    if (!this.props.autoCursor && this.props.autoCursor !== undefined) {
      preserved.cursor = this.editor.getDoc().getCursor();
    }

    this.hydrate(this.props);

    if (!this.appliedNext) {
      this.shared.applyNext(prevProps, this.props, preserved);
      this.appliedNext = true;
    }

    this.shared.applyUserDefined(prevProps, preserved);
    this.appliedUserDefined = true;
  };

  Controlled.prototype.componentWillUnmount = function() {
    if (SERVER_RENDERED) return;

    if (this.props.editorWillUnmount) {
      this.props.editorWillUnmount(cm);
    }
  };

  Controlled.prototype.shouldComponentUpdate = function(nextProps, nextState) {
    return !SERVER_RENDERED;
  };

  Controlled.prototype.render = function() {
    var _this = this;

    if (SERVER_RENDERED) return null;
    var className = this.props.className ? 'react-codemirror2 ' + this.props.className : 'react-codemirror2';
    return React.createElement('div', {
      className: className,
      ref: function ref(self) {
        return _this.ref = self;
      }
    });
  };

  return Controlled;
}(React.Component);

exports.Controlled = Controlled;

var UnControlled = function(_super) {
  __extends(UnControlled, _super);

  function UnControlled(props) {
    var _this = _super.call(this, props) || this;

    if (SERVER_RENDERED) return _this;
    _this.applied = false;
    _this.appliedUserDefined = false;
    _this.continueChange = false;
    _this.detached = false;
    _this.hydrated = false;

    _this.initCb = function() {
      if (_this.props.editorDidConfigure) {
        _this.props.editorDidConfigure(_this.editor);
      }
    };

    _this.mounted = false;

    _this.onBeforeChangeCb = function() {
      _this.continueChange = true;
    };

    return _this;
  }

  UnControlled.prototype.hydrate = function(props) {
    var _this = this;

    var _options = props && props.options ? props.options : {};

    var userDefinedOptions = _extends({}, cm.defaults, this.editor.options, _options);

    var optionDelta = Object.keys(userDefinedOptions).some(function(key) {
      return _this.editor.getOption(key) !== userDefinedOptions[key];
    });

    if (optionDelta) {
      Object.keys(userDefinedOptions).forEach(function(key) {
        if (_options.hasOwnProperty(key)) {
          if (_this.editor.getOption(key) !== userDefinedOptions[key]) {
            _this.editor.setOption(key, userDefinedOptions[key]);
          }
        }
      });
    }

    if (!this.hydrated) {
      var doc = this.editor.getDoc();
      var lastLine = doc.lastLine();
      var lastChar = doc.getLine(doc.lastLine()).length;
      doc.replaceRange(props.value || '', {
        line: 0,
        ch: 0
      }, {
        line: lastLine,
        ch: lastChar
      });
    }

    this.hydrated = true;
  };

  UnControlled.prototype.componentDidMount = function() {
    var _this = this;

    if (SERVER_RENDERED) return;
    this.detached = this.props.detach === true;

    if (this.props.defineMode) {
      if (this.props.defineMode.name && this.props.defineMode.fn) {
        cm.defineMode(this.props.defineMode.name, this.props.defineMode.fn);
      }
    }

    this.editor = cm(this.ref, this.props.options);
    this.shared = new Shared(this.editor, this.props);
    this.editor.on('beforeChange', function(cm, data) {
      if (_this.props.onBeforeChange) {
        _this.props.onBeforeChange(_this.editor, data, _this.editor.getValue(), _this.onBeforeChangeCb);
      }
    });
    this.editor.on('change', function(cm, data) {
      if (!_this.mounted || !_this.props.onChange) {
        return;
      }

      if (_this.props.onBeforeChange) {
        if (_this.continueChange) {
          _this.props.onChange(_this.editor, data, _this.editor.getValue());
        }
      } else {
        _this.props.onChange(_this.editor, data, _this.editor.getValue());
      }
    });
    this.hydrate(this.props);
    this.shared.apply(this.props);
    this.applied = true;
    this.mounted = true;
    this.shared.wire(this.props);
    this.editor.getDoc().clearHistory();

    if (this.props.editorDidMount) {
      this.props.editorDidMount(this.editor, this.editor.getValue(), this.initCb);
    }
  };

  UnControlled.prototype.componentDidUpdate = function(prevProps) {
    if (this.detached && this.props.detach === false) {
      this.detached = false;

      if (prevProps.editorDidAttach) {
        prevProps.editorDidAttach(this.editor);
      }
    }

    if (!this.detached && this.props.detach === true) {
      this.detached = true;

      if (prevProps.editorDidDetach) {
        prevProps.editorDidDetach(this.editor);
      }
    }

    if (SERVER_RENDERED || this.detached) return;
    var preserved = {
      cursor: null
    };

    if (this.props.value !== prevProps.value) {
      this.hydrated = false;
      this.applied = false;
      this.appliedUserDefined = false;
    }

    if (!prevProps.autoCursor && prevProps.autoCursor !== undefined) {
      preserved.cursor = this.editor.getDoc().getCursor();
    }

    this.hydrate(this.props);

    if (!this.applied) {
      this.shared.apply(prevProps);
      this.applied = true;
    }

    if (!this.appliedUserDefined) {
      this.shared.applyUserDefined(prevProps, preserved);
      this.appliedUserDefined = true;
    }
  };

  UnControlled.prototype.componentWillUnmount = function() {
    if (SERVER_RENDERED) return;

    if (this.props.editorWillUnmount) {
      this.props.editorWillUnmount(cm);
    }
  };

  UnControlled.prototype.shouldComponentUpdate = function(nextProps, nextState) {
    var update = true;
    if (SERVER_RENDERED) update = false;
    if (this.detached && nextProps.detach) update = false;
    return update;
  };

  UnControlled.prototype.render = function() {
    var _this = this;

    if (SERVER_RENDERED) return null;
    var className = this.props.className ? 'react-codemirror2 ' + this.props.className : 'react-codemirror2';
    return React.createElement('div', {
      className: className,
      ref: function ref(self) {
        return _this.ref = self;
      }
    });
  };

  return UnControlled;
}(React.Component);

exports.UnControlled = UnControlled;

/***/ }),

/***/ "../../node_modules/@elyra/pipeline-editor/dist/index.js":
/*!***************************************************************!*\
  !*** ../../node_modules/@elyra/pipeline-editor/dist/index.js ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

var e=__webpack_require__(/*! react/jsx-runtime */ "../../node_modules/react/jsx-runtime.js"),n=__webpack_require__(/*! react */ "webpack/sharing/consume/default/react"),t=__webpack_require__(/*! styled-components */ "../../node_modules/styled-components/dist/styled-components.browser.esm.js"),r=__webpack_require__(/*! @elyra/canvas/dist/styles/common-canvas.min.css */ "../../node_modules/@elyra/canvas/dist/styles/common-canvas.min.css"),o=__webpack_require__(/*! path */ "../../node_modules/path-browserify/index.js"),i=__webpack_require__(/*! @elyra/canvas */ "../../node_modules/@elyra/canvas/dist/common-canvas.es.js"),a=__webpack_require__(/*! react-intl */ "webpack/sharing/consume/default/react-intl/react-intl"),l=__webpack_require__(/*! react-dom */ "webpack/sharing/consume/default/react-dom"),u=__webpack_require__(/*! @elyra/pipeline-services */ "webpack/sharing/consume/default/@elyra/pipeline-services/@elyra/pipeline-services?3008"),d=__webpack_require__(/*! immer */ "../../node_modules/immer/dist/immer.esm.js"),p=__webpack_require__(/*! react-redux */ "webpack/sharing/consume/default/react-redux/react-redux"),s=__webpack_require__(/*! downshift */ "../../node_modules/downshift/dist/downshift.esm.js");function c(e){return e&&"object"==typeof e&&"default"in e?e:{default:e}}var f=c(n),h=c(t),m=c(r),v=c(o),b=c(l),g=c(d);function x(){return(x=Object.assign||function(e){for(var n=1;n<arguments.length;n++){var t=arguments[n];for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&(e[r]=t[r])}return e}).apply(this,arguments)}function y(e,n){e.prototype=Object.create(n.prototype),e.prototype.constructor=e,j(e,n)}function w(e){return(w=Object.setPrototypeOf?Object.getPrototypeOf:function(e){return e.__proto__||Object.getPrototypeOf(e)})(e)}function j(e,n){return(j=Object.setPrototypeOf||function(e,n){return e.__proto__=n,e})(e,n)}function k(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch(e){return!1}}function _(e,n,t){return(_=k()?Reflect.construct:function(e,n,t){var r=[null];r.push.apply(r,n);var o=new(Function.bind.apply(e,r));return t&&j(o,t.prototype),o}).apply(null,arguments)}function C(e){var n="function"==typeof Map?new Map:void 0;return(C=function(e){if(null===e||-1===Function.toString.call(e).indexOf("[native code]"))return e;if("function"!=typeof e)throw new TypeError("Super expression must either be null or a function");if(void 0!==n){if(n.has(e))return n.get(e);n.set(e,t)}function t(){return _(e,arguments,w(this).constructor)}return t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}),j(t,e)})(e)}function P(e,n){if(null==e)return{};var t,r,o={},i=Object.keys(e);for(r=0;r<i.length;r++)n.indexOf(t=i[r])>=0||(o[t]=e[t]);return o}function O(e,n){return n||(n=e.slice(0)),e.raw=n,e}function N(e,n){(null==n||n>e.length)&&(n=e.length);for(var t=0,r=new Array(n);t<n;t++)r[t]=e[t];return r}function S(e,n){var t;if("undefined"==typeof Symbol||null==e[Symbol.iterator]){if(Array.isArray(e)||(t=function(e,n){if(e){if("string"==typeof e)return N(e,n);var t=Object.prototype.toString.call(e).slice(8,-1);return"Object"===t&&e.constructor&&(t=e.constructor.name),"Map"===t||"Set"===t?Array.from(e):"Arguments"===t||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t)?N(e,n):void 0}}(e))||n&&e&&"number"==typeof e.length){t&&(e=t);var r=0;return function(){return r>=e.length?{done:!0}:{done:!1,value:e[r++]}}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}return(t=e[Symbol.iterator]()).next.bind(t)}var E,T=function(e){function n(){return e.call(this,"Pipeline was last edited in a newer version of Elyra. Update Elyra to use this pipeline.")||this}return y(n,e),n}(C(Error)),I=function(e){function n(){return e.call(this,"Pipeline is out of date.")||this}return y(n,e),n}(C(Error)),R=function(e){function n(){return e.call(this,"Pipeline is invalid.")||this}return y(n,e),n}(C(Error)),F=t.createGlobalStyle(E||(E=O(["\n  ","\n\n  .toolbar-popover-list {\n    border: 1px solid ",";\n    background-color: ",";\n  }\n\n  .toolbar-divider {\n    border-right: 1px solid ",";\n    background-color: transparent;\n  }\n\n  .toolbar-divider:focus {\n    outline: none;\n  }\n\n  .toolbar-div,\n  .toolbar-item,\n  .toolbar-overflow-item,\n  .toolbar-item.default button,\n  .toolbar-item.ghost button,\n  .toolbar-overflow-item button,\n  .toolbar-overflow-menu-item button {\n    background-color: ",";\n    border: none;\n  }\n\n  .toolbar-item.default button:focus,\n  .toolbar-item.ghost button:focus,\n  .toolbar-overflow-item button:focus,\n  .toolbar-overflow-menu-item button:focus {\n    outline: none;\n  }\n\n  .toolbar-item.default button:hover,\n  .toolbar-item.ghost button:hover,\n  .toolbar-overflow-item button:hover,\n  .toolbar-overflow-menu-item button:hover {\n    background-color: ",";\n  }\n\n  .toolbar-item.default button:disabled:hover,\n  .toolbar-item.ghost button:disabled:hover,\n  .toolbar-overflow-menu-item button:disabled:hover {\n    background-color: ",";\n  }\n\n  .toolbar-item.default button:hover,\n  .toolbar-item.ghost button:hover,\n  .toolbar-overflow-item button:hover,\n  .toolbar-overflow-menu-item button:hover {\n    background-color: var(--vscode-statusBarItem-hoverBackground);\n  }\n\n  .toolbar-item.default button:active,\n  .toolbar-item.ghost button:active,\n  .toolbar-overflow-item button:active,\n  .toolbar-overflow-menu-item button:active {\n    background-color: ",";\n  }\n\n  .toolbar-item-content.default {\n    color: ",";\n  }\n\n  .toolbar-item-content.disabled.default {\n    color: ",";\n  }\n\n  .properties-control-description {\n    margin-top: -1px;\n    font-family: ",";\n    font-weight: ",";\n    font-size: ",";\n    color: ",";\n    line-height: 1.4em;\n    letter-spacing: normal;\n    padding: 0;\n    opacity: 0.9;\n  }\n\n  /* elevate specificity */\n  .properties-control-label.properties-control-label {\n    font-family: ",";\n    font-weight: 600;\n    font-size: ",";\n    color: ",';\n    line-height: 1.4em;\n    letter-spacing: normal;\n  }\n\n  /* text input */\n  .bx--text-input__field-outer-wrapper {\n    margin-top: 9px;\n  }\n\n  .properties-wrapper {\n    background: none;\n  }\n\n  .properties-wrapper input[type="text" i],\n  .properties-wrapper input[type="number" i],\n  .properties-wrapper textarea {\n    box-sizing: border-box;\n    padding: 4px;\n    background-color: ',";\n    color: ",";\n    border: 1px solid ",";\n    width: 100%;\n    max-width: 500px;\n    font-family: ",";\n    font-weight: ",";\n    font-size: ",";\n    border-radius: ",";\n  }\n\n  .properties-wrapper p {\n    font-family: ",";\n    font-weight: ",";\n    font-size: ",';\n  }\n\n  .properties-wrapper textarea {\n    resize: vertical;\n  }\n\n  .properties-wrapper input[type="text" i]:hover,\n  .properties-wrapper input[type="number" i]:hover {\n    border: 1px solid ',";\n    border-radius: ",'};\n  }\n\n  .properties-wrapper input[type="text" i]:focus,\n  .properties-wrapper input[type="number" i]:focus {\n    border: 1px solid ',";\n    border-radius: ",';\n  }\n\n  .properties-wrapper input[type="text" i]:disabled,\n  .properties-wrapper input[type="number" i]:disabled {\n    color: ',";\n  }\n\n  /* ========================================================================== */\n  /* CANVAS TOOLTIP */\n  /* ========================================================================== */\n\n  .common-canvas-tooltip {\n    max-width: unset;\n    background-color: ",";\n    border: 1px solid ",";\n    opacity: 100%;\n    color: ",";\n    border-radius: 0;\n    transition: opacity 0.1s ease-in-out, visibility 0.1s ease-in-out;\n\n    padding: 4px 7px;\n    line-height: 1.5;\n\n    font-family: ",";\n    font-weight: ",";\n    font-size: ",";\n  }\n\n  .common-canvas-tooltip #tipArrow polyline {\n    fill: ",";\n    stroke-width: 0;\n  }\n\n  .common-canvas-tooltip #tipArrow polygon {\n    fill: ",";\n  }\n\n  /* ========================================================================== */\n  /* COMMON PROPERTIES */\n  /* ========================================================================== */\n  .properties-wrapper,\n  .properties-wrapper * {\n    outline: none;\n  }\n\n  .properties-category {\n    padding: 0;\n  }\n\n  .properties-editor-form\n    .properties-control-panel\n    > .properties-control-panel {\n    padding-left: 33px;\n    padding-right: 24px;\n    /* 765 + 33 + 24 */\n    max-width: 822px;\n  }\n\n  .properties-editor-form\n    .properties-control-panel\n    > .properties-control-panel\n    > .properties-ctrl-wrapper {\n    padding-left: 14px;\n    padding-right: 14px;\n    padding-top: 12px;\n    padding-bottom: 18px;\n  }\n\n  .properties-label-container {\n    white-space: nowrap;\n    overflow: hidden;\n    text-overflow: ellipsis;\n    display: inline-block;\n    padding-bottom: 0;\n  }\n\n  .properties-wrapper .bx--visually-hidden,\n  .properties-wrapper .properties-validation-message {\n    display: none;\n  }\n\n  /* select */\n\n  .bx--dropdown {\n    margin-top: 9px;\n  }\n\n  .properties-wrapper .bx--list-box {\n    position: relative;\n    max-width: 320px;\n  }\n\n  .properties-wrapper .bx--list-box__field {\n    background-color: ",";\n    color: ",";\n    border: 1px solid ",";\n    display: flex;\n    width: 100%;\n    height: 26px;\n    align-items: center;\n    justify-content: space-between;\n    padding: 2px 8px;\n  }\n\n  .bx--list-box__label {\n    white-space: nowrap;\n    overflow: hidden;\n    text-overflow: ellipsis;\n  }\n\n  .bx--list-box__menu-icon {\n    display: flex;\n    align-items: center;\n    justify-content: center;\n  }\n\n  .properties-wrapper .bx--list-box__field:hover {\n    background-color: ",";\n  }\n\n  .properties-wrapper .bx--list-box__menu {\n    display: none;\n  }\n\n  .properties-wrapper .bx--list-box--expanded .bx--list-box__menu {\n    display: block;\n  }\n\n  .properties-wrapper .bx--list-box__menu {\n    z-index: 10;\n    position: absolute;\n    top: 26px;\n    left: 0;\n    right: 0;\n    color: ",";\n    background-color: ",";\n    padding: 2px;\n    padding-bottom: 4px;\n  }\n\n  .properties-wrapper .bx--list-box__menu-item {\n    height: 18px;\n    line-height: 18px;\n    padding-left: 3.5px;\n    color: ",";\n  }\n\n  .bx--list-box__menu-item__option {\n    white-space: nowrap;\n    overflow: hidden;\n    text-overflow: ellipsis;\n  }\n\n  .properties-wrapper .bx--list-box__menu-item:hover {\n    background-color: ",";\n  }\n\n  .properties-wrapper .bx--list-box__menu-item__selected-icon {\n    display: none;\n  }\n\n  .bx--list-box--expanded .bx--list-box__field,\n  .bx--list-box--expanded .bx--list-box__menu {\n    border: 1px solid ",";\n    border-radius: ",";\n    background-color: ",";\n  }\n\n  .bx--list-box__field:focus {\n    border: 1px solid ",";\n    border-radius: ",";\n  }\n\n  /* button */\n  .properties-wrapper button {\n    color: ",";\n    background-color: ",";\n    font-family: ",";\n    font-weight: ",";\n    font-size: ",";\n    padding: 2px 14px;\n    cursor: pointer;\n    line-height: 1.4em;\n    border: 1px solid ",";\n    border-radius: ",";\n  }\n\n  .properties-wrapper button:hover {\n    background-color: ",";\n    border: 1px solid ",";\n  }\n\n  /* ========================================================================== */\n  /* CANVAS */\n  /* ========================================================================== */\n  .common-canvas {\n    overflow: hidden;\n  }\n\n  .d3-svg-canvas-div {\n    background-color: transparent;\n  }\n\n  .d3-svg-background {\n    fill: ",";\n    cursor: default !important; /* set via element.style (must override with important) */\n  }\n\n  .d3-node-super-expand-icon-group .d3-node-super-expand-icon-background {\n    cursor: pointer;\n    fill: transparent;\n  }\n\n  .d3-node-super-expand-icon-group .d3-node-super-expand-icon {\n    cursor: pointer;\n    fill: ",";\n  }\n\n  .d3-node-super-expand-icon-group:hover .d3-node-super-expand-icon-background {\n    fill: transparent;\n  }\n\n  .d3-back-to-previous-flow-box {\n    display: none;\n  }\n\n  .d3-back-to-previous-flow-text {\n    display: none;\n  }\n\n  .d3-node-body-outline {\n    stroke: transparent;\n    fill: ",";\n  }\n\n  .d3-node-group:hover .d3-node-body-outline {\n    stroke: transparent;\n    fill: ",";\n  }\n\n  .d3-link-group {\n    cursor: pointer;\n  }\n\n  .d3-link-group.d3-data-link:hover .d3-link-line,\n  .d3-link-group.d3-data-link .d3-link-line {\n    stroke: ",";\n    stroke-width: 2;\n  }\n\n  .d3-link-group.d3-comment-link:hover .d3-link-line,\n  .d3-link-group.d3-comment-link .d3-link-line {\n    stroke: ",";\n    stroke-width: 1;\n    stroke-dasharray: none;\n    opacity: 0.4;\n  }\n\n  .d3-comment-rect {\n    fill: ",";\n    stroke: transparent;\n    stroke-width: 0;\n  }\n\n  .d3-node-label,\n  .d3-supernode-label {\n    font-family: ",";\n    font-weight: ",";\n    font-size: ",";\n    color: ",";\n  }\n\n  .d3-comment-text {\n    font-family: ",";\n    font-weight: ",";\n    font-size: ",";\n    color: ",";\n  }\n\n  .d3-comment-entry {\n    background-color: ",";\n    font-family: ",";\n    font-weight: ",";\n    font-size: ",";\n    color: ",';\n    box-sizing: border-box; /* very important! */\n  }\n\n  .d3-comment-entry:focus {\n    outline: none;\n    box-shadow: none;\n  }\n\n  .d3-node-selection-highlight[data-selected="yes"] {\n    stroke: ',";\n  }\n\n  .d3-comment-selection-highlight {\n    stroke: ",';\n    stroke-width: 1;\n  }\n\n  .d3-comment-selection-highlight[data-selected="yes"] {\n    stroke: ',";\n    stroke-width: 3;\n  }\n\n  .d3-node-ellipsis-group .d3-node-ellipsis {\n    fill: ",';\n  }\n\n  .d3-node-ellipsis-group:hover .d3-node-ellipsis-background {\n    fill: transparent;\n  }\n\n  .d3-new-connection-line[linkType="nodeLink"] {\n    stroke: ',';\n    stroke-width: 2;\n    stroke-dasharray: 10 10;\n    stroke-linecap: round;\n  }\n\n  .d3-new-connection-start[linkType="nodeLink"],\n  .d3-new-connection-guide[linkType="nodeLink"] {\n    stroke: ',";\n    fill: ",';\n  }\n\n  .d3-new-connection-line[linkType="commentLink"] {\n    stroke: ',';\n    stroke-width: 2;\n    stroke-dasharray: 10 10;\n    stroke-linecap: round;\n  }\n\n  .d3-new-connection-start[linkType="commentLink"],\n  .d3-new-connection-guide[linkType="commentLink"] {\n    stroke: ',";\n    fill: ",';\n  }\n\n  .pipeline-read-only .d3-comment-sizing,\n  .pipeline-read-only .d3-comment-port-circle,\n  .pipeline-read-only .d3-node-selection-highlight,\n  .pipeline-read-only .d3-comment-selection-highlight,\n  .pipeline-read-only .d3-node-port-input,\n  .pipeline-read-only .d3-node-port-output,\n  .pipeline-read-only .d3-node-port-input-arrow,\n  .pipeline-read-only .d3-node-ellipsis-group,\n  .pipeline-read-only .d3-new-connection-line,\n  .pipeline-read-only .d3-new-connection-start,\n  .pipeline-read-only .d3-new-connection-guide,\n  .pipeline-read-only .d3-comment-entry {\n    display: none;\n  }\n\n  .properties-editor-form\n    .properties-control-panel\n    > .properties-control-panel\n    > .properties-ctrl-wrapper {\n    position: relative;\n  }\n\n  .properties-editor-form\n    .properties-control-panel\n    > .properties-control-panel\n    > .properties-ctrl-wrapper\n    .error::before {\n    display: block;\n    content: "";\n    width: 6px;\n    border-left-width: 2px;\n    border-left-style: solid;\n    left: 5px;\n    top: 15px;\n    bottom: 18px;\n    border-color: ',";\n  }\n\n  .properties-editor-form\n  .properties-control-panel\n  > .properties-control-panel\n  > .properties-ctrl-wrapper:only-child\n  .error::before {\n    position: absolute;\n  }\n\n  .properties-editor-form\n  .properties-control-panel\n  > .properties-control-panel\n  > .properties-ctrl-wrapper:only-child\n  .elyra-errorMessage {\n    position: unset;\n  }\n\n  .properties-input-control.error input:not([disabled]) {\n    box-shadow: none;\n  }\n\n  .properties-dropdown.error .bx--list-box__field:not([disabled]) {\n    box-shadow: none;\n  }\n\n  .properties-required-indicator {\n    display: none;\n  }\n  .properties-editor-form\n    .properties-control-panel\n    > .properties-control-panel\n    > .properties-ctrl-wrapper {\n    position: relative;\n    border: 1px solid transparent;\n  }\n\n  .properties-editor-form\n    .properties-control-panel\n    > .properties-control-panel\n    > .properties-ctrl-wrapper:hover {\n    background-color: ",";\n  }\n\n  .properties-editor-form\n    .properties-control-panel\n    > .properties-control-panel\n    > .properties-ctrl-wrapper.selected {\n    background-color: ",";\n    border: 1px solid ",';\n  }\n\n  .d3-node-port-input,\n  .d3-node-port-output,\n  .d3-node-port-input[connected="yes"],\n  .d3-node-port-output[connected="yes"] {\n    stroke: ',";\n    fill: ",';\n    stroke-width: 4;\n  }\n\n  .d3-node-port-input:hover,\n  .d3-node-port-output:hover,\n  .d3-node-port-input[connected="yes"]:hover,\n  .d3-node-port-output[connected="yes"]:hover {\n    stroke: ',";\n    fill: ",";\n    stroke-width: 4;\n  }\n\n  .d3-comment-port-circle {\n    stroke: ",";\n    fill: ",";\n  }\n\n  .d3-comment-port-circle:hover {\n    stroke: ",";\n    fill: ",';\n  }\n\n  .d3-node-port-input-arrow {\n    display: none;\n  }\n\n  /* context menu */\n\n  .d3-node-ellipsis-group {\n    display: none;\n  }\n\n  .context-menu-popover {\n    margin-top: -6px;\n    margin-left: 2px;\n    padding: 6px 0;\n    backdrop-filter: saturate(180%) blur(20px);\n    border-radius: 6px;\n    user-select: none;\n    cursor: default;\n    box-shadow: 0px 1px 2px 0px rgba(0, 0, 0, 0.05),\n      0px 4px 15px 2px rgba(0, 0, 0, 0.18);\n  }\n\n  .context-menu-popover::before {\n    position: absolute;\n    top: 0;\n    left: 0;\n    width: 200%;\n    height: 200%;\n    border-radius: 13px;\n    content: "";\n    transform: scale(0.5);\n    -webkit-transform: scale(0.5);\n    transform-origin: 0 0;\n    -webkit-transform-origin: 0 0;\n  }\n\n  .react-contextmenu-item {\n    position: relative;\n    margin: 0 6px;\n    width: auto;\n    height: 22px;\n    border-radius: 4px;\n    font-size: 13px;\n    padding: 3px 9px;\n    box-sizing: border-box;\n    cursor: default;\n    z-index: 0;\n  }\n\n  .react-contextmenu-item:hover::before {\n    content: "";\n    background-color: rgba(54, 131, 247, 0.75);\n    backdrop-filter: saturate(0%);\n    position: absolute;\n    top: 0;\n    left: 0;\n    right: 0;\n    bottom: 0;\n    border-radius: 4px;\n    z-index: -1;\n  }\n\n  .react-contextmenu-item:hover::after {\n    content: "";\n    background: ',";\n    position: absolute;\n    top: 0;\n    left: 0;\n    right: 0;\n    bottom: 0;\n    border-radius: 4px;\n    z-index: -2;\n  }\n\n  .react-contextmenu-item.contextmenu-divider {\n    margin: 5px 15px;\n  }\n\n  .react-contextmenu-item.react-contextmenu-item--disabled {\n    cursor: default;\n    opacity: 1;\n  }\n\n  .react-contextmenu-item:active,\n  .react-contextmenu-item:focus,\n  .react-contextmenu-item.react-contextmenu-item--disabled {\n    background: transparent;\n  }\n\n  .react-contextmenu-item.react-contextmenu-item--disabled::before,\n  .react-contextmenu-item.react-contextmenu-item--disabled::after {\n    display: none;\n  }\n\n  .context-menu-popover {\n    background: ",";\n  }\n\n  .context-menu-popover::before {\n    box-shadow: ",";\n  }\n\n  .react-contextmenu-item {\n    color: ",";\n  }\n\n  .react-contextmenu-item:hover {\n    color: ",";\n  }\n\n  .react-contextmenu-item.react-contextmenu-item--disabled {\n    color: ",";\n  }\n\n  .react-contextmenu-item.contextmenu-divider {\n    background-color: ",";\n    opacity: ",";\n  }\n"])),m.default,function(e){return e.theme.palette.border},function(e){return e.theme.palette.background.secondary},function(e){return e.theme.palette.border},function(e){return e.theme.palette.background.secondary},function(e){return e.theme.palette.hover},function(e){return e.theme.palette.background.secondary},function(e){return e.theme.palette.active},function(e){return e.theme.palette.text.icon},function(e){return e.theme.palette.text.disabled},function(e){return e.theme.typography.fontFamily},function(e){return e.theme.typography.fontWeight},function(e){return e.theme.typography.fontSize},function(e){return e.theme.palette.text.secondary},function(e){return e.theme.typography.fontFamily},function(e){return e.theme.typography.fontSize},function(e){return e.theme.palette.text.secondary},function(e){return e.theme.palette.background.input},function(e){return e.theme.palette.text.primary},function(e){return e.theme.palette.inputBorder},function(e){return e.theme.typography.fontFamily},function(e){return e.theme.typography.fontWeight},function(e){return e.theme.typography.fontSize},function(e){return e.theme.shape.borderRadius},function(e){return e.theme.typography.fontFamily},function(e){return e.theme.typography.fontWeight},function(e){return e.theme.typography.fontSize},function(e){return e.theme.palette.highlight.hover},function(e){return e.theme.shape.borderRadius},function(e){return e.theme.palette.focus},function(e){return e.theme.shape.borderRadius},function(e){return e.theme.palette.text.disabled},function(e){return e.theme.palette.background.secondary},function(e){return e.theme.palette.border},function(e){return e.theme.palette.text.secondary},function(e){return e.theme.typography.fontFamily},function(e){return e.theme.typography.fontWeight},function(e){return e.theme.typography.fontSize},function(e){return e.theme.palette.background.secondary},function(e){return e.theme.palette.border},function(e){return e.theme.palette.secondary.main},function(e){return e.theme.palette.secondary.contrastText},function(e){return e.theme.palette.inputBorder},function(e){return e.theme.palette.secondary.main},function(e){return e.theme.palette.secondary.contrastText},function(e){return e.theme.palette.secondary.main},function(e){return e.theme.palette.text.primary},function(e){return e.theme.palette.primary.hover},function(e){return e.theme.palette.highlight.hover},function(e){return e.theme.shape.borderRadius},function(e){return e.theme.palette.background.input},function(e){return e.theme.palette.focus},function(e){return e.theme.shape.borderRadius},function(e){return e.theme.palette.text.primary},function(e){return e.theme.palette.secondary.main},function(e){return e.theme.typography.fontFamily},function(e){return e.theme.typography.fontWeight},function(e){return e.theme.typography.fontSize},function(e){return e.theme.palette.inputBorder},function(e){return e.theme.shape.borderRadius},function(e){return e.theme.palette.primary.hover},function(e){return e.theme.palette.highlight.hover},function(e){return e.theme.palette.background.default},function(e){return e.theme.palette.text.icon},function(e){return e.theme.palette.background.secondary},function(e){return e.theme.palette.background.secondary},function(e){return e.theme.palette.text.link},function(e){return e.theme.palette.text.inactive},function(e){return e.theme.palette.background.default},function(e){return e.theme.typography.fontFamily},function(e){return e.theme.typography.fontWeight},function(e){return e.theme.typography.fontSize},function(e){return e.theme.palette.text.primary},function(e){return e.theme.typography.fontFamily},function(e){return e.theme.typography.fontWeight},function(e){return e.theme.typography.fontSize},function(e){return e.theme.palette.text.inactive},function(e){return e.theme.palette.background.default},function(e){return e.theme.typography.fontFamily},function(e){return e.theme.typography.fontWeight},function(e){return e.theme.typography.fontSize},function(e){return e.theme.palette.text.inactive},function(e){return e.theme.palette.text.link},function(e){return e.theme.palette.text.inactive},function(e){return e.theme.palette.text.inactive},function(e){return e.theme.palette.text.icon},function(e){return e.theme.palette.text.link},function(e){return e.theme.palette.text.link},function(e){return e.theme.palette.text.link},function(e){return e.theme.palette.text.inactive},function(e){return e.theme.palette.text.primary},function(e){return e.theme.palette.text.primary},function(e){return e.theme.palette.error.main},function(e){return e.theme.palette.primary.hover},function(e){return e.theme.palette.highlight.focus},function(e){return e.theme.palette.highlight.border},function(e){return e.theme.palette.text.secondary},function(e){return e.theme.palette.text.secondary},function(e){return e.theme.palette.text.primary},function(e){return e.theme.palette.text.primary},function(e){return e.theme.palette.text.secondary},function(e){return e.theme.palette.text.secondary},function(e){return e.theme.palette.text.primary},function(e){return e.theme.palette.text.primary},function(e){return e.theme.palette.background.default},function(e){return"dark"===e.theme.mode?"rgba(46, 46, 46, 0.72)":"rgba(231, 231, 231, 0.76)"},function(e){return"dark"===e.theme.mode?"inset 0px 0px 0px 1px rgba(0, 0, 0, 0.86), inset 0px 0px 0px 3px rgba(255, 255, 255, 0.2)":"0px 0px 0px 1px rgba(0, 0, 0, 0.22), inset 0px 0px 0px 1px rgba(255, 255, 255, 0.1)"},function(e){return"dark"===e.theme.mode?"rgba(255, 255, 255, 0.9)":"rgba(0, 0, 0, 0.85)"},function(e){return"dark"===e.theme.mode?"rgba(255, 255, 255, 0.9)":"rgba(255, 255, 255, 1)"},function(e){return"dark"===e.theme.mode?"rgba(255, 255, 255, 0.355)":"rgba(0, 0, 0, 0.315)"},function(e){return"dark"===e.theme.mode?"#ffffff":"#000000"},function(e){return"dark"===e.theme.mode?.205:.13});function M(e){return e&&"object"==typeof e&&e.constructor===Object}function A(e,n){var t=x({},e);if(M(e)&&M(n))for(var r=0,o=Object.keys(n);r<o.length;r++){var i=o[r],a=e[i],l=n[i];void 0!==l&&(t[i]=M(l)&&void 0!==a?A(a,l):l)}return t}var z={palette:{focus:"#528bff",border:"#181a1f",divider:"rgba(128, 128, 128, 0.35)",hover:"#2c313a",active:"rgba(255, 255, 255, 0.18)",tabBorder:"#e7e7e7",inputBorder:"transparent",sash:"transparent",primary:{main:"#4d78cc",hover:"#6087cf",contrastText:"#fff"},secondary:{main:"#353b45",contrastText:"#f0f0f0"},error:{main:"#be1100",contrastText:"#fff"},errorMessage:{main:"#be1100",contrastText:"#fff",errorBorder:"#be1100"},text:{icon:"#c5c5c5",primary:"#cccccc",secondary:"#abb2bf",bold:"#e7e7e7",inactive:"rgba(231, 231, 231, 0.6)",disabled:"rgba(215, 218, 224, 0.25)",link:"#3794ff",error:"#f48771"},background:{default:"#282c34",secondary:"#21252b",input:"#1b1d23"},highlight:{border:"rgba(255, 255, 255, 0.12)",hover:"rgba(128, 128, 128, 0.07)",focus:"rgba(128, 128, 128, 0.14)"}},shape:{borderRadius:"0px"},typography:{fontFamily:"-apple-system, system-ui, sans-serif",fontWeight:"normal",fontSize:"13px"}};function L(e){return function(n){return A(x({},z,e),n)}}var D,q,B,H,U=function(r){var o=r.children,i=function(){var e=n.useState(window.matchMedia("(prefers-color-scheme: dark)").matches?"dark":"light"),t=e[0],r=e[1];n.useEffect(function(){var e=window.matchMedia("(prefers-color-scheme: dark)");try{e.addEventListener("change",function(e){r(e.matches?"dark":"light")})}catch(n){try{e.addListener(function(e){r(e.matches?"dark":"light")})}catch(e){}}},[]);var o=n.useMemo(function(){return window.navigator.platform.startsWith("Mac")?"mac":window.navigator.platform.startsWith("Win")?"win":"other"},[]);return n.useMemo(function(){return{mode:t,platform:o}},[t,o])}(),a=n.useMemo(function(){return L(i)},[i]);return e.jsxs(t.ThemeProvider,Object.assign({theme:a},{children:[e.jsx(F,{},void 0),o]}),void 0)};function W(e){function n(e){return"boolean"==typeof e?e?"Yes":"No":void 0===e?"undefined":null===e?"null":e.toString()}return Array.isArray(e)?e.map(function(e){var t;return n(null!=(t=null==e?void 0:e.value)?t:e)}).join("\n"):e&&e.constructor===Object?Object.entries(e).map(function(e){return e[0]+": "+n(e[1])}).join("\n"):n(e)}var V,Y,X,K,J=h.default.div(D||(D=O(["\n  padding-top: 7px;\n  text-align: left;\n"]))),G=h.default.div(q||(q=O(["\n  color: ",";\n  font-weight: 600;\n"])),function(e){return e.theme.palette.text.primary}),Z=h.default.div(B||(B=O(["\n  margin-left: 7px;\n  margin-bottom: 7px;\n  white-space: pre-wrap;\n"]))),$=h.default(Z)(H||(H=O(["\n  color: ",";\n"])),function(e){return e.theme.palette.text.error});function Q(n){var t=n.error,r=n.nodeLabel,o=n.properties;return e.jsxs(J,{children:[t&&e.jsxs("div",{children:[e.jsx(G,{children:"Error"},void 0),e.jsx($,{children:W(t)},void 0)]},void 0),e.jsx(G,{children:r},void 0),o.filter(function(e){var n;return null!=(n=e.value)&&(Array.isArray(n)?n.length>0:"boolean"==typeof n||""!==n)}).map(function(n){var t=n.label,r=n.value;return e.jsxs("div",{children:[e.jsx(G,{children:t},void 0),e.jsx(Z,{children:W(r)},void 0)]},t)})]},void 0)}function ee(n){var t=n.image,r=n.label;return e.jsx("svg",Object.assign({className:"svg-area",width:"172px",height:"35px",x:"0",y:"0"},{children:e.jsx("g",Object.assign({className:"d3-canvas-group"},{children:e.jsx("g",Object.assign({className:"d3-nodes-links-group"},{children:e.jsxs("g",Object.assign({className:"d3-node-group",transform:"translate(6, 0)"},{children:[e.jsx("path",{className:"d3-node-body-outline",d:"M 0 0 L 160 0  L 160 14 A 6 6 180 0 1 160 26 L 160 40 L 0 40 L 0 26 A 6 6 180 0 1 0 14 Z"},void 0),e.jsx("image",{className:"node-image",xlinkHref:t,x:"12.5",y:"0",width:"16",height:"35"},void 0),e.jsx("foreignObject",Object.assign({x:"34.5",y:"9",width:"112",height:"19",className:"d3-foreign-object"},{children:e.jsx("div",Object.assign({className:"d3-node-label  d3-node-label-single-line"},{children:e.jsx("span",{children:r},void 0)}),void 0)}),void 0),e.jsx("circle",{className:"d3-node-port-input",r:"3",cx:"0",cy:"17.5"},void 0),e.jsx("path",{className:"d3-node-port-input-arrow",d:"M -2 17 L 2 20 -2 23"},void 0),e.jsx("circle",{className:"d3-node-port-output",r:"3",cx:"160",cy:"17.5"},void 0)]}),void 0)}),void 0)}),void 0)}),void 0)}var ne=h.default.div(V||(V=O(["\n  margin-top: 14px;\n"]))),te=h.default.div.attrs({draggable:!0})(Y||(Y=O(["\n  display: flex;\n  align-items: center;\n  cursor: grab;\n  height: 40px;\n  margin: 0 22px 8px;\n  background-color: ",";\n  border: 1px solid transparent;\n"])),function(e){return e.theme.palette.background.secondary}),re=h.default.img.attrs({draggable:!1,alt:""})(X||(X=O(["\n  height: 26px;\n  margin: 0 7px;\n"]))),oe=h.default.div(K||(K=O(["\n  font-family: ",";\n  font-weight: ",";\n  font-size: ",";\n  color: ",";\n"])),function(e){return e.theme.typography.fontFamily},function(e){return e.theme.typography.fontWeight},function(e){return e.theme.typography.fontSize},function(e){return e.theme.palette.text.primary});function ie(t){var r=t.nodes,o=n.useCallback(function(n,t){var r={operation:"addToCanvas",data:{editType:"createExternalNode",nodeTemplate:{op:t.op}}},o=document.createElement("div");o.style.position="absolute",o.style.top="-100px",document.body.appendChild(o),b.default.render(e.jsx(ee,Object.assign({},t),void 0),o),n.dataTransfer.setDragImage(o,86,20),n.dataTransfer.setData("text",JSON.stringify(r))},[]);return e.jsx(ne,{children:r.map(function(n){var t,r;return e.jsxs(te,Object.assign({onDragStart:function(e){return o(e,n)}},{children:[e.jsx(re,{src:null==(t=n.app_data.ui_data)?void 0:t.image},void 0),e.jsx(oe,{children:null==(r=n.app_data.ui_data)?void 0:r.label},void 0)]}),n.op)})},void 0)}function ae(e){for(var n={},t=e.component_parameters,r=e.pipeline_defaults,o=P(e,["component_parameters","pipeline_defaults"]),i=0,a=Object.entries(o);i<a.length;i++){var l=a[i];n[l[0]]=l[1]}var u=null!=t?t:r;if(u)for(var d=0,p=Object.entries(u);d<p.length;d++){var s=p[d];n["elyra_"+s[0]]=s[1]}return n}function le(e,n){for(var t=n?{pipeline_defaults:{}}:{component_parameters:{}},r=0,o=Object.entries(e);r<o.length;r++){var i=o[r],a=i[0],l=i[1];if(a.startsWith("elyra_")){var u=a.replace(/^elyra_/,"");n?t.pipeline_defaults[u]=l:t.component_parameters[u]=l}else t[a]=l}return t}var ue,de=function(e){function n(){var n;return(n=e.apply(this,arguments)||this).palette={},n}y(n,e);var t=n.prototype;return t.resolveParameterRef=function(e,n){var t,r=this.getAllPaletteNodes().find(function(n){return n.op===e});return null==r||null==(t=r.app_data.parameter_refs)?void 0:t[n]},t.open=function(e){var n,t;if(null==e&&(e={doc_type:"pipeline",version:"3.0",json_schema:"http://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v3-schema.json",id:"elyra-auto-generated-pipeline",primary_pipeline:"primary",pipelines:[{id:"primary",nodes:[],app_data:{ui_data:{comments:[]},version:7,properties:{}},runtime_ref:""}],schemas:[]}),this.lastOpened!==e){if(this.lastOpened=e,null==(r=e)||"3.0"!==r.version||!Array.isArray(r.pipelines)||r.pipelines.length<1||void 0!==(null==(o=r.pipelines[0].app_data)?void 0:o.version)&&"number"!=typeof r.pipelines[0].app_data.version)throw new R;var r,o,i=null!=(n=null==(t=e.pipelines[0].app_data)?void 0:t.version)?n:0;if(7!==i){if(i>7)throw new T;throw new I}this.setPipelineFlow(e)}},t.addNode=function(e){try{var n,t=this,r=function(){t.editActionHandler(s)},o=e.path,i=e.onPropertiesUpdateRequested,a=e.offsetX,l=e.offsetY,u=e.nodeTemplate.op,d=P(e,["path","onPropertiesUpdateRequested","offsetX","offsetY","nodeTemplate"]),p=t.getPaletteNode(u),s=x({},d,{finalized:!0,offsetX:null!=a?a:40,offsetY:null!=l?l:40,nodeTemplate:t.convertNodeTemplate(p)}),c=t.getAllPaletteNodes().find(function(e){return e.op===u});null!=c&&null!=(n=c.app_data.properties)&&n.current_parameters&&(s.nodeTemplate.app_data=x({},le(c.app_data.properties.current_parameters)));var f=t.resolveParameterRef(u,"filehandler"),h=function(){if(o&&f){s.nodeTemplate.app_data.component_parameters[f]=o;var e=function(){if("function"==typeof i)return Promise.resolve(i(ae(s.nodeTemplate.app_data))).then(function(e){var n=s.nodeTemplate.app_data,t=n.component_parameters,r=P(n,["component_parameters"]),o=le(e),i=o.component_parameters,a=P(o,["component_parameters"]);s.nodeTemplate.app_data=x({},r,a,{component_parameters:x({},t,i)})})}();if(e&&e.then)return e.then(function(){})}}();return Promise.resolve(h&&h.then?h.then(r):r())}catch(e){return Promise.reject(e)}},t.setNodeErrors=function(e,n){this.setObjectsStyle(e,{body:{default:"stroke: "+(null==n?void 0:n.redColor)+";"},selection_outline:{default:"stroke: "+(null==n?void 0:n.redColor)+";"}},!0);for(var t={id:"error",image:"data:image/svg+xml;utf8,"+encodeURIComponent('<svg focusable="false" preserveAspectRatio="xMidYMid meet" xmlns="http://www.w3.org/2000/svg" fill="#da1e28" width="16" height="16" viewBox="0 0 16 16" aria-hidden="true"><circle cx="8" cy="8" r="8" fill="#ffffff"></circle><path d="M8,1C4.2,1,1,4.2,1,8s3.2,7,7,7s7-3.1,7-7S11.9,1,8,1z M7.5,4h1v5h-1C7.5,9,7.5,4,7.5,4z M8,12.2\tc-0.4,0-0.8-0.4-0.8-0.8s0.3-0.8,0.8-0.8c0.4,0,0.8,0.4,0.8,0.8S8.4,12.2,8,12.2z"></path><path d="M7.5,4h1v5h-1C7.5,9,7.5,4,7.5,4z M8,12.2c-0.4,0-0.8-0.4-0.8-0.8s0.3-0.8,0.8-0.8\tc0.4,0,0.8,0.4,0.8,0.8S8.4,12.2,8,12.2z" data-icon-path="inner-path" opacity="0"></path></svg>'),outline:!1,position:"topRight",x_pos:-24,y_pos:-8},r=0,o=Object.entries(e);r<o.length;r++)for(var i,a=o[r],l=a[0],u=S(a[1]);!(i=u()).done;)this.setNodeDecorations(i.value,[t],l)},t.setLinkErrors=function(e,n){this.setLinksStyle(e,{line:{default:"\n            stroke: "+(null==n?void 0:n.redColor)+" !important; \n            stroke-width: 2;\n            stroke-linecap: round;\n            stroke-dasharray: 10 10;\n            "}},!0)},t.getLabelForNode=function(e,n){var t,r,o,i,a=null==(t=n.app_data.ui_data)?void 0:t.label,l=this.resolveParameterRef(e.op,"filehandler"),u=null==(r=e.app_data)?void 0:r.component_parameters;return l&&"string"==typeof(null==u?void 0:u[l])&&""!==(null==u?void 0:u[l])&&(v.default.extname(i=u[l]),a=v.default.basename(i,void 0)),"string"==typeof e.app_data.label&&""!==e.app_data.label&&(a=e.app_data.label),null!=(o=a)?o:""},t.resetStyles=function(){var e=this;this.removeAllStyles();for(var n,t=S(this.getPipelineFlow().pipelines);!(n=t()).done;)for(var r,o=n.value,i=function(){var n,t=r.value;if("execution_node"!==t.type&&"super_node"!==t.type)return"continue";if(void 0!==t.app_data.ui_data.decorations&&0!==t.app_data.ui_data.decorations.length&&e.setNodeDecorations(t.id,[],o.id),"execution_node"!==t.type)return"continue";var i=e.getAllPaletteNodes().find(function(e){return e.op===t.op});if(void 0===i)return"continue";var a,l=e.getLabelForNode(t,i);t.app_data.ui_data.label!==l&&e.setNodeLabel(t.id,l,o.id),(t.app_data.ui_data.description!==i.description||t.app_data.ui_data.image!==(null==(n=i.app_data.ui_data)?void 0:n.image)||void 0!==t.app_data.invalidNodeError)&&e.setNodeProperties(t.id,{description:i.description,image:null==(a=i.app_data.ui_data)?void 0:a.image,app_data:x({},t.app_data,{invalidNodeError:void 0})},o.id)},a=S(o.nodes);!(r=a()).done;)i()},t.setSupernodeErrors=function(e,n){for(var t,r={},o=S(e);!(t=o()).done;){var i=t.value;try{var a,l=this.getSupernodeObjReferencing(i);r[l.parentPipelineId]=[].concat(null!=(a=r[l.parentPipelineId])?a:[],[l.supernodeId])}catch(e){}}this.setNodeErrors(r,n)},t.validate=function(e){var n,t,r,o,i,a;this.resetStyles();for(var l,d={},p={},s=S(u.validate(JSON.stringify(this.getPipelineFlow()),this.getAllPaletteNodes()));!(l=s()).done;){var c=l.value;switch(c.info.type){case"circularReference":d[c.info.pipelineID]=[].concat(null!=(n=d[c.info.pipelineID])?n:[],[c.info.linkID]);break;case"missingProperty":p[c.info.pipelineID]=[].concat(null!=(t=p[c.info.pipelineID])?t:[],[null!=(r=c.info.nodeID)?r:""]);break;case"invalidProperty":p[c.info.pipelineID]=[].concat(null!=(o=p[c.info.pipelineID])?o:[],[null!=(i=c.info.nodeID)?i:""]);break;case"missingComponent":p[c.info.pipelineID]=[].concat(null!=(a=p[c.info.pipelineID])?a:[],[c.info.nodeID])}}this.setLinkErrors(d,e),this.setNodeErrors(p,e),this.setSupernodeErrors([].concat(new Set([].concat(Object.keys(d),Object.keys(p)))),e)},t.setPalette=function(e){this.palette=e,this.setPipelineFlowPalette(e)},t.idsToNodes=function(e){for(var n,t=[],r=S(this.getPipelineFlow().pipelines);!(n=r()).done;)t.push.apply(t,n.value.nodes.filter(function(n){return e.includes(n.id)}));return t},t.getAllPaletteNodes=function(){if(void 0===this.palette.categories)return[];for(var e,n=[],t=S(this.palette.categories);!(e=t()).done;){var r,o=e.value;o.node_types&&(r=n).push.apply(r,o.node_types)}return this.propagatePipelineDefaultProperties(n,this.palette)},t.propagatePipelineDefaultProperties=function(e,n){var t=this;return g.default(e,function(e){for(var r,o=function(){var n,o,i,a,l,u,d=r.value,p=null==(n=t.getPipelineFlow())||null==(o=n.pipelines)||null==(i=o[0])||null==(a=i.app_data)||null==(l=a.properties)||null==(u=l.pipeline_defaults)?void 0:u[d.parameter_ref.replace(/^elyra_/,"")];e.forEach(function(e){var n=e.app_data.properties.uihints.parameter_info.findIndex(function(e){return e.parameter_ref===d.parameter_ref}),t=e.app_data.properties.uihints.parameter_info[n];if(t)if("EnumControl"===d.custom_control_id){var r,o,i,a=null!=(r=null==t||null==(o=t.data)||null==(i=o.labels)?void 0:i[p])?r:p;a&&(t.data.placeholder=a+" (pipeline default)",t.data.pipeline_default=!0)}else"StringArrayControl"===d.custom_control_id&&(t.data.pipeline_defaults=p)})},i=S(null!=(a=null==(l=n.properties)||null==(u=l.uihints)?void 0:u.parameter_info)?a:[]);!(r=i()).done;){var a,l,u;o()}})},t.getUpstreamNodes=function(e){var n,t,r=null!=(n=null==(t=this.findNodeParentPipeline(e))?void 0:t.id)?n:"",o=this.objectModel.getHighlightObjectIds(r,[e],"upstream");return this.idsToNodes(o.nodes[r].filter(function(n){return n!==e}))},t.findExecutionNode=function(e){for(var n,t=S(this.getPipelineFlow().pipelines);!(n=t()).done;){var r=n.value.nodes.find(function(n){return n.id===e});if(void 0!==r&&"execution_node"===r.type)return r}},t.findNodeParentPipeline=function(e){for(var n,t=S(this.getPipelineFlow().pipelines);!(n=t()).done;){var r=n.value;if(void 0!==r.nodes.find(function(n){return n.id===e}))return r}},t.errors=function(e){var n=this.findExecutionNode(e);if("execution_node"===(null==n?void 0:n.type)){for(var t,r=this.getAllPaletteNodes(),o=u.validate(JSON.stringify(this.getPipelineFlow()),r),i=[],a=this.getAllPaletteNodes().find(function(e){return e.op===n.op}),l=S(o);!(t=l()).done;){var d=t.value;switch(d.info.type){case"missingProperty":d.info.nodeID===e&&function(){var e=d.info.property,n=a.app_data.properties.uihints.parameter_info.find(function(n){return n.parameter_ref===e}).label.default;i.push('property "'+n+'" is required')}();break;case"invalidProperty":d.info.nodeID===e&&function(){var e=d.info.property,n=a.app_data.properties.uihints.parameter_info.find(function(n){return n.parameter_ref===e}).label.default;i.push('property "'+n+'" is invalid: '+d.info.message)}();break;case"missingComponent":d.info.nodeID===e&&i.push('component "'+d.info.op+'" cannot be found')}}if(i.length>0)return i.join("\n")}return""},t.getPropertyValue=function(e,n,t){var r,o,i,a,l,u,d,p,s;if("inputpath"===(null==n||null==(r=n.data)?void 0:r.format)||"inputpath"===(null==n?void 0:n.format)){var c,f,h,m,v,b,g,x,y,w=this.findExecutionNode(null!=(c=null==e?void 0:e.value)?c:""),j=null==w||null==(f=w.app_data)||null==(h=f.ui_data)?void 0:h.label,k=this.getAllPaletteNodes().find(function(e){return e.op===(null==w?void 0:w.op)}),_=null==k||null==(m=k.app_data)||null==(v=m.properties)||null==(b=v.uihints)||null==(g=b.parameter_info)||null==(x=g.find(function(n){return n.parameter_ref===e.option}))||null==(y=x.label)?void 0:y.default;return{label:t,value:j?_?j+": "+_:j:"No value specified."}}if("outputpath"===(null==n||null==(o=n.data)?void 0:o.format)||"outputpath"===(null==n?void 0:n.format))return{label:t,value:"This is an output of the component."};if(null!=e&&e.activeControl)return this.getPropertyValue(e[e.activeControl],null==n||null==(i=n.data)||null==(a=i.controls)?void 0:a[e.activeControl],t);if("EnumControl"===(null==n?void 0:n.custom_control_id))return{label:t,value:null!=(l=null!=(u=null==n||null==(d=n.data)||null==(p=d.labels)?void 0:p[e])?u:e)?l:null==n||null==(s=n.data)?void 0:s.placeholder};if("StringArrayControl"===(null==n?void 0:n.custom_control_id)){var C,P,O,N,S,E,T,I=null==(C=this.getPipelineFlow())||null==(P=C.pipelines)||null==(O=P[0].app_data)||null==(N=O.properties)||null==(S=N.pipeline_defaults)?void 0:S[null==n?void 0:n.parameter_ref.replace(/^elyra_/,"")];return{label:t,value:null==e?void 0:e.concat(null!=(E=null==I||null==(T=I.filter(function(n){return!e.includes(n)}))?void 0:T.map(function(e){return e+" (pipeline default)"}))?E:[])}}return{label:t,value:e}},t.properties=function(e){var n=this,t=this.findExecutionNode(e);if(void 0!==t){var r,o,i,a=t.op,l=t.app_data,u=this.getAllPaletteNodes().find(function(e){return e.op===a});return(null!=(r=null==u||null==(o=u.app_data.properties)||null==(i=o.uihints)?void 0:i.parameter_info)?r:[]).map(function(e){if(e.parameter_ref.startsWith("elyra_")){var t,r=e.parameter_ref.replace(/^elyra_/,""),o=null==l||null==(t=l.component_parameters)?void 0:t[r];return n.getPropertyValue(o,e,e.label.default)}return{label:e.label.default,value:null==l?void 0:l[e.parameter_ref]}})}return[]},t.updateProperties=function(e,n){var t=this.findNodeParentPipeline(e);if(void 0!==t){for(var r,o=le(n),i=0,a=Object.entries(null!=(l=o.component_parameters)?l:{});i<a.length;i++){var l,u=a[i];null==u[1]&&delete o.component_parameters[u[0]]}if(this.setNodeProperties(e,{app_data:o},t.id),n.label!==(null==(r=n.ui_data)?void 0:r.label)){var d=this.getNode(e,t.id);if("execution_node"===d.type){var p=this.getAllPaletteNodes().find(function(e){return e.op===d.op});if(p){var s=this.getLabelForNode(d,p);this.setNodeLabel(e,s,t.id)}}}}},n}(i.CanvasController),pe=f.default.createContext({name:"",controller:{},id:""});function se(){var e=n.useContext(pe),t=n.useRef(e.controller);return n.useMemo(function(){return t.current.getHandlers()},[])}function ce(){return n.useContext(pe).name}function fe(){var e=n.useContext(pe),t=e.name,r=e.id,o=n.useRef(e.controller),i=p.useSelector(function(e){return e.propertiesReducer[t]}),a=p.useSelector(function(e){var n;return"OneOfControl"!==r?e.propertiesReducer[t]:null==(n=e.propertiesReducer[t])?void 0:n[(e.propertiesReducer[t]||{}).activeControl]}),l=p.useSelector(function(e){var n,r;return null!=(n=null==(r=e.propertiesReducer[t])?void 0:r.activeControl)?n:""}),u=n.useCallback(function(e){var n;o.current.updatePropertyValue({name:t},"OneOfControl"!==r?e:x({},i,((n={})[l]=e,n)))},[t,i,l,r]),d=n.useCallback(function(e){o.current.updatePropertyValue({name:t},x({},i,{activeControl:e}))},[t,i]);return[a,u,l,d]}function he(n,t){function r(e,t,r){this.value={name:e.name,controller:t,id:n},this.data=r}return r.id=function(){return n},r.prototype.renderControl=function(){return e.jsx(pe.Provider,Object.assign({value:this.value},{children:e.jsx(t,Object.assign({},this.data),void 0)}),void 0)},r}var me,ve,be=h.default.div.attrs({className:"elyra-errorMessage"})(ue||(ue=O(["\n  position: absolute;\n  left: 0;\n  right: 0;\n  padding: 5px;\n  box-sizing: border-box;\n  z-index: 1;\n  border-style: solid;\n  border-width: 1px;\n  border-color: ",";\n  background-color: ",";\n  color: ",";\n"])),function(e){return e.theme.palette.errorMessage.errorBorder},function(e){return e.theme.palette.errorMessage.main},function(e){return e.theme.palette.errorMessage.contrastText}),ge=h.default.div(me||(me=O(["\n  margin-top: 9px;\n  display: flex;\n"]))),xe=h.default.div(ve||(ve=O(["\n  position: relative;\n  width: 100%;\n  max-width: 500px;\n"])));function ye(t){var r,o=t.pattern,i=t.patternErrorMessage,a=t.minLength,l=t.maxLength,d=t.format,p=t.required,s=t.placeholder,c=t.extensions,f=ce(),h=fe(),m=h[0],v=h[1],b=n.useState(),g=b[0],x=b[1],y=n.useCallback(function(e){x(e),v(function(e){if(""!==e.trim())return e.trim()}(e))},[v]),w=n.useCallback(function(e){y(e.target.value)},[y]),j=n.useCallback(function(){x(void 0)},[]),k=se().actionHandler,_=n.useCallback(function(){try{return Promise.resolve(null==k?void 0:k("browse_file",void 0,{canSelectMany:!1,defaultUri:m,filters:{File:c},propertyID:f})).then(function(e){void 0!==e&&e.length>0&&y(e[0])})}catch(e){return Promise.reject(e)}},[k,m,c,f,y]),C=u.getStringValidators({pattern:o,patternErrorMessage:i,minLength:a,maxLength:l,format:d,required:p}),P=null!=(r=null!=g?g:m)?r:"",O=P.trim(),N=u.getErrorMessages(O,C);return p||""!==O||(N=[]),e.jsxs(ge,Object.assign({className:N.length>0?"error":void 0},{children:[e.jsxs(xe,{children:["multiline"===d?e.jsx("textarea",{value:P,placeholder:s,onChange:w,onBlur:j},void 0):e.jsx("input",{type:"text",value:P,placeholder:s,onChange:w,disabled:"file"===d,onBlur:j},void 0),void 0!==N[0]&&e.jsx(be,{children:N[0]},void 0)]},void 0),"file"===d&&e.jsx("button",Object.assign({onClick:_},{children:"Browse"}),void 0)]}),void 0)}var we=he("StringControl",ye);function je(){var n=fe();return e.jsx("p",{children:n[0]},void 0)}var ke,_e,Ce,Pe,Oe,Ne,Se,Ee,Te,Ie,Re,Fe,Me=he("DisplayControl",je),Ae=h.default.div(ke||(ke=O(["\n  cursor: pointer;\n  user-select: none;\n  display: inline-block;\n  transition: transform 50ms ease;\n  position: relative;\n\n  &:active {\n    transform: scale(1.272019649);\n  }\n"]))),ze=h.default.div(_e||(_e=O(["\n  color: ",";\n"])),function(e){return e.theme.palette.text.primary});function Le(n){return e.jsx(Ae,{children:e.jsx(ze,Object.assign({},n),void 0)},void 0)}var De=h.default.div(Ce||(Ce=O(["\n  margin-top: 9px;\n"]))),qe=h.default.div(Pe||(Pe=O(["\n  padding: 1px;\n  margin-bottom: 1px;\n"]))),Be=h.default.div(Oe||(Oe=O(["\n  display: flex;\n  margin-top: 4px;\n  margin-bottom: 4px;\n  & button {\n    margin-right: 4px;\n  }\n"]))),He=h.default(Le)(Ne||(Ne=O(["\n  width: 16px;\n  height: 20px;\n  padding: 2px;\n  margin-right: 2px;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n"]))),Ue=h.default.div(Se||(Se=O(["\n  display: block;\n  margin-right: 47px;\n  margin-left: 2px;\n  line-height: 24px;\n  max-width: 90%;\n  font-family: ",";\n  font-weight: ",";\n  font-size: ",";\n  color: ",";\n  white-space: nowrap;\n  overflow: hidden;\n  text-overflow: ellipsis;\n"])),function(e){return e.theme.typography.fontFamily},function(e){return e.theme.typography.fontWeight},function(e){return e.theme.typography.fontSize},function(e){return e.theme.palette.text.primary}),We=h.default.div(Ee||(Ee=O(["\n  display: flex;\n  margin-right: 2px;\n  margin-left: 2px;\n  line-height: 24px;\n  font-family: ",";\n  font-weight: ",";\n  font-size: ",";\n  color: ",";\n\n  & .left {\n    flex: 1;\n    overflow: hidden;\n    text-align: left;\n    text-overflow: ellipsis;\n    white-space: nowrap;\n  }\n\n  & .right {\n    float: right;\n    text-align: right;\n    white-space: nowrap;\n  }\n"])),function(e){return e.theme.typography.fontFamily},function(e){return e.theme.typography.fontWeight},function(e){return e.theme.typography.fontSize},function(e){return e.theme.palette.text.primary}),Ve=h.default.div(Te||(Te=O(["\n  display: flex;\n  margin-bottom: 3px;\n\n  & button:first-of-type {\n    margin: 0 4px;\n  }\n"]))),Ye=h.default.div.attrs({className:"elyra-inputContainer"})(Ie||(Ie=O(["\n  background-color: ",";\n  border: 1px solid ",";\n  border-radius: ",";\n  height: 24px;\n  max-width: 320px;\n  margin-right: 4px;\n  box-sizing: border-box;\n\n  & input {\n    background-color: ",";\n    color: ",";\n    display: inline-block;\n    box-sizing: border-box;\n    width: 100%;\n    height: 100%;\n    line-height: inherit;\n    border: none;\n    font-family: inherit;\n    font-size: inherit;\n    resize: none;\n    padding: 4px;\n    border: 1px solid ",";\n    border-radius: ",";\n  }\n\n  & input:hover {\n    border: 2px solid ",";\n    border-radius: ",";\n  }\n\n  & input:focus {\n    border: 2px solid ",";\n    border-radius: ",";\n  }\n"])),function(e){return e.theme.palette.background.secondary},function(e){return e.theme.palette.inputBorder},function(e){return e.theme.shape.borderRadius},function(e){return e.theme.palette.background.input},function(e){return e.theme.palette.text.primary},function(e){return e.theme.palette.inputBorder},function(e){return e.theme.shape.borderRadius},function(e){return e.theme.palette.highlight.hover},function(e){return e.theme.shape.borderRadius},function(e){return e.theme.palette.focus},function(e){return e.theme.shape.borderRadius}),Xe=h.default.div.attrs({className:"elyra-stringArrayActions"})(Re||(Re=O(["\n  display: none;\n  position: absolute;\n  right: 0;\n  top: 0;\n"]))),Ke=h.default.div.attrs({className:"elyra-listRow"})(Fe||(Fe=O(["\n  position: relative;\n  border: 1px solid ",";\n  border-radius: ",";\n  background-color: ",";\n\n  &:hover "," {\n    display: flex;\n  }\n"])),function(e){return e.theme.palette.inputBorder},function(e){return e.theme.shape.borderRadius},function(e){return e.theme.palette.background.input},Xe),Je=g.default(function(e,n){var t=n.payload;switch(n.type){case"DELETE_ITEM":var r=t.index;void 0!==r&&r<e.length&&e.splice(r,1);break;case"UPSERT_ITEM":var o=t.index;void 0!==o&&o<e.length?""===t.value.trim()?e.splice(o,1):e[o]=t.value:""!==t.value.trim()&&e.push(t.value);break;case"UPSERT_ITEMS":var i=t.index;void 0!==i&&i<e.length&&t.items.length>0?(e[i]=t.items[0],e.splice.apply(e,[i+1,0].concat(t.items.slice(1)))):e.push.apply(e,t.items)}});function Ge(r){var o,i,a,l=r.value,u=r.isEditing,d=r.placeholder,p=r.canBrowseFiles,s=r.onSubmit,c=r.onCancel,f=r.onDelete,h=r.onChooseFiles,m=r.onEdit,v=t.useTheme(),b=n.useRef(null);return n.useEffect(function(){u&&(b.current.focus(),b.current.select())},[u]),u?e.jsxs(Ve,{children:[e.jsx(Ye,{children:e.jsx("input",{ref:b,defaultValue:null!=l?l:"",placeholder:d,onKeyDown:function(e){"Enter"!==e.code?"Escape"!==e.code||null==c||c():null==s||s(b.current.value)}},void 0)},void 0),e.jsx("button",Object.assign({onClick:function(){null==s||s(b.current.value)}},{children:"OK"}),void 0),e.jsx("button",Object.assign({onClick:function(){null==c||c()}},{children:"Cancel"}),void 0)]},void 0):e.jsxs(Ke,Object.assign({"data-testid":"list-row",onDoubleClick:function(){null==m||m()}},{children:[e.jsx(Ue,{children:l},void 0),e.jsxs(Xe,{children:[e.jsx(He,Object.assign({title:"Edit",className:"elyricon elyricon-edit",onClick:function(){null==m||m()}},{children:null==(o=v.overrides)?void 0:o.editIcon}),void 0),!!p&&e.jsx(He,Object.assign({title:"Browse",className:"elyricon elyricon-folder",onClick:function(){null==h||h()}},{children:null==(i=v.overrides)?void 0:i.folderIcon}),void 0),e.jsx(He,Object.assign({title:"Delete",className:"elyricon elyricon-delete",onClick:function(){null==f||f()}},{children:null==(a=v.overrides)?void 0:a.deleteIcon}),void 0)]},void 0)]}),void 0)}function Ze(t){var r,o=t.uniqueItems,i=t.minItems,a=t.maxItems,l=t.keyValueEntries,d=t.placeholder,p=t.format,s=t.canRefresh,c=t.pipeline_defaults,f=ce(),h=fe(),m=h[0],v=void 0===m?[]:m,b=h[1],g=n.useState(),x=g[0],y=g[1],w=n.useCallback(function(e){return e.map(l?function(e){var n=e.split("="),t=n[0].trim(),r=n.slice(1).join("=").trim();return t&&r?t+"="+r:e.trim()}:function(e){return e.trim()})},[l]),j=n.useCallback(function(e){var n=Je(v,e);b(w(n))},[v,b,w]),k=se().actionHandler,_=n.useCallback(function(e){try{return Promise.resolve(null==k?void 0:k("browse_file",void 0,{canSelectMany:!0,defaultUri:v[e],propertyID:f})).then(function(n){Array.isArray(n)&&j({type:"UPSERT_ITEMS",payload:{index:e,items:n}})})}catch(e){return Promise.reject(e)}},[k,j,v,f]),C=n.useCallback(function(){try{return Promise.resolve(null==k?void 0:k("refresh_properties")).then(function(e){null!=e&&e[f]&&b(w(e[f]))})}catch(e){return Promise.reject(e)}},[k,f,b,w]),P=u.getStringArrayValidators({uniqueItems:o,minItems:i,maxItems:a,keyValueEntries:l}),O=u.getErrorMessages(v,P);return e.jsxs(De,Object.assign({className:O.length>0?"error":void 0},{children:[e.jsxs(qe,{children:[v.map(function(n,t){return e.jsx(Ge,{value:n,placeholder:d,canBrowseFiles:"file"===p,isEditing:t===x,onSubmit:function(e){y(void 0),j({type:"UPSERT_ITEM",payload:{index:t,value:e}})},onCancel:function(){y(void 0)},onDelete:function(){j({type:"DELETE_ITEM",payload:{index:t}})},onChooseFiles:function(){_(t)},onEdit:function(){y(t)}},t)}),"new"===x&&e.jsx(Ge,{placeholder:d,isEditing:!0,onSubmit:function(e){y(void 0),j({type:"UPSERT_ITEM",payload:{value:e}})},onCancel:function(){y(void 0)}},void 0),null==c||null==(r=c.filter(function(e){return!v.includes(e)}))?void 0:r.map(function(n,t){return e.jsx(Ke,Object.assign({"data-testid":"list-row"},{children:e.jsxs(We,{children:[e.jsx("div",Object.assign({className:"left"},{children:n}),void 0),e.jsx("div",Object.assign({className:"right"},{children:"(pipeline default)"}),void 0)]},void 0)}),""+n+t)})]},void 0),"new"!==x&&e.jsxs(Be,{children:[e.jsx("button",Object.assign({onClick:function(){y("new")}},{children:"Add Item"}),void 0),"file"===p&&e.jsx("button",Object.assign({onClick:function(){_(void 0)}},{children:"Browse"}),void 0),s&&e.jsx("button",Object.assign({onClick:function(){y(void 0),C()}},{children:"Refresh"}),void 0)]},void 0),void 0!==O[0]&&e.jsx(be,{children:O[0]},void 0)]}),void 0)}var $e,Qe,en=he("StringArrayControl",Ze),nn=h.default.div($e||($e=O(["\n  display: flex;\n"]))),tn=h.default.div(Qe||(Qe=O(["\n  box-sizing: border-box;\n  flex-shrink: 0;\n  cursor: pointer;\n  display: inline-block;\n  text-align: center;\n  font-size: 16px;\n  height: 18px;\n  width: 18px;\n  border: 1px solid ",";\n  border-radius: 3px;\n  margin-right: 9px;\n  margin-left: 0;\n  padding: 0;\n  background-color: ",";\n  color: ",";\n  border-radius: ",";\n\n  &:hover {\n    border: 1px solid ",";\n    border-radius: ",";\n  }\n\n  &:focus {\n    border: 1px solid ",";\n    border-radius: ",";\n  }\n\n  &::before,\n  & > * {\n    opacity: ",";\n  }\n"])),function(e){return e.theme.palette.inputBorder},function(e){return e.theme.palette.secondary.main},function(e){return e.theme.palette.secondary.contrastText},function(e){return e.theme.shape.borderRadius},function(e){return e.theme.palette.highlight.hover},function(e){return e.theme.shape.borderRadius},function(e){return e.theme.palette.focus},function(e){return e.theme.shape.borderRadius},function(e){return e.isChecked?1:0});function rn(r){var o,i=r.description,a=t.useTheme(),l=fe(),u=l[0],d=void 0!==u&&u,p=l[1],s=n.useCallback(function(){p(!d)},[d,p]);return e.jsxs(nn,Object.assign({onClick:s},{children:[e.jsx(tn,Object.assign({isChecked:d,className:"elyricon elyricon-check",tabIndex:0,role:"checkbox","aria-checked":d?"true":"false","aria-label":""},{children:null==(o=a.overrides)?void 0:o.checkIcon}),void 0),e.jsx("div",Object.assign({className:"properties-control-description"},{children:i}),void 0)]}),void 0)}var on,an,ln,un,dn,pn,sn,cn=he("BooleanControl",rn),fn=h.default.button.attrs({type:"button"})(on||(on=O(["\n  /* higher specificity to override button styles */\n  && {\n    background-color: ",";\n    color: ",";\n    border: 1px solid ",";\n    display: flex;\n    width: 100%;\n    height: 26px;\n    align-items: center;\n    justify-content: space-between;\n    padding: 2px 8px;\n    border-radius: ",";\n  }\n\n  &&:hover {\n    background-color: ",";\n    border: 1px solid ",";\n    border-radius: ",";\n  }\n\n  &&:focus {\n    border: 1px solid ",";\n    border-radius: ",";\n  }\n"])),function(e){return e.theme.palette.secondary.main},function(e){return e.theme.palette.secondary.contrastText},function(e){return e.theme.palette.inputBorder},function(e){return e.theme.shape.borderRadius},function(e){return e.theme.palette.secondary.main},function(e){return e.theme.palette.highlight.hover},function(e){return e.theme.shape.borderRadius},function(e){return e.theme.palette.focus},function(e){return e.theme.shape.borderRadius}),hn=h.default.div(an||(an=O(["\n  white-space: nowrap;\n  overflow: hidden;\n  text-overflow: ellipsis;\n"]))),mn=h.default.div(ln||(ln=O(["\n  display: flex;\n  align-items: center;\n  justify-content: center;\n"]))),vn=h.default.ul(un||(un=O(["\n  z-index: 10;\n  position: absolute;\n  top: 26px;\n  left: 0;\n  right: 0;\n  color: ",";\n  background-color: ",";\n  padding: 2px;\n  padding-bottom: 4px;\n  margin: 0;\n  list-style-type: none;\n  border-radius: ",";\n"])),function(e){return e.theme.palette.secondary.contrastText},function(e){return e.theme.palette.background.secondary},function(e){return e.theme.shape.borderRadius}),bn=h.default.li(dn||(dn=O(["\n  cursor: pointer;\n  height: 18px;\n  line-height: 18px;\n  padding-left: 3.5px;\n  color: ",";\n\n  &:hover {\n    background-color: ",";\n    border-radius: ",";\n  }\n"])),function(e){return e.theme.palette.text.primary},function(e){return e.theme.palette.hover},function(e){return e.theme.shape.borderRadius}),gn=h.default.div(pn||(pn=O(["\n  position: relative;\n  margin-top: 9px;\n  width: 100%;\n  max-width: 320px;\n\n  & ",", & "," {\n    border: 1px solid ",";\n    border-radius: ",";\n  }\n\n  & "," {\n    display: ",";\n  }\n"])),fn,vn,function(e){return e.theme.palette.inputBorder},function(e){return e.theme.shape.borderRadius},vn,function(e){return e.isOpen?"block":"none"}),xn=h.default.div(sn||(sn=O(["\n  margin-top: 9px;\n  display: flex;\n"])));function yn(e,n,t){var r;return e?null!=(r=null==t?void 0:t[e])?r:e:n}function wn(r){var o,i=r.items,a=r.placeholder,l=void 0===a?"Select a value...":a,d=r.labels,p=r.required,c=r.pipeline_default,f=fe(),h=f[0],m=f[1],v=t.useTheme(),b=n.useCallback(function(e){var n=e.selectedItem;m(n===l?void 0:n)},[l,m]),g=u.getEnumValidators({required:p,pipeline_default:c}),x=u.getErrorMessages(h,g),y=[l].concat(i),w=s.useSelect({items:y,selectedItem:null!=h?h:l,onSelectedItemChange:b}),j=w.isOpen,k=w.getMenuProps,_=w.getItemProps;return e.jsx(xn,Object.assign({className:x.length>0?"error":void 0},{children:e.jsxs(gn,Object.assign({isOpen:j},{children:[e.jsxs(fn,Object.assign({},(0,w.getToggleButtonProps)(),{children:[e.jsx(hn,{children:yn(h,l,d)},void 0),e.jsx(mn,Object.assign({className:"elyricon elyricon-chevron-down"},{children:null==(o=v.overrides)?void 0:o.chevronDownIcon}),void 0)]}),void 0),e.jsx(vn,Object.assign({},k(),{children:j&&y.map(function(n,t){var r=yn(n,l,d);return e.jsx(bn,Object.assign({},_({item:n,index:t}),{children:e.jsx(hn,Object.assign({title:r},{children:r}),void 0)}),""+n+t)})}),void 0),void 0!==x[0]&&e.jsx(be,{children:x[0]},void 0)]}),void 0)}),void 0)}var jn=he("EnumControl",wn);function kn(e,n){var t=[];return e.forEach(function(e){var r;null==(r=e.options)||r.forEach(function(n){t.push({value:e.value,option:n.value})}),!n||e.options&&0!==e.options.length||t.push({value:e.value,option:""})}),t}function _n(e,n,t){var r;if(!e)return t;var o=n.find(function(n){return n.value===e.value}),i=null==o||null==(r=o.options)?void 0:r.find(function(n){return n.value===e.option});return o?o.label+(i?": "+(null==i?void 0:i.label):""):t}function Cn(r){var o,i=r.data,a=void 0===i?[]:i,l=r.placeholder,d=void 0===l?"Select a value":l,p=r.allownooptions,c=void 0!==p&&p,f=r.required,h=fe(),m=h[0],v=h[1],b=t.useTheme(),g=kn(a,c),x=n.useCallback(function(e){var n=e.selectedItem;v(n.value?n:void 0)},[v]);n.useEffect(function(){void 0===m||kn(a,c).find(function(e){return e.value===m.value})||v(void 0)},[a,c,m,v]);var y=s.useSelect({items:g,selectedItem:m,onSelectedItemChange:x}),w=y.isOpen,j=y.getToggleButtonProps,k=y.getMenuProps,_=y.getItemProps,C=u.getNestedEnumValidators({data:a,allownooptions:c,required:f}),P=f?u.getErrorMessages(m,C):[];return e.jsx("div",Object.assign({className:P.length>0?"error":void 0},{children:e.jsxs(gn,Object.assign({isOpen:w},{children:[e.jsxs(fn,Object.assign({},j(),{children:[e.jsx(hn,{children:_n(m,a,d)},void 0),e.jsx(mn,Object.assign({className:"elyricon elyricon-chevron-down"},{children:null==(o=b.overrides)?void 0:o.chevronDownIcon}),void 0)]}),void 0),e.jsx(vn,Object.assign({},k(),{children:w&&g.map(function(n,t){var r=_n(n,a,d);return e.jsx(bn,Object.assign({},_({item:n,index:t}),{children:e.jsx(hn,Object.assign({title:r},{children:r}),void 0)}),""+n.value+n.option+t)})}),void 0),void 0!==P[0]&&e.jsx(be,{children:P[0]},void 0)]}),void 0)}),void 0)}var Pn,On,Nn=he("NestedEnumControl",Cn),Sn=h.default.div(Pn||(Pn=O(["\n  margin-top: 9px;\n  display: flex;\n"]))),En=h.default.div(On||(On=O(["\n  position: relative;\n  width: 100%;\n  max-width: 200px;\n"])));function Tn(t){var r,o=t.type,i=t.multipleOf,a=t.minimum,l=t.maximum,d=t.exclusiveMinimum,p=t.exclusiveMaximum,s=t.required,c=fe(),f=c[0],h=c[1],m=n.useState(),v=m[0],b=m[1],g=n.useCallback(function(e){b(e.target.value),h(function(e){var n=parseFloat(e);if(!isNaN(n))return n}(e.target.value))},[h]),x=n.useCallback(function(){b(void 0)},[]),y=u.getNumberValidators({type:o,multipleOf:i,minimum:a,maximum:l,exclusiveMinimum:d,exclusiveMaximum:p,required:s}),w=null!=(r=null!=v?v:function(e){return null==e?void 0:e.toString()}(f))?r:"",j=w.trim(),k=u.getErrorMessages(j,y);return s||""!==j||(k=[]),e.jsx(Sn,Object.assign({className:k.length>0?"error":void 0},{children:e.jsxs(En,{children:[e.jsx("input",{type:"text",inputMode:"numeric",value:w,onChange:g,onBlur:x},void 0),void 0!==k[0]&&e.jsx(be,{children:k[0]},void 0)]},void 0)}),void 0)}var In,Rn=he("NumberControl",Tn),Fn=h.default.div(In||(In=O(["\n  margin-top: 9px;\n"])));function Mn(n){var t={StringControl:ye,DisplayControl:je,StringArrayControl:Ze,BooleanControl:rn,EnumControl:wn,NestedEnumControl:Cn,NumberControl:Tn}[n.name];return t?e.jsx(t,Object.assign({},n.data),void 0):null}var An,zn={__proto__:null,StringControl:we,DisplayControl:Me,StringArrayControl:en,BooleanControl:cn,EnumControl:jn,NestedEnumControl:Nn,NumberControl:Rn,OneOfControl:he("OneOfControl",function(r){var o,i=r.controls,a=r.required,l=Object.keys(i),u=fe(),d=u[2],p=u[3],c=t.useTheme(),f=n.useCallback(function(e){p(e.selectedItem)},[p]),h=s.useSelect({items:l,selectedItem:d,onSelectedItemChange:f}),m=h.selectedItem,v=h.isOpen,b=h.getMenuProps,g=h.getItemProps,y=function(e){var n,t;return null!=(n=null==(t=i[null!=e?e:""])?void 0:t.label)?n:e};return e.jsxs("div",{children:[e.jsxs(gn,Object.assign({isOpen:v},{children:[e.jsxs(fn,Object.assign({},(0,h.getToggleButtonProps)(),{children:[e.jsx(hn,{children:y(m)},void 0),e.jsx(mn,Object.assign({className:"elyricon elyricon-chevron-down"},{children:null==(o=c.overrides)?void 0:o.chevronDownIcon}),void 0)]}),void 0),e.jsx(vn,Object.assign({},b(),{children:v&&l.map(function(n,t){return e.jsx(bn,Object.assign({},g({item:n,index:t}),{children:e.jsx(hn,Object.assign({title:y(n)},{children:y(n)}),void 0)}),""+n+t)})}),void 0)]}),void 0),e.jsx(Fn,{children:m?e.jsx(Mn,{name:m,data:x({},i[m],{required:a})},void 0):null},void 0)]},void 0)})};function Ln(e,n,t){if(!e.s){if(t instanceof qn){if(!t.s)return void(t.o=Ln.bind(null,e,n));1&n&&(n=t.s),t=t.v}if(t&&t.then)return void t.then(Ln.bind(null,e,n),Ln.bind(null,e,2));e.s=n,e.v=t;var r=e.o;r&&r(e)}}var Dn,qn=function(){function e(){}return e.prototype.then=function(n,t){var r=new e,o=this.s;if(o){var i=1&o?n:t;if(i){try{Ln(r,1,i(this.v))}catch(e){Ln(r,2,e)}return r}return this}return this.o=function(e){try{var o=e.v;1&e.s?Ln(r,1,n?n(o):o):t?Ln(r,1,t(o)):Ln(r,2,o)}catch(e){Ln(r,2,e)}},r},e}(),Bn=h.default.div(An||(An=O(["\n  margin-top: 14px;\n  padding: 0 22px;\n  font-family: ",";\n  font-weight: ",";\n  font-size: ",";\n  color: ",";\n  opacity: 0.5;\n"])),function(e){return e.theme.typography.fontFamily},function(e){return e.theme.typography.fontWeight},function(e){return e.theme.typography.fontSize},function(e){return e.theme.palette.text.primary});function Hn(t){var r=t.refs,o=t.currentProperties,a=t.propertiesSchema,l=t.onFileRequested,u=t.onPropertiesUpdateRequested,d=t.onChange,p=t.id;n.useEffect(function(){function e(e){for(var n,t=S(document.querySelectorAll(".properties-control-panel > .properties-control-panel > .properties-ctrl-wrapper"));!(n=t()).done;){var r=n.value;r.contains(e.target)?r.classList.add("selected"):r.classList.remove("selected")}}return document.addEventListener("mousedown",e,{capture:!0}),function(){document.removeEventListener("mousedown",e)}},[]);var s,c,f=n.useRef();return n.useEffect(function(){void 0!==f.current&&f.current.validatePropertiesValues()}),e.jsx(i.CommonProperties,{propertiesInfo:{parameterDef:(s=a,c=o,g.default(s,function(e){e.current_parameters=ae(c)})),labelEditable:!1},propertiesConfig:{containerType:"Custom",rightFlyout:!1},callbacks:{actionHandler:function(e,n,t){try{var o,i=f.current.getPropertyValues();return null!=r&&r.filehandler&&(o=i["elyra_"+(null==r?void 0:r.filehandler)]),Promise.resolve(function(e,n){var t,r=-1;e:{for(var o=0;o<n.length;o++){var i=n[o][0];if(i){var a=i();if(a&&a.then)break e;if(a===e){r=o;break}}else r=o}if(-1!==r){do{for(var l=n[r][1];!l;)r++,l=n[r][1];var u=l();if(u&&u.then){t=!0;break e}var d=n[r][2];r++}while(d&&!d());return u}}var p=new qn,s=Ln.bind(null,p,2);return(t?u.then(c):a.then(function t(a){for(;;){if(a===e){r=o;break}if(++o===n.length){if(-1!==r)break;return void Ln(p,1,u)}if(i=n[o][0]){if((a=i())&&a.then)return void a.then(t).then(void 0,s)}else r=o}do{for(var l=n[r][1];!l;)r++,l=n[r][1];var u=l();if(u&&u.then)return void u.then(c).then(void 0,s);var d=n[r][2];r++}while(d&&!d());Ln(p,1,u)})).then(void 0,s),p;function c(e){for(;;){var t=n[r][2];if(!t||t())break;r++;for(var o=n[r][1];!o;)r++,o=n[r][1];if((e=o())&&e.then)return void e.then(c).then(void 0,s)}Ln(p,1,e)}}(e,[[function(){return"browse_file"},function(){return Promise.resolve(null==l?void 0:l(x({},t,{filename:o})))}],[function(){return"refresh_properties"},function(){return Promise.resolve(null==u?void 0:u(i))}]]))}catch(e){return Promise.reject(e)}},controllerHandler:function(e){f.current=e},propertyListener:function(e){"UPDATE_PROPERTY"===e.action&&(null==d||d(f.current.getPropertyValues()))}},customControls:Object.values(zn)},p)}var Un,Wn,Vn=h.default.div(Dn||(Dn=O(["\n  margin-top: 14px;\n  padding: 0 47px;\n  font-family: ",";\n  font-weight: ",";\n  font-size: 16px;\n  color: ",";\n  opacity: 0.5;\n"])),function(e){return e.theme.typography.fontFamily},function(e){return e.theme.typography.fontWeight},function(e){return e.theme.palette.text.primary});function Yn(n){var t=n.selectedNodes,r=n.nodes,o=n.upstreamNodes,i=n.onFileRequested,a=n.onPropertiesUpdateRequested,l=n.onChange;if(void 0===t||0===t.length)return e.jsx(Bn,{children:"Select a node to edit its properties."},void 0);if(t.length>1)return e.jsx(Bn,{children:"Multiple nodes are selected. Select a single node to edit its properties."},void 0);var u=t[0];if(!u)return e.jsx(Bn,{children:"Select a node to edit its properties."},void 0);if("execution_node"!==u.type)return e.jsx(Bn,{children:"This node type doesn't have any editable properties."},void 0);var d=r.find(function(e){return e.op===u.op});if(void 0===d)return e.jsxs(Bn,{children:["This node uses a component that is not stored in your component registry.",void 0!==u.app_data.component_source?" The component's path is: "+u.app_data.component_source:""]},void 0);if(void 0===(null==d?void 0:d.app_data.properties))return e.jsx(Bn,{children:"This node type doesn't have any editable properties."},void 0);var p=d.app_data.parameter_refs;return e.jsxs("div",{children:[e.jsx(Vn,{children:d.label},void 0),e.jsx(Hn,{refs:p,currentProperties:u.app_data,onPropertiesUpdateRequested:a,propertiesSchema:function(){for(var e,n=[],t=function(){for(var t,o,i,a=e.value,l=r.find(function(e){return e.op===a.op}),u=[],d=S(null!=(p=null==l?void 0:l.app_data.properties.uihints.parameter_info)?p:[]);!(i=d()).done;){var p,s=i.value;"outputpath"===s.data.format&&u.push({value:s.parameter_ref,label:s.label.default})}n.push({value:a.id,label:null==(t=a.app_data)||null==(o=t.ui_data)?void 0:o.label,options:u})},i=S(null!=o?o:[]);!(e=i()).done;)t();return g.default(null==d?void 0:d.app_data.properties,function(e){for(var t,r=S(e.uihints.parameter_info);!(t=r()).done;){var o,i,a=t.value;if("inputpath"===(null==(o=a.data)?void 0:o.format))a.data=x({},a.data,{data:n,placeholder:"Select an input source"});else if(null!=(i=a.data)&&i.controls)for(var l in null==(u=a.data)?void 0:u.controls){var u,d;"inputpath"===(null==(d=a.data)?void 0:d.controls[l].format)&&(a.data.controls[l]=x({},a.data.controls[l],{data:n,placeholder:"Select an input source"}))}}})}(),onFileRequested:i,onChange:function(e){null==l||l(u.id,e)},id:u.id},void 0)]},void 0)}function Xn(n){var t,r,o,i,a=n.pipelineFlow,l=n.propertiesSchema,u=n.onFileRequested,d=n.onPropertiesUpdateRequested,p=n.onChange;return void 0===l?e.jsx(Bn,{children:"No pipeline properties defined."},void 0):e.jsx(Hn,{currentProperties:null!=(t=null==a||null==(r=a.pipelines)||null==(o=r[0])||null==(i=o.app_data)?void 0:i.properties)?t:{},onPropertiesUpdateRequested:d,propertiesSchema:l,onFileRequested:u,onChange:p,id:null==a?void 0:a.id},void 0)}var Kn,Jn,Gn,Zn,$n,Qn,et,nt,tt=h.default.div(Un||(Un=O(["\n  position: absolute;\n  top: 0;\n  bottom: 0;\n  background: ",";\n"])),function(e){return e.theme.palette.background.default}),rt=h.default.div(Wn||(Wn=O(["\n  position: absolute;\n  cursor: col-resize;\n  top: 0;\n  bottom: 0;\n  width: 4px;\n  transition: background-color 0.1s ease-out;\n  background: ",";\n"])),function(e){return e.isActive?e.theme.palette.sash:"transparent"});function ot(r){var o=r.mode,i=r.width,a=r.isActive,l=r.children,u=r.onMouseDown,d=t.useTheme(),p=n.useState(!1),s=p[0],c=p[1],f=n.useRef(),h=n.useCallback(function(){f.current&&clearTimeout(f.current),c(!1)},[]),m=n.useCallback(function(){!0===a?(f.current&&clearTimeout(f.current),c(!0)):f.current=window.setTimeout(function(){c(!0)},300)},[a]);switch(o){case"open":return e.jsxs("div",{children:[e.jsx(tt,Object.assign({style:{borderLeft:"1px solid "+d.palette.divider,width:i+"px",right:0}},{children:l}),void 0),e.jsx(rt,{"data-testid":"drag-handle",style:{right:i-1+"px"},isActive:s||a,onMouseDown:u,onMouseEnter:m,onMouseLeave:h},void 0)]},void 0);case"collapsed":return e.jsx(tt,Object.assign({style:{background:d.palette.background.secondary,width:"32px",right:0}},{children:l}),void 0);case"closed":return null}}function it(t){var r=t.left,o=t.right,i=t.mode,a=n.useState(void 0),l=a[0],u=a[1],d=n.useState(!1),p=d[0],s=d[1],c=n.useRef(!1);n.useEffect(function(){function e(e){if(c.current){e.preventDefault();var n=document.body.clientWidth-e.clientX,t=Math.max(Math.min(document.body.clientWidth-300,n),300);u(t)}}function n(){c.current=!1,s(!1)}return document.addEventListener("mousemove",e),document.addEventListener("mouseup",n),function(){document.removeEventListener("mousemove",e),document.removeEventListener("mouseup",n)}},[]);var h=n.useCallback(function(){c.current=!0,s(!0)},[]),m="open"===i?null!=l?l:500:0;return e.jsxs(f.default.Fragment,{children:[e.jsx(tt,Object.assign({style:{left:0,right:m+"px"}},{children:r}),void 0),e.jsx(ot,Object.assign({mode:i,width:m,onMouseDown:h,isActive:p},{children:o}),void 0)]},void 0)}var at=h.default.div(Kn||(Kn=O(["\n  padding: 7px 0;\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n"]))),lt=h.default.div(Jn||(Jn=O(["\n  display: flex;\n"]))),ut=h.default.div(Gn||(Gn=O(["\n  "," & {\n    margin: 3px 0;\n  }\n  "," &:hover {\n    background-color: ",";\n  }\n  "," &:active {\n    background-color: ",";\n  }\n  "," & {\n    cursor: pointer;\n    user-select: none;\n    text-transform: uppercase;\n    padding: 4px 10px 3px;\n  }\n"])),at,at,function(e){return e.theme.palette.hover},at,function(e){return e.theme.palette.active},lt),dt=h.default.div(Zn||(Zn=O(["\n  padding: 0 8px;\n  display: flex;\n  justify-content: space-between;\n"]))),pt=h.default.div($n||($n=O(["\n  position: absolute;\n  top: 35px;\n  bottom: 0;\n  overflow: auto;\n  width: 100%;\n"]))),st=h.default(Le)(Qn||(Qn=O(["\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  height: 35px;\n  line-height: 35px;\n  min-width: 28px;\n  margin-right: 4px;\n"]))),ct=h.default.div(et||(et=O(["\n  line-height: 27px;\n  font-family: ",";\n  font-weight: ",";\n  font-size: 11px;\n\n  color: ",";\n\n  border-bottom: 1px solid\n    ",";\n\n  &:hover {\n    color: ",";\n  }\n"])),function(e){return e.theme.typography.fontFamily},function(e){return e.theme.typography.fontWeight},function(e){var n=e.theme;return e.active?n.palette.text.bold:n.palette.text.inactive},function(e){return e.active?e.theme.palette.tabBorder:"transparent"},function(e){return e.theme.palette.text.bold}),ft=h.default.div(nt||(nt=O(["\n  cursor: pointer;\n  user-select: none;\n  color: ",";\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  height: 35px;\n  line-height: 35px;\n  min-width: 28px;\n  margin-right: 4px;\n"])),function(e){return e.theme.palette.text.icon});function ht(n){var r,o,i,a=n.currentTab,l=n.onTabClick,u=n.tabs,d=n.showCloseButton,p=n.collapsed,s=n.onClose,c=t.useTheme();if(!0===p)return e.jsx(at,{children:u.map(function(n){return e.jsx(ut,{children:e.jsx(ft,Object.assign({title:n.label,className:"elyricon elyricon-"+n.id,onClick:function(){null==l||l(n.id)}},{children:n.icon}),void 0)},n.id)})},void 0);var h=void 0===a?u[0].id:a;return e.jsxs(f.default.Fragment,{children:[e.jsxs(dt,{children:[e.jsx(lt,{children:u.map(function(n){return e.jsx(ut,{children:e.jsx(ct,Object.assign({title:n.title,active:h===n.id,onClick:function(){null==l||l(n.id)}},{children:n.label}),void 0)},n.id)})},void 0),!0===d&&e.jsx(st,Object.assign({title:"Close Panel",className:"elyricon elyricon-close",onClick:function(){null==s||s()}},{children:null==(r=c.overrides)?void 0:r.closeIcon}),void 0)]},void 0),e.jsx(pt,{children:null!=(o=null==(i=u.find(function(e){return e.id===h}))?void 0:i.content)?o:"Invalid tab id."},void 0)]},void 0)}function mt(e){e.stopPropagation()}var vt,bt,gt={passive:!1,capture:!0},xt="M 0 0 h 160 a 6 6 0 0 1 6 6 v 28 a 6 6 0 0 1 -6 6 h -160 a 6 6 0 0 1 -6 -6 v -28 a 6 6 0 0 1 6 -6 z";function yt(e){return"createNode"===e.editType||"createAutoNode"===e.editType}function wt(e){return!0===e.divider}function jt(e,n){var t=e.find(function(e){return!wt(e)&&(void 0===e.menu?e.action===n:e.menu.find(function(e){return e.action===n}))});return void 0!==t&&!wt(t)&&!1!==t.enable}var kt=h.default.div(vt||(vt=O(["\n  height: 100%;\n  color: ",";\n  font-family: ",";\n  font-weight: ",";\n  font-size: ",";\n"])),function(e){return e.theme.palette.text.primary},function(e){return e.theme.typography.fontFamily},function(e){return e.theme.typography.fontWeight},function(e){return e.theme.typography.fontSize}),_t=h.default.div(bt||(bt=O(["\n  cursor: pointer;\n  position: absolute;\n  top: ","px;\n  left: 28px;\n  z-index: 1;\n  padding: 10px;\n  background-color: ",";\n  border: none;\n  font-size: ",";\n  font-weight: ",";\n  font-family: ",";\n  color: ",";\n\n  &:hover {\n    background-color: ",";\n  }\n\n  &:focus {\n    outline: none;\n  }\n"])),function(e){return e.hasToolbar?64:24},function(e){return e.theme.palette.primary.main},function(e){return e.theme.typography.fontSize},function(e){return e.theme.typography.fontWeight},function(e){return e.theme.typography.fontFamily},function(e){return e.theme.palette.primary.contrastText},function(e){return e.theme.palette.primary.hover}),Ct=n.forwardRef(function(r,o){var l,u,d=r.pipeline,p=r.palette,s=r.pipelineProperties,c=r.toolbar,f=r.onAction,h=r.onChange,m=r.onDoubleClickNode,b=r.onError,g=r.onFileRequested,y=r.onPropertiesUpdateRequested,w=r.readOnly,j=r.children,k=r.nativeKeyboardActions,_=r.leftPalette,C=t.useTheme(),P=n.useRef(new de),O=n.useState(!1),N=O[0],S=O[1];n.useEffect(function(){var e,n=P.current.objectModel.store.store,t=n.subscribe(function(){e!==(e=n.getState().breadcrumbs.length>1)&&S(e)});return function(){t()}},[]);var E=n.useState(),T=E[0],I=E[1],R=n.useState(!1),F=R[0],M=R[1];!function(e){n.useEffect(function(){function n(n){var t=document.getElementById("context-menu-popover");null===t||t.contains(n.target)||e.current.closeContextMenu()}function t(){document.hasFocus()||e.current.closeContextMenu()}return document.addEventListener("visibilitychange",t),window.addEventListener("blur",t),document.addEventListener("mousedown",n),function(){document.removeEventListener("visibilitychange",t),window.removeEventListener("blur",t),document.removeEventListener("mousedown",n)}},[e])}(P);var A=function(e){var t=n.useRef(null);return n.useEffect(function(){window.scrollTo(0,0)},[]),n.useEffect(function(){var n=t.current;return e.wheel&&(null==n||n.addEventListener("wheel",mt,gt)),function(){e.wheel&&(null==n||n.removeEventListener("wheel",mt,gt))}},[e.wheel]),n.useEffect(function(){var n,r=t.current;return e.contextmenu&&(null==(n=t.current)||n.addEventListener("contextmenu",mt,gt)),function(){e.contextmenu&&(null==r||r.removeEventListener("contextmenu",mt,gt))}},[e.contextmenu]),t}({wheel:!0,contextmenu:w});n.useEffect(function(){try{P.current.open(d),w?P.current.resetStyles():(P.current.setPalette(p),P.current.validate({redColor:C.palette.error.main}))}catch(e){null==b||b(e)}},[p,b,d,w,C.palette.error.main]),n.useImperativeHandle(o,function(){return{addFile:function(e){try{return P.current.editActionHandler(x({editType:"createNode"},e)),Promise.resolve()}catch(e){return Promise.reject(e)}}}},[]);var z=n.useCallback(function(e,n){var t=jt(n,"paste"),r=jt(n,"disconnectNode"),o=jt(n,"expandSuperNodeInPlace");if(e.selectedObjectIds.length>1)return[{action:"createSuperNode",label:"Create Supernode",enable:"comment"!==e.type},{divider:!0},{action:"cut",label:"Cut"},{action:"copy",label:"Copy"},{divider:!0},{action:"disconnectNode",label:"Disconnect",enable:r},{action:"deleteSelectedObjects",label:"Delete"}];switch(e.type){case"canvas":return[{action:"newFileNode",label:"New Node from File"},{action:"createComment",label:"New Comment"},{divider:!0},{action:"paste",label:"Paste",enable:t}];case"node":if("execution_node"===e.targetObject.type){var i,a=P.current.resolveParameterRef(e.targetObject.op,"filehandler"),l=null==(i=e.targetObject.app_data)?void 0:i.component_parameters;return[{action:"openFile",label:a?"Open File":"Open Component Definition",enable:void 0===a||void 0!==(null==l?void 0:l[a])&&""!==(null==l?void 0:l[a].trim())},{action:"properties",label:"Open Properties"},{divider:!0},{action:"createSuperNode",label:"Create Supernode"},{divider:!0},{action:"cut",label:"Cut"},{action:"copy",label:"Copy"},{divider:!0},{action:"disconnectNode",label:"Disconnect",enable:r},{action:"deleteSelectedObjects",label:"Delete"}]}if("super_node"===e.targetObject.type)return[{action:o?"expandSuperNodeInPlace":"collapseSuperNodeInPlace",label:o?"Expand Supernode":"Collapse Supernode"},{divider:!0},{action:"createSuperNode",label:"Create Supernode"},{divider:!0},{action:"cut",label:"Cut"},{action:"copy",label:"Copy"},{divider:!0},{action:"disconnectNode",label:"Disconnect",enable:r},{action:"deleteSelectedObjects",label:"Delete"}];break;case"link":return[{action:"deleteLink",label:"Delete"}];case"comment":return[{action:"createSuperNode",label:"Create Supernode",enable:!1},{divider:!0},{action:"cut",label:"Cut"},{action:"copy",label:"Copy"},{divider:!0},{action:"disconnectNode",label:"Disconnect",enable:r},{action:"deleteSelectedObjects",label:"Delete"}]}return n},[]),L=n.useCallback(function(e){if("DOUBLE_CLICK"===e.clickType&&"node"===e.objectType){if(void 0!==m)return m(e);P.current.editActionHandler({editType:"properties"})}},[m]),D=n.useState(),q=D[0],B=D[1],H=n.useCallback(function(e){B(e.selectedNodes.map(function(e){return e.id})),e.selectedNodes.length>0?I("properties"):P.current.getNodes().length>0||_?I("pipeline-properties"):I("palette")},[_]),U=n.useCallback(function(e){return yt(e)&&!0===e.finalized?(delete e.finalized,e):yt(e)?(P.current.addNode(x({},e,{onPropertiesUpdateRequested:y})),null):e},[y]),W=n.useCallback(function(e){try{var n,t=function(){switch("properties"===e.editType&&(I("properties"),M(!0)),"toggleOpenPanel"===e.editType&&M(function(e){return!e}),"createExternalNode"===e.editType&&P.current.editActionHandler({editType:"createNode",nodeTemplate:e.nodeTemplate,offsetX:e.offsetX,offsetY:e.offsetY,pipelineId:e.pipelineId}),e.editType){case"properties":case"openFile":case"toggleOpenPanel":case"copy":case"displaySubPipeline":case"displayPreviousPipeline":return}null==h||h(P.current.getPipelineFlow())},r=e.editType;if("openFile"===e.editType){var o,i,a,l,u=P.current.resolveParameterRef(e.targetObject.op,"filehandler");u?n=null==(o=e.targetObject)||null==(i=o.app_data)||null==(a=i.component_parameters)?void 0:a[u]:(r="openComponentDef",n={componentId:null==(l=P.current.getAllPaletteNodes().find(function(n){return n.op===e.targetObject.op}))?void 0:l.id,componentSource:e.targetObject.app_data.component_source})}null==f||f({type:r,payload:n});var d=function(){if("newFileNode"===e.editType){var n=P.current.getAllPaletteNodes(),t=n.map(function(e){return e.app_data.extensions}).flat();return Promise.resolve(null==g?void 0:g({canSelectMany:!1,filters:{File:t}})).then(function(t){var r=t[0],o=n.find(function(e){var n;return null==(n=e.app_data.extensions)?void 0:n.includes(v.default.extname(r))});void 0!==o&&P.current.editActionHandler({editType:"createNode",nodeTemplate:{op:o.op},pipelineId:e.pipelineId,offsetX:e.mousePos.x,offsetY:e.mousePos.y,path:r})})}}();return Promise.resolve(d&&d.then?d.then(t):t())}catch(e){return Promise.reject(e)}},[f,h,g]),V=n.useCallback(function(e,n){P.current.updateProperties(e,n),null==h||h(P.current.getPipelineFlow())},[h]),Y=n.useCallback(function(e){var n,t,r=P.current.getPipelineFlow();null!=r&&null!=(n=r.pipelines)&&null!=(t=n[0])&&t.app_data&&(r.pipelines[0].app_data.properties=le(e,!0),P.current.setPipelineFlow(r),null==h||h(P.current.getPipelineFlow()))},[h]);if(w)return e.jsx(kt,Object.assign({className:"pipeline-read-only",ref:A},{children:e.jsx(a.IntlProvider,Object.assign({locale:"en"},{children:e.jsx(i.CommonCanvas,{canvasController:P.current,contextMenuHandler:function(){},editActionHandler:function(){P.current.setPipelineFlow(d),P.current.resetStyles()},toolbarConfig:[],config:{enableInternalObjectModel:!1,emptyCanvasContent:j,enablePaletteLayout:"None",enableNodeFormatType:"Horizontal",enableToolbarLayout:"None",enableNodeLayout:{bodyPath:xt,selectionPath:xt,dropShadow:!1}}},void 0)}),void 0)}),void 0);var X,K=P.current.idsToNodes(null!=q?q:[]),J=null!=q&&q[0]?P.current.getUpstreamNodes(q[0]):[],G=[{id:"pipeline-properties",label:"Pipeline Properties",title:"Edit pipeline properties",icon:null==(l=C.overrides)?void 0:l.pipelineIcon,content:e.jsx(Xn,{pipelineFlow:d,propertiesSchema:s,onFileRequested:g,onPropertiesUpdateRequested:y,onChange:Y},void 0)},{id:"properties",label:"Node Properties",title:"Edit node properties",icon:null==(u=C.overrides)?void 0:u.propertiesIcon,content:e.jsx(Yn,{selectedNodes:K,nodes:P.current.getAllPaletteNodes(),upstreamNodes:J,onFileRequested:g,onPropertiesUpdateRequested:y,onChange:V},void 0)}];return _||G.push({id:"palette",label:"Palette",title:"Add nodes to pipeline",icon:null==(X=C.overrides)?void 0:X.paletteIcon,content:e.jsx(ie,{nodes:P.current.getAllPaletteNodes()},void 0)}),e.jsx(kt,Object.assign({ref:A},{children:e.jsxs(a.IntlProvider,Object.assign({locale:"en"},{children:[!0===N&&e.jsx(_t,Object.assign({hasToolbar:void 0!==c,onClick:function(){P.current.editActionHandler({editType:"displayPreviousPipeline"})}},{children:"Return to previous flow"}),void 0),e.jsx(it,{left:e.jsx(i.CommonCanvas,{canvasController:P.current,contextMenuHandler:z,clickActionHandler:L,beforeEditActionHandler:U,editActionHandler:W,selectionChangeHandler:H,tipHandler:function(n,t){function r(e,n){return"tipTypeNode"===e}if(r(n)&&"execution_node"===t.node.type){var o=P.current.errors(t.node.id),i=P.current.properties(t.node.id),a=P.current.getAllPaletteNodes().find(function(e){return e.op===t.node.op});return e.jsx(Q,{error:o,properties:i,nodeLabel:null==a?void 0:a.label},void 0)}return r(n)&&"super_node"===t.node.type?"Supernode":null},toolbarConfig:null!=c?c:[],config:{enableInternalObjectModel:!0,emptyCanvasContent:j,enablePaletteLayout:_?"Flyout":"None",enableNodeFormatType:"Horizontal",enableToolbarLayout:void 0===c?"None":"Top",enableNodeLayout:{imagePosX:12.5,imagePosY:0,imageWidth:16,imageHeight:35,labelPosX:34.5,labelMaxWidth:113,defaultNodeHeight:35,inputPortLeftPosY:17.5,outputPortRightPosY:17.5,dropShadow:!1,labelPosY:9}},notificationConfig:{enable:!1},contextMenuConfig:{enableCreateSupernodeNonContiguous:!0,defaultMenuEntries:{saveToPalette:!1,createSupernode:!0}},keyboardConfig:k?{actions:{undo:!1,redo:!1,cutToClipboard:!1,copyToClipboard:!1,pasteFromClipboard:!1}}:void 0},void 0),right:e.jsx(ht,{currentTab:T,onTabClick:function(e){I(e),null==f||f({type:"openPanel"}),M(!0)},tabs:G,collapsed:!1===F,showCloseButton:void 0===c,onClose:function(){null==f||f({type:"closePanel"}),M(!1)}},void 0),mode:F?"open":void 0===c?"collapsed":"closed"},void 0)]}),void 0)}),void 0)}),Pt=n.forwardRef(function(n,t){return e.jsx(U,{children:e.jsx(Ct,Object.assign({},n,{ref:t}),void 0)},void 0)});exports.ElyraOutOfDateError=T,exports.InvalidPipelineError=R,exports.PIPELINE_CURRENT_VERSION=7,exports.PipelineEditor=Pt,exports.PipelineOutOfDateError=I,exports.ThemeProvider=function(n){return e.jsx(t.ThemeProvider,Object.assign({theme:n.theme},{children:n.children}),void 0)},exports.createTheme=function(e){return e};
//# sourceMappingURL=index.js.map


/***/ }),

/***/ "../../node_modules/@elyra/pipeline-schemas/common-pipeline/pipeline-flow/upgrade/upgrade-flow.js":
/*!********************************************************************************************************!*\
  !*** ../../node_modules/@elyra/pipeline-schemas/common-pipeline/pipeline-flow/upgrade/upgrade-flow.js ***!
  \********************************************************************************************************/
/***/ ((module) => {

/*
 * Copyright 2017-2020 Elyra Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 /* eslint max-depth: ["error", 6] */

// Modules

// Globals -------------------------------------------------------------------->

// The lowest version accepted
const FIRST_VERSION = 1;

// The latest pipeline-flow version - update as new versions are developed
const LATEST_VERSION = 3;

// Array of major version upgrade functions
const updateFuncs = [
	_update0to1,
	_update1to2,
	_update2to3
];

// Private Methods ------------------------------------------------------------>

/**
 * Extracts the version from the given pipeline-flow.
 *
 * @param {Object} pipelineFlow: A pipeline-flow JSON object
 *
 * @return {integer} An integer version number
 *
 * @throws {Error} If the version number cannot be extracted
 */
function extractVersion(pipelineFlow) {
	var baseVersion;
	// Validate the incoming pipeline-flow
	if (!pipelineFlow || !pipelineFlow.version ||
		!(typeof pipelineFlow.version === "string") ||
		pipelineFlow.version.length === 0) {
		throw new Error("Invalid pipeline-flow document: The 'version' attribute is missing or invalid");
	} else {
		baseVersion = parseInt(pipelineFlow.version, 10);
		if (!baseVersion) {
			throw new Error("Invalid pipeline-flow document: The 'version' attribute cannot be parsed");
		}
	}
	return baseVersion;
}

// Version 1 methods ------------------------>

/**
 * Updates version 0 to version 1.
 *
 * @param {object} pipelineFlow: A pipeline-flow JSON object
 *
 * @return A pipeline-flow object that has been upgraded to version 1
 */
function _update0to1(pipelineFlow) {
	pipelineFlow.version = "1.0";
	return pipelineFlow;
}

// Version 2 methods ------------------------>

/**
 * Updates version 1 to version 2.
 *
 * @param {object} pipelineFlow: A pipeline-flow JSON object
 *
 * @return A pipeline-flow object that has been upgraded to version 2
 */
function _update1to2(pipelineFlow) {
	pipelineFlow.version = "2.0";
	pipelineFlow.json_schema = "https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v2-schema.json";

	// --> Changed the binding node. Instead of just a single input or output port,
	// binding nodes can have either an array of input ports or an array of output ports.
	// Also added "parameters" and "op" elements in the binding node *
	// Cycle the pipelines...
	for (var id1 = 0; id1 < pipelineFlow.pipelines.length; id1++) {
		const pipeline = pipelineFlow.pipelines[id1];
		updateBindingNodesInPipeline(pipeline);
	}

	// --> "pipeline_id_ref" was removed from "link_def"
	for (var id2 = 0; id2 < pipelineFlow.pipelines.length; id2++) {
		const pipeline = pipelineFlow.pipelines[id2];
		updatePipelinesIdRef(pipeline);
	}

	// --> Renamed "runtime" to "runtime_ref" and added an array of runtime objects that "runtime_ref" refers to
	if (!pipelineFlow.runtimes) {
		pipelineFlow.runtimes = [];
	}
	for (var id3 = 0; id3 < pipelineFlow.pipelines.length; id3++) {
		const pipeline = pipelineFlow.pipelines[id3];
		if (pipeline.runtime) {
			const runtimeName = pipeline.runtime;
			pipeline.runtime_ref = runtimeName;
			if (_getRuntime(pipelineFlow, runtimeName) === null) {
				// Add a new runtime object
				pipelineFlow.runtimes.push({
					"id": runtimeName,
					"name": runtimeName
				});
			}
			delete pipeline.runtime;
		}
	}

	return pipelineFlow;
}

/**
 * Updates version 2 to version 3.
 *
 * @param {object} pipelineFlow: A pipeline-flow JSON object
 *
 * @return A pipeline-flow object that has been upgraded to version 2
 */
function _update2to3(pipelineFlow) {
	pipelineFlow.version = "3.0";
	pipelineFlow.json_schema = "https://api.dataplatform.ibm.com/schemas/common-pipeline/pipeline-flow/pipeline-flow-v3-schema.json";

	return pipelineFlow;
}

/**
 * Attempts to locate a runtime object with the given name.
 *
 * @param {Object} pipelineFlow: A pipeline-flow JSON object
 * @param {String} name: The name of the runtime to search for
 *
 * @return {Object} a runtime object or null if not found
 */
function _getRuntime(pipelineFlow, runtimeName) {
	if (pipelineFlow.runtimes) {
		for (var idx = 0; idx < pipelineFlow.runtimes; idx++) {
			const runtime = pipelineFlow.runtimes[idx];
			if (runtime.name === runtimeName) {
				return runtime;
			}
		}
	}
	return null;
}

/**
 * Updates the binding nodes in the given pipeline to 2.0 state.
 *
 * @param {object} pipeline: A single pipeline
 * @return {void}
 */
function updateBindingNodesInPipeline(pipeline) {
	for (var id2 = 0; id2 < pipeline.nodes.length; id2++) {
		const node = pipeline.nodes[id2];
		if (node.type === "binding") {
			// Extract the port and add it to a new array of ports instead
			if (typeof node.input !== "undefined") {
				if (node.input.link) {
					node.input.links = [node.input.link];
					delete node.input.link;
				}
				node.inputs = [node.input];
				delete node.input;
			} else if (typeof node.output !== "undefined") {
				node.outputs = [node.output];
				delete node.output;
			}
		}
	}
}

/**
 * Removes all pipeline_id_ref elements from ports.
 *
 * @param {object} pipeline: A single pipeline
 * @return {void}
 */
function updatePipelinesIdRef(pipeline) {
	for (var id2 = 0; id2 < pipeline.nodes.length; id2++) {
		const node = pipeline.nodes[id2];
		if (node.links) {
			for (var id3 = 0; id3 < node.links.length; id3++) {
				const link = node.links[id3];
				if (link.pipeline_id_ref) {
					delete link.pipeline_id_ref;
				}
			}
		}
	}
}


// Public Methods ------------------------------------------------------------->

/**
 * Upgrades the given pipeline-flow object to the current version.
 *
 * @param {Object} pipelineFlow: A pipeline-flow JSON object
 *
 * @returns A pipeline-flow object that has been upgraded to the latest version
 */
function upgrade(pipelineFlow) {
	const baseVersion = Math.max(extractVersion(pipelineFlow), FIRST_VERSION);
	var flow = JSON.parse(JSON.stringify(pipelineFlow));
	for (var idx = baseVersion; idx < LATEST_VERSION; idx++) {
		flow = updateFuncs[idx](flow);
	}
	return flow;
}


module.exports = {
	upgradePipelineFlow: upgrade,
	extractVersion: extractVersion,
	LATEST_VERSION: LATEST_VERSION
};


/***/ }),

/***/ "../../node_modules/@emotion/is-prop-valid/dist/emotion-is-prop-valid.browser.esm.js":
/*!*******************************************************************************************!*\
  !*** ../../node_modules/@emotion/is-prop-valid/dist/emotion-is-prop-valid.browser.esm.js ***!
  \*******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _emotion_memoize__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @emotion/memoize */ "../../node_modules/@emotion/memoize/dist/emotion-memoize.browser.esm.js");


var reactPropsRegex = /^((children|dangerouslySetInnerHTML|key|ref|autoFocus|defaultValue|defaultChecked|innerHTML|suppressContentEditableWarning|suppressHydrationWarning|valueLink|abbr|accept|acceptCharset|accessKey|action|allow|allowUserMedia|allowPaymentRequest|allowFullScreen|allowTransparency|alt|async|autoComplete|autoPlay|capture|cellPadding|cellSpacing|challenge|charSet|checked|cite|classID|className|cols|colSpan|content|contentEditable|contextMenu|controls|controlsList|coords|crossOrigin|data|dateTime|decoding|default|defer|dir|disabled|disablePictureInPicture|download|draggable|encType|enterKeyHint|form|formAction|formEncType|formMethod|formNoValidate|formTarget|frameBorder|headers|height|hidden|high|href|hrefLang|htmlFor|httpEquiv|id|inputMode|integrity|is|keyParams|keyType|kind|label|lang|list|loading|loop|low|marginHeight|marginWidth|max|maxLength|media|mediaGroup|method|min|minLength|multiple|muted|name|nonce|noValidate|open|optimum|pattern|placeholder|playsInline|poster|preload|profile|radioGroup|readOnly|referrerPolicy|rel|required|reversed|role|rows|rowSpan|sandbox|scope|scoped|scrolling|seamless|selected|shape|size|sizes|slot|span|spellCheck|src|srcDoc|srcLang|srcSet|start|step|style|summary|tabIndex|target|title|translate|type|useMap|value|width|wmode|wrap|about|datatype|inlist|prefix|property|resource|typeof|vocab|autoCapitalize|autoCorrect|autoSave|color|incremental|fallback|inert|itemProp|itemScope|itemType|itemID|itemRef|on|option|results|security|unselectable|accentHeight|accumulate|additive|alignmentBaseline|allowReorder|alphabetic|amplitude|arabicForm|ascent|attributeName|attributeType|autoReverse|azimuth|baseFrequency|baselineShift|baseProfile|bbox|begin|bias|by|calcMode|capHeight|clip|clipPathUnits|clipPath|clipRule|colorInterpolation|colorInterpolationFilters|colorProfile|colorRendering|contentScriptType|contentStyleType|cursor|cx|cy|d|decelerate|descent|diffuseConstant|direction|display|divisor|dominantBaseline|dur|dx|dy|edgeMode|elevation|enableBackground|end|exponent|externalResourcesRequired|fill|fillOpacity|fillRule|filter|filterRes|filterUnits|floodColor|floodOpacity|focusable|fontFamily|fontSize|fontSizeAdjust|fontStretch|fontStyle|fontVariant|fontWeight|format|from|fr|fx|fy|g1|g2|glyphName|glyphOrientationHorizontal|glyphOrientationVertical|glyphRef|gradientTransform|gradientUnits|hanging|horizAdvX|horizOriginX|ideographic|imageRendering|in|in2|intercept|k|k1|k2|k3|k4|kernelMatrix|kernelUnitLength|kerning|keyPoints|keySplines|keyTimes|lengthAdjust|letterSpacing|lightingColor|limitingConeAngle|local|markerEnd|markerMid|markerStart|markerHeight|markerUnits|markerWidth|mask|maskContentUnits|maskUnits|mathematical|mode|numOctaves|offset|opacity|operator|order|orient|orientation|origin|overflow|overlinePosition|overlineThickness|panose1|paintOrder|pathLength|patternContentUnits|patternTransform|patternUnits|pointerEvents|points|pointsAtX|pointsAtY|pointsAtZ|preserveAlpha|preserveAspectRatio|primitiveUnits|r|radius|refX|refY|renderingIntent|repeatCount|repeatDur|requiredExtensions|requiredFeatures|restart|result|rotate|rx|ry|scale|seed|shapeRendering|slope|spacing|specularConstant|specularExponent|speed|spreadMethod|startOffset|stdDeviation|stemh|stemv|stitchTiles|stopColor|stopOpacity|strikethroughPosition|strikethroughThickness|string|stroke|strokeDasharray|strokeDashoffset|strokeLinecap|strokeLinejoin|strokeMiterlimit|strokeOpacity|strokeWidth|surfaceScale|systemLanguage|tableValues|targetX|targetY|textAnchor|textDecoration|textRendering|textLength|to|transform|u1|u2|underlinePosition|underlineThickness|unicode|unicodeBidi|unicodeRange|unitsPerEm|vAlphabetic|vHanging|vIdeographic|vMathematical|values|vectorEffect|version|vertAdvY|vertOriginX|vertOriginY|viewBox|viewTarget|visibility|widths|wordSpacing|writingMode|x|xHeight|x1|x2|xChannelSelector|xlinkActuate|xlinkArcrole|xlinkHref|xlinkRole|xlinkShow|xlinkTitle|xlinkType|xmlBase|xmlns|xmlnsXlink|xmlLang|xmlSpace|y|y1|y2|yChannelSelector|z|zoomAndPan|for|class|autofocus)|(([Dd][Aa][Tt][Aa]|[Aa][Rr][Ii][Aa]|x)-.*))$/; // https://esbench.com/bench/5bfee68a4cd7e6009ef61d23

var isPropValid = /* #__PURE__ */(0,_emotion_memoize__WEBPACK_IMPORTED_MODULE_0__["default"])(function (prop) {
  return reactPropsRegex.test(prop) || prop.charCodeAt(0) === 111
  /* o */
  && prop.charCodeAt(1) === 110
  /* n */
  && prop.charCodeAt(2) < 91;
}
/* Z+1 */
);

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (isPropValid);


/***/ }),

/***/ "../../node_modules/@emotion/memoize/dist/emotion-memoize.browser.esm.js":
/*!*******************************************************************************!*\
  !*** ../../node_modules/@emotion/memoize/dist/emotion-memoize.browser.esm.js ***!
  \*******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
function memoize(fn) {
  var cache = Object.create(null);
  return function (arg) {
    if (cache[arg] === undefined) cache[arg] = fn(arg);
    return cache[arg];
  };
}

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (memoize);


/***/ }),

/***/ "../../node_modules/@emotion/stylis/dist/stylis.browser.esm.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/@emotion/stylis/dist/stylis.browser.esm.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
function stylis_min (W) {
  function M(d, c, e, h, a) {
    for (var m = 0, b = 0, v = 0, n = 0, q, g, x = 0, K = 0, k, u = k = q = 0, l = 0, r = 0, I = 0, t = 0, B = e.length, J = B - 1, y, f = '', p = '', F = '', G = '', C; l < B;) {
      g = e.charCodeAt(l);
      l === J && 0 !== b + n + v + m && (0 !== b && (g = 47 === b ? 10 : 47), n = v = m = 0, B++, J++);

      if (0 === b + n + v + m) {
        if (l === J && (0 < r && (f = f.replace(N, '')), 0 < f.trim().length)) {
          switch (g) {
            case 32:
            case 9:
            case 59:
            case 13:
            case 10:
              break;

            default:
              f += e.charAt(l);
          }

          g = 59;
        }

        switch (g) {
          case 123:
            f = f.trim();
            q = f.charCodeAt(0);
            k = 1;

            for (t = ++l; l < B;) {
              switch (g = e.charCodeAt(l)) {
                case 123:
                  k++;
                  break;

                case 125:
                  k--;
                  break;

                case 47:
                  switch (g = e.charCodeAt(l + 1)) {
                    case 42:
                    case 47:
                      a: {
                        for (u = l + 1; u < J; ++u) {
                          switch (e.charCodeAt(u)) {
                            case 47:
                              if (42 === g && 42 === e.charCodeAt(u - 1) && l + 2 !== u) {
                                l = u + 1;
                                break a;
                              }

                              break;

                            case 10:
                              if (47 === g) {
                                l = u + 1;
                                break a;
                              }

                          }
                        }

                        l = u;
                      }

                  }

                  break;

                case 91:
                  g++;

                case 40:
                  g++;

                case 34:
                case 39:
                  for (; l++ < J && e.charCodeAt(l) !== g;) {
                  }

              }

              if (0 === k) break;
              l++;
            }

            k = e.substring(t, l);
            0 === q && (q = (f = f.replace(ca, '').trim()).charCodeAt(0));

            switch (q) {
              case 64:
                0 < r && (f = f.replace(N, ''));
                g = f.charCodeAt(1);

                switch (g) {
                  case 100:
                  case 109:
                  case 115:
                  case 45:
                    r = c;
                    break;

                  default:
                    r = O;
                }

                k = M(c, r, k, g, a + 1);
                t = k.length;
                0 < A && (r = X(O, f, I), C = H(3, k, r, c, D, z, t, g, a, h), f = r.join(''), void 0 !== C && 0 === (t = (k = C.trim()).length) && (g = 0, k = ''));
                if (0 < t) switch (g) {
                  case 115:
                    f = f.replace(da, ea);

                  case 100:
                  case 109:
                  case 45:
                    k = f + '{' + k + '}';
                    break;

                  case 107:
                    f = f.replace(fa, '$1 $2');
                    k = f + '{' + k + '}';
                    k = 1 === w || 2 === w && L('@' + k, 3) ? '@-webkit-' + k + '@' + k : '@' + k;
                    break;

                  default:
                    k = f + k, 112 === h && (k = (p += k, ''));
                } else k = '';
                break;

              default:
                k = M(c, X(c, f, I), k, h, a + 1);
            }

            F += k;
            k = I = r = u = q = 0;
            f = '';
            g = e.charCodeAt(++l);
            break;

          case 125:
          case 59:
            f = (0 < r ? f.replace(N, '') : f).trim();
            if (1 < (t = f.length)) switch (0 === u && (q = f.charCodeAt(0), 45 === q || 96 < q && 123 > q) && (t = (f = f.replace(' ', ':')).length), 0 < A && void 0 !== (C = H(1, f, c, d, D, z, p.length, h, a, h)) && 0 === (t = (f = C.trim()).length) && (f = '\x00\x00'), q = f.charCodeAt(0), g = f.charCodeAt(1), q) {
              case 0:
                break;

              case 64:
                if (105 === g || 99 === g) {
                  G += f + e.charAt(l);
                  break;
                }

              default:
                58 !== f.charCodeAt(t - 1) && (p += P(f, q, g, f.charCodeAt(2)));
            }
            I = r = u = q = 0;
            f = '';
            g = e.charCodeAt(++l);
        }
      }

      switch (g) {
        case 13:
        case 10:
          47 === b ? b = 0 : 0 === 1 + q && 107 !== h && 0 < f.length && (r = 1, f += '\x00');
          0 < A * Y && H(0, f, c, d, D, z, p.length, h, a, h);
          z = 1;
          D++;
          break;

        case 59:
        case 125:
          if (0 === b + n + v + m) {
            z++;
            break;
          }

        default:
          z++;
          y = e.charAt(l);

          switch (g) {
            case 9:
            case 32:
              if (0 === n + m + b) switch (x) {
                case 44:
                case 58:
                case 9:
                case 32:
                  y = '';
                  break;

                default:
                  32 !== g && (y = ' ');
              }
              break;

            case 0:
              y = '\\0';
              break;

            case 12:
              y = '\\f';
              break;

            case 11:
              y = '\\v';
              break;

            case 38:
              0 === n + b + m && (r = I = 1, y = '\f' + y);
              break;

            case 108:
              if (0 === n + b + m + E && 0 < u) switch (l - u) {
                case 2:
                  112 === x && 58 === e.charCodeAt(l - 3) && (E = x);

                case 8:
                  111 === K && (E = K);
              }
              break;

            case 58:
              0 === n + b + m && (u = l);
              break;

            case 44:
              0 === b + v + n + m && (r = 1, y += '\r');
              break;

            case 34:
            case 39:
              0 === b && (n = n === g ? 0 : 0 === n ? g : n);
              break;

            case 91:
              0 === n + b + v && m++;
              break;

            case 93:
              0 === n + b + v && m--;
              break;

            case 41:
              0 === n + b + m && v--;
              break;

            case 40:
              if (0 === n + b + m) {
                if (0 === q) switch (2 * x + 3 * K) {
                  case 533:
                    break;

                  default:
                    q = 1;
                }
                v++;
              }

              break;

            case 64:
              0 === b + v + n + m + u + k && (k = 1);
              break;

            case 42:
            case 47:
              if (!(0 < n + m + v)) switch (b) {
                case 0:
                  switch (2 * g + 3 * e.charCodeAt(l + 1)) {
                    case 235:
                      b = 47;
                      break;

                    case 220:
                      t = l, b = 42;
                  }

                  break;

                case 42:
                  47 === g && 42 === x && t + 2 !== l && (33 === e.charCodeAt(t + 2) && (p += e.substring(t, l + 1)), y = '', b = 0);
              }
          }

          0 === b && (f += y);
      }

      K = x;
      x = g;
      l++;
    }

    t = p.length;

    if (0 < t) {
      r = c;
      if (0 < A && (C = H(2, p, r, d, D, z, t, h, a, h), void 0 !== C && 0 === (p = C).length)) return G + p + F;
      p = r.join(',') + '{' + p + '}';

      if (0 !== w * E) {
        2 !== w || L(p, 2) || (E = 0);

        switch (E) {
          case 111:
            p = p.replace(ha, ':-moz-$1') + p;
            break;

          case 112:
            p = p.replace(Q, '::-webkit-input-$1') + p.replace(Q, '::-moz-$1') + p.replace(Q, ':-ms-input-$1') + p;
        }

        E = 0;
      }
    }

    return G + p + F;
  }

  function X(d, c, e) {
    var h = c.trim().split(ia);
    c = h;
    var a = h.length,
        m = d.length;

    switch (m) {
      case 0:
      case 1:
        var b = 0;

        for (d = 0 === m ? '' : d[0] + ' '; b < a; ++b) {
          c[b] = Z(d, c[b], e).trim();
        }

        break;

      default:
        var v = b = 0;

        for (c = []; b < a; ++b) {
          for (var n = 0; n < m; ++n) {
            c[v++] = Z(d[n] + ' ', h[b], e).trim();
          }
        }

    }

    return c;
  }

  function Z(d, c, e) {
    var h = c.charCodeAt(0);
    33 > h && (h = (c = c.trim()).charCodeAt(0));

    switch (h) {
      case 38:
        return c.replace(F, '$1' + d.trim());

      case 58:
        return d.trim() + c.replace(F, '$1' + d.trim());

      default:
        if (0 < 1 * e && 0 < c.indexOf('\f')) return c.replace(F, (58 === d.charCodeAt(0) ? '' : '$1') + d.trim());
    }

    return d + c;
  }

  function P(d, c, e, h) {
    var a = d + ';',
        m = 2 * c + 3 * e + 4 * h;

    if (944 === m) {
      d = a.indexOf(':', 9) + 1;
      var b = a.substring(d, a.length - 1).trim();
      b = a.substring(0, d).trim() + b + ';';
      return 1 === w || 2 === w && L(b, 1) ? '-webkit-' + b + b : b;
    }

    if (0 === w || 2 === w && !L(a, 1)) return a;

    switch (m) {
      case 1015:
        return 97 === a.charCodeAt(10) ? '-webkit-' + a + a : a;

      case 951:
        return 116 === a.charCodeAt(3) ? '-webkit-' + a + a : a;

      case 963:
        return 110 === a.charCodeAt(5) ? '-webkit-' + a + a : a;

      case 1009:
        if (100 !== a.charCodeAt(4)) break;

      case 969:
      case 942:
        return '-webkit-' + a + a;

      case 978:
        return '-webkit-' + a + '-moz-' + a + a;

      case 1019:
      case 983:
        return '-webkit-' + a + '-moz-' + a + '-ms-' + a + a;

      case 883:
        if (45 === a.charCodeAt(8)) return '-webkit-' + a + a;
        if (0 < a.indexOf('image-set(', 11)) return a.replace(ja, '$1-webkit-$2') + a;
        break;

      case 932:
        if (45 === a.charCodeAt(4)) switch (a.charCodeAt(5)) {
          case 103:
            return '-webkit-box-' + a.replace('-grow', '') + '-webkit-' + a + '-ms-' + a.replace('grow', 'positive') + a;

          case 115:
            return '-webkit-' + a + '-ms-' + a.replace('shrink', 'negative') + a;

          case 98:
            return '-webkit-' + a + '-ms-' + a.replace('basis', 'preferred-size') + a;
        }
        return '-webkit-' + a + '-ms-' + a + a;

      case 964:
        return '-webkit-' + a + '-ms-flex-' + a + a;

      case 1023:
        if (99 !== a.charCodeAt(8)) break;
        b = a.substring(a.indexOf(':', 15)).replace('flex-', '').replace('space-between', 'justify');
        return '-webkit-box-pack' + b + '-webkit-' + a + '-ms-flex-pack' + b + a;

      case 1005:
        return ka.test(a) ? a.replace(aa, ':-webkit-') + a.replace(aa, ':-moz-') + a : a;

      case 1e3:
        b = a.substring(13).trim();
        c = b.indexOf('-') + 1;

        switch (b.charCodeAt(0) + b.charCodeAt(c)) {
          case 226:
            b = a.replace(G, 'tb');
            break;

          case 232:
            b = a.replace(G, 'tb-rl');
            break;

          case 220:
            b = a.replace(G, 'lr');
            break;

          default:
            return a;
        }

        return '-webkit-' + a + '-ms-' + b + a;

      case 1017:
        if (-1 === a.indexOf('sticky', 9)) break;

      case 975:
        c = (a = d).length - 10;
        b = (33 === a.charCodeAt(c) ? a.substring(0, c) : a).substring(d.indexOf(':', 7) + 1).trim();

        switch (m = b.charCodeAt(0) + (b.charCodeAt(7) | 0)) {
          case 203:
            if (111 > b.charCodeAt(8)) break;

          case 115:
            a = a.replace(b, '-webkit-' + b) + ';' + a;
            break;

          case 207:
          case 102:
            a = a.replace(b, '-webkit-' + (102 < m ? 'inline-' : '') + 'box') + ';' + a.replace(b, '-webkit-' + b) + ';' + a.replace(b, '-ms-' + b + 'box') + ';' + a;
        }

        return a + ';';

      case 938:
        if (45 === a.charCodeAt(5)) switch (a.charCodeAt(6)) {
          case 105:
            return b = a.replace('-items', ''), '-webkit-' + a + '-webkit-box-' + b + '-ms-flex-' + b + a;

          case 115:
            return '-webkit-' + a + '-ms-flex-item-' + a.replace(ba, '') + a;

          default:
            return '-webkit-' + a + '-ms-flex-line-pack' + a.replace('align-content', '').replace(ba, '') + a;
        }
        break;

      case 973:
      case 989:
        if (45 !== a.charCodeAt(3) || 122 === a.charCodeAt(4)) break;

      case 931:
      case 953:
        if (!0 === la.test(d)) return 115 === (b = d.substring(d.indexOf(':') + 1)).charCodeAt(0) ? P(d.replace('stretch', 'fill-available'), c, e, h).replace(':fill-available', ':stretch') : a.replace(b, '-webkit-' + b) + a.replace(b, '-moz-' + b.replace('fill-', '')) + a;
        break;

      case 962:
        if (a = '-webkit-' + a + (102 === a.charCodeAt(5) ? '-ms-' + a : '') + a, 211 === e + h && 105 === a.charCodeAt(13) && 0 < a.indexOf('transform', 10)) return a.substring(0, a.indexOf(';', 27) + 1).replace(ma, '$1-webkit-$2') + a;
    }

    return a;
  }

  function L(d, c) {
    var e = d.indexOf(1 === c ? ':' : '{'),
        h = d.substring(0, 3 !== c ? e : 10);
    e = d.substring(e + 1, d.length - 1);
    return R(2 !== c ? h : h.replace(na, '$1'), e, c);
  }

  function ea(d, c) {
    var e = P(c, c.charCodeAt(0), c.charCodeAt(1), c.charCodeAt(2));
    return e !== c + ';' ? e.replace(oa, ' or ($1)').substring(4) : '(' + c + ')';
  }

  function H(d, c, e, h, a, m, b, v, n, q) {
    for (var g = 0, x = c, w; g < A; ++g) {
      switch (w = S[g].call(B, d, x, e, h, a, m, b, v, n, q)) {
        case void 0:
        case !1:
        case !0:
        case null:
          break;

        default:
          x = w;
      }
    }

    if (x !== c) return x;
  }

  function T(d) {
    switch (d) {
      case void 0:
      case null:
        A = S.length = 0;
        break;

      default:
        if ('function' === typeof d) S[A++] = d;else if ('object' === typeof d) for (var c = 0, e = d.length; c < e; ++c) {
          T(d[c]);
        } else Y = !!d | 0;
    }

    return T;
  }

  function U(d) {
    d = d.prefix;
    void 0 !== d && (R = null, d ? 'function' !== typeof d ? w = 1 : (w = 2, R = d) : w = 0);
    return U;
  }

  function B(d, c) {
    var e = d;
    33 > e.charCodeAt(0) && (e = e.trim());
    V = e;
    e = [V];

    if (0 < A) {
      var h = H(-1, c, e, e, D, z, 0, 0, 0, 0);
      void 0 !== h && 'string' === typeof h && (c = h);
    }

    var a = M(O, e, c, 0, 0);
    0 < A && (h = H(-2, a, e, e, D, z, a.length, 0, 0, 0), void 0 !== h && (a = h));
    V = '';
    E = 0;
    z = D = 1;
    return a;
  }

  var ca = /^\0+/g,
      N = /[\0\r\f]/g,
      aa = /: */g,
      ka = /zoo|gra/,
      ma = /([,: ])(transform)/g,
      ia = /,\r+?/g,
      F = /([\t\r\n ])*\f?&/g,
      fa = /@(k\w+)\s*(\S*)\s*/,
      Q = /::(place)/g,
      ha = /:(read-only)/g,
      G = /[svh]\w+-[tblr]{2}/,
      da = /\(\s*(.*)\s*\)/g,
      oa = /([\s\S]*?);/g,
      ba = /-self|flex-/g,
      na = /[^]*?(:[rp][el]a[\w-]+)[^]*/,
      la = /stretch|:\s*\w+\-(?:conte|avail)/,
      ja = /([^-])(image-set\()/,
      z = 1,
      D = 1,
      E = 0,
      w = 1,
      O = [],
      S = [],
      A = 0,
      R = null,
      Y = 0,
      V = '';
  B.use = T;
  B.set = U;
  void 0 !== W && U(W);
  return B;
}

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (stylis_min);


/***/ }),

/***/ "../../node_modules/@emotion/unitless/dist/unitless.browser.esm.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/@emotion/unitless/dist/unitless.browser.esm.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
var unitlessKeys = {
  animationIterationCount: 1,
  borderImageOutset: 1,
  borderImageSlice: 1,
  borderImageWidth: 1,
  boxFlex: 1,
  boxFlexGroup: 1,
  boxOrdinalGroup: 1,
  columnCount: 1,
  columns: 1,
  flex: 1,
  flexGrow: 1,
  flexPositive: 1,
  flexShrink: 1,
  flexNegative: 1,
  flexOrder: 1,
  gridRow: 1,
  gridRowEnd: 1,
  gridRowSpan: 1,
  gridRowStart: 1,
  gridColumn: 1,
  gridColumnEnd: 1,
  gridColumnSpan: 1,
  gridColumnStart: 1,
  msGridRow: 1,
  msGridRowSpan: 1,
  msGridColumn: 1,
  msGridColumnSpan: 1,
  fontWeight: 1,
  lineHeight: 1,
  opacity: 1,
  order: 1,
  orphans: 1,
  tabSize: 1,
  widows: 1,
  zIndex: 1,
  zoom: 1,
  WebkitLineClamp: 1,
  // SVG-related properties
  fillOpacity: 1,
  floodOpacity: 1,
  stopOpacity: 1,
  strokeDasharray: 1,
  strokeDashoffset: 1,
  strokeMiterlimit: 1,
  strokeOpacity: 1,
  strokeWidth: 1
};

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (unitlessKeys);


/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Accordion/Accordion.Skeleton.js":
/*!************************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Accordion/Accordion.Skeleton.js ***!
  \************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var _SkeletonText__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../SkeletonText */ "../../node_modules/carbon-components-react/es/components/SkeletonText/SkeletonText.js");
/* harmony import */ var _prop_types_deprecate__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../../prop-types/deprecate */ "../../node_modules/carbon-components-react/es/prop-types/deprecate.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");



var _excluded = ["align", "open", "count", "className"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */








function AccordionSkeleton(_ref) {
  var align = _ref.align,
      open = _ref.open,
      count = _ref.count,
      className = _ref.className,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  var classes = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--accordion"), "".concat(prefix, "--skeleton"), className, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--accordion--").concat(align), align));
  var numSkeletonItems = open ? count - 1 : count;
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("ul", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    className: classes
  }, rest), open && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("li", {
    className: "".concat(prefix, "--accordion__item ").concat(prefix, "--accordion__item--active")
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("span", {
    className: "".concat(prefix, "--accordion__heading")
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_6__.ChevronRight16, {
    className: "".concat(prefix, "--accordion__arrow")
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_SkeletonText__WEBPACK_IMPORTED_MODULE_7__["default"], {
    className: "".concat(prefix, "--accordion__title")
  })), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: "".concat(prefix, "--accordion__content")
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_SkeletonText__WEBPACK_IMPORTED_MODULE_7__["default"], {
    width: "90%"
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_SkeletonText__WEBPACK_IMPORTED_MODULE_7__["default"], {
    width: "80%"
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_SkeletonText__WEBPACK_IMPORTED_MODULE_7__["default"], {
    width: "95%"
  }))), Array.from({
    length: numSkeletonItems
  }).map(function (_, i) {
    return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(AccordionSkeletonItem, {
      key: i
    });
  }));
}

AccordionSkeleton.propTypes = {
  /**
   * Specify the alignment of the accordion heading title and chevron.
   */
  align: prop_types__WEBPACK_IMPORTED_MODULE_8___default().oneOf(['start', 'end']),

  /**
   * Specify an optional className to add.
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().string),

  /**
   * Set number of items to render
   */
  count: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().number),

  /**
   * `false` to not display the first item opened
   */
  open: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().bool),

  /**
   * Set unique identifier to generate unique item keys
   */
  uid: (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_9__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_8___default().any))
};
AccordionSkeleton.defaultProps = {
  open: true,
  count: 4,
  align: 'end'
};

function AccordionSkeletonItem() {
  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("li", {
    className: "".concat(prefix, "--accordion__item")
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("span", {
    className: "".concat(prefix, "--accordion__heading")
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_6__.ChevronRight16, {
    className: "".concat(prefix, "--accordion__arrow")
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_SkeletonText__WEBPACK_IMPORTED_MODULE_7__["default"], {
    className: "".concat(prefix, "--accordion__title")
  })));
}

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (AccordionSkeleton);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Accordion/Accordion.js":
/*!***************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Accordion/Accordion.js ***!
  \***************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_6__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @carbon/feature-flags */ "../../node_modules/@carbon/feature-flags/es/index.js");



var _excluded = ["align", "children", "className", "disabled", "size"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */






function Accordion(_ref) {
  var _cx;

  var _ref$align = _ref.align,
      align = _ref$align === void 0 ? 'end' : _ref$align,
      children = _ref.children,
      customClassName = _ref.className,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'md' : _ref$size,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  var className = classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--accordion"), customClassName, (_cx = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--accordion--").concat(align), align), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--accordion--").concat(size), size), _cx));
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("ul", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    className: className
  }, rest), disabled ? react__WEBPACK_IMPORTED_MODULE_4___default().Children.toArray(children).map(function (child) {
    return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().cloneElement(child, {
      disabled: disabled
    });
  }) : children);
}

Accordion.propTypes = {
  /**
   * Specify the alignment of the accordion heading title and chevron.
   */
  align: prop_types__WEBPACK_IMPORTED_MODULE_6___default().oneOf(['start', 'end']),

  /**
   * Pass in the children that will be rendered within the Accordion
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().node),

  /**
   * Specify an optional className to be applied to the container node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().string),

  /**
   * Specify whether an individual AccordionItem should be disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool),

  /**
   * Specify the size of the Accordion. Currently supports the following:
   */
  size: _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_7__.enabled('enable-v11-release') ? prop_types__WEBPACK_IMPORTED_MODULE_6___default().oneOf(['sm', 'md', 'lg']) : prop_types__WEBPACK_IMPORTED_MODULE_6___default().oneOf(['sm', 'md', 'lg', 'xl'])
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Accordion);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Accordion/AccordionItem.js":
/*!*******************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Accordion/AccordionItem.js ***!
  \*******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_12___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_12__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var _Text__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../Text */ "../../node_modules/carbon-components-react/es/components/Text/Text.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/match.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/keys.js");
/* harmony import */ var _internal_useId__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../internal/useId */ "../../node_modules/carbon-components-react/es/internal/useId.js");
/* harmony import */ var _prop_types_deprecate__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../../prop-types/deprecate */ "../../node_modules/carbon-components-react/es/prop-types/deprecate.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");




var _excluded = ["children", "className", "iconDescription", "open", "onHeadingClick", "renderExpando", "renderToggle", "title", "disabled"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */










var defaultRenderToggle = function defaultRenderToggle(props) {
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("button", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_3__["default"])({
    type: "button"
  }, props));
};

function AccordionItem(_ref) {
  var _cx;

  var children = _ref.children,
      customClassName = _ref.className,
      iconDescription = _ref.iconDescription,
      _ref$open = _ref.open,
      open = _ref$open === void 0 ? false : _ref$open,
      onHeadingClick = _ref.onHeadingClick,
      _ref$renderExpando = _ref.renderExpando,
      renderExpando = _ref$renderExpando === void 0 ? defaultRenderToggle : _ref$renderExpando,
      renderToggle = _ref.renderToggle,
      _ref$title = _ref.title,
      title = _ref$title === void 0 ? 'title' : _ref$title,
      disabled = _ref.disabled,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(open),
      _useState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_1__["default"])(_useState, 2),
      isOpen = _useState2[0],
      setIsOpen = _useState2[1];

  var _useState3 = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(open),
      _useState4 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_1__["default"])(_useState3, 2),
      prevIsOpen = _useState4[0],
      setPrevIsOpen = _useState4[1];

  var _useState5 = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(''),
      _useState6 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_1__["default"])(_useState5, 2),
      animation = _useState6[0],
      setAnimation = _useState6[1];

  var id = (0,_internal_useId__WEBPACK_IMPORTED_MODULE_6__.useId)('accordion-item');
  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_7__.usePrefix)();
  var className = classnames__WEBPACK_IMPORTED_MODULE_4___default()((_cx = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_cx, "".concat(prefix, "--accordion__item"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_cx, "".concat(prefix, "--accordion__item--active"), isOpen), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_cx, "".concat(prefix, "--accordion__item--").concat(animation), animation), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_cx, "".concat(prefix, "--accordion__item--disabled"), disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_cx, customClassName, !!customClassName), _cx));
  var Toggle = renderToggle || renderExpando; // remove renderExpando in next major release

  if (open !== prevIsOpen) {
    setAnimation(isOpen ? 'collapsing' : 'expanding');
    setIsOpen(open);
    setPrevIsOpen(open);
  } // When the AccordionItem heading is clicked, toggle the open state of the
  // panel


  function onClick(event) {
    var nextValue = !isOpen;
    setAnimation(isOpen ? 'collapsing' : 'expanding');
    setIsOpen(nextValue);

    if (onHeadingClick) {
      // TODO: normalize signature, potentially:
      // onHeadingClick :: (event: Event, state: { isOpen: Boolean }) => any
      onHeadingClick({
        isOpen: nextValue,
        event: event
      });
    }
  } // If the AccordionItem is open, and the user hits the ESC key, then close it


  function onKeyDown(event) {
    if (isOpen && (0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_8__.match)(event, _internal_keyboard__WEBPACK_IMPORTED_MODULE_9__.Escape)) {
      setIsOpen(false);
    }
  }

  function handleAnimationEnd(event) {
    if (rest.handleAnimationEnd) {
      rest.handleAnimationEnd(event);
    }

    setAnimation('');
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("li", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_3__["default"])({
    className: className
  }, rest, {
    onAnimationEnd: handleAnimationEnd
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(Toggle, {
    disabled: disabled,
    "aria-controls": id,
    "aria-expanded": isOpen,
    className: "".concat(prefix, "--accordion__heading"),
    onClick: onClick,
    onKeyDown: onKeyDown,
    type: "button"
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_10__.ChevronRight16, {
    className: "".concat(prefix, "--accordion__arrow")
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_Text__WEBPACK_IMPORTED_MODULE_11__.Text, {
    as: "div",
    className: "".concat(prefix, "--accordion__title")
  }, title)), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("div", {
    id: id,
    className: "".concat(prefix, "--accordion__content")
  }, children));
}

AccordionItem.propTypes = {
  /**
   * Provide the contents of your AccordionItem
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().node),

  /**
   * Specify an optional className to be applied to the container node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().string),

  /**
   * Specify whether an individual AccordionItem should be disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().bool),

  /**
   * The description of the expand icon.
   */
  iconDescription: (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_13__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_12___default().string), 'The `iconDescription` prop has been deprecated as it is no longer ' + 'required. Feel free to remove this prop from <AccordionItem>. This ' + 'prop will be removed in the next major release of ' + '`carbon-components-react`'),

  /**
   * The handler of the massaged `click` event.
   */
  onClick: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func),

  /**
   * The handler of the massaged `click` event on the heading.
   */
  onHeadingClick: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func),

  /**
   * `true` to open the expand.
   */
  open: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().bool),

  /**
   * The callback function to render the expand button.
   * Can be a React component class.
   */
  renderExpando: (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_13__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_12___default().func), 'The `renderExpando` prop has been deprecated and will be removed in the next major release of Carbon. Use the `renderToggle` prop instead.'),

  /**
   * The callback function to render the expand button.
   * Can be a React component class.
   */
  renderToggle: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func),

  /**
   * The accordion title.
   */
  title: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().node)
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (AccordionItem);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Accordion/index.js":
/*!***********************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Accordion/index.js ***!
  \***********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "AccordionItem": () => (/* reexport safe */ _AccordionItem__WEBPACK_IMPORTED_MODULE_1__["default"]),
/* harmony export */   "AccordionSkeleton": () => (/* reexport safe */ _Accordion_Skeleton__WEBPACK_IMPORTED_MODULE_2__["default"]),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _Accordion__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./Accordion */ "../../node_modules/carbon-components-react/es/components/Accordion/Accordion.js");
/* harmony import */ var _AccordionItem__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./AccordionItem */ "../../node_modules/carbon-components-react/es/components/Accordion/AccordionItem.js");
/* harmony import */ var _Accordion_Skeleton__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./Accordion.Skeleton */ "../../node_modules/carbon-components-react/es/components/Accordion/Accordion.Skeleton.js");
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_Accordion__WEBPACK_IMPORTED_MODULE_0__["default"]);



/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/AccordionItem/index.js":
/*!***************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/AccordionItem/index.js ***!
  \***************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _Accordion__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Accordion */ "../../node_modules/carbon-components-react/es/components/Accordion/AccordionItem.js");
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
// Alias for import paths for build tools that rely on this

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_Accordion__WEBPACK_IMPORTED_MODULE_0__["default"]);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Button/Button.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Button/Button.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_toConsumableArray__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/toConsumableArray */ "../../node_modules/@babel/runtime/helpers/esm/toConsumableArray.js");
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_14___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_14__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var _prop_types_types__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ../../prop-types/types */ "../../node_modules/carbon-components-react/es/prop-types/types.js");
/* harmony import */ var _prop_types_deprecate__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ../../prop-types/deprecate */ "../../node_modules/carbon-components-react/es/prop-types/deprecate.js");
/* harmony import */ var _tools_events__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../../tools/events */ "../../node_modules/carbon-components-react/es/tools/events.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/match.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/keys.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");
/* harmony import */ var _internal_useId__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../../internal/useId */ "../../node_modules/carbon-components-react/es/internal/useId.js");
/* harmony import */ var _tools_toggleClass__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../tools/toggleClass */ "../../node_modules/carbon-components-react/es/tools/toggleClass.js");
/* harmony import */ var _FeatureFlags__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../FeatureFlags */ "../../node_modules/carbon-components-react/es/components/FeatureFlags/index.js");
/* harmony import */ var _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @carbon/feature-flags */ "../../node_modules/@carbon/feature-flags/es/index.js");




var _excluded = ["as", "children", "className", "dangerDescription", "disabled", "hasIconOnly", "href", "iconDescription", "isExpressive", "isSelected", "kind", "onBlur", "onClick", "onFocus", "onMouseEnter", "onMouseLeave", "renderIcon", "size", "small", "tabIndex", "tooltipAlignment", "tooltipPosition", "type"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */












var Button = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().forwardRef(function Button(_ref, ref) {
  var _classNames;

  var as = _ref.as,
      children = _ref.children,
      className = _ref.className,
      _ref$dangerDescriptio = _ref.dangerDescription,
      dangerDescription = _ref$dangerDescriptio === void 0 ? 'danger' : _ref$dangerDescriptio,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      _ref$hasIconOnly = _ref.hasIconOnly,
      hasIconOnly = _ref$hasIconOnly === void 0 ? false : _ref$hasIconOnly,
      href = _ref.href,
      iconDescription = _ref.iconDescription,
      _ref$isExpressive = _ref.isExpressive,
      isExpressive = _ref$isExpressive === void 0 ? false : _ref$isExpressive,
      isSelected = _ref.isSelected,
      _ref$kind = _ref.kind,
      kind = _ref$kind === void 0 ? 'primary' : _ref$kind,
      onBlur = _ref.onBlur,
      onClick = _ref.onClick,
      onFocus = _ref.onFocus,
      onMouseEnter = _ref.onMouseEnter,
      onMouseLeave = _ref.onMouseLeave,
      ButtonImageElement = _ref.renderIcon,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_6__.enabled('enable-v11-release') ? 'lg' : 'default' : _ref$size,
      small = _ref.small,
      _ref$tabIndex = _ref.tabIndex,
      tabIndex = _ref$tabIndex === void 0 ? 0 : _ref$tabIndex,
      _ref$tooltipAlignment = _ref.tooltipAlignment,
      tooltipAlignment = _ref$tooltipAlignment === void 0 ? 'center' : _ref$tooltipAlignment,
      _ref$tooltipPosition = _ref.tooltipPosition,
      tooltipPosition = _ref$tooltipPosition === void 0 ? 'top' : _ref$tooltipPosition,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'button' : _ref$type,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_3__["default"])(_ref, _excluded);

  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_4__.useState)(false),
      _useState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState, 2),
      allowTooltipVisibility = _useState2[0],
      setAllowTooltipVisibility = _useState2[1];

  var _useState3 = (0,react__WEBPACK_IMPORTED_MODULE_4__.useState)(false),
      _useState4 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState3, 2),
      isHovered = _useState4[0],
      setIsHovered = _useState4[1];

  var _useState5 = (0,react__WEBPACK_IMPORTED_MODULE_4__.useState)(false),
      _useState6 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState5, 2),
      isFocused = _useState6[0],
      setIsFocused = _useState6[1];

  var tooltipRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var tooltipTimeout = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_7__.usePrefix)();

  var closeTooltips = function closeTooltips(evt) {
    var _document;

    var tooltipNode = (_document = document) === null || _document === void 0 ? void 0 : _document.querySelectorAll(".".concat(prefix, "--tooltip--a11y"));

    (0,_babel_runtime_helpers_toConsumableArray__WEBPACK_IMPORTED_MODULE_1__["default"])(tooltipNode).map(function (node) {
      (0,_tools_toggleClass__WEBPACK_IMPORTED_MODULE_8__["default"])(node, "".concat(prefix, "--tooltip--hidden"), node !== evt.currentTarget);
    });
  };

  var handleFocus = function handleFocus(evt) {
    if (hasIconOnly) {
      closeTooltips(evt);
      setIsFocused(true);
      setAllowTooltipVisibility(true);
    }
  };

  var handleBlur = function handleBlur() {
    if (hasIconOnly) {
      setIsHovered(false);
      setIsFocused(false);
      setAllowTooltipVisibility(false);
    }
  };

  var handleMouseEnter = function handleMouseEnter(evt) {
    if (hasIconOnly) {
      tooltipTimeout.current && clearTimeout(tooltipTimeout.current);

      if (evt.target === tooltipRef.current) {
        setAllowTooltipVisibility(true);
        return;
      }

      closeTooltips(evt);
      setAllowTooltipVisibility(true);
    }
  };

  var handleMouseLeave = function handleMouseLeave() {
    if (!isFocused && hasIconOnly) {
      tooltipTimeout.current = setTimeout(function () {
        setAllowTooltipVisibility(false);
        setIsHovered(false);
      }, 100);
    }
  };

  var handleClick = function handleClick(evt) {
    // Prevent clicks on the tooltip from triggering the button click event
    setAllowTooltipVisibility(false);

    if (evt.target === tooltipRef.current) {
      evt.preventDefault();
      return;
    }
  };

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    var handleEscKeyDown = function handleEscKeyDown(event) {
      if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_9__.matches)(event, [_internal_keyboard__WEBPACK_IMPORTED_MODULE_10__.Escape])) {
        setAllowTooltipVisibility(false);
        setIsHovered(false);
      }
    };

    document.addEventListener('keydown', handleEscKeyDown);
    return function () {
      return document.removeEventListener('keydown', handleEscKeyDown);
    };
  }, []);
  var enabled = (0,_FeatureFlags__WEBPACK_IMPORTED_MODULE_11__.useFeatureFlag)('enable-v11-release');
  var buttonClasses = classnames__WEBPACK_IMPORTED_MODULE_5___default()(className, (_classNames = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--btn"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--btn--sm"), size === 'small' && !isExpressive || size === 'sm' && !isExpressive || small && !isExpressive), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--btn--md"), size === 'field' && !isExpressive || size === 'md' && !isExpressive), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--btn--lg"), enabled ? size === 'xl' : size === 'lg'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--btn--xl"), enabled ? size === '2xl' : size === 'xl'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--btn--").concat(kind), kind), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--btn--disabled"), disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--btn--expressive"), isExpressive), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--tooltip--visible"), isHovered), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--tooltip--hidden"), hasIconOnly && !allowTooltipVisibility), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--btn--icon-only"), hasIconOnly), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--btn--selected"), hasIconOnly && isSelected && kind === 'ghost'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--tooltip__trigger"), hasIconOnly), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--tooltip--a11y"), hasIconOnly), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--btn--icon-only--").concat(tooltipPosition), hasIconOnly && tooltipPosition), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--tooltip--align-").concat(tooltipAlignment), hasIconOnly && tooltipAlignment), _classNames));
  var commonProps = {
    tabIndex: tabIndex,
    className: buttonClasses,
    ref: ref
  };
  var buttonImage = !ButtonImageElement ? null : /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement(ButtonImageElement, {
    "aria-label": iconDescription,
    className: "".concat(prefix, "--btn__icon"),
    "aria-hidden": "true"
  });
  var dangerButtonVariants = ['danger', 'danger--tertiary', 'danger--ghost'];
  var component = 'button';
  var assistiveId = (0,_internal_useId__WEBPACK_IMPORTED_MODULE_12__.useId)('danger-description');
  var otherProps = {
    disabled: disabled,
    type: type,
    'aria-describedby': dangerButtonVariants.includes(kind) ? assistiveId : null,
    'aria-pressed': hasIconOnly && kind === 'ghost' ? isSelected : null
  };
  var anchorProps = {
    href: href
  };
  var assistiveText;

  if (hasIconOnly) {
    assistiveText = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", {
      ref: tooltipRef,
      onMouseEnter: handleMouseEnter,
      className: "".concat(prefix, "--assistive-text")
    }, iconDescription);
  } else if (dangerButtonVariants.includes(kind)) {
    assistiveText = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("span", {
      id: assistiveId,
      className: "".concat(prefix, "--visually-hidden")
    }, dangerDescription);
  } else {
    assistiveText = null;
  }

  if (as) {
    component = as;
    otherProps = _objectSpread(_objectSpread({}, otherProps), anchorProps);
  } else if (href && !disabled) {
    component = 'a';
    otherProps = anchorProps;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement(component, _objectSpread(_objectSpread(_objectSpread({
    onMouseEnter: (0,_tools_events__WEBPACK_IMPORTED_MODULE_13__.composeEventHandlers)([onMouseEnter, handleMouseEnter]),
    onMouseLeave: (0,_tools_events__WEBPACK_IMPORTED_MODULE_13__.composeEventHandlers)([onMouseLeave, handleMouseLeave]),
    onFocus: (0,_tools_events__WEBPACK_IMPORTED_MODULE_13__.composeEventHandlers)([onFocus, handleFocus]),
    onBlur: (0,_tools_events__WEBPACK_IMPORTED_MODULE_13__.composeEventHandlers)([onBlur, handleBlur]),
    onClick: (0,_tools_events__WEBPACK_IMPORTED_MODULE_13__.composeEventHandlers)([onClick, handleClick])
  }, rest), commonProps), otherProps), assistiveText, children, buttonImage);
});
Button.displayName = 'Button';
Button.propTypes = {
  /**
   * Specify how the button itself should be rendered.
   * Make sure to apply all props to the root node and render children appropriately
   */
  as: prop_types__WEBPACK_IMPORTED_MODULE_14___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_14___default().func), (prop_types__WEBPACK_IMPORTED_MODULE_14___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_14___default().elementType)]),

  /**
   * Specify the content of your Button
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().node),

  /**
   * Specify an optional className to be added to your Button
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().string),

  /**
   * Specify the message read by screen readers for the danger button variant
   */
  dangerDescription: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().string),

  /**
   * Specify whether the Button should be disabled, or not
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().bool),

  /**
   * Specify if the button is an icon-only button
   */
  hasIconOnly: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().bool),

  /**
   * Optionally specify an href for your Button to become an `<a>` element
   */
  href: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().string),

  /**
   * If specifying the `renderIcon` prop, provide a description for that icon that can
   * be read by screen readers
   */
  iconDescription: function iconDescription(props) {
    if (props.renderIcon && !props.children && !props.iconDescription) {
      return new Error('renderIcon property specified without also providing an iconDescription property.');
    }

    return undefined;
  },

  /**
   * Specify whether the Button is expressive, or not
   */
  isExpressive: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().bool),

  /**
   * Specify whether the Button is currently selected. Only applies to the Ghost variant.
   */
  isSelected: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().bool),

  /**
   * Specify the kind of Button you want to create
   */
  kind: prop_types__WEBPACK_IMPORTED_MODULE_14___default().oneOf(_prop_types_types__WEBPACK_IMPORTED_MODULE_15__.ButtonKinds),

  /**
   * Provide an optional function to be called when the button element
   * loses focus
   */
  onBlur: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().func),

  /**
   * Provide an optional function to be called when the button element
   * is clicked
   */
  onClick: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().func),

  /**
   * Provide an optional function to be called when the button element
   * receives focus
   */
  onFocus: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().func),

  /**
   * Provide an optional function to be called when the mouse
   * enters the button element
   */
  onMouseEnter: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().func),

  /**
   * Provide an optional function to be called when the mouse
   * leaves the button element
   */
  onMouseLeave: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().func),

  /**
   * Optional prop to allow overriding the icon rendering.
   * Can be a React component class
   */
  renderIcon: prop_types__WEBPACK_IMPORTED_MODULE_14___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_14___default().func), (prop_types__WEBPACK_IMPORTED_MODULE_14___default().object)]),

  /**
   * Optional prop to specify the role of the Button
   */
  role: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().string),

  /**
   * Specify the size of the button, from the following list of sizes:
   */
  size: _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_6__.enabled('enable-v11-release') ? prop_types__WEBPACK_IMPORTED_MODULE_14___default().oneOf(['sm', 'md', 'lg', 'xl', '2xl']) : prop_types__WEBPACK_IMPORTED_MODULE_14___default().oneOf(['default', 'field', 'small', 'sm', 'md', 'lg', 'xl', '2xl']),

  /**
   * Deprecated in v10 in favor of `size`.
   * Specify whether the Button should be a small variant
   */
  small: (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_16__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_14___default().bool), "\nThe prop `small` for Button has been deprecated in favor of `size`. Please use `size=\"sm\"` instead."),

  /**
   * Optional prop to specify the tabIndex of the Button
   */
  tabIndex: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().number),

  /**
   * Specify the alignment of the tooltip to the icon-only button.
   * Can be one of: start, center, or end.
   */
  tooltipAlignment: prop_types__WEBPACK_IMPORTED_MODULE_14___default().oneOf(['start', 'center', 'end']),

  /**
   * Specify the direction of the tooltip for icon-only buttons.
   * Can be either top, right, bottom, or left.
   */
  tooltipPosition: prop_types__WEBPACK_IMPORTED_MODULE_14___default().oneOf(['top', 'right', 'bottom', 'left']),

  /**
   * Optional prop to specify the type of the Button
   */
  type: prop_types__WEBPACK_IMPORTED_MODULE_14___default().oneOf(['button', 'reset', 'submit'])
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Button);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/ButtonSet/ButtonSet.js":
/*!***************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/ButtonSet/ButtonSet.js ***!
  \***************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_6__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");



var _excluded = ["children", "className", "stacked"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */




var ButtonSet = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().forwardRef(function ButtonSet(_ref, ref) {
  var children = _ref.children,
      className = _ref.className,
      stacked = _ref.stacked,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  var buttonSetClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()(className, "".concat(prefix, "--btn-set"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--btn-set--stacked"), stacked));
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, rest, {
    className: buttonSetClasses,
    ref: ref
  }), children);
});
ButtonSet.displayName = 'ButtonSet';
ButtonSet.propTypes = {
  /**
   * Specify the content of your ButtonSet
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().node),

  /**
   * Specify an optional className to be added to your ButtonSet
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().string),

  /**
   * Specify the button arrangement of the set (vertically stacked or
   * horizontal)
   */
  stacked: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool)
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ButtonSet);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Checkbox/Checkbox.js":
/*!*************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Checkbox/Checkbox.js ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _Text__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../Text */ "../../node_modules/carbon-components-react/es/components/Text/Text.js");
/* harmony import */ var _FeatureFlags__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../FeatureFlags */ "../../node_modules/carbon-components-react/es/components/FeatureFlags/index.js");
/* harmony import */ var _prop_types_deprecate__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../../prop-types/deprecate */ "../../node_modules/carbon-components-react/es/prop-types/deprecate.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");



var _excluded = ["className", "id", "labelText", "onChange", "indeterminate", "hideLabel", "wrapperClassName", "title"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */







var Checkbox = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().forwardRef(function Checkbox(_ref, _ref2) {
  var className = _ref.className,
      id = _ref.id,
      labelText = _ref.labelText,
      _onChange = _ref.onChange,
      indeterminate = _ref.indeterminate,
      hideLabel = _ref.hideLabel,
      wrapperClassName = _ref.wrapperClassName,
      _ref$title = _ref.title,
      title = _ref$title === void 0 ? '' : _ref$title,
      other = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var enabled = (0,_FeatureFlags__WEBPACK_IMPORTED_MODULE_5__.useFeatureFlag)('enable-v11-release');
  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_6__.usePrefix)();
  var labelClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--checkbox-label"), [enabled ? null : className]);
  var innerLabelClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--checkbox-label-text"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--visually-hidden"), hideLabel));
  var wrapperClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--form-item"), "".concat(prefix, "--checkbox-wrapper"), [enabled ? className : wrapperClassName]);
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: wrapperClasses
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("input", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, other, {
    type: "checkbox",
    onChange: function onChange(evt) {
      if (enabled) {
        _onChange(evt, {
          checked: evt.target.checked,
          id: id
        });
      } else {
        _onChange(evt.target.checked, id, evt);
      }
    },
    className: "".concat(prefix, "--checkbox"),
    id: id,
    ref: function ref(el) {
      if (el) {
        el.indeterminate = indeterminate;
      }

      if (typeof _ref2 === 'function') {
        _ref2(el);
      } else if (Object(_ref2) === _ref2) {
        _ref2.current = el;
      }
    }
  })), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("label", {
    htmlFor: id,
    className: labelClasses,
    title: title || null
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_Text__WEBPACK_IMPORTED_MODULE_7__.Text, {
    className: innerLabelClasses
  }, labelText)));
});
Checkbox.propTypes = {
  /**
   * Specify whether the underlying input should be checked
   */
  checked: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().bool),

  /**
   * Specify an optional className to be applied to the <label> node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().string),

  /**
   * Specify whether the underlying input should be checked by default
   */
  defaultChecked: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().bool),

  /**
   * Specify whether the Checkbox should be disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().bool),

  /**
   * Specify whether the label should be hidden, or not
   */
  hideLabel: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().bool),

  /**
   * Provide an `id` to uniquely identify the Checkbox input
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().string.isRequired),

  /**
   * Specify whether the Checkbox is in an indeterminate state
   */
  indeterminate: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().bool),

  /**
   * Provide a label to provide a description of the Checkbox input that you are
   * exposing to the user
   */
  labelText: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().node.isRequired),

  /**
   * Receives three arguments: true/false, the checkbox's id, and the dom event.
   * `(value, id, event) => console.log({value, id, event})`
   */
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().func),

  /**
   * Specify a title for the <label> node for the Checkbox
   */
  title: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().string),

  /**
   * The CSS class name to be placed on the wrapping element
   */
  wrapperClassName: (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_9__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_8___default().string), "\nThe prop `wrapperClassName` for Checkbox will be deprecated in V11 in favor of `className`. `className` will then be placed on the outer wrapper.")
};
Checkbox.defaultProps = {
  onChange: function onChange() {},
  indeterminate: false
};
Checkbox.displayName = 'Checkbox';
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Checkbox);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/ComboBox/ComboBox.js":
/*!*************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/ComboBox/ComboBox.js ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var downshift__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! downshift */ "../../node_modules/carbon-components-react/node_modules/downshift/dist/downshift.esm.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_20___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_20__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var _Text__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../Text */ "../../node_modules/carbon-components-react/es/components/Text/Text.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-29.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var _ListBox__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../ListBox */ "../../node_modules/carbon-components-react/es/components/ListBox/index.js");
/* harmony import */ var _ListBox__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ../ListBox */ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxPropTypes.js");
/* harmony import */ var _ListBox_next__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ../ListBox/next */ "../../node_modules/carbon-components-react/es/components/ListBox/next/ListBoxSelection.js");
/* harmony import */ var _ListBox_next__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ../ListBox/next */ "../../node_modules/carbon-components-react/es/components/ListBox/next/ListBoxTrigger.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/match.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/keys.js");
/* harmony import */ var _tools_setupGetInstanceId__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../tools/setupGetInstanceId */ "../../node_modules/carbon-components-react/es/tools/setupGetInstanceId.js");
/* harmony import */ var _tools_createPropAdapter__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../../tools/createPropAdapter */ "../../node_modules/carbon-components-react/es/tools/createPropAdapter.js");
/* harmony import */ var _tools_mergeRefs__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ../../tools/mergeRefs */ "../../node_modules/carbon-components-react/es/tools/mergeRefs.js");
/* harmony import */ var _FeatureFlags__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../FeatureFlags */ "../../node_modules/carbon-components-react/es/components/FeatureFlags/index.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");




var _excluded = ["ariaLabel", "className", "direction", "disabled", "downshiftProps", "helperText", "id", "initialSelectedItem", "invalid", "invalidText", "items", "itemToElement", "itemToString", "light", "onChange", "onInputChange", "onToggleClick", "placeholder", "selectedItem", "shouldFilterItem", "size", "titleText", "translateWithId", "type", "warn", "warnText", "onStateChange"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */















var defaultItemToString = function defaultItemToString(item) {
  if (typeof item === 'string') {
    return item;
  }

  return item && item.label;
};

var defaultShouldFilterItem = function defaultShouldFilterItem() {
  return true;
};

var getInputValue = function getInputValue(_ref) {
  var initialSelectedItem = _ref.initialSelectedItem,
      inputValue = _ref.inputValue,
      itemToString = _ref.itemToString,
      selectedItem = _ref.selectedItem;

  if (selectedItem) {
    return itemToString(selectedItem);
  } // TODO: consistent `initialSelectedItem` behavior with other listbox components in v11


  if (initialSelectedItem) {
    return itemToString(initialSelectedItem);
  }

  return inputValue || '';
};

var findHighlightedIndex = function findHighlightedIndex(_ref2, inputValue) {
  var items = _ref2.items,
      itemToString = _ref2.itemToString;

  if (!inputValue) {
    return -1;
  }

  var searchValue = inputValue.toLowerCase();

  for (var i = 0; i < items.length; i++) {
    var item = itemToString(items[i]).toLowerCase();

    if (item.indexOf(searchValue) !== -1) {
      return i;
    }
  }

  return -1;
};

var getInstanceId = (0,_tools_setupGetInstanceId__WEBPACK_IMPORTED_MODULE_6__["default"])();
var ComboBox = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().forwardRef(function (props, ref) {
  var _cx;

  var ariaLabel = props.ariaLabel,
      containerClassName = props.className,
      direction = props.direction,
      disabled = props.disabled,
      downshiftProps = props.downshiftProps,
      helperText = props.helperText,
      id = props.id,
      initialSelectedItem = props.initialSelectedItem,
      invalid = props.invalid,
      invalidText = props.invalidText,
      items = props.items,
      itemToElement = props.itemToElement,
      itemToString = props.itemToString,
      light = props.light,
      onChange = props.onChange,
      onInputChange = props.onInputChange,
      onToggleClick = props.onToggleClick,
      placeholder = props.placeholder,
      selectedItem = props.selectedItem,
      shouldFilterItem = props.shouldFilterItem,
      size = props.size,
      titleText = props.titleText,
      translateWithId = props.translateWithId,
      type = props.type,
      warn = props.warn,
      warnText = props.warnText,
      onStateChange = props.onStateChange,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_3__["default"])(props, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_7__.usePrefix)();
  var textInput = (0,react__WEBPACK_IMPORTED_MODULE_5__.useRef)();
  var comboBoxInstanceId = getInstanceId();

  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(getInputValue({
    initialSelectedItem: initialSelectedItem,
    inputValue: '',
    itemToString: itemToString,
    selectedItem: selectedItem
  })),
      _useState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState, 2),
      inputValue = _useState2[0],
      setInputValue = _useState2[1];

  var _useState3 = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(null),
      _useState4 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState3, 2),
      prevSelectedItem = _useState4[0],
      setPrevSelectedItem = _useState4[1];

  var _useState5 = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(null),
      _useState6 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState5, 2),
      doneInitialSelectedItem = _useState6[0],
      setDoneInitialSelectedItem = _useState6[1];

  var savedOnInputChange = (0,react__WEBPACK_IMPORTED_MODULE_5__.useRef)(onInputChange);

  if (!doneInitialSelectedItem || prevSelectedItem !== selectedItem) {
    setDoneInitialSelectedItem(true);
    setPrevSelectedItem(selectedItem);
    setInputValue(getInputValue({
      initialSelectedItem: initialSelectedItem,
      inputValue: inputValue,
      itemToString: itemToString,
      selectedItem: selectedItem
    }));
  }

  var filterItems = function filterItems(items, itemToString, inputValue) {
    return items.filter(function (item) {
      return shouldFilterItem({
        item: item,
        itemToString: itemToString,
        inputValue: inputValue
      });
    });
  };

  var handleOnChange = function handleOnChange(selectedItem) {
    if (onChange) {
      onChange({
        selectedItem: selectedItem
      });
    }
  };

  var handleOnInputValueChange = function handleOnInputValueChange(inputValue) {
    setInputValue(inputValue || '');
  };

  (0,react__WEBPACK_IMPORTED_MODULE_5__.useEffect)(function () {
    savedOnInputChange.current = onInputChange;
  }, [onInputChange]);
  (0,react__WEBPACK_IMPORTED_MODULE_5__.useEffect)(function () {
    if (savedOnInputChange.current) {
      savedOnInputChange.current(inputValue);
    }
  }, [inputValue]);

  var handleSelectionClear = function handleSelectionClear() {
    if (textInput !== null && textInput !== void 0 && textInput.current) {
      textInput.current.focus();
    }
  };

  var handleOnStateChange = function handleOnStateChange(newState, _ref3) {
    var setHighlightedIndex = _ref3.setHighlightedIndex;

    if (Object.prototype.hasOwnProperty.call(newState, 'inputValue')) {
      var _inputValue = newState.inputValue;
      var filteredItems = filterItems(items, itemToString, _inputValue);
      setHighlightedIndex(findHighlightedIndex(_objectSpread(_objectSpread({}, props), {}, {
        items: filteredItems
      }), _inputValue));
    }
  };

  var handleToggleClick = function handleToggleClick(isOpen) {
    return function (event) {
      if (onToggleClick) {
        onToggleClick(event);
      }

      if (event.target === textInput.current && isOpen) {
        event.preventDownshiftDefault = true;
        event.persist();
      }
    };
  };

  var enabled = (0,_FeatureFlags__WEBPACK_IMPORTED_MODULE_8__.useFeatureFlag)('enable-v11-release');
  var showWarning = !invalid && warn;
  var className = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--combo-box"), [enabled ? null : containerClassName], (_cx = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--list-box--up"), direction === 'top'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--combo-box--warning"), showWarning), _cx));
  var titleClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--label"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--label--disabled"), disabled));
  var comboBoxHelperId = !helperText ? undefined : "combobox-helper-text-".concat(comboBoxInstanceId);
  var helperClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--form__helper-text"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--form__helper-text--disabled"), disabled));
  var wrapperClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--list-box__wrapper"), [enabled ? containerClassName : null]);
  var inputClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--text-input"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--text-input--empty"), !inputValue)); // needs to be Capitalized for react to render it correctly

  var ItemToElement = itemToElement;
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(downshift__WEBPACK_IMPORTED_MODULE_9__["default"], (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, (0,_tools_createPropAdapter__WEBPACK_IMPORTED_MODULE_10__.mapDownshiftProps)(downshiftProps), {
    onChange: handleOnChange,
    onInputValueChange: handleOnInputValueChange,
    onStateChange: function onStateChange() {
      var _downshiftProps$onSta;

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      handleOnStateChange.apply(void 0, args);
      downshiftProps === null || downshiftProps === void 0 ? void 0 : (_downshiftProps$onSta = downshiftProps.onStateChange) === null || _downshiftProps$onSta === void 0 ? void 0 : _downshiftProps$onSta.call.apply(_downshiftProps$onSta, [downshiftProps].concat(args));
    },
    inputValue: inputValue || '',
    itemToString: itemToString,
    initialSelectedItem: initialSelectedItem,
    inputId: id,
    selectedItem: selectedItem
  }), function (_ref4) {
    var _textInput$current;

    var getInputProps = _ref4.getInputProps,
        getItemProps = _ref4.getItemProps,
        getLabelProps = _ref4.getLabelProps,
        getMenuProps = _ref4.getMenuProps,
        getRootProps = _ref4.getRootProps,
        getToggleButtonProps = _ref4.getToggleButtonProps,
        isOpen = _ref4.isOpen,
        inputValue = _ref4.inputValue,
        selectedItem = _ref4.selectedItem,
        highlightedIndex = _ref4.highlightedIndex,
        clearSelection = _ref4.clearSelection,
        toggleMenu = _ref4.toggleMenu;
    var rootProps = getRootProps({}, {
      suppressRefError: true
    });
    var labelProps = getLabelProps();
    var buttonProps = getToggleButtonProps({
      disabled: disabled,
      onClick: handleToggleClick(isOpen),
      // When we moved the "root node" of Downshift to the <input> for
      // ARIA 1.2 compliance, we unfortunately hit this branch for the
      // "mouseup" event that downshift listens to:
      // https://github.com/downshift-js/downshift/blob/v5.2.1/src/downshift.js#L1051-L1065
      //
      // As a result, it will reset the state of the component and so we
      // stop the event from propagating to prevent this if the menu is already open.
      // This allows the toggleMenu behavior for the toggleButton to correctly open and
      // close the menu.
      onMouseUp: function onMouseUp(event) {
        if (isOpen) {
          event.stopPropagation();
        }
      }
    });
    var inputProps = getInputProps({
      // Remove excess aria `aria-labelledby`. HTML <label for> provides this aria information.
      'aria-labelledby': null,
      disabled: disabled,
      placeholder: placeholder,
      onClick: function onClick() {
        toggleMenu();
      },
      onKeyDown: function onKeyDown(event) {
        if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_11__.match)(event, _internal_keyboard__WEBPACK_IMPORTED_MODULE_12__.Space)) {
          event.stopPropagation();
        }

        if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_11__.match)(event, _internal_keyboard__WEBPACK_IMPORTED_MODULE_12__.Enter) && !inputValue) {
          toggleMenu();
        }
      }
    });
    return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("div", {
      className: wrapperClasses
    }, titleText && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_Text__WEBPACK_IMPORTED_MODULE_13__.Text, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
      as: "label",
      className: titleClasses
    }, labelProps), titleText), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_14__["default"], {
      className: className,
      disabled: disabled,
      invalid: invalid,
      invalidText: invalidText,
      isOpen: isOpen,
      light: light,
      size: size,
      warn: warn,
      warnText: warnText
    }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("div", {
      className: "".concat(prefix, "--list-box__field")
    }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("input", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
      role: "combobox",
      disabled: disabled,
      className: inputClasses,
      type: "text",
      tabIndex: "0",
      "aria-autocomplete": "list",
      "aria-expanded": rootProps['aria-expanded'],
      "aria-haspopup": "listbox",
      "aria-controls": inputProps['aria-controls'],
      title: textInput === null || textInput === void 0 ? void 0 : (_textInput$current = textInput.current) === null || _textInput$current === void 0 ? void 0 : _textInput$current.value
    }, inputProps, rest, {
      ref: (0,_tools_mergeRefs__WEBPACK_IMPORTED_MODULE_15__["default"])(textInput, ref)
    })), invalid && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_16__.WarningFilled16, {
      className: "".concat(prefix, "--list-box__invalid-icon")
    }), showWarning && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_16__.WarningAltFilled16, {
      className: "".concat(prefix, "--list-box__invalid-icon ").concat(prefix, "--list-box__invalid-icon--warning")
    }), inputValue && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_ListBox_next__WEBPACK_IMPORTED_MODULE_17__["default"], {
      clearSelection: clearSelection,
      translateWithId: translateWithId,
      disabled: disabled,
      onClearSelection: handleSelectionClear
    }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_ListBox_next__WEBPACK_IMPORTED_MODULE_18__["default"], (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, buttonProps, {
      isOpen: isOpen,
      translateWithId: translateWithId
    }))), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_14__["default"].Menu, getMenuProps({
      'aria-label': ariaLabel
    }), isOpen ? filterItems(items, itemToString, inputValue).map(function (item, index) {
      var _getItemProps;

      var itemProps = getItemProps((_getItemProps = {
        item: item,
        index: index
      }, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_getItemProps, 'aria-current', selectedItem === item ? true : null), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_getItemProps, 'aria-selected', highlightedIndex === index ? true : null), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_getItemProps, "disabled", item.disabled), _getItemProps));
      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_14__["default"].MenuItem, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
        key: itemProps.id,
        isActive: selectedItem === item,
        tabIndex: "-1",
        isHighlighted: highlightedIndex === index || (selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.id) && (selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.id) === item.id || false,
        title: itemToElement ? item.text : itemToString(item)
      }, itemProps), itemToElement ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(ItemToElement, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
        key: itemProps.id
      }, item)) : itemToString(item), selectedItem === item && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_19__.Checkmark16, {
        className: "".concat(prefix, "--list-box__menu-item__selected-icon")
      }));
    }) : null)), helperText && !invalid && !warn && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_Text__WEBPACK_IMPORTED_MODULE_13__.Text, {
      as: "div",
      id: comboBoxHelperId,
      className: helperClasses
    }, helperText));
  });
});
ComboBox.displayName = 'ComboBox';
ComboBox.propTypes = {
  /**
   * 'aria-label' of the ListBox component.
   */
  ariaLabel: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().string),

  /**
   * An optional className to add to the container node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().string),

  /**
   * Specify the direction of the combobox dropdown. Can be either top or bottom.
   */
  direction: prop_types__WEBPACK_IMPORTED_MODULE_20___default().oneOf(['top', 'bottom']),

  /**
   * Specify if the control should be disabled, or not
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().bool),

  /**
   * Additional props passed to Downshift
   */
  downshiftProps: prop_types__WEBPACK_IMPORTED_MODULE_20___default().shape(downshift__WEBPACK_IMPORTED_MODULE_9__["default"].propTypes),

  /**
   * Provide helper text that is used alongside the control label for
   * additional help
   */
  helperText: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().string),

  /**
   * Specify a custom `id` for the input
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().string.isRequired),

  /**
   * Allow users to pass in an arbitrary item or a string (in case their items are an array of strings)
   * from their collection that are pre-selected
   */
  initialSelectedItem: prop_types__WEBPACK_IMPORTED_MODULE_20___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_20___default().object), (prop_types__WEBPACK_IMPORTED_MODULE_20___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_20___default().number)]),

  /**
   * Specify if the currently selected value is invalid.
   */
  invalid: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().bool),

  /**
   * Message which is displayed if the value is invalid.
   */
  invalidText: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().node),

  /**
   * Optional function to render items as custom components instead of strings.
   * Defaults to null and is overridden by a getter
   */
  itemToElement: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().func),

  /**
   * Helper function passed to downshift that allows the library to render a
   * given item to a string label. By default, it extracts the `label` field
   * from a given item to serve as the item label in the list
   */
  itemToString: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().func),

  /**
   * We try to stay as generic as possible here to allow individuals to pass
   * in a collection of whatever kind of data structure they prefer
   */
  items: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().array.isRequired),

  /**
   * should use "light theme" (white background)?
   */
  light: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().bool),

  /**
   * `onChange` is a utility for this controlled component to communicate to a
   * consuming component when a specific dropdown item is selected.
   * @param {{ selectedItem }}
   */
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().func.isRequired),

  /**
   * Callback function to notify consumer when the text input changes.
   * This provides support to change available items based on the text.
   * @param {string} inputText
   */
  onInputChange: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().func),

  /**
   * Helper function passed to Downshift that allows the user to observe internal
   * state changes
   */
  onStateChange: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().func),

  /**
   * Callback function that fires when the combobox menu toggle is clicked
   * @param {MouseEvent} event
   */
  onToggleClick: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().func),

  /**
   * Used to provide a placeholder text node before a user enters any input.
   * This is only present if the control has no items selected
   */
  placeholder: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().string),

  /**
   * For full control of the selection
   */
  selectedItem: prop_types__WEBPACK_IMPORTED_MODULE_20___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_20___default().object), (prop_types__WEBPACK_IMPORTED_MODULE_20___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_20___default().number)]),

  /**
   * Specify your own filtering logic by passing in a `shouldFilterItem`
   * function that takes in the current input and an item and passes back
   * whether or not the item should be filtered.
   */
  shouldFilterItem: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().func),

  /**
   * Specify the size of the ListBox. Currently supports either `sm`, `md` or `lg` as an option.
   */
  size: _ListBox__WEBPACK_IMPORTED_MODULE_21__.ListBoxSize,

  /**
   * Provide text to be used in a `<label>` element that is tied to the
   * combobox via ARIA attributes.
   */
  titleText: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().node),

  /**
   * Specify a custom translation function that takes in a message identifier
   * and returns the localized string for the message
   */
  translateWithId: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().func),

  /**
   * Currently supports either the default type, or an inline variant
   */
  type: _ListBox__WEBPACK_IMPORTED_MODULE_21__.ListBoxType,

  /**
   * Specify whether the control is currently in warning state
   */
  warn: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().bool),

  /**
   * Provide the text that is displayed when the control is in warning state
   */
  warnText: (prop_types__WEBPACK_IMPORTED_MODULE_20___default().node)
};
ComboBox.defaultProps = {
  disabled: false,
  itemToString: defaultItemToString,
  itemToElement: null,
  shouldFilterItem: defaultShouldFilterItem,
  type: 'default',
  ariaLabel: 'Choose an item',
  light: false,
  direction: 'bottom'
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ComboBox);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/ComboBox/tools/filter.js":
/*!*****************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/ComboBox/tools/filter.js ***!
  \*****************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "defaultFilterItems": () => (/* binding */ defaultFilterItems)
/* harmony export */ });
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
var defaultFilterItems = function defaultFilterItems(items, _ref) {
  var itemToString = _ref.itemToString,
      inputValue = _ref.inputValue;
  return items.filter(function (item) {
    if (!inputValue) {
      return true;
    }

    return itemToString(item).toLowerCase().includes(inputValue.toLowerCase());
  });
};

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/ContentSwitcher/ContentSwitcher.js":
/*!***************************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/ContentSwitcher/ContentSwitcher.js ***!
  \***************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ ContentSwitcher)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_15___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_15__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_10___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_10__);
/* harmony import */ var _prop_types_deprecate__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ../../prop-types/deprecate */ "../../node_modules/carbon-components-react/es/prop-types/deprecate.js");
/* harmony import */ var _tools_events__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../../tools/events */ "../../node_modules/carbon-components-react/es/tools/events.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/match.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/keys.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/navigation.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");









var _excluded = ["children", "className", "light", "selectedIndex", "selectionMode", "size"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__["default"])(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__["default"])(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_6__["default"])(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */








var ContentSwitcher = /*#__PURE__*/function (_React$Component) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(ContentSwitcher, _React$Component);

  var _super = _createSuper(ContentSwitcher);

  function ContentSwitcher() {
    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ContentSwitcher);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _super.call.apply(_super, [this].concat(args));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_switchRefs", []);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "state", {});

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "handleItemRef", function (index) {
      return function (ref) {
        _this._switchRefs[index] = ref;
      };
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "handleChildChange", function (data) {
      var selectionMode = _this.props.selectionMode; // the currently selected child index

      var selectedIndex = _this.state.selectedIndex; // the newly selected child index

      var index = data.index;
      var key = data.key;

      if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_11__.matches)(data, [_internal_keyboard__WEBPACK_IMPORTED_MODULE_12__.ArrowRight, _internal_keyboard__WEBPACK_IMPORTED_MODULE_12__.ArrowLeft])) {
        var nextIndex = (0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_13__.getNextIndex)(key, index, _this.props.children.length);
        var children = react__WEBPACK_IMPORTED_MODULE_9___default().Children.toArray(_this.props.children);

        if (selectionMode === 'manual') {
          var switchRef = _this._switchRefs[nextIndex];
          switchRef && switchRef.focus();
        } else {
          _this.setState({
            selectedIndex: nextIndex
          }, function () {
            var child = children[_this.state.selectedIndex];
            var switchRef = _this._switchRefs[_this.state.selectedIndex];
            switchRef && switchRef.focus();

            _this.props.onChange(_objectSpread(_objectSpread({}, data), {}, {
              index: _this.state.selectedIndex,
              name: child.props.name,
              text: child.props.text
            }));
          });
        }
      } else if (selectedIndex !== index) {
        _this.setState({
          selectedIndex: index
        }, function () {
          var switchRef = _this._switchRefs[index];
          switchRef && switchRef.focus();

          _this.props.onChange(data);
        });
      }
    });

    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ContentSwitcher, [{
    key: "render",
    value: function render() {
      var _classNames,
          _this2 = this;

      var prefix = this.context;

      var _this$props = this.props,
          children = _this$props.children,
          className = _this$props.className,
          light = _this$props.light,
          selectedIndex = _this$props.selectedIndex,
          selectionMode = _this$props.selectionMode,
          size = _this$props.size,
          other = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_this$props, _excluded);

      var classes = classnames__WEBPACK_IMPORTED_MODULE_10___default()("".concat(prefix, "--content-switcher"), className, (_classNames = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--content-switcher--light"), light), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--content-switcher--").concat(size), size), _classNames));
      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, other, {
        className: classes,
        role: "tablist"
      }), react__WEBPACK_IMPORTED_MODULE_9___default().Children.map(children, function (child, index) {
        return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().cloneElement(child, {
          index: index,
          onClick: (0,_tools_events__WEBPACK_IMPORTED_MODULE_14__.composeEventHandlers)([_this2.handleChildChange, child.props.onClick]),
          onKeyDown: _this2.handleChildChange,
          selected: index === _this2.state.selectedIndex,
          ref: _this2.handleItemRef(index)
        });
      }));
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(_ref, state) {
      var selectedIndex = _ref.selectedIndex;
      var prevSelectedIndex = state.prevSelectedIndex;
      return prevSelectedIndex === selectedIndex ? null : {
        selectedIndex: selectedIndex,
        prevSelectedIndex: selectedIndex
      };
    }
  }]);

  return ContentSwitcher;
}((react__WEBPACK_IMPORTED_MODULE_9___default().Component));

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(ContentSwitcher, "propTypes", {
  /**
   * Pass in Switch components to be rendered in the ContentSwitcher
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_15___default().node),

  /**
   * Specify an optional className to be added to the container node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_15___default().string),

  /**
   * `true` to use the light variant.
   */
  light: (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_16__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_15___default().bool), 'The `light` prop for `ContentSwitcher` is no longer needed and has ' + 'been deprecated. It will be removed in the next major release.'),

  /**
   * Specify an `onChange` handler that is called whenever the ContentSwitcher
   * changes which item is selected
   */
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_15___default().func.isRequired),

  /**
   * Specify a selected index for the initially selected content
   */
  selectedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_15___default().number),

  /**
   * Choose whether or not to automatically change selection on focus
   */
  selectionMode: prop_types__WEBPACK_IMPORTED_MODULE_15___default().oneOf(['automatic', 'manual']),

  /**
   * Specify the size of the Content Switcher. Currently supports either `sm`, 'md' (default) or 'lg` as an option.
   * TODO V11: remove `xl` (replaced with lg)
   */
  size: prop_types__WEBPACK_IMPORTED_MODULE_15___default().oneOf(['sm', 'md', 'lg', 'xl'])
});

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(ContentSwitcher, "contextType", _internal_usePrefix__WEBPACK_IMPORTED_MODULE_17__.PrefixContext);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(ContentSwitcher, "defaultProps", {
  selectedIndex: 0,
  selectionMode: 'automatic',
  onChange: function onChange() {}
});



/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Dropdown/Dropdown.js":
/*!*************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Dropdown/Dropdown.js ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var downshift__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! downshift */ "../../node_modules/carbon-components-react/node_modules/downshift/dist/downshift.esm.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_13___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_13__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-29.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var _ListBox__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../ListBox */ "../../node_modules/carbon-components-react/es/components/ListBox/index.js");
/* harmony import */ var _ListBox__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ../ListBox */ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxPropTypes.js");
/* harmony import */ var _tools_createPropAdapter__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../tools/createPropAdapter */ "../../node_modules/carbon-components-react/es/tools/createPropAdapter.js");
/* harmony import */ var _tools_mergeRefs__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../tools/mergeRefs */ "../../node_modules/carbon-components-react/es/tools/mergeRefs.js");
/* harmony import */ var _prop_types_deprecate__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../../prop-types/deprecate */ "../../node_modules/carbon-components-react/es/prop-types/deprecate.js");
/* harmony import */ var _FeatureFlags__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../FeatureFlags */ "../../node_modules/carbon-components-react/es/components/FeatureFlags/index.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");



var _excluded = ["className", "disabled", "direction", "items", "label", "ariaLabel", "itemToString", "itemToElement", "renderSelectedItem", "type", "size", "onChange", "id", "titleText", "hideLabel", "helperText", "translateWithId", "light", "invalid", "invalidText", "warn", "warnText", "initialSelectedItem", "selectedItem", "downshiftProps"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */












var defaultItemToString = function defaultItemToString(item) {
  if (typeof item === 'string') {
    return item;
  }

  return item ? item.label : '';
};

var Dropdown = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().forwardRef(function Dropdown(_ref, ref) {
  var _cx, _cx2, _cx4;

  var containerClassName = _ref.className,
      disabled = _ref.disabled,
      direction = _ref.direction,
      items = _ref.items,
      label = _ref.label,
      ariaLabel = _ref.ariaLabel,
      itemToString = _ref.itemToString,
      itemToElement = _ref.itemToElement,
      renderSelectedItem = _ref.renderSelectedItem,
      type = _ref.type,
      size = _ref.size,
      onChange = _ref.onChange,
      id = _ref.id,
      titleText = _ref.titleText,
      hideLabel = _ref.hideLabel,
      helperText = _ref.helperText,
      translateWithId = _ref.translateWithId,
      light = _ref.light,
      invalid = _ref.invalid,
      invalidText = _ref.invalidText,
      warn = _ref.warn,
      warnText = _ref.warnText,
      initialSelectedItem = _ref.initialSelectedItem,
      controlledSelectedItem = _ref.selectedItem,
      downshiftProps = _ref.downshiftProps,
      other = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  var selectProps = (0,_tools_createPropAdapter__WEBPACK_IMPORTED_MODULE_6__.mapDownshiftProps)(_objectSpread(_objectSpread({}, downshiftProps), {}, {
    items: items,
    itemToString: itemToString,
    initialSelectedItem: initialSelectedItem,
    onSelectedItemChange: onSelectedItemChange
  })); // only set selectedItem if the prop is defined. Setting if it is undefined
  // will overwrite default selected items from useSelect

  if (controlledSelectedItem !== undefined) {
    selectProps.selectedItem = controlledSelectedItem;
  }

  var _useSelect = (0,downshift__WEBPACK_IMPORTED_MODULE_7__.useSelect)(selectProps),
      isOpen = _useSelect.isOpen,
      getToggleButtonProps = _useSelect.getToggleButtonProps,
      getLabelProps = _useSelect.getLabelProps,
      getMenuProps = _useSelect.getMenuProps,
      getItemProps = _useSelect.getItemProps,
      highlightedIndex = _useSelect.highlightedIndex,
      selectedItem = _useSelect.selectedItem;

  var inline = type === 'inline';
  var showWarning = !invalid && warn;
  var enabled = (0,_FeatureFlags__WEBPACK_IMPORTED_MODULE_8__.useFeatureFlag)('enable-v11-release');
  var className = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--dropdown"), [enabled ? null : containerClassName], (_cx = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--dropdown--invalid"), invalid), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--dropdown--warning"), showWarning), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--dropdown--open"), isOpen), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--dropdown--inline"), inline), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--dropdown--disabled"), disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--dropdown--light"), light), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--dropdown--").concat(size), size), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--list-box--up"), direction === 'top'), _cx));
  var titleClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--label"), (_cx2 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx2, "".concat(prefix, "--label--disabled"), disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx2, "".concat(prefix, "--visually-hidden"), hideLabel), _cx2));
  var helperClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--form__helper-text"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--form__helper-text--disabled"), disabled));
  var wrapperClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--dropdown__wrapper"), "".concat(prefix, "--list-box__wrapper"), [enabled ? containerClassName : null], (_cx4 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx4, "".concat(prefix, "--dropdown__wrapper--inline"), inline), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx4, "".concat(prefix, "--list-box__wrapper--inline"), inline), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx4, "".concat(prefix, "--dropdown__wrapper--inline--invalid"), inline && invalid), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx4, "".concat(prefix, "--list-box__wrapper--inline--invalid"), inline && invalid), _cx4)); // needs to be Capitalized for react to render it correctly

  var ItemToElement = itemToElement;
  var toggleButtonProps = getToggleButtonProps();
  var helper = helperText ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: helperClasses
  }, helperText) : null;

  function onSelectedItemChange(_ref2) {
    var selectedItem = _ref2.selectedItem;

    if (onChange) {
      onChange({
        selectedItem: selectedItem
      });
    }
  }

  var menuItemOptionRefs = (0,react__WEBPACK_IMPORTED_MODULE_3__.useRef)(items.map(function (_) {
    return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createRef();
  }));
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    className: wrapperClasses
  }, other), titleText && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("label", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    className: titleClasses
  }, getLabelProps()), titleText), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_9__["default"], {
    "aria-label": ariaLabel,
    size: size,
    className: className,
    invalid: invalid,
    invalidText: invalidText,
    warn: warn,
    warnText: warnText,
    light: light,
    isOpen: isOpen,
    id: id
  }, invalid && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_10__.WarningFilled16, {
    className: "".concat(prefix, "--list-box__invalid-icon")
  }), showWarning && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_10__.WarningAltFilled16, {
    className: "".concat(prefix, "--list-box__invalid-icon ").concat(prefix, "--list-box__invalid-icon--warning")
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("button", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    type: "button",
    className: "".concat(prefix, "--list-box__field"),
    disabled: disabled,
    "aria-disabled": disabled,
    title: selectedItem ? itemToString(selectedItem) : label
  }, toggleButtonProps, {
    ref: (0,_tools_mergeRefs__WEBPACK_IMPORTED_MODULE_11__["default"])(toggleButtonProps.ref, ref)
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("span", {
    className: "".concat(prefix, "--list-box__label")
  }, selectedItem ? renderSelectedItem ? renderSelectedItem(selectedItem) : itemToString(selectedItem) : label), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_9__["default"].MenuIcon, {
    isOpen: isOpen,
    translateWithId: translateWithId
  })), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_9__["default"].Menu, getMenuProps(), isOpen && items.map(function (item, index) {
    var _menuItemOptionRefs$c;

    var itemProps = getItemProps({
      item: item,
      index: index,
      disabled: item.disabled
    });
    var title = itemToElement ? item.text : itemToString(item);

    var _ref3 = (menuItemOptionRefs === null || menuItemOptionRefs === void 0 ? void 0 : (_menuItemOptionRefs$c = menuItemOptionRefs.current[index]) === null || _menuItemOptionRefs$c === void 0 ? void 0 : _menuItemOptionRefs$c.current) || {},
        offsetWidth = _ref3.offsetWidth,
        scrollWidth = _ref3.scrollWidth;

    return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_9__["default"].MenuItem, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
      key: itemProps.id,
      isActive: selectedItem === item,
      isHighlighted: highlightedIndex === index || selectedItem === item,
      title: offsetWidth < scrollWidth && title || undefined,
      ref: {
        menuItemOptionRef: menuItemOptionRefs.current[index]
      }
    }, itemProps), itemToElement ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(ItemToElement, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
      key: itemProps.id
    }, item)) : itemToString(item), selectedItem === item && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_12__.Checkmark16, {
      className: "".concat(prefix, "--list-box__menu-item__selected-icon")
    }));
  }))), !inline && !invalid && !warn && helper);
});
Dropdown.displayName = 'Dropdown';
Dropdown.propTypes = {
  /**
   * 'aria-label' of the ListBox component.
   */
  ariaLabel: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().string),

  /**
   * Provide a custom className to be applied on the bx--dropdown node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().string),

  /**
   * Specify the direction of the dropdown. Can be either top or bottom.
   */
  direction: prop_types__WEBPACK_IMPORTED_MODULE_13___default().oneOf(['top', 'bottom']),

  /**
   * Disable the control
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().bool),

  /**
   * Additional props passed to Downshift
   */
  downshiftProps: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().object),

  /**
   * Provide helper text that is used alongside the control label for
   * additional help
   */
  helperText: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().node),

  /**
   * Specify whether the title text should be hidden or not
   */
  hideLabel: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().bool),

  /**
   * Specify a custom `id`
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().string.isRequired),

  /**
   * Allow users to pass in an arbitrary item or a string (in case their items are an array of strings)
   * from their collection that are pre-selected
   */
  initialSelectedItem: prop_types__WEBPACK_IMPORTED_MODULE_13___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_13___default().object), (prop_types__WEBPACK_IMPORTED_MODULE_13___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_13___default().number)]),

  /**
   * Specify whether you want the inline version of this control
   */
  inline: (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_14__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_13___default().bool), "The `inline` prop has been deprecated and will\n    be removed in the next major release. To specify the inline variant of Dropdown, please use the `type` prop."),

  /**
   * Specify if the currently selected value is invalid.
   */
  invalid: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().bool),

  /**
   * Message which is displayed if the value is invalid.
   */
  invalidText: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().node),

  /**
   * Function to render items as custom components instead of strings.
   * Defaults to null and is overridden by a getter
   */
  itemToElement: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().func),

  /**
   * Helper function passed to downshift that allows the library to render a
   * given item to a string label. By default, it extracts the `label` field
   * from a given item to serve as the item label in the list.
   */
  itemToString: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().func),

  /**
   * We try to stay as generic as possible here to allow individuals to pass
   * in a collection of whatever kind of data structure they prefer
   */
  items: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().array.isRequired),

  /**
   * Generic `label` that will be used as the textual representation of what
   * this field is for
   */
  label: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().node.isRequired),

  /**
   * `true` to use the light version.
   */
  light: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().bool),

  /**
   * `onChange` is a utility for this controlled component to communicate to a
   * consuming component what kind of internal state changes are occurring.
   */
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().func),

  /**
   * An optional callback to render the currently selected item as a react element instead of only
   * as a string.
   */
  renderSelectedItem: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().func),

  /**
   * In the case you want to control the dropdown selection entirely.
   */
  selectedItem: prop_types__WEBPACK_IMPORTED_MODULE_13___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_13___default().object), (prop_types__WEBPACK_IMPORTED_MODULE_13___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_13___default().number)]),

  /**
   * Specify the size of the ListBox. Currently supports either `sm`, `md` or `lg` as an option.
   */
  size: _ListBox__WEBPACK_IMPORTED_MODULE_15__.ListBoxSize,

  /**
   * Provide the title text that will be read by a screen reader when
   * visiting this control
   */
  titleText: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().node),

  /**
   * Callback function for translating ListBoxMenuIcon SVG title
   */
  translateWithId: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().func),

  /**
   * The dropdown type, `default` or `inline`
   */
  type: _ListBox__WEBPACK_IMPORTED_MODULE_15__.ListBoxType,

  /**
   * Specify whether the control is currently in warning state
   */
  warn: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().bool),

  /**
   * Provide the text that is displayed when the control is in warning state
   */
  warnText: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().node)
};
Dropdown.defaultProps = {
  disabled: false,
  type: 'default',
  itemToString: defaultItemToString,
  itemToElement: null,
  light: false,
  titleText: '',
  helperText: '',
  direction: 'bottom'
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Dropdown);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/FeatureFlags/index.js":
/*!**************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/FeatureFlags/index.js ***!
  \**************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "FeatureFlagContext": () => (/* binding */ FeatureFlagContext),
/* harmony export */   "FeatureFlags": () => (/* binding */ FeatureFlags),
/* harmony export */   "useFeatureFlag": () => (/* binding */ useFeatureFlag),
/* harmony export */   "useFeatureFlags": () => (/* binding */ useFeatureFlags)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @carbon/feature-flags */ "../../node_modules/@carbon/feature-flags/es/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_1__);


/**
 * Copyright IBM Corp. 2015, 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */



/**
 * Our FeatureFlagContext is used alongside the FeatureFlags component to enable
 * or disable feature flags in a given React tree
 */

var FeatureFlagContext = /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_1__.createContext)(_carbon_feature_flags__WEBPACK_IMPORTED_MODULE_2__.FeatureFlags);
/**
 * Supports an object of feature flag values with the `flags` prop, merging them
 * along with the current `FeatureFlagContext` to provide consumers to check if
 * a feature flag is enabled or disabled in a given React tree
 */

function FeatureFlags(_ref) {
  var children = _ref.children,
      _ref$flags = _ref.flags,
      flags = _ref$flags === void 0 ? {} : _ref$flags;
  var parentScope = (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(FeatureFlagContext);

  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(parentScope),
      _useState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__["default"])(_useState, 2),
      prevParentScope = _useState2[0],
      setPrevParentScope = _useState2[1];

  var _useState3 = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(function () {
    var scope = (0,_carbon_feature_flags__WEBPACK_IMPORTED_MODULE_2__.createScope)(flags);
    scope.mergeWithScope(parentScope);
    return scope;
  }),
      _useState4 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__["default"])(_useState3, 2),
      scope = _useState4[0],
      updateScope = _useState4[1];

  if (parentScope !== prevParentScope) {
    var _scope = (0,_carbon_feature_flags__WEBPACK_IMPORTED_MODULE_2__.createScope)(flags);

    _scope.mergeWithScope(parentScope);

    updateScope(_scope);
    setPrevParentScope(parentScope);
  } // We use a custom hook to detect if any of the keys or their values change
  // for flags that are passed in. If they have changed, then we re-create the
  // FeatureFlagScope using the new flags


  useChangedValue(flags, isEqual, function (changedFlags) {
    var scope = (0,_carbon_feature_flags__WEBPACK_IMPORTED_MODULE_2__.createScope)(changedFlags);
    scope.mergeWithScope(parentScope);
    updateScope(scope);
  });
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_1___default().createElement(FeatureFlagContext.Provider, {
    value: scope
  }, children);
}

FeatureFlags.propTypes = {
  children: (prop_types__WEBPACK_IMPORTED_MODULE_3___default().node),

  /**
   * Provide the feature flags to enabled or disabled in the current React tree
   */
  flags: prop_types__WEBPACK_IMPORTED_MODULE_3___default().objectOf((prop_types__WEBPACK_IMPORTED_MODULE_3___default().bool))
};
/**
 * This hook will store previous versions of the given `value` and compare the
 * current value to the previous one using the `compare` function. If the
 * compare function returns true, then the given `callback` is invoked in an
 * effect.
 *
 * @param {any} value
 * @param {Function} compare
 * @param {Function} callback
 */

function useChangedValue(value, compare, callback) {
  var initialRender = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(false);
  var savedCallback = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(callback);

  var _useState5 = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(value),
      _useState6 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__["default"])(_useState5, 2),
      prevValue = _useState6[0],
      setPrevValue = _useState6[1];

  if (!compare(prevValue, value)) {
    setPrevValue(value);
  }

  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(function () {
    savedCallback.current = callback;
  });
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(function () {
    // We only want the callback triggered after the first render
    if (initialRender.current) {
      savedCallback.current(prevValue);
    }
  }, [prevValue]);
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(function () {
    initialRender.current = true;
  }, []);
}
/**
 * Access whether a given flag is enabled or disabled in a given
 * FeatureFlagContext
 *
 * @returns {boolean}
 */


function useFeatureFlag(flag) {
  var scope = (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(FeatureFlagContext);
  return scope.enabled(flag);
}
/**
 * Access all feature flag information for the given FeatureFlagContext
 *
 * @returns {FeatureFlagScope}
 */


function useFeatureFlags() {
  return (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(FeatureFlagContext);
}
/**
 * Compare two objects and determine if they are equal. This is a shallow
 * comparison since the objects we are comparing are objects with boolean flags
 * from the flags prop in the `FeatureFlags` component
 *
 * @param {object} a
 * @param {object} b
 * @returns {boolean}
 */


function isEqual(a, b) {
  if (a === b) {
    return true;
  }

  for (var _i = 0, _Object$keys = Object.keys(a); _i < _Object$keys.length; _i++) {
    var key = _Object$keys[_i];

    if (a[key] !== b[key]) {
      return false;
    }
  }

  for (var _i2 = 0, _Object$keys2 = Object.keys(b); _i2 < _Object$keys2.length; _i2++) {
    var _key = _Object$keys2[_i2];

    if (b[_key] !== a[_key]) {
      return false;
    }
  }

  return true;
}



/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/FluidForm/FormContext.js":
/*!*****************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/FluidForm/FormContext.js ***!
  \*****************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "FormContext": () => (/* binding */ FormContext)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

var FormContext = /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_0__.createContext)({
  isFluid: false
});

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/InlineLoading/InlineLoading.js":
/*!***********************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/InlineLoading/InlineLoading.js ***!
  \***********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ InlineLoading)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-10.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var _prop_types_deprecate__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../../prop-types/deprecate */ "../../node_modules/carbon-components-react/es/prop-types/deprecate.js");
/* harmony import */ var _Loading__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../Loading */ "../../node_modules/carbon-components-react/es/components/Loading/Loading.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");


var _excluded = ["className", "success", "status", "iconDescription", "description", "onSuccess", "successDelay"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */







function InlineLoading(_ref) {
  var className = _ref.className,
      success = _ref.success,
      _ref$status = _ref.status,
      status = _ref$status === void 0 ? success ? 'finished' : 'active' : _ref$status,
      iconDescription = _ref.iconDescription,
      description = _ref.description,
      onSuccess = _ref.onSuccess,
      successDelay = _ref.successDelay,
      other = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_4__.usePrefix)();
  var loadingClasses = classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--inline-loading"), className);

  var getLoading = function getLoading() {
    if (status === 'error') {
      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_5__.ErrorFilled16, {
        className: "".concat(prefix, "--inline-loading--error")
      }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("title", null, iconDescription));
    }

    if (status === 'finished') {
      setTimeout(function () {
        if (onSuccess) {
          onSuccess();
        }
      }, successDelay);
      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_6__.CheckmarkFilled16, {
        className: "".concat(prefix, "--inline-loading__checkmark-container")
      }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("title", null, iconDescription));
    }

    if (status === 'inactive' || status === 'active') {
      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement(_Loading__WEBPACK_IMPORTED_MODULE_7__["default"], {
        small: true,
        description: iconDescription,
        withOverlay: false,
        active: status === 'active'
      });
    }

    return undefined;
  };

  var loadingText = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", {
    className: "".concat(prefix, "--inline-loading__text")
  }, description);
  var loading = getLoading();
  var loadingAnimation = loading && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", {
    className: "".concat(prefix, "--inline-loading__animation")
  }, loading);
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    className: loadingClasses
  }, other, {
    "aria-live": 'assertive' || 0
  }), loadingAnimation, description && loadingText);
}
InlineLoading.propTypes = {
  /**
   * Specify a custom className to be applied to the container node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().string),

  /**
   * Specify the description for the inline loading text
   */
  description: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().node),

  /**
   * Specify the description for the inline loading text
   */
  iconDescription: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().string),

  /**
   * Provide an optional handler to be invoked when <InlineLoading> is
   * successful
   */
  onSuccess: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().func),

  /**
   * Specify the loading status
   */
  status: prop_types__WEBPACK_IMPORTED_MODULE_8___default().oneOf(['inactive', 'active', 'finished', 'error']),

  /**
   * Specify whether the load was successful
   */
  success: (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_9__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_8___default().bool), "\nThe prop `success` for InlineLoading has been deprecated in favor of `status`. Please use `status=\"finished\"` instead."),

  /**
   * Provide a delay for the `setTimeout` for success
   */
  successDelay: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().number)
};
InlineLoading.defaultProps = {
  successDelay: 1500
};

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Link/Link.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Link/Link.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_6__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");



var _excluded = ["children", "className", "href", "disabled", "inline", "visited", "renderIcon", "size"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */




var Link = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().forwardRef(function Link(_ref, ref) {
  var _cx;

  var children = _ref.children,
      customClassName = _ref.className,
      href = _ref.href,
      disabled = _ref.disabled,
      inline = _ref.inline,
      visited = _ref.visited,
      Icon = _ref.renderIcon,
      size = _ref.size,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  var className = classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--link"), customClassName, (_cx = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--link--disabled"), disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--link--inline"), inline), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--link--visited"), visited), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--link--").concat(size), size), _cx));
  var rel = rest.target === '_blank' ? 'noopener' : null;
  var linkProps = {
    className: className,
    rel: rel
  }; // Reference for disabled links:
  // https://www.scottohara.me/blog/2021/05/28/disabled-links.html

  if (!disabled) {
    linkProps.href = href;
  } else {
    linkProps.role = 'link';
    linkProps['aria-disabled'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("a", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    ref: ref
  }, linkProps, rest), children, !inline && Icon && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", {
    className: "".concat(prefix, "--link__icon")
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement(Icon, null)));
});
Link.displayName = 'Link';
Link.propTypes = {
  /**
   * Provide the content for the Link
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().node),

  /**
   * Provide a custom className to be applied to the containing `<a>` node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().string),

  /**
   * Specify if the control should be disabled, or not
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool),

  /**
   * Provide the `href` attribute for the `<a>` node
   */
  href: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().string),

  /**
   * Specify whether you want the inline version of this control
   */
  inline: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool),

  /**
   * Optional prop to render an icon next to the link.
   * Can be a React component class
   */
  renderIcon: prop_types__WEBPACK_IMPORTED_MODULE_6___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_6___default().func), (prop_types__WEBPACK_IMPORTED_MODULE_6___default().object)]),

  /**
   * Specify the size of the Link. Currently supports either `sm`, 'md' (default) or 'lg` as an option.
   */
  size: prop_types__WEBPACK_IMPORTED_MODULE_6___default().oneOf(['sm', 'md', 'lg']),

  /**
   * Specify whether you want the link to receive visited styles after the link has been clicked
   */
  visited: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool)
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Link);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/ListBox/ListBox.js":
/*!***********************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/ListBox/ListBox.js ***!
  \***********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_6__);
/* harmony import */ var _ListBoxPropTypes__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./ListBoxPropTypes */ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxPropTypes.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");



var _excluded = ["children", "className", "disabled", "type", "size", "invalid", "invalidText", "warn", "warnText", "light", "isOpen"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */






var handleOnKeyDown = function handleOnKeyDown(event) {
  if (event.keyCode === 27) {
    event.stopPropagation();
  }
};

var handleClick = function handleClick(event) {
  event.preventDefault();
  event.stopPropagation();
};
/**
 * `ListBox` is a generic container component that handles creating the
 * container class name in response to certain props.
 */


var ListBox = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().forwardRef(function ListBox(_ref, ref) {
  var _cx;

  var children = _ref.children,
      containerClassName = _ref.className,
      disabled = _ref.disabled,
      type = _ref.type,
      size = _ref.size,
      invalid = _ref.invalid,
      invalidText = _ref.invalidText,
      warn = _ref.warn,
      warnText = _ref.warnText,
      light = _ref.light,
      isOpen = _ref.isOpen,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  var showWarning = !invalid && warn;
  var className = classnames__WEBPACK_IMPORTED_MODULE_3___default()((_cx = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, containerClassName, !!containerClassName), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--list-box"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--list-box--").concat(size), size), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--list-box--inline"), type === 'inline'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--list-box--disabled"), disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--list-box--light"), light), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--list-box--expanded"), isOpen), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--list-box--warning"), showWarning), _cx));
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement((react__WEBPACK_IMPORTED_MODULE_4___default().Fragment), null, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, rest, {
    className: className,
    ref: ref,
    onKeyDown: handleOnKeyDown,
    onClick: handleClick,
    "data-invalid": invalid || undefined
  }), children), invalid ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", {
    className: "".concat(prefix, "--form-requirement")
  }, invalidText) : null, showWarning ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", {
    className: "".concat(prefix, "--form-requirement")
  }, warnText) : null);
});
ListBox.displayName = 'ListBox';
ListBox.propTypes = {
  /**
   * Provide the contents of your ListBox
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().node),

  /**
   * Specify a class name to be applied on the containing list box node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().string),

  /**
   * Specify whether the ListBox is currently disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool.isRequired),

  /**
   * Specify whether the control is currently invalid
   */
  invalid: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool),

  /**
   * Specify the text to be displayed when the control is invalid
   */
  invalidText: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().node),

  /**
   * Specify if the control should render open
   */
  isOpen: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool),

  /**
   * `true` to use the light version. For use on $ui-01 backgrounds only.
   * Don't use this to make tile background color same as container background color.
   */
  light: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool),

  /**
   * Specify the size of the ListBox. Currently supports either `sm`, `md` or `lg` as an option.
   */
  size: _ListBoxPropTypes__WEBPACK_IMPORTED_MODULE_7__.ListBoxSize,

  /**
   * Specify the "type" of the ListBox. Currently supports either `default` or
   * `inline` as an option.
   */
  type: _ListBoxPropTypes__WEBPACK_IMPORTED_MODULE_7__.ListBoxType.isRequired,

  /**
   * Specify whether the control is currently in warning state
   */
  warn: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool),

  /**
   * Provide the text that is displayed when the control is in warning state
   */
  warnText: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().node)
};
ListBox.defaultProps = {
  disabled: false,
  type: 'default'
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ListBox);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxField.js":
/*!****************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/ListBox/ListBoxField.js ***!
  \****************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__),
/* harmony export */   "translationIds": () => (/* binding */ translationIds)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");


var _excluded = ["children", "disabled", "tabIndex"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */


 // No longer used, left export for backward-compatibility

var translationIds = {};
/**
 * `ListBoxField` is responsible for creating the containing node for valid
 * elements inside of a field. It also provides a11y-related attributes like
 * `role` to make sure a user can focus the given field.
 */

function ListBoxField(_ref) {
  var children = _ref.children,
      disabled = _ref.disabled,
      tabIndex = _ref.tabIndex,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_3__.usePrefix)();
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    className: "".concat(prefix, "--list-box__field"),
    tabIndex: !disabled && tabIndex || -1
  }, rest), children);
}

ListBoxField.propTypes = {
  /**
   * Typically set by `getToggleButtonProps`, this should specify whether the
   * field has a popup.
   */
  'aria-haspopup': prop_types__WEBPACK_IMPORTED_MODULE_4___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_4___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_4___default().bool)]),

  /**
   * Provide the contents of your ListBoxField
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_4___default().node),

  /**
   * Specify if the parent <ListBox> is disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_4___default().bool),

  /**
   * The role for the component, should be set by `getToggleButtonProps` coming
   * from Downshift
   */
  role: (prop_types__WEBPACK_IMPORTED_MODULE_4___default().string),

  /**
   * Optional prop to specify the tabIndex of the <ListBox> trigger button
   */
  tabIndex: prop_types__WEBPACK_IMPORTED_MODULE_4___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_4___default().number), (prop_types__WEBPACK_IMPORTED_MODULE_4___default().string)])
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ListBoxField);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxMenu.js":
/*!***************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/ListBox/ListBoxMenu.js ***!
  \***************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _ListBoxMenuItem__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./ListBoxMenuItem */ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxMenuItem.js");


var _excluded = ["children", "id"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */




/**
 * `ListBoxMenu` is a simple container node that isolates the `list-box__menu`
 * class into a single component. It is also being used to validate given
 * `children` components.
 */

var ListBoxMenu = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().forwardRef(function ListBoxMenu(_ref, ref) {
  var children = _ref.children,
      id = _ref.id,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_3__.usePrefix)();
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    ref: ref,
    id: id,
    className: "".concat(prefix, "--list-box__menu"),
    role: "listbox"
  }, rest), children);
});
ListBoxMenu.displayName = 'ListBoxMenu';
ListBoxMenu.propTypes = {
  /**
   * Provide the contents of your ListBoxMenu
   */
  children: prop_types__WEBPACK_IMPORTED_MODULE_4___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_4___default().node), prop_types__WEBPACK_IMPORTED_MODULE_4___default().arrayOf(_ListBoxMenuItem__WEBPACK_IMPORTED_MODULE_5__["default"]),
  /**
   * allow single item using the workaround for functional components
   * https://github.com/facebook/react/issues/2979#issuecomment-222379916
   */
  prop_types__WEBPACK_IMPORTED_MODULE_4___default().shape({
    type: prop_types__WEBPACK_IMPORTED_MODULE_4___default().oneOf([_ListBoxMenuItem__WEBPACK_IMPORTED_MODULE_5__["default"]])
  }), (prop_types__WEBPACK_IMPORTED_MODULE_4___default().bool) // used in Dropdown for closed state
  ]),

  /**
   * Specify a custom `id`
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_4___default().string.isRequired)
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ListBoxMenu);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxMenuIcon.js":
/*!*******************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/ListBox/ListBoxMenuIcon.js ***!
  \*******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__),
/* harmony export */   "translationIds": () => (/* binding */ translationIds)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");


var _defaultTranslations;

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */





var translationIds = {
  'close.menu': 'close.menu',
  'open.menu': 'open.menu'
};
var defaultTranslations = (_defaultTranslations = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_defaultTranslations, translationIds['close.menu'], 'Close menu'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_defaultTranslations, translationIds['open.menu'], 'Open menu'), _defaultTranslations);
/**
 * `ListBoxMenuIcon` is used to orient the icon up or down depending on the
 * state of the menu for a given `ListBox`
 */

var ListBoxMenuIcon = function ListBoxMenuIcon(_ref) {
  var isOpen = _ref.isOpen,
      t = _ref.translateWithId;
  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_3__.usePrefix)();
  var className = classnames__WEBPACK_IMPORTED_MODULE_1___default()("".concat(prefix, "--list-box__menu-icon"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])({}, "".concat(prefix, "--list-box__menu-icon--open"), isOpen));
  var description = isOpen ? t('close.menu') : t('open.menu');
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", {
    className: className
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_4__.ChevronDown16, {
    name: "chevron--down",
    "aria-label": description
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("title", null, description)));
};

ListBoxMenuIcon.propTypes = {
  /**
   * Specify whether the menu is currently open, which will influence the
   * direction of the menu icon
   */
  isOpen: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().bool.isRequired),

  /**
   * i18n hook used to provide the appropriate description for the given menu
   * icon. This function takes in an id defined in `translationIds` and should
   * return a string message for that given message id.
   */
  translateWithId: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().func.isRequired)
};
ListBoxMenuIcon.defaultProps = {
  translateWithId: function translateWithId(id) {
    return defaultTranslations[id];
  }
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ListBoxMenuIcon);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxMenuItem.js":
/*!*******************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/ListBox/ListBoxMenuItem.js ***!
  \*******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_7__);
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");




var _excluded = ["children", "isActive", "isHighlighted", "title"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */





function useIsTruncated(ref) {
  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(false),
      _useState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(_useState, 2),
      isTruncated = _useState2[0],
      setIsTruncated = _useState2[1];

  (0,react__WEBPACK_IMPORTED_MODULE_5__.useEffect)(function () {
    var _ref$current = ref.current,
        offsetWidth = _ref$current.offsetWidth,
        scrollWidth = _ref$current.scrollWidth;
    setIsTruncated(offsetWidth < scrollWidth);
  }, [ref, setIsTruncated]);
  return isTruncated;
}
/**
 * `ListBoxMenuItem` is a helper component for managing the container class
 * name, alongside any classes for any corresponding states, for a generic list
 * box menu item.
 */


var ListBoxMenuItem = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().forwardRef(function ListBoxMenuItem(_ref, forwardedRef) {
  var _cx;

  var children = _ref.children,
      isActive = _ref.isActive,
      isHighlighted = _ref.isHighlighted,
      title = _ref.title,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_6__.usePrefix)();
  var ref = (0,react__WEBPACK_IMPORTED_MODULE_5__.useRef)(null);
  var isTruncated = useIsTruncated((forwardedRef === null || forwardedRef === void 0 ? void 0 : forwardedRef.menuItemOptionRef) || ref);
  var className = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--list-box__menu-item"), (_cx = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--list-box__menu-item--active"), isActive), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--list-box__menu-item--highlighted"), isHighlighted), _cx));
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, rest, {
    className: className,
    title: isTruncated ? title : undefined
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("div", {
    className: "".concat(prefix, "--list-box__menu-item__option"),
    ref: (forwardedRef === null || forwardedRef === void 0 ? void 0 : forwardedRef.menuItemOptionRef) || ref
  }, children));
});
ListBoxMenuItem.displayName = 'ListBoxMenuItem';
ListBoxMenuItem.propTypes = {
  /**
   * Specify any children nodes that should be rendered inside of the ListBox
   * Menu Item
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().node),

  /**
   * Specify whether the current menu item is "active".
   */
  isActive: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool.isRequired),

  /**
   * Specify whether the current menu item is "highlighted".
   */
  isHighlighted: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool.isRequired),

  /**
   * Provide an optional tooltip for the ListBoxMenuItem
   */
  title: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string)
};
ListBoxMenuItem.defaultProps = {
  isActive: false,
  isHighlighted: false
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ListBoxMenuItem);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxPropTypes.js":
/*!********************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/ListBox/ListBoxPropTypes.js ***!
  \********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "ListBoxSize": () => (/* binding */ ListBoxSize),
/* harmony export */   "ListBoxType": () => (/* binding */ ListBoxType)
/* harmony export */ });
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @carbon/feature-flags */ "../../node_modules/@carbon/feature-flags/es/index.js");
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */


var ListBoxType = prop_types__WEBPACK_IMPORTED_MODULE_0___default().oneOf(['default', 'inline']);
var ListBoxSize = _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_1__.enabled('enable-v11-release') ? prop_types__WEBPACK_IMPORTED_MODULE_0___default().oneOf(['sm', 'md', 'lg']) : prop_types__WEBPACK_IMPORTED_MODULE_0___default().oneOf(['sm', 'md', 'lg', 'xl']);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxSelection.js":
/*!********************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/ListBox/ListBoxSelection.js ***!
  \********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__),
/* harmony export */   "translationIds": () => (/* binding */ translationIds)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_7__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/match.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/keys.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");


var _defaultTranslations;

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */






/**
 * `ListBoxSelection` is used to provide controls for clearing a selection, in
 * addition to conditionally rendering a badge if the control has more than one
 * selection.
 */

var ListBoxSelection = function ListBoxSelection(_ref) {
  var _cx;

  var clearSelection = _ref.clearSelection,
      selectionCount = _ref.selectionCount,
      t = _ref.translateWithId,
      disabled = _ref.disabled,
      onClearSelection = _ref.onClearSelection;
  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_3__.usePrefix)();
  var className = classnames__WEBPACK_IMPORTED_MODULE_1___default()("".concat(prefix, "--list-box__selection"), (_cx = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_cx, "".concat(prefix, "--tag--filter"), selectionCount), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_cx, "".concat(prefix, "--list-box__selection--multi"), selectionCount), _cx));

  var handleOnClick = function handleOnClick(event) {
    event.stopPropagation();

    if (disabled) {
      return;
    }

    clearSelection(event);

    if (onClearSelection) {
      onClearSelection(event);
    }
  };

  var handleOnKeyDown = function handleOnKeyDown(event) {
    event.stopPropagation();

    if (disabled) {
      return;
    } // When a user hits ENTER, we'll clear the selection


    if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_4__.match)(event, _internal_keyboard__WEBPACK_IMPORTED_MODULE_5__.Enter)) {
      clearSelection(event);

      if (onClearSelection) {
        onClearSelection(event);
      }
    }
  };

  var description = selectionCount ? t('clear.all') : t('clear.selection');
  var tagClasses = classnames__WEBPACK_IMPORTED_MODULE_1___default()("".concat(prefix, "--tag"), "".concat(prefix, "--tag--filter"), "".concat(prefix, "--tag--high-contrast"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])({}, "".concat(prefix, "--tag--disabled"), disabled));
  return selectionCount ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", {
    className: tagClasses
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("span", {
    className: "".concat(prefix, "--tag__label"),
    title: selectionCount
  }, selectionCount), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", {
    role: "button",
    tabIndex: disabled ? -1 : 0,
    className: "".concat(prefix, "--tag__close-icon"),
    onClick: handleOnClick,
    onKeyDown: handleOnKeyDown,
    disabled: disabled,
    "aria-label": t('clear.all'),
    title: description
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_6__.Close16, null))) : /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", {
    role: "button",
    className: className,
    tabIndex: disabled ? -1 : 0,
    onClick: handleOnClick,
    onKeyDown: handleOnKeyDown,
    "aria-label": description,
    title: description
  }, selectionCount, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_6__.Close16, null));
};

var translationIds = {
  'clear.all': 'clear.all',
  'clear.selection': 'clear.selection'
};
var defaultTranslations = (_defaultTranslations = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_defaultTranslations, translationIds['clear.all'], 'Clear all selected items'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_defaultTranslations, translationIds['clear.selection'], 'Clear selected item'), _defaultTranslations);
ListBoxSelection.propTypes = {
  /**
   * Specify a function to be invoked when a user interacts with the clear
   * selection element.
   */
  clearSelection: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func.isRequired),

  /**
   * Specify whether or not the clear selection element should be disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),

  /**
   * Specify an optional `onClearSelection` handler that is called when the underlying
   * element is cleared
   */
  onClearSelection: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),

  /**
   * Specify an optional `onClick` handler that is called when the underlying
   * clear selection element is clicked
   */
  onClick: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),

  /**
   * Specify an optional `onKeyDown` handler that is called when the underlying
   * clear selection element fires a keydown event
   */
  onKeyDown: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),

  /**
   * Specify an optional `selectionCount` value that will be used to determine
   * whether the selection should display a badge or a single clear icon.
   */
  selectionCount: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),

  /**
   * i18n hook used to provide the appropriate description for the given menu
   * icon. This function takes in an id defined in `translationIds` and should
   * return a string message for that given message id.
   */
  translateWithId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func.isRequired)
};
ListBoxSelection.defaultProps = {
  translateWithId: function translateWithId(id) {
    return defaultTranslations[id];
  }
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ListBoxSelection);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/ListBox/index.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/ListBox/index.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "PropTypes": () => (/* reexport module object */ _ListBoxPropTypes__WEBPACK_IMPORTED_MODULE_0__),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _ListBoxPropTypes__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./ListBoxPropTypes */ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxPropTypes.js");
/* harmony import */ var _ListBox__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./ListBox */ "../../node_modules/carbon-components-react/es/components/ListBox/ListBox.js");
/* harmony import */ var _ListBoxField__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./ListBoxField */ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxField.js");
/* harmony import */ var _ListBoxMenu__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./ListBoxMenu */ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxMenu.js");
/* harmony import */ var _ListBoxMenuIcon__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./ListBoxMenuIcon */ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxMenuIcon.js");
/* harmony import */ var _ListBoxMenuItem__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./ListBoxMenuItem */ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxMenuItem.js");
/* harmony import */ var _ListBoxSelection__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./ListBoxSelection */ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxSelection.js");
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */








_ListBox__WEBPACK_IMPORTED_MODULE_1__["default"].Field = _ListBoxField__WEBPACK_IMPORTED_MODULE_2__["default"];
_ListBox__WEBPACK_IMPORTED_MODULE_1__["default"].Menu = _ListBoxMenu__WEBPACK_IMPORTED_MODULE_3__["default"];
_ListBox__WEBPACK_IMPORTED_MODULE_1__["default"].MenuIcon = _ListBoxMenuIcon__WEBPACK_IMPORTED_MODULE_4__["default"];
_ListBox__WEBPACK_IMPORTED_MODULE_1__["default"].MenuItem = _ListBoxMenuItem__WEBPACK_IMPORTED_MODULE_5__["default"];
_ListBox__WEBPACK_IMPORTED_MODULE_1__["default"].Selection = _ListBoxSelection__WEBPACK_IMPORTED_MODULE_6__["default"];
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_ListBox__WEBPACK_IMPORTED_MODULE_1__["default"]);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/ListBox/next/ListBoxSelection.js":
/*!*************************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/ListBox/next/ListBoxSelection.js ***!
  \*************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__),
/* harmony export */   "translationIds": () => (/* binding */ translationIds)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/match.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/keys.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");




var _defaultTranslations;

var _excluded = ["clearSelection", "selectionCount", "translateWithId", "disabled", "onClearSelection"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */






/**
 * `ListBoxSelection` is used to provide controls for clearing a selection, in
 * addition to conditionally rendering a badge if the control has more than one
 * selection.
 */

function ListBoxSelection(_ref) {
  var _cx;

  var clearSelection = _ref.clearSelection,
      selectionCount = _ref.selectionCount,
      t = _ref.translateWithId,
      disabled = _ref.disabled,
      onClearSelection = _ref.onClearSelection,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  var className = classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--list-box__selection"), (_cx = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--tag--filter"), selectionCount), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--list-box__selection--multi"), selectionCount), _cx));
  var description = selectionCount ? t('clear.all') : t('clear.selection');
  var tagClasses = classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--tag"), "".concat(prefix, "--tag--filter"), "".concat(prefix, "--tag--high-contrast"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--tag--disabled"), disabled));

  function onClick(event) {
    event.stopPropagation();

    if (disabled) {
      return;
    }

    clearSelection(event);

    if (onClearSelection) {
      onClearSelection(event);
    }
  }

  function onKeyDown(event) {
    event.stopPropagation();

    if (disabled) {
      return;
    } // When a user hits ENTER, we'll clear the selection


    if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_6__.match)(event, _internal_keyboard__WEBPACK_IMPORTED_MODULE_7__.Enter)) {
      clearSelection(event);

      if (onClearSelection) {
        onClearSelection(event);
      }
    }
  }

  if (selectionCount) {
    return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", {
      className: tagClasses
    }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("span", {
      className: "".concat(prefix, "--tag__label"),
      title: selectionCount
    }, selectionCount), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("button", {
      "aria-label": description,
      className: "".concat(prefix, "--tag__close-icon"),
      disabled: disabled,
      onClick: onClick,
      onKeyDown: onKeyDown,
      tabIndex: disabled ? -1 : 0,
      title: description,
      type: "button"
    }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__.Close16, null)));
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("button", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, rest, {
    "aria-label": description,
    className: className,
    onClick: onClick,
    onKeyDown: onKeyDown,
    tabIndex: disabled ? -1 : 0,
    title: description,
    type: "button"
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__.Close16, null));
}

var translationIds = {
  'clear.all': 'clear.all',
  'clear.selection': 'clear.selection'
};
var defaultTranslations = (_defaultTranslations = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_defaultTranslations, translationIds['clear.all'], 'Clear all selected items'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_defaultTranslations, translationIds['clear.selection'], 'Clear selected item'), _defaultTranslations);
ListBoxSelection.propTypes = {
  /**
   * Specify a function to be invoked when a user interacts with the clear
   * selection element.
   */
  clearSelection: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func.isRequired),

  /**
   * Specify whether or not the clear selection element should be disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Specify an optional `onClearSelection` handler that is called when the underlying
   * element is cleared
   */
  onClearSelection: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func),

  /**
   * Specify an optional `onClick` handler that is called when the underlying
   * clear selection element is clicked
   */
  onClick: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func),

  /**
   * Specify an optional `onKeyDown` handler that is called when the underlying
   * clear selection element fires a keydown event
   */
  onKeyDown: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func),

  /**
   * Specify an optional `selectionCount` value that will be used to determine
   * whether the selection should display a badge or a single clear icon.
   */
  selectionCount: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number),

  /**
   * i18n hook used to provide the appropriate description for the given menu
   * icon. This function takes in an id defined in `translationIds` and should
   * return a string message for that given message id.
   */
  translateWithId: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func.isRequired)
};
ListBoxSelection.defaultProps = {
  translateWithId: function translateWithId(id) {
    return defaultTranslations[id];
  }
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ListBoxSelection);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/ListBox/next/ListBoxTrigger.js":
/*!***********************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/ListBox/next/ListBoxTrigger.js ***!
  \***********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__),
/* harmony export */   "translationIds": () => (/* binding */ translationIds)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_7__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");



var _excluded = ["isOpen", "translateWithId"];

var _defaultTranslations;

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */





var translationIds = {
  'close.menu': 'close.menu',
  'open.menu': 'open.menu'
};
var defaultTranslations = (_defaultTranslations = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(_defaultTranslations, translationIds['close.menu'], 'Close'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(_defaultTranslations, translationIds['open.menu'], 'Open'), _defaultTranslations);
/**
 * `ListBoxTrigger` is used to orient the icon up or down depending on the
 * state of the menu for a given `ListBox`
 */

var ListBoxTrigger = function ListBoxTrigger(_ref) {
  var _cx;

  var isOpen = _ref.isOpen,
      t = _ref.translateWithId,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  var className = classnames__WEBPACK_IMPORTED_MODULE_3___default()((_cx = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(_cx, "".concat(prefix, "--list-box__menu-icon"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(_cx, "".concat(prefix, "--list-box__menu-icon--open"), isOpen), _cx));
  var description = isOpen ? t('close.menu') : t('open.menu');
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("button", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, rest, {
    "aria-label": description,
    title: description,
    className: className,
    type: "button",
    tabIndex: "-1"
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_6__.ChevronDown16, null));
};

ListBoxTrigger.propTypes = {
  /**
   * Specify whether the menu is currently open, which will influence the
   * direction of the menu icon
   */
  isOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool.isRequired),

  /**
   * i18n hook used to provide the appropriate description for the given menu
   * icon. This function takes in an id defined in `translationIds` and should
   * return a string message for that given message id.
   */
  translateWithId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func.isRequired)
};
ListBoxTrigger.defaultProps = {
  translateWithId: function translateWithId(id) {
    return defaultTranslations[id];
  }
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ListBoxTrigger);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Loading/Loading.js":
/*!***********************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Loading/Loading.js ***!
  \***********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_7__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _tools_setupGetInstanceId__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../tools/setupGetInstanceId */ "../../node_modules/carbon-components-react/es/tools/setupGetInstanceId.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");



var _excluded = ["id", "active", "className", "withOverlay", "small", "description"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */





var getInstanceId = (0,_tools_setupGetInstanceId__WEBPACK_IMPORTED_MODULE_5__["default"])();

function Loading(_ref) {
  var _cx, _cx2;

  var id = _ref.id,
      active = _ref.active,
      customClassName = _ref.className,
      withOverlay = _ref.withOverlay,
      small = _ref.small,
      description = _ref.description,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_6__.usePrefix)();

  var _useRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(getInstanceId()),
      instanceId = _useRef.current;

  var loadingClassName = classnames__WEBPACK_IMPORTED_MODULE_3___default()(customClassName, (_cx = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--loading"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--loading--small"), small), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--loading--stop"), !active), _cx));
  var overlayClassName = classnames__WEBPACK_IMPORTED_MODULE_3___default()((_cx2 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx2, "".concat(prefix, "--loading-overlay"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx2, "".concat(prefix, "--loading-overlay--stop"), !active), _cx2));
  var loadingId = id || "loading-id-".concat(instanceId);
  var loading = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, rest, {
    "aria-atomic": "true",
    "aria-labelledby": loadingId,
    "aria-live": active ? 'assertive' : 'off',
    className: loadingClassName
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("label", {
    id: loadingId,
    className: "".concat(prefix, "--visually-hidden")
  }, description), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("svg", {
    className: "".concat(prefix, "--loading__svg"),
    viewBox: "0 0 100 100"
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("title", null, description), small ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("circle", {
    className: "".concat(prefix, "--loading__background"),
    cx: "50%",
    cy: "50%",
    r: "44"
  }) : null, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("circle", {
    className: "".concat(prefix, "--loading__stroke"),
    cx: "50%",
    cy: "50%",
    r: "44"
  })));
  return withOverlay ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", {
    className: overlayClassName
  }, loading) : loading;
}

Loading.propTypes = {
  /**
   * Specify whether you want the loading indicator to be spinning or not
   */
  active: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),

  /**
   * Provide an optional className to be applied to the containing node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),

  /**
   * Specify a description that would be used to best describe the loading state
   */
  description: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),

  /**
   * Provide an `id` to uniquely identify the label
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),

  /**
   * Specify whether you would like the small variant of <Loading>
   */
  small: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),

  /**
   * Specify whether you want the loader to be applied with an overlay
   */
  withOverlay: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool)
};
Loading.defaultProps = {
  active: true,
  withOverlay: true,
  small: false,
  description: 'Active loading indicator'
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Loading);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Modal/Modal.js":
/*!*******************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Modal/Modal.js ***!
  \*******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ Modal)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_18___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_18__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_10___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_10__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var _tools_toggleClass__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../../tools/toggleClass */ "../../node_modules/carbon-components-react/es/tools/toggleClass.js");
/* harmony import */ var _Button__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ../Button */ "../../node_modules/carbon-components-react/es/components/Button/Button.js");
/* harmony import */ var _ButtonSet__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ../ButtonSet */ "../../node_modules/carbon-components-react/es/components/ButtonSet/ButtonSet.js");
/* harmony import */ var _prop_types_deprecate__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ../../prop-types/deprecate */ "../../node_modules/carbon-components-react/es/prop-types/deprecate.js");
/* harmony import */ var _prop_types_requiredIfGivenPropIsTruthy__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ../../prop-types/requiredIfGivenPropIsTruthy */ "../../node_modules/carbon-components-react/es/prop-types/requiredIfGivenPropIsTruthy.js");
/* harmony import */ var _internal_wrapFocus__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../../internal/wrapFocus */ "../../node_modules/carbon-components-react/es/internal/wrapFocus.js");
/* harmony import */ var _tools_setupGetInstanceId__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../tools/setupGetInstanceId */ "../../node_modules/carbon-components-react/es/tools/setupGetInstanceId.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");










var _defineProperty2;

var _excluded = ["modalHeading", "modalLabel", "modalAriaLabel", "passiveModal", "hasForm", "secondaryButtonText", "primaryButtonText", "open", "onRequestClose", "onRequestSubmit", "onSecondarySubmit", "iconDescription", "primaryButtonDisabled", "danger", "alert", "secondaryButtons", "selectorPrimaryFocus", "selectorsFloatingMenus", "shouldSubmitOnEnter", "size", "hasScrollingContent", "closeButtonLabel", "preventCloseOnClickOutside"];

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__["default"])(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__["default"])(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_6__["default"])(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */












var getInstanceId = (0,_tools_setupGetInstanceId__WEBPACK_IMPORTED_MODULE_11__["default"])();

var Modal = /*#__PURE__*/function (_Component) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(Modal, _Component);

  var _super = _createSuper(Modal);

  function Modal() {
    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, Modal);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _super.call.apply(_super, [this].concat(args));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "button", /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createRef());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "secondaryButton", /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createRef());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "outerModal", /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createRef());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "innerModal", /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createRef());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "startTrap", /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createRef());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "endTrap", /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createRef());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "modalInstanceId", "modal-".concat(getInstanceId()));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "modalLabelId", "".concat(_this.context, "--modal-header__label--").concat(_this.modalInstanceId));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "modalHeadingId", "".concat(_this.context, "--modal-header__heading--").concat(_this.modalInstanceId));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "modalBodyId", "".concat(_this.context, "--modal-body--").concat(_this.modalInstanceId));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "modalCloseButtonClass", "".concat(_this.context, "--modal-close"));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "isCloseButton", function (element) {
      return !_this.props.onSecondarySubmit && element === _this.secondaryButton.current || element.classList.contains(_this.modalCloseButtonClass);
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "handleKeyDown", function (evt) {
      if (_this.props.open) {
        if (evt.which === 27) {
          _this.props.onRequestClose(evt);
        }

        if (evt.which === 13 && _this.props.shouldSubmitOnEnter && !_this.isCloseButton(evt.target)) {
          _this.props.onRequestSubmit(evt);
        }
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "handleMousedown", function (evt) {
      if (_this.innerModal.current && !_this.innerModal.current.contains(evt.target) && !(0,_internal_wrapFocus__WEBPACK_IMPORTED_MODULE_12__.elementOrParentIsFloatingMenu)(evt.target, _this.props.selectorsFloatingMenus) && !_this.props.preventCloseOnClickOutside) {
        _this.props.onRequestClose(evt);
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "handleBlur", function (_ref) {
      var oldActiveNode = _ref.target,
          currentActiveNode = _ref.relatedTarget;
      var _this$props = _this.props,
          open = _this$props.open,
          selectorsFloatingMenus = _this$props.selectorsFloatingMenus;

      if (open && currentActiveNode && oldActiveNode) {
        var bodyNode = _this.innerModal.current;
        var startTrapNode = _this.startTrap.current;
        var endTrapNode = _this.endTrap.current;
        (0,_internal_wrapFocus__WEBPACK_IMPORTED_MODULE_12__["default"])({
          bodyNode: bodyNode,
          startTrapNode: startTrapNode,
          endTrapNode: endTrapNode,
          currentActiveNode: currentActiveNode,
          oldActiveNode: oldActiveNode,
          selectorsFloatingMenus: selectorsFloatingMenus
        });
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "initialFocus", function (focusContainerElement) {
      var containerElement = focusContainerElement || _this.innerModal.current;
      var primaryFocusElement = containerElement ? containerElement.querySelector(_this.props.selectorPrimaryFocus) : null;

      if (primaryFocusElement) {
        return primaryFocusElement;
      }

      return _this.button && _this.button.current;
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "focusButton", function (focusContainerElement) {
      var target = _this.initialFocus(focusContainerElement);

      if (target) {
        target.focus();
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "handleTransitionEnd", function (evt) {
      if (evt.target === evt.currentTarget && // Not to handle `onTransitionEnd` on child DOM nodes
      _this.outerModal.current && _this.outerModal.current.offsetWidth && _this.outerModal.current.offsetHeight && _this.beingOpen) {
        _this.focusButton(evt.currentTarget);

        _this.beingOpen = false;
      }
    });

    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(Modal, [{
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps) {
      if (!prevProps.open && this.props.open) {
        this.beingOpen = true;
      } else if (prevProps.open && !this.props.open) {
        this.beingOpen = false;
      }

      (0,_tools_toggleClass__WEBPACK_IMPORTED_MODULE_13__["default"])(document.body, "".concat(this.context, "--body--with-modal-open"), this.props.open);
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      (0,_tools_toggleClass__WEBPACK_IMPORTED_MODULE_13__["default"])(document.body, "".concat(this.context, "--body--with-modal-open"), false);
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      (0,_tools_toggleClass__WEBPACK_IMPORTED_MODULE_13__["default"])(document.body, "".concat(this.context, "--body--with-modal-open"), this.props.open);

      if (!this.props.open) {
        return;
      }

      this.focusButton(this.innerModal.current);
    }
  }, {
    key: "render",
    value: function render() {
      var _classNames, _classNames3;

      var _this$props2 = this.props,
          modalHeading = _this$props2.modalHeading,
          modalLabel = _this$props2.modalLabel,
          modalAriaLabel = _this$props2.modalAriaLabel,
          passiveModal = _this$props2.passiveModal,
          hasForm = _this$props2.hasForm,
          secondaryButtonText = _this$props2.secondaryButtonText,
          primaryButtonText = _this$props2.primaryButtonText,
          open = _this$props2.open,
          onRequestClose = _this$props2.onRequestClose,
          onRequestSubmit = _this$props2.onRequestSubmit,
          onSecondarySubmit = _this$props2.onSecondarySubmit,
          iconDescription = _this$props2.iconDescription,
          primaryButtonDisabled = _this$props2.primaryButtonDisabled,
          danger = _this$props2.danger,
          alert = _this$props2.alert,
          secondaryButtons = _this$props2.secondaryButtons,
          selectorPrimaryFocus = _this$props2.selectorPrimaryFocus,
          selectorsFloatingMenus = _this$props2.selectorsFloatingMenus,
          shouldSubmitOnEnter = _this$props2.shouldSubmitOnEnter,
          size = _this$props2.size,
          hasScrollingContent = _this$props2.hasScrollingContent,
          closeButtonLabel = _this$props2.closeButtonLabel,
          preventCloseOnClickOutside = _this$props2.preventCloseOnClickOutside,
          other = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_this$props2, _excluded);

      var prefix = this.context;
      var onSecondaryButtonClick = onSecondarySubmit ? onSecondarySubmit : onRequestClose;
      var modalClasses = classnames__WEBPACK_IMPORTED_MODULE_10___default()((_classNames = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--modal"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--modal-tall"), !passiveModal), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, 'is-visible', open), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--modal--danger"), this.props.danger), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, this.props.className, this.props.className), _classNames));
      var containerClasses = classnames__WEBPACK_IMPORTED_MODULE_10___default()("".concat(prefix, "--modal-container"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])({}, "".concat(prefix, "--modal-container--").concat(size), size));
      var contentClasses = classnames__WEBPACK_IMPORTED_MODULE_10___default()("".concat(prefix, "--modal-content"), (_classNames3 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames3, "".concat(prefix, "--modal-content--with-form"), hasForm), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames3, "".concat(prefix, "--modal-scroll-content"), hasScrollingContent), _classNames3));
      var footerClasses = classnames__WEBPACK_IMPORTED_MODULE_10___default()("".concat(prefix, "--modal-footer"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])({}, "".concat(prefix, "--modal-footer--three-button"), Array.isArray(secondaryButtons) && secondaryButtons.length === 2));
      var modalButton = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("button", {
        className: this.modalCloseButtonClass,
        type: "button",
        onClick: onRequestClose,
        title: ariaLabel ? ariaLabel : iconDescription,
        "aria-label": closeButtonLabel ? closeButtonLabel : 'close',
        ref: this.button
      }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_14__.Close20, {
        "aria-hidden": "true",
        tabIndex: "-1",
        className: "".concat(this.modalCloseButtonClass, "__icon")
      }));
      var ariaLabel = modalLabel || this.props['aria-label'] || modalAriaLabel || modalHeading;
      var getAriaLabelledBy = modalLabel ? this.modalLabelId : this.modalHeadingId;
      var hasScrollingContentProps = hasScrollingContent ? {
        tabIndex: 0,
        role: 'region',
        'aria-label': ariaLabel,
        'aria-labelledby': getAriaLabelledBy
      } : {};
      var alertDialogProps = {};

      if (alert && passiveModal) {
        alertDialogProps.role = 'alert';
      }

      if (alert && !passiveModal) {
        alertDialogProps.role = 'alertdialog';
        alertDialogProps['aria-describedby'] = this.modalBodyId;
      }

      var modalBody = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
        ref: this.innerModal,
        role: "dialog"
      }, alertDialogProps, {
        className: containerClasses,
        "aria-label": ariaLabel,
        "aria-modal": "true",
        tabIndex: "-1"
      }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", {
        className: "".concat(prefix, "--modal-header")
      }, passiveModal && modalButton, modalLabel && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("h2", {
        id: this.modalLabelId,
        className: "".concat(prefix, "--modal-header__label")
      }, modalLabel), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("h3", {
        id: this.modalHeadingId,
        className: "".concat(prefix, "--modal-header__heading")
      }, modalHeading), !passiveModal && modalButton), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
        id: this.modalBodyId,
        className: contentClasses
      }, hasScrollingContentProps, {
        "aria-labelledby": getAriaLabelledBy
      }), this.props.children), hasScrollingContent && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", {
        className: "".concat(prefix, "--modal-content--overflow-indicator")
      }), !passiveModal && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement(_ButtonSet__WEBPACK_IMPORTED_MODULE_15__["default"], {
        className: footerClasses
      }, Array.isArray(secondaryButtons) && secondaryButtons.length <= 2 ? secondaryButtons.map(function (_ref2, i) {
        var buttonText = _ref2.buttonText,
            onButtonClick = _ref2.onClick;
        return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement(_Button__WEBPACK_IMPORTED_MODULE_16__["default"], {
          key: "".concat(buttonText, "-").concat(i),
          kind: "secondary",
          onClick: onButtonClick
        }, buttonText);
      }) : secondaryButtonText && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement(_Button__WEBPACK_IMPORTED_MODULE_16__["default"], {
        kind: "secondary",
        onClick: onSecondaryButtonClick,
        ref: this.secondaryButton
      }, secondaryButtonText), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement(_Button__WEBPACK_IMPORTED_MODULE_16__["default"], {
        kind: danger ? 'danger' : 'primary',
        disabled: primaryButtonDisabled,
        onClick: onRequestSubmit,
        ref: this.button
      }, primaryButtonText)));
      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, other, {
        onKeyDown: this.handleKeyDown,
        onMouseDown: this.handleMousedown,
        onBlur: this.handleBlur,
        className: modalClasses,
        role: "presentation",
        onTransitionEnd: this.props.open ? this.handleTransitionEnd : undefined,
        ref: this.outerModal
      }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("span", {
        ref: this.startTrap,
        tabIndex: "0",
        role: "link",
        className: "".concat(prefix, "--visually-hidden")
      }, "Focus sentinel"), modalBody, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("span", {
        ref: this.endTrap,
        tabIndex: "0",
        role: "link",
        className: "".concat(prefix, "--visually-hidden")
      }, "Focus sentinel"));
    }
  }]);

  return Modal;
}(react__WEBPACK_IMPORTED_MODULE_9__.Component);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(Modal, "contextType", _internal_usePrefix__WEBPACK_IMPORTED_MODULE_17__.PrefixContext);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(Modal, "propTypes", (_defineProperty2 = {
  /**
   * Specify whether the Modal is displaying an alert, error or warning
   * Should go hand in hand with the danger prop.
   */
  alert: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().bool)
}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, 'aria-label', (0,_prop_types_requiredIfGivenPropIsTruthy__WEBPACK_IMPORTED_MODULE_19__["default"])('hasScrollingContent', (prop_types__WEBPACK_IMPORTED_MODULE_18___default().string))), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "children", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().node)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "className", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().string)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "closeButtonLabel", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().string)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "danger", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().bool)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "focusTrap", (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_20__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_18___default().bool), "\nThe prop `focusTrap` for Modal has been deprecated, as the feature of `focusTrap` runs by default.")), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "hasForm", (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_20__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_18___default().bool), "\nThe prop `hasForm` for Modal has been deprecated, as the feature of `hasForm` runs by default.")), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "hasScrollingContent", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().bool)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "iconDescription", (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_20__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_18___default().string), 'The iconDescription prop is no longer needed and can be safely removed. This prop will be removed in the next major release of Carbon.')), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "id", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().string)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "modalAriaLabel", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().string)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "modalHeading", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().node)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "modalLabel", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().node)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "onKeyDown", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().func)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "onRequestClose", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().func)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "onRequestSubmit", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().func)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "onSecondarySubmit", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().func)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "open", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().bool)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "passiveModal", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().bool)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "preventCloseOnClickOutside", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().bool)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "primaryButtonDisabled", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().bool)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "primaryButtonText", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().node)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "secondaryButtonText", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().node)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "secondaryButtons", function secondaryButtons(props, propName, componentName) {
  if (props.secondaryButtons) {
    if (!Array.isArray(props.secondaryButtons) || props.secondaryButtons.length !== 2) {
      return new Error("".concat(propName, " needs to be an array of two button config objects"));
    }

    var shape = {
      buttonText: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().node),
      onClick: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().func)
    };
    props[propName].forEach(function (secondaryButton) {
      prop_types__WEBPACK_IMPORTED_MODULE_18___default().checkPropTypes(shape, secondaryButton, propName, componentName);
    });
  }

  return null;
}), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "selectorPrimaryFocus", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().string)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "selectorsFloatingMenus", prop_types__WEBPACK_IMPORTED_MODULE_18___default().arrayOf((prop_types__WEBPACK_IMPORTED_MODULE_18___default().string))), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "shouldSubmitOnEnter", (prop_types__WEBPACK_IMPORTED_MODULE_18___default().bool)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defineProperty2, "size", prop_types__WEBPACK_IMPORTED_MODULE_18___default().oneOf(['xs', 'sm', 'md', 'lg'])), _defineProperty2));

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(Modal, "defaultProps", {
  onRequestClose: function onRequestClose() {},
  onRequestSubmit: function onRequestSubmit() {},
  primaryButtonDisabled: false,
  onKeyDown: function onKeyDown() {},
  passiveModal: false,
  modalHeading: '',
  modalLabel: '',
  preventCloseOnClickOutside: false,
  selectorPrimaryFocus: '[data-modal-primary-focus]',
  hasScrollingContent: false
});



/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Modal/index.js":
/*!*******************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Modal/index.js ***!
  \*******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @carbon/feature-flags */ "../../node_modules/@carbon/feature-flags/es/index.js");
/* harmony import */ var _next_Modal__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./next/Modal */ "../../node_modules/carbon-components-react/es/components/Modal/next/Modal.js");
/* harmony import */ var _Modal__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./Modal */ "../../node_modules/carbon-components-react/es/components/Modal/Modal.js");
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */



var Modal = _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_0__.enabled('enable-v11-release') ? _next_Modal__WEBPACK_IMPORTED_MODULE_1__["default"] : _Modal__WEBPACK_IMPORTED_MODULE_2__["default"];
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Modal);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Modal/next/Modal.js":
/*!************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Modal/next/Modal.js ***!
  \************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_12___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_12__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var _tools_toggleClass__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../../../tools/toggleClass */ "../../node_modules/carbon-components-react/es/tools/toggleClass.js");
/* harmony import */ var _Button__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../Button */ "../../node_modules/carbon-components-react/es/components/Button/Button.js");
/* harmony import */ var _ButtonSet__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../../ButtonSet */ "../../node_modules/carbon-components-react/es/components/ButtonSet/ButtonSet.js");
/* harmony import */ var _prop_types_deprecate__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../../../prop-types/deprecate */ "../../node_modules/carbon-components-react/es/prop-types/deprecate.js");
/* harmony import */ var _prop_types_requiredIfGivenPropIsTruthy__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../../../prop-types/requiredIfGivenPropIsTruthy */ "../../node_modules/carbon-components-react/es/prop-types/requiredIfGivenPropIsTruthy.js");
/* harmony import */ var _internal_wrapFocus__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../../internal/wrapFocus */ "../../node_modules/carbon-components-react/es/internal/wrapFocus.js");
/* harmony import */ var _tools_setupGetInstanceId__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../../tools/setupGetInstanceId */ "../../node_modules/carbon-components-react/es/tools/setupGetInstanceId.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");




var _Modal$propTypes;

var _excluded = ["children", "className", "modalHeading", "modalLabel", "modalAriaLabel", "passiveModal", "hasForm", "secondaryButtonText", "primaryButtonText", "open", "onRequestClose", "onRequestSubmit", "onSecondarySubmit", "iconDescription", "primaryButtonDisabled", "danger", "alert", "secondaryButtons", "selectorPrimaryFocus", "selectorsFloatingMenus", "shouldSubmitOnEnter", "size", "hasScrollingContent", "closeButtonLabel", "preventCloseOnClickOutside"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */












var getInstanceId = (0,_tools_setupGetInstanceId__WEBPACK_IMPORTED_MODULE_5__["default"])();
var Modal = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().forwardRef(function Modal(_ref, ref) {
  var _classNames, _classNames3;

  var children = _ref.children,
      className = _ref.className,
      modalHeading = _ref.modalHeading,
      modalLabel = _ref.modalLabel,
      modalAriaLabel = _ref.modalAriaLabel,
      passiveModal = _ref.passiveModal,
      hasForm = _ref.hasForm,
      secondaryButtonText = _ref.secondaryButtonText,
      primaryButtonText = _ref.primaryButtonText,
      open = _ref.open,
      onRequestClose = _ref.onRequestClose,
      onRequestSubmit = _ref.onRequestSubmit,
      onSecondarySubmit = _ref.onSecondarySubmit,
      iconDescription = _ref.iconDescription,
      primaryButtonDisabled = _ref.primaryButtonDisabled,
      danger = _ref.danger,
      alert = _ref.alert,
      secondaryButtons = _ref.secondaryButtons,
      selectorPrimaryFocus = _ref.selectorPrimaryFocus,
      selectorsFloatingMenus = _ref.selectorsFloatingMenus,
      shouldSubmitOnEnter = _ref.shouldSubmitOnEnter,
      size = _ref.size,
      hasScrollingContent = _ref.hasScrollingContent,
      closeButtonLabel = _ref.closeButtonLabel,
      preventCloseOnClickOutside = _ref.preventCloseOnClickOutside,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_6__.usePrefix)();
  var button = (0,react__WEBPACK_IMPORTED_MODULE_3__.useRef)();
  var secondaryButton = (0,react__WEBPACK_IMPORTED_MODULE_3__.useRef)();
  var innerModal = (0,react__WEBPACK_IMPORTED_MODULE_3__.useRef)();
  var startTrap = (0,react__WEBPACK_IMPORTED_MODULE_3__.useRef)();
  var endTrap = (0,react__WEBPACK_IMPORTED_MODULE_3__.useRef)();
  var modalInstanceId = "modal-".concat(getInstanceId());
  var modalLabelId = "".concat(prefix, "--modal-header__label--").concat(modalInstanceId);
  var modalHeadingId = "".concat(prefix, "--modal-header__heading--").concat(modalInstanceId);
  var modalBodyId = "".concat(prefix, "--modal-body--").concat(modalInstanceId);
  var modalCloseButtonClass = "".concat(prefix, "--modal-close");

  function isCloseButton(element) {
    return !onSecondarySubmit && element === secondaryButton.current || element.classList.contains(modalCloseButtonClass);
  }

  function handleKeyDown(evt) {
    if (open) {
      if (evt.which === 27) {
        onRequestClose(evt);
      }

      if (evt.which === 13 && shouldSubmitOnEnter && !isCloseButton(evt.target)) {
        onRequestSubmit(evt);
      }
    }
  }

  function handleMousedown(evt) {
    if (innerModal.current && !innerModal.current.contains(evt.target) && !(0,_internal_wrapFocus__WEBPACK_IMPORTED_MODULE_7__.elementOrParentIsFloatingMenu)(evt.target, selectorsFloatingMenus) && !preventCloseOnClickOutside) {
      onRequestClose(evt);
    }
  }

  function handleBlur(_ref2) {
    var oldActiveNode = _ref2.target,
        currentActiveNode = _ref2.relatedTarget;

    if (open && currentActiveNode && oldActiveNode) {
      var bodyNode = innerModal.current;
      var startTrapNode = startTrap.current;
      var endTrapNode = endTrap.current;
      (0,_internal_wrapFocus__WEBPACK_IMPORTED_MODULE_7__["default"])({
        bodyNode: bodyNode,
        startTrapNode: startTrapNode,
        endTrapNode: endTrapNode,
        currentActiveNode: currentActiveNode,
        oldActiveNode: oldActiveNode,
        selectorsFloatingMenus: selectorsFloatingMenus
      });
    }
  }

  var onSecondaryButtonClick = onSecondarySubmit ? onSecondarySubmit : onRequestClose;
  var modalClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--modal"), (_classNames = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--modal-tall"), !passiveModal), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, 'is-visible', open), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--modal--danger"), danger), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, className, className), _classNames));
  var containerClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--modal-container"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--modal-container--").concat(size), size));
  var contentClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--modal-content"), (_classNames3 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames3, "".concat(prefix, "--modal-content--with-form"), hasForm), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames3, "".concat(prefix, "--modal-scroll-content"), hasScrollingContent), _classNames3));
  var footerClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--modal-footer"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--modal-footer--three-button"), Array.isArray(secondaryButtons) && secondaryButtons.length === 2));
  var modalButton = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("button", {
    className: modalCloseButtonClass,
    type: "button",
    onClick: onRequestClose,
    title: ariaLabel ? ariaLabel : iconDescription,
    "aria-label": closeButtonLabel ? closeButtonLabel : 'close',
    ref: button
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__.Close20, {
    "aria-hidden": "true",
    tabIndex: "-1",
    className: "".concat(modalCloseButtonClass, "__icon")
  }));
  var ariaLabel = modalLabel || ['aria-label'] || 0 || 0;
  var getAriaLabelledBy = modalLabel ? modalLabelId : modalHeadingId;
  var hasScrollingContentProps = hasScrollingContent ? {
    tabIndex: 0,
    role: 'region',
    'aria-label': ariaLabel,
    'aria-labelledby': getAriaLabelledBy
  } : {};
  var alertDialogProps = {};

  if (alert && passiveModal) {
    alertDialogProps.role = 'alert';
  }

  if (alert && !passiveModal) {
    alertDialogProps.role = 'alertdialog';
    alertDialogProps['aria-describedby'] = modalBodyId;
  }

  (0,react__WEBPACK_IMPORTED_MODULE_3__.useEffect)(function () {
    return function () {
      (0,_tools_toggleClass__WEBPACK_IMPORTED_MODULE_9__["default"])(document.body, "".concat(prefix, "--body--with-modal-open"), false);
    };
  }, [prefix]);
  (0,react__WEBPACK_IMPORTED_MODULE_3__.useEffect)(function () {
    (0,_tools_toggleClass__WEBPACK_IMPORTED_MODULE_9__["default"])(document.body, "".concat(prefix, "--body--with-modal-open"), open);
  }, [open, prefix]);
  (0,react__WEBPACK_IMPORTED_MODULE_3__.useEffect)(function () {
    var initialFocus = function initialFocus(focusContainerElement) {
      var containerElement = focusContainerElement || innerModal.current;
      var primaryFocusElement = containerElement ? containerElement.querySelector(selectorPrimaryFocus) : null;

      if (primaryFocusElement) {
        return primaryFocusElement;
      }

      return button && button.current;
    };

    var focusButton = function focusButton(focusContainerElement) {
      var target = initialFocus(focusContainerElement);

      if (target) {
        target.focus();
      }
    };

    if (open) {
      focusButton(innerModal.current);
    }
  }, [open, selectorPrimaryFocus]);
  var modalBody = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    ref: innerModal,
    role: "dialog"
  }, alertDialogProps, {
    className: containerClasses,
    "aria-label": ariaLabel,
    "aria-modal": "true",
    tabIndex: "-1"
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: "".concat(prefix, "--modal-header")
  }, passiveModal && modalButton, modalLabel && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("h2", {
    id: modalLabelId,
    className: "".concat(prefix, "--modal-header__label")
  }, modalLabel), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("h3", {
    id: modalHeadingId,
    className: "".concat(prefix, "--modal-header__heading")
  }, modalHeading), !passiveModal && modalButton), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    id: modalBodyId,
    className: contentClasses
  }, hasScrollingContentProps, {
    "aria-labelledby": getAriaLabelledBy
  }), children), hasScrollingContent && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: "".concat(prefix, "--modal-content--overflow-indicator")
  }), !passiveModal && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_ButtonSet__WEBPACK_IMPORTED_MODULE_10__["default"], {
    className: footerClasses
  }, Array.isArray(secondaryButtons) && secondaryButtons.length <= 2 ? secondaryButtons.map(function (_ref3, i) {
    var buttonText = _ref3.buttonText,
        onButtonClick = _ref3.onClick;
    return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_Button__WEBPACK_IMPORTED_MODULE_11__["default"], {
      key: "".concat(buttonText, "-").concat(i),
      kind: "secondary",
      onClick: onButtonClick
    }, buttonText);
  }) : secondaryButtonText && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_Button__WEBPACK_IMPORTED_MODULE_11__["default"], {
    kind: "secondary",
    onClick: onSecondaryButtonClick,
    ref: secondaryButton
  }, secondaryButtonText), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_Button__WEBPACK_IMPORTED_MODULE_11__["default"], {
    kind: danger ? 'danger' : 'primary',
    disabled: primaryButtonDisabled,
    onClick: onRequestSubmit,
    ref: button
  }, primaryButtonText)));
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, rest, {
    onKeyDown: handleKeyDown,
    onMouseDown: handleMousedown,
    onBlur: handleBlur,
    className: modalClasses,
    role: "presentation",
    ref: ref
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("span", {
    ref: startTrap,
    tabIndex: "0",
    role: "link",
    className: "".concat(prefix, "--visually-hidden")
  }, "Focus sentinel"), modalBody, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("span", {
    ref: endTrap,
    tabIndex: "0",
    role: "link",
    className: "".concat(prefix, "--visually-hidden")
  }, "Focus sentinel"));
});
Modal.propTypes = (_Modal$propTypes = {
  /**
   * Specify whether the Modal is displaying an alert, error or warning
   * Should go hand in hand with the danger prop.
   */
  alert: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().bool)
}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, 'aria-label', (0,_prop_types_requiredIfGivenPropIsTruthy__WEBPACK_IMPORTED_MODULE_13__["default"])('hasScrollingContent', (prop_types__WEBPACK_IMPORTED_MODULE_12___default().string))), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "children", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().node)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "className", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().string)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "closeButtonLabel", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().string)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "danger", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().bool)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "focusTrap", (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_14__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_12___default().bool), "\nThe prop `focusTrap` for Modal has been deprecated, as the feature of `focusTrap` runs by default.")), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "hasForm", (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_14__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_12___default().bool), "\nThe prop `hasForm` for Modal has been deprecated, as the feature of `hasForm` runs by default.")), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "hasScrollingContent", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().bool)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "iconDescription", (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_14__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_12___default().string), 'The iconDescription prop is no longer needed and can be safely removed. This prop will be removed in the next major release of Carbon.')), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "id", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().string)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "modalAriaLabel", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().string)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "modalHeading", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().node)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "modalLabel", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().node)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "onKeyDown", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "onRequestClose", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "onRequestSubmit", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "onSecondarySubmit", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "open", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().bool)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "passiveModal", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().bool)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "preventCloseOnClickOutside", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().bool)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "primaryButtonDisabled", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().bool)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "primaryButtonText", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().node)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "secondaryButtonText", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().node)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "secondaryButtons", function secondaryButtons(props, propName, componentName) {
  if (props.secondaryButtons) {
    if (!Array.isArray(props.secondaryButtons) || props.secondaryButtons.length !== 2) {
      return new Error("".concat(propName, " needs to be an array of two button config objects"));
    }

    var shape = {
      buttonText: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().node),
      onClick: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func)
    };
    props[propName].forEach(function (secondaryButton) {
      prop_types__WEBPACK_IMPORTED_MODULE_12___default().checkPropTypes(shape, secondaryButton, propName, componentName);
    });
  }

  return null;
}), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "selectorPrimaryFocus", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().string)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "selectorsFloatingMenus", prop_types__WEBPACK_IMPORTED_MODULE_12___default().arrayOf((prop_types__WEBPACK_IMPORTED_MODULE_12___default().string))), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "shouldSubmitOnEnter", (prop_types__WEBPACK_IMPORTED_MODULE_12___default().bool)), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_Modal$propTypes, "size", prop_types__WEBPACK_IMPORTED_MODULE_12___default().oneOf(['xs', 'sm', 'md', 'lg'])), _Modal$propTypes);
Modal.defaultProps = {
  onRequestClose: function onRequestClose() {},
  onRequestSubmit: function onRequestSubmit() {},
  primaryButtonDisabled: false,
  onKeyDown: function onKeyDown() {},
  passiveModal: false,
  modalHeading: '',
  modalLabel: '',
  preventCloseOnClickOutside: false,
  selectorPrimaryFocus: '[data-modal-primary-focus]',
  hasScrollingContent: false
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Modal);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/MultiSelect/FilterableMultiSelect.js":
/*!*****************************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/MultiSelect/FilterableMultiSelect.js ***!
  \*****************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ FilterableMultiSelect)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-29.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */ var downshift__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! downshift */ "../../node_modules/carbon-components-react/node_modules/downshift/dist/downshift.esm.js");
/* harmony import */ var lodash_isequal__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! lodash.isequal */ "../../node_modules/lodash.isequal/index.js");
/* harmony import */ var lodash_isequal__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(lodash_isequal__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_23___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_23__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_10___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_10__);
/* harmony import */ var _ComboBox_tools_filter__WEBPACK_IMPORTED_MODULE_28__ = __webpack_require__(/*! ../ComboBox/tools/filter */ "../../node_modules/carbon-components-react/es/components/ComboBox/tools/filter.js");
/* harmony import */ var _MultiSelectPropTypes__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(/*! ./MultiSelectPropTypes */ "../../node_modules/carbon-components-react/es/components/MultiSelect/MultiSelectPropTypes.js");
/* harmony import */ var _ListBox__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ../ListBox */ "../../node_modules/carbon-components-react/es/components/ListBox/index.js");
/* harmony import */ var _ListBox__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(/*! ../ListBox */ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxPropTypes.js");
/* harmony import */ var _ListBox_next__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ../ListBox/next */ "../../node_modules/carbon-components-react/es/components/ListBox/next/ListBoxSelection.js");
/* harmony import */ var _ListBox_next__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ../ListBox/next */ "../../node_modules/carbon-components-react/es/components/ListBox/next/ListBoxTrigger.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/match.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/keys.js");
/* harmony import */ var _internal_Selection__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../../internal/Selection */ "../../node_modules/carbon-components-react/es/internal/Selection.js");
/* harmony import */ var _tools_createPropAdapter__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ../../tools/createPropAdapter */ "../../node_modules/carbon-components-react/es/tools/createPropAdapter.js");
/* harmony import */ var _tools_itemToString__WEBPACK_IMPORTED_MODULE_29__ = __webpack_require__(/*! ./tools/itemToString */ "../../node_modules/carbon-components-react/es/components/MultiSelect/tools/itemToString.js");
/* harmony import */ var _tools_mergeRefs__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ../../tools/mergeRefs */ "../../node_modules/carbon-components-react/es/tools/mergeRefs.js");
/* harmony import */ var _tools_setupGetInstanceId__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../tools/setupGetInstanceId */ "../../node_modules/carbon-components-react/es/tools/setupGetInstanceId.js");
/* harmony import */ var _tools_sorting__WEBPACK_IMPORTED_MODULE_27__ = __webpack_require__(/*! ./tools/sorting */ "../../node_modules/carbon-components-react/es/components/MultiSelect/tools/sorting.js");
/* harmony import */ var _FeatureFlags__WEBPACK_IMPORTED_MODULE_26__ = __webpack_require__(/*! ../FeatureFlags */ "../../node_modules/carbon-components-react/es/components/FeatureFlags/index.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");









function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_6__["default"])(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_6__["default"])(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_5__["default"])(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */



















var getInstanceId = (0,_tools_setupGetInstanceId__WEBPACK_IMPORTED_MODULE_11__["default"])();

var FilterableMultiSelect = /*#__PURE__*/function (_React$Component) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(FilterableMultiSelect, _React$Component);

  var _super = _createSuper(FilterableMultiSelect);

  function FilterableMultiSelect(props) {
    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_1__["default"])(this, FilterableMultiSelect);

    _this = _super.call(this, props);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_3__["default"])(_this), "handleOnChange", function (changes) {
      if (_this.props.onChange) {
        _this.props.onChange(changes);
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_3__["default"])(_this), "handleOnMenuChange", function (isOpen) {
      _this.setState(function (state) {
        return {
          isOpen: isOpen !== null && isOpen !== void 0 ? isOpen : !state.isOpen
        };
      });

      if (_this.props.onMenuChange) {
        _this.props.onMenuChange(isOpen);
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_3__["default"])(_this), "handleOnOuterClick", function () {
      _this.handleOnMenuChange(false);
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_3__["default"])(_this), "handleOnStateChange", function (changes, downshift) {
      if (changes.isOpen && !_this.state.isOpen) {
        _this.setState({
          topItems: downshift.selectedItem
        });
      }

      var type = changes.type;
      var stateChangeTypes = downshift__WEBPACK_IMPORTED_MODULE_12__["default"].stateChangeTypes;

      switch (type) {
        case stateChangeTypes.keyDownArrowDown:
        case stateChangeTypes.keyDownArrowUp:
        case stateChangeTypes.keyDownHome:
        case stateChangeTypes.keyDownEnd:
          _this.setState({
            highlightedIndex: changes.highlightedIndex !== undefined ? changes.highlightedIndex : null
          });

          if (stateChangeTypes.keyDownArrowDown === type && !_this.state.isOpen) {
            _this.handleOnMenuChange(true);
          }

          break;

        case stateChangeTypes.keyDownEscape:
          _this.handleOnMenuChange(false);

          break;
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_3__["default"])(_this), "handleOnInputKeyDown", function (event) {
      event.stopPropagation();
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_3__["default"])(_this), "handleOnInputValueChange", function (inputValue, _ref) {
      var type = _ref.type;

      if (type !== downshift__WEBPACK_IMPORTED_MODULE_12__["default"].stateChangeTypes.changeInput) {
        return;
      }

      _this.setState(function () {
        if (Array.isArray(inputValue)) {
          return {
            inputValue: ''
          };
        }

        return {
          inputValue: inputValue || ''
        };
      });

      if (inputValue && !_this.state.isOpen) {
        _this.handleOnMenuChange(true);
      } else if (!inputValue && _this.state.isOpen) {
        _this.handleOnMenuChange(false);
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_3__["default"])(_this), "clearInputValue", function () {
      _this.setState({
        inputValue: ''
      }, function () {
        if (_this.textInput.current) {
          _this.textInput.current.focus();
        }
      });
    });

    _this.filterableMultiSelectInstanceId = getInstanceId();
    _this.state = {
      isOpen: props.open,
      inputValue: '',
      topItems: [],
      inputFocused: false,
      highlightedIndex: null
    };
    _this.textInput = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createRef();
    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(FilterableMultiSelect, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$state = this.state,
          highlightedIndex = _this$state.highlightedIndex,
          isOpen = _this$state.isOpen,
          inputValue = _this$state.inputValue;
      var _this$props = this.props,
          ariaLabel = _this$props.ariaLabel,
          containerClassName = _this$props.className,
          direction = _this$props.direction,
          disabled = _this$props.disabled,
          filterItems = _this$props.filterItems,
          items = _this$props.items,
          itemToElement = _this$props.itemToElement,
          itemToString = _this$props.itemToString,
          titleText = _this$props.titleText,
          hideLabel = _this$props.hideLabel,
          helperText = _this$props.helperText,
          type = _this$props.type,
          initialSelectedItems = _this$props.initialSelectedItems,
          id = _this$props.id,
          locale = _this$props.locale,
          size = _this$props.size,
          placeholder = _this$props.placeholder,
          sortItems = _this$props.sortItems,
          compareItems = _this$props.compareItems,
          light = _this$props.light,
          invalid = _this$props.invalid,
          invalidText = _this$props.invalidText,
          warn = _this$props.warn,
          warnText = _this$props.warnText,
          useTitleInItem = _this$props.useTitleInItem,
          translateWithId = _this$props.translateWithId,
          downshiftProps = _this$props.downshiftProps;
      var inline = type === 'inline';
      var showWarning = !invalid && warn; // needs to be capitalized for react to render it correctly

      var ItemToElement = itemToElement;
      var scope = this.context;
      var enabled;

      if (scope.enabled) {
        enabled = scope.enabled('enable-v11-release');
      }

      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement(_internal_usePrefix__WEBPACK_IMPORTED_MODULE_13__.PrefixContext.Consumer, null, function (prefix) {
        var _cx, _cx2, _cx3, _cx4;

        var wrapperClasses = classnames__WEBPACK_IMPORTED_MODULE_8___default()("".concat(prefix, "--multi-select__wrapper"), "".concat(prefix, "--list-box__wrapper"), [enabled ? containerClassName : null], (_cx = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx, "".concat(prefix, "--multi-select__wrapper--inline"), inline), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx, "".concat(prefix, "--list-box__wrapper--inline"), inline), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx, "".concat(prefix, "--multi-select__wrapper--inline--invalid"), inline && invalid), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx, "".concat(prefix, "--list-box__wrapper--inline--invalid"), inline && invalid), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx, "".concat(prefix, "--list-box--up"), direction === 'top'), _cx));
        var helperId = !helperText ? undefined : "filterablemultiselect-helper-text-".concat(_this2.filterableMultiSelectInstanceId);
        var labelId = "".concat(id, "-label");
        var titleClasses = classnames__WEBPACK_IMPORTED_MODULE_8___default()((_cx2 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx2, "".concat(prefix, "--label"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx2, "".concat(prefix, "--label--disabled"), disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx2, "".concat(prefix, "--visually-hidden"), hideLabel), _cx2));
        var helperClasses = classnames__WEBPACK_IMPORTED_MODULE_8___default()((_cx3 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx3, "".concat(prefix, "--form__helper-text"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx3, "".concat(prefix, "--form__helper-text--disabled"), disabled), _cx3));
        var inputClasses = classnames__WEBPACK_IMPORTED_MODULE_8___default()((_cx4 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx4, "".concat(prefix, "--text-input"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx4, "".concat(prefix, "--text-input--empty"), !_this2.state.inputValue), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx4, "".concat(prefix, "--text-input--light"), light), _cx4));
        var helper = helperText ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement("div", {
          id: helperId,
          className: helperClasses
        }, helperText) : null;
        var menuId = "".concat(id, "__menu");
        var inputId = "".concat(id, "-input");
        return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement(_internal_Selection__WEBPACK_IMPORTED_MODULE_14__["default"], {
          disabled: disabled,
          onChange: _this2.handleOnChange,
          initialSelectedItems: initialSelectedItems,
          render: function render(_ref2) {
            var selectedItems = _ref2.selectedItems,
                onItemChange = _ref2.onItemChange,
                _clearSelection = _ref2.clearSelection;
            return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement(downshift__WEBPACK_IMPORTED_MODULE_12__["default"], (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, (0,_tools_createPropAdapter__WEBPACK_IMPORTED_MODULE_15__.mapDownshiftProps)(downshiftProps), {
              highlightedIndex: highlightedIndex,
              id: id,
              isOpen: isOpen,
              inputValue: inputValue,
              onInputValueChange: _this2.handleOnInputValueChange,
              onChange: function onChange(selectedItem) {
                if (selectedItem !== null) {
                  onItemChange(selectedItem);
                }
              },
              itemToString: itemToString,
              onStateChange: _this2.handleOnStateChange,
              onOuterClick: _this2.handleOnOuterClick,
              selectedItem: selectedItems,
              labelId: labelId,
              menuId: menuId,
              inputId: inputId
            }), function (_ref3) {
              var _cx5;

              var getInputProps = _ref3.getInputProps,
                  getItemProps = _ref3.getItemProps,
                  getLabelProps = _ref3.getLabelProps,
                  getMenuProps = _ref3.getMenuProps,
                  getRootProps = _ref3.getRootProps,
                  getToggleButtonProps = _ref3.getToggleButtonProps,
                  isOpen = _ref3.isOpen,
                  inputValue = _ref3.inputValue,
                  selectedItem = _ref3.selectedItem;
              var className = classnames__WEBPACK_IMPORTED_MODULE_8___default()("".concat(prefix, "--multi-select"), "".concat(prefix, "--combo-box"), "".concat(prefix, "--multi-select--filterable"), [enabled ? null : containerClassName], (_cx5 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx5, "".concat(prefix, "--multi-select--invalid"), invalid), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx5, "".concat(prefix, "--multi-select--open"), isOpen), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx5, "".concat(prefix, "--multi-select--inline"), inline), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx5, "".concat(prefix, "--multi-select--selected"), selectedItem.length > 0), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_cx5, "".concat(prefix, "--multi-select--filterable--input-focused"), _this2.state.inputFocused), _cx5));
              var rootProps = getRootProps({}, {
                suppressRefError: true
              });
              var labelProps = getLabelProps();
              var buttonProps = getToggleButtonProps({
                disabled: disabled,
                onClick: function onClick() {
                  _this2.handleOnMenuChange(!_this2.state.isOpen);

                  if (_this2.textInput.current) {
                    _this2.textInput.current.focus();
                  }
                },
                // When we moved the "root node" of Downshift to the <input> for
                // ARIA 1.2 compliance, we unfortunately hit this branch for the
                // "mouseup" event that downshift listens to:
                // https://github.com/downshift-js/downshift/blob/v5.2.1/src/downshift.js#L1051-L1065
                //
                // As a result, it will reset the state of the component and so we
                // stop the event from propagating to prevent this. This allows the
                // toggleMenu behavior for the toggleButton to correctly open and
                // close the menu.
                onMouseUp: function onMouseUp(event) {
                  event.stopPropagation();
                }
              });
              var inputProps = getInputProps({
                'aria-controls': isOpen ? menuId : null,
                'aria-describedby': helperText ? helperId : null,
                // Remove excess aria `aria-labelledby`. HTML <label for>
                // provides this aria information.
                'aria-labelledby': null,
                disabled: disabled,
                placeholder: placeholder,
                onClick: function onClick() {
                  _this2.handleOnMenuChange(true);
                },
                onKeyDown: function onKeyDown(event) {
                  if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_16__.match)(event, _internal_keyboard__WEBPACK_IMPORTED_MODULE_17__.Space)) {
                    event.stopPropagation();
                  }
                },
                onFocus: function onFocus() {
                  _this2.setState({
                    inputFocused: true
                  });
                },
                onBlur: function onBlur() {
                  _this2.setState({
                    inputFocused: false
                  });
                }
              });
              var menuProps = getMenuProps({
                'aria-label': ariaLabel
              }, {
                suppressRefError: true
              });
              return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement("div", {
                className: wrapperClasses
              }, titleText ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement("label", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
                className: titleClasses
              }, labelProps), titleText) : null, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_18__["default"], {
                className: className,
                disabled: disabled,
                light: light,
                invalid: invalid,
                invalidText: invalidText,
                warn: warn,
                warnText: warnText,
                isOpen: isOpen,
                size: size
              }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement("div", {
                className: "".concat(prefix, "--list-box__field")
              }, selectedItem.length > 0 && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement(_ListBox_next__WEBPACK_IMPORTED_MODULE_19__["default"], {
                clearSelection: function clearSelection() {
                  _clearSelection();

                  if (_this2.textInput.current) {
                    _this2.textInput.current.focus();
                  }
                },
                selectionCount: selectedItem.length,
                translateWithId: translateWithId,
                disabled: disabled
              }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement("input", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
                className: inputClasses
              }, rootProps, inputProps, {
                ref: (0,_tools_mergeRefs__WEBPACK_IMPORTED_MODULE_20__["default"])(_this2.textInput, rootProps.ref)
              })), invalid && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_21__.WarningFilled16, {
                className: "".concat(prefix, "--list-box__invalid-icon")
              }), showWarning && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_21__.WarningAltFilled16, {
                className: "".concat(prefix, "--list-box__invalid-icon ").concat(prefix, "--list-box__invalid-icon--warning")
              }), inputValue && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement(_ListBox_next__WEBPACK_IMPORTED_MODULE_19__["default"], {
                clearSelection: _this2.clearInputValue,
                disabled: disabled,
                translateWithId: translateWithId,
                onMouseUp: function onMouseUp(event) {
                  // If we do not stop this event from propagating,
                  // it seems like Downshift takes our event and
                  // prevents us from getting `onClick` /
                  // `clearSelection` from the underlying <button> in
                  // ListBoxSelection
                  event.stopPropagation();
                }
              }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement(_ListBox_next__WEBPACK_IMPORTED_MODULE_22__["default"], (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, buttonProps, {
                isOpen: isOpen,
                translateWithId: translateWithId
              }))), isOpen ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_18__["default"].Menu, menuProps, sortItems(filterItems(items, {
                itemToString: itemToString,
                inputValue: inputValue
              }), {
                selectedItems: {
                  top: selectedItems,
                  fixed: [],
                  'top-after-reopen': _this2.state.topItems
                }[_this2.props.selectionFeedback],
                itemToString: itemToString,
                compareItems: compareItems,
                locale: locale
              }).map(function (item, index) {
                var itemProps = getItemProps({
                  item: item,
                  disabled: item.disabled
                });
                var itemText = itemToString(item);
                var isChecked = selectedItem.filter(function (selected) {
                  return lodash_isequal__WEBPACK_IMPORTED_MODULE_9___default()(selected, item);
                }).length > 0;
                return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_18__["default"].MenuItem, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
                  key: itemProps.id,
                  "aria-label": itemText,
                  isActive: isChecked,
                  isHighlighted: highlightedIndex === index,
                  title: itemText
                }, itemProps), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement("div", {
                  className: "".concat(prefix, "--checkbox-wrapper")
                }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement("span", {
                  title: useTitleInItem ? itemText : null,
                  className: "".concat(prefix, "--checkbox-label"),
                  "data-contained-checkbox-state": isChecked,
                  id: "".concat(itemProps.id, "-item")
                }, itemToElement ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement(ItemToElement, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
                  key: itemProps.id
                }, item)) : itemText)));
              })) : null), !inline && !invalid && !warn ? helper : null);
            });
          }
        });
      });
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(_ref4, state) {
      var open = _ref4.open;

      /**
       * programmatically control this `open` prop
       */
      var prevOpen = state.prevOpen;
      return prevOpen === open ? null : {
        isOpen: open,
        prevOpen: open
      };
    }
  }]);

  return FilterableMultiSelect;
}((react__WEBPACK_IMPORTED_MODULE_10___default().Component));

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(FilterableMultiSelect, "propTypes", _objectSpread(_objectSpread({
  /**
   * 'aria-label' of the ListBox component.
   */
  ariaLabel: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().string),

  /**
   * Specify the direction of the multiselect dropdown. Can be either top or bottom.
   */
  direction: prop_types__WEBPACK_IMPORTED_MODULE_23___default().oneOf(['top', 'bottom']),

  /**
   * Disable the control
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().bool),

  /**
   * Additional props passed to Downshift
   */
  downshiftProps: prop_types__WEBPACK_IMPORTED_MODULE_23___default().shape(downshift__WEBPACK_IMPORTED_MODULE_12__["default"].propTypes),

  /**
   * Specify whether the title text should be hidden or not
   */
  hideLabel: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().bool),

  /**
   * Specify a custom `id`
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().string.isRequired),

  /**
   * Allow users to pass in arbitrary items from their collection that are
   * pre-selected
   */
  initialSelectedItems: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().array),

  /**
   * Is the current selection invalid?
   */
  invalid: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().bool),

  /**
   * If invalid, what is the error?
   */
  invalidText: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().node),

  /**
   * Function to render items as custom components instead of strings.
   * Defaults to null and is overridden by a getter
   */
  itemToElement: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().func),

  /**
   * Helper function passed to downshift that allows the library to render a
   * given item to a string label. By default, it extracts the `label` field
   * from a given item to serve as the item label in the list.
   */
  itemToString: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().func),

  /**
   * We try to stay as generic as possible here to allow individuals to pass
   * in a collection of whatever kind of data structure they prefer
   */
  items: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().array.isRequired),

  /**
   * `true` to use the light version.
   */
  light: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().bool),

  /**
   * Specify the locale of the control. Used for the default `compareItems`
   * used for sorting the list of items in the control.
   */
  locale: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().string),

  /**
   * `onChange` is a utility for this controlled component to communicate to a
   * consuming component what kind of internal state changes are occurring.
   */
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().func),

  /**
   * `onMenuChange` is a utility for this controlled component to communicate to a
   * consuming component that the menu was opened(`true`)/closed(`false`).
   */
  onMenuChange: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().func),

  /**
   * Initialize the component with an open(`true`)/closed(`false`) menu.
   */
  open: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().bool),

  /**
   * Generic `placeholder` that will be used as the textual representation of
   * what this field is for
   */
  placeholder: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().string.isRequired),

  /**
   * Specify feedback (mode) of the selection.
   * `top`: selected item jumps to top
   * `fixed`: selected item stays at it's position
   * `top-after-reopen`: selected item jump to top after reopen dropdown
   */
  selectionFeedback: prop_types__WEBPACK_IMPORTED_MODULE_23___default().oneOf(['top', 'fixed', 'top-after-reopen']),

  /**
   * Specify the size of the ListBox. Currently supports either `sm`, `md` or `lg` as an option.
   */
  size: _ListBox__WEBPACK_IMPORTED_MODULE_24__.ListBoxSize
}, _MultiSelectPropTypes__WEBPACK_IMPORTED_MODULE_25__.sortingPropTypes), {}, {
  /**
   * Callback function for translating ListBoxMenuIcon SVG title
   */
  translateWithId: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().func),

  /**
   * Specify title to show title on hover
   */
  useTitleInItem: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().bool),

  /**
   * Specify whether the control is currently in warning state
   */
  warn: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().bool),

  /**
   * Provide the text that is displayed when the control is in warning state
   */
  warnText: (prop_types__WEBPACK_IMPORTED_MODULE_23___default().node)
}));

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(FilterableMultiSelect, "contextType", _FeatureFlags__WEBPACK_IMPORTED_MODULE_26__.FeatureFlagContext);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(FilterableMultiSelect, "defaultProps", {
  ariaLabel: 'Choose an item',
  compareItems: _tools_sorting__WEBPACK_IMPORTED_MODULE_27__.defaultCompareItems,
  direction: 'bottom',
  disabled: false,
  filterItems: _ComboBox_tools_filter__WEBPACK_IMPORTED_MODULE_28__.defaultFilterItems,
  initialSelectedItems: [],
  itemToString: _tools_itemToString__WEBPACK_IMPORTED_MODULE_29__.defaultItemToString,
  locale: 'en',
  sortItems: _tools_sorting__WEBPACK_IMPORTED_MODULE_27__.defaultSortItems,
  light: false,
  open: false,
  selectionFeedback: 'top-after-reopen'
});



/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/MultiSelect/MultiSelect.js":
/*!*******************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/MultiSelect/MultiSelect.js ***!
  \*******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-29.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var downshift__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! downshift */ "../../node_modules/carbon-components-react/node_modules/downshift/dist/downshift.esm.js");
/* harmony import */ var lodash_isequal__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! lodash.isequal */ "../../node_modules/lodash.isequal/index.js");
/* harmony import */ var lodash_isequal__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(lodash_isequal__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_18___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_18__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var _ListBox__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../ListBox */ "../../node_modules/carbon-components-react/es/components/ListBox/index.js");
/* harmony import */ var _ListBox__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ../ListBox */ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxPropTypes.js");
/* harmony import */ var _MultiSelectPropTypes__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./MultiSelectPropTypes */ "../../node_modules/carbon-components-react/es/components/MultiSelect/MultiSelectPropTypes.js");
/* harmony import */ var _tools_itemToString__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ./tools/itemToString */ "../../node_modules/carbon-components-react/es/components/MultiSelect/tools/itemToString.js");
/* harmony import */ var _tools_sorting__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./tools/sorting */ "../../node_modules/carbon-components-react/es/components/MultiSelect/tools/sorting.js");
/* harmony import */ var _internal_Selection__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../../internal/Selection */ "../../node_modules/carbon-components-react/es/internal/Selection.js");
/* harmony import */ var _tools_setupGetInstanceId__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../tools/setupGetInstanceId */ "../../node_modules/carbon-components-react/es/tools/setupGetInstanceId.js");
/* harmony import */ var _tools_createPropAdapter__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../../tools/createPropAdapter */ "../../node_modules/carbon-components-react/es/tools/createPropAdapter.js");
/* harmony import */ var _tools_mergeRefs__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ../../tools/mergeRefs */ "../../node_modules/carbon-components-react/es/tools/mergeRefs.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/match.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/keys.js");
/* harmony import */ var _FeatureFlags__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../FeatureFlags */ "../../node_modules/carbon-components-react/es/components/FeatureFlags/index.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");




function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */


















var noop = function noop() {};

var getInstanceId = (0,_tools_setupGetInstanceId__WEBPACK_IMPORTED_MODULE_6__["default"])();
var _useSelect$stateChang = downshift__WEBPACK_IMPORTED_MODULE_7__.useSelect.stateChangeTypes,
    ItemClick = _useSelect$stateChang.ItemClick,
    MenuBlur = _useSelect$stateChang.MenuBlur,
    MenuKeyDownArrowDown = _useSelect$stateChang.MenuKeyDownArrowDown,
    MenuKeyDownArrowUp = _useSelect$stateChang.MenuKeyDownArrowUp,
    MenuKeyDownEnter = _useSelect$stateChang.MenuKeyDownEnter,
    MenuKeyDownEscape = _useSelect$stateChang.MenuKeyDownEscape,
    MenuKeyDownSpaceButton = _useSelect$stateChang.MenuKeyDownSpaceButton,
    ToggleButtonClick = _useSelect$stateChang.ToggleButtonClick;
var MultiSelect = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().forwardRef(function MultiSelect(_ref, ref) {
  var _cx, _cx2, _cx4;

  var containerClassName = _ref.className,
      id = _ref.id,
      items = _ref.items,
      itemToElement = _ref.itemToElement,
      _itemToString = _ref.itemToString,
      titleText = _ref.titleText,
      hideLabel = _ref.hideLabel,
      helperText = _ref.helperText,
      label = _ref.label,
      type = _ref.type,
      size = _ref.size,
      disabled = _ref.disabled,
      initialSelectedItems = _ref.initialSelectedItems,
      sortItems = _ref.sortItems,
      compareItems = _ref.compareItems,
      clearSelectionText = _ref.clearSelectionText,
      clearSelectionDescription = _ref.clearSelectionDescription,
      light = _ref.light,
      invalid = _ref.invalid,
      invalidText = _ref.invalidText,
      warn = _ref.warn,
      warnText = _ref.warnText,
      useTitleInItem = _ref.useTitleInItem,
      translateWithId = _ref.translateWithId,
      downshiftProps = _ref.downshiftProps,
      open = _ref.open,
      selectionFeedback = _ref.selectionFeedback,
      onChange = _ref.onChange,
      onMenuChange = _ref.onMenuChange,
      direction = _ref.direction,
      selected = _ref.selectedItems;
  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_8__.usePrefix)();

  var _useRef = (0,react__WEBPACK_IMPORTED_MODULE_5__.useRef)(getInstanceId()),
      multiSelectInstanceId = _useRef.current;

  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(null),
      _useState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState, 2),
      highlightedIndex = _useState2[0],
      setHighlightedIndex = _useState2[1];

  var _useState3 = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(open),
      _useState4 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState3, 2),
      isOpen = _useState4[0],
      setIsOpen = _useState4[1];

  var _useState5 = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(open),
      _useState6 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState5, 2),
      prevOpenProp = _useState6[0],
      setPrevOpenProp = _useState6[1];

  var _useState7 = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)([]),
      _useState8 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState7, 2),
      topItems = _useState8[0],
      setTopItems = _useState8[1];

  var _useSelection = (0,_internal_Selection__WEBPACK_IMPORTED_MODULE_9__.useSelection)({
    disabled: disabled,
    initialSelectedItems: initialSelectedItems,
    onChange: onChange,
    selectedItems: selected
  }),
      controlledSelectedItems = _useSelection.selectedItems,
      onItemChange = _useSelection.onItemChange,
      clearSelection = _useSelection.clearSelection;

  var _useSelect = (0,downshift__WEBPACK_IMPORTED_MODULE_7__.useSelect)((0,_tools_createPropAdapter__WEBPACK_IMPORTED_MODULE_10__.mapDownshiftProps)(_objectSpread(_objectSpread({}, downshiftProps), {}, {
    highlightedIndex: highlightedIndex,
    isOpen: isOpen,
    itemToString: function itemToString(items) {
      return items.map(function (item) {
        return _itemToString(item);
      }).join(', ');
    },
    onStateChange: onStateChange,
    selectedItem: controlledSelectedItems,
    items: items
  }))),
      getToggleButtonProps = _useSelect.getToggleButtonProps,
      getLabelProps = _useSelect.getLabelProps,
      getMenuProps = _useSelect.getMenuProps,
      getItemProps = _useSelect.getItemProps,
      selectedItems = _useSelect.selectedItem;
  /**
   * wrapper function to forward changes to consumer
   */


  var setIsOpenWrapper = function setIsOpenWrapper(open) {
    setIsOpen(open);

    if (onMenuChange) {
      onMenuChange(open);
    }
  };
  /**
   * programmatically control this `open` prop
   */


  if (prevOpenProp !== open) {
    setIsOpenWrapper(open);
    setPrevOpenProp(open);
  }

  var inline = type === 'inline';
  var showWarning = !invalid && warn;
  var enabled = (0,_FeatureFlags__WEBPACK_IMPORTED_MODULE_11__.useFeatureFlag)('enable-v11-release');
  var wrapperClasses = classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--multi-select__wrapper"), "".concat(prefix, "--list-box__wrapper"), [enabled ? containerClassName : null], (_cx = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--multi-select__wrapper--inline"), inline), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--list-box__wrapper--inline"), inline), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--multi-select__wrapper--inline--invalid"), inline && invalid), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--list-box__wrapper--inline--invalid"), inline && invalid), _cx));
  var titleClasses = classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--label"), (_cx2 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx2, "".concat(prefix, "--label--disabled"), disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx2, "".concat(prefix, "--visually-hidden"), hideLabel), _cx2));
  var helperId = !helperText ? undefined : "multiselect-helper-text-".concat(multiSelectInstanceId);
  var fieldLabelId = "multiselect-field-label-".concat(multiSelectInstanceId);
  var helperClasses = classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--form__helper-text"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--form__helper-text--disabled"), disabled));
  var className = classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--multi-select"), [enabled ? null : containerClassName], (_cx4 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx4, "".concat(prefix, "--multi-select--invalid"), invalid), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx4, "".concat(prefix, "--multi-select--warning"), showWarning), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx4, "".concat(prefix, "--multi-select--inline"), inline), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx4, "".concat(prefix, "--multi-select--selected"), selectedItems && selectedItems.length > 0), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx4, "".concat(prefix, "--list-box--up"), direction === 'top'), _cx4)); // needs to be capitalized for react to render it correctly

  var ItemToElement = itemToElement;
  var sortOptions = {
    selectedItems: controlledSelectedItems,
    itemToString: _itemToString,
    compareItems: compareItems,
    locale: 'en'
  };

  if (selectionFeedback === 'fixed') {
    sortOptions.selectedItems = [];
  } else if (selectionFeedback === 'top-after-reopen') {
    sortOptions.selectedItems = topItems;
  }

  function onStateChange(changes) {
    if (changes.isOpen && !isOpen) {
      setTopItems(controlledSelectedItems);
    }

    var type = changes.type;

    switch (type) {
      case ItemClick:
      case MenuKeyDownSpaceButton:
      case MenuKeyDownEnter:
        if (changes.selectedItem === undefined) {
          break;
        }

        onItemChange(changes.selectedItem);
        break;

      case MenuKeyDownArrowDown:
      case MenuKeyDownArrowUp:
        setHighlightedIndex(changes.highlightedIndex);
        break;

      case MenuBlur:
      case MenuKeyDownEscape:
        setIsOpenWrapper(false);
        setHighlightedIndex(changes.highlightedIndex);
        break;

      case ToggleButtonClick:
        setIsOpenWrapper(changes.isOpen || false);
        setHighlightedIndex(changes.highlightedIndex);
        break;
    }
  }

  var onKeyDown = function onKeyDown(e) {
    if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_12__.match)(e, _internal_keyboard__WEBPACK_IMPORTED_MODULE_13__.Delete) && !disabled) {
      clearSelection();
      e.stopPropagation();
    }
  };

  var toggleButtonProps = getToggleButtonProps();
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("div", {
    className: wrapperClasses
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("label", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    className: titleClasses
  }, getLabelProps()), titleText && titleText, selectedItems.length > 0 && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("span", {
    className: "".concat(prefix, "--visually-hidden")
  }, clearSelectionDescription, " ", selectedItems.length, ",", clearSelectionText)), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_14__["default"], {
    type: type,
    size: size,
    className: className,
    disabled: disabled,
    light: light,
    invalid: invalid,
    invalidText: invalidText,
    warn: warn,
    warnText: warnText,
    isOpen: isOpen,
    id: id
  }, invalid && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_15__.WarningFilled16, {
    className: "".concat(prefix, "--list-box__invalid-icon")
  }), showWarning && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_15__.WarningAltFilled16, {
    className: "".concat(prefix, "--list-box__invalid-icon ").concat(prefix, "--list-box__invalid-icon--warning")
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("button", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    type: "button",
    className: "".concat(prefix, "--list-box__field"),
    disabled: disabled,
    "aria-disabled": disabled
  }, toggleButtonProps, {
    ref: (0,_tools_mergeRefs__WEBPACK_IMPORTED_MODULE_16__["default"])(toggleButtonProps.ref, ref),
    onKeyDown: onKeyDown
  }), selectedItems.length > 0 && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_14__["default"].Selection, {
    clearSelection: !disabled ? clearSelection : noop,
    selectionCount: selectedItems.length,
    translateWithId: translateWithId,
    disabled: disabled
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("span", {
    id: fieldLabelId,
    className: "".concat(prefix, "--list-box__label")
  }, label), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_14__["default"].MenuIcon, {
    isOpen: isOpen,
    translateWithId: translateWithId
  })), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_14__["default"].Menu, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    "aria-multiselectable": "true"
  }, getMenuProps()), isOpen && sortItems(items, sortOptions).map(function (item, index) {
    var _getItemProps;

    var itemProps = getItemProps((_getItemProps = {
      item: item
    }, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_getItemProps, 'aria-selected', isChecked ? true : null), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_getItemProps, "disabled", item.disabled), _getItemProps));

    var itemText = _itemToString(item);

    var isChecked = selectedItems.filter(function (selected) {
      return lodash_isequal__WEBPACK_IMPORTED_MODULE_4___default()(selected, item);
    }).length > 0;
    return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_14__["default"].MenuItem, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
      key: itemProps.id,
      isActive: isChecked,
      "aria-label": itemText,
      isHighlighted: highlightedIndex === index,
      title: itemText
    }, itemProps), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("div", {
      className: "".concat(prefix, "--checkbox-wrapper")
    }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("span", {
      title: useTitleInItem ? itemText : null,
      className: "".concat(prefix, "--checkbox-label"),
      "data-contained-checkbox-state": isChecked,
      id: "".concat(itemProps.id, "__checkbox")
    }, itemToElement ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(ItemToElement, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
      key: itemProps.id
    }, item)) : itemText)));
  }))), !inline && !invalid && !warn && helperText && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("div", {
    id: helperId,
    className: helperClasses
  }, helperText));
});
MultiSelect.displayName = 'MultiSelect';
MultiSelect.propTypes = _objectSpread(_objectSpread({}, _MultiSelectPropTypes__WEBPACK_IMPORTED_MODULE_17__.sortingPropTypes), {}, {
  /**
   * Specify the text that should be read for screen readers that describes total items selected
   */
  clearSelectionDescription: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().string),

  /**
   * Specify the text that should be read for screen readers to clear selection.
   */
  clearSelectionText: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().string),

  /**
   * Specify the direction of the multiselect dropdown. Can be either top or bottom.
   */
  direction: prop_types__WEBPACK_IMPORTED_MODULE_18___default().oneOf(['top', 'bottom']),

  /**
   * Disable the control
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().bool),

  /**
   * Additional props passed to Downshift
   */
  downshiftProps: prop_types__WEBPACK_IMPORTED_MODULE_18___default().shape(downshift__WEBPACK_IMPORTED_MODULE_7__["default"].propTypes),

  /**
   * Specify whether the title text should be hidden or not
   */
  hideLabel: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().bool),

  /**
   * Specify a custom `id`
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().string.isRequired),

  /**
   * Allow users to pass in arbitrary items from their collection that are
   * pre-selected
   */
  initialSelectedItems: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().array),

  /**
   * Is the current selection invalid?
   */
  invalid: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().bool),

  /**
   * If invalid, what is the error?
   */
  invalidText: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().node),

  /**
   * Function to render items as custom components instead of strings.
   * Defaults to null and is overridden by a getter
   */
  itemToElement: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().func),

  /**
   * Helper function passed to downshift that allows the library to render a
   * given item to a string label. By default, it extracts the `label` field
   * from a given item to serve as the item label in the list.
   */
  itemToString: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().func),

  /**
   * We try to stay as generic as possible here to allow individuals to pass
   * in a collection of whatever kind of data structure they prefer
   */
  items: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().array.isRequired),

  /**
   * Generic `label` that will be used as the textual representation of what
   * this field is for
   */
  label: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().node.isRequired),

  /**
   * `true` to use the light version.
   */
  light: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().bool),

  /**
   * Specify the locale of the control. Used for the default `compareItems`
   * used for sorting the list of items in the control.
   */
  locale: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().string),

  /**
   * `onChange` is a utility for this controlled component to communicate to a
   * consuming component what kind of internal state changes are occurring.
   */
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().func),

  /**
   * `onMenuChange` is a utility for this controlled component to communicate to a
   * consuming component that the menu was opend(`true`)/closed(`false`).
   */
  onMenuChange: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().func),

  /**
   * Initialize the component with an open(`true`)/closed(`false`) menu.
   */
  open: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().bool),

  /**
   * For full control of the selected items
   */
  selectedItems: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().array),

  /**
   * Specify feedback (mode) of the selection.
   * `top`: selected item jumps to top
   * `fixed`: selected item stays at it's position
   * `top-after-reopen`: selected item jump to top after reopen dropdown
   */
  selectionFeedback: prop_types__WEBPACK_IMPORTED_MODULE_18___default().oneOf(['top', 'fixed', 'top-after-reopen']),

  /**
   * Specify the size of the ListBox. Currently supports either `sm`, `md` or `lg` as an option.
   */
  size: _ListBox__WEBPACK_IMPORTED_MODULE_19__.ListBoxSize,

  /**
   * Provide text to be used in a `<label>` element that is tied to the
   * multiselect via ARIA attributes.
   */
  titleText: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().node),

  /**
   * Callback function for translating ListBoxMenuIcon SVG title
   */
  translateWithId: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().func),

  /**
   * Specify 'inline' to create an inline multi-select.
   */
  type: prop_types__WEBPACK_IMPORTED_MODULE_18___default().oneOf(['default', 'inline']),

  /**
   * Specify title to show title on hover
   */
  useTitleInItem: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().bool),

  /**
   * Specify whether the control is currently in warning state
   */
  warn: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().bool),

  /**
   * Provide the text that is displayed when the control is in warning state
   */
  warnText: (prop_types__WEBPACK_IMPORTED_MODULE_18___default().node)
});
MultiSelect.defaultProps = {
  compareItems: _tools_sorting__WEBPACK_IMPORTED_MODULE_20__.defaultCompareItems,
  disabled: false,
  locale: 'en',
  itemToString: _tools_itemToString__WEBPACK_IMPORTED_MODULE_21__.defaultItemToString,
  initialSelectedItems: [],
  sortItems: _tools_sorting__WEBPACK_IMPORTED_MODULE_20__.defaultSortItems,
  type: 'default',
  light: false,
  title: false,
  open: false,
  selectionFeedback: 'top-after-reopen',
  direction: 'bottom',
  clearSelectionText: 'To clear selection, press Delete or Backspace,',
  clearSelectionDescription: 'Total items selected: ',
  selectedItems: null
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (MultiSelect);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/MultiSelect/MultiSelectPropTypes.js":
/*!****************************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/MultiSelect/MultiSelectPropTypes.js ***!
  \****************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "sortingPropTypes": () => (/* binding */ sortingPropTypes)
/* harmony export */ });
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

var sortingPropTypes = {
  /**
   * Provide a compare function that is used to determine the ordering of
   * options. `compareItems` has the following function signature:
   *
   * compareFunction :
   *  (itemA: string, itemB: string, { locale: string }) => number
   */
  compareItems: (prop_types__WEBPACK_IMPORTED_MODULE_0___default().func.isRequired),

  /**
   * Provide a method that sorts all options in the control. Overriding this
   * prop means that you also have to handle the sort logic for selected versus
   * un-selected items. If you just want to control ordering, consider the
   * `compareItems` prop instead.
   *
   * `sortItems` has the following signature:
   *
   * sortItems :
   *   (items: Array<Item>, {
   *     selectedItems: Array<Item>,
   *     itemToString: Item => string,
   *     compareItems: (itemA: string, itemB: string, {
   *       locale: string
   *     }) => number,
   *     locale: string,
   *   }) => Array<Item>
   */
  sortItems: (prop_types__WEBPACK_IMPORTED_MODULE_0___default().func.isRequired)
};

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/MultiSelect/index.js":
/*!*************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/MultiSelect/index.js ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "FilterableMultiSelect": () => (/* binding */ FilterableMultiSelect),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @carbon/feature-flags */ "../../node_modules/@carbon/feature-flags/es/index.js");
/* harmony import */ var _internal_deprecateFieldOnObject__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../internal/deprecateFieldOnObject */ "../../node_modules/carbon-components-react/es/internal/deprecateFieldOnObject.js");
/* harmony import */ var _MultiSelect__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./MultiSelect */ "../../node_modules/carbon-components-react/es/components/MultiSelect/MultiSelect.js");
/* harmony import */ var _FilterableMultiSelect__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./FilterableMultiSelect */ "../../node_modules/carbon-components-react/es/components/MultiSelect/FilterableMultiSelect.js");
/* harmony import */ var _next_FilterableMultiSelect__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./next/FilterableMultiSelect */ "../../node_modules/carbon-components-react/es/components/MultiSelect/next/FilterableMultiSelect.js");
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */





_next_FilterableMultiSelect__WEBPACK_IMPORTED_MODULE_0__["default"].displayName = 'MultiSelect.Filterable';
_MultiSelect__WEBPACK_IMPORTED_MODULE_1__["default"].Filterable = _FilterableMultiSelect__WEBPACK_IMPORTED_MODULE_2__["default"];
var FilterableMultiSelect = _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_3__.enabled('enable-v11-release') ? _next_FilterableMultiSelect__WEBPACK_IMPORTED_MODULE_0__["default"] : _FilterableMultiSelect__WEBPACK_IMPORTED_MODULE_2__["default"];

if (true) {
  (0,_internal_deprecateFieldOnObject__WEBPACK_IMPORTED_MODULE_4__.deprecateFieldOnObject)(_MultiSelect__WEBPACK_IMPORTED_MODULE_1__["default"], 'Filterable', FilterableMultiSelect);
}

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_MultiSelect__WEBPACK_IMPORTED_MODULE_1__["default"]);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/MultiSelect/next/FilterableMultiSelect.js":
/*!**********************************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/MultiSelect/next/FilterableMultiSelect.js ***!
  \**********************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-29.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var downshift__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! downshift */ "../../node_modules/carbon-components-react/node_modules/downshift/dist/downshift.esm.js");
/* harmony import */ var lodash_isequal__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! lodash.isequal */ "../../node_modules/lodash.isequal/index.js");
/* harmony import */ var lodash_isequal__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(lodash_isequal__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_19___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_19__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var _ComboBox_tools_filter__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! ../../ComboBox/tools/filter */ "../../node_modules/carbon-components-react/es/components/ComboBox/tools/filter.js");
/* harmony import */ var _MultiSelectPropTypes__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ../MultiSelectPropTypes */ "../../node_modules/carbon-components-react/es/components/MultiSelect/MultiSelectPropTypes.js");
/* harmony import */ var _ListBox__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../../ListBox */ "../../node_modules/carbon-components-react/es/components/ListBox/index.js");
/* harmony import */ var _ListBox__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ../../ListBox */ "../../node_modules/carbon-components-react/es/components/ListBox/ListBoxPropTypes.js");
/* harmony import */ var _ListBox_next__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ../../ListBox/next */ "../../node_modules/carbon-components-react/es/components/ListBox/next/ListBoxSelection.js");
/* harmony import */ var _ListBox_next__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ../../ListBox/next */ "../../node_modules/carbon-components-react/es/components/ListBox/next/ListBoxTrigger.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/match.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/keys.js");
/* harmony import */ var _internal_Selection__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../../../internal/Selection */ "../../node_modules/carbon-components-react/es/internal/Selection.js");
/* harmony import */ var _tools_createPropAdapter__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../../tools/createPropAdapter */ "../../node_modules/carbon-components-react/es/tools/createPropAdapter.js");
/* harmony import */ var _tools_itemToString__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(/*! ../tools/itemToString */ "../../node_modules/carbon-components-react/es/components/MultiSelect/tools/itemToString.js");
/* harmony import */ var _tools_mergeRefs__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ../../../tools/mergeRefs */ "../../node_modules/carbon-components-react/es/tools/mergeRefs.js");
/* harmony import */ var _internal_useId__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../../internal/useId */ "../../node_modules/carbon-components-react/es/internal/useId.js");
/* harmony import */ var _tools_sorting__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ../tools/sorting */ "../../node_modules/carbon-components-react/es/components/MultiSelect/tools/sorting.js");
/* harmony import */ var _FeatureFlags__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../FeatureFlags */ "../../node_modules/carbon-components-react/es/components/FeatureFlags/index.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");




function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */



















var FilterableMultiSelect = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().forwardRef(function FilterableMultiSelect(_ref, ref) {
  var _cx, _cx2, _cx3, _cx4;

  var ariaLabel = _ref.ariaLabel,
      containerClassName = _ref.className,
      compareItems = _ref.compareItems,
      direction = _ref.direction,
      disabled = _ref.disabled,
      downshiftProps = _ref.downshiftProps,
      filterItems = _ref.filterItems,
      helperText = _ref.helperText,
      hideLabel = _ref.hideLabel,
      id = _ref.id,
      initialSelectedItems = _ref.initialSelectedItems,
      invalid = _ref.invalid,
      invalidText = _ref.invalidText,
      items = _ref.items,
      ItemToElement = _ref.itemToElement,
      itemToString = _ref.itemToString,
      light = _ref.light,
      locale = _ref.locale,
      open = _ref.open,
      onChange = _ref.onChange,
      onMenuChange = _ref.onMenuChange,
      placeholder = _ref.placeholder,
      titleText = _ref.titleText,
      type = _ref.type,
      selectionFeedback = _ref.selectionFeedback,
      size = _ref.size,
      sortItems = _ref.sortItems,
      translateWithId = _ref.translateWithId,
      useTitleInItem = _ref.useTitleInItem,
      warn = _ref.warn,
      warnText = _ref.warnText;

  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(open),
      _useState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState, 2),
      isOpen = _useState2[0],
      setIsOpen = _useState2[1];

  var _useState3 = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(open),
      _useState4 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState3, 2),
      prevOpen = _useState4[0],
      setPrevOpen = _useState4[1];

  var _useState5 = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(''),
      _useState6 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState5, 2),
      inputValue = _useState6[0],
      setInputValue = _useState6[1];

  var _useState7 = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)([]),
      _useState8 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState7, 2),
      topItems = _useState8[0],
      setTopItems = _useState8[1];

  var _useState9 = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(false),
      _useState10 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState9, 2),
      inputFocused = _useState10[0],
      setInputFocused = _useState10[1];

  var _useState11 = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(null),
      _useState12 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState11, 2),
      highlightedIndex = _useState12[0],
      setHighlightedIndex = _useState12[1];

  var textInput = (0,react__WEBPACK_IMPORTED_MODULE_5__.useRef)();
  var filterableMultiSelectInstanceId = (0,_internal_useId__WEBPACK_IMPORTED_MODULE_6__.useId)();
  var enabled = (0,_FeatureFlags__WEBPACK_IMPORTED_MODULE_7__.useFeatureFlag)('enable-v11-release');
  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_8__.usePrefix)();

  if (prevOpen !== open) {
    setIsOpen(open);
    setPrevOpen(open);
  }

  var inline = type === 'inline';
  var showWarning = !invalid && warn;
  var wrapperClasses = classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--multi-select__wrapper"), "".concat(prefix, "--list-box__wrapper"), [enabled ? containerClassName : null], (_cx = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--multi-select__wrapper--inline"), inline), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--list-box__wrapper--inline"), inline), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--multi-select__wrapper--inline--invalid"), inline && invalid), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--list-box__wrapper--inline--invalid"), inline && invalid), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--list-box--up"), direction === 'top'), _cx));
  var helperId = !helperText ? undefined : "filterablemultiselect-helper-text-".concat(filterableMultiSelectInstanceId);
  var labelId = "".concat(id, "-label");
  var titleClasses = classnames__WEBPACK_IMPORTED_MODULE_3___default()((_cx2 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx2, "".concat(prefix, "--label"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx2, "".concat(prefix, "--label--disabled"), disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx2, "".concat(prefix, "--visually-hidden"), hideLabel), _cx2));
  var helperClasses = classnames__WEBPACK_IMPORTED_MODULE_3___default()((_cx3 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx3, "".concat(prefix, "--form__helper-text"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx3, "".concat(prefix, "--form__helper-text--disabled"), disabled), _cx3));
  var inputClasses = classnames__WEBPACK_IMPORTED_MODULE_3___default()((_cx4 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx4, "".concat(prefix, "--text-input"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx4, "".concat(prefix, "--text-input--empty"), !inputValue), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx4, "".concat(prefix, "--text-input--light"), light), _cx4));
  var helper = helperText ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("div", {
    id: helperId,
    className: helperClasses
  }, helperText) : null;
  var menuId = "".concat(id, "__menu");
  var inputId = "".concat(id, "-input");

  function handleOnChange(changes) {
    if (onChange) {
      onChange(changes);
    }
  }

  function handleOnMenuChange(forceIsOpen) {
    var nextIsOpen = forceIsOpen !== null && forceIsOpen !== void 0 ? forceIsOpen : !isOpen;
    setIsOpen(nextIsOpen);

    if (onMenuChange) {
      onMenuChange(nextIsOpen);
    }
  }

  function handleOnOuterClick() {
    handleOnMenuChange(false);
  }

  function handleOnStateChange(changes, downshift) {
    if (changes.isOpen && !isOpen) {
      setTopItems(downshift.selectedItem);
    }

    var type = changes.type;
    var stateChangeTypes = downshift__WEBPACK_IMPORTED_MODULE_9__["default"].stateChangeTypes;

    switch (type) {
      case stateChangeTypes.keyDownArrowDown:
      case stateChangeTypes.keyDownArrowUp:
      case stateChangeTypes.keyDownHome:
      case stateChangeTypes.keyDownEnd:
        setHighlightedIndex(changes.highlightedIndex !== undefined ? changes.highlightedIndex : null);

        if (stateChangeTypes.keyDownArrowDown === type && !isOpen) {
          handleOnMenuChange(true);
        }

        break;

      case stateChangeTypes.keyDownEscape:
        handleOnMenuChange(false);
        break;
    }
  }

  function handleOnInputValueChange(inputValue, _ref2) {
    var type = _ref2.type;

    if (type !== downshift__WEBPACK_IMPORTED_MODULE_9__["default"].stateChangeTypes.changeInput) {
      return;
    }

    if (Array.isArray(inputValue)) {
      clearInputValue();
    } else {
      setInputValue(inputValue);
    }

    if (inputValue && !isOpen) {
      handleOnMenuChange(true);
    } else if (!inputValue && isOpen) {
      handleOnMenuChange(false);
    }
  }

  function clearInputValue() {
    setInputValue('');

    if (textInput.current) {
      textInput.current.focus();
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_internal_Selection__WEBPACK_IMPORTED_MODULE_10__["default"], {
    disabled: disabled,
    onChange: handleOnChange,
    initialSelectedItems: initialSelectedItems,
    render: function render(_ref3) {
      var selectedItems = _ref3.selectedItems,
          onItemChange = _ref3.onItemChange,
          _clearSelection = _ref3.clearSelection;
      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(downshift__WEBPACK_IMPORTED_MODULE_9__["default"], (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, (0,_tools_createPropAdapter__WEBPACK_IMPORTED_MODULE_11__.mapDownshiftProps)(downshiftProps), {
        highlightedIndex: highlightedIndex,
        id: id,
        isOpen: isOpen,
        inputValue: inputValue,
        onInputValueChange: handleOnInputValueChange,
        onChange: function onChange(selectedItem) {
          if (selectedItem !== null) {
            onItemChange(selectedItem);
          }
        },
        itemToString: itemToString,
        onStateChange: handleOnStateChange,
        onOuterClick: handleOnOuterClick,
        selectedItem: selectedItems,
        labelId: labelId,
        menuId: menuId,
        inputId: inputId
      }), function (_ref4) {
        var _cx5;

        var getInputProps = _ref4.getInputProps,
            getItemProps = _ref4.getItemProps,
            getLabelProps = _ref4.getLabelProps,
            getMenuProps = _ref4.getMenuProps,
            getRootProps = _ref4.getRootProps,
            getToggleButtonProps = _ref4.getToggleButtonProps,
            isOpen = _ref4.isOpen,
            inputValue = _ref4.inputValue,
            selectedItem = _ref4.selectedItem;
        var className = classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--multi-select"), "".concat(prefix, "--combo-box"), "".concat(prefix, "--multi-select--filterable"), [enabled ? null : containerClassName], (_cx5 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx5, "".concat(prefix, "--multi-select--invalid"), invalid), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx5, "".concat(prefix, "--multi-select--open"), isOpen), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx5, "".concat(prefix, "--multi-select--inline"), inline), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx5, "".concat(prefix, "--multi-select--selected"), selectedItem.length > 0), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx5, "".concat(prefix, "--multi-select--filterable--input-focused"), inputFocused), _cx5));
        var rootProps = getRootProps({}, {
          suppressRefError: true
        });
        var labelProps = getLabelProps();
        var buttonProps = getToggleButtonProps({
          disabled: disabled,
          onClick: function onClick() {
            handleOnMenuChange(!isOpen);

            if (textInput.current) {
              textInput.current.focus();
            }
          },
          // When we moved the "root node" of Downshift to the <input> for
          // ARIA 1.2 compliance, we unfortunately hit this branch for the
          // "mouseup" event that downshift listens to:
          // https://github.com/downshift-js/downshift/blob/v5.2.1/src/downshift.js#L1051-L1065
          //
          // As a result, it will reset the state of the component and so we
          // stop the event from propagating to prevent this. This allows the
          // toggleMenu behavior for the toggleButton to correctly open and
          // close the menu.
          onMouseUp: function onMouseUp(event) {
            event.stopPropagation();
          }
        });
        var inputProps = getInputProps({
          'aria-controls': isOpen ? menuId : null,
          'aria-describedby': helperText ? helperId : null,
          // Remove excess aria `aria-labelledby`. HTML <label for>
          // provides this aria information.
          'aria-labelledby': null,
          disabled: disabled,
          placeholder: placeholder,
          onClick: function onClick() {
            handleOnMenuChange(true);
          },
          onKeyDown: function onKeyDown(event) {
            if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_12__.match)(event, _internal_keyboard__WEBPACK_IMPORTED_MODULE_13__.Space)) {
              event.stopPropagation();
            }
          },
          onFocus: function onFocus() {
            setInputFocused(true);
          },
          onBlur: function onBlur() {
            setInputFocused(false);
          }
        });
        var menuProps = getMenuProps({
          'aria-label': ariaLabel
        }, {
          suppressRefError: true
        });
        return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("div", {
          className: wrapperClasses
        }, titleText ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("label", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
          className: titleClasses
        }, labelProps), titleText) : null, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_14__["default"], {
          className: className,
          disabled: disabled,
          light: light,
          ref: ref,
          invalid: invalid,
          invalidText: invalidText,
          warn: warn,
          warnText: warnText,
          isOpen: isOpen,
          size: size
        }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("div", {
          className: "".concat(prefix, "--list-box__field")
        }, selectedItem.length > 0 && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_ListBox_next__WEBPACK_IMPORTED_MODULE_15__["default"], {
          clearSelection: function clearSelection() {
            _clearSelection();

            if (textInput.current) {
              textInput.current.focus();
            }
          },
          selectionCount: selectedItem.length,
          translateWithId: translateWithId,
          disabled: disabled
        }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("input", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
          className: inputClasses
        }, rootProps, inputProps, {
          ref: (0,_tools_mergeRefs__WEBPACK_IMPORTED_MODULE_16__["default"])(textInput, rootProps.ref)
        })), invalid && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_17__.WarningFilled16, {
          className: "".concat(prefix, "--list-box__invalid-icon")
        }), showWarning && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_17__.WarningAltFilled16, {
          className: "".concat(prefix, "--list-box__invalid-icon ").concat(prefix, "--list-box__invalid-icon--warning")
        }), inputValue && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_ListBox_next__WEBPACK_IMPORTED_MODULE_15__["default"], {
          clearSelection: clearInputValue,
          disabled: disabled,
          translateWithId: translateWithId,
          onMouseUp: function onMouseUp(event) {
            // If we do not stop this event from propagating,
            // it seems like Downshift takes our event and
            // prevents us from getting `onClick` /
            // `clearSelection` from the underlying <button> in
            // ListBoxSelection
            event.stopPropagation();
          }
        }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_ListBox_next__WEBPACK_IMPORTED_MODULE_18__["default"], (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, buttonProps, {
          isOpen: isOpen,
          translateWithId: translateWithId
        }))), isOpen ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_14__["default"].Menu, menuProps, sortItems(filterItems(items, {
          itemToString: itemToString,
          inputValue: inputValue
        }), {
          selectedItems: {
            top: selectedItems,
            fixed: [],
            'top-after-reopen': topItems
          }[selectionFeedback],
          itemToString: itemToString,
          compareItems: compareItems,
          locale: locale
        }).map(function (item, index) {
          var itemProps = getItemProps({
            item: item,
            disabled: item.disabled
          });
          var itemText = itemToString(item);
          var isChecked = selectedItem.filter(function (selected) {
            return lodash_isequal__WEBPACK_IMPORTED_MODULE_4___default()(selected, item);
          }).length > 0;
          return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_ListBox__WEBPACK_IMPORTED_MODULE_14__["default"].MenuItem, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
            key: itemProps.id,
            "aria-label": itemText,
            isActive: isChecked,
            isHighlighted: highlightedIndex === index,
            title: itemText
          }, itemProps), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("div", {
            className: "".concat(prefix, "--checkbox-wrapper")
          }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("span", {
            title: useTitleInItem ? itemText : null,
            className: "".concat(prefix, "--checkbox-label"),
            "data-contained-checkbox-state": isChecked,
            id: "".concat(itemProps.id, "-item")
          }, ItemToElement ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(ItemToElement, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
            key: itemProps.id
          }, item)) : itemText)));
        })) : null), !inline && !invalid && !warn ? helper : null);
      });
    }
  });
});
FilterableMultiSelect.propTypes = _objectSpread(_objectSpread({
  /**
   * 'aria-label' of the ListBox component.
   */
  ariaLabel: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().string),

  /**
   * Specify the direction of the multiselect dropdown. Can be either top or bottom.
   */
  direction: prop_types__WEBPACK_IMPORTED_MODULE_19___default().oneOf(['top', 'bottom']),

  /**
   * Disable the control
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().bool),

  /**
   * Additional props passed to Downshift
   */
  downshiftProps: prop_types__WEBPACK_IMPORTED_MODULE_19___default().shape(downshift__WEBPACK_IMPORTED_MODULE_9__["default"].propTypes),

  /**
   * Specify whether the title text should be hidden or not
   */
  hideLabel: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().bool),

  /**
   * Specify a custom `id`
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().string.isRequired),

  /**
   * Allow users to pass in arbitrary items from their collection that are
   * pre-selected
   */
  initialSelectedItems: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().array),

  /**
   * Is the current selection invalid?
   */
  invalid: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().bool),

  /**
   * If invalid, what is the error?
   */
  invalidText: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().node),

  /**
   * Function to render items as custom components instead of strings.
   * Defaults to null and is overridden by a getter
   */
  itemToElement: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().func),

  /**
   * Helper function passed to downshift that allows the library to render a
   * given item to a string label. By default, it extracts the `label` field
   * from a given item to serve as the item label in the list.
   */
  itemToString: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().func),

  /**
   * We try to stay as generic as possible here to allow individuals to pass
   * in a collection of whatever kind of data structure they prefer
   */
  items: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().array.isRequired),

  /**
   * `true` to use the light version.
   */
  light: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().bool),

  /**
   * Specify the locale of the control. Used for the default `compareItems`
   * used for sorting the list of items in the control.
   */
  locale: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().string),

  /**
   * `onChange` is a utility for this controlled component to communicate to a
   * consuming component what kind of internal state changes are occurring.
   */
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().func),

  /**
   * `onMenuChange` is a utility for this controlled component to communicate to a
   * consuming component that the menu was opened(`true`)/closed(`false`).
   */
  onMenuChange: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().func),

  /**
   * Initialize the component with an open(`true`)/closed(`false`) menu.
   */
  open: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().bool),

  /**
   * Generic `placeholder` that will be used as the textual representation of
   * what this field is for
   */
  placeholder: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().string),

  /**
   * Specify feedback (mode) of the selection.
   * `top`: selected item jumps to top
   * `fixed`: selected item stays at it's position
   * `top-after-reopen`: selected item jump to top after reopen dropdown
   */
  selectionFeedback: prop_types__WEBPACK_IMPORTED_MODULE_19___default().oneOf(['top', 'fixed', 'top-after-reopen']),

  /**
   * Specify the size of the ListBox. Currently supports either `sm`, `md` or `lg` as an option.
   */
  size: _ListBox__WEBPACK_IMPORTED_MODULE_20__.ListBoxSize
}, _MultiSelectPropTypes__WEBPACK_IMPORTED_MODULE_21__.sortingPropTypes), {}, {
  /**
   * Callback function for translating ListBoxMenuIcon SVG title
   */
  translateWithId: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().func),

  /**
   * Specify title to show title on hover
   */
  useTitleInItem: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().bool),

  /**
   * Specify whether the control is currently in warning state
   */
  warn: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().bool),

  /**
   * Provide the text that is displayed when the control is in warning state
   */
  warnText: (prop_types__WEBPACK_IMPORTED_MODULE_19___default().node)
});
FilterableMultiSelect.defaultProps = {
  ariaLabel: 'Choose an item',
  compareItems: _tools_sorting__WEBPACK_IMPORTED_MODULE_22__.defaultCompareItems,
  direction: 'bottom',
  disabled: false,
  filterItems: _ComboBox_tools_filter__WEBPACK_IMPORTED_MODULE_23__.defaultFilterItems,
  initialSelectedItems: [],
  itemToString: _tools_itemToString__WEBPACK_IMPORTED_MODULE_24__.defaultItemToString,
  locale: 'en',
  sortItems: _tools_sorting__WEBPACK_IMPORTED_MODULE_22__.defaultSortItems,
  light: false,
  open: false,
  selectionFeedback: 'top-after-reopen'
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (FilterableMultiSelect);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/MultiSelect/tools/itemToString.js":
/*!**************************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/MultiSelect/tools/itemToString.js ***!
  \**************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "defaultItemToString": () => (/* binding */ defaultItemToString)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_typeof__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/typeof */ "../../node_modules/@babel/runtime/helpers/esm/typeof.js");
/* harmony import */ var invariant__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! invariant */ "../../node_modules/invariant/browser.js");
/* harmony import */ var invariant__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(invariant__WEBPACK_IMPORTED_MODULE_1__);


/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */


var itemToString = function itemToString(item) {
  !(typeof item.label === 'string') ?  true ? invariant__WEBPACK_IMPORTED_MODULE_1___default()(false, '[MultiSelect] the default `itemToString` method expected to receive ' + 'an item with a `label` field of type `string`. Instead received: `%s`', (0,_babel_runtime_helpers_typeof__WEBPACK_IMPORTED_MODULE_0__["default"])(item.label)) : 0 : void 0;
  return item.label || '';
};

var defaultItemToString = function defaultItemToString(item) {
  if (Array.isArray(item)) {
    return item.map(itemToString);
  }

  return itemToString(item);
};

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/MultiSelect/tools/sorting.js":
/*!*********************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/MultiSelect/tools/sorting.js ***!
  \*********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "defaultCompareItems": () => (/* binding */ defaultCompareItems),
/* harmony export */   "defaultSortItems": () => (/* binding */ defaultSortItems)
/* harmony export */ });
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * Use the local `localCompare` with the `numeric` option to sort two,
 * potentially alpha-numeric, strings in a list of items.
 *
 * @param {string} itemA
 * @param {string} itemB
 * @param {object} options
 * @param {string} options.locale
 * @returns {number}
 */
var defaultCompareItems = function defaultCompareItems(itemA, itemB, _ref) {
  var locale = _ref.locale;
  return itemA.localeCompare(itemB, locale, {
    numeric: true
  });
};
/**
 * Default sorting algorithm for options in a selection control
 */

var defaultSortItems = function defaultSortItems(items, _ref2) {
  var _ref2$selectedItems = _ref2.selectedItems,
      selectedItems = _ref2$selectedItems === void 0 ? [] : _ref2$selectedItems,
      itemToString = _ref2.itemToString,
      compareItems = _ref2.compareItems,
      _ref2$locale = _ref2.locale,
      locale = _ref2$locale === void 0 ? 'en' : _ref2$locale;
  return items.sort(function (itemA, itemB) {
    var hasItemA = selectedItems.includes(itemA);
    var hasItemB = selectedItems.includes(itemB); // Prefer whichever item is in the `selectedItems` array first

    if (hasItemA && !hasItemB) {
      return -1;
    }

    if (hasItemB && !hasItemA) {
      return 1;
    }

    return compareItems(itemToString(itemA), itemToString(itemB), {
      locale: locale
    });
  });
};

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/NumberInput/NumberInput.js":
/*!*******************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/NumberInput/NumberInput.js ***!
  \*******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "NumberInput": () => (/* binding */ NumberInput),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__),
/* harmony export */   "translationIds": () => (/* binding */ translationIds)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_17___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_17__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_10___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_10__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-25.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-0.js");
/* harmony import */ var _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! @carbon/feature-flags */ "../../node_modules/@carbon/feature-flags/es/index.js");
/* harmony import */ var _tools_mergeRefs__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../../tools/mergeRefs */ "../../node_modules/carbon-components-react/es/tools/mergeRefs.js");
/* harmony import */ var _prop_types_requiredIfValueExists__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ../../prop-types/requiredIfValueExists */ "../../node_modules/carbon-components-react/es/prop-types/requiredIfValueExists.js");
/* harmony import */ var _internal_useNormalizedInputProps__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../../internal/useNormalizedInputProps */ "../../node_modules/carbon-components-react/es/internal/useNormalizedInputProps.js");
/* harmony import */ var _internal_FeatureFlags__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../internal/FeatureFlags */ "../../node_modules/carbon-components-react/es/internal/FeatureFlags.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");
/* harmony import */ var _prop_types_deprecate__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ../../prop-types/deprecate */ "../../node_modules/carbon-components-react/es/prop-types/deprecate.js");
/* harmony import */ var _FeatureFlags__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ../FeatureFlags */ "../../node_modules/carbon-components-react/es/components/FeatureFlags/index.js");









var _excluded = ["className", "disabled", "iconDescription", "id", "hideLabel", "hideSteppers", "label", "max", "min", "step", "value", "readOnly", "invalid", "invalidText", "warn", "warnText", "helperText", "ariaLabel", "light", "allowEmpty", "innerRef", "translateWithId", "isMobile", "size", "defaultValue"];

var _defaultTranslations;

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__["default"])(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__["default"])(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_6__["default"])(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */






 // replace "use" prefix to avoid react thinking this is a hook that
// can only be placed in a function component






var translationIds = {
  'increment.number': 'increment.number',
  'decrement.number': 'decrement.number'
};
var defaultTranslations = (_defaultTranslations = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defaultTranslations, translationIds['increment.number'], 'Increment number'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_defaultTranslations, translationIds['decrement.number'], 'Decrement number'), _defaultTranslations);

var capMin = function capMin(min, value) {
  return isNaN(min) || !min && min !== 0 || isNaN(value) || !value && value !== 0 ? value : Math.max(min, value);
};

var capMax = function capMax(max, value) {
  return isNaN(max) || !max && max !== 0 || isNaN(value) || !value && value !== 0 ? value : Math.min(max, value);
};

var NumberInput = /*#__PURE__*/function (_Component) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(NumberInput, _Component);

  var _super = _createSuper(NumberInput);

  function NumberInput(props) {
    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, NumberInput);

    _this = _super.call(this, props);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_inputRef", null);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "handleChange", function (evt) {
      var _this$props = _this.props,
          disabled = _this$props.disabled,
          onChange = _this$props.onChange;

      if (!disabled) {
        evt.persist();
        evt.imaginaryTarget = _this._inputRef;
        var prevValue = _this.state.value;
        var value = evt.target.value;
        var direction = prevValue < value ? 'up' : 'down';

        _this.setState({
          value: value
        }, function () {
          if (_internal_FeatureFlags__WEBPACK_IMPORTED_MODULE_11__.useControlledStateWithValue) {
            onChange(evt, {
              value: value,
              direction: direction
            });
          } else if (onChange) {
            onChange(evt, {
              value: value,
              direction: direction
            });
          }
        });
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "handleArrowClick", function (evt, direction) {
      var value = typeof _this.state.value === 'string' ? Number(_this.state.value) : _this.state.value;
      var _this$props2 = _this.props,
          disabled = _this$props2.disabled,
          min = _this$props2.min,
          max = _this$props2.max,
          step = _this$props2.step,
          onChange = _this$props2.onChange,
          onClick = _this$props2.onClick;
      var conditional = direction === 'down' ? min !== undefined && value > min || min === undefined : max !== undefined && value < max || max === undefined;

      if (!disabled && conditional) {
        value = direction === 'down' ? value - step : value + step;
        value = capMax(max, capMin(min, value));
        evt.persist();
        evt.imaginaryTarget = _this._inputRef;

        _this.setState({
          value: value
        }, function () {
          //TO-DO v11: update these events to return the same things --> evt, {value, direction}
          if (_internal_FeatureFlags__WEBPACK_IMPORTED_MODULE_11__.useControlledStateWithValue) {
            onClick && onClick(evt, {
              value: value,
              direction: direction
            });
            onChange && onChange(evt, {
              value: value,
              direction: direction
            });
          } else {
            // value added as a 3rd argument rather than in same obj so it doesn't break in v10
            onClick && onClick(evt, direction, value);
            onChange && onChange(evt, direction, value);
          }
        });
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_handleInputRef", function (ref) {
      _this._inputRef = ref;
    });

    _this.isControlled = props.value !== undefined;

    if (_internal_FeatureFlags__WEBPACK_IMPORTED_MODULE_11__.useControlledStateWithValue && _this.isControlled) {
      // Skips the logic of setting initial state if this component is controlled
      _this.state = {};
      return (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_6__["default"])(_this);
    }

    var _value = _internal_FeatureFlags__WEBPACK_IMPORTED_MODULE_11__.useControlledStateWithValue || typeof props.defaultValue !== 'undefined' ? props.defaultValue : props.value;

    _value = _value === undefined ? 0 : _value;

    if (props.min || props.min === 0) {
      _value = Math.max(props.min, _value);
    }

    _this.state = {
      value: _value
    };
    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(NumberInput, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props3 = this.props,
          className = _this$props3.className,
          disabled = _this$props3.disabled,
          iconDescription = _this$props3.iconDescription,
          id = _this$props3.id,
          hideLabel = _this$props3.hideLabel,
          hideSteppers = _this$props3.hideSteppers,
          label = _this$props3.label,
          max = _this$props3.max,
          min = _this$props3.min,
          step = _this$props3.step,
          value = _this$props3.value,
          readOnly = _this$props3.readOnly,
          invalid = _this$props3.invalid,
          invalidText = _this$props3.invalidText,
          warn = _this$props3.warn,
          warnText = _this$props3.warnText,
          helperText = _this$props3.helperText,
          ariaLabel = _this$props3.ariaLabel,
          light = _this$props3.light,
          allowEmpty = _this$props3.allowEmpty,
          ref = _this$props3.innerRef,
          t = _this$props3.translateWithId,
          isMobile = _this$props3.isMobile,
          size = _this$props3.size,
          defaultValue = _this$props3.defaultValue,
          other = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_this$props3, _excluded);

      var scope = this.context;
      var enabled;

      if (scope.enabled) {
        enabled = scope.enabled('enable-v11-release');
      }

      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement(_internal_usePrefix__WEBPACK_IMPORTED_MODULE_12__.PrefixContext.Consumer, null, function (prefix) {
        var _classNames, _classNames3, _classNames5;

        var numberInputClasses = classnames__WEBPACK_IMPORTED_MODULE_10___default()("".concat(prefix, "--number ").concat(prefix, "--number--helpertext"), [enabled ? null : className], (_classNames = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--number--readonly"), readOnly), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--number--light"), light), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--number--nolabel"), hideLabel), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--number--nosteppers"), hideSteppers), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--number--mobile"), isMobile), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--number--").concat(size), size), _classNames));
        var isInputInvalid; // If the user supplied `invalid` through props, we'll defer to the passed in value

        if (invalid) {
          isInputInvalid = true;
        } else {
          // Otherwise, if we don't allow an empty value then we check to see
          // if the value is empty, or if it is out of range
          if (!allowEmpty && _this2.state.value === '') {
            isInputInvalid = true;
          } else {
            if (_this2.state.value !== '' && (_this2.state.value > max || _this2.state.value < min)) {
              isInputInvalid = true;
            }
          }
        }

        var normalizedProps = (0,_internal_useNormalizedInputProps__WEBPACK_IMPORTED_MODULE_13__.useNormalizedInputProps)({
          id: id,
          readOnly: readOnly,
          disabled: disabled,
          invalid: isInputInvalid,
          invalidText: invalidText,
          warn: warn,
          warnText: warnText
        });
        var props = {
          disabled: normalizedProps.disabled,
          id: id,
          max: max,
          min: min,
          step: step,
          onChange: _this2.handleChange,
          value: _internal_FeatureFlags__WEBPACK_IMPORTED_MODULE_11__.useControlledStateWithValue && _this2.isControlled ? value : _this2.state.value,
          readOnly: readOnly,
          'aria-label': label ? null : ariaLabel
        };
        var buttonProps = {
          disabled: disabled
        };
        var inputWrapperProps = {};

        if (normalizedProps.invalid) {
          inputWrapperProps['data-invalid'] = true;
        }

        var helperTextClasses = classnames__WEBPACK_IMPORTED_MODULE_10___default()("".concat(prefix, "--form__helper-text"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])({}, "".concat(prefix, "--form__helper-text--disabled"), normalizedProps.disabled));
        var helper = helperText ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", {
          className: helperTextClasses
        }, helperText) : null;
        var labelClasses = classnames__WEBPACK_IMPORTED_MODULE_10___default()("".concat(prefix, "--label"), (_classNames3 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames3, "".concat(prefix, "--label--disabled"), normalizedProps.disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames3, "".concat(prefix, "--visually-hidden"), hideLabel), _classNames3));
        var labelText = label ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("label", {
          htmlFor: id,
          className: labelClasses
        }, label) : null;
        var _ref = [t('increment.number'), t('decrement.number')],
            incrementNumLabel = _ref[0],
            decrementNumLabel = _ref[1];
        var wrapperClasses = classnames__WEBPACK_IMPORTED_MODULE_10___default()("".concat(prefix, "--number__input-wrapper"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])({}, "".concat(prefix, "--number__input-wrapper--warning"), normalizedProps.warn));
        var iconClasses = classnames__WEBPACK_IMPORTED_MODULE_10___default()((_classNames5 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames5, "".concat(prefix, "--number__invalid"), normalizedProps.invalid || normalizedProps.warn), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames5, "".concat(prefix, "--number__invalid--warning"), normalizedProps.warn), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames5, "".concat(prefix, "--number__readonly-icon"), readOnly), _classNames5));
        var ariaDescribedBy = null;

        if (normalizedProps.invalid) {
          ariaDescribedBy = normalizedProps.invalidId;
        }

        if (normalizedProps.warn) {
          ariaDescribedBy = normalizedProps.warnId;
        }

        return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", {
          className: enabled ? classnames__WEBPACK_IMPORTED_MODULE_10___default()("".concat(prefix, "--form-item"), className) : "".concat(prefix, "--form-item")
        }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
          className: numberInputClasses
        }, inputWrapperProps), function () {
          return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement((react__WEBPACK_IMPORTED_MODULE_9___default().Fragment), null, labelText, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", {
            className: wrapperClasses
          }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("input", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
            "data-invalid": normalizedProps.invalid,
            "aria-invalid": normalizedProps.invalid,
            "aria-describedby": ariaDescribedBy,
            type: "number",
            pattern: "[0-9]*"
          }, other, props, {
            ref: (0,_tools_mergeRefs__WEBPACK_IMPORTED_MODULE_14__["default"])(ref, _this2._handleInputRef)
          })), normalizedProps.icon && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement(normalizedProps.icon, {
            className: iconClasses
          }), !hideSteppers && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", {
            className: "".concat(prefix, "--number__controls")
          }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("button", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
            type: "button",
            className: "".concat(prefix, "--number__control-btn down-icon")
          }, buttonProps, {
            onClick: function onClick(evt) {
              return _this2.handleArrowClick(evt, 'down');
            },
            title: decrementNumLabel || iconDescription,
            "aria-label": decrementNumLabel || iconDescription,
            tabIndex: "-1"
          }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_15__.Subtract16, {
            className: "down-icon"
          })), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", {
            className: "".concat(prefix, "--number__rule-divider")
          }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("button", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
            type: "button",
            className: "".concat(prefix, "--number__control-btn up-icon")
          }, buttonProps, {
            onClick: function onClick(evt) {
              return _this2.handleArrowClick(evt, 'up');
            },
            title: incrementNumLabel || iconDescription,
            "aria-label": incrementNumLabel || iconDescription,
            tabIndex: "-1"
          }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_16__.Add16, {
            className: "up-icon"
          })), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", {
            className: "".concat(prefix, "--number__rule-divider")
          }))), normalizedProps.validation ? null : helper);
        }(), normalizedProps.validation));
      });
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(_ref2, state) {
      var value = _ref2.value;
      var prevValue = state.prevValue;

      if (_internal_FeatureFlags__WEBPACK_IMPORTED_MODULE_11__.useControlledStateWithValue && value === '' && prevValue !== '') {
        return {
          value: '',
          prevValue: ''
        };
      } // If `useControlledStateWithValue` feature flag is on, do nothing here.
      // Otherwise, do prop -> state sync with "value capping".
      //// Value capping removed in #8965
      //// value: capMax(max, capMin(min, value)), (L223)


      return _internal_FeatureFlags__WEBPACK_IMPORTED_MODULE_11__.useControlledStateWithValue || prevValue === value ? null : {
        value: value,
        prevValue: value
      };
    }
    /**
     * The DOM node reference to the `<input>`.
     * @type {HTMLInputElement}
     */

  }]);

  return NumberInput;
}(react__WEBPACK_IMPORTED_MODULE_9__.Component);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(NumberInput, "propTypes", {
  /**
   * `true` to allow empty string.
   */
  allowEmpty: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().bool),

  /**
   * Provide a description that would be used to best describe the use case of the NumberInput component
   */
  ariaLabel: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().string),

  /**
   * Specify an optional className to be applied to the wrapper node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().string),

  /**
   * Optional starting value for uncontrolled state
   */
  defaultValue: prop_types__WEBPACK_IMPORTED_MODULE_17___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_17___default().number), (prop_types__WEBPACK_IMPORTED_MODULE_17___default().string)]),

  /**
   * Specify if the control should be disabled, or not
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().bool),

  /**
   * Provide text that is used alongside the control label for additional help
   */
  helperText: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().node),

  /**
   * Specify whether you want the underlying label to be visually hidden
   */
  hideLabel: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().bool),

  /**
   * Specify whether you want the steppers to be hidden
   */
  hideSteppers: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().bool),

  /**
   * Provide a description for up/down icons that can be read by screen readers
   */
  iconDescription: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().string.isRequired),

  /**
   * Specify a custom `id` for the input
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().string.isRequired),

  /**
   * Specify if the currently value is invalid.
   */
  invalid: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().bool),

  /**
   * Message which is displayed if the value is invalid.
   */
  invalidText: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().node),

  /**
   * `true` to use the mobile variant.
   */
  isMobile: (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_18__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_17___default().bool), "The `isMobile` prop no longer needed as the default NumberInput styles are now identical to the mobile variant styles. This prop will be removed in the next major version of `carbon-components-react`"),

  /**
   * Generic `label` that will be used as the textual representation of what
   * this field is for
   */
  label: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().node),

  /**
   * `true` to use the light version.
   */
  light: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().bool),

  /**
   * The maximum value.
   */
  max: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().number),

  /**
   * The minimum value.
   */
  min: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().number),

  /**
   * The new value is available in 'imaginaryTarget.value'
   * i.e. to get the value: evt.imaginaryTarget.value
   *
   * * _With_ `useControlledStateWithValue` feature flag, the signature of the event handler will be altered to provide additional context in the second parameter: `onChange(event, { value, direction })` where:
   *   * `event` is the (React) raw event
   *   * `value` is the new value
   *   * `direction` tells you the button you hit is up button or down button
   * * _Without_ this feature flag the event handler has `onChange(event, direction)` signature.
   */
  onChange: !_internal_FeatureFlags__WEBPACK_IMPORTED_MODULE_11__.useControlledStateWithValue ? (prop_types__WEBPACK_IMPORTED_MODULE_17___default().func) : (0,_prop_types_requiredIfValueExists__WEBPACK_IMPORTED_MODULE_19__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_17___default().func)),

  /**
   * Provide an optional function to be called when the up/down button is clicked
   */
  onClick: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().func),

  /**
   * Specify if the component should be read-only
   */
  readOnly: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().bool),

  /**
   * Specify the size of the Number Input. Currently supports either `sm`, 'md' (default) or 'lg` as an option.
   * TODO V11: remove `xl` (replaced with lg)
   */
  size: prop_types__WEBPACK_IMPORTED_MODULE_17___default().oneOf(['sm', 'md', 'lg', 'xl']),

  /**
   * Specify how much the values should increase/decrease upon clicking on up/down button
   */
  step: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().number),

  /**
   * Provide custom text for the component for each translation id
   */
  translateWithId: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().func.isRequired),

  /**
   * Specify the value of the input
   */
  value: prop_types__WEBPACK_IMPORTED_MODULE_17___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_17___default().number), (prop_types__WEBPACK_IMPORTED_MODULE_17___default().string)]),

  /**
   * Specify whether the control is currently in warning state
   */
  warn: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().bool),

  /**
   * Provide the text that is displayed when the control is in warning state
   */
  warnText: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().node)
});

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(NumberInput, "defaultProps", {
  disabled: false,
  hideLabel: false,
  iconDescription: _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_20__.enabled('enable-v11-release') ? undefined : 'choose a number',
  step: 1,
  invalid: false,
  invalidText: _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_20__.enabled('enable-v11-release') ? undefined : 'Provide invalidText',
  warn: false,
  warnText: '',
  ariaLabel: 'Numeric input field with increment and decrement buttons',
  helperText: '',
  light: false,
  allowEmpty: false,
  translateWithId: function translateWithId(id) {
    return defaultTranslations[id];
  }
});

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(NumberInput, "contextType", _FeatureFlags__WEBPACK_IMPORTED_MODULE_21__.FeatureFlagContext);


/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ((function () {
  var forwardRef = function forwardRef(props, ref) {
    return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement(NumberInput, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, props, {
      innerRef: ref
    }));
  };

  forwardRef.displayName = 'NumberInput';
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().forwardRef(forwardRef);
})());

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Popover/index.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Popover/index.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Popover": () => (/* binding */ Popover),
/* harmony export */   "PopoverContent": () => (/* binding */ PopoverContent)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_6__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");



var _excluded = ["align", "as", "caret", "className", "children", "dropShadow", "highContrast", "open"],
    _excluded2 = ["className", "children"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */




var Popover = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().forwardRef(function Popover(props, ref) {
  var _cx;

  var _props$align = props.align,
      align = _props$align === void 0 ? 'bottom' : _props$align,
      _props$as = props.as,
      BaseComponent = _props$as === void 0 ? 'span' : _props$as,
      _props$caret = props.caret,
      caret = _props$caret === void 0 ? true : _props$caret,
      customClassName = props.className,
      children = props.children,
      _props$dropShadow = props.dropShadow,
      dropShadow = _props$dropShadow === void 0 ? true : _props$dropShadow,
      _props$highContrast = props.highContrast,
      highContrast = _props$highContrast === void 0 ? false : _props$highContrast,
      open = props.open,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(props, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  var className = classnames__WEBPACK_IMPORTED_MODULE_3___default()((_cx = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--popover-container"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--popover--caret"), caret), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--popover--drop-shadow"), dropShadow), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--popover--high-contrast"), highContrast), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--popover--open"), open), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--popover--").concat(align), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, customClassName, !!customClassName), _cx));
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement(BaseComponent, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, rest, {
    className: className,
    ref: ref
  }), children);
}); // Note: this displayName is temporarily set so that Storybook ArgTable
// correctly displays the name of this component

if (true) {
  Popover.displayName = 'Popover';
}

Popover.propTypes = {
  /**
   * Specify how the popover should align with the trigger element
   */
  align: prop_types__WEBPACK_IMPORTED_MODULE_6___default().oneOf(['top', 'top-left', 'top-right', 'bottom', 'bottom-left', 'bottom-right', 'left', 'left-bottom', 'left-top', 'right', 'right-bottom', 'right-top']),

  /**
   * Provide a custom element or component to render the top-level node for the
   * component.
   */
  as: prop_types__WEBPACK_IMPORTED_MODULE_6___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_6___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_6___default().elementType)]),

  /**
   * Specify whether a caret should be rendered
   */
  caret: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool),

  /**
   * Provide elements to be rendered inside of the component
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().node),

  /**
   * Provide a custom class name to be added to the outermost node in the
   * component
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().string),

  /**
   * Specify whether a drop shadow should be rendered on the popover
   */
  dropShadow: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool),

  /**
   * Render the component using the high-contrast variant
   */
  highContrast: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool),

  /**
   * Specify whether the component is currently open or closed
   */
  open: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool.isRequired)
};
var PopoverContent = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().forwardRef(function PopoverContent(_ref, ref) {
  var className = _ref.className,
      children = _ref.children,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded2);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("span", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, rest, {
    className: "".concat(prefix, "--popover")
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("span", {
    className: classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--popover-content"), className),
    ref: ref
  }, children), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("span", {
    className: "".concat(prefix, "--popover-caret")
  }));
});
PopoverContent.propTypes = {
  /**
   * Provide elements to be rendered inside of the component
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().node),

  /**
   * Provide a custom class name to be added to the outermost node in the
   * component
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().string)
};


/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/RadioButton/RadioButton.Skeleton.js":
/*!****************************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/RadioButton/RadioButton.Skeleton.js ***!
  \****************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");


var _excluded = ["className"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */





function RadioButtonSkeleton(_ref) {
  var className = _ref.className,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_4__.usePrefix)();
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    className: classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--radio-button-wrapper"), className)
  }, rest), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", {
    className: "".concat(prefix, "--radio-button ").concat(prefix, "--skeleton")
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("span", {
    className: "".concat(prefix, "--radio-button__label ").concat(prefix, "--skeleton")
  }));
}

RadioButtonSkeleton.propTypes = {
  /**
   * Specify an optional className to add.
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().string)
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (RadioButtonSkeleton);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/RadioButton/RadioButton.js":
/*!*******************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/RadioButton/RadioButton.js ***!
  \*******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "RadioButton": () => (/* binding */ RadioButton),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_14___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_14__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_10___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_10__);
/* harmony import */ var _internal_warning__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../../internal/warning */ "../../node_modules/carbon-components-react/es/internal/warning.js");
/* harmony import */ var _tools_uniqueId__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../tools/uniqueId */ "../../node_modules/carbon-components-react/es/tools/uniqueId.js");
/* harmony import */ var _Text__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../Text */ "../../node_modules/carbon-components-react/es/components/Text/Text.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");









var _excluded = ["className", "labelText", "labelPosition", "innerRef", "hideLabel"];

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__["default"])(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__["default"])(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_6__["default"])(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */








var RadioButton = /*#__PURE__*/function (_React$Component) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(RadioButton, _React$Component);

  var _super = _createSuper(RadioButton);

  function RadioButton() {
    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, RadioButton);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _super.call.apply(_super, [this].concat(args));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "prefix", _this.context);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "uid", _this.props.id || (0,_tools_uniqueId__WEBPACK_IMPORTED_MODULE_11__["default"])());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "handleChange", function (evt) {
      _this.props.onChange(_this.props.value, _this.props.name, evt);
    });

    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(RadioButton, [{
    key: "render",
    value: function render() {
      var prefix = this.prefix;

      var _this$props = this.props,
          className = _this$props.className,
          labelText = _this$props.labelText,
          labelPosition = _this$props.labelPosition,
          ref = _this$props.innerRef,
          hideLabel = _this$props.hideLabel,
          other = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_this$props, _excluded);

      if (true) {
         true ? (0,_internal_warning__WEBPACK_IMPORTED_MODULE_12__.warning)(labelPosition !== 'top' && labelPosition !== 'bottom', '`top`/`bottom` values for `labelPosition` property in the `RadioButton` component is deprecated ' + 'and being removed in the next release of `carbon-components-react`.') : 0;
      }

      var innerLabelClasses = classnames__WEBPACK_IMPORTED_MODULE_9___default()((0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])({}, "".concat(prefix, "--visually-hidden"), hideLabel));
      var wrapperClasses = classnames__WEBPACK_IMPORTED_MODULE_9___default()(className, "".concat(prefix, "--radio-button-wrapper"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])({}, "".concat(prefix, "--radio-button-wrapper--label-").concat(labelPosition), labelPosition !== 'right'));
      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement("div", {
        className: wrapperClasses
      }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement("input", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, other, {
        type: "radio",
        className: "".concat(prefix, "--radio-button"),
        onChange: this.handleChange,
        id: this.uid,
        ref: ref
      })), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement("label", {
        htmlFor: this.uid,
        className: "".concat(prefix, "--radio-button__label")
      }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement("span", {
        className: "".concat(prefix, "--radio-button__appearance")
      }), labelText && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement(_Text__WEBPACK_IMPORTED_MODULE_13__.Text, {
        className: innerLabelClasses
      }, labelText)));
    }
  }]);

  return RadioButton;
}((react__WEBPACK_IMPORTED_MODULE_10___default().Component));

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(RadioButton, "propTypes", {
  /**
   * Specify whether the <RadioButton> is currently checked
   */
  checked: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().bool),

  /**
   * Provide an optional className to be applied to the containing node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().string),

  /**
   * Specify whether the <RadioButton> should be checked by default
   */
  defaultChecked: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().bool),

  /**
   * Specify whether the control is disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().bool),

  /**
   * Specify whether the label should be hidden, or not
   */
  hideLabel: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().bool),

  /**
   * Provide a unique id for the underlying `<input>` node
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().string),

  /**
   * Provide where label text should be placed
   * NOTE: `top`/`bottom` are deprecated
   */
  labelPosition: prop_types__WEBPACK_IMPORTED_MODULE_14___default().oneOf(['top', 'right', 'bottom', 'left']),

  /**
   * Provide label text to be read by screen readers when interacting with the
   * control
   */
  labelText: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().node.isRequired),

  /**
   * Provide a name for the underlying `<input>` node
   */
  name: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().string),

  /**
   * Provide an optional `onChange` hook that is called each time the value of
   * the underlying `<input>` changes
   */
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().func),

  /**
   * Provide a handler that is invoked when a user clicks on the control
   */
  onClick: (prop_types__WEBPACK_IMPORTED_MODULE_14___default().func),

  /**
   * Specify the value of the <RadioButton>
   */
  value: prop_types__WEBPACK_IMPORTED_MODULE_14___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_14___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_14___default().number)]).isRequired
});

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(RadioButton, "contextType", _internal_usePrefix__WEBPACK_IMPORTED_MODULE_15__.PrefixContext);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(RadioButton, "defaultProps", {
  labelText: '',
  labelPosition: 'right',
  onChange: function onChange() {},
  value: ''
});


/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ((function () {
  var forwardRef = function forwardRef(props, ref) {
    return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().createElement(RadioButton, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, props, {
      innerRef: ref
    }));
  };

  forwardRef.displayName = 'RadioButton';
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_10___default().forwardRef(forwardRef);
})());

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/RadioButton/index.js":
/*!*************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/RadioButton/index.js ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "RadioButtonSkeleton": () => (/* reexport safe */ _RadioButton_Skeleton__WEBPACK_IMPORTED_MODULE_3__["default"]),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @carbon/feature-flags */ "../../node_modules/@carbon/feature-flags/es/index.js");
/* harmony import */ var _next_RadioButton__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./next/RadioButton */ "../../node_modules/carbon-components-react/es/components/RadioButton/next/RadioButton.js");
/* harmony import */ var _RadioButton__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./RadioButton */ "../../node_modules/carbon-components-react/es/components/RadioButton/RadioButton.js");
/* harmony import */ var _RadioButton_Skeleton__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./RadioButton.Skeleton */ "../../node_modules/carbon-components-react/es/components/RadioButton/RadioButton.Skeleton.js");
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */



var RadioButton = _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_0__.enabled('enable-v11-release') ? _next_RadioButton__WEBPACK_IMPORTED_MODULE_1__["default"] : _RadioButton__WEBPACK_IMPORTED_MODULE_2__["default"];
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (RadioButton);


/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/RadioButton/next/RadioButton.js":
/*!************************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/RadioButton/next/RadioButton.js ***!
  \************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");
/* harmony import */ var _internal_useId__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../../internal/useId */ "../../node_modules/carbon-components-react/es/internal/useId.js");
/* harmony import */ var _Text__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../Text */ "../../node_modules/carbon-components-react/es/components/Text/Text.js");



var _excluded = ["className", "disabled", "hideLabel", "id", "labelPosition", "labelText", "name", "onChange", "value"];






var RadioButton = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().forwardRef(function RadioButton(_ref, ref) {
  var className = _ref.className,
      disabled = _ref.disabled,
      hideLabel = _ref.hideLabel,
      id = _ref.id,
      _ref$labelPosition = _ref.labelPosition,
      labelPosition = _ref$labelPosition === void 0 ? 'right' : _ref$labelPosition,
      _ref$labelText = _ref.labelText,
      labelText = _ref$labelText === void 0 ? '' : _ref$labelText,
      name = _ref.name,
      _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? function () {} : _ref$onChange,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? '' : _ref$value,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  var uid = (0,_internal_useId__WEBPACK_IMPORTED_MODULE_6__.useId)('radio-button');
  var uniqueId = id || uid;

  function handleOnChange(event) {
    onChange(value, name, event);
  }

  var innerLabelClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()((0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--visually-hidden"), hideLabel));
  var wrapperClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()(className, "".concat(prefix, "--radio-button-wrapper"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--radio-button-wrapper--label-").concat(labelPosition), labelPosition !== 'right'));
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: wrapperClasses
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("input", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, rest, {
    type: "radio",
    className: "".concat(prefix, "--radio-button"),
    onChange: handleOnChange,
    id: uniqueId,
    ref: ref,
    disabled: disabled
  })), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("label", {
    htmlFor: uniqueId,
    className: "".concat(prefix, "--radio-button__label")
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("span", {
    className: "".concat(prefix, "--radio-button__appearance")
  }), labelText && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_Text__WEBPACK_IMPORTED_MODULE_7__.Text, {
    className: innerLabelClasses
  }, labelText)));
});
RadioButton.propTypes = {
  /**
   * Specify whether the <RadioButton> is currently checked
   */
  checked: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().bool),

  /**
   * Provide an optional className to be applied to the containing node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().string),

  /**
   * Specify whether the <RadioButton> should be checked by default
   */
  defaultChecked: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().bool),

  /**
   * Specify whether the control is disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().bool),

  /**
   * Specify whether the label should be hidden, or not
   */
  hideLabel: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().bool),

  /**
   * Provide a unique id for the underlying `<input>` node
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().string),

  /**
   * Provide where label text should be placed
   * NOTE: `top`/`bottom` are deprecated
   */
  labelPosition: prop_types__WEBPACK_IMPORTED_MODULE_8___default().oneOf(['right', 'left']),

  /**
   * Provide label text to be read by screen readers when interacting with the
   * control
   */
  labelText: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().node.isRequired),

  /**
   * Provide a name for the underlying `<input>` node
   */
  name: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().string),

  /**
   * Provide an optional `onChange` hook that is called each time the value of
   * the underlying `<input>` changes
   */
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().func),

  /**
   * Provide a handler that is invoked when a user clicks on the control
   */
  onClick: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().func),

  /**
   * Specify the value of the <RadioButton>
   */
  value: prop_types__WEBPACK_IMPORTED_MODULE_8___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_8___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_8___default().number)]).isRequired
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (RadioButton);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Search/Search.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Search/Search.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ Search)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_17___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_17__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_10___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_10__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-23.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var _tools_events__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ../../tools/events */ "../../node_modules/carbon-components-react/es/tools/events.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/match.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/keys.js");
/* harmony import */ var _prop_types_deprecate__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ../../prop-types/deprecate */ "../../node_modules/carbon-components-react/es/prop-types/deprecate.js");
/* harmony import */ var _FeatureFlags__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ../FeatureFlags */ "../../node_modules/carbon-components-react/es/components/FeatureFlags/index.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");









var _excluded = ["className", "type", "id", "placeHolderText", "placeholder", "labelText", "closeButtonLabelText", "small", "size", "light", "disabled", "onChange", "onKeyDown", "renderIcon", "onClear"];

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__["default"])(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__["default"])(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_6__["default"])(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */










var Search = /*#__PURE__*/function (_Component) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(Search, _Component);

  var _super = _createSuper(Search);

  function Search() {
    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, Search);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _super.call.apply(_super, [this].concat(args));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "state", {
      hasContent: _this.props.value || _this.props.defaultValue || false,
      prevValue: _this.props.value
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "clearInput", function (evt) {
      if (!_this.props.value) {
        _this.input.value = '';

        _this.props.onChange(evt);
      } else {
        var clearedEvt = Object.assign({}, evt.target, {
          target: {
            value: ''
          }
        });

        _this.props.onChange(clearedEvt);
      }

      _this.props.onClear();

      _this.setState({
        hasContent: false
      }, function () {
        return _this.input.focus();
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "handleChange", function (evt) {
      _this.setState({
        hasContent: evt.target.value !== ''
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "handleKeyDown", function (evt) {
      if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_11__.match)(evt, _internal_keyboard__WEBPACK_IMPORTED_MODULE_12__.Escape)) {
        _this.clearInput(evt);
      }
    });

    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(Search, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          className = _this$props.className,
          type = _this$props.type,
          _this$props$id = _this$props.id,
          id = _this$props$id === void 0 ? this._inputId = this._inputId || "search__input__id_".concat(Math.random().toString(36).substr(2)) : _this$props$id,
          placeHolderText = _this$props.placeHolderText,
          placeholder = _this$props.placeholder,
          labelText = _this$props.labelText,
          closeButtonLabelText = _this$props.closeButtonLabelText,
          small = _this$props.small,
          _this$props$size = _this$props.size,
          size = _this$props$size === void 0 ? !small ? 'xl' : 'sm' : _this$props$size,
          light = _this$props.light,
          disabled = _this$props.disabled,
          onChange = _this$props.onChange,
          onKeyDown = _this$props.onKeyDown,
          renderIcon = _this$props.renderIcon,
          onClear = _this$props.onClear,
          other = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_this$props, _excluded);

      var hasContent = this.state.hasContent;
      var scope = this.context;
      var enabled;

      if (scope.enabled) {
        enabled = scope.enabled('enable-v11-release');
      }

      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement(_internal_usePrefix__WEBPACK_IMPORTED_MODULE_13__.PrefixContext.Consumer, null, function (prefix) {
        var _classNames, _classNames2;

        var searchClasses = classnames__WEBPACK_IMPORTED_MODULE_10___default()((_classNames = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--search"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--search--sm"), size === 'sm'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--search--lg"), enabled ? size === 'md' : size === 'lg'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--search--xl"), enabled ? size === 'lg' : size === 'xl'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--search--light"), light), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--search--disabled"), disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, className, className), _classNames));
        var clearClasses = classnames__WEBPACK_IMPORTED_MODULE_10___default()((_classNames2 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames2, "".concat(prefix, "--search-close"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames2, "".concat(prefix, "--search-close--hidden"), !hasContent), _classNames2));
        var customIcon;

        if (renderIcon) {
          customIcon = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().cloneElement(renderIcon, {
            className: "".concat(prefix, "--search-magnifier-icon")
          });
        }

        var searchId = "".concat(id, "-search");
        var searchIcon = renderIcon ? customIcon : /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_14__.Search16, {
          className: "".concat(prefix, "--search-magnifier-icon")
        });
        return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", {
          role: "search",
          "aria-labelledby": searchId,
          className: searchClasses
        }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", {
          className: "".concat(prefix, "--search-magnifier"),
          ref: function ref(magnifier) {
            _this2.magnifier = magnifier;
          }
        }, searchIcon), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("label", {
          id: searchId,
          htmlFor: id,
          className: "".concat(prefix, "--label")
        }, labelText), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("input", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
          role: "searchbox",
          autoComplete: "off"
        }, other, {
          type: type,
          disabled: disabled,
          className: "".concat(prefix, "--search-input"),
          id: id,
          placeholder: placeHolderText || placeholder,
          onChange: (0,_tools_events__WEBPACK_IMPORTED_MODULE_15__.composeEventHandlers)([onChange, _this2.handleChange]),
          onKeyDown: (0,_tools_events__WEBPACK_IMPORTED_MODULE_15__.composeEventHandlers)([onKeyDown, _this2.handleKeyDown]),
          ref: function ref(input) {
            _this2.input = input;
          }
        })), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("button", {
          className: clearClasses,
          disabled: disabled,
          onClick: _this2.clearInput,
          type: "button",
          "aria-label": closeButtonLabelText
        }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_16__.Close16, null)));
      });
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(_ref, state) {
      var value = _ref.value;
      var prevValue = state.prevValue;
      return prevValue === value ? null : {
        hasContent: !!value,
        prevValue: value
      };
    }
  }]);

  return Search;
}(react__WEBPACK_IMPORTED_MODULE_9__.Component);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(Search, "propTypes", {
  /**
   * Specify an optional className to be applied to the container node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().string),

  /**
   * Specify a label to be read by screen readers on the "close" button
   */
  closeButtonLabelText: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().string),

  /**
   * Optionally provide the default value of the `<input>`
   */
  defaultValue: prop_types__WEBPACK_IMPORTED_MODULE_17___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_17___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_17___default().number)]),

  /**
   * Specify whether the `<input>` should be disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().bool),

  /**
   * Specify a custom `id` for the input
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().string),

  /**
   * Provide the label text for the Search icon
   */
  labelText: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().node.isRequired),

  /**
   * Specify light version or default version of this control
   */
  light: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().bool),

  /**
   * Optional callback called when the search value changes.
   */
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().func),

  /**
   * Optional callback called when the search value is cleared.
   */
  onClear: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().func),

  /**
   * Provide a handler that is invoked on the key down event for the input
   */
  onKeyDown: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().func),

  /**
   * Deprecated in favor of `placeholder`
   */
  placeHolderText: (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_18__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_17___default().string), "\nThe prop `placeHolderText` for Search has been deprecated in favor of `placeholder`. Please use `placeholder` instead."),

  /**
   * Provide an optional placeholder text for the Search.
   * Note: if the label and placeholder differ,
   * VoiceOver on Mac will read both
   */
  placeholder: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().string),

  /**
   * Rendered icon for the Search.
   * Can be a React component class
   */
  renderIcon: prop_types__WEBPACK_IMPORTED_MODULE_17___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_17___default().func), (prop_types__WEBPACK_IMPORTED_MODULE_17___default().object)]),

  /**
   * Specify the search size
   */
  size: prop_types__WEBPACK_IMPORTED_MODULE_17___default().oneOf(['sm', 'md', 'lg', 'xl']),

  /**
   * Specify whether the Search should be a small variant
   */

  /**
   * Specify whether the load was successful
   */
  small: (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_18__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_17___default().bool), "\nThe prop `small` for Search has been deprecated in favor of `size`. Please use `size=\"sm\"` instead."),

  /**
   * Optional prop to specify the type of the `<input>`
   */
  type: (prop_types__WEBPACK_IMPORTED_MODULE_17___default().string),

  /**
   * Specify the value of the `<input>`
   */
  value: prop_types__WEBPACK_IMPORTED_MODULE_17___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_17___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_17___default().number)])
});

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(Search, "contextType", _FeatureFlags__WEBPACK_IMPORTED_MODULE_19__.FeatureFlagContext);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(Search, "defaultProps", {
  type: 'text',
  placeholder: '',
  closeButtonLabelText: 'Clear search input',
  onChange: function onChange() {},
  onClear: function onClear() {}
});



/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Search/index.js":
/*!********************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Search/index.js ***!
  \********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @carbon/feature-flags */ "../../node_modules/@carbon/feature-flags/es/index.js");
/* harmony import */ var _next_Search__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./next/Search */ "../../node_modules/carbon-components-react/es/components/Search/next/Search.js");
/* harmony import */ var _Search__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./Search */ "../../node_modules/carbon-components-react/es/components/Search/Search.js");
/**
 * Copyright IBM Corp. 2016, 2021
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */



var Search = _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_0__.enabled('enable-v11-release') ? _next_Search__WEBPACK_IMPORTED_MODULE_1__["default"] : _Search__WEBPACK_IMPORTED_MODULE_2__["default"];

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Search);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Search/next/Search.js":
/*!**************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Search/next/Search.js ***!
  \**************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-23.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_13___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_13__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var _internal_focus__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../../internal/focus */ "../../node_modules/carbon-components-react/es/internal/focus/index.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/match.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/keys.js");
/* harmony import */ var _internal_useId__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../../internal/useId */ "../../node_modules/carbon-components-react/es/internal/useId.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");
/* harmony import */ var _prop_types_deprecate__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../../../prop-types/deprecate */ "../../node_modules/carbon-components-react/es/prop-types/deprecate.js");
/* harmony import */ var _tools_events__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../../tools/events */ "../../node_modules/carbon-components-react/es/tools/events.js");




var _excluded = ["autoComplete", "className", "closeButtonLabelText", "defaultValue", "disabled", "id", "labelText", "light", "onChange", "onClear", "onKeyDown", "placeHolderText", "placeholder", "renderIcon", "role", "size", "type", "value"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */











function Search(_ref) {
  var _cx, _cx2;

  var _ref$autoComplete = _ref.autoComplete,
      autoComplete = _ref$autoComplete === void 0 ? 'off' : _ref$autoComplete,
      className = _ref.className,
      _ref$closeButtonLabel = _ref.closeButtonLabelText,
      closeButtonLabelText = _ref$closeButtonLabel === void 0 ? 'Clear search input' : _ref$closeButtonLabel,
      defaultValue = _ref.defaultValue,
      disabled = _ref.disabled,
      id = _ref.id,
      labelText = _ref.labelText,
      light = _ref.light,
      _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? function () {} : _ref$onChange,
      _ref$onClear = _ref.onClear,
      onClear = _ref$onClear === void 0 ? function () {} : _ref$onClear,
      onKeyDown = _ref.onKeyDown,
      placeHolderText = _ref.placeHolderText,
      _ref$placeholder = _ref.placeholder,
      placeholder = _ref$placeholder === void 0 ? '' : _ref$placeholder,
      renderIcon = _ref.renderIcon,
      _ref$role = _ref.role,
      role = _ref$role === void 0 ? 'searchbox' : _ref$role,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'md' : _ref$size,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'text' : _ref$type,
      value = _ref.value,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_3__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_6__.usePrefix)();
  var input = (0,react__WEBPACK_IMPORTED_MODULE_5__.useRef)(null);
  var magnifier = (0,react__WEBPACK_IMPORTED_MODULE_5__.useRef)(null);
  var inputId = (0,_internal_useId__WEBPACK_IMPORTED_MODULE_7__.useId)('search-input');
  var uniqueId = id || inputId;
  var searchId = "".concat(uniqueId, "-search");

  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(value || defaultValue || false),
      _useState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState, 2),
      hasContent = _useState2[0],
      setHasContent = _useState2[1];

  var _useState3 = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(value),
      _useState4 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState3, 2),
      prevValue = _useState4[0],
      setPrevValue = _useState4[1];

  var searchClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()((_cx = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--search"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--search--sm"), size === 'sm'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--search--md"), size === 'md'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--search--lg"), size === 'lg'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--search--light"), light), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--search--disabled"), disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, className, className), _cx));
  var clearClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()((_cx2 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx2, "".concat(prefix, "--search-close"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx2, "".concat(prefix, "--search-close--hidden"), !hasContent), _cx2));

  if (value !== prevValue) {
    setHasContent(!!value);
    setPrevValue(value);
  }

  function clearInput(event) {
    if (!value) {
      input.current.value = '';
      onChange(event);
    } else {
      var clearedEvt = Object.assign({}, event.target, {
        target: {
          value: ''
        }
      });
      onChange(clearedEvt);
    }

    onClear();
    setHasContent(false);
    (0,_internal_focus__WEBPACK_IMPORTED_MODULE_8__.focus)(input);
  }

  function handleChange(event) {
    setHasContent(event.target.value !== '');
  }

  function handleKeyDown(event) {
    if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_9__.match)(event, _internal_keyboard__WEBPACK_IMPORTED_MODULE_10__.Escape)) {
      event.stopPropagation();
      clearInput(event);
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("div", {
    role: "search",
    "aria-labelledby": searchId,
    className: searchClasses
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("div", {
    className: "".concat(prefix, "--search-magnifier"),
    ref: magnifier
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(SearchIcon, {
    icon: renderIcon
  })), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("label", {
    id: searchId,
    htmlFor: uniqueId,
    className: "".concat(prefix, "--label")
  }, labelText), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("input", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, rest, {
    autoComplete: autoComplete,
    className: "".concat(prefix, "--search-input"),
    defaultValue: defaultValue,
    disabled: disabled,
    role: role,
    ref: input,
    id: uniqueId,
    onChange: (0,_tools_events__WEBPACK_IMPORTED_MODULE_11__.composeEventHandlers)([onChange, handleChange]),
    onKeyDown: (0,_tools_events__WEBPACK_IMPORTED_MODULE_11__.composeEventHandlers)([onKeyDown, handleKeyDown]),
    placeholder: placeHolderText || placeholder,
    type: type,
    value: value
  })), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement("button", {
    "aria-label": closeButtonLabelText,
    className: clearClasses,
    disabled: disabled,
    onClick: clearInput,
    type: "button"
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_12__.Close16, null)));
}

Search.propTypes = {
  /**
   * Specify an optional value for the `autocomplete` property on the underlying
   * `<input>`, defaults to "off"
   */
  autoComplete: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().string),

  /**
   * Specify an optional className to be applied to the container node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().string),

  /**
   * Specify a label to be read by screen readers on the "close" button
   */
  closeButtonLabelText: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().string),

  /**
   * Optionally provide the default value of the `<input>`
   */
  defaultValue: prop_types__WEBPACK_IMPORTED_MODULE_13___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_13___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_13___default().number)]),

  /**
   * Specify whether the `<input>` should be disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().bool),

  /**
   * Specify a custom `id` for the input
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().string),

  /**
   * Provide the label text for the Search icon
   */
  labelText: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().node.isRequired),

  /**
   * Specify light version or default version of this control
   */
  light: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().bool),

  /**
   * Optional callback called when the search value changes.
   */
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().func),

  /**
   * Optional callback called when the search value is cleared.
   */
  onClear: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().func),

  /**
   * Provide a handler that is invoked on the key down event for the input
   */
  onKeyDown: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().func),

  /**
   * Deprecated in favor of `placeholder`
   */
  placeHolderText: (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_14__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_13___default().string), "\nThe prop `placeHolderText` for Search has been deprecated in favor of `placeholder`. Please use `placeholder` instead."),

  /**
   * Provide an optional placeholder text for the Search.
   * Note: if the label and placeholder differ,
   * VoiceOver on Mac will read both
   */
  placeholder: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().string),

  /**
   * Rendered icon for the Search.
   * Can be a React component class
   */
  renderIcon: prop_types__WEBPACK_IMPORTED_MODULE_13___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_13___default().func), (prop_types__WEBPACK_IMPORTED_MODULE_13___default().object)]),

  /**
   * Specify the role for the underlying `<input>`, defaults to `searchbox`
   */
  role: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().string),

  /**
   * Specify the size of the Search
   */
  size: prop_types__WEBPACK_IMPORTED_MODULE_13___default().oneOf(['sm', 'md', 'lg']),

  /**
   * Optional prop to specify the type of the `<input>`
   */
  type: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().string),

  /**
   * Specify the value of the `<input>`
   */
  value: prop_types__WEBPACK_IMPORTED_MODULE_13___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_13___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_13___default().number)])
};

function SearchIcon(_ref2) {
  var icon = _ref2.icon;
  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_6__.usePrefix)();

  if (icon) {
    return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().cloneElement(icon, {
      className: "".concat(prefix, "--search-magnifier-icon")
    });
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_5___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_15__.Search16, {
    className: "".concat(prefix, "--search-magnifier-icon")
  });
}

SearchIcon.propTypes = {
  /**
   * Rendered icon for the Search. Can be a React component class
   */
  icon: prop_types__WEBPACK_IMPORTED_MODULE_13___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_13___default().func), (prop_types__WEBPACK_IMPORTED_MODULE_13___default().object)])
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Search);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Select/Select.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Select/Select.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-29.js");
/* harmony import */ var _prop_types_deprecate__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../../prop-types/deprecate */ "../../node_modules/carbon-components-react/es/prop-types/deprecate.js");
/* harmony import */ var _FeatureFlags__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../FeatureFlags */ "../../node_modules/carbon-components-react/es/components/FeatureFlags/index.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");
/* harmony import */ var _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! @carbon/feature-flags */ "../../node_modules/@carbon/feature-flags/es/index.js");



var _excluded = ["className", "id", "inline", "labelText", "disabled", "children", "noLabel", "iconDescription", "hideLabel", "invalid", "invalidText", "helperText", "light", "size", "warn", "warnText"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */








var Select = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().forwardRef(function Select(_ref, ref) {
  var _classNames, _classNames2, _classNames3;

  var className = _ref.className,
      id = _ref.id,
      inline = _ref.inline,
      labelText = _ref.labelText,
      disabled = _ref.disabled,
      children = _ref.children,
      noLabel = _ref.noLabel,
      iconDescription = _ref.iconDescription,
      hideLabel = _ref.hideLabel,
      invalid = _ref.invalid,
      invalidText = _ref.invalidText,
      helperText = _ref.helperText,
      light = _ref.light,
      size = _ref.size,
      warn = _ref.warn,
      warnText = _ref.warnText,
      other = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  var enabled = (0,_FeatureFlags__WEBPACK_IMPORTED_MODULE_6__.useFeatureFlag)('enable-v11-release');
  var selectClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()((_classNames = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--select"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--select--inline"), inline), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--select--light"), light), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--select--invalid"), invalid), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--select--disabled"), disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--select--warning"), warn), _classNames), [enabled ? null : className]);
  var labelClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--label"), (_classNames2 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames2, "".concat(prefix, "--visually-hidden"), hideLabel), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames2, "".concat(prefix, "--label--disabled"), disabled), _classNames2));
  var inputClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()((_classNames3 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames3, "".concat(prefix, "--select-input"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames3, "".concat(prefix, "--select-input--").concat(size), size), _classNames3));
  var errorId = "".concat(id, "-error-msg");

  var errorText = function () {
    if (invalid) {
      return invalidText;
    }

    if (warn) {
      return warnText;
    }
  }();

  var error = invalid || warn ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: "".concat(prefix, "--form-requirement"),
    id: errorId
  }, errorText) : null;
  var helperTextClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--form__helper-text"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--form__helper-text--disabled"), disabled));
  var helper = helperText ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: helperTextClasses
  }, helperText) : null;
  var ariaProps = {};

  if (invalid) {
    ariaProps['aria-describedby'] = errorId;
  }

  var input = function () {
    return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement((react__WEBPACK_IMPORTED_MODULE_3___default().Fragment), null, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("select", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, other, ariaProps, {
      id: id,
      className: inputClasses,
      disabled: disabled || undefined,
      "aria-invalid": invalid || undefined,
      ref: ref
    }), children), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_7__.ChevronDown16, {
      className: "".concat(prefix, "--select__arrow")
    }), invalid && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__.WarningFilled16, {
      className: "".concat(prefix, "--select__invalid-icon")
    }), !invalid && warn && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__.WarningAltFilled16, {
      className: "".concat(prefix, "--select__invalid-icon ").concat(prefix, "--select__invalid-icon--warning")
    }));
  }();

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: enabled ? classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--form-item"), className) : "".concat(prefix, "--form-item")
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: selectClasses
  }, !noLabel && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("label", {
    htmlFor: id,
    className: labelClasses
  }, labelText), inline && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: "".concat(prefix, "--select-input--inline__wrapper")
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: "".concat(prefix, "--select-input__wrapper"),
    "data-invalid": invalid || null
  }, input), error), !inline && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: "".concat(prefix, "--select-input__wrapper"),
    "data-invalid": invalid || null
  }, input), !inline && error ? error : helper));
});
Select.displayName = 'Select';
Select.propTypes = {
  /**
   * Provide the contents of your Select
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node),

  /**
   * Specify an optional className to be applied to the node containing the label and the select box
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),

  /**
   * Optionally provide the default value of the `<select>`
   */
  defaultValue: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().any),

  /**
   * Specify whether the control is disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Provide text that is used alongside the control label for additional help
   */
  helperText: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node),

  /**
   * Specify whether the label should be hidden, or not
   */
  hideLabel: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Provide a description for the twistie icon that can be read by screen readers
   */
  iconDescription: (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_10__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_9___default().string), 'The `iconDescription` prop for `Select` is no longer needed and has ' + 'been deprecated. It will be moved in the next major release.'),

  /**
   * Specify a custom `id` for the `<select>`
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string.isRequired),

  /**
   * Specify whether you want the inline version of this control
   */
  inline: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Specify if the currently value is invalid.
   */
  invalid: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Message which is displayed if the value is invalid.
   */
  invalidText: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node),

  /**
   * Provide label text to be read by screen readers when interacting with the
   * control
   */
  labelText: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node),

  /**
   * `true` to use the light version. For use on $ui-01 backgrounds only.
   * Don't use this to make tile background color same as container background color.
   */
  light: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Reserved for use with <Pagination> component. Will not render a label for the
   * select since Pagination renders one for us.
   */
  noLabel: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Provide an optional `onChange` hook that is called each time the value of
   * the underlying `<input>` changes
   */
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func),

  /**
   * Specify the size of the Select Input.
   */
  size: _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_11__.enabled('enable-v11-release') ? prop_types__WEBPACK_IMPORTED_MODULE_9___default().oneOf(['sm', 'md', 'lg']) : prop_types__WEBPACK_IMPORTED_MODULE_9___default().oneOf(['sm', 'md', 'lg', 'xl']),

  /**
   * Specify whether the control is currently in warning state
   */
  warn: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Provide the text that is displayed when the control is in warning state
   */
  warnText: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node)
};
Select.defaultProps = {
  disabled: false,
  labelText: 'Select',
  inline: false,
  invalid: false,
  invalidText: '',
  helperText: '',
  light: false
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Select);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/SelectItem/SelectItem.js":
/*!*****************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/SelectItem/SelectItem.js ***!
  \*****************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_6__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");



var _excluded = ["className", "value", "disabled", "hidden", "text"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */





var SelectItem = function SelectItem(_ref) {
  var _classNames;

  var className = _ref.className,
      value = _ref.value,
      disabled = _ref.disabled,
      hidden = _ref.hidden,
      text = _ref.text,
      other = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  var selectItemClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()((_classNames = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--select-option"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, className, className), _classNames));
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("option", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, other, {
    className: selectItemClasses,
    value: value,
    disabled: disabled,
    hidden: hidden
  }), text);
};

SelectItem.propTypes = {
  /**
   * Specify an optional className to be applied to the node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().string),

  /**
   * Specify whether the <SelectItem> should be disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool),

  /**
   * Specify whether the <SelectItem> is hidden
   */
  hidden: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool),

  /**
   * Provide the contents of your <SelectItem>
   */
  text: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().string.isRequired),

  /**
   * Specify the value of the <SelectItem>
   */
  value: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().any.isRequired)
};
SelectItem.defaultProps = {
  disabled: false,
  hidden: false,
  value: '',
  text: ''
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (SelectItem);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/SkeletonText/SkeletonText.js":
/*!*********************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/SkeletonText/SkeletonText.js ***!
  \*********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_6__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");



var _excluded = ["paragraph", "lineCount", "width", "heading", "className"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */




var randoms = [0.973051493507435, 0.15334737213558558, 0.5671034553053769];

function getRandomInt(min, max, n) {
  return Math.floor(randoms[n % 3] * (max - min + 1)) + min;
}

var SkeletonText = function SkeletonText(_ref) {
  var _classNames;

  var paragraph = _ref.paragraph,
      lineCount = _ref.lineCount,
      width = _ref.width,
      heading = _ref.heading,
      className = _ref.className,
      other = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  var skeletonTextClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()((_classNames = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--skeleton__text"), true), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--skeleton__heading"), heading), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, className, className), _classNames));
  var widthNum = parseInt(width, 10);
  var widthPx = width.includes('px');
  var widthPercent = width.includes('%');

  if (widthPercent && paragraph) {
    var lines = [];

    for (var i = 0; i < lineCount; i++) {
      var randomWidth = getRandomInt(0, 75, i) + 'px';
      lines.push( /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("p", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
        className: skeletonTextClasses,
        style: {
          width: "calc(".concat(width, " - ").concat(randomWidth, ")")
        },
        key: i
      }, other)));
    }

    return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", null, lines);
  }

  if (widthPx && paragraph) {
    var _lines = [];

    for (var j = 0; j < lineCount; j++) {
      var _randomWidth = getRandomInt(widthNum - 75, widthNum, j) + 'px';

      _lines.push( /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("p", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
        className: skeletonTextClasses,
        style: {
          width: _randomWidth
        },
        key: j
      }, other)));
    }

    return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", null, _lines);
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("p", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    className: skeletonTextClasses,
    style: {
      width: width
    }
  }, other));
};

SkeletonText.propTypes = {
  /**
   * Specify an optional className to be applied to the container node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().string),

  /**
   * generates skeleton text at a larger size
   */
  heading: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool),

  /**
   * the number of lines in a paragraph
   */
  lineCount: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().number),

  /**
   * will generate multiple lines of text
   */
  paragraph: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool),

  /**
   * width (in px or %) of single line of text or max-width of paragraph lines
   */
  width: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().string)
};
SkeletonText.defaultProps = {
  paragraph: false,
  width: '100%',
  heading: false,
  lineCount: 3
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (SkeletonText);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Switch/Switch.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Switch/Switch.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_6__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");



var _excluded = ["children", "className", "disabled", "index", "name", "onClick", "onKeyDown", "selected", "text"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */




var Switch = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().forwardRef(function Switch(props, tabRef) {
  var children = props.children,
      className = props.className,
      disabled = props.disabled,
      index = props.index,
      name = props.name,
      onClick = props.onClick,
      onKeyDown = props.onKeyDown,
      selected = props.selected,
      text = props.text,
      other = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(props, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();

  var handleClick = function handleClick(e) {
    e.preventDefault();
    onClick({
      index: index,
      name: name,
      text: text
    });
  };

  var handleKeyDown = function handleKeyDown(event) {
    var key = event.key || event.which;
    onKeyDown({
      index: index,
      name: name,
      text: text,
      key: key
    });
  };

  var classes = classnames__WEBPACK_IMPORTED_MODULE_4___default()(className, "".concat(prefix, "--content-switcher-btn"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--content-switcher--selected"), selected));
  var commonProps = {
    onClick: handleClick,
    onKeyDown: handleKeyDown,
    className: classes,
    disabled: disabled
  };
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("button", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    type: "button",
    ref: tabRef,
    role: "tab",
    tabIndex: selected ? '0' : '-1',
    "aria-selected": selected
  }, other, commonProps), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("span", {
    className: "".concat(prefix, "--content-switcher__label"),
    title: text
  }, text !== undefined ? text : children));
});
Switch.displayName = 'Switch';
Switch.propTypes = {
  /**
   * Provide child elements to be rendered inside of the Switch
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().node),

  /**
   * Specify an optional className to be added to your Switch
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().string),

  /**
   * Specify whether or not the Switch should be disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool),

  /**
   * The index of your Switch in your ContentSwitcher that is used for event handlers.
   * Reserved for usage in ContentSwitcher
   */
  index: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().number),

  /**
   * Provide the name of your Switch that is used for event handlers
   */
  name: prop_types__WEBPACK_IMPORTED_MODULE_6___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_6___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_6___default().number)]),

  /**
   * A handler that is invoked when a user clicks on the control.
   * Reserved for usage in ContentSwitcher
   */
  onClick: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().func),

  /**
   * A handler that is invoked on the key down event for the control.
   * Reserved for usage in ContentSwitcher
   */
  onKeyDown: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().func),

  /**
   * Whether your Switch is selected. Reserved for usage in ContentSwitcher
   */
  selected: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool),

  /**
   * Provide the contents of your Switch
   */
  text: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().string)
};
Switch.defaultProps = {
  selected: false,
  text: 'Provide text',
  onClick: function onClick() {},
  onKeyDown: function onKeyDown() {}
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Switch);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Tab/Tab.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Tab/Tab.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ Tab)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_11___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_11__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! @carbon/feature-flags */ "../../node_modules/@carbon/feature-flags/es/index.js");
/* harmony import */ var _prop_types_deprecate__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../../prop-types/deprecate */ "../../node_modules/carbon-components-react/es/prop-types/deprecate.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");








var _excluded = ["id", "className", "handleTabClick", "handleTabKeyDown", "disabled", "href", "index", "label", "selected", "tabIndex", "onClick", "onKeyDown", "renderAnchor", "renderButton", "renderContent", "role"];

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_6__["default"])(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_6__["default"])(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_5__["default"])(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */







var Tab = /*#__PURE__*/function (_React$Component) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(Tab, _React$Component);

  var _super = _createSuper(Tab);

  function Tab() {
    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, Tab);

    return _super.apply(this, arguments);
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(Tab, [{
    key: "render",
    value: function render() {
      var _classNames,
          _this = this,
          _buttonProps;

      var prefix = this.context;

      var _this$props = this.props,
          id = _this$props.id,
          className = _this$props.className,
          handleTabClick = _this$props.handleTabClick,
          handleTabKeyDown = _this$props.handleTabKeyDown,
          disabled = _this$props.disabled,
          _this$props$href = _this$props.href,
          href = _this$props$href === void 0 ? '#' : _this$props$href,
          index = _this$props.index,
          label = _this$props.label,
          selected = _this$props.selected,
          _this$props$tabIndex = _this$props.tabIndex,
          tabIndex = _this$props$tabIndex === void 0 ? 0 : _this$props$tabIndex,
          _onClick = _this$props.onClick,
          _onKeyDown = _this$props.onKeyDown,
          renderAnchor = _this$props.renderAnchor,
          renderButton = _this$props.renderButton,
          renderContent = _this$props.renderContent,
          role = _this$props.role,
          other = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_this$props, _excluded);

      var classes = classnames__WEBPACK_IMPORTED_MODULE_9___default()(className, // TODO: remove scrollable in next major release
      // `${prefix}--tabs__nav-item`,
      "".concat(prefix, "--tabs--scrollable__nav-item"), (_classNames = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_classNames, "".concat(prefix, "--tabs__nav-item--disabled"), disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_classNames, "".concat(prefix, "--tabs__nav-item--selected"), selected), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_classNames, "".concat(prefix, "--tabs--scrollable__nav-item--disabled"), disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_classNames, "".concat(prefix, "--tabs--scrollable__nav-item--selected"), selected), _classNames));
      var buttonProps = (_buttonProps = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_buttonProps, 'aria-selected', selected), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_buttonProps, 'aria-disabled', disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_buttonProps, 'aria-controls', id && "".concat(id, "__panel")), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_buttonProps, "id", id), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_buttonProps, "className", "".concat(prefix, "--tabs--scrollable__nav-link")), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_buttonProps, "href", href), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_buttonProps, "tabIndex", !disabled ? tabIndex : -1), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_buttonProps, "ref", function ref(e) {
        _this.tabAnchor = e;
      }), _buttonProps);
      var renderElement = renderButton || renderAnchor;
      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_8___default().createElement("li", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, other, {
        className: classes,
        onClick: function onClick(evt) {
          if (disabled) {
            return;
          }

          if (handleTabClick) {
            handleTabClick(index, evt);
          }

          _onClick(evt);
        },
        onKeyDown: function onKeyDown(evt) {
          if (disabled) {
            return;
          }

          if (handleTabKeyDown) {
            handleTabKeyDown(index, evt);
          }

          _onKeyDown(evt);
        },
        role: "presentation"
      }), renderElement ? renderElement(buttonProps) : /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_8___default().createElement("button", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
        type: "button",
        role: "tab"
      }, buttonProps), label));
    }
  }]);

  return Tab;
}((react__WEBPACK_IMPORTED_MODULE_8___default().Component));

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(Tab, "contextType", _internal_usePrefix__WEBPACK_IMPORTED_MODULE_10__.PrefixContext);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(Tab, "propTypes", {
  /**
   * Specify an optional className to be added to your Tab
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().string),

  /**
   * Whether your Tab is disabled.
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),

  /**
   * A handler that is invoked when a user clicks on the control.
   * Reserved for usage in Tabs
   */
  handleTabClick: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().func),

  /**
   * A handler that is invoked on the key down event for the control.
   * Reserved for usage in Tabs
   */
  handleTabKeyDown: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().func),

  /**
   * Provide a string that represents the `href` of the Tab
   */
  href: (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_12__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_11___default().string)),

  /**
   * The element ID for the top-level element.
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().string),

  /**
   * The index of your Tab in your Tabs. Reserved for usage in Tabs
   */
  index: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number),

  /**
   * Provide the contents of your Tab
   */
  label: _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_13__.enabled('enable-v11-release') ? (prop_types__WEBPACK_IMPORTED_MODULE_11___default().node.isRequired) : (prop_types__WEBPACK_IMPORTED_MODULE_11___default().node),

  /**
   * Provide a handler that is invoked when a user clicks on the control
   */
  onClick: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().func.isRequired),

  /**
   * Provide a handler that is invoked on the key down event for the control
   */
  onKeyDown: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().func.isRequired),

  /*
   * An optional parameter to allow overriding the anchor rendering.
   * Useful for using Tab along with react-router or other client
   * side router libraries.
   **/
  renderAnchor: (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_12__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_11___default().func)),
  renderButton: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().func),

  /*
   * An optional parameter to allow overriding the content rendering.
   **/
  renderContent: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().func),

  /**
   * Provide an accessibility role for your Tab
   */
  role: (0,_prop_types_deprecate__WEBPACK_IMPORTED_MODULE_12__["default"])((prop_types__WEBPACK_IMPORTED_MODULE_11___default().string)),

  /**
   * Whether your Tab is selected.
   * Reserved for usage in Tabs
   */
  selected: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool.isRequired),

  /**
   * Specify the tab index of the `<button>` node
   */
  tabIndex: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number)
});

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(Tab, "defaultProps", {
  label: _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_13__.enabled('enable-v11-release') ? undefined : 'provide a label',
  selected: false,
  onClick: function onClick() {},
  onKeyDown: function onKeyDown() {}
});



/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Tab/index.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Tab/index.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @carbon/feature-flags */ "../../node_modules/@carbon/feature-flags/es/index.js");
/* harmony import */ var _Tabs_next_Tabs__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Tabs/next/Tabs */ "../../node_modules/carbon-components-react/es/components/Tabs/next/Tabs.js");
/* harmony import */ var _Tab__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./Tab */ "../../node_modules/carbon-components-react/es/components/Tab/Tab.js");
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */



var Tab = _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_0__.enabled('enable-v11-release') ? _Tabs_next_Tabs__WEBPACK_IMPORTED_MODULE_1__.Tab : _Tab__WEBPACK_IMPORTED_MODULE_2__["default"];
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Tab);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/TabContent/TabContent.js":
/*!*****************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/TabContent/TabContent.js ***!
  \*****************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var _internal_keyboard_navigation__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../internal/keyboard/navigation */ "../../node_modules/carbon-components-react/es/internal/keyboard/navigation.js");
/* harmony import */ var _internal_useIsomorphicEffect__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../internal/useIsomorphicEffect */ "../../node_modules/carbon-components-react/es/internal/useIsomorphicEffect.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");




var _excluded = ["className", "selected", "children"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */






/**
 * Determine if the node within the provided ref contains content that is tabbable.
 */

function useTabbableContent(ref) {
  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_4__.useState)(false),
      _useState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(_useState, 2),
      hasTabbableContent = _useState2[0],
      setHasTabbableContent = _useState2[1];

  (0,_internal_useIsomorphicEffect__WEBPACK_IMPORTED_MODULE_6__["default"])(function () {
    if (ref.current) {
      setHasTabbableContent(ref.current.querySelector(_internal_keyboard_navigation__WEBPACK_IMPORTED_MODULE_7__.selectorTabbable));
    }
  });
  return hasTabbableContent;
}

var TabContent = function TabContent(props) {
  var className = props.className,
      selected = props.selected,
      children = props.children,
      other = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(props, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_8__.usePrefix)();
  var tabContentClasses = classnames__WEBPACK_IMPORTED_MODULE_5___default()("".concat(prefix, "--tab-content"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, className, className));
  var ref = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var hasTabbableContent = useTabbableContent(ref);
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    role: "tabpanel"
  }, other, {
    className: tabContentClasses,
    selected: selected,
    hidden: !selected,
    ref: ref,
    tabIndex: hasTabbableContent ? undefined : 0
  }), children);
};

TabContent.propTypes = {
  /**
   * Pass in content to render inside of the TabContent
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node),

  /**
   * Provide a className for the tab content container
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),

  /**
   * Specify whether the TabContent is selected
   */
  selected: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool)
};
TabContent.defaultProps = {
  selected: false
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (TabContent);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Tabs/Tabs.Skeleton.js":
/*!**************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Tabs/Tabs.Skeleton.js ***!
  \**************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_6__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");



var _excluded = ["className", "type"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */





function Tab() {
  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("li", {
    className: "".concat(prefix, "--tabs--scrollable__nav-item")
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: "".concat(prefix, "--tabs__nav-link")
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("span", null)));
}

function TabsSkeleton(_ref) {
  var className = _ref.className,
      type = _ref.type,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  var tabClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()(className, "".concat(prefix, "--tabs"), "".concat(prefix, "--skeleton"), "".concat(prefix, "--tabs--scrollable"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--tabs--scrollable--container"), type === 'container'));
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    className: tabClasses
  }, rest), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("ul", {
    className: "".concat(prefix, "--tabs--scrollable__nav")
  }, Tab(), Tab(), Tab(), Tab(), Tab()));
}

TabsSkeleton.propTypes = {
  /**
   * Specify an optional className to add.
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().string),

  /**
   * Provide the type of Tab
   */
  type: prop_types__WEBPACK_IMPORTED_MODULE_6___default().oneOf(['', 'default', 'container'])
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (TabsSkeleton);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Tabs/Tabs.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Tabs/Tabs.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ Tabs)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_16___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_16__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_10___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_10__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var lodash_debounce__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! lodash.debounce */ "../../node_modules/lodash.debounce/index.js");
/* harmony import */ var lodash_debounce__WEBPACK_IMPORTED_MODULE_11___default = /*#__PURE__*/__webpack_require__.n(lodash_debounce__WEBPACK_IMPORTED_MODULE_11__);
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/match.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/keys.js");
/* harmony import */ var _TabContent__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../TabContent */ "../../node_modules/carbon-components-react/es/components/TabContent/TabContent.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");









var _excluded = ["className", "type", "light", "onSelectionChange", "scrollDebounceWait", "scrollIntoView", "selectionMode", "tabContentClassName", "leftOverflowButtonProps", "rightOverflowButtonProps"];

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__["default"])(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_7__["default"])(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_6__["default"])(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */









var Tabs = /*#__PURE__*/function (_React$Component) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(Tabs, _React$Component);

  var _super = _createSuper(Tabs);

  function Tabs() {
    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, Tabs);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _super.call.apply(_super, [this].concat(args));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "state", {
      horizontalOverflow: false
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "tablist", /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createRef());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "leftOverflowNavButton", /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createRef());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "rightOverflowNavButton", /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createRef());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "OVERFLOW_BUTTON_OFFSET", 40);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "handleScroll", function () {
      var _this$tablist;

      if (!((_this$tablist = _this.tablist) !== null && _this$tablist !== void 0 && _this$tablist.current)) {
        return;
      }

      var _this$tablist$current = _this.tablist.current,
          tablistClientWidth = _this$tablist$current.clientWidth,
          tablistScrollLeft = _this$tablist$current.scrollLeft,
          tablistScrollWidth = _this$tablist$current.scrollWidth;

      _this.setState({
        tablistClientWidth: tablistClientWidth,
        horizontalOverflow: tablistScrollWidth > tablistClientWidth,
        tablistScrollWidth: tablistScrollWidth,
        tablistScrollLeft: tablistScrollLeft
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_debouncedHandleWindowResize", null);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_handleWindowResize", _this.handleScroll);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_debouncedHandleScroll", null);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_handleScroll", _this.handleScroll);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "getEnabledTabs", function () {
      return react__WEBPACK_IMPORTED_MODULE_9___default().Children.toArray(_this.props.children).reduce(function (enabledTabs, tab, index) {
        return !tab.props.disabled ? enabledTabs.concat(index) : enabledTabs;
      }, []);
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "getNextIndex", function (index, direction) {
      var enabledTabs = _this.getEnabledTabs();

      var nextIndex = Math.max(enabledTabs.indexOf(index) + direction, // For `tab` not found in `enabledTabs`
      -1);
      var nextIndexLooped = nextIndex >= 0 && nextIndex < enabledTabs.length ? nextIndex : nextIndex - Math.sign(nextIndex) * enabledTabs.length;
      return enabledTabs[nextIndexLooped];
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "getDirection", function (evt) {
      if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_12__.match)(evt, _internal_keyboard__WEBPACK_IMPORTED_MODULE_13__.ArrowLeft)) {
        return -1;
      }

      if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_12__.match)(evt, _internal_keyboard__WEBPACK_IMPORTED_MODULE_13__.ArrowRight)) {
        return 1;
      }

      return 0;
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "getTabAt", function (index, useFresh) {
      return !useFresh && _this["tab".concat(index)] || react__WEBPACK_IMPORTED_MODULE_9___default().Children.toArray(_this.props.children)[index];
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "scrollTabIntoView", function (event, _ref) {
      var index = _ref.index;

      var tab = _this.getTabAt(index);

      if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_12__.matches)(event, [_internal_keyboard__WEBPACK_IMPORTED_MODULE_13__.ArrowLeft, _internal_keyboard__WEBPACK_IMPORTED_MODULE_13__.ArrowRight]) || event.type === 'click') {
        var _tab$tabAnchor, _tab$tabAnchor2;

        var currentScrollLeft = _this.state.tablistScrollLeft;
        tab === null || tab === void 0 ? void 0 : (_tab$tabAnchor = tab.tabAnchor) === null || _tab$tabAnchor === void 0 ? void 0 : _tab$tabAnchor.scrollIntoView({
          block: 'nearest',
          inline: 'nearest'
        });
        tab === null || tab === void 0 ? void 0 : (_tab$tabAnchor2 = tab.tabAnchor) === null || _tab$tabAnchor2 === void 0 ? void 0 : _tab$tabAnchor2.focus();
        var newScrollLeft = _this.tablist.current.scrollLeft;

        if (newScrollLeft > currentScrollLeft) {
          _this.tablist.current.scrollLeft += _this.OVERFLOW_BUTTON_OFFSET;
        }
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "selectTabAt", function (event, _ref2) {
      var index = _ref2.index,
          onSelectionChange = _ref2.onSelectionChange;

      _this.scrollTabIntoView(event, {
        index: index
      });

      if (_this.state.selected !== index) {
        _this.setState({
          selected: index
        });

        if (typeof onSelectionChange === 'function') {
          onSelectionChange(index);
        }
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "handleTabKeyDown", function (onSelectionChange) {
      return function (index, evt) {
        if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_12__.matches)(evt, [_internal_keyboard__WEBPACK_IMPORTED_MODULE_13__.Enter, _internal_keyboard__WEBPACK_IMPORTED_MODULE_13__.Space])) {
          _this.selectTabAt(evt, {
            index: index,
            onSelectionChange: onSelectionChange
          });
        }

        var nextIndex = function () {
          if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_12__.matches)(evt, [_internal_keyboard__WEBPACK_IMPORTED_MODULE_13__.ArrowLeft, _internal_keyboard__WEBPACK_IMPORTED_MODULE_13__.ArrowRight])) {
            return _this.getNextIndex(index, _this.getDirection(evt));
          }

          if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_12__.match)(evt, _internal_keyboard__WEBPACK_IMPORTED_MODULE_13__.Home)) {
            return 0;
          }

          if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_12__.match)(evt, _internal_keyboard__WEBPACK_IMPORTED_MODULE_13__.End)) {
            return _this.getEnabledTabs().pop();
          }
        }();

        var tab = _this.getTabAt(nextIndex);

        if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_12__.matches)(evt, [_internal_keyboard__WEBPACK_IMPORTED_MODULE_13__.ArrowLeft, _internal_keyboard__WEBPACK_IMPORTED_MODULE_13__.ArrowRight, _internal_keyboard__WEBPACK_IMPORTED_MODULE_13__.Home, _internal_keyboard__WEBPACK_IMPORTED_MODULE_13__.End])) {
          var _tab$tabAnchor3;

          evt.preventDefault();

          if (_this.props.selectionMode !== 'manual') {
            _this.selectTabAt(evt, {
              index: nextIndex,
              onSelectionChange: onSelectionChange
            });
          } else {
            _this.scrollTabIntoView(evt, {
              index: nextIndex
            });
          }

          tab === null || tab === void 0 ? void 0 : (_tab$tabAnchor3 = tab.tabAnchor) === null || _tab$tabAnchor3 === void 0 ? void 0 : _tab$tabAnchor3.focus();
        }
      };
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "getTabs", function () {
      return react__WEBPACK_IMPORTED_MODULE_9___default().Children.map(_this.props.children, function (tab) {
        return tab;
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "handleTabClick", function (onSelectionChange) {
      return function (index, evt) {
        evt.preventDefault();

        _this.selectTabAt(evt, {
          index: index,
          onSelectionChange: onSelectionChange
        });
      };
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "setTabAt", function (index, tabRef) {
      _this["tab".concat(index)] = tabRef;
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "overflowNavInterval", null);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "handleOverflowNavClick", function (_, _ref3) {
      var _this$tablist2;

      var direction = _ref3.direction,
          _ref3$multiplier = _ref3.multiplier,
          multiplier = _ref3$multiplier === void 0 ? 10 : _ref3$multiplier;

      // account for overflow button appearing and causing tablist width change
      var _this$tablist$current2 = (_this$tablist2 = _this.tablist) === null || _this$tablist2 === void 0 ? void 0 : _this$tablist2.current,
          clientWidth = _this$tablist$current2.clientWidth,
          scrollLeft = _this$tablist$current2.scrollLeft,
          scrollWidth = _this$tablist$current2.scrollWidth;

      if (direction === 1 && !scrollLeft) {
        _this.tablist.current.scrollLeft += _this.OVERFLOW_BUTTON_OFFSET;
      }

      _this.tablist.current.scrollLeft += direction * multiplier;
      var leftEdgeReached = direction === -1 && scrollLeft < _this.OVERFLOW_BUTTON_OFFSET;
      var rightEdgeReached = direction === 1 && scrollLeft + clientWidth >= scrollWidth - _this.OVERFLOW_BUTTON_OFFSET;

      if (leftEdgeReached || rightEdgeReached) {
        if (leftEdgeReached) {
          var _this$rightOverflowNa, _this$rightOverflowNa2;

          (_this$rightOverflowNa = _this.rightOverflowNavButton) === null || _this$rightOverflowNa === void 0 ? void 0 : (_this$rightOverflowNa2 = _this$rightOverflowNa.current) === null || _this$rightOverflowNa2 === void 0 ? void 0 : _this$rightOverflowNa2.focus();
        }

        if (rightEdgeReached) {
          var _this$leftOverflowNav, _this$leftOverflowNav2;

          (_this$leftOverflowNav = _this.leftOverflowNavButton) === null || _this$leftOverflowNav === void 0 ? void 0 : (_this$leftOverflowNav2 = _this$leftOverflowNav.current) === null || _this$leftOverflowNav2 === void 0 ? void 0 : _this$leftOverflowNav2.focus();
        }
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "handleOverflowNavMouseDown", function (event, _ref4) {
      var direction = _ref4.direction;

      // disregard mouse buttons aside from left mouse button
      if (event.buttons !== 1) {
        return;
      }

      _this.overflowNavInterval = setInterval(function () {
        var _this$tablist3;

        var _this$tablist$current3 = (_this$tablist3 = _this.tablist) === null || _this$tablist3 === void 0 ? void 0 : _this$tablist3.current,
            clientWidth = _this$tablist$current3.clientWidth,
            scrollLeft = _this$tablist$current3.scrollLeft,
            scrollWidth = _this$tablist$current3.scrollWidth; // clear interval if scroll reaches left or right edge


        var leftEdgeReached = direction === -1 && scrollLeft < _this.OVERFLOW_BUTTON_OFFSET;
        var rightEdgeReached = direction === 1 && scrollLeft + clientWidth >= scrollWidth - _this.OVERFLOW_BUTTON_OFFSET;

        if (leftEdgeReached || rightEdgeReached) {
          clearInterval(_this.overflowNavInterval);
        } // account for overflow button appearing and causing tablist width change


        _this.handleOverflowNavClick(event, {
          direction: direction
        });
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "handleOverflowNavMouseUp", function () {
      clearInterval(_this.overflowNavInterval);
    });

    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(Tabs, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this$tablist4;

      if (!this._debouncedHandleWindowResize) {
        this._debouncedHandleWindowResize = lodash_debounce__WEBPACK_IMPORTED_MODULE_11___default()(this._handleWindowResize, 200);
      }

      this._handleWindowResize();

      window.addEventListener('resize', this._debouncedHandleWindowResize);

      if (!this._debouncedHandleScroll) {
        this._debouncedHandleScroll = lodash_debounce__WEBPACK_IMPORTED_MODULE_11___default()(this._handleScroll, this.props.scrollDebounceWait);
      } // scroll selected tab into view on mount


      var _ref5 = ((_this$tablist4 = this.tablist) === null || _this$tablist4 === void 0 ? void 0 : _this$tablist4.current) || {},
          tablistClientWidth = _ref5.clientWidth,
          tablistScrollLeft = _ref5.scrollLeft,
          tablistScrollWidth = _ref5.scrollWidth;

      var tab = this.getTabAt(this.state.selected);
      var horizontalOverflow = tablistScrollWidth > tablistClientWidth;

      if (horizontalOverflow) {
        var _tab$tabAnchor4, _tab$tabAnchor5, _tab$tabAnchor6;

        var leftOverflowNavButtonHidden = (tab === null || tab === void 0 ? void 0 : (_tab$tabAnchor4 = tab.tabAnchor) === null || _tab$tabAnchor4 === void 0 ? void 0 : _tab$tabAnchor4.getBoundingClientRect().right) < (tab === null || tab === void 0 ? void 0 : (_tab$tabAnchor5 = tab.tabAnchor) === null || _tab$tabAnchor5 === void 0 ? void 0 : _tab$tabAnchor5.offsetParent.getBoundingClientRect().right);
        var rightOverflowNavButtonHidden = tablistScrollLeft + tablistClientWidth === tablistScrollWidth;
        this.props.scrollIntoView && (tab === null || tab === void 0 ? void 0 : (_tab$tabAnchor6 = tab.tabAnchor) === null || _tab$tabAnchor6 === void 0 ? void 0 : _tab$tabAnchor6.scrollIntoView({
          block: 'nearest',
          inline: 'nearest'
        })); // account for overflow buttons in scroll position on mount

        if (!leftOverflowNavButtonHidden && !rightOverflowNavButtonHidden) {
          this.tablist.current.scrollLeft += this.OVERFLOW_BUTTON_OFFSET * 2;
        }
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      if (this._debouncedHandleWindowResize) {
        this._debouncedHandleWindowResize.cancel();
      }

      window.removeEventListener('resize', this._debouncedHandleWindowResize);
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(_, prevState) {
      // compare current tablist properties to current state
      var _this$tablist$current4 = this.tablist.current,
          tablistClientWidth = _this$tablist$current4.clientWidth,
          tablistScrollLeft = _this$tablist$current4.scrollLeft,
          tablistScrollWidth = _this$tablist$current4.scrollWidth;
      var _this$state = this.state,
          currentStateClientWidth = _this$state.tablistClientWidth,
          currentStateScrollLeft = _this$state.tablistScrollLeft,
          currentStateScrollWidth = _this$state.tablistScrollWidth,
          selected = _this$state.selected;

      if (tablistClientWidth !== currentStateClientWidth || tablistScrollLeft !== currentStateScrollLeft || tablistScrollWidth !== currentStateScrollWidth) {
        this.setState({
          horizontalOverflow: tablistScrollWidth > tablistClientWidth,
          tablistClientWidth: tablistClientWidth,
          tablistScrollLeft: tablistScrollLeft,
          tablistScrollWidth: tablistScrollWidth
        });
      }

      if (this.props.scrollIntoView && prevState.selected !== selected) {
        var _this$getTabAt, _this$getTabAt$tabAnc;

        (_this$getTabAt = this.getTabAt(selected)) === null || _this$getTabAt === void 0 ? void 0 : (_this$getTabAt$tabAnc = _this$getTabAt.tabAnchor) === null || _this$getTabAt$tabAnc === void 0 ? void 0 : _this$getTabAt$tabAnc.scrollIntoView({
          block: 'nearest',
          inline: 'nearest'
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this,
          _classNames,
          _classNames2,
          _classNames3;

      var _this$props = this.props,
          className = _this$props.className,
          type = _this$props.type,
          light = _this$props.light,
          onSelectionChange = _this$props.onSelectionChange,
          scrollDebounceWait = _this$props.scrollDebounceWait,
          scrollIntoView = _this$props.scrollIntoView,
          selectionMode = _this$props.selectionMode,
          tabContentClassName = _this$props.tabContentClassName,
          leftOverflowButtonProps = _this$props.leftOverflowButtonProps,
          rightOverflowButtonProps = _this$props.rightOverflowButtonProps,
          other = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_this$props, _excluded);

      var prefix = this.context;
      /**
       * The tab panel acts like a tab panel when the screen is wider, but acts
       * like a select list when the screen is narrow.  In the wide case we want
       * to allow the user to use the tab key to set the focus in the tab panel
       * and then use the left and right arrow keys to navigate the tabs.  In the
       * narrow case we want to use the tab key to select different options in
       * the list.
       *
       * We set the tab index based on the different states so the browser will treat
       * the whole tab panel as a single focus component when it looks like a tab
       * panel and separate components when it looks like a select list.
       */

      var tabsWithProps = this.getTabs().map(function (tab, index) {
        var tabIndex = index === _this2.state.selected ? 0 : -1;
        var newTab = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().cloneElement(tab, {
          index: index,
          selected: index === _this2.state.selected,
          handleTabClick: _this2.handleTabClick(onSelectionChange),
          tabIndex: tabIndex,
          ref: function ref(e) {
            _this2.setTabAt(index, e);
          },
          handleTabKeyDown: _this2.handleTabKeyDown(onSelectionChange)
        });
        return newTab;
      });
      var tabContentWithProps = react__WEBPACK_IMPORTED_MODULE_9___default().Children.map(tabsWithProps, function (tab) {
        var _tab$props = tab.props,
            tabId = _tab$props.id,
            children = _tab$props.children,
            selected = _tab$props.selected,
            _tab$props$renderCont = _tab$props.renderContent,
            Content = _tab$props$renderCont === void 0 ? _TabContent__WEBPACK_IMPORTED_MODULE_14__["default"] : _tab$props$renderCont;
        return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement(Content, {
          id: tabId && "".concat(tabId, "__panel"),
          className: tabContentClassName,
          hidden: !selected,
          selected: selected,
          "aria-labelledby": tabId
        }, children);
      });
      var leftOverflowNavButtonHidden = !this.state.horizontalOverflow || !this.state.tablistScrollLeft;
      var rightOverflowNavButtonHidden = !this.state.horizontalOverflow || this.state.tablistScrollLeft + this.state.tablistClientWidth === this.state.tablistScrollWidth;
      var classes = {
        // TODO: remove scrollable from classnames in next major release and uncomment classnames that don't contain scrollable
        tabs: classnames__WEBPACK_IMPORTED_MODULE_10___default()(className, // `${prefix}--tabs`,
        "".concat(prefix, "--tabs--scrollable"), (_classNames = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--tabs--scrollable--container"), type === 'container'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames, "".concat(prefix, "--tabs--scrollable--light"), light), _classNames)),
        // TODO: remove scrollable from classnames in next major release and uncomment classnames that don't contain scrollable
        tablist: classnames__WEBPACK_IMPORTED_MODULE_10___default()( // `${prefix}--tabs__nav`,
        "".concat(prefix, "--tabs--scrollable__nav")),
        leftOverflowButtonClasses: classnames__WEBPACK_IMPORTED_MODULE_10___default()((_classNames2 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames2, "".concat(prefix, "--tab--overflow-nav-button"), this.state.horizontalOverflow), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames2, "".concat(prefix, "--tab--overflow-nav-button--hidden"), leftOverflowNavButtonHidden), _classNames2)),
        rightOverflowButtonClasses: classnames__WEBPACK_IMPORTED_MODULE_10___default()((_classNames3 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames3, "".concat(prefix, "--tab--overflow-nav-button"), this.state.horizontalOverflow), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(_classNames3, "".concat(prefix, "--tab--overflow-nav-button--hidden"), rightOverflowNavButtonHidden), _classNames3))
      };
      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement((react__WEBPACK_IMPORTED_MODULE_9___default().Fragment), null, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, other, {
        className: classes.tabs
      }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("button", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
        "aria-hidden": "true",
        "aria-label": "Scroll left",
        className: classes.leftOverflowButtonClasses,
        onClick: function onClick(_) {
          return _this2.handleOverflowNavClick(_, {
            direction: -1
          });
        },
        onMouseDown: function onMouseDown(event) {
          return _this2.handleOverflowNavMouseDown(event, {
            direction: -1
          });
        },
        onMouseUp: this.handleOverflowNavMouseUp,
        ref: this.leftOverflowNavButton,
        tabIndex: "-1",
        type: "button"
      }, leftOverflowButtonProps), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_15__.ChevronLeft16, null)), !leftOverflowNavButtonHidden && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", {
        className: "".concat(prefix, "--tabs__overflow-indicator--left")
      }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("ul", {
        role: "tablist",
        tabIndex: -1,
        className: classes.tablist,
        ref: this.tablist,
        onScroll: this._debouncedHandleScroll
      }, tabsWithProps), !rightOverflowNavButtonHidden && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("div", {
        className: "".concat(prefix, "--tabs__overflow-indicator--right")
      }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement("button", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
        "aria-hidden": "true",
        "aria-label": "Scroll right",
        className: classes.rightOverflowButtonClasses,
        onClick: function onClick(_) {
          return _this2.handleOverflowNavClick(_, {
            direction: 1
          });
        },
        onMouseDown: function onMouseDown(event) {
          return _this2.handleOverflowNavMouseDown(event, {
            direction: 1
          });
        },
        onMouseUp: this.handleOverflowNavMouseUp,
        ref: this.rightOverflowNavButton,
        tabIndex: "-1",
        type: "button"
      }, rightOverflowButtonProps), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_9___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_15__.ChevronRight16, null))), tabContentWithProps);
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(_ref6, state) {
      var selected = _ref6.selected;
      var prevSelected = state.prevSelected;
      return prevSelected === selected ? null : {
        selected: selected,
        prevSelected: selected
      };
    }
    /**
     * `scroll` event handler to save tablist clientWidth, scrollWidth, and
     * scrollLeft
     */

  }]);

  return Tabs;
}((react__WEBPACK_IMPORTED_MODULE_9___default().Component));

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(Tabs, "propTypes", {
  /**
   * Pass in a collection of <Tab> children to be rendered depending on the
   * currently selected tab
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().node),

  /**
   * Provide a className that is applied to the root <div> component for the
   * <Tabs>
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().string),

  /**
   * Specify whether the Tab content is hidden
   */
  hidden: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().bool),

  /**
   * Provide the props that describe the left overflow button
   */
  leftOverflowButtonProps: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().object),

  /**
   * Specify whether or not to use the light component variant
   */
  light: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().bool),

  /**
   * Optionally provide an `onClick` handler that is invoked when a <Tab> is
   * clicked
   */
  onClick: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),

  /**
   * Optionally provide an `onKeyDown` handler that is invoked when keyed
   * navigation is triggered
   */
  onKeyDown: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),

  /**
   * Provide an optional handler that is called whenever the selection
   * changes. This method is called with the index of the tab that was
   * selected
   */
  onSelectionChange: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),

  /**
   * Provide the props that describe the right overflow button
   */
  rightOverflowButtonProps: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().object),

  /**
   * Optionally provide a delay (in milliseconds) passed to the lodash
   * debounce of the onScroll handler. This will impact the responsiveness
   * of scroll arrow buttons rendering when scrolling to the first or last tab.
   */
  scrollDebounceWait: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().number),

  /**
   * Choose whether or not to automatically scroll to newly selected tabs
   * on component rerender
   */
  scrollIntoView: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().bool),

  /**
   * Optionally provide an index for the currently selected <Tab>
   */
  selected: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().number),

  /**
   * Choose whether or not to automatically change selection on focus
   */
  selectionMode: prop_types__WEBPACK_IMPORTED_MODULE_16___default().oneOf(['automatic', 'manual']),

  /**
   * Provide a className that is applied to the <TabContent> components
   */
  tabContentClassName: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().string),

  /**
   * Provide the type of Tab
   */
  type: prop_types__WEBPACK_IMPORTED_MODULE_16___default().oneOf(['default', 'container'])
});

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(Tabs, "defaultProps", {
  type: 'default',
  scrollIntoView: true,
  selected: 0,
  selectionMode: 'automatic',
  scrollDebounceWait: 150
});

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(Tabs, "contextType", _internal_usePrefix__WEBPACK_IMPORTED_MODULE_17__.PrefixContext);



/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Tabs/index.js":
/*!******************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Tabs/index.js ***!
  \******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "IconTab": () => (/* reexport safe */ _next_Tabs__WEBPACK_IMPORTED_MODULE_1__.IconTab),
/* harmony export */   "TabList": () => (/* reexport safe */ _next_Tabs__WEBPACK_IMPORTED_MODULE_1__.TabList),
/* harmony export */   "TabPanel": () => (/* reexport safe */ _next_Tabs__WEBPACK_IMPORTED_MODULE_1__.TabPanel),
/* harmony export */   "TabPanels": () => (/* reexport safe */ _next_Tabs__WEBPACK_IMPORTED_MODULE_1__.TabPanels),
/* harmony export */   "TabsSkeleton": () => (/* binding */ TabsSkeleton),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @carbon/feature-flags */ "../../node_modules/@carbon/feature-flags/es/index.js");
/* harmony import */ var _next_Tabs__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./next/Tabs */ "../../node_modules/carbon-components-react/es/components/Tabs/next/Tabs.js");
/* harmony import */ var _Tabs__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./Tabs */ "../../node_modules/carbon-components-react/es/components/Tabs/Tabs.js");
/* harmony import */ var _Tabs_Skeleton__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./Tabs.Skeleton */ "../../node_modules/carbon-components-react/es/components/Tabs/Tabs.Skeleton.js");
/* harmony import */ var _next_Tabs_Skeleton__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./next/Tabs.Skeleton */ "../../node_modules/carbon-components-react/es/components/Tabs/next/Tabs.Skeleton.js");
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */





var Tabs = _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_0__.enabled('enable-v11-release') ? _next_Tabs__WEBPACK_IMPORTED_MODULE_1__.Tabs : _Tabs__WEBPACK_IMPORTED_MODULE_2__["default"];
var TabsSkeleton = _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_0__.enabled('enable-v11-release') ? _next_Tabs_Skeleton__WEBPACK_IMPORTED_MODULE_3__["default"] : _Tabs_Skeleton__WEBPACK_IMPORTED_MODULE_4__["default"];

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Tabs);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Tabs/next/Tabs.Skeleton.js":
/*!*******************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Tabs/next/Tabs.Skeleton.js ***!
  \*******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_6__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");



var _excluded = ["className", "contained"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */





function Tab() {
  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("li", {
    className: "".concat(prefix, "--tabs__nav-item")
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: "".concat(prefix, "--tabs__nav-link")
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("span", null)));
}

function TabsSkeleton(_ref) {
  var className = _ref.className,
      contained = _ref.contained,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();
  var tabClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()(className, "".concat(prefix, "--tabs"), "".concat(prefix, "--skeleton"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--tabs--contained"), contained));
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    className: tabClasses
  }, rest), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("ul", {
    className: "".concat(prefix, "--tabs__nav")
  }, Tab(), Tab(), Tab(), Tab(), Tab()));
}

TabsSkeleton.propTypes = {
  /**
   * Specify an optional className to add.
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().string),

  /**
   * Provide the type of Tab
   */
  contained: (prop_types__WEBPACK_IMPORTED_MODULE_6___default().bool)
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (TabsSkeleton);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Tabs/next/Tabs.js":
/*!**********************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Tabs/next/Tabs.js ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "IconTab": () => (/* binding */ IconTab),
/* harmony export */   "Tab": () => (/* binding */ Tab),
/* harmony export */   "TabList": () => (/* binding */ TabList),
/* harmony export */   "TabPanel": () => (/* binding */ TabPanel),
/* harmony export */   "TabPanels": () => (/* binding */ TabPanels),
/* harmony export */   "Tabs": () => (/* binding */ Tabs)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-5.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var lodash_debounce__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! lodash.debounce */ "../../node_modules/lodash.debounce/index.js");
/* harmony import */ var lodash_debounce__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(lodash_debounce__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_6__);
/* harmony import */ var _Tooltip_next__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ../../Tooltip/next */ "../../node_modules/carbon-components-react/es/components/Tooltip/next/Tooltip.js");
/* harmony import */ var _internal_useControllableState__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../../internal/useControllableState */ "../../node_modules/carbon-components-react/es/internal/useControllableState.js");
/* harmony import */ var _internal_useEffectOnce__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../../../internal/useEffectOnce */ "../../node_modules/carbon-components-react/es/internal/useEffectOnce.js");
/* harmony import */ var _internal_useId__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../../internal/useId */ "../../node_modules/carbon-components-react/es/internal/useId.js");
/* harmony import */ var _internal_useIsomorphicEffect__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../../../internal/useIsomorphicEffect */ "../../node_modules/carbon-components-react/es/internal/useIsomorphicEffect.js");
/* harmony import */ var _internal_useMergedRefs__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ../../../internal/useMergedRefs */ "../../node_modules/carbon-components-react/es/internal/useMergedRefs.js");
/* harmony import */ var _internal_useNoInteractiveChildren__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ../../../internal/useNoInteractiveChildren */ "../../node_modules/carbon-components-react/es/internal/useNoInteractiveChildren.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/match.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/keys.js");
/* harmony import */ var _usePressable__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./usePressable */ "../../node_modules/carbon-components-react/es/components/Tabs/next/usePressable.js");




var _excluded = ["activation", "aria-label", "children", "className", "contained", "iconSize", "leftOverflowButtonProps", "light", "rightOverflowButtonProps", "scrollDebounceWait", "scrollIntoView"],
    _excluded2 = ["as", "children", "className", "disabled", "onClick", "onKeyDown"],
    _excluded3 = ["children", "className", "defaultOpen", "enterDelayMs", "leaveDelayMs", "label"],
    _excluded4 = ["children", "className"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */














 // Used to manage the overall state of the Tabs

var TabsContext = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().createContext(); // Used to keep track of position in a tablist

var TabContext = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().createContext(); // Used to keep track of position in a list of tab panels

var TabPanelContext = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().createContext();

function Tabs(_ref) {
  var children = _ref.children,
      _ref$defaultSelectedI = _ref.defaultSelectedIndex,
      defaultSelectedIndex = _ref$defaultSelectedI === void 0 ? 0 : _ref$defaultSelectedI,
      _onChange = _ref.onChange,
      controlledSelectedIndex = _ref.selectedIndex;
  var baseId = (0,_internal_useId__WEBPACK_IMPORTED_MODULE_7__.useId)('ccs'); // The active index is used to track the element which has focus in our tablist

  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_6__.useState)(defaultSelectedIndex),
      _useState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(_useState, 2),
      activeIndex = _useState2[0],
      setActiveIndex = _useState2[1]; // The selected index is used for the tab/panel pairing which is "visible"


  var _useControllableState = (0,_internal_useControllableState__WEBPACK_IMPORTED_MODULE_8__.useControllableState)({
    value: controlledSelectedIndex,
    defaultValue: defaultSelectedIndex,
    onChange: function onChange(value) {
      if (_onChange) {
        _onChange({
          selectedIndex: value
        });
      }
    }
  }),
      _useControllableState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(_useControllableState, 2),
      selectedIndex = _useControllableState2[0],
      setSelectedIndex = _useControllableState2[1];

  var value = {
    baseId: baseId,
    activeIndex: activeIndex,
    defaultSelectedIndex: defaultSelectedIndex,
    setActiveIndex: setActiveIndex,
    selectedIndex: selectedIndex,
    setSelectedIndex: setSelectedIndex
  };
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().createElement(TabsContext.Provider, {
    value: value
  }, children);
}

Tabs.propTypes = {
  /**
   * Provide child elements to be rendered inside of the `Tabs`.
   * These elements should render either `TabsList` or `TabsPanels`
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node),

  /**
   * Specify which content tab should be initially selected when the component
   * is first rendered
   */
  defaultSelectedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number),

  /**
   * Provide an optional function which is called whenever the state of the
   * `Tabs` changes
   */
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func),

  /**
   * Control which content panel is currently selected. This puts the component
   * in a controlled mode and should be used along with `onChange`
   */
  selectedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number)
};
/**
 * Get the next index for a given keyboard event given a count of the total
 * items and the current index
 * @param {Event} event
 * @param {number} total
 * @param {number} index
 * @returns {number}
 */

function getNextIndex(event, total, index) {
  if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_10__.match)(event, _internal_keyboard__WEBPACK_IMPORTED_MODULE_11__.ArrowRight)) {
    return (index + 1) % total;
  } else if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_10__.match)(event, _internal_keyboard__WEBPACK_IMPORTED_MODULE_11__.ArrowLeft)) {
    return (total + index - 1) % total;
  } else if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_10__.match)(event, _internal_keyboard__WEBPACK_IMPORTED_MODULE_11__.Home)) {
    return 0;
  } else if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_10__.match)(event, _internal_keyboard__WEBPACK_IMPORTED_MODULE_11__.End)) {
    return total - 1;
  }
}

function TabList(_ref2) {
  var _cx;

  var _ref2$activation = _ref2.activation,
      activation = _ref2$activation === void 0 ? 'automatic' : _ref2$activation,
      label = _ref2['aria-label'],
      children = _ref2.children,
      customClassName = _ref2.className,
      _ref2$contained = _ref2.contained,
      contained = _ref2$contained === void 0 ? false : _ref2$contained,
      iconSize = _ref2.iconSize,
      leftOverflowButtonProps = _ref2.leftOverflowButtonProps,
      light = _ref2.light,
      rightOverflowButtonProps = _ref2.rightOverflowButtonProps,
      _ref2$scrollDebounceW = _ref2.scrollDebounceWait,
      scrollDebounceWait = _ref2$scrollDebounceW === void 0 ? 200 : _ref2$scrollDebounceW,
      scrollIntoView = _ref2.scrollIntoView,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref2, _excluded);

  var _React$useContext = react__WEBPACK_IMPORTED_MODULE_6___default().useContext(TabsContext),
      activeIndex = _React$useContext.activeIndex,
      selectedIndex = _React$useContext.selectedIndex,
      setSelectedIndex = _React$useContext.setSelectedIndex,
      setActiveIndex = _React$useContext.setActiveIndex;

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_12__.usePrefix)();
  var ref = (0,react__WEBPACK_IMPORTED_MODULE_6__.useRef)(null);
  var previousButton = (0,react__WEBPACK_IMPORTED_MODULE_6__.useRef)(null);
  var nextButton = (0,react__WEBPACK_IMPORTED_MODULE_6__.useRef)(null);

  var _useState3 = (0,react__WEBPACK_IMPORTED_MODULE_6__.useState)(false),
      _useState4 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(_useState3, 2),
      isScrollable = _useState4[0],
      setIsScrollable = _useState4[1];

  var _useState5 = (0,react__WEBPACK_IMPORTED_MODULE_6__.useState)(false),
      _useState6 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(_useState5, 2),
      scrollLeft = _useState6[0],
      setScrollLeft = _useState6[1];

  var className = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--tabs"), customClassName, (_cx = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--tabs--contained"), contained), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--tabs--light"), light), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--tabs__icon--default"), iconSize === 'default'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx, "".concat(prefix, "--tabs__icon--lg"), iconSize === 'lg'), _cx)); // Previous Button
  // VISIBLE IF:
  //   SCROLLABLE
  //   AND SCROLL_LEFT > 0

  var buttonWidth = 44;
  var isPreviousButtonVisible = ref.current ? isScrollable && scrollLeft > 0 : false; // Next Button
  // VISIBLE IF:
  //   SCROLLABLE
  //   AND SCROLL_LEFT + CLIENT_WIDTH < SCROLL_WIDTH

  var isNextButtonVisible = ref.current ? scrollLeft + buttonWidth + ref.current.clientWidth < ref.current.scrollWidth : false;
  var previousButtonClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--tab--overflow-nav-button"), "".concat(prefix, "--tab--overflow-nav-button--previous"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--tab--overflow-nav-button--hidden"), !isPreviousButtonVisible));
  var nextButtonClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--tab--overflow-nav-button"), "".concat(prefix, "--tab--overflow-nav-button--next"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--tab--overflow-nav-button--hidden"), !isNextButtonVisible));
  var tabs = [];
  var debouncedOnScroll = (0,react__WEBPACK_IMPORTED_MODULE_6__.useCallback)(function () {
    return lodash_debounce__WEBPACK_IMPORTED_MODULE_5___default()(function (event) {
      setScrollLeft(event.target.scrollLeft);
    }, scrollDebounceWait);
  }, [scrollDebounceWait]);

  function onKeyDown(event) {
    if ((0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_10__.matches)(event, [_internal_keyboard__WEBPACK_IMPORTED_MODULE_11__.ArrowRight, _internal_keyboard__WEBPACK_IMPORTED_MODULE_11__.ArrowLeft, _internal_keyboard__WEBPACK_IMPORTED_MODULE_11__.Home, _internal_keyboard__WEBPACK_IMPORTED_MODULE_11__.End])) {
      event.preventDefault();
      var activeTabs = tabs.filter(function (tab) {
        return !tab.current.disabled;
      });
      var currentIndex = activeTabs.indexOf(tabs[activation === 'automatic' ? selectedIndex : activeIndex]);
      var nextIndex = tabs.indexOf(activeTabs[getNextIndex(event, activeTabs.length, currentIndex)]);

      if (activation === 'automatic') {
        setSelectedIndex(nextIndex);
      } else if (activation === 'manual') {
        setActiveIndex(nextIndex);
      }

      tabs[nextIndex].current.focus();
    }
  }

  (0,_internal_useEffectOnce__WEBPACK_IMPORTED_MODULE_13__.useEffectOnce)(function () {
    var tab = tabs[selectedIndex];

    if (scrollIntoView && tab) {
      tab.current.scrollIntoView({
        block: 'nearest',
        inline: 'nearest'
      });
    }
  });
  (0,_internal_useEffectOnce__WEBPACK_IMPORTED_MODULE_13__.useEffectOnce)(function () {
    if (tabs[selectedIndex].current.disabled) {
      var activeTabs = tabs.filter(function (tab) {
        return !tab.current.disabled;
      });

      if (activeTabs.length > 0) {
        var tab = activeTabs[0];
        setSelectedIndex(tabs.indexOf(tab));
      }
    }
  });
  (0,_internal_useIsomorphicEffect__WEBPACK_IMPORTED_MODULE_14__["default"])(function () {
    if (ref.current) {
      setIsScrollable(ref.current.scrollWidth > ref.current.clientWidth);
    }

    function handler() {
      if (ref.current) {
        setIsScrollable(ref.current.scrollWidth > ref.current.clientWidth);
      }
    }

    var debouncedHandler = lodash_debounce__WEBPACK_IMPORTED_MODULE_5___default()(handler, 200);
    window.addEventListener('resize', debouncedHandler);
    return function () {
      debouncedHandler.cancel();
      window.removeEventListener('resize', debouncedHandler);
    };
  }, []); // updates scroll location for all scroll behavior.

  (0,_internal_useIsomorphicEffect__WEBPACK_IMPORTED_MODULE_14__["default"])(function () {
    ref.current.scrollLeft = scrollLeft;
  }, [scrollLeft]);
  (0,_internal_useIsomorphicEffect__WEBPACK_IMPORTED_MODULE_14__["default"])(function () {
    var tab = activation === 'manual' ? tabs[activeIndex] : tabs[selectedIndex];

    if (tab) {
      // The width of the "scroll buttons"
      // The start and end position of the selected tab
      var _tab$current$getBound = tab.current.getBoundingClientRect(),
          tabWidth = _tab$current$getBound.width;

      var start = tab.current.offsetLeft;
      var end = tab.current.offsetLeft + tabWidth; // The start and end of the visible area for the tabs

      var visibleStart = ref.current.scrollLeft + buttonWidth;
      var visibleEnd = ref.current.scrollLeft + ref.current.clientWidth - buttonWidth; // The beginning of the tab is clipped and not visible

      if (start < visibleStart) {
        setScrollLeft(start - buttonWidth);
      } // The end of teh tab is clipped and not visible


      if (end > visibleEnd) {
        setScrollLeft(end + buttonWidth - ref.current.clientWidth);
      }
    }
  }, [activation, activeIndex, selectedIndex]);
  (0,_usePressable__WEBPACK_IMPORTED_MODULE_15__.usePressable)(previousButton, {
    onPress: function onPress(_ref3) {
      var longPress = _ref3.longPress;

      if (!longPress) {
        setScrollLeft(Math.max(scrollLeft - ref.current.scrollWidth / tabs.length * 1.5, 0));
      }
    },
    onLongPress: function onLongPress() {
      return createLongPressBehavior(ref, 'backward', setScrollLeft);
    }
  });
  (0,_usePressable__WEBPACK_IMPORTED_MODULE_15__.usePressable)(nextButton, {
    onPress: function onPress(_ref4) {
      var longPress = _ref4.longPress;

      if (!longPress) {
        setScrollLeft(Math.min(scrollLeft + ref.current.scrollWidth / tabs.length * 1.5, ref.current.scrollWidth - ref.current.clientWidth));
      }
    },
    onLongPress: function onLongPress() {
      return createLongPressBehavior(ref, 'forward', setScrollLeft);
    }
  });
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().createElement("div", {
    className: className
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().createElement("button", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    "aria-hidden": "true",
    "aria-label": "Scroll left",
    ref: previousButton,
    className: previousButtonClasses,
    type: "button"
  }, leftOverflowButtonProps), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_16__.ChevronLeft16, null)), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, rest, {
    "aria-label": label,
    ref: ref,
    role: "tablist",
    className: "".concat(prefix, "--tab--list"),
    onScroll: debouncedOnScroll,
    onKeyDown: onKeyDown
  }), react__WEBPACK_IMPORTED_MODULE_6___default().Children.map(children, function (child, index) {
    var ref = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().createRef();
    tabs.push(ref);
    return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().createElement(TabContext.Provider, {
      value: index
    }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().cloneElement(child, {
      ref: ref
    }));
  })), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().createElement("button", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    "aria-hidden": "true",
    "aria-label": "Scroll right",
    ref: nextButton,
    className: nextButtonClasses,
    type: "button"
  }, rightOverflowButtonProps), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_16__.ChevronRight16, null)));
}

TabList.propTypes = {
  /**
   * Specify whether the content tab should be activated automatically or
   * manually
   */
  activation: prop_types__WEBPACK_IMPORTED_MODULE_9___default().oneOf(['automatic', 'manual']),

  /**
   * Provide an accessible label to be read when a user interacts with this
   * component
   */
  'aria-label': (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string.isRequired),

  /**
   * Provide child elements to be rendered inside of `ContentTabs`.
   * These elements should render a `ContentTab`
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node),

  /**
   * Specify an optional className to be added to the container node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),

  /**
   * Specify whether component is contained type
   */
  contained: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * If using `IconTab`, specify the size of the icon being used.
   */
  iconSize: prop_types__WEBPACK_IMPORTED_MODULE_9___default().oneOf(['default', 'lg']),

  /**
   * Provide the props that describe the left overflow button
   */
  leftOverflowButtonProps: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().object),

  /**
   * Specify whether or not to use the light component variant
   */
  light: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Provide the props that describe the right overflow button
   */
  rightOverflowButtonProps: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().object),

  /**
   * Optionally provide a delay (in milliseconds) passed to the lodash
   * debounce of the onScroll handler. This will impact the responsiveness
   * of scroll arrow buttons rendering when scrolling to the first or last tab.
   */
  scrollDebounceWait: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number),

  /**
   * Choose whether or not to automatically scroll to newly selected tabs
   * on component rerender
   */
  scrollIntoView: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool)
};
/**
 * Helper function to setup the behavior when a button is "long pressed". This
 * function will take a ref to the tablist, a direction, and a setter for
 * scrollLeft and will update the scroll position within a
 * requestAnimationFrame.
 *
 * It returns a cleanup function to be run when the long press is
 * deactivated
 *
 * @param {RefObject} ref
 * @param {'forward' | 'backward'} direction
 * @param {Function} setScrollLeft
 * @returns {Function}
 */

function createLongPressBehavior(ref, direction, setScrollLeft) {
  // We manually override the scroll behavior to be "auto". If it is set as
  // smooth, this animation does not update correctly
  var defaultScrollBehavior = ref.current.style['scroll-behavior'];
  ref.current.style['scroll-behavior'] = 'auto';
  var scrollDelta = direction === 'forward' ? 5 : -5;
  var frameId = null;

  function tick() {
    ref.current.scrollLeft = ref.current.scrollLeft + scrollDelta;
    frameId = requestAnimationFrame(tick);
  }

  frameId = requestAnimationFrame(tick);
  return function () {
    // Restore the previous scroll behavior
    ref.current.style['scroll-behavior'] = defaultScrollBehavior; // Make sure that our `scrollLeft` value is in sync with the existing
    // `ref` after our requestAnimationFrame loop above

    setScrollLeft(ref.current.scrollLeft);

    if (frameId) {
      cancelAnimationFrame(frameId);
    }
  };
}

var Tab = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().forwardRef(function Tab(_ref5, ref) {
  var _cx4;

  var _ref5$as = _ref5.as,
      BaseComponent = _ref5$as === void 0 ? 'button' : _ref5$as,
      children = _ref5.children,
      customClassName = _ref5.className,
      disabled = _ref5.disabled,
      _onClick = _ref5.onClick,
      onKeyDown = _ref5.onKeyDown,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref5, _excluded2);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_12__.usePrefix)();

  var _React$useContext2 = react__WEBPACK_IMPORTED_MODULE_6___default().useContext(TabsContext),
      selectedIndex = _React$useContext2.selectedIndex,
      setSelectedIndex = _React$useContext2.setSelectedIndex,
      baseId = _React$useContext2.baseId;

  var index = react__WEBPACK_IMPORTED_MODULE_6___default().useContext(TabContext);
  var id = "".concat(baseId, "-tab-").concat(index);
  var panelId = "".concat(baseId, "-tabpanel-").concat(index);
  var className = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--tabs__nav-item"), "".concat(prefix, "--tabs__nav-link"), customClassName, (_cx4 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx4, "".concat(prefix, "--tabs__nav-item--selected"), selectedIndex === index), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_cx4, "".concat(prefix, "--tabs__nav-item--disabled"), disabled), _cx4));
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().createElement(BaseComponent, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, rest, {
    "aria-controls": panelId,
    "aria-disabled": disabled,
    "aria-selected": selectedIndex === index,
    ref: ref,
    id: id,
    role: "tab",
    className: className,
    disabled: disabled,
    onClick: function onClick(evt) {
      if (disabled) {
        return;
      }

      setSelectedIndex(index);

      if (_onClick) {
        _onClick(evt);
      }
    },
    onKeyDown: onKeyDown,
    tabIndex: selectedIndex === index ? '0' : '-1',
    type: "button"
  }), children);
});
Tab.propTypes = {
  /**
   * Provide a custom element to render instead of the default button
   */
  as: prop_types__WEBPACK_IMPORTED_MODULE_9___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_9___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_9___default().elementType)]),

  /**
   * Provide child elements to be rendered inside of `Tab`.
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node),

  /**
   * Specify an optional className to be added to your Tab
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),

  /**
   * Whether your Tab is disabled.
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Provide a handler that is invoked when a user clicks on the control
   */
  onClick: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func),

  /**
   * Provide a handler that is invoked on the key down event for the control
   */
  onKeyDown: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func),

  /*
   * An optional parameter to allow overriding the anchor rendering.
   * Useful for using Tab along with react-router or other client
   * side router libraries.
   **/
  renderButton: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func)
};
var IconTab = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().forwardRef(function IconTab(_ref6, ref) {
  var children = _ref6.children,
      customClassName = _ref6.className,
      _ref6$defaultOpen = _ref6.defaultOpen,
      defaultOpen = _ref6$defaultOpen === void 0 ? false : _ref6$defaultOpen,
      enterDelayMs = _ref6.enterDelayMs,
      leaveDelayMs = _ref6.leaveDelayMs,
      label = _ref6.label,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref6, _excluded3);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_12__.usePrefix)();
  var classNames = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--tabs__nav-item--icon"), customClassName);
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().createElement(_Tooltip_next__WEBPACK_IMPORTED_MODULE_17__.Tooltip, {
    align: "bottom",
    defaultOpen: defaultOpen,
    className: "".concat(prefix, "--icon-tooltip"),
    enterDelayMs: enterDelayMs,
    label: label,
    leaveDelayMs: leaveDelayMs
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().createElement(Tab, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    className: classNames,
    ref: ref
  }, rest), children));
});
IconTab.propTypes = {
  /**
   * Provide an icon to be rendered inside of `IconTab` as the visual label for Tab.
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node),

  /**
   * Specify an optional className to be added to your Tab
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),

  /**
   * Specify whether the tooltip for the icon should be open when it first renders
   */
  defaultOpen: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Specify the duration in milliseconds to delay before displaying the tooltip for the icon.
   */
  enterDelayMs: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number),

  /**
   * Provide the label to be rendered inside of the Tooltip. The label will use
   * `aria-labelledby` and will fully describe the child node that is provided.
   * This means that if you have text in the child node it will not be
   * announced to the screen reader.
   */
  label: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node.isRequired),

  /**
   * Specify the duration in milliseconds to delay before hiding the tooltip
   */
  leaveDelayMs: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number)
};
var TabPanel = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().forwardRef(function TabPanel(_ref7, forwardRef) {
  var children = _ref7.children,
      customClassName = _ref7.className,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref7, _excluded4);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_12__.usePrefix)();
  var panel = (0,react__WEBPACK_IMPORTED_MODULE_6__.useRef)(null);
  var ref = (0,_internal_useMergedRefs__WEBPACK_IMPORTED_MODULE_18__.useMergedRefs)([forwardRef, panel]);

  var _useState7 = (0,react__WEBPACK_IMPORTED_MODULE_6__.useState)('0'),
      _useState8 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(_useState7, 2),
      tabIndex = _useState8[0],
      setTabIndex = _useState8[1];

  var _React$useContext3 = react__WEBPACK_IMPORTED_MODULE_6___default().useContext(TabsContext),
      selectedIndex = _React$useContext3.selectedIndex,
      baseId = _React$useContext3.baseId;

  var index = react__WEBPACK_IMPORTED_MODULE_6___default().useContext(TabPanelContext);
  var id = "".concat(baseId, "-tabpanel-").concat(index);
  var tabId = "".concat(baseId, "-tab-").concat(index);
  var className = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--tab-content"), customClassName); // tabindex should only be 0 if no interactive content in children

  (0,react__WEBPACK_IMPORTED_MODULE_6__.useEffect)(function () {
    var interactiveContent = (0,_internal_useNoInteractiveChildren__WEBPACK_IMPORTED_MODULE_19__.getInteractiveContent)(panel.current);

    if (interactiveContent) {
      setTabIndex('-1');
    }
  }, []);
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, rest, {
    "aria-labelledby": tabId,
    id: id,
    className: className,
    ref: ref,
    role: "tabpanel",
    tabIndex: tabIndex,
    hidden: selectedIndex !== index
  }), children);
});
TabPanel.propTypes = {
  /**
   * Provide child elements to be rendered inside of `TabPanel`.
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node),

  /**
   * Specify an optional className to be added to TabPanel.
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string)
};

function TabPanels(_ref8) {
  var children = _ref8.children;
  return react__WEBPACK_IMPORTED_MODULE_6___default().Children.map(children, function (child, index) {
    return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_6___default().createElement(TabPanelContext.Provider, {
      value: index
    }, child);
  });
}

TabPanels.propTypes = {
  /**
   * Provide child elements to be rendered inside of `TabPanels`.
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node)
};


/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Tabs/next/usePressable.js":
/*!******************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Tabs/next/usePressable.js ***!
  \******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "usePressable": () => (/* binding */ usePressable)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_1__);


/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

function usePressable(ref) {
  var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      onPress = _ref.onPress,
      onPressIn = _ref.onPressIn,
      onPressOut = _ref.onPressOut,
      onLongPress = _ref.onLongPress,
      _ref$delayLongPressMs = _ref.delayLongPressMs,
      delayLongPressMs = _ref$delayLongPressMs === void 0 ? 500 : _ref$delayLongPressMs;

  var savedOnPress = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(onPress);
  var savedOnPressIn = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(onPressIn);
  var savedOnPressOut = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(onPressOut);
  var savedOnLongPress = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(onLongPress);

  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(false),
      _useState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__["default"])(_useState, 2),
      pendingLongPress = _useState2[0],
      setPendingLongPress = _useState2[1];

  var _useState3 = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(false),
      _useState4 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__["default"])(_useState3, 2),
      longPress = _useState4[0],
      setLongPress = _useState4[1];

  var state = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)({
    longPress: false
  });
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(function () {
    savedOnPress.current = onPress;
  }, [onPress]);
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(function () {
    savedOnPressIn.current = onPressIn;
  }, [onPressIn]);
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(function () {
    savedOnPressOut.current = onPressOut;
  }, [onPressOut]);
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(function () {
    savedOnLongPress.current = onLongPress;
  }, [onLongPress]);
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(function () {
    var element = ref.current; // Fired when a pointer becomes active buttons state.

    function onPointerDown() {
      var _savedOnPressIn$curre;

      setPendingLongPress(true);
      (_savedOnPressIn$curre = savedOnPressIn.current) === null || _savedOnPressIn$curre === void 0 ? void 0 : _savedOnPressIn$curre.call(savedOnPressIn);
    } // Fired when a pointer is no longer active buttons state.


    function onPointerUp() {
      var _savedOnPressOut$curr;

      setPendingLongPress(false);
      setLongPress(false);
      (_savedOnPressOut$curr = savedOnPressOut.current) === null || _savedOnPressOut$curr === void 0 ? void 0 : _savedOnPressOut$curr.call(savedOnPressOut, state.current);
    } // A browser fires this event if it concludes the pointer
    // will no longer be able to generate events (for example
    // the related device is deactivated).


    function onPointerCancel() {
      var _savedOnPressOut$curr2;

      setPendingLongPress(false);
      setLongPress(false);
      (_savedOnPressOut$curr2 = savedOnPressOut.current) === null || _savedOnPressOut$curr2 === void 0 ? void 0 : _savedOnPressOut$curr2.call(savedOnPressOut);
      state.current.longPress = false;
    } // Fired when a pointer is moved out of the hit test
    // boundaries of an element. For pen devices, this event
    // is fired when the stylus leaves the hover range
    // detectable by the digitizer.


    function onPointerLeave() {
      var _savedOnPressOut$curr3;

      setPendingLongPress(false);
      setLongPress(false);
      (_savedOnPressOut$curr3 = savedOnPressOut.current) === null || _savedOnPressOut$curr3 === void 0 ? void 0 : _savedOnPressOut$curr3.call(savedOnPressOut);
      state.current.longPress = false;
    }

    function onClick() {
      var _savedOnPress$current;

      setLongPress(false);
      setPendingLongPress(false);
      (_savedOnPress$current = savedOnPress.current) === null || _savedOnPress$current === void 0 ? void 0 : _savedOnPress$current.call(savedOnPress, state.current);
      state.current.longPress = false;
    }

    function onTouchStart(event) {
      // We prevent the default event on touchstart so that text selection is
      // disabled on iOS  Safari when interacting with a "pressable" element
      event.preventDefault();
    }

    element.addEventListener('touchstart', onTouchStart);
    element.addEventListener('pointerdown', onPointerDown);
    element.addEventListener('pointerup', onPointerUp);
    element.addEventListener('pointercancel', onPointerCancel);
    element.addEventListener('pointerleave', onPointerLeave);
    element.addEventListener('click', onClick);
    return function () {
      element.removeEventListener('touchstart', onTouchStart);
      element.removeEventListener('pointerdown', onPointerDown);
      element.removeEventListener('pointerup', onPointerUp);
      element.removeEventListener('pointercancel', onPointerCancel);
      element.removeEventListener('pointerleave', onPointerLeave);
      element.removeEventListener('click', onClick);
    };
  }, [ref]);
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(function () {
    if (pendingLongPress) {
      var timeoutId = setTimeout(function () {
        setPendingLongPress(false);
        setLongPress(true);
      }, delayLongPressMs);
      return function () {
        clearTimeout(timeoutId);
      };
    }
  }, [pendingLongPress, delayLongPressMs]);
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(function () {
    if (longPress) {
      var _savedOnLongPress$cur;

      state.current.longPress = true;
      return (_savedOnLongPress$cur = savedOnLongPress.current) === null || _savedOnLongPress$cur === void 0 ? void 0 : _savedOnLongPress$cur.call(savedOnLongPress);
    }
  }, [longPress]);
}

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Text/Text.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Text/Text.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Text": () => (/* binding */ Text)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var _TextDirectionContext__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./TextDirectionContext */ "../../node_modules/carbon-components-react/es/components/Text/TextDirectionContext.js");



var _excluded = ["as", "children", "dir"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */




function Text(_ref) {
  var _ref$as = _ref.as,
      BaseComponent = _ref$as === void 0 ? 'span' : _ref$as,
      children = _ref.children,
      _ref$dir = _ref.dir,
      dir = _ref$dir === void 0 ? 'auto' : _ref$dir,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var context = (0,react__WEBPACK_IMPORTED_MODULE_3__.useContext)(_TextDirectionContext__WEBPACK_IMPORTED_MODULE_4__.TextDirectionContext);
  var textProps = {};

  var value = _objectSpread({}, context);

  if (!context) {
    textProps.dir = dir;
    value.direction = dir;
  } else {
    var parentDirection = context.direction,
        getTextDirection = context.getTextDirection;

    if (getTextDirection && getTextDirection.current) {
      var text = getTextFromChildren(children);
      var override = getTextDirection.current(text);

      if (parentDirection !== override) {
        textProps.dir = override;
        value.direction = override;
      } else if (parentDirection === 'auto') {
        textProps.dir = override;
      }
    } else if (parentDirection !== dir) {
      textProps.dir = dir;
      value.direction = dir;
    } else if (parentDirection === 'auto') {
      textProps.dir = dir;
    }
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_TextDirectionContext__WEBPACK_IMPORTED_MODULE_4__.TextDirectionContext.Provider, {
    value: value
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(BaseComponent, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, rest, textProps), children));
}

Text.propTypes = {
  /**
   * Provide a custom element type used to render the outermost node
   */
  as: prop_types__WEBPACK_IMPORTED_MODULE_5___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_5___default().func), (prop_types__WEBPACK_IMPORTED_MODULE_5___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_5___default().elementType)]),

  /**
   * Provide child elements or text to be rendered inside of this component
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().node.isRequired),

  /**
   * Specify the text direction to be used for this component and any of its
   * children
   */
  dir: prop_types__WEBPACK_IMPORTED_MODULE_5___default().oneOf(['ltr', 'rtl', 'auto'])
};

function getTextFromChildren(children) {
  if (typeof children === 'string') {
    return children;
  }

  var text = react__WEBPACK_IMPORTED_MODULE_3___default().Children.map(children, function (child) {
    if (typeof child === 'string') {
      return child;
    }

    return null;
  }).filter(function (text) {
    return text !== null;
  });

  if (text.length === 1) {
    return text[0];
  }

  return text;
}



/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Text/TextDirectionContext.js":
/*!*********************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Text/TextDirectionContext.js ***!
  \*********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "TextDirectionContext": () => (/* binding */ TextDirectionContext)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

var TextDirectionContext = /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_0__.createContext)(null);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/TextArea/TextArea.js":
/*!*************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/TextArea/TextArea.js ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-29.js");
/* harmony import */ var _FeatureFlags__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../FeatureFlags */ "../../node_modules/carbon-components-react/es/components/FeatureFlags/index.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");




var _excluded = ["className", "id", "labelText", "hideLabel", "onChange", "onClick", "invalid", "invalidText", "helperText", "light", "placeholder", "enableCounter", "maxCount"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */






var TextArea = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().forwardRef(function TextArea(_ref, ref) {
  var _classNames, _classNames4;

  var className = _ref.className,
      id = _ref.id,
      labelText = _ref.labelText,
      hideLabel = _ref.hideLabel,
      _onChange = _ref.onChange,
      _onClick = _ref.onClick,
      invalid = _ref.invalid,
      invalidText = _ref.invalidText,
      helperText = _ref.helperText,
      light = _ref.light,
      placeholder = _ref.placeholder,
      enableCounter = _ref.enableCounter,
      maxCount = _ref.maxCount,
      other = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_3__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_6__.usePrefix)();
  var enabled = (0,_FeatureFlags__WEBPACK_IMPORTED_MODULE_7__.useFeatureFlag)('enable-v11-release');
  var defaultValue = other.defaultValue,
      value = other.value,
      disabled = other.disabled;

  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_4__.useState)((defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.length) || (value === null || value === void 0 ? void 0 : value.length) || 0),
      _useState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState, 2),
      textCount = _useState2[0],
      setTextCount = _useState2[1];

  var textareaProps = {
    id: id,
    onChange: function onChange(evt) {
      if (!other.disabled) {
        var _evt$target$value;

        setTextCount((_evt$target$value = evt.target.value) === null || _evt$target$value === void 0 ? void 0 : _evt$target$value.length);

        _onChange(evt);
      }
    },
    onClick: function onClick(evt) {
      if (!other.disabled) {
        _onClick(evt);
      }
    },
    ref: ref
  };

  if (enableCounter) {
    textareaProps.maxLength = maxCount;
  }

  var labelClasses = classnames__WEBPACK_IMPORTED_MODULE_5___default()("".concat(prefix, "--label"), (_classNames = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--visually-hidden"), hideLabel), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--label--disabled"), disabled), _classNames));
  var label = labelText ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("label", {
    htmlFor: id,
    className: labelClasses
  }, labelText) : null;
  var counterClasses = classnames__WEBPACK_IMPORTED_MODULE_5___default()("".concat(prefix, "--label"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--label--disabled"), disabled));
  var counter = enableCounter && maxCount ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", {
    className: counterClasses
  }, "".concat(textCount, "/").concat(maxCount)) : null;
  var helperTextClasses = classnames__WEBPACK_IMPORTED_MODULE_5___default()("".concat(prefix, "--form__helper-text"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--form__helper-text--disabled"), other.disabled));
  var helper = helperText ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", {
    className: helperTextClasses
  }, helperText) : null;
  var errorId = id + '-error-msg';
  var error = invalid ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", {
    role: "alert",
    className: "".concat(prefix, "--form-requirement"),
    id: errorId
  }, invalidText) : null;
  var textareaClasses = classnames__WEBPACK_IMPORTED_MODULE_5___default()("".concat(prefix, "--text-area"), [enabled ? null : className], (_classNames4 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames4, "".concat(prefix, "--text-area--light"), light), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames4, "".concat(prefix, "--text-area--invalid"), invalid), _classNames4));
  var input = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("textarea", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, other, textareaProps, {
    placeholder: placeholder || null,
    className: textareaClasses,
    "aria-invalid": invalid || null,
    "aria-describedby": invalid ? errorId : null,
    disabled: other.disabled
  }));
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", {
    className: enabled ? classnames__WEBPACK_IMPORTED_MODULE_5___default()("".concat(prefix, "--form-item"), className) : "".concat(prefix, "--form-item")
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", {
    className: "".concat(prefix, "--text-area__label-wrapper")
  }, label, counter), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", {
    className: "".concat(prefix, "--text-area__wrapper"),
    "data-invalid": invalid || null
  }, invalid && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__.WarningFilled16, {
    className: "".concat(prefix, "--text-area__invalid-icon")
  }), input), invalid ? error : helper);
});
TextArea.displayName = 'TextArea';
TextArea.propTypes = {
  /**
   * Provide a custom className that is applied directly to the underlying
   * `<textarea>` node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),

  /**
   * Specify the `cols` attribute for the underlying `<textarea>` node
   */
  cols: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number),

  /**
   * Optionally provide the default value of the `<textarea>`
   */
  defaultValue: prop_types__WEBPACK_IMPORTED_MODULE_9___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_9___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number)]),

  /**
   * Specify whether the control is disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Specify whether to display the character counter
   */
  enableCounter: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Provide text that is used alongside the control label for additional help
   */
  helperText: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node),

  /**
   * Specify whether you want the underlying label to be visually hidden
   */
  hideLabel: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Provide a unique identifier for the control
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),

  /**
   * Specify whether the control is currently invalid
   */
  invalid: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Provide the text that is displayed when the control is in an invalid state
   */
  invalidText: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node),

  /**
   * Provide the text that will be read by a screen reader when visiting this
   * control
   */
  labelText: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node.isRequired),

  /**
   * `true` to use the light version. For use on $ui-01 backgrounds only.
   * Don't use this to make tile background color same as container background color.
   */
  light: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Max character count allowed for the textarea. This is needed in order for enableCounter to display
   */
  maxCount: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number),

  /**
   * Optionally provide an `onChange` handler that is called whenever `<textarea>`
   * is updated
   */
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func),

  /**
   * Optionally provide an `onClick` handler that is called whenever the
   * `<textarea>` is clicked
   */
  onClick: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func),

  /**
   * Specify the placeholder attribute for the `<textarea>`
   */
  placeholder: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),

  /**
   * Specify the rows attribute for the `<textarea>`
   */
  rows: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number),

  /**
   * Provide the current value of the `<textarea>`
   */
  value: prop_types__WEBPACK_IMPORTED_MODULE_9___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_9___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number)])
};
TextArea.defaultProps = {
  disabled: false,
  onChange: function onChange() {},
  onClick: function onClick() {},
  placeholder: '',
  rows: 4,
  cols: 50,
  invalid: false,
  invalidText: '',
  helperText: '',
  light: false,
  enableCounter: false,
  maxCount: undefined
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (TextArea);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/TextInput/ControlledPasswordInput.js":
/*!*****************************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/TextInput/ControlledPasswordInput.js ***!
  \*****************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-29.js");
/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./util */ "../../node_modules/carbon-components-react/es/components/TextInput/util.js");
/* harmony import */ var _internal_warning__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../internal/warning */ "../../node_modules/carbon-components-react/es/internal/warning.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");



var _excluded = ["labelText", "className", "id", "placeholder", "onChange", "onClick", "hideLabel", "invalid", "invalidText", "helperText", "light", "type", "togglePasswordVisibility", "tooltipPosition", "tooltipAlignment", "hidePasswordLabel", "showPasswordLabel", "size"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }








var didWarnAboutDeprecation = false;
var ControlledPasswordInput = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().forwardRef(function ControlledPasswordInput(_ref, ref) {
  var _classNames, _classNames2, _classNames4;

  var labelText = _ref.labelText,
      className = _ref.className,
      id = _ref.id,
      placeholder = _ref.placeholder,
      _onChange = _ref.onChange,
      _onClick = _ref.onClick,
      hideLabel = _ref.hideLabel,
      invalid = _ref.invalid,
      invalidText = _ref.invalidText,
      helperText = _ref.helperText,
      light = _ref.light,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'password' : _ref$type,
      togglePasswordVisibility = _ref.togglePasswordVisibility,
      _ref$tooltipPosition = _ref.tooltipPosition,
      tooltipPosition = _ref$tooltipPosition === void 0 ? 'bottom' : _ref$tooltipPosition,
      _ref$tooltipAlignment = _ref.tooltipAlignment,
      tooltipAlignment = _ref$tooltipAlignment === void 0 ? 'center' : _ref$tooltipAlignment,
      _ref$hidePasswordLabe = _ref.hidePasswordLabel,
      hidePasswordLabel = _ref$hidePasswordLabe === void 0 ? 'Hide password' : _ref$hidePasswordLabe,
      _ref$showPasswordLabe = _ref.showPasswordLabel,
      showPasswordLabel = _ref$showPasswordLabe === void 0 ? 'Show password' : _ref$showPasswordLabe,
      size = _ref.size,
      other = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_5__.usePrefix)();

  if (true) {
     true ? (0,_internal_warning__WEBPACK_IMPORTED_MODULE_6__.warning)(didWarnAboutDeprecation, '`<TextInput.ControlledPasswordInput>` has been deprecated in favor of `<TextInput.PasswordInput />` and will be removed in the next major release of `carbon-components-react`') : 0;
    didWarnAboutDeprecation = true;
  }

  var errorId = id + '-error-msg';
  var textInputClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--text-input"), "".concat(prefix, "--password-input"), className, (_classNames = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--text-input--light"), light), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--text-input--invalid"), invalid), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--text-input--").concat(size), size), _classNames));

  var sharedTextInputProps = _objectSpread({
    id: id,
    onChange: function onChange(evt) {
      if (!other.disabled) {
        _onChange(evt);
      }
    },
    onClick: function onClick(evt) {
      if (!other.disabled) {
        _onClick(evt);
      }
    },
    placeholder: placeholder,
    type: type,
    ref: ref,
    className: textInputClasses
  }, other);

  var labelClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--label"), (_classNames2 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames2, "".concat(prefix, "--visually-hidden"), hideLabel), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames2, "".concat(prefix, "--label--disabled"), other.disabled), _classNames2));
  var helperTextClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--form__helper-text"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--form__helper-text--disabled"), other.disabled));
  var label = labelText ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("label", {
    htmlFor: id,
    className: labelClasses
  }, labelText) : null;
  var error = invalid ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: "".concat(prefix, "--form-requirement"),
    id: errorId
  }, invalidText) : null;
  var passwordIsVisible = type === 'text';
  var passwordVisibilityIcon = passwordIsVisible ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_7__.ViewOff16, {
    className: "".concat(prefix, "--icon-visibility-off")
  }) : /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_7__.View16, {
    className: "".concat(prefix, "--icon-visibility-on")
  });
  var passwordVisibilityToggleClasses = classnames__WEBPACK_IMPORTED_MODULE_4___default()("".concat(prefix, "--text-input--password__visibility__toggle"), "".concat(prefix, "--btn"), "".concat(prefix, "--btn--icon-only"), "".concat(prefix, "--tooltip__trigger"), "".concat(prefix, "--tooltip--a11y"), (_classNames4 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames4, "".concat(prefix, "--tooltip--").concat(tooltipPosition), tooltipPosition), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames4, "".concat(prefix, "--tooltip--align-").concat(tooltipAlignment), tooltipAlignment), _classNames4));
  var input = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement((react__WEBPACK_IMPORTED_MODULE_3___default().Fragment), null, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("input", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, (0,_util__WEBPACK_IMPORTED_MODULE_8__.textInputProps)({
    invalid: invalid,
    sharedTextInputProps: sharedTextInputProps,
    invalidId: errorId
  }), {
    "data-toggle-password-visibility": type === 'password'
  })), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("button", {
    type: "button",
    className: passwordVisibilityToggleClasses,
    onClick: togglePasswordVisibility
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("span", {
    className: "".concat(prefix, "--assistive-text")
  }, passwordIsVisible ? hidePasswordLabel : showPasswordLabel), passwordVisibilityIcon));
  var helper = helperText ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: helperTextClasses
  }, helperText) : null;
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: "".concat(prefix, "--form-item ").concat(prefix, "--text-input-wrapper ").concat(prefix, "--password-input-wrapper")
  }, label, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement("div", {
    className: "".concat(prefix, "--text-input__field-wrapper"),
    "data-invalid": invalid || null
  }, invalid && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_3___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_7__.WarningFilled16, {
    className: "".concat(prefix, "--text-input__invalid-icon")
  }), input), error ? error : helper);
});
ControlledPasswordInput.displayName = 'ControlledPasswordInput';
ControlledPasswordInput.propTypes = {
  /**
   * Provide a custom className that is applied directly to the underlying
   * `<input>` node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),

  /**
   * Optionally provide the default value of the `<input>`
   */
  defaultValue: prop_types__WEBPACK_IMPORTED_MODULE_9___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_9___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number)]),

  /**
   * Specify whether the control is disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Provide text that is used alongside the control label for additional help
   */
  helperText: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node),

  /**
   * Specify whether or not the underlying label is visually hidden
   */
  hideLabel: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * "Hide password" tooltip text on password visibility toggle
   */
  hidePasswordLabel: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),

  /**
   * Provide a unique identifier for the input field
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string.isRequired),

  /**
   * Specify whether the control is currently invalid
   */
  invalid: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Provide the text that is displayed when the control is in an invalid state
   */
  invalidText: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node),

  /**
   * Provide the text that will be read by a screen reader when visiting this
   * control
   */
  labelText: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().node.isRequired),

  /**
   * `true` to use the light version. For use on $ui-01 backgrounds only.
   * Don't use this to make tile background color same as container background color.
   */
  light: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),

  /**
   * Optionally provide an `onChange` handler that is called whenever `<input>`
   * is updated
   */
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func),

  /**
   * Optionally provide an `onClick` handler that is called whenever the
   * `<input>` is clicked
   */
  onClick: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func),

  /**
   * Specify the placeholder attribute for the `<input>`
   */
  placeholder: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),

  /**
   * "Show password" tooltip text on password visibility toggle
   */
  showPasswordLabel: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),

  /**
   * Specify the size of the Text Input. Currently supports either `small` or `large` as an option. If omitted, defaults to standard size
   */
  size: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),

  /**
   * Specify the alignment of the tooltip to the icon-only button.
   * Can be one of: start, center, or end.
   */
  tooltipAlignment: prop_types__WEBPACK_IMPORTED_MODULE_9___default().oneOf(['start', 'center', 'end']),

  /**
   * Specify the direction of the tooltip for icon-only buttons.
   * Can be either top, right, bottom, or left.
   */
  tooltipPosition: prop_types__WEBPACK_IMPORTED_MODULE_9___default().oneOf(['top', 'right', 'bottom', 'left']),

  /**
   * Provide the current value of the `<input>`
   */
  value: prop_types__WEBPACK_IMPORTED_MODULE_9___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_9___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number)])
};
ControlledPasswordInput.defaultProps = {
  className: '${prefix}--text__input',
  disabled: false,
  onChange: function onChange() {},
  onClick: function onClick() {},
  invalid: false,
  invalidText: '',
  helperText: '',
  light: false,
  size: ''
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ControlledPasswordInput);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/TextInput/PasswordInput.js":
/*!*******************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/TextInput/PasswordInput.js ***!
  \*******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_11___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_11__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-29.js");
/* harmony import */ var _internal_useNormalizedInputProps__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../internal/useNormalizedInputProps */ "../../node_modules/carbon-components-react/es/internal/useNormalizedInputProps.js");
/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./util */ "../../node_modules/carbon-components-react/es/components/TextInput/util.js");
/* harmony import */ var _FluidForm__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../FluidForm */ "../../node_modules/carbon-components-react/es/components/FluidForm/FormContext.js");
/* harmony import */ var _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! @carbon/feature-flags */ "../../node_modules/@carbon/feature-flags/es/index.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");




var _excluded = ["className", "disabled", "helperText", "hideLabel", "hidePasswordLabel", "id", "inline", "invalid", "invalidText", "labelText", "light", "onChange", "onClick", "onTogglePasswordVisibility", "placeholder", "size", "showPasswordLabel", "tooltipPosition", "tooltipAlignment", "type", "warn", "warnText"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }










var PasswordInput = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().forwardRef(function PasswordInput(_ref, ref) {
  var _classNames, _classNames2, _classNames3, _classNames4, _classNames7, _classNames8;

  var className = _ref.className,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      helperText = _ref.helperText,
      hideLabel = _ref.hideLabel,
      _ref$hidePasswordLabe = _ref.hidePasswordLabel,
      hidePasswordLabel = _ref$hidePasswordLabe === void 0 ? 'Hide password' : _ref$hidePasswordLabe,
      id = _ref.id,
      inline = _ref.inline,
      _ref$invalid = _ref.invalid,
      invalid = _ref$invalid === void 0 ? false : _ref$invalid,
      invalidText = _ref.invalidText,
      labelText = _ref.labelText,
      _ref$light = _ref.light,
      light = _ref$light === void 0 ? false : _ref$light,
      _ref$onChange = _ref.onChange,
      _onChange = _ref$onChange === void 0 ? function () {} : _ref$onChange,
      _ref$onClick = _ref.onClick,
      _onClick = _ref$onClick === void 0 ? function () {} : _ref$onClick,
      onTogglePasswordVisibility = _ref.onTogglePasswordVisibility,
      placeholder = _ref.placeholder,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'md' : _ref$size,
      _ref$showPasswordLabe = _ref.showPasswordLabel,
      showPasswordLabel = _ref$showPasswordLabe === void 0 ? 'Show password' : _ref$showPasswordLabe,
      _ref$tooltipPosition = _ref.tooltipPosition,
      tooltipPosition = _ref$tooltipPosition === void 0 ? 'bottom' : _ref$tooltipPosition,
      _ref$tooltipAlignment = _ref.tooltipAlignment,
      tooltipAlignment = _ref$tooltipAlignment === void 0 ? 'center' : _ref$tooltipAlignment,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'password' : _ref$type,
      warn = _ref.warn,
      warnText = _ref.warnText,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_3__["default"])(_ref, _excluded);

  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_4__.useState)(type),
      _useState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_useState, 2),
      inputType = _useState2[0],
      setInputType = _useState2[1];

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_6__.usePrefix)();
  var normalizedProps = (0,_internal_useNormalizedInputProps__WEBPACK_IMPORTED_MODULE_7__.useNormalizedInputProps)({
    id: id,
    invalid: invalid,
    invalidText: invalidText,
    warn: warn,
    warnText: warnText
  });

  var handleTogglePasswordVisibility = function handleTogglePasswordVisibility(event) {
    setInputType(inputType === 'password' ? 'text' : 'password');
    onTogglePasswordVisibility && onTogglePasswordVisibility(event);
  };

  var textInputClasses = classnames__WEBPACK_IMPORTED_MODULE_5___default()("".concat(prefix, "--text-input"), "".concat(prefix, "--password-input"), className, (_classNames = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--text-input--light"), light), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--text-input--invalid"), normalizedProps.invalid), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--text-input--warning"), normalizedProps.warn), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames, "".concat(prefix, "--text-input--").concat(size), size), _classNames));

  var sharedTextInputProps = _objectSpread({
    id: id,
    onChange: function onChange(evt) {
      if (!disabled) {
        _onChange(evt);
      }
    },
    onClick: function onClick(evt) {
      if (!disabled) {
        _onClick(evt);
      }
    },
    placeholder: placeholder,
    type: inputType,
    className: textInputClasses,
    ref: ref
  }, rest);

  var inputWrapperClasses = classnames__WEBPACK_IMPORTED_MODULE_5___default()("".concat(prefix, "--form-item"), "".concat(prefix, "--text-input-wrapper"), "".concat(prefix, "--password-input-wrapper"), (_classNames2 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames2, "".concat(prefix, "--text-input-wrapper--light"), light), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames2, "".concat(prefix, "--text-input-wrapper--inline"), inline), _classNames2));
  var labelClasses = classnames__WEBPACK_IMPORTED_MODULE_5___default()("".concat(prefix, "--label"), (_classNames3 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames3, "".concat(prefix, "--visually-hidden"), hideLabel), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames3, "".concat(prefix, "--label--disabled"), disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames3, "".concat(prefix, "--label--inline"), inline), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames3, "".concat(prefix, "--label--inline--").concat(size), inline && !!size), _classNames3));
  var helperTextClasses = classnames__WEBPACK_IMPORTED_MODULE_5___default()("".concat(prefix, "--form__helper-text"), (_classNames4 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames4, "".concat(prefix, "--form__helper-text--disabled"), disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames4, "".concat(prefix, "--form__helper-text--inline"), inline), _classNames4));
  var fieldOuterWrapperClasses = classnames__WEBPACK_IMPORTED_MODULE_5___default()("".concat(prefix, "--text-input__field-outer-wrapper"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--text-input__field-outer-wrapper--inline"), inline));
  var fieldWrapperClasses = classnames__WEBPACK_IMPORTED_MODULE_5___default()("".concat(prefix, "--text-input__field-wrapper"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])({}, "".concat(prefix, "--text-input__field-wrapper--warning"), normalizedProps.warn));
  var iconClasses = classnames__WEBPACK_IMPORTED_MODULE_5___default()((_classNames7 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames7, "".concat(prefix, "--text-input__invalid-icon"), normalizedProps.invalid || normalizedProps.warn), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames7, "".concat(prefix, "--text-input__invalid-icon--warning"), normalizedProps.warn), _classNames7));
  var label = labelText ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("label", {
    htmlFor: id,
    className: labelClasses
  }, labelText) : null;
  var helper = helperText ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", {
    className: helperTextClasses
  }, helperText) : null;
  var passwordIsVisible = inputType === 'text';
  var passwordVisibilityIcon = passwordIsVisible ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__.ViewOff16, {
    className: "".concat(prefix, "--icon-visibility-off")
  }) : /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement(_carbon_icons_react__WEBPACK_IMPORTED_MODULE_8__.View16, {
    className: "".concat(prefix, "--icon-visibility-on")
  });
  var passwordVisibilityToggleClasses = classnames__WEBPACK_IMPORTED_MODULE_5___default()("".concat(prefix, "--text-input--password__visibility__toggle"), "".concat(prefix, "--btn"), "".concat(prefix, "--btn--icon-only"), "".concat(prefix, "--tooltip__trigger"), "".concat(prefix, "--tooltip--a11y"), (_classNames8 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames8, "".concat(prefix, "--btn--disabled"), disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames8, "".concat(prefix, "--tooltip--").concat(tooltipPosition), tooltipPosition), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__["default"])(_classNames8, "".concat(prefix, "--tooltip--align-").concat(tooltipAlignment), tooltipAlignment), _classNames8));
  var input = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement((react__WEBPACK_IMPORTED_MODULE_4___default().Fragment), null, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("input", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, (0,_util__WEBPACK_IMPORTED_MODULE_9__.textInputProps)({
    sharedTextInputProps: sharedTextInputProps,
    invalid: normalizedProps.invalid,
    invalidId: normalizedProps.invalidId,
    warn: normalizedProps.warn,
    warnId: normalizedProps.warnId
  }), {
    disabled: disabled,
    "data-toggle-password-visibility": inputType === 'password'
  })), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("button", {
    type: "button",
    className: passwordVisibilityToggleClasses,
    disabled: disabled,
    onClick: handleTogglePasswordVisibility
  }, !disabled && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("span", {
    className: "".concat(prefix, "--assistive-text")
  }, passwordIsVisible ? hidePasswordLabel : showPasswordLabel), passwordVisibilityIcon));

  var _useContext = (0,react__WEBPACK_IMPORTED_MODULE_4__.useContext)(_FluidForm__WEBPACK_IMPORTED_MODULE_10__.FormContext),
      isFluid = _useContext.isFluid;

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    setInputType(type);
  }, [type]);
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", {
    className: inputWrapperClasses
  }, !inline ? label : /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", {
    className: "".concat(prefix, "--text-input__label-helper-wrapper")
  }, label, !isFluid && helper), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", {
    className: fieldOuterWrapperClasses
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement("div", {
    className: fieldWrapperClasses,
    "data-invalid": normalizedProps.invalid || null
  }, normalizedProps.icon && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement(normalizedProps.icon, {
    className: iconClasses
  }), input, isFluid && !inline && normalizedProps.validation), !isFluid && !inline && (normalizedProps.validation || helper)));
});
PasswordInput.displayName = 'PasswordInput';
PasswordInput.propTypes = {
  /**
   * Provide a custom className that is applied directly to the underlying
   * `<input>` node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().string),

  /**
   * Optionally provide the default value of the `<input>`
   */
  defaultValue: prop_types__WEBPACK_IMPORTED_MODULE_11___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_11___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number)]),

  /**
   * Specify whether the control is disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),

  /**
   * Provide text that is used alongside the control label for additional help
   */
  helperText: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().node),

  /**
   * Specify whether or not the underlying label is visually hidden
   */
  hideLabel: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),

  /**
   * "Hide password" tooltip text on password visibility toggle
   */
  hidePasswordLabel: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().string),

  /**
   * Provide a unique identifier for the input field
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().string.isRequired),

  /**
   * `true` to use the inline version.
   */
  inline: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),

  /**
   * Specify whether the control is currently invalid
   */
  invalid: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),

  /**
   * Provide the text that is displayed when the control is in an invalid state
   */
  invalidText: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().node),

  /**
   * Provide the text that will be read by a screen reader when visiting this
   * control
   */
  labelText: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().node.isRequired),

  /**
   * `true` to use the light version. For use on $ui-01 backgrounds only.
   * Don't use this to make tile background color same as container background color.
   */
  light: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),

  /**
   * Optionally provide an `onChange` handler that is called whenever `<input>`
   * is updated
   */
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().func),

  /**
   * Optionally provide an `onClick` handler that is called whenever the
   * `<input>` is clicked
   */
  onClick: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().func),

  /**
   * Callback function that is called whenever the toggle password visibility
   * button is clicked
   */
  onTogglePasswordVisibility: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().func),

  /**
   * Specify the placeholder attribute for the `<input>`
   */
  placeholder: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().string),

  /**
   * "Show password" tooltip text on password visibility toggle
   */
  showPasswordLabel: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().string),

  /**
   * Specify the size of the Text Input. Supports `sm`, `md`, or `lg`.
   */
  size: _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_12__.enabled('enable-v11-release') ? prop_types__WEBPACK_IMPORTED_MODULE_11___default().oneOf(['sm', 'md', 'lg']) : (prop_types__WEBPACK_IMPORTED_MODULE_11___default().string),

  /**
   * Specify the alignment of the tooltip to the icon-only button.
   * Can be one of: start, center, or end.
   */
  tooltipAlignment: prop_types__WEBPACK_IMPORTED_MODULE_11___default().oneOf(['start', 'center', 'end']),

  /**
   * Specify the direction of the tooltip for icon-only buttons.
   * Can be either top, right, bottom, or left.
   */
  tooltipPosition: prop_types__WEBPACK_IMPORTED_MODULE_11___default().oneOf(['top', 'right', 'bottom', 'left']),

  /**
   * The input type, either password or text
   */
  type: prop_types__WEBPACK_IMPORTED_MODULE_11___default().oneOf(['password', 'text']),

  /**
   * Provide the current value of the `<input>`
   */
  value: prop_types__WEBPACK_IMPORTED_MODULE_11___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_11___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number)]),

  /**
   * Specify whether the control is currently in warning state
   */
  warn: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),

  /**
   * Provide the text that is displayed when the control is in warning state
   */
  warnText: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().node)
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (PasswordInput);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/TextInput/TextInput.Skeleton.js":
/*!************************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/TextInput/TextInput.Skeleton.js ***!
  \************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");


var _excluded = ["hideLabel", "className"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */





var TextInputSkeleton = function TextInputSkeleton(_ref) {
  var hideLabel = _ref.hideLabel,
      className = _ref.className,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_4__.usePrefix)();
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
    className: classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--form-item"), className)
  }, rest), !hideLabel && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("span", {
    className: "".concat(prefix, "--label ").concat(prefix, "--skeleton")
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", {
    className: "".concat(prefix, "--skeleton ").concat(prefix, "--text-input")
  }));
};

TextInputSkeleton.propTypes = {
  /**
   * Specify an optional className to add to the form item wrapper.
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().string),

  /**
   * Specify whether the label should be hidden, or not
   */
  hideLabel: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().bool)
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (TextInputSkeleton);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/TextInput/TextInput.js":
/*!***************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/TextInput/TextInput.js ***!
  \***************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_11___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_11__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var _internal_useNormalizedInputProps__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../internal/useNormalizedInputProps */ "../../node_modules/carbon-components-react/es/internal/useNormalizedInputProps.js");
/* harmony import */ var _PasswordInput__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./PasswordInput */ "../../node_modules/carbon-components-react/es/components/TextInput/PasswordInput.js");
/* harmony import */ var _ControlledPasswordInput__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./ControlledPasswordInput */ "../../node_modules/carbon-components-react/es/components/TextInput/ControlledPasswordInput.js");
/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./util */ "../../node_modules/carbon-components-react/es/components/TextInput/util.js");
/* harmony import */ var _FluidForm__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../FluidForm */ "../../node_modules/carbon-components-react/es/components/FluidForm/FormContext.js");
/* harmony import */ var _FeatureFlags__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../FeatureFlags */ "../../node_modules/carbon-components-react/es/components/FeatureFlags/index.js");
/* harmony import */ var _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! @carbon/feature-flags */ "../../node_modules/@carbon/feature-flags/es/index.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");


var _excluded = ["className", "disabled", "helperText", "hideLabel", "id", "inline", "invalid", "invalidText", "labelText", "light", "onChange", "onClick", "placeholder", "readOnly", "size", "type", "warn", "warnText"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */











var TextInput = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().forwardRef(function TextInput(_ref, ref) {
  var _classNames, _classNames2, _classNames3, _classNames4, _classNames7;

  var className = _ref.className,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      helperText = _ref.helperText,
      hideLabel = _ref.hideLabel,
      id = _ref.id,
      _ref$inline = _ref.inline,
      inline = _ref$inline === void 0 ? false : _ref$inline,
      _ref$invalid = _ref.invalid,
      invalid = _ref$invalid === void 0 ? false : _ref$invalid,
      invalidText = _ref.invalidText,
      labelText = _ref.labelText,
      _ref$light = _ref.light,
      light = _ref$light === void 0 ? false : _ref$light,
      _ref$onChange = _ref.onChange,
      _onChange = _ref$onChange === void 0 ? function () {} : _ref$onChange,
      _ref$onClick = _ref.onClick,
      _onClick = _ref$onClick === void 0 ? function () {} : _ref$onClick,
      placeholder = _ref.placeholder,
      readOnly = _ref.readOnly,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'md' : _ref$size,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'text' : _ref$type,
      _ref$warn = _ref.warn,
      warn = _ref$warn === void 0 ? false : _ref$warn,
      warnText = _ref.warnText,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_ref, _excluded);

  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_4__.usePrefix)();
  var enabled = (0,_FeatureFlags__WEBPACK_IMPORTED_MODULE_5__.useFeatureFlag)('enable-v11-release');
  var normalizedProps = (0,_internal_useNormalizedInputProps__WEBPACK_IMPORTED_MODULE_6__.useNormalizedInputProps)({
    id: id,
    readOnly: readOnly,
    disabled: disabled,
    invalid: invalid,
    invalidText: invalidText,
    warn: warn,
    warnText: warnText
  });
  var customClassName = className !== null && className !== void 0 ? className : "".concat(prefix, "--text__input");
  var textInputClasses = classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--text-input"), [enabled ? null : className], (_classNames = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, customClassName, enabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--text-input--light"), light), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--text-input--invalid"), normalizedProps.invalid), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--text-input--warning"), normalizedProps.warn), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames, "".concat(prefix, "--text-input--").concat(size), size), _classNames));

  var sharedTextInputProps = _objectSpread((0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])({
    id: id,
    onChange: function onChange(evt) {
      if (!normalizedProps.disabled) {
        _onChange(evt);
      }
    },
    onClick: function onClick(evt) {
      if (!normalizedProps.disabled) {
        _onClick(evt);
      }
    },
    placeholder: placeholder,
    type: type,
    ref: ref,
    className: textInputClasses,
    title: placeholder,
    disabled: normalizedProps.disabled,
    readOnly: readOnly
  }, 'aria-describedby', helperText && normalizedProps.helperId), rest);

  var inputWrapperClasses = classnames__WEBPACK_IMPORTED_MODULE_3___default()([enabled ? classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--form-item"), className) : "".concat(prefix, "--form-item")], "".concat(prefix, "--text-input-wrapper"), (_classNames2 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames2, "".concat(prefix, "--text-input-wrapper--readonly"), readOnly), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames2, "".concat(prefix, "--text-input-wrapper--light"), light), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames2, "".concat(prefix, "--text-input-wrapper--inline"), inline), _classNames2));
  var labelClasses = classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--label"), (_classNames3 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames3, "".concat(prefix, "--visually-hidden"), hideLabel), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames3, "".concat(prefix, "--label--disabled"), normalizedProps.disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames3, "".concat(prefix, "--label--inline"), inline), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames3, "".concat(prefix, "--label--inline--").concat(size), inline && !!size), _classNames3));
  var helperTextClasses = classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--form__helper-text"), (_classNames4 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames4, "".concat(prefix, "--form__helper-text--disabled"), normalizedProps.disabled), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames4, "".concat(prefix, "--form__helper-text--inline"), inline), _classNames4));
  var fieldOuterWrapperClasses = classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--text-input__field-outer-wrapper"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])({}, "".concat(prefix, "--text-input__field-outer-wrapper--inline"), inline));
  var fieldWrapperClasses = classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--text-input__field-wrapper"), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])({}, "".concat(prefix, "--text-input__field-wrapper--warning"), normalizedProps.warn));
  var iconClasses = classnames__WEBPACK_IMPORTED_MODULE_3___default()((_classNames7 = {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames7, "".concat(prefix, "--text-input__invalid-icon"), normalizedProps.invalid || normalizedProps.warn), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames7, "".concat(prefix, "--text-input__invalid-icon--warning"), normalizedProps.warn), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_classNames7, "".concat(prefix, "--text-input__readonly-icon"), readOnly), _classNames7));
  var label = labelText ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("label", {
    htmlFor: id,
    className: labelClasses
  }, labelText) : null;
  var helper = helperText ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", {
    id: normalizedProps.helperId,
    className: helperTextClasses
  }, helperText) : null;
  var input = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("input", (0,_util__WEBPACK_IMPORTED_MODULE_7__.textInputProps)({
    sharedTextInputProps: sharedTextInputProps,
    invalid: normalizedProps.invalid,
    invalidId: normalizedProps.invalidId,
    warn: normalizedProps.warn,
    warnId: normalizedProps.warnId
  }));

  var _useContext = (0,react__WEBPACK_IMPORTED_MODULE_2__.useContext)(_FluidForm__WEBPACK_IMPORTED_MODULE_8__.FormContext),
      isFluid = _useContext.isFluid;

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", {
    className: inputWrapperClasses
  }, !inline ? label : /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", {
    className: "".concat(prefix, "--text-input__label-helper-wrapper")
  }, label, !isFluid && helper), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", {
    className: fieldOuterWrapperClasses
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("div", {
    className: fieldWrapperClasses,
    "data-invalid": normalizedProps.invalid || null
  }, normalizedProps.icon && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement(normalizedProps.icon, {
    className: iconClasses
  }), input, isFluid && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_2___default().createElement("hr", {
    className: "".concat(prefix, "--text-input__divider")
  }), isFluid && !inline && normalizedProps.validation), !isFluid && !inline && (normalizedProps.validation || helper)));
});
TextInput.displayName = 'TextInput';
TextInput.PasswordInput = _PasswordInput__WEBPACK_IMPORTED_MODULE_9__["default"];
TextInput.ControlledPasswordInput = _ControlledPasswordInput__WEBPACK_IMPORTED_MODULE_10__["default"];
TextInput.propTypes = {
  /**
   * Specify an optional className to be applied to the `<input>` node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().string),

  /**
   * Optionally provide the default value of the `<input>`
   */
  defaultValue: prop_types__WEBPACK_IMPORTED_MODULE_11___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_11___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number)]),

  /**
   * Specify whether the `<input>` should be disabled
   */
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),

  /**
   * Provide text that is used alongside the control label for additional help
   */
  helperText: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().node),

  /**
   * Specify whether you want the underlying label to be visually hidden
   */
  hideLabel: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),

  /**
   * Specify a custom `id` for the `<input>`
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().string.isRequired),

  /**
   * `true` to use the inline version.
   */
  inline: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),

  /**
   * Specify whether the control is currently invalid
   */
  invalid: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),

  /**
   * Provide the text that is displayed when the control is in an invalid state
   */
  invalidText: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().node),

  /**
   * Provide the text that will be read by a screen reader when visiting this
   * control
   */
  labelText: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().node.isRequired),

  /**
   * `true` to use the light version. For use on $ui-01 backgrounds only.
   * Don't use this to make tile background color same as container background color.
   */
  light: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),

  /**
   * Optionally provide an `onChange` handler that is called whenever `<input>`
   * is updated
   */
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().func),

  /**
   * Optionally provide an `onClick` handler that is called whenever the
   * `<input>` is clicked
   */
  onClick: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().func),

  /**
   * Specify the placeholder attribute for the `<input>`
   */
  placeholder: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().string),

  /**
   * Whether the input should be read-only
   */
  readOnly: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),

  /**
   * Specify the size of the Text Input. Currently supports the following:
   */
  size: _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_12__.enabled('enable-v11-release') ? prop_types__WEBPACK_IMPORTED_MODULE_11___default().oneOf(['sm', 'md', 'lg']) : prop_types__WEBPACK_IMPORTED_MODULE_11___default().oneOf(['sm', 'md', 'lg', 'xl']),

  /**
   * Specify the type of the `<input>`
   */
  type: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().string),

  /**
   * Specify the value of the `<input>`
   */
  value: prop_types__WEBPACK_IMPORTED_MODULE_11___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_11___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number)]),

  /**
   * Specify whether the control is currently in warning state
   */
  warn: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),

  /**
   * Provide the text that is displayed when the control is in warning state
   */
  warnText: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().node)
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (TextInput);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/TextInput/index.js":
/*!***********************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/TextInput/index.js ***!
  \***********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "TextInputSkeleton": () => (/* reexport safe */ _TextInput_Skeleton__WEBPACK_IMPORTED_MODULE_4__["default"]),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _internal_deprecateFieldOnObject__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../internal/deprecateFieldOnObject */ "../../node_modules/carbon-components-react/es/internal/deprecateFieldOnObject.js");
/* harmony import */ var _ControlledPasswordInput__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./ControlledPasswordInput */ "../../node_modules/carbon-components-react/es/components/TextInput/ControlledPasswordInput.js");
/* harmony import */ var _PasswordInput__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./PasswordInput */ "../../node_modules/carbon-components-react/es/components/TextInput/PasswordInput.js");
/* harmony import */ var _TextInput__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./TextInput */ "../../node_modules/carbon-components-react/es/components/TextInput/TextInput.js");
/* harmony import */ var _TextInput_Skeleton__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./TextInput.Skeleton */ "../../node_modules/carbon-components-react/es/components/TextInput/TextInput.Skeleton.js");
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */




_TextInput__WEBPACK_IMPORTED_MODULE_0__["default"].ControlledPasswordInput = _ControlledPasswordInput__WEBPACK_IMPORTED_MODULE_1__["default"];
_TextInput__WEBPACK_IMPORTED_MODULE_0__["default"].PasswordInput = _PasswordInput__WEBPACK_IMPORTED_MODULE_2__["default"];

if (true) {
  (0,_internal_deprecateFieldOnObject__WEBPACK_IMPORTED_MODULE_3__.deprecateFieldOnObject)(_TextInput__WEBPACK_IMPORTED_MODULE_0__["default"], 'ControlledPasswordInput', _ControlledPasswordInput__WEBPACK_IMPORTED_MODULE_1__["default"]);
  (0,_internal_deprecateFieldOnObject__WEBPACK_IMPORTED_MODULE_3__.deprecateFieldOnObject)(_TextInput__WEBPACK_IMPORTED_MODULE_0__["default"], 'PasswordInput', _PasswordInput__WEBPACK_IMPORTED_MODULE_2__["default"]);
}


/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_TextInput__WEBPACK_IMPORTED_MODULE_0__["default"]);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/TextInput/util.js":
/*!**********************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/TextInput/util.js ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "textInputProps": () => (/* binding */ textInputProps)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");


function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

var invalidProps = function invalidProps(invalidId) {
  return {
    'data-invalid': true,
    'aria-invalid': true,
    'aria-describedby': invalidId
  };
};

var warnProps = function warnProps(warnId) {
  return {
    'aria-describedby': warnId
  };
};

var textInputProps = function textInputProps(_ref) {
  var sharedTextInputProps = _ref.sharedTextInputProps,
      invalid = _ref.invalid,
      invalidId = _ref.invalidId,
      warn = _ref.warn,
      warnId = _ref.warnId;
  return _objectSpread(_objectSpread(_objectSpread({}, sharedTextInputProps), invalid ? invalidProps(invalidId) : {}), warn ? warnProps(warnId) : {});
};

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/components/Tooltip/next/Tooltip.js":
/*!****************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/components/Tooltip/next/Tooltip.js ***!
  \****************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Tooltip": () => (/* binding */ Tooltip)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_12___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_12__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _Popover__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../Popover */ "../../node_modules/carbon-components-react/es/components/Popover/index.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/match.js");
/* harmony import */ var _internal_keyboard__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../../../internal/keyboard */ "../../node_modules/carbon-components-react/es/internal/keyboard/keys.js");
/* harmony import */ var _internal_useDelayedState__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../../internal/useDelayedState */ "../../node_modules/carbon-components-react/es/internal/useDelayedState.js");
/* harmony import */ var _internal_useId__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../../internal/useId */ "../../node_modules/carbon-components-react/es/internal/useId.js");
/* harmony import */ var _internal_useNoInteractiveChildren__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../../../internal/useNoInteractiveChildren */ "../../node_modules/carbon-components-react/es/internal/useNoInteractiveChildren.js");
/* harmony import */ var _internal_usePrefix__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../../internal/usePrefix */ "../../node_modules/carbon-components-react/es/internal/usePrefix.js");



var _excluded = ["align", "className", "children", "label", "description", "enterDelayMs", "leaveDelayMs", "defaultOpen"];

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */










function Tooltip(_ref) {
  var _ref$align = _ref.align,
      align = _ref$align === void 0 ? 'top' : _ref$align,
      customClassName = _ref.className,
      children = _ref.children,
      label = _ref.label,
      description = _ref.description,
      _ref$enterDelayMs = _ref.enterDelayMs,
      enterDelayMs = _ref$enterDelayMs === void 0 ? 100 : _ref$enterDelayMs,
      _ref$leaveDelayMs = _ref.leaveDelayMs,
      leaveDelayMs = _ref$leaveDelayMs === void 0 ? 300 : _ref$leaveDelayMs,
      _ref$defaultOpen = _ref.defaultOpen,
      defaultOpen = _ref$defaultOpen === void 0 ? false : _ref$defaultOpen,
      rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, _excluded);

  var containerRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var tooltipRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);

  var _useDelayedState = (0,_internal_useDelayedState__WEBPACK_IMPORTED_MODULE_5__.useDelayedState)(defaultOpen),
      _useDelayedState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_1__["default"])(_useDelayedState, 2),
      open = _useDelayedState2[0],
      setOpen = _useDelayedState2[1];

  var id = (0,_internal_useId__WEBPACK_IMPORTED_MODULE_6__.useId)('tooltip');
  var prefix = (0,_internal_usePrefix__WEBPACK_IMPORTED_MODULE_7__.usePrefix)();
  var child = react__WEBPACK_IMPORTED_MODULE_4___default().Children.only(children);
  var triggerProps = {
    onFocus: function onFocus() {
      return setOpen(true);
    },
    onBlur: function onBlur() {
      return setOpen(false);
    },
    // This should be placed on the trigger in case the element is disabled
    onMouseEnter: onMouseEnter
  };

  if (label) {
    triggerProps['aria-labelledby'] = id;
  } else {
    triggerProps['aria-describedby'] = id;
  }

  function onKeyDown(event) {
    if (open && (0,_internal_keyboard__WEBPACK_IMPORTED_MODULE_8__.match)(event, _internal_keyboard__WEBPACK_IMPORTED_MODULE_9__.Escape)) {
      event.stopPropagation();
      setOpen(false);
    }
  }

  function onMouseEnter() {
    setOpen(true, enterDelayMs);
  }

  function onMouseLeave() {
    setOpen(false, leaveDelayMs);
  }

  (0,_internal_useNoInteractiveChildren__WEBPACK_IMPORTED_MODULE_10__.useNoInteractiveChildren)(tooltipRef, 'The Tooltip component must have no interactive content rendered by the' + '`label` or `description` prop');
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement(_Popover__WEBPACK_IMPORTED_MODULE_11__.Popover, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, rest, {
    align: align,
    className: classnames__WEBPACK_IMPORTED_MODULE_3___default()("".concat(prefix, "--tooltip"), customClassName),
    dropShadow: false,
    highContrast: true,
    onKeyDown: onKeyDown,
    onMouseLeave: onMouseLeave,
    open: open,
    ref: containerRef
  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().cloneElement(child, triggerProps), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4___default().createElement(_Popover__WEBPACK_IMPORTED_MODULE_11__.PopoverContent, {
    "aria-hidden": "true",
    className: "".concat(prefix, "--tooltip-content"),
    id: id,
    ref: tooltipRef,
    role: "tooltip"
  }, label || description));
}

Tooltip.propTypes = {
  /**
   * Specify how the trigger should align with the tooltip
   */
  align: prop_types__WEBPACK_IMPORTED_MODULE_12___default().oneOf(['top', 'top-left', 'top-right', 'bottom', 'bottom-left', 'bottom-right', 'left', 'left-bottom', 'left-top', 'right', 'right-bottom', 'right-top']),

  /**
   * Pass in the child to which the tooltip will be applied
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().node),

  /**
   * Specify an optional className to be applied to the container node
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().string),

  /**
   * Specify whether the tooltip should be open when it first renders
   */
  defaultOpen: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().bool),

  /**
   * Provide the description to be rendered inside of the Tooltip. The
   * description will use `aria-describedby` and will describe the child node
   * in addition to the text rendered inside of the child. This means that if you
   * have text in the child node, that it will be announced alongside the
   * description to the screen reader.
   *
   * Note: if label and description are both provided, label will be used and
   * description will not be used
   */
  description: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().node),

  /**
   * Specify the duration in milliseconds to delay before displaying the tooltip
   */
  enterDelayMs: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number),

  /**
   * Provide the label to be rendered inside of the Tooltip. The label will use
   * `aria-labelledby` and will fully describe the child node that is provided.
   * This means that if you have text in the child node, that it will not be
   * announced to the screen reader.
   *
   * Note: if label and description are both provided, description will not be
   * used
   */
  label: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().node),

  /**
   * Specify the duration in milliseconds to delay before hiding the tooltip
   */
  leaveDelayMs: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number)
};


/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/FeatureFlags.js":
/*!******************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/FeatureFlags.js ***!
  \******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "useControlledStateWithValue": () => (/* binding */ useControlledStateWithValue)
/* harmony export */ });
/* harmony import */ var _carbon_feature_flags__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @carbon/feature-flags */ "../../node_modules/@carbon/feature-flags/es/index.js");
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * This file contains the list of the default values of compile-time feature flags.
 *
 * Build toolchain can replace variable here and/or the references
 * in order to apply non-default values to those feature flags.
 *
 * @example Render `foo` if `aFeatureFlag` is `true`, render `bar` otherwise.
 * import { aFeatureFlag } from '/path/to/FeatureFlags';
 * ...
 * const MyComponent = props => (<div {...props}>{aFeatureFlag ? 'foo' : 'bar'}</div>);
 */

/**
 * With this flag, certain components will be created in either a controlled or controlled
 * mode based on the existence of a value prop.
 *
 * The following components will have the significance of their props slightly altered as outlined below.
 *
 * Components: `<NumberInput>`
 *
 * * `value` → when provided, enables controlled mode.
 *   For the rest of the component's lifecycle, it will be controlled by this prop as it's single source of truth.
 * * `defaultValue` → Optional starting value, used for for uncontrolled mode only (no value prop).
 *   The value prop takes precedence over defaultValue.
 * * `onChange` → Optional event handler.
 *   However, if value is provided and a handler is not, we'll throw a warning indicating the component is now read-only
 * * `readOnly` → silences the above warning, acknowledging the read-only state of the component
 *
 * This flag also disables prop -> state sync in several components, notably `<NumberInput>`.
 *
 * This flag also updates event handlers to pass an up-to-date value in the second parameter,
 * so applications can use it in both controlled and uncontrolled components.
 *
 * * _With_ this feature flag, the signature of the event handler will be altered to provide additional context in the second parameter: `onChange(event, { value, ...rest })` where:
 *   * `event` is the (React) raw event
 *   * `value` is the new value
 *   * `rest` tells you additional information based on the source component
 * * _Without_ this feature flag the event handler has component-specific signature, e.g. `onChange(event, direction)`.
 */

var useControlledStateWithValue = (0,_carbon_feature_flags__WEBPACK_IMPORTED_MODULE_0__.enabled)('enable-use-controlled-state-with-value');

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/Selection.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/Selection.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ Selection),
/* harmony export */   "useSelection": () => (/* binding */ useSelection)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_10___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_10__);
/* harmony import */ var lodash_isequal__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! lodash.isequal */ "../../node_modules/lodash.isequal/index.js");
/* harmony import */ var lodash_isequal__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(lodash_isequal__WEBPACK_IMPORTED_MODULE_9__);









function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_5__["default"])(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_5__["default"])(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_4__["default"])(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */




function callOnChangeHandler(_ref) {
  var isControlled = _ref.isControlled,
      isMounted = _ref.isMounted,
      onChangeHandlerControlled = _ref.onChangeHandlerControlled,
      onChangeHandlerUncontrolled = _ref.onChangeHandlerUncontrolled,
      selectedItems = _ref.selectedItems;

  if (isControlled) {
    if (isMounted && onChangeHandlerControlled) {
      onChangeHandlerControlled({
        selectedItems: selectedItems
      });
    }
  } else {
    onChangeHandlerUncontrolled(selectedItems);
  }
}

function useSelection(_ref2) {
  var disabled = _ref2.disabled,
      onChange = _ref2.onChange,
      _ref2$initialSelected = _ref2.initialSelectedItems,
      initialSelectedItems = _ref2$initialSelected === void 0 ? [] : _ref2$initialSelected,
      controlledItems = _ref2.selectedItems;
  var isMounted = (0,react__WEBPACK_IMPORTED_MODULE_8__.useRef)(false);
  var savedOnChange = (0,react__WEBPACK_IMPORTED_MODULE_8__.useRef)(onChange);

  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_8__.useState)(initialSelectedItems),
      _useState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_7__["default"])(_useState, 2),
      uncontrolledItems = _useState2[0],
      setUncontrolledItems = _useState2[1];

  var isControlled = !!controlledItems;
  var selectedItems = isControlled ? controlledItems : uncontrolledItems;
  var onItemChange = (0,react__WEBPACK_IMPORTED_MODULE_8__.useCallback)(function (item) {
    if (disabled) {
      return;
    }

    var selectedIndex;
    selectedItems.forEach(function (selectedItem, index) {
      if (lodash_isequal__WEBPACK_IMPORTED_MODULE_9___default()(selectedItem, item)) {
        selectedIndex = index;
      }
    });
    var newSelectedItems;

    if (selectedIndex === undefined) {
      newSelectedItems = selectedItems.concat(item);
      callOnChangeHandler({
        isControlled: isControlled,
        isMounted: isMounted.current,
        onChangeHandlerControlled: savedOnChange.current,
        onChangeHandlerUncontrolled: setUncontrolledItems,
        selectedItems: newSelectedItems
      });
      return;
    }

    newSelectedItems = removeAtIndex(selectedItems, selectedIndex);
    callOnChangeHandler({
      isControlled: isControlled,
      isMounted: isMounted.current,
      onChangeHandlerControlled: savedOnChange.current,
      onChangeHandlerUncontrolled: setUncontrolledItems,
      selectedItems: newSelectedItems
    });
  }, [disabled, isControlled, selectedItems]);
  var clearSelection = (0,react__WEBPACK_IMPORTED_MODULE_8__.useCallback)(function () {
    if (disabled) {
      return;
    }

    callOnChangeHandler({
      isControlled: isControlled,
      isMounted: isMounted.current,
      onChangeHandlerControlled: savedOnChange.current,
      onChangeHandlerUncontrolled: setUncontrolledItems,
      selectedItems: []
    });
  }, [disabled, isControlled]);
  (0,react__WEBPACK_IMPORTED_MODULE_8__.useEffect)(function () {
    savedOnChange.current = onChange;
  }, [onChange]);
  (0,react__WEBPACK_IMPORTED_MODULE_8__.useEffect)(function () {
    if (isMounted.current && savedOnChange.current && !isControlled) {
      savedOnChange.current({
        selectedItems: selectedItems
      });
    }
  }, [isControlled, selectedItems]);
  (0,react__WEBPACK_IMPORTED_MODULE_8__.useEffect)(function () {
    isMounted.current = true;
    return function () {
      isMounted.current = false;
    };
  }, []);
  return {
    selectedItems: selectedItems,
    onItemChange: onItemChange,
    clearSelection: clearSelection
  };
}

var Selection = /*#__PURE__*/function (_React$Component) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(Selection, _React$Component);

  var _super = _createSuper(Selection);

  function Selection(props) {
    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, Selection);

    _this = _super.call(this, props);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this), "internalSetState", function (stateToSet, callback) {
      return _this.setState(stateToSet, function () {
        if (callback) {
          callback();
        }

        if (_this.props.onChange) {
          _this.props.onChange(_this.state);
        }
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this), "handleClearSelection", function () {
      if (_this.props.disabled) {
        return;
      }

      _this.internalSetState({
        selectedItems: []
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this), "handleSelectItem", function (item) {
      _this.internalSetState(function (state) {
        return {
          selectedItems: state.selectedItems.concat(item)
        };
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this), "handleRemoveItem", function (index) {
      _this.internalSetState(function (state) {
        return {
          selectedItems: removeAtIndex(state.selectedItems, index)
        };
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this), "handleOnItemChange", function (item) {
      if (_this.props.disabled) {
        return;
      }

      var selectedItems = _this.state.selectedItems;
      var selectedIndex;
      selectedItems.forEach(function (selectedItem, index) {
        if (lodash_isequal__WEBPACK_IMPORTED_MODULE_9___default()(selectedItem, item)) {
          selectedIndex = index;
        }
      });

      if (selectedIndex === undefined) {
        _this.handleSelectItem(item);

        return;
      }

      _this.handleRemoveItem(selectedIndex);
    });

    _this.state = {
      selectedItems: props.initialSelectedItems
    };
    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(Selection, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          children = _this$props.children,
          render = _this$props.render;
      var selectedItems = this.state.selectedItems;
      var renderProps = {
        selectedItems: selectedItems,
        onItemChange: this.handleOnItemChange,
        clearSelection: this.handleClearSelection
      };

      if (render !== undefined) {
        return render(renderProps);
      }

      if (children !== undefined) {
        return children(renderProps);
      }

      return null;
    }
  }]);

  return Selection;
}((react__WEBPACK_IMPORTED_MODULE_8___default().Component)); // Generic utility for safely removing an element at a given index from an
// array.


(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(Selection, "propTypes", {
  children: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().func),
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().bool),
  initialSelectedItems: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().array.isRequired),
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().func),
  render: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().func)
});

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(Selection, "defaultProps", {
  initialSelectedItems: []
});



var removeAtIndex = function removeAtIndex(array, index) {
  var result = array.slice();
  result.splice(index, 1);
  return result;
};

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/deprecateFieldOnObject.js":
/*!****************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/deprecateFieldOnObject.js ***!
  \****************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "deprecateFieldOnObject": () => (/* binding */ deprecateFieldOnObject)
/* harmony export */ });
/* harmony import */ var _internal_warning__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../internal/warning */ "../../node_modules/carbon-components-react/es/internal/warning.js");
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

var didWarnAboutDeprecation = {};

function deprecateFieldOnObject(object, field, Component, message) {
  Object.defineProperty(object, field, {
    enumerable: true,
    get: function get() {
      if (!didWarnAboutDeprecation[field]) {
         true ? (0,_internal_warning__WEBPACK_IMPORTED_MODULE_0__.warning)(false, message || "The ".concat(field, " field has been deprecated on the ").concat(object.displayName, " object. ") + "Please import and use ".concat(Component.displayName || Component.name || 'the field', " directly.")) : 0;
        didWarnAboutDeprecation[field] = true;
      }

      return Component;
    }
  });
}



/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/environment.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/environment.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "canUseDOM": () => (/* binding */ canUseDOM)
/* harmony export */ });
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * Indicate whether current execution environment can access the DOM.
 *
 * @see https://github.com/facebook/fbjs/blob/4d1751311d3f67af2dcce2e40df8512a23c7b9c6/packages/fbjs/src/core/ExecutionEnvironment.js#L12
 */
var canUseDOM = !!(typeof window !== 'undefined' && window.document && window.document.createElement);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/focus/index.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/focus/index.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "focus": () => (/* binding */ focus)
/* harmony export */ });
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
function focus(elementOrRef) {
  var element = elementOrRef.current || elementOrRef;

  if (element && element.focus && document.activeElement !== element) {
    element.focus();
  }
}

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/keyboard/keys.js":
/*!*******************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/keyboard/keys.js ***!
  \*******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "ArrowDown": () => (/* binding */ ArrowDown),
/* harmony export */   "ArrowLeft": () => (/* binding */ ArrowLeft),
/* harmony export */   "ArrowRight": () => (/* binding */ ArrowRight),
/* harmony export */   "ArrowUp": () => (/* binding */ ArrowUp),
/* harmony export */   "Delete": () => (/* binding */ Delete),
/* harmony export */   "End": () => (/* binding */ End),
/* harmony export */   "Enter": () => (/* binding */ Enter),
/* harmony export */   "Escape": () => (/* binding */ Escape),
/* harmony export */   "Home": () => (/* binding */ Home),
/* harmony export */   "PageDown": () => (/* binding */ PageDown),
/* harmony export */   "PageUp": () => (/* binding */ PageUp),
/* harmony export */   "Space": () => (/* binding */ Space),
/* harmony export */   "Tab": () => (/* binding */ Tab)
/* harmony export */ });
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
var Tab = {
  key: 'Tab',
  which: 9,
  keyCode: 9
};
var Enter = {
  key: 'Enter',
  which: 13,
  keyCode: 13
};
var Escape = {
  key: ['Escape', // IE11 Escape
  'Esc'],
  which: 27,
  keyCode: 27
};
var Space = {
  key: ' ',
  which: 32,
  keyCode: 32
};
var PageUp = {
  key: 'PageUp',
  which: 33,
  keyCode: 33
};
var PageDown = {
  key: 'PageDown',
  which: 34,
  keyCode: 34
};
var End = {
  key: 'End',
  which: 35,
  keyCode: 35
};
var Home = {
  key: 'Home',
  which: 36,
  keyCode: 36
};
var ArrowLeft = {
  key: 'ArrowLeft',
  which: 37,
  keyCode: 37
};
var ArrowUp = {
  key: 'ArrowUp',
  which: 38,
  keyCode: 38
};
var ArrowRight = {
  key: 'ArrowRight',
  which: 39,
  keyCode: 39
};
var ArrowDown = {
  key: 'ArrowDown',
  which: 40,
  keyCode: 40
};
var Delete = {
  key: 'Delete',
  which: 8 || 0,
  keyCode: 8 || 0
};

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/keyboard/match.js":
/*!********************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/keyboard/match.js ***!
  \********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "getCharacterFor": () => (/* binding */ getCharacterFor),
/* harmony export */   "match": () => (/* binding */ match),
/* harmony export */   "matches": () => (/* binding */ matches)
/* harmony export */ });
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * @typedef Key
 * @property key {Array<string>|string}
 * @property which {number}
 * @property keyCode {number}
 */

/**
 * Check to see if at least one key code matches the key code of the
 * given event.
 *
 * @example
 * import * as keys from '../keys';
 * import { matches } from '../match';
 *
 * function handleOnKeyDown(event) {
 *   if (matches(event, [keys.Enter, keys.Space]) {
 *     // ...
 *   }
 * }
 *
 * @param {Event} event
 * @param {Array<Key>} keysToMatch
 * @returns {boolean}
 */
function matches(event, keysToMatch) {
  for (var i = 0; i < keysToMatch.length; i++) {
    if (match(event, keysToMatch[i])) {
      return true;
    }
  }

  return false;
}
/**
 * Check to see if the given key matches the corresponding keyboard event. Also
 * supports passing in the value directly if you can't used the given event.
 *
 * @example
 * import * as keys from '../keys';
 * import { matches } from '../match';
 *
 * function handleOnKeyDown(event) {
 *   if (match(event, keys.Enter) {
 *     // ...
 *   }
 * }
 *
 * @param {Event|number|string} eventOrCode
 * @param {Key} key
 * @returns {boolean}
 */

function match(eventOrCode) {
  var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      key = _ref.key,
      which = _ref.which,
      keyCode = _ref.keyCode;

  if (typeof eventOrCode === 'string') {
    return eventOrCode === key;
  }

  if (typeof eventOrCode === 'number') {
    return eventOrCode === which || eventOrCode === keyCode;
  }

  if (eventOrCode.key && Array.isArray(key)) {
    return key.indexOf(eventOrCode.key) !== -1;
  }

  return eventOrCode.key === key || eventOrCode.which === which || eventOrCode.keyCode === keyCode;
}
/**
 * Get a string character for a given event or event code (useful for synthetic
 * events)
 *
 * @param {Event|number} eventOrCode
 * @returns {string}
 */

function getCharacterFor(eventOrCode) {
  if (typeof eventOrCode === 'number') {
    return String.fromCharCode(eventOrCode);
  }

  return eventOrCode.key || String.fromCharCode(eventOrCode.which || eventOrCode.keyCode);
}

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/keyboard/navigation.js":
/*!*************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/keyboard/navigation.js ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "DOCUMENT_POSITION_BROAD_FOLLOWING": () => (/* binding */ DOCUMENT_POSITION_BROAD_FOLLOWING),
/* harmony export */   "DOCUMENT_POSITION_BROAD_PRECEDING": () => (/* binding */ DOCUMENT_POSITION_BROAD_PRECEDING),
/* harmony export */   "getNextIndex": () => (/* binding */ getNextIndex),
/* harmony export */   "selectorFocusable": () => (/* binding */ selectorFocusable),
/* harmony export */   "selectorTabbable": () => (/* binding */ selectorTabbable)
/* harmony export */ });
/* harmony import */ var _keys__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./keys */ "../../node_modules/carbon-components-react/es/internal/keyboard/keys.js");
/* harmony import */ var _match__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./match */ "../../node_modules/carbon-components-react/es/internal/keyboard/match.js");
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */


/**
 * Various utilities to help with a11y work
 */

/**
 * A "ring buffer" function that takes an array and depending on an ArrowRight
 * or ArrowLeft key input loops from last index to first or first index to last.
 *
 * @param {string} key - the left or right arrow keys
 * @param {number} index - the current index in a given array
 * @param {number} arrayLength - the total length of the array
 *
 * @example
 * 	getNextIndex(keyCodes.RIGHT, 0, 4)
 */

var getNextIndex = function getNextIndex(key, index, arrayLength) {
  if ((0,_match__WEBPACK_IMPORTED_MODULE_0__.match)(key, _keys__WEBPACK_IMPORTED_MODULE_1__.ArrowRight)) {
    return (index + 1) % arrayLength;
  }

  if ((0,_match__WEBPACK_IMPORTED_MODULE_0__.match)(key, _keys__WEBPACK_IMPORTED_MODULE_1__.ArrowLeft)) {
    return (index + arrayLength - 1) % arrayLength;
  }
};
/**
 * A flag `node.compareDocumentPosition(target)` returns,
 * that indicates `target` is located earlier than `node` in the document or `target` contains `node`.
 */

var DOCUMENT_POSITION_BROAD_PRECEDING = // Checks `typeof Node` for `react-docgen`
typeof Node !== 'undefined' && Node.DOCUMENT_POSITION_PRECEDING | Node.DOCUMENT_POSITION_CONTAINS;
/**
 * A flag `node.compareDocumentPosition(target)` returns,
 * that indicates `target` is located later than `node` in the document or `node` contains `target`.
 */

var DOCUMENT_POSITION_BROAD_FOLLOWING = // Checks `typeof Node` for `react-docgen`
typeof Node !== 'undefined' && Node.DOCUMENT_POSITION_FOLLOWING | Node.DOCUMENT_POSITION_CONTAINED_BY;
/**
 * CSS selector that selects major nodes that are sequential-focusable.
 */

var selectorTabbable = "\n  a[href], area[href], input:not([disabled]):not([tabindex='-1']),\n  button:not([disabled]):not([tabindex='-1']),select:not([disabled]):not([tabindex='-1']),\n  textarea:not([disabled]):not([tabindex='-1']),\n  iframe, object, embed, *[tabindex]:not([tabindex='-1']):not([disabled]), *[contenteditable=true]\n";
/**
 * CSS selector that selects major nodes that are click focusable
 */

var selectorFocusable = "\n  a[href], area[href], input:not([disabled]),\n  button:not([disabled]),select:not([disabled]),\n  textarea:not([disabled]),\n  iframe, object, embed, *[tabindex]:not([disabled]), *[contenteditable=true]\n";

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/useControllableState.js":
/*!**************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/useControllableState.js ***!
  \**************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "useControllableState": () => (/* binding */ useControllableState)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _warning__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./warning */ "../../node_modules/carbon-components-react/es/internal/warning.js");


/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */


/**
 * This custom hook simplifies the behavior of a component if it has state that
 * can be both controlled and uncontrolled. It functions identical to a
 * useState() hook and provides [state, setState] for you to use. You can use
 * the `onChange` argument to allow updates to the `state` to be communicated to
 * owners of controlled components.
 *
 * Note: this hook will warn if a component is switching from controlled to
 * uncontrolled, or vice-verse.
 *
 * @param {object} config
 * @param {string} config.name - the name of the custom component
 * @param {any} config.defaultValue - the default value used for the state. This will be
 * the fallback value used if `value` is not defined.
 * @param {Function} config.onChange - an optional function that is called when
 * the value of the state changes. This is useful for communicating to parents of
 * controlled components that the value is requesting to be changed.
 * @param {any} config.value - a controlled value. Omitting this means that the state is
 * uncontrolled
 * @returns {[any, Function]}
 */

function useControllableState(_ref) {
  var defaultValue = _ref.defaultValue,
      _ref$name = _ref.name,
      name = _ref$name === void 0 ? 'custom' : _ref$name,
      onChange = _ref.onChange,
      value = _ref.value;

  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(value !== null && value !== void 0 ? value : defaultValue),
      _useState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__["default"])(_useState, 2),
      state = _useState2[0],
      internalSetState = _useState2[1];

  var controlled = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(null);

  if (controlled.current === null) {
    controlled.current = value !== undefined;
  }

  function setState(stateOrUpdater) {
    var value = typeof stateOrUpdater === 'function' ? stateOrUpdater(state) : stateOrUpdater;

    if (controlled.current === false) {
      internalSetState(value);
    }

    if (onChange) {
      onChange(value);
    }
  }

  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(function () {
    var controlledValue = value !== undefined; // Uncontrolled -> Controlled
    // If the component prop is uncontrolled, the prop value should be undefined

    if (controlled.current === false && controlledValue) {
       true ? (0,_warning__WEBPACK_IMPORTED_MODULE_2__.warning)(false, 'A component is changing an uncontrolled %s component to be controlled. ' + 'This is likely caused by the value changing to a defined value ' + 'from undefined. Decide between using a controlled or uncontrolled ' + 'value for the lifetime of the component. ' + 'More info: https://reactjs.org/link/controlled-components', name) : 0;
    } // Controlled -> Uncontrolled
    // If the component prop is controlled, the prop value should be defined


    if (controlled.current === true && !controlledValue) {
       true ? (0,_warning__WEBPACK_IMPORTED_MODULE_2__.warning)(false, 'A component is changing a controlled %s component to be uncontrolled. ' + 'This is likely caused by the value changing to an undefined value ' + 'from a defined one. Decide between using a controlled or ' + 'uncontrolled value for the lifetime of the component. ' + 'More info: https://reactjs.org/link/controlled-components', name) : 0;
    }
  }, [name, value]);

  if (controlled.current === true) {
    return [value, setState];
  }

  return [state, setState];
}

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/useDelayedState.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/useDelayedState.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "useDelayedState": () => (/* binding */ useDelayedState)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_1__);


/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * `useDelayedState` mirrors `useState` but also allows you to add a delay to
 * when your state updates. You can provide a second argument to `setState`,
 * `delayMs`, which will be the time in milliseconds after which the state is
 * updated.
 *
 * This hook will clean up pending timers in `useEffect` and will cancel any
 * pending timers when a `setState` is called before the state is updated from
 * a previous call
 */

function useDelayedState(initialState) {
  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(initialState),
      _useState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__["default"])(_useState, 2),
      state = _useState2[0],
      setState = _useState2[1];

  var timeoutId = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(null); // We use `useCallback` to match the signature of React's `useState` which will
  // always return the same reference for the `setState` updater

  var setStateWithDelay = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(function (stateToSet) {
    var delayMs = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    clearTimeout(timeoutId.current);
    timeoutId.current = null;

    if (delayMs === 0) {
      setState(stateToSet);
      return;
    }

    timeoutId.current = setTimeout(function () {
      setState(stateToSet);
      timeoutId.current = null;
    }, delayMs);
  }, []);
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(function () {
    return function () {
      clearTimeout(timeoutId.current);
    };
  }, []);
  return [state, setStateWithDelay];
}

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/useEffectOnce.js":
/*!*******************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/useEffectOnce.js ***!
  \*******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "useEffectOnce": () => (/* binding */ useEffectOnce)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * A custom hook which will call the given callback exactly once when your
 * component is initially rendered and effects are first called
 *
 * @param {Function} callback
 */

function useEffectOnce(callback) {
  var savedCallback = (0,react__WEBPACK_IMPORTED_MODULE_0__.useRef)(callback);
  var effectGuard = (0,react__WEBPACK_IMPORTED_MODULE_0__.useRef)(false);
  (0,react__WEBPACK_IMPORTED_MODULE_0__.useEffect)(function () {
    savedCallback.current = callback;
  });
  (0,react__WEBPACK_IMPORTED_MODULE_0__.useEffect)(function () {
    if (effectGuard.current !== true) {
      effectGuard.current = true;
      savedCallback.current();
    }
  }, []);
}

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/useId.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/useId.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "useFallbackId": () => (/* binding */ useFallbackId),
/* harmony export */   "useId": () => (/* binding */ useId)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _tools_setupGetInstanceId__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../tools/setupGetInstanceId */ "../../node_modules/carbon-components-react/es/tools/setupGetInstanceId.js");
/* harmony import */ var _environment__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./environment */ "../../node_modules/carbon-components-react/es/internal/environment.js");


/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
// This file was heavily inspired by Reach UI and their work on their auto-id
// package
// https://github.com/reach/reach-ui/blob/86a046f54d53b6420e392b3fa56dd991d9d4e458/packages/auto-id/src/index.ts
//
// The problem that this solves is an id mismatch when auto-generating
// ids on both the server and the client. When using server-side rendering,
// there can be the chance of a mismatch between what the server renders and
// what the client renders when the id value is auto-generated.
//
// To get around this, we set the initial value of the `id` to `null` and then
// conditionally use `useLayoutEffect` on the client and `useEffect` on the
// server. On the client, `useLayoutEffect` will patch up the id to the correct
// value. On the server, `useEffect` will not run.
//
// This ensures that we won't encounter a mismatch in ids between server and
// client, at the cost of runtime patching of the id value in
// `useLayoutEffect`



var getId = (0,_tools_setupGetInstanceId__WEBPACK_IMPORTED_MODULE_2__["default"])();
var useIsomorphicLayoutEffect = _environment__WEBPACK_IMPORTED_MODULE_3__.canUseDOM ? react__WEBPACK_IMPORTED_MODULE_1__.useLayoutEffect : react__WEBPACK_IMPORTED_MODULE_1__.useEffect;
var serverHandoffCompleted = false;
/**
 * Generate a unique ID with an optional prefix prepended to it
 * @param {string} [prefix]
 * @returns {string}
 */

function useId() {
  var prefix = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'id';

  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(function () {
    if (serverHandoffCompleted) {
      return "".concat(prefix, "-").concat(getId());
    }

    return null;
  }),
      _useState2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__["default"])(_useState, 2),
      id = _useState2[0],
      setId = _useState2[1];

  useIsomorphicLayoutEffect(function () {
    if (id === null) {
      setId("".concat(prefix, "-").concat(getId()));
    }
  }, [getId]);
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(function () {
    if (serverHandoffCompleted === false) {
      serverHandoffCompleted = true;
    }
  }, []);
  return id;
}
/**
 * Generate a unique id if a given `id` is not provided
 * @param {string} id
 * @returns {string}
 */

function useFallbackId(id) {
  var fallback = useId();
  return id !== null && id !== void 0 ? id : fallback;
}

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/useIsomorphicEffect.js":
/*!*************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/useIsomorphicEffect.js ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
 // useLayoutEffect on the client, useEffect on the server

var useIsomorphicEffect = typeof window !== 'undefined' ? react__WEBPACK_IMPORTED_MODULE_0__.useLayoutEffect : react__WEBPACK_IMPORTED_MODULE_0__.useEffect;
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (useIsomorphicEffect);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/useMergedRefs.js":
/*!*******************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/useMergedRefs.js ***!
  \*******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "useMergedRefs": () => (/* binding */ useMergedRefs)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * Combine multiple refs into a single ref. This use useful when you have two
 * refs from both `React.forwardRef` and `useRef` that you would like to add to
 * the same node.
 *
 * @param {Array} refs
 * @returns {Function}
 */

function useMergedRefs(refs) {
  return (0,react__WEBPACK_IMPORTED_MODULE_0__.useCallback)(function (node) {
    refs.forEach(function (ref) {
      if (typeof ref === 'function') {
        ref(node);
      } else if (ref !== null && ref !== undefined) {
        ref.current = node;
      }
    }); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, refs);
}

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/useNoInteractiveChildren.js":
/*!******************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/useNoInteractiveChildren.js ***!
  \******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "getInteractiveContent": () => (/* binding */ getInteractiveContent),
/* harmony export */   "useNoInteractiveChildren": () => (/* binding */ useNoInteractiveChildren)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

function useNoInteractiveChildren(ref) {
  var message = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'component should have no interactive child nodes';

  if (true) {
    // eslint-disable-next-line react-hooks/rules-of-hooks
    (0,react__WEBPACK_IMPORTED_MODULE_0__.useEffect)(function () {
      var node = ref.current ? getInteractiveContent(ref.current) : false;

      if (node) {
        throw new Error("Error: ".concat(message, ".\n\nInstead found: ").concat(node.outerHTML));
      }
    });
  }
}
/**
 * Determines if a given DOM node has interactive content, or is itself
 * interactive. It returns the interactive node if one is found
 *
 * @param {HTMLElement} node
 * @returns {HTMLElement}
 */

function getInteractiveContent(node) {
  if (isFocusable(node)) {
    return node;
  }

  var _iterator = _createForOfIteratorHelper(node.childNodes),
      _step;

  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var childNode = _step.value;
      var interactiveNode = getInteractiveContent(childNode);

      if (interactiveNode) {
        return interactiveNode;
      }
    }
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }

  return null;
}
/**
 * Determines if the given element is focusable, or not
 *
 * @param {HTMLElement} element
 * @returns {boolean}
 * @see https://github.com/w3c/aria-practices/blob/0553bb51588ffa517506e2a1b2ca1422ed438c5f/examples/js/utils.js#L68
 */

function isFocusable(element) {
  if (element.tabIndex < 0) {
    return false;
  }

  if (element.disabled) {
    return false;
  }

  switch (element.nodeName) {
    case 'A':
      return !!element.href && element.rel !== 'ignore';

    case 'INPUT':
      return element.type !== 'hidden';

    case 'BUTTON':
    case 'SELECT':
    case 'TEXTAREA':
      return true;

    default:
      return false;
  }
}

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/useNormalizedInputProps.js":
/*!*****************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/useNormalizedInputProps.js ***!
  \*****************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "useNormalizedInputProps": () => (/* binding */ useNormalizedInputProps)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-10.js");
/* harmony import */ var _carbon_icons_react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @carbon/icons-react */ "../../node_modules/@carbon/icons-react/es/__generated__/bucket-29.js");
/* harmony import */ var carbon_components__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! carbon-components */ "webpack/sharing/consume/default/carbon-components/carbon-components");
/* harmony import */ var carbon_components__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(carbon_components__WEBPACK_IMPORTED_MODULE_1__);
/**
 * Copyright IBM Corp. 2021
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */



var prefix = carbon_components__WEBPACK_IMPORTED_MODULE_1__.settings.prefix;
/**
 * @typedef {object} InputProps
 * @property {string} id - The input's id
 * @property {boolean} readOnly - Whether the input should be readonly
 * @property {boolean} disabled - Whether the input should be disabled
 * @property {boolean} invalid - Whether the input should be marked as invalid
 * @property {string} invalidText - The validation message displayed in case the input is considered invalid
 * @property {boolean} warn - Whether the input should be in warning state
 * @property {string} warnText - The validation message displayed in case the input is in warning state
 */

/**
 * @typedef {object} NormalizedInputProps
 * @property {boolean} disabled - Whether the input is disabled
 * @property {boolean} invalid - Whether the input is invalid (takes precedence over warn)
 * @property {string} invalidId - The invalid message's id
 * @property {boolean} warn - Whether the input is in warning state
 * @property {string} warnId - The warning message's id
 * @property {React.ReactNode | null} validation – React node rendering the appropriate validation message (if any)
 * @property {React.ReactNode | null} icon – React node rendering the appropriate accompanying icon (if any)
 */

/**
 * Returns an object containing non-colliding props and additional, generated ones.
 * This hook ensures that only either "invalid" or "warn" is true but never both at
 * the same time. Regardless whether "invalid" or "warn", the appropriate validation
 * message is passed as "validation". If the input should be accompanied by an icon
 * (to visually represent a readonly, invalid or warning state), the appropriate icon
 * is passed as "icon".
 * It also ensure that neither "invalid", nor "warn", nor "disabled" are enabled when
 * "readonly" is passed as "readonly" takes precedence over these variants.
 *
 * @param {InputProps} props - The props passed to the component
 * @returns {NormalizedInputProps}
 */

function useNormalizedInputProps(_ref) {
  var id = _ref.id,
      readOnly = _ref.readOnly,
      disabled = _ref.disabled,
      invalid = _ref.invalid,
      invalidText = _ref.invalidText,
      warn = _ref.warn,
      warnText = _ref.warnText;
  var normalizedProps = {
    disabled: !readOnly && disabled,
    invalid: !readOnly && invalid,
    invalidId: "".concat(id, "-error-msg"),
    warn: !readOnly && !invalid && warn,
    warnId: "".concat(id, "-warn-msg"),
    validation: null,
    icon: null,
    helperId: "".concat(id, "-helper-text")
  };

  if (readOnly) {
    normalizedProps.icon = _carbon_icons_react__WEBPACK_IMPORTED_MODULE_2__.EditOff16;
  } else {
    if (normalizedProps.invalid) {
      normalizedProps.icon = _carbon_icons_react__WEBPACK_IMPORTED_MODULE_3__.WarningFilled16;
      normalizedProps.validation = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div", {
        className: "".concat(prefix, "--form-requirement"),
        id: normalizedProps.invalidId
      }, invalidText);
    } else if (normalizedProps.warn) {
      normalizedProps.icon = _carbon_icons_react__WEBPACK_IMPORTED_MODULE_3__.WarningAltFilled16;
      normalizedProps.validation = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement("div", {
        className: "".concat(prefix, "--form-requirement"),
        id: normalizedProps.warnId
      }, warnText);
    }
  }

  return normalizedProps;
}

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/usePrefix.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/usePrefix.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "PrefixContext": () => (/* binding */ PrefixContext),
/* harmony export */   "usePrefix": () => (/* binding */ usePrefix)
/* harmony export */ });
/* harmony import */ var carbon_components__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! carbon-components */ "webpack/sharing/consume/default/carbon-components/carbon-components");
/* harmony import */ var carbon_components__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(carbon_components__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_1__);
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */


var PrefixContext = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_1___default().createContext(carbon_components__WEBPACK_IMPORTED_MODULE_0__.settings.prefix);
function usePrefix() {
  return react__WEBPACK_IMPORTED_MODULE_1___default().useContext(PrefixContext);
}

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/warning.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/warning.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "warning": () => (/* binding */ warning)
/* harmony export */ });
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
var emptyFunction = function emptyFunction() {};

var warning =  true ? function warning(condition, format) {
  for (var _len = arguments.length, args = new Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
    args[_key - 2] = arguments[_key];
  }

  if (format === undefined) {
    throw new Error('`warning(condition, format, ...args)` requires a warning ' + 'format argument');
  }

  if (!condition) {
    var index = 0;
    var message = format.replace(/%s/g, function () {
      return args[index++];
    });
    console.warn('Warning: ' + message);
  }
} : 0;


/***/ }),

/***/ "../../node_modules/carbon-components-react/es/internal/wrapFocus.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/internal/wrapFocus.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__),
/* harmony export */   "elementOrParentIsFloatingMenu": () => (/* binding */ elementOrParentIsFloatingMenu)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/toConsumableArray */ "../../node_modules/@babel/runtime/helpers/esm/toConsumableArray.js");
/* harmony import */ var lodash_findlast__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! lodash.findlast */ "../../node_modules/lodash.findlast/index.js");
/* harmony import */ var lodash_findlast__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(lodash_findlast__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var carbon_components__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! carbon-components */ "webpack/sharing/consume/default/carbon-components/carbon-components");
/* harmony import */ var carbon_components__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(carbon_components__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _keyboard_navigation__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./keyboard/navigation */ "../../node_modules/carbon-components-react/es/internal/keyboard/navigation.js");


/**
 * Copyright IBM Corp. 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */



var prefix = carbon_components__WEBPACK_IMPORTED_MODULE_2__.settings.prefix;
/**
 * @param {Node} node A DOM node.
 * @param {string[]} selectorsFloatingMenus The CSS selectors that matches floating menus.
 * @returns {boolean} `true` of the given `node` is in a floating menu.
 */

function elementOrParentIsFloatingMenu(node) {
  var selectorsFloatingMenus = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];

  if (node && typeof node.closest === 'function') {
    var allSelectorsFloatingMenus = [".".concat(prefix, "--overflow-menu-options"), ".".concat(prefix, "--tooltip"), '.flatpickr-calendar'].concat((0,_babel_runtime_helpers_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__["default"])(selectorsFloatingMenus));
    return allSelectorsFloatingMenus.some(function (selector) {
      return node.closest(selector);
    });
  }
}
/**
 * Ensures the focus is kept in the given `modalNode`, implementing "focus-wrap" behavior.
 * @param {object} options The options.
 * @param {Node} options.bodyNode
 * @param {Node} options.startTrapNode The DOM node of the focus sentinel the is placed earlier next to `modalNode`.
 * @param {Node} options.endTrapNode The DOM node of the focus sentinel the is placed next to `modalNode`.
 * @param {Node} options.currentActiveNode The DOM node that has focus.
 * @param {Node} options.oldActiveNode The DOM node that previously had focus.
 * @param {Node} [options.selectorsFloatingMenus] The CSS selectors that matches floating menus.
 */


function wrapFocus(_ref) {
  var bodyNode = _ref.bodyNode,
      startTrapNode = _ref.startTrapNode,
      endTrapNode = _ref.endTrapNode,
      currentActiveNode = _ref.currentActiveNode,
      oldActiveNode = _ref.oldActiveNode,
      selectorsFloatingMenus = _ref.selectorsFloatingMenus;

  if (bodyNode && currentActiveNode && oldActiveNode && !bodyNode.contains(currentActiveNode) && !elementOrParentIsFloatingMenu(currentActiveNode, selectorsFloatingMenus)) {
    var comparisonResult = oldActiveNode.compareDocumentPosition(currentActiveNode);

    if (currentActiveNode === startTrapNode || comparisonResult & _keyboard_navigation__WEBPACK_IMPORTED_MODULE_3__.DOCUMENT_POSITION_BROAD_PRECEDING) {
      var tabbable = lodash_findlast__WEBPACK_IMPORTED_MODULE_1___default()(bodyNode.querySelectorAll(_keyboard_navigation__WEBPACK_IMPORTED_MODULE_3__.selectorTabbable), function (elem) {
        return Boolean(elem.offsetParent);
      });

      if (tabbable) {
        tabbable.focus();
      } else if (bodyNode !== oldActiveNode) {
        bodyNode.focus();
      }
    } else if (currentActiveNode === endTrapNode || comparisonResult & _keyboard_navigation__WEBPACK_IMPORTED_MODULE_3__.DOCUMENT_POSITION_BROAD_FOLLOWING) {
      var _tabbable = Array.prototype.find.call(bodyNode.querySelectorAll(_keyboard_navigation__WEBPACK_IMPORTED_MODULE_3__.selectorTabbable), function (elem) {
        return Boolean(elem.offsetParent);
      });

      if (_tabbable) {
        _tabbable.focus();
      } else if (bodyNode !== oldActiveNode) {
        bodyNode.focus();
      }
    }
  }
}


/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (wrapFocus);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/prop-types/deprecate.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/prop-types/deprecate.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ deprecate)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _internal_warning__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../internal/warning */ "../../node_modules/carbon-components-react/es/internal/warning.js");


function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

var didWarnAboutDeprecation = {};
function deprecate(propType, message) {
  function checker(props, propName, componentName) {
    if (props[propName] === undefined) {
      return;
    }

    if (!didWarnAboutDeprecation[componentName] || !didWarnAboutDeprecation[componentName][propName]) {
      didWarnAboutDeprecation[componentName] = _objectSpread(_objectSpread({}, didWarnAboutDeprecation[componentName]), {}, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])({}, propName, true));
       true ? (0,_internal_warning__WEBPACK_IMPORTED_MODULE_1__.warning)(false, message || "The prop `".concat(propName, "` has been deprecated for the ") + "".concat(componentName, " component. It will be removed in the next major ") + "release") : 0;
    }

    for (var _len = arguments.length, rest = new Array(_len > 3 ? _len - 3 : 0), _key = 3; _key < _len; _key++) {
      rest[_key - 3] = arguments[_key];
    }

    return propType.apply(void 0, [props, propName, componentName].concat(rest));
  }

  return checker;
}

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/prop-types/requiredIfGivenPropIsTruthy.js":
/*!***********************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/prop-types/requiredIfGivenPropIsTruthy.js ***!
  \***********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ requiredIfGivenPropIsTruthy)
/* harmony export */ });
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * @param {Function} name The name of the prop that must exist to validate
 * the current prop.
 * @param {Function} propType The original prop type checker.
 * @returns {Function} The new prop type checker for the current prop that
 * becomes required if the prop corresponding to the provided prop name exists.
 */
function requiredIfGivenPropIsTruthy(name, propType) {
  return function check(props, propName, componentName) {
    if ( true && props[name] == true && props[propName] == null) {
      return new Error("You must provide a value for `".concat(propName, "` in `").concat(componentName, "` if `").concat(name, "` exists."));
    }

    for (var _len = arguments.length, rest = new Array(_len > 3 ? _len - 3 : 0), _key = 3; _key < _len; _key++) {
      rest[_key - 3] = arguments[_key];
    }

    return propType.apply(void 0, [props, propName, componentName].concat(rest));
  };
}

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/prop-types/requiredIfValueExists.js":
/*!*****************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/prop-types/requiredIfValueExists.js ***!
  \*****************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ requiredIfValueExists)
/* harmony export */ });
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * @param {Function} propType The original prop type checker.
 * @returns {Function} The new prop type checker for `onChange` that makes it required if `value` exists and `readOnly` does not exist.
 */
function requiredIfValueExists(propType) {
  return function check(props, propName, componentName) {
    var onChange = props[propName],
        value = props.value,
        readOnly = props.readOnly;
    var exists = onChange !== undefined;
    var valueExists = value !== undefined;

    if ( true && !exists && valueExists && !readOnly) {
      return new Error("You provided a value prop to `".concat(componentName, "` without an `onChange` handler. ") + 'This will render a read-only field. ' + 'If the field should be mutable use `defaultValue`. Otherwise, set either `onChange` or `readOnly`.');
    }

    for (var _len = arguments.length, rest = new Array(_len > 3 ? _len - 3 : 0), _key = 3; _key < _len; _key++) {
      rest[_key - 3] = arguments[_key];
    }

    return propType.apply(void 0, [props, propName, componentName].concat(rest));
  };
}

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/prop-types/types.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/prop-types/types.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "ButtonKinds": () => (/* binding */ ButtonKinds)
/* harmony export */ });
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
var ButtonKinds = ['primary', 'secondary', 'danger', 'ghost', 'danger--primary', 'danger--ghost', 'danger--tertiary', 'tertiary'];

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/tools/createPropAdapter.js":
/*!********************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/tools/createPropAdapter.js ***!
  \********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "mapDownshiftProps": () => (/* binding */ mapDownshiftProps)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");


/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * Create an adapter that converts an object of props with potentially deprecated
 * prop names to the replacement prop names in a newer version. Useful for guarding
 * against breaking changes when a prop has been renamed
 *
 * @param {Array} spec - an array of options which specify a text or regex
 * matcher alongside a replacement if there is a match
 * @returns {Function}
 */
function createPropAdapter(spec) {
  // if props aren't passed in we should default the prop to empty object
  return function () {
    var input = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var output = {};
    Object.keys(input).forEach(function (key) {
      var match = spec.find(function (_ref) {
        var _ref2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref, 1),
            regex = _ref2[0];

        return key.match(regex);
      });

      if (match) {
        var _match = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__["default"])(match, 2),
            regex = _match[0],
            replacer = _match[1];

        output[key.replace(regex, replacer)] = input[key];
        return;
      }

      output[key] = input[key];
    });
    return output;
  };
}
/**
 * TODO: REMOVE IN v11
 * props staring with "default..." were changed to "initial..." in Downshift v3
 *
 * @see https://github.com/downshift-js/downshift/releases/tag/v3.0.0
 */


var mapDownshiftProps = createPropAdapter([[/^default/g, 'initial']]);


/***/ }),

/***/ "../../node_modules/carbon-components-react/es/tools/events.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/tools/events.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "composeEventHandlers": () => (/* binding */ composeEventHandlers)
/* harmony export */ });
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * Generic utility to compose event handlers so that consumers can supply their
 * own event listeners on table components. The default heuristic here is to
 * iterate through the given functions until `preventDefault` is called on the
 * given event.
 *
 * @param {Array<Function>} fns array of functions to apply to the event
 * @returns {Function}
 */
var composeEventHandlers = function composeEventHandlers(fns) {
  return function (event) {
    for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }

    for (var i = 0; i < fns.length; i++) {
      if (event.defaultPrevented) {
        break;
      }

      if (typeof fns[i] === 'function') {
        fns[i].apply(fns, [event].concat(args));
      }
    }
  };
};

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/tools/mergeRefs.js":
/*!************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/tools/mergeRefs.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * @param {...Ref<Element>} refs List of React refs to merge.
 * @returns {Ref<Element>} Merged React ref.
 */
var mergeRefs = function mergeRefs() {
  for (var _len = arguments.length, refs = new Array(_len), _key = 0; _key < _len; _key++) {
    refs[_key] = arguments[_key];
  }

  return function (el) {
    refs.forEach(function (ref) {
      // https://github.com/facebook/react/issues/13029#issuecomment-410002316
      if (typeof ref === 'function') {
        ref(el);
      } else if (Object(ref) === ref) {
        ref.current = el;
      }
    });
  };
};

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (mergeRefs);

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/tools/setupGetInstanceId.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/tools/setupGetInstanceId.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ setupGetInstanceId)
/* harmony export */ });
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * Generic utility to initialize a method that will return a unique instance id
 * for a component.
 */
function setupGetInstanceId() {
  var instanceId = 0;
  return function getInstanceId() {
    return ++instanceId;
  };
}

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/tools/toggleClass.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/tools/toggleClass.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ toggleClass)
/* harmony export */ });
/**
 * Adds or removes a CSS class to an element.
 * @param {Element} element An element.
 * @param {string} name A CSS class name.
 * @param {boolean} add `true` to add the given CSS class to given the element. Otherwise to remove.
 */
function toggleClass(element, name, add) {
  if (element.classList.contains(name) === !add) {
    element.classList[add ? 'add' : 'remove'](name);
  }
}

/***/ }),

/***/ "../../node_modules/carbon-components-react/es/tools/uniqueId.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/carbon-components-react/es/tools/uniqueId.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ uniqueId)
/* harmony export */ });
/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
var lastId = 0;
function uniqueId() {
  var prefix = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'id';
  lastId++;
  return "".concat(prefix).concat(lastId);
}

/***/ }),

/***/ "../../node_modules/carbon-components-react/node_modules/downshift/dist/downshift.esm.js":
/*!***********************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/node_modules/downshift/dist/downshift.esm.js ***!
  \***********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__),
/* harmony export */   "resetIdCounter": () => (/* binding */ resetIdCounter),
/* harmony export */   "useCombobox": () => (/* binding */ useCombobox),
/* harmony export */   "useMultipleSelection": () => (/* binding */ useMultipleSelection),
/* harmony export */   "useSelect": () => (/* binding */ useSelect)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/esm/objectWithoutPropertiesLoose */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutPropertiesLoose.js");
/* harmony import */ var _babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/esm/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/esm/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/esm/inheritsLoose */ "../../node_modules/@babel/runtime/helpers/esm/inheritsLoose.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_7__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var react_is__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! react-is */ "../../node_modules/carbon-components-react/node_modules/downshift/node_modules/react-is/index.js");
/* harmony import */ var compute_scroll_into_view__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! compute-scroll-into-view */ "../../node_modules/compute-scroll-into-view/dist/index.module.js");









var idCounter = 0;
/**
 * Accepts a parameter and returns it if it's a function
 * or a noop function if it's not. This allows us to
 * accept a callback, but not worry about it if it's not
 * passed.
 * @param {Function} cb the callback
 * @return {Function} a function
 */

function cbToCb(cb) {
  return typeof cb === 'function' ? cb : noop;
}

function noop() {}
/**
 * Scroll node into view if necessary
 * @param {HTMLElement} node the element that should scroll into view
 * @param {HTMLElement} menuNode the menu element of the component
 */


function scrollIntoView(node, menuNode) {
  if (node === null) {
    return;
  }

  var actions = (0,compute_scroll_into_view__WEBPACK_IMPORTED_MODULE_6__["default"])(node, {
    boundary: menuNode,
    block: 'nearest',
    scrollMode: 'if-needed'
  });
  actions.forEach(function (_ref) {
    var el = _ref.el,
        top = _ref.top,
        left = _ref.left;
    el.scrollTop = top;
    el.scrollLeft = left;
  });
}
/**
 * @param {HTMLElement} parent the parent node
 * @param {HTMLElement} child the child node
 * @return {Boolean} whether the parent is the child or the child is in the parent
 */


function isOrContainsNode(parent, child) {
  return parent === child || parent.contains && parent.contains(child);
}
/**
 * Simple debounce implementation. Will call the given
 * function once after the time given has passed since
 * it was last called.
 * @param {Function} fn the function to call after the time
 * @param {Number} time the time to wait
 * @return {Function} the debounced function
 */


function debounce(fn, time) {
  var timeoutId;

  function cancel() {
    if (timeoutId) {
      clearTimeout(timeoutId);
    }
  }

  function wrapper() {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    cancel();
    timeoutId = setTimeout(function () {
      timeoutId = null;
      fn.apply(void 0, args);
    }, time);
  }

  wrapper.cancel = cancel;
  return wrapper;
}
/**
 * This is intended to be used to compose event handlers.
 * They are executed in order until one of them sets
 * `event.preventDownshiftDefault = true`.
 * @param {...Function} fns the event handler functions
 * @return {Function} the event handler to add to an element
 */


function callAllEventHandlers() {
  for (var _len2 = arguments.length, fns = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
    fns[_key2] = arguments[_key2];
  }

  return function (event) {
    for (var _len3 = arguments.length, args = new Array(_len3 > 1 ? _len3 - 1 : 0), _key3 = 1; _key3 < _len3; _key3++) {
      args[_key3 - 1] = arguments[_key3];
    }

    return fns.some(function (fn) {
      if (fn) {
        fn.apply(void 0, [event].concat(args));
      }

      return event.preventDownshiftDefault || event.hasOwnProperty('nativeEvent') && event.nativeEvent.preventDownshiftDefault;
    });
  };
}

function handleRefs() {
  for (var _len4 = arguments.length, refs = new Array(_len4), _key4 = 0; _key4 < _len4; _key4++) {
    refs[_key4] = arguments[_key4];
  }

  return function (node) {
    refs.forEach(function (ref) {
      if (typeof ref === 'function') {
        ref(node);
      } else if (ref) {
        ref.current = node;
      }
    });
  };
}
/**
 * This generates a unique ID for an instance of Downshift
 * @return {String} the unique ID
 */


function generateId() {
  return String(idCounter++);
}
/**
 * Resets idCounter to 0. Used for SSR.
 */


function resetIdCounter() {
  idCounter = 0;
}
/**
 * Default implementation for status message. Only added when menu is open.
 * Will specift if there are results in the list, and if so, how many,
 * and what keys are relevant.
 *
 * @param {Object} param the downshift state and other relevant properties
 * @return {String} the a11y status message
 */


function getA11yStatusMessage(_ref2) {
  var isOpen = _ref2.isOpen,
      resultCount = _ref2.resultCount,
      previousResultCount = _ref2.previousResultCount;

  if (!isOpen) {
    return '';
  }

  if (!resultCount) {
    return 'No results are available.';
  }

  if (resultCount !== previousResultCount) {
    return resultCount + " result" + (resultCount === 1 ? ' is' : 's are') + " available, use up and down arrow keys to navigate. Press Enter key to select.";
  }

  return '';
}
/**
 * Takes an argument and if it's an array, returns the first item in the array
 * otherwise returns the argument
 * @param {*} arg the maybe-array
 * @param {*} defaultValue the value if arg is falsey not defined
 * @return {*} the arg or it's first item
 */


function unwrapArray(arg, defaultValue) {
  arg = Array.isArray(arg) ?
  /* istanbul ignore next (preact) */
  arg[0] : arg;

  if (!arg && defaultValue) {
    return defaultValue;
  } else {
    return arg;
  }
}
/**
 * @param {Object} element (P)react element
 * @return {Boolean} whether it's a DOM element
 */


function isDOMElement(element) {
  // then we assume this is react
  return typeof element.type === 'string';
}
/**
 * @param {Object} element (P)react element
 * @return {Object} the props
 */


function getElementProps(element) {
  return element.props;
}
/**
 * Throws a helpful error message for required properties. Useful
 * to be used as a default in destructuring or object params.
 * @param {String} fnName the function name
 * @param {String} propName the prop name
 */


function requiredProp(fnName, propName) {
  // eslint-disable-next-line no-console
  console.error("The property \"" + propName + "\" is required in \"" + fnName + "\"");
}

var stateKeys = ['highlightedIndex', 'inputValue', 'isOpen', 'selectedItem', 'type'];
/**
 * @param {Object} state the state object
 * @return {Object} state that is relevant to downshift
 */

function pickState(state) {
  if (state === void 0) {
    state = {};
  }

  var result = {};
  stateKeys.forEach(function (k) {
    if (state.hasOwnProperty(k)) {
      result[k] = state[k];
    }
  });
  return result;
}
/**
 * This will perform a shallow merge of the given state object
 * with the state coming from props
 * (for the controlled component scenario)
 * This is used in state updater functions so they're referencing
 * the right state regardless of where it comes from.
 *
 * @param {Object} state The state of the component/hook.
 * @param {Object} props The props that may contain controlled values.
 * @returns {Object} The merged controlled state.
 */


function getState(state, props) {
  return Object.keys(state).reduce(function (prevState, key) {
    prevState[key] = isControlledProp(props, key) ? props[key] : state[key];
    return prevState;
  }, {});
}
/**
 * This determines whether a prop is a "controlled prop" meaning it is
 * state which is controlled by the outside of this component rather
 * than within this component.
 *
 * @param {Object} props The props that may contain controlled values.
 * @param {String} key the key to check
 * @return {Boolean} whether it is a controlled controlled prop
 */


function isControlledProp(props, key) {
  return props[key] !== undefined;
}
/**
 * Normalizes the 'key' property of a KeyboardEvent in IE/Edge
 * @param {Object} event a keyboardEvent object
 * @return {String} keyboard key
 */


function normalizeArrowKey(event) {
  var key = event.key,
      keyCode = event.keyCode;
  /* istanbul ignore next (ie) */

  if (keyCode >= 37 && keyCode <= 40 && key.indexOf('Arrow') !== 0) {
    return "Arrow" + key;
  }

  return key;
}
/**
 * Simple check if the value passed is object literal
 * @param {*} obj any things
 * @return {Boolean} whether it's object literal
 */


function isPlainObject(obj) {
  return Object.prototype.toString.call(obj) === '[object Object]';
}
/**
 * Returns the new index in the list, in a circular way. If next value is out of bonds from the total,
 * it will wrap to either 0 or itemCount - 1.
 *
 * @param {number} moveAmount Number of positions to move. Negative to move backwards, positive forwards.
 * @param {number} baseIndex The initial position to move from.
 * @param {number} itemCount The total number of items.
 * @param {Function} getItemNodeFromIndex Used to check if item is disabled.
 * @param {boolean} circular Specify if navigation is circular. Default is true.
 * @returns {number} The new index after the move.
 */


function getNextWrappingIndex(moveAmount, baseIndex, itemCount, getItemNodeFromIndex, circular) {
  if (circular === void 0) {
    circular = true;
  }

  var itemsLastIndex = itemCount - 1;

  if (typeof baseIndex !== 'number' || baseIndex < 0 || baseIndex >= itemCount) {
    baseIndex = moveAmount > 0 ? -1 : itemsLastIndex + 1;
  }

  var newIndex = baseIndex + moveAmount;

  if (newIndex < 0) {
    newIndex = circular ? itemsLastIndex : 0;
  } else if (newIndex > itemsLastIndex) {
    newIndex = circular ? 0 : itemsLastIndex;
  }

  var nonDisabledNewIndex = getNextNonDisabledIndex(moveAmount, newIndex, itemCount, getItemNodeFromIndex, circular);
  return nonDisabledNewIndex === -1 ? baseIndex : nonDisabledNewIndex;
}
/**
 * Returns the next index in the list of an item that is not disabled.
 *
 * @param {number} moveAmount Number of positions to move. Negative to move backwards, positive forwards.
 * @param {number} baseIndex The initial position to move from.
 * @param {number} itemCount The total number of items.
 * @param {Function} getItemNodeFromIndex Used to check if item is disabled.
 * @param {boolean} circular Specify if navigation is circular. Default is true.
 * @returns {number} The new index. Returns baseIndex if item is not disabled. Returns next non-disabled item otherwise. If no non-disabled found it will return -1.
 */


function getNextNonDisabledIndex(moveAmount, baseIndex, itemCount, getItemNodeFromIndex, circular) {
  var currentElementNode = getItemNodeFromIndex(baseIndex);

  if (!currentElementNode || !currentElementNode.hasAttribute('disabled')) {
    return baseIndex;
  }

  if (moveAmount > 0) {
    for (var index = baseIndex + 1; index < itemCount; index++) {
      if (!getItemNodeFromIndex(index).hasAttribute('disabled')) {
        return index;
      }
    }
  } else {
    for (var _index = baseIndex - 1; _index >= 0; _index--) {
      if (!getItemNodeFromIndex(_index).hasAttribute('disabled')) {
        return _index;
      }
    }
  }

  if (circular) {
    return moveAmount > 0 ? getNextNonDisabledIndex(1, 0, itemCount, getItemNodeFromIndex, false) : getNextNonDisabledIndex(-1, itemCount - 1, itemCount, getItemNodeFromIndex, false);
  }

  return -1;
}
/**
 * Checks if event target is within the downshift elements.
 *
 * @param {EventTarget} target Target to check.
 * @param {HTMLElement[]} downshiftElements The elements that form downshift (list, toggle button etc).
 * @param {Document} document The document.
 * @param {boolean} checkActiveElement Whether to also check activeElement.
 *
 * @returns {boolean} Whether or not the target is within downshift elements.
 */


function targetWithinDownshift(target, downshiftElements, document, checkActiveElement) {
  if (checkActiveElement === void 0) {
    checkActiveElement = true;
  }

  return downshiftElements.some(function (contextNode) {
    return contextNode && (isOrContainsNode(contextNode, target) || checkActiveElement && isOrContainsNode(contextNode, document.activeElement));
  });
}

var cleanupStatus = debounce(function () {
  getStatusDiv().textContent = '';
}, 500);
/**
 * @param {String} status the status message
 * @param {Object} documentProp document passed by the user.
 */

function setStatus(status, documentProp) {
  var div = getStatusDiv(documentProp);

  if (!status) {
    return;
  }

  div.textContent = status;
  cleanupStatus();
}
/**
 * Get the status node or create it if it does not already exist.
 * @param {Object} documentProp document passed by the user.
 * @return {HTMLElement} the status node.
 */


function getStatusDiv(documentProp) {
  if (documentProp === void 0) {
    documentProp = document;
  }

  var statusDiv = documentProp.getElementById('a11y-status-message');

  if (statusDiv) {
    return statusDiv;
  }

  statusDiv = documentProp.createElement('div');
  statusDiv.setAttribute('id', 'a11y-status-message');
  statusDiv.setAttribute('role', 'status');
  statusDiv.setAttribute('aria-live', 'polite');
  statusDiv.setAttribute('aria-relevant', 'additions text');
  Object.assign(statusDiv.style, {
    border: '0',
    clip: 'rect(0 0 0 0)',
    height: '1px',
    margin: '-1px',
    overflow: 'hidden',
    padding: '0',
    position: 'absolute',
    width: '1px'
  });
  documentProp.body.appendChild(statusDiv);
  return statusDiv;
}

var unknown =  true ? '__autocomplete_unknown__' : 0;
var mouseUp =  true ? '__autocomplete_mouseup__' : 0;
var itemMouseEnter =  true ? '__autocomplete_item_mouseenter__' : 0;
var keyDownArrowUp =  true ? '__autocomplete_keydown_arrow_up__' : 0;
var keyDownArrowDown =  true ? '__autocomplete_keydown_arrow_down__' : 0;
var keyDownEscape =  true ? '__autocomplete_keydown_escape__' : 0;
var keyDownEnter =  true ? '__autocomplete_keydown_enter__' : 0;
var keyDownHome =  true ? '__autocomplete_keydown_home__' : 0;
var keyDownEnd =  true ? '__autocomplete_keydown_end__' : 0;
var clickItem =  true ? '__autocomplete_click_item__' : 0;
var blurInput =  true ? '__autocomplete_blur_input__' : 0;
var changeInput =  true ? '__autocomplete_change_input__' : 0;
var keyDownSpaceButton =  true ? '__autocomplete_keydown_space_button__' : 0;
var clickButton =  true ? '__autocomplete_click_button__' : 0;
var blurButton =  true ? '__autocomplete_blur_button__' : 0;
var controlledPropUpdatedSelectedItem =  true ? '__autocomplete_controlled_prop_updated_selected_item__' : 0;
var touchEnd =  true ? '__autocomplete_touchend__' : 0;

var stateChangeTypes = /*#__PURE__*/Object.freeze({
  __proto__: null,
  unknown: unknown,
  mouseUp: mouseUp,
  itemMouseEnter: itemMouseEnter,
  keyDownArrowUp: keyDownArrowUp,
  keyDownArrowDown: keyDownArrowDown,
  keyDownEscape: keyDownEscape,
  keyDownEnter: keyDownEnter,
  keyDownHome: keyDownHome,
  keyDownEnd: keyDownEnd,
  clickItem: clickItem,
  blurInput: blurInput,
  changeInput: changeInput,
  keyDownSpaceButton: keyDownSpaceButton,
  clickButton: clickButton,
  blurButton: blurButton,
  controlledPropUpdatedSelectedItem: controlledPropUpdatedSelectedItem,
  touchEnd: touchEnd
});

var Downshift =
/*#__PURE__*/
function () {
  var Downshift =
  /*#__PURE__*/
  function (_Component) {
    (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_3__["default"])(Downshift, _Component);

    function Downshift(_props) {
      var _this = _Component.call(this, _props) || this;

      _this.id = _this.props.id || "downshift-" + generateId();
      _this.menuId = _this.props.menuId || _this.id + "-menu";
      _this.labelId = _this.props.labelId || _this.id + "-label";
      _this.inputId = _this.props.inputId || _this.id + "-input";

      _this.getItemId = _this.props.getItemId || function (index) {
        return _this.id + "-item-" + index;
      };

      _this.input = null;
      _this.items = [];
      _this.itemCount = null;
      _this.previousResultCount = 0;
      _this.timeoutIds = [];

      _this.internalSetTimeout = function (fn, time) {
        var id = setTimeout(function () {
          _this.timeoutIds = _this.timeoutIds.filter(function (i) {
            return i !== id;
          });
          fn();
        }, time);

        _this.timeoutIds.push(id);
      };

      _this.setItemCount = function (count) {
        _this.itemCount = count;
      };

      _this.unsetItemCount = function () {
        _this.itemCount = null;
      };

      _this.setHighlightedIndex = function (highlightedIndex, otherStateToSet) {
        if (highlightedIndex === void 0) {
          highlightedIndex = _this.props.defaultHighlightedIndex;
        }

        if (otherStateToSet === void 0) {
          otherStateToSet = {};
        }

        otherStateToSet = pickState(otherStateToSet);

        _this.internalSetState((0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          highlightedIndex: highlightedIndex
        }, otherStateToSet));
      };

      _this.clearSelection = function (cb) {
        _this.internalSetState({
          selectedItem: null,
          inputValue: '',
          highlightedIndex: _this.props.defaultHighlightedIndex,
          isOpen: _this.props.defaultIsOpen
        }, cb);
      };

      _this.selectItem = function (item, otherStateToSet, cb) {
        otherStateToSet = pickState(otherStateToSet);

        _this.internalSetState((0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          isOpen: _this.props.defaultIsOpen,
          highlightedIndex: _this.props.defaultHighlightedIndex,
          selectedItem: item,
          inputValue: _this.props.itemToString(item)
        }, otherStateToSet), cb);
      };

      _this.selectItemAtIndex = function (itemIndex, otherStateToSet, cb) {
        var item = _this.items[itemIndex];

        if (item == null) {
          return;
        }

        _this.selectItem(item, otherStateToSet, cb);
      };

      _this.selectHighlightedItem = function (otherStateToSet, cb) {
        return _this.selectItemAtIndex(_this.getState().highlightedIndex, otherStateToSet, cb);
      };

      _this.internalSetState = function (stateToSet, cb) {
        var isItemSelected, onChangeArg;
        var onStateChangeArg = {};
        var isStateToSetFunction = typeof stateToSet === 'function'; // we want to call `onInputValueChange` before the `setState` call
        // so someone controlling the `inputValue` state gets notified of
        // the input change as soon as possible. This avoids issues with
        // preserving the cursor position.
        // See https://github.com/downshift-js/downshift/issues/217 for more info.

        if (!isStateToSetFunction && stateToSet.hasOwnProperty('inputValue')) {
          _this.props.onInputValueChange(stateToSet.inputValue, (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, _this.getStateAndHelpers(), {}, stateToSet));
        }

        return _this.setState(function (state) {
          state = _this.getState(state);
          var newStateToSet = isStateToSetFunction ? stateToSet(state) : stateToSet; // Your own function that could modify the state that will be set.

          newStateToSet = _this.props.stateReducer(state, newStateToSet); // checks if an item is selected, regardless of if it's different from
          // what was selected before
          // used to determine if onSelect and onChange callbacks should be called

          isItemSelected = newStateToSet.hasOwnProperty('selectedItem'); // this keeps track of the object we want to call with setState

          var nextState = {}; // this is just used to tell whether the state changed

          var nextFullState = {}; // we need to call on change if the outside world is controlling any of our state
          // and we're trying to update that state. OR if the selection has changed and we're
          // trying to update the selection

          if (isItemSelected && newStateToSet.selectedItem !== state.selectedItem) {
            onChangeArg = newStateToSet.selectedItem;
          }

          newStateToSet.type = newStateToSet.type || unknown;
          Object.keys(newStateToSet).forEach(function (key) {
            // onStateChangeArg should only have the state that is
            // actually changing
            if (state[key] !== newStateToSet[key]) {
              onStateChangeArg[key] = newStateToSet[key];
            } // the type is useful for the onStateChangeArg
            // but we don't actually want to set it in internal state.
            // this is an undocumented feature for now... Not all internalSetState
            // calls support it and I'm not certain we want them to yet.
            // But it enables users controlling the isOpen state to know when
            // the isOpen state changes due to mouseup events which is quite handy.


            if (key === 'type') {
              return;
            }

            nextFullState[key] = newStateToSet[key]; // if it's coming from props, then we don't care to set it internally

            if (!isControlledProp(_this.props, key)) {
              nextState[key] = newStateToSet[key];
            }
          }); // if stateToSet is a function, then we weren't able to call onInputValueChange
          // earlier, so we'll call it now that we know what the inputValue state will be.

          if (isStateToSetFunction && newStateToSet.hasOwnProperty('inputValue')) {
            _this.props.onInputValueChange(newStateToSet.inputValue, (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, _this.getStateAndHelpers(), {}, newStateToSet));
          }

          return nextState;
        }, function () {
          // call the provided callback if it's a function
          cbToCb(cb)(); // only call the onStateChange and onChange callbacks if
          // we have relevant information to pass them.

          var hasMoreStateThanType = Object.keys(onStateChangeArg).length > 1;

          if (hasMoreStateThanType) {
            _this.props.onStateChange(onStateChangeArg, _this.getStateAndHelpers());
          }

          if (isItemSelected) {
            _this.props.onSelect(stateToSet.selectedItem, _this.getStateAndHelpers());
          }

          if (onChangeArg !== undefined) {
            _this.props.onChange(onChangeArg, _this.getStateAndHelpers());
          } // this is currently undocumented and therefore subject to change
          // We'll try to not break it, but just be warned.


          _this.props.onUserAction(onStateChangeArg, _this.getStateAndHelpers());
        });
      };

      _this.rootRef = function (node) {
        return _this._rootNode = node;
      };

      _this.getRootProps = function (_temp, _temp2) {
        var _extends2;

        var _ref = _temp === void 0 ? {} : _temp,
            _ref$refKey = _ref.refKey,
            refKey = _ref$refKey === void 0 ? 'ref' : _ref$refKey,
            ref = _ref.ref,
            rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref, ["refKey", "ref"]);

        var _ref2 = _temp2 === void 0 ? {} : _temp2,
            _ref2$suppressRefErro = _ref2.suppressRefError,
            suppressRefError = _ref2$suppressRefErro === void 0 ? false : _ref2$suppressRefErro;

        // this is used in the render to know whether the user has called getRootProps.
        // It uses that to know whether to apply the props automatically
        _this.getRootProps.called = true;
        _this.getRootProps.refKey = refKey;
        _this.getRootProps.suppressRefError = suppressRefError;

        var _this$getState = _this.getState(),
            isOpen = _this$getState.isOpen;

        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends2 = {}, _extends2[refKey] = handleRefs(ref, _this.rootRef), _extends2.role = 'combobox', _extends2['aria-expanded'] = isOpen, _extends2['aria-haspopup'] = 'listbox', _extends2['aria-owns'] = isOpen ? _this.menuId : null, _extends2['aria-labelledby'] = _this.labelId, _extends2), rest);
      };

      _this.keyDownHandlers = {
        ArrowDown: function ArrowDown(event) {
          var _this2 = this;

          event.preventDefault();

          if (this.getState().isOpen) {
            var amount = event.shiftKey ? 5 : 1;
            this.moveHighlightedIndex(amount, {
              type: keyDownArrowDown
            });
          } else {
            this.internalSetState({
              isOpen: true,
              type: keyDownArrowDown
            }, function () {
              var itemCount = _this2.getItemCount();

              if (itemCount > 0) {
                var _this2$getState = _this2.getState(),
                    highlightedIndex = _this2$getState.highlightedIndex;

                var nextHighlightedIndex = getNextWrappingIndex(1, highlightedIndex, itemCount, function (index) {
                  return _this2.getItemNodeFromIndex(index);
                });

                _this2.setHighlightedIndex(nextHighlightedIndex, {
                  type: keyDownArrowDown
                });
              }
            });
          }
        },
        ArrowUp: function ArrowUp(event) {
          var _this3 = this;

          event.preventDefault();

          if (this.getState().isOpen) {
            var amount = event.shiftKey ? -5 : -1;
            this.moveHighlightedIndex(amount, {
              type: keyDownArrowUp
            });
          } else {
            this.internalSetState({
              isOpen: true,
              type: keyDownArrowUp
            }, function () {
              var itemCount = _this3.getItemCount();

              if (itemCount > 0) {
                var _this3$getState = _this3.getState(),
                    highlightedIndex = _this3$getState.highlightedIndex;

                var nextHighlightedIndex = getNextWrappingIndex(-1, highlightedIndex, itemCount, function (index) {
                  return _this3.getItemNodeFromIndex(index);
                });

                _this3.setHighlightedIndex(nextHighlightedIndex, {
                  type: keyDownArrowUp
                });
              }
            });
          }
        },
        Enter: function Enter(event) {
          if (event.which === 229) {
            return;
          }

          var _this$getState2 = this.getState(),
              isOpen = _this$getState2.isOpen,
              highlightedIndex = _this$getState2.highlightedIndex;

          if (isOpen && highlightedIndex != null) {
            event.preventDefault();
            var item = this.items[highlightedIndex];
            var itemNode = this.getItemNodeFromIndex(highlightedIndex);

            if (item == null || itemNode && itemNode.hasAttribute('disabled')) {
              return;
            }

            this.selectHighlightedItem({
              type: keyDownEnter
            });
          }
        },
        Escape: function Escape(event) {
          event.preventDefault();
          this.reset({
            type: keyDownEscape,
            selectedItem: null,
            inputValue: ''
          });
        }
      };
      _this.buttonKeyDownHandlers = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, _this.keyDownHandlers, {
        ' ': function _(event) {
          event.preventDefault();
          this.toggleMenu({
            type: keyDownSpaceButton
          });
        }
      });
      _this.inputKeyDownHandlers = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, _this.keyDownHandlers, {
        Home: function Home(event) {
          var _this4 = this;

          event.preventDefault();
          var itemCount = this.getItemCount();

          var _this$getState3 = this.getState(),
              isOpen = _this$getState3.isOpen;

          if (itemCount <= 0 || !isOpen) {
            return;
          } // get next non-disabled starting downwards from 0 if that's disabled.


          var newHighlightedIndex = getNextNonDisabledIndex(1, 0, itemCount, function (index) {
            return _this4.getItemNodeFromIndex(index);
          }, false);
          this.setHighlightedIndex(newHighlightedIndex, {
            type: keyDownHome
          });
        },
        End: function End(event) {
          var _this5 = this;

          event.preventDefault();
          var itemCount = this.getItemCount();

          var _this$getState4 = this.getState(),
              isOpen = _this$getState4.isOpen;

          if (itemCount <= 0 || !isOpen) {
            return;
          } // get next non-disabled starting upwards from last index if that's disabled.


          var newHighlightedIndex = getNextNonDisabledIndex(-1, itemCount - 1, itemCount, function (index) {
            return _this5.getItemNodeFromIndex(index);
          }, false);
          this.setHighlightedIndex(newHighlightedIndex, {
            type: keyDownEnd
          });
        }
      });

      _this.getToggleButtonProps = function (_temp3) {
        var _ref3 = _temp3 === void 0 ? {} : _temp3,
            onClick = _ref3.onClick,
            onPress = _ref3.onPress,
            onKeyDown = _ref3.onKeyDown,
            onKeyUp = _ref3.onKeyUp,
            onBlur = _ref3.onBlur,
            rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref3, ["onClick", "onPress", "onKeyDown", "onKeyUp", "onBlur"]);

        var _this$getState5 = _this.getState(),
            isOpen = _this$getState5.isOpen;

        var enabledEventHandlers = {
          onClick: callAllEventHandlers(onClick, _this.buttonHandleClick),
          onKeyDown: callAllEventHandlers(onKeyDown, _this.buttonHandleKeyDown),
          onKeyUp: callAllEventHandlers(onKeyUp, _this.buttonHandleKeyUp),
          onBlur: callAllEventHandlers(onBlur, _this.buttonHandleBlur)
        };
        var eventHandlers = rest.disabled ? {} : enabledEventHandlers;
        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          type: 'button',
          role: 'button',
          'aria-label': isOpen ? 'close menu' : 'open menu',
          'aria-haspopup': true,
          'data-toggle': true
        }, eventHandlers, {}, rest);
      };

      _this.buttonHandleKeyUp = function (event) {
        // Prevent click event from emitting in Firefox
        event.preventDefault();
      };

      _this.buttonHandleKeyDown = function (event) {
        var key = normalizeArrowKey(event);

        if (_this.buttonKeyDownHandlers[key]) {
          _this.buttonKeyDownHandlers[key].call((0,_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this), event);
        }
      };

      _this.buttonHandleClick = function (event) {
        event.preventDefault(); // handle odd case for Safari and Firefox which
        // don't give the button the focus properly.

        /* istanbul ignore if (can't reasonably test this) */

        if ( _this.props.environment.document.activeElement === _this.props.environment.document.body) {
          event.target.focus();
        } // to simplify testing components that use downshift, we'll not wrap this in a setTimeout
        // if the NODE_ENV is test. With the proper build system, this should be dead code eliminated
        // when building for production and should therefore have no impact on production code.


        if (false) {} else {
          // Ensure that toggle of menu occurs after the potential blur event in iOS
          _this.internalSetTimeout(function () {
            return _this.toggleMenu({
              type: clickButton
            });
          });
        }
      };

      _this.buttonHandleBlur = function (event) {
        var blurTarget = event.target; // Save blur target for comparison with activeElement later
        // Need setTimeout, so that when the user presses Tab, the activeElement is the next focused element, not body element

        _this.internalSetTimeout(function () {
          if (!_this.isMouseDown && (_this.props.environment.document.activeElement == null || _this.props.environment.document.activeElement.id !== _this.inputId) && _this.props.environment.document.activeElement !== blurTarget // Do nothing if we refocus the same element again (to solve issue in Safari on iOS)
          ) {
              _this.reset({
                type: blurButton
              });
            }
        });
      };

      _this.getLabelProps = function (props) {
        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          htmlFor: _this.inputId,
          id: _this.labelId
        }, props);
      };

      _this.getInputProps = function (_temp4) {
        var _ref4 = _temp4 === void 0 ? {} : _temp4,
            onKeyDown = _ref4.onKeyDown,
            onBlur = _ref4.onBlur,
            onChange = _ref4.onChange,
            onInput = _ref4.onInput,
            onChangeText = _ref4.onChangeText,
            rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref4, ["onKeyDown", "onBlur", "onChange", "onInput", "onChangeText"]);

        var onChangeKey;
        var eventHandlers = {};
        /* istanbul ignore next (preact) */

        onChangeKey = 'onChange';

        var _this$getState6 = _this.getState(),
            inputValue = _this$getState6.inputValue,
            isOpen = _this$getState6.isOpen,
            highlightedIndex = _this$getState6.highlightedIndex;

        if (!rest.disabled) {
          var _eventHandlers;

          eventHandlers = (_eventHandlers = {}, _eventHandlers[onChangeKey] = callAllEventHandlers(onChange, onInput, _this.inputHandleChange), _eventHandlers.onKeyDown = callAllEventHandlers(onKeyDown, _this.inputHandleKeyDown), _eventHandlers.onBlur = callAllEventHandlers(onBlur, _this.inputHandleBlur), _eventHandlers);
        }
        /* istanbul ignore if (react-native) */


        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          'aria-autocomplete': 'list',
          'aria-activedescendant': isOpen && typeof highlightedIndex === 'number' && highlightedIndex >= 0 ? _this.getItemId(highlightedIndex) : null,
          'aria-controls': isOpen ? _this.menuId : null,
          'aria-labelledby': _this.labelId,
          // https://developer.mozilla.org/en-US/docs/Web/Security/Securing_your_site/Turning_off_form_autocompletion
          // revert back since autocomplete="nope" is ignored on latest Chrome and Opera
          autoComplete: 'off',
          value: inputValue,
          id: _this.inputId
        }, eventHandlers, {}, rest);
      };

      _this.inputHandleKeyDown = function (event) {
        var key = normalizeArrowKey(event);

        if (key && _this.inputKeyDownHandlers[key]) {
          _this.inputKeyDownHandlers[key].call((0,_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this), event);
        }
      };

      _this.inputHandleChange = function (event) {
        _this.internalSetState({
          type: changeInput,
          isOpen: true,
          inputValue: event.target.value,
          highlightedIndex: _this.props.defaultHighlightedIndex
        });
      };

      _this.inputHandleBlur = function () {
        // Need setTimeout, so that when the user presses Tab, the activeElement is the next focused element, not the body element
        _this.internalSetTimeout(function () {
          var downshiftButtonIsActive = _this.props.environment.document && !!_this.props.environment.document.activeElement && !!_this.props.environment.document.activeElement.dataset && _this.props.environment.document.activeElement.dataset.toggle && _this._rootNode && _this._rootNode.contains(_this.props.environment.document.activeElement);

          if (!_this.isMouseDown && !downshiftButtonIsActive) {
            _this.reset({
              type: blurInput
            });
          }
        });
      };

      _this.menuRef = function (node) {
        _this._menuNode = node;
      };

      _this.getMenuProps = function (_temp5, _temp6) {
        var _extends3;

        var _ref5 = _temp5 === void 0 ? {} : _temp5,
            _ref5$refKey = _ref5.refKey,
            refKey = _ref5$refKey === void 0 ? 'ref' : _ref5$refKey,
            ref = _ref5.ref,
            props = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref5, ["refKey", "ref"]);

        var _ref6 = _temp6 === void 0 ? {} : _temp6,
            _ref6$suppressRefErro = _ref6.suppressRefError,
            suppressRefError = _ref6$suppressRefErro === void 0 ? false : _ref6$suppressRefErro;

        _this.getMenuProps.called = true;
        _this.getMenuProps.refKey = refKey;
        _this.getMenuProps.suppressRefError = suppressRefError;
        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends3 = {}, _extends3[refKey] = handleRefs(ref, _this.menuRef), _extends3.role = 'listbox', _extends3['aria-labelledby'] = props && props['aria-label'] ? null : _this.labelId, _extends3.id = _this.menuId, _extends3), props);
      };

      _this.getItemProps = function (_temp7) {
        var _enabledEventHandlers;

        var _ref7 = _temp7 === void 0 ? {} : _temp7,
            onMouseMove = _ref7.onMouseMove,
            onMouseDown = _ref7.onMouseDown,
            onClick = _ref7.onClick,
            onPress = _ref7.onPress,
            index = _ref7.index,
            _ref7$item = _ref7.item,
            item = _ref7$item === void 0 ?  false ?
        /* istanbul ignore next */
        0 : requiredProp('getItemProps', 'item') : _ref7$item,
            rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref7, ["onMouseMove", "onMouseDown", "onClick", "onPress", "index", "item"]);

        if (index === undefined) {
          _this.items.push(item);

          index = _this.items.indexOf(item);
        } else {
          _this.items[index] = item;
        }

        var onSelectKey = 'onClick';
        var customClickHandler = onClick;
        var enabledEventHandlers = (_enabledEventHandlers = {
          // onMouseMove is used over onMouseEnter here. onMouseMove
          // is only triggered on actual mouse movement while onMouseEnter
          // can fire on DOM changes, interrupting keyboard navigation
          onMouseMove: callAllEventHandlers(onMouseMove, function () {
            if (index === _this.getState().highlightedIndex) {
              return;
            }

            _this.setHighlightedIndex(index, {
              type: itemMouseEnter
            }); // We never want to manually scroll when changing state based
            // on `onMouseMove` because we will be moving the element out
            // from under the user which is currently scrolling/moving the
            // cursor


            _this.avoidScrolling = true;

            _this.internalSetTimeout(function () {
              return _this.avoidScrolling = false;
            }, 250);
          }),
          onMouseDown: callAllEventHandlers(onMouseDown, function (event) {
            // This prevents the activeElement from being changed
            // to the item so it can remain with the current activeElement
            // which is a more common use case.
            event.preventDefault();
          })
        }, _enabledEventHandlers[onSelectKey] = callAllEventHandlers(customClickHandler, function () {
          _this.selectItemAtIndex(index, {
            type: clickItem
          });
        }), _enabledEventHandlers); // Passing down the onMouseDown handler to prevent redirect
        // of the activeElement if clicking on disabled items

        var eventHandlers = rest.disabled ? {
          onMouseDown: enabledEventHandlers.onMouseDown
        } : enabledEventHandlers;
        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          id: _this.getItemId(index),
          role: 'option',
          'aria-selected': _this.getState().highlightedIndex === index
        }, eventHandlers, {}, rest);
      };

      _this.clearItems = function () {
        _this.items = [];
      };

      _this.reset = function (otherStateToSet, cb) {
        if (otherStateToSet === void 0) {
          otherStateToSet = {};
        }

        otherStateToSet = pickState(otherStateToSet);

        _this.internalSetState(function (_ref8) {
          var selectedItem = _ref8.selectedItem;
          return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
            isOpen: _this.props.defaultIsOpen,
            highlightedIndex: _this.props.defaultHighlightedIndex,
            inputValue: _this.props.itemToString(selectedItem)
          }, otherStateToSet);
        }, cb);
      };

      _this.toggleMenu = function (otherStateToSet, cb) {
        if (otherStateToSet === void 0) {
          otherStateToSet = {};
        }

        otherStateToSet = pickState(otherStateToSet);

        _this.internalSetState(function (_ref9) {
          var isOpen = _ref9.isOpen;
          return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
            isOpen: !isOpen
          }, isOpen && {
            highlightedIndex: _this.props.defaultHighlightedIndex
          }, {}, otherStateToSet);
        }, function () {
          var _this$getState7 = _this.getState(),
              isOpen = _this$getState7.isOpen,
              highlightedIndex = _this$getState7.highlightedIndex;

          if (isOpen) {
            if (_this.getItemCount() > 0 && typeof highlightedIndex === 'number') {
              _this.setHighlightedIndex(highlightedIndex, otherStateToSet);
            }
          }

          cbToCb(cb)();
        });
      };

      _this.openMenu = function (cb) {
        _this.internalSetState({
          isOpen: true
        }, cb);
      };

      _this.closeMenu = function (cb) {
        _this.internalSetState({
          isOpen: false
        }, cb);
      };

      _this.updateStatus = debounce(function () {
        var state = _this.getState();

        var item = _this.items[state.highlightedIndex];

        var resultCount = _this.getItemCount();

        var status = _this.props.getA11yStatusMessage((0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          itemToString: _this.props.itemToString,
          previousResultCount: _this.previousResultCount,
          resultCount: resultCount,
          highlightedItem: item
        }, state));

        _this.previousResultCount = resultCount;
        setStatus(status, _this.props.environment.document);
      }, 200);

      // fancy destructuring + defaults + aliases
      // this basically says each value of state should either be set to
      // the initial value or the default value if the initial value is not provided
      var _this$props = _this.props,
          defaultHighlightedIndex = _this$props.defaultHighlightedIndex,
          _this$props$initialHi = _this$props.initialHighlightedIndex,
          _highlightedIndex = _this$props$initialHi === void 0 ? defaultHighlightedIndex : _this$props$initialHi,
          defaultIsOpen = _this$props.defaultIsOpen,
          _this$props$initialIs = _this$props.initialIsOpen,
          _isOpen = _this$props$initialIs === void 0 ? defaultIsOpen : _this$props$initialIs,
          _this$props$initialIn = _this$props.initialInputValue,
          _inputValue = _this$props$initialIn === void 0 ? '' : _this$props$initialIn,
          _this$props$initialSe = _this$props.initialSelectedItem,
          _selectedItem = _this$props$initialSe === void 0 ? null : _this$props$initialSe;

      var _state = _this.getState({
        highlightedIndex: _highlightedIndex,
        isOpen: _isOpen,
        inputValue: _inputValue,
        selectedItem: _selectedItem
      });

      if (_state.selectedItem != null && _this.props.initialInputValue === undefined) {
        _state.inputValue = _this.props.itemToString(_state.selectedItem);
      }

      _this.state = _state;
      return _this;
    }

    var _proto = Downshift.prototype;

    /**
     * Clear all running timeouts
     */
    _proto.internalClearTimeouts = function internalClearTimeouts() {
      this.timeoutIds.forEach(function (id) {
        clearTimeout(id);
      });
      this.timeoutIds = [];
    }
    /**
     * Gets the state based on internal state or props
     * If a state value is passed via props, then that
     * is the value given, otherwise it's retrieved from
     * stateToMerge
     *
     * @param {Object} stateToMerge defaults to this.state
     * @return {Object} the state
     */
    ;

    _proto.getState = function getState$1(stateToMerge) {
      if (stateToMerge === void 0) {
        stateToMerge = this.state;
      }

      return getState(stateToMerge, this.props);
    };

    _proto.getItemCount = function getItemCount() {
      // things read better this way. They're in priority order:
      // 1. `this.itemCount`
      // 2. `this.props.itemCount`
      // 3. `this.items.length`
      var itemCount = this.items.length;

      if (this.itemCount != null) {
        itemCount = this.itemCount;
      } else if (this.props.itemCount !== undefined) {
        itemCount = this.props.itemCount;
      }

      return itemCount;
    };

    _proto.getItemNodeFromIndex = function getItemNodeFromIndex(index) {
      return this.props.environment.document.getElementById(this.getItemId(index));
    };

    _proto.scrollHighlightedItemIntoView = function scrollHighlightedItemIntoView() {
      /* istanbul ignore else (react-native) */
      {
        var node = this.getItemNodeFromIndex(this.getState().highlightedIndex);
        this.props.scrollIntoView(node, this._menuNode);
      }
    };

    _proto.moveHighlightedIndex = function moveHighlightedIndex(amount, otherStateToSet) {
      var _this6 = this;

      var itemCount = this.getItemCount();

      var _this$getState8 = this.getState(),
          highlightedIndex = _this$getState8.highlightedIndex;

      if (itemCount > 0) {
        var nextHighlightedIndex = getNextWrappingIndex(amount, highlightedIndex, itemCount, function (index) {
          return _this6.getItemNodeFromIndex(index);
        });
        this.setHighlightedIndex(nextHighlightedIndex, otherStateToSet);
      }
    };

    _proto.getStateAndHelpers = function getStateAndHelpers() {
      var _this$getState9 = this.getState(),
          highlightedIndex = _this$getState9.highlightedIndex,
          inputValue = _this$getState9.inputValue,
          selectedItem = _this$getState9.selectedItem,
          isOpen = _this$getState9.isOpen;

      var itemToString = this.props.itemToString;
      var id = this.id;
      var getRootProps = this.getRootProps,
          getToggleButtonProps = this.getToggleButtonProps,
          getLabelProps = this.getLabelProps,
          getMenuProps = this.getMenuProps,
          getInputProps = this.getInputProps,
          getItemProps = this.getItemProps,
          openMenu = this.openMenu,
          closeMenu = this.closeMenu,
          toggleMenu = this.toggleMenu,
          selectItem = this.selectItem,
          selectItemAtIndex = this.selectItemAtIndex,
          selectHighlightedItem = this.selectHighlightedItem,
          setHighlightedIndex = this.setHighlightedIndex,
          clearSelection = this.clearSelection,
          clearItems = this.clearItems,
          reset = this.reset,
          setItemCount = this.setItemCount,
          unsetItemCount = this.unsetItemCount,
          setState = this.internalSetState;
      return {
        // prop getters
        getRootProps: getRootProps,
        getToggleButtonProps: getToggleButtonProps,
        getLabelProps: getLabelProps,
        getMenuProps: getMenuProps,
        getInputProps: getInputProps,
        getItemProps: getItemProps,
        // actions
        reset: reset,
        openMenu: openMenu,
        closeMenu: closeMenu,
        toggleMenu: toggleMenu,
        selectItem: selectItem,
        selectItemAtIndex: selectItemAtIndex,
        selectHighlightedItem: selectHighlightedItem,
        setHighlightedIndex: setHighlightedIndex,
        clearSelection: clearSelection,
        clearItems: clearItems,
        setItemCount: setItemCount,
        unsetItemCount: unsetItemCount,
        setState: setState,
        // props
        itemToString: itemToString,
        // derived
        id: id,
        // state
        highlightedIndex: highlightedIndex,
        inputValue: inputValue,
        isOpen: isOpen,
        selectedItem: selectedItem
      };
    } //////////////////////////// ROOT
    ;

    _proto.componentDidMount = function componentDidMount() {
      var _this7 = this;

      /* istanbul ignore if (react-native) */
      if ( true && this.getMenuProps.called && !this.getMenuProps.suppressRefError) {
        validateGetMenuPropsCalledCorrectly(this._menuNode, this.getMenuProps);
      }
      /* istanbul ignore if (react-native) */


      {
        // this.isMouseDown helps us track whether the mouse is currently held down.
        // This is useful when the user clicks on an item in the list, but holds the mouse
        // down long enough for the list to disappear (because the blur event fires on the input)
        // this.isMouseDown is used in the blur handler on the input to determine whether the blur event should
        // trigger hiding the menu.
        var onMouseDown = function () {
          _this7.isMouseDown = true;
        };

        var onMouseUp = function (event) {
          _this7.isMouseDown = false; // if the target element or the activeElement is within a downshift node
          // then we don't want to reset downshift

          var contextWithinDownshift = targetWithinDownshift(event.target, [_this7._rootNode, _this7._menuNode], _this7.props.environment.document);

          if (!contextWithinDownshift && _this7.getState().isOpen) {
            _this7.reset({
              type: mouseUp
            }, function () {
              return _this7.props.onOuterClick(_this7.getStateAndHelpers());
            });
          }
        }; // Touching an element in iOS gives focus and hover states, but touching out of
        // the element will remove hover, and persist the focus state, resulting in the
        // blur event not being triggered.
        // this.isTouchMove helps us track whether the user is tapping or swiping on a touch screen.
        // If the user taps outside of Downshift, the component should be reset,
        // but not if the user is swiping


        var onTouchStart = function () {
          _this7.isTouchMove = false;
        };

        var onTouchMove = function () {
          _this7.isTouchMove = true;
        };

        var onTouchEnd = function (event) {
          var contextWithinDownshift = targetWithinDownshift(event.target, [_this7._rootNode, _this7._menuNode], _this7.props.environment.document, false);

          if (!_this7.isTouchMove && !contextWithinDownshift && _this7.getState().isOpen) {
            _this7.reset({
              type: touchEnd
            }, function () {
              return _this7.props.onOuterClick(_this7.getStateAndHelpers());
            });
          }
        };

        var environment = this.props.environment;
        environment.addEventListener('mousedown', onMouseDown);
        environment.addEventListener('mouseup', onMouseUp);
        environment.addEventListener('touchstart', onTouchStart);
        environment.addEventListener('touchmove', onTouchMove);
        environment.addEventListener('touchend', onTouchEnd);

        this.cleanup = function () {
          _this7.internalClearTimeouts();

          _this7.updateStatus.cancel();

          environment.removeEventListener('mousedown', onMouseDown);
          environment.removeEventListener('mouseup', onMouseUp);
          environment.removeEventListener('touchstart', onTouchStart);
          environment.removeEventListener('touchmove', onTouchMove);
          environment.removeEventListener('touchend', onTouchEnd);
        };
      }
    };

    _proto.shouldScroll = function shouldScroll(prevState, prevProps) {
      var _ref10 = this.props.highlightedIndex === undefined ? this.getState() : this.props,
          currentHighlightedIndex = _ref10.highlightedIndex;

      var _ref11 = prevProps.highlightedIndex === undefined ? prevState : prevProps,
          prevHighlightedIndex = _ref11.highlightedIndex;

      var scrollWhenOpen = currentHighlightedIndex && this.getState().isOpen && !prevState.isOpen;
      return scrollWhenOpen || currentHighlightedIndex !== prevHighlightedIndex;
    };

    _proto.componentDidUpdate = function componentDidUpdate(prevProps, prevState) {
      if (true) {
        validateControlledUnchanged(prevProps, this.props);
        /* istanbul ignore if (react-native) */

        if ( this.getMenuProps.called && !this.getMenuProps.suppressRefError) {
          validateGetMenuPropsCalledCorrectly(this._menuNode, this.getMenuProps);
        }
      }

      if (isControlledProp(this.props, 'selectedItem') && this.props.selectedItemChanged(prevProps.selectedItem, this.props.selectedItem)) {
        this.internalSetState({
          type: controlledPropUpdatedSelectedItem,
          inputValue: this.props.itemToString(this.props.selectedItem)
        });
      }

      if (!this.avoidScrolling && this.shouldScroll(prevState, prevProps)) {
        this.scrollHighlightedItemIntoView();
      }
      /* istanbul ignore else (react-native) */


      this.updateStatus();
    };

    _proto.componentWillUnmount = function componentWillUnmount() {
      this.cleanup(); // avoids memory leak
    };

    _proto.render = function render() {
      var children = unwrapArray(this.props.children, noop); // because the items are rerendered every time we call the children
      // we clear this out each render and it will be populated again as
      // getItemProps is called.

      this.clearItems(); // we reset this so we know whether the user calls getRootProps during
      // this render. If they do then we don't need to do anything,
      // if they don't then we need to clone the element they return and
      // apply the props for them.

      this.getRootProps.called = false;
      this.getRootProps.refKey = undefined;
      this.getRootProps.suppressRefError = undefined; // we do something similar for getMenuProps

      this.getMenuProps.called = false;
      this.getMenuProps.refKey = undefined;
      this.getMenuProps.suppressRefError = undefined; // we do something similar for getLabelProps

      this.getLabelProps.called = false; // and something similar for getInputProps

      this.getInputProps.called = false;
      var element = unwrapArray(children(this.getStateAndHelpers()));

      if (!element) {
        return null;
      }

      if (this.getRootProps.called || this.props.suppressRefError) {
        if ( true && !this.getRootProps.suppressRefError && !this.props.suppressRefError) {
          validateGetRootPropsCalledCorrectly(element, this.getRootProps);
        }

        return element;
      } else if (isDOMElement(element)) {
        // they didn't apply the root props, but we can clone
        // this and apply the props ourselves
        return (0,react__WEBPACK_IMPORTED_MODULE_4__.cloneElement)(element, this.getRootProps(getElementProps(element)));
      }
      /* istanbul ignore else */


      if (true) {
        // they didn't apply the root props, but they need to
        // otherwise we can't query around the autocomplete
        throw new Error('downshift: If you return a non-DOM element, you must apply the getRootProps function');
      }
      /* istanbul ignore next */


      return undefined;
    };

    return Downshift;
  }(react__WEBPACK_IMPORTED_MODULE_4__.Component);

  Downshift.defaultProps = {
    defaultHighlightedIndex: null,
    defaultIsOpen: false,
    getA11yStatusMessage: getA11yStatusMessage,
    itemToString: function itemToString(i) {
      if (i == null) {
        return '';
      }

      if ( true && isPlainObject(i) && !i.hasOwnProperty('toString')) {
        // eslint-disable-next-line no-console
        console.warn('downshift: An object was passed to the default implementation of `itemToString`. You should probably provide your own `itemToString` implementation. Please refer to the `itemToString` API documentation.', 'The object that was passed:', i);
      }

      return String(i);
    },
    onStateChange: noop,
    onInputValueChange: noop,
    onUserAction: noop,
    onChange: noop,
    onSelect: noop,
    onOuterClick: noop,
    selectedItemChanged: function selectedItemChanged(prevItem, item) {
      return prevItem !== item;
    },
    environment: typeof window === 'undefined'
    /* istanbul ignore next (ssr) */
    ? {} : window,
    stateReducer: function stateReducer(state, stateToSet) {
      return stateToSet;
    },
    suppressRefError: false,
    scrollIntoView: scrollIntoView
  };
  Downshift.stateChangeTypes = stateChangeTypes;
  return Downshift;
}();

 true ? Downshift.propTypes = {
  children: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  defaultHighlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  defaultIsOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  initialHighlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  initialSelectedItem: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
  initialInputValue: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  initialIsOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  getA11yStatusMessage: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  itemToString: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onSelect: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onStateChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onInputValueChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onUserAction: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onOuterClick: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  selectedItemChanged: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  stateReducer: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  itemCount: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  id: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  environment: prop_types__WEBPACK_IMPORTED_MODULE_7___default().shape({
    addEventListener: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    removeEventListener: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    document: prop_types__WEBPACK_IMPORTED_MODULE_7___default().shape({
      getElementById: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
      activeElement: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
      body: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any)
    })
  }),
  suppressRefError: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  scrollIntoView: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  // things we keep in state for uncontrolled components
  // but can accept as props for controlled components

  /* eslint-disable react/no-unused-prop-types */
  selectedItem: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
  isOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  inputValue: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  highlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  labelId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  inputId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  menuId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  getItemId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func)
  /* eslint-enable react/no-unused-prop-types */

} : 0;

function validateGetMenuPropsCalledCorrectly(node, _ref12) {
  var refKey = _ref12.refKey;

  if (!node) {
    // eslint-disable-next-line no-console
    console.error("downshift: The ref prop \"" + refKey + "\" from getMenuProps was not applied correctly on your menu element.");
  }
}

function validateGetRootPropsCalledCorrectly(element, _ref13) {
  var refKey = _ref13.refKey;
  var refKeySpecified = refKey !== 'ref';
  var isComposite = !isDOMElement(element);

  if (isComposite && !refKeySpecified && !(0,react_is__WEBPACK_IMPORTED_MODULE_5__.isForwardRef)(element)) {
    // eslint-disable-next-line no-console
    console.error('downshift: You returned a non-DOM element. You must specify a refKey in getRootProps');
  } else if (!isComposite && refKeySpecified) {
    // eslint-disable-next-line no-console
    console.error("downshift: You returned a DOM element. You should not specify a refKey in getRootProps. You specified \"" + refKey + "\"");
  }

  if (!(0,react_is__WEBPACK_IMPORTED_MODULE_5__.isForwardRef)(element) && !getElementProps(element)[refKey]) {
    // eslint-disable-next-line no-console
    console.error("downshift: You must apply the ref prop \"" + refKey + "\" from getRootProps onto your root element.");
  }
}

function validateControlledUnchanged(prevProps, nextProps) {
  var warningDescription = "This prop should not switch from controlled to uncontrolled (or vice versa). Decide between using a controlled or uncontrolled Downshift element for the lifetime of the component. More info: https://github.com/downshift-js/downshift#control-props";
  ['selectedItem', 'isOpen', 'inputValue', 'highlightedIndex'].forEach(function (propKey) {
    if (prevProps[propKey] !== undefined && nextProps[propKey] === undefined) {
      // eslint-disable-next-line no-console
      console.error("downshift: A component has changed the controlled prop \"" + propKey + "\" to be uncontrolled. " + warningDescription);
    } else if (prevProps[propKey] === undefined && nextProps[propKey] !== undefined) {
      // eslint-disable-next-line no-console
      console.error("downshift: A component has changed the uncontrolled prop \"" + propKey + "\" to be controlled. " + warningDescription);
    }
  });
}

var dropdownDefaultStateValues = {
  highlightedIndex: -1,
  isOpen: false,
  selectedItem: null,
  inputValue: ''
};

function callOnChangeProps(action, state, newState) {
  var props = action.props,
      type = action.type;
  var changes = {};
  Object.keys(state).forEach(function (key) {
    invokeOnChangeHandler(key, props, state, newState);

    if (newState[key] !== state[key]) {
      changes[key] = newState[key];
    }
  });

  if (props.onStateChange && Object.keys(changes).length) {
    props.onStateChange((0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
      type: type
    }, changes));
  }
}

function invokeOnChangeHandler(key, props, state, newState) {
  var handler = "on" + capitalizeString(key) + "Change";

  if (props[handler] && newState[key] !== undefined && newState[key] !== state[key]) {
    props[handler](newState);
  }
}
/**
 * Default state reducer that returns the changes.
 *
 * @param {Object} s state.
 * @param {Object} a action with changes.
 * @returns {Object} changes.
 */


function stateReducer(s, a) {
  return a.changes;
}
/**
 * Returns a message to be added to aria-live region when item is selected.
 *
 * @param {Object} selectionParameters Parameters required to build the message.
 * @returns {string} The a11y message.
 */


function getA11ySelectionMessage(selectionParameters) {
  var selectedItem = selectionParameters.selectedItem,
      itemToStringLocal = selectionParameters.itemToString;
  return selectedItem ? itemToStringLocal(selectedItem) + " has been selected." : '';
}
/**
 * Debounced call for updating the a11y message.
 */


var updateA11yStatus = debounce(function (getA11yMessage, document) {
  setStatus(getA11yMessage(), document);
}, 200);
function getElementIds(_ref) {
  var id = _ref.id,
      labelId = _ref.labelId,
      menuId = _ref.menuId,
      getItemId = _ref.getItemId,
      toggleButtonId = _ref.toggleButtonId;
  var uniqueId = id === undefined ? "downshift-" + generateId() : id;
  return {
    labelId: labelId || uniqueId + "-label",
    menuId: menuId || uniqueId + "-menu",
    getItemId: getItemId || function (index) {
      return uniqueId + "-item-" + index;
    },
    toggleButtonId: toggleButtonId || uniqueId + "-toggle-button"
  };
}
function getItemIndex(index, item, items) {
  if (index !== undefined) {
    return index;
  }

  if (items.length === 0) {
    return -1;
  }

  return items.indexOf(item);
}

function itemToString(item) {
  return item ? String(item) : '';
}

function getPropTypesValidator(caller, propTypes) {
  // istanbul ignore next
  return function (options) {
    if (options === void 0) {
      options = {};
    }

    Object.keys(propTypes).forEach(function (key) {
      prop_types__WEBPACK_IMPORTED_MODULE_7___default().checkPropTypes(propTypes, options, key, caller.name);
    });
  };
}
function isAcceptedCharacterKey(key) {
  return /^\S{1}$/.test(key);
}
function capitalizeString(string) {
  return "" + string.slice(0, 1).toUpperCase() + string.slice(1);
}
/**
 * Computes the controlled state using a the previous state, props,
 * two reducers, one from downshift and an optional one from the user.
 * Also calls the onChange handlers for state values that have changed.
 *
 * @param {Function} reducer Reducer function from downshift.
 * @param {Object} initialState Initial state of the hook.
 * @param {Object} props The hook props.
 * @returns {Array} An array with the state and an action dispatcher.
 */

function useControlledState(reducer, initialState, props) {
  var _useState = (0,react__WEBPACK_IMPORTED_MODULE_4__.useState)(initialState),
      uncontrolledState = _useState[0],
      setState = _useState[1];

  var state = getState(uncontrolledState, props);

  var dispatch = function (action) {
    var stateReducerFromProps = action.props.stateReducer;
    var changes = reducer(state, action);
    var newState = stateReducerFromProps(state, (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, action, {
      changes: changes
    }));
    callOnChangeProps(action, state, newState);
    setState(newState);
  };

  return [getState(state, props), function dispatchWithProps(action) {
    return dispatch((0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
      props: props
    }, action));
  }];
}
var defaultProps = {
  itemToString: itemToString,
  stateReducer: stateReducer,
  getA11ySelectionMessage: getA11ySelectionMessage,
  scrollIntoView: scrollIntoView,
  circularNavigation: false,
  environment: typeof window === 'undefined'
  /* istanbul ignore next (ssr) */
  ? {} : window
};
function getDefaultValue(props, propKey, defaultStateValues) {
  if (defaultStateValues === void 0) {
    defaultStateValues = dropdownDefaultStateValues;
  }

  var defaultPropKey = "default" + capitalizeString(propKey);

  if (defaultPropKey in props) {
    return props[defaultPropKey];
  }

  return defaultStateValues[propKey];
}
function getInitialValue(props, propKey, defaultStateValues) {
  if (defaultStateValues === void 0) {
    defaultStateValues = dropdownDefaultStateValues;
  }

  if (propKey in props) {
    return props[propKey];
  }

  var initialPropKey = "initial" + capitalizeString(propKey);

  if (initialPropKey in props) {
    return props[initialPropKey];
  }

  return getDefaultValue(props, propKey, defaultStateValues);
}
function getInitialState(props) {
  var selectedItem = getInitialValue(props, 'selectedItem');
  var isOpen = getInitialValue(props, 'isOpen');
  var highlightedIndex = getInitialValue(props, 'highlightedIndex');
  var inputValue = getInitialValue(props, 'inputValue');
  return {
    highlightedIndex: highlightedIndex < 0 && selectedItem ? props.items.indexOf(selectedItem) : highlightedIndex,
    isOpen: isOpen,
    selectedItem: selectedItem,
    inputValue: inputValue
  };
}
function getHighlightedIndexOnOpen(props, state, offset, getItemNodeFromIndex) {
  var items = props.items,
      initialHighlightedIndex = props.initialHighlightedIndex,
      defaultHighlightedIndex = props.defaultHighlightedIndex;
  var selectedItem = state.selectedItem,
      highlightedIndex = state.highlightedIndex; // initialHighlightedIndex will give value to highlightedIndex on initial state only.

  if (initialHighlightedIndex !== undefined && highlightedIndex === initialHighlightedIndex) {
    return initialHighlightedIndex;
  }

  if (defaultHighlightedIndex !== undefined) {
    return defaultHighlightedIndex;
  }

  if (selectedItem) {
    if (offset === 0) {
      return items.indexOf(selectedItem);
    }

    return getNextWrappingIndex(offset, items.indexOf(selectedItem), items.length, getItemNodeFromIndex, false);
  }

  if (offset === 0) {
    return -1;
  }

  return offset < 0 ? items.length - 1 : 0;
}

function getItemIndexByCharacterKey(keysSoFar, highlightedIndex, items, itemToStringParam, getItemNodeFromIndex) {
  var lowerCasedItemStrings = items.map(function (item) {
    return itemToStringParam(item).toLowerCase();
  });
  var lowerCasedKeysSoFar = keysSoFar.toLowerCase();

  var isValid = function (itemString, index) {
    var element = getItemNodeFromIndex(index);
    return itemString.startsWith(lowerCasedKeysSoFar) && !(element && element.hasAttribute('disabled'));
  };

  for (var index = highlightedIndex + 1; index < lowerCasedItemStrings.length; index++) {
    var itemString = lowerCasedItemStrings[index];

    if (isValid(itemString, index)) {
      return index;
    }
  }

  for (var _index = 0; _index < highlightedIndex; _index++) {
    var _itemString = lowerCasedItemStrings[_index];

    if (isValid(_itemString, _index)) {
      return _index;
    }
  }

  return highlightedIndex;
}

var propTypes = {
  items: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().array.isRequired),
  itemToString: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  getA11yStatusMessage: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  getA11ySelectionMessage: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  circularNavigation: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  highlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  defaultHighlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  initialHighlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  isOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  defaultIsOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  initialIsOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  selectedItem: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
  initialSelectedItem: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
  defaultSelectedItem: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
  id: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  labelId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  menuId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  getItemId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  toggleButtonId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  stateReducer: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onSelectedItemChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onHighlightedIndexChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onStateChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onIsOpenChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  environment: prop_types__WEBPACK_IMPORTED_MODULE_7___default().shape({
    addEventListener: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    removeEventListener: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    document: prop_types__WEBPACK_IMPORTED_MODULE_7___default().shape({
      getElementById: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
      activeElement: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
      body: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any)
    })
  })
};
/**
 * Default implementation for status message. Only added when menu is open.
 * Will specift if there are results in the list, and if so, how many,
 * and what keys are relevant.
 *
 * @param {Object} param the downshift state and other relevant properties
 * @return {String} the a11y status message
 */

function getA11yStatusMessage$1(_ref) {
  var isOpen = _ref.isOpen,
      resultCount = _ref.resultCount,
      previousResultCount = _ref.previousResultCount;

  if (!isOpen) {
    return '';
  }

  if (!resultCount) {
    return 'No results are available.';
  }

  if (resultCount !== previousResultCount) {
    return resultCount + " result" + (resultCount === 1 ? ' is' : 's are') + " available, use up and down arrow keys to navigate. Press Enter or Space Bar keys to select.";
  }

  return '';
}

var defaultProps$1 = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, defaultProps, {
  getA11yStatusMessage: getA11yStatusMessage$1
});

var MenuKeyDownArrowDown =  true ? '__menu_keydown_arrow_down__' : 0;
var MenuKeyDownArrowUp =  true ? '__menu_keydown_arrow_up__' : 0;
var MenuKeyDownEscape =  true ? '__menu_keydown_escape__' : 0;
var MenuKeyDownHome =  true ? '__menu_keydown_home__' : 0;
var MenuKeyDownEnd =  true ? '__menu_keydown_end__' : 0;
var MenuKeyDownEnter =  true ? '__menu_keydown_enter__' : 0;
var MenuKeyDownSpaceButton =  true ? '__menu_keydown_space_button__' : 0;
var MenuKeyDownCharacter =  true ? '__menu_keydown_character__' : 0;
var MenuBlur =  true ? '__menu_blur__' : 0;
var MenuMouseLeave =  true ? '__menu_mouse_leave__' : 0;
var ItemMouseMove =  true ? '__item_mouse_move__' : 0;
var ItemClick =  true ? '__item_click__' : 0;
var ToggleButtonClick =  true ? '__togglebutton_click__' : 0;
var ToggleButtonKeyDownArrowDown =  true ? '__togglebutton_keydown_arrow_down__' : 0;
var ToggleButtonKeyDownArrowUp =  true ? '__togglebutton_keydown_arrow_up__' : 0;
var ToggleButtonKeyDownCharacter =  true ? '__togglebutton_keydown_character__' : 0;
var FunctionToggleMenu =  true ? '__function_toggle_menu__' : 0;
var FunctionOpenMenu =  true ? '__function_open_menu__' : 0;
var FunctionCloseMenu =  true ? '__function_close_menu__' : 0;
var FunctionSetHighlightedIndex =  true ? '__function_set_highlighted_index__' : 0;
var FunctionSelectItem =  true ? '__function_select_item__' : 0;
var FunctionSetInputValue =  true ? '__function_set_input_value__' : 0;
var FunctionReset =  true ? '__function_reset__' : 0;

var stateChangeTypes$1 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  MenuKeyDownArrowDown: MenuKeyDownArrowDown,
  MenuKeyDownArrowUp: MenuKeyDownArrowUp,
  MenuKeyDownEscape: MenuKeyDownEscape,
  MenuKeyDownHome: MenuKeyDownHome,
  MenuKeyDownEnd: MenuKeyDownEnd,
  MenuKeyDownEnter: MenuKeyDownEnter,
  MenuKeyDownSpaceButton: MenuKeyDownSpaceButton,
  MenuKeyDownCharacter: MenuKeyDownCharacter,
  MenuBlur: MenuBlur,
  MenuMouseLeave: MenuMouseLeave,
  ItemMouseMove: ItemMouseMove,
  ItemClick: ItemClick,
  ToggleButtonClick: ToggleButtonClick,
  ToggleButtonKeyDownArrowDown: ToggleButtonKeyDownArrowDown,
  ToggleButtonKeyDownArrowUp: ToggleButtonKeyDownArrowUp,
  ToggleButtonKeyDownCharacter: ToggleButtonKeyDownCharacter,
  FunctionToggleMenu: FunctionToggleMenu,
  FunctionOpenMenu: FunctionOpenMenu,
  FunctionCloseMenu: FunctionCloseMenu,
  FunctionSetHighlightedIndex: FunctionSetHighlightedIndex,
  FunctionSelectItem: FunctionSelectItem,
  FunctionSetInputValue: FunctionSetInputValue,
  FunctionReset: FunctionReset
});

/* eslint-disable complexity */

function downshiftSelectReducer(state, action) {
  var type = action.type,
      props = action.props,
      shiftKey = action.shiftKey;
  var changes;

  switch (type) {
    case ItemMouseMove:
      changes = {
        highlightedIndex: action.index
      };
      break;

    case ItemClick:
      changes = {
        isOpen: getDefaultValue(props, 'isOpen'),
        highlightedIndex: getDefaultValue(props, 'highlightedIndex'),
        selectedItem: props.items[action.index]
      };
      break;

    case ToggleButtonKeyDownCharacter:
      {
        var lowercasedKey = action.key;
        var inputValue = "" + state.inputValue + lowercasedKey;
        var itemIndex = getItemIndexByCharacterKey(inputValue, state.selectedItem ? props.items.indexOf(state.selectedItem) : -1, props.items, props.itemToString, action.getItemNodeFromIndex);
        changes = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          inputValue: inputValue
        }, itemIndex >= 0 && {
          selectedItem: props.items[itemIndex]
        });
      }
      break;

    case ToggleButtonKeyDownArrowDown:
      changes = {
        highlightedIndex: getHighlightedIndexOnOpen(props, state, 1, action.getItemNodeFromIndex),
        isOpen: true
      };
      break;

    case ToggleButtonKeyDownArrowUp:
      changes = {
        highlightedIndex: getHighlightedIndexOnOpen(props, state, -1, action.getItemNodeFromIndex),
        isOpen: true
      };
      break;

    case MenuKeyDownEnter:
    case MenuKeyDownSpaceButton:
      changes = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
        isOpen: getDefaultValue(props, 'isOpen'),
        highlightedIndex: getDefaultValue(props, 'highlightedIndex')
      }, state.highlightedIndex >= 0 && {
        selectedItem: props.items[state.highlightedIndex]
      });
      break;

    case MenuKeyDownHome:
      changes = {
        highlightedIndex: getNextNonDisabledIndex(1, 0, props.items.length, action.getItemNodeFromIndex, false)
      };
      break;

    case MenuKeyDownEnd:
      changes = {
        highlightedIndex: getNextNonDisabledIndex(-1, props.items.length - 1, props.items.length, action.getItemNodeFromIndex, false)
      };
      break;

    case MenuKeyDownEscape:
      changes = {
        isOpen: false,
        highlightedIndex: -1
      };
      break;

    case MenuBlur:
      changes = {
        isOpen: false,
        highlightedIndex: -1
      };
      break;

    case MenuKeyDownCharacter:
      {
        var _lowercasedKey = action.key;

        var _inputValue = "" + state.inputValue + _lowercasedKey;

        var highlightedIndex = getItemIndexByCharacterKey(_inputValue, state.highlightedIndex, props.items, props.itemToString, action.getItemNodeFromIndex);
        changes = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          inputValue: _inputValue
        }, highlightedIndex >= 0 && {
          highlightedIndex: highlightedIndex
        });
      }
      break;

    case MenuKeyDownArrowDown:
      changes = {
        highlightedIndex: getNextWrappingIndex(shiftKey ? 5 : 1, state.highlightedIndex, props.items.length, action.getItemNodeFromIndex, props.circularNavigation)
      };
      break;

    case MenuKeyDownArrowUp:
      changes = {
        highlightedIndex: getNextWrappingIndex(shiftKey ? -5 : -1, state.highlightedIndex, props.items.length, action.getItemNodeFromIndex, props.circularNavigation)
      };
      break;

    case MenuMouseLeave:
      changes = {
        highlightedIndex: -1
      };
      break;

    case ToggleButtonClick:
    case FunctionToggleMenu:
      changes = {
        isOpen: !state.isOpen,
        highlightedIndex: state.isOpen ? -1 : getHighlightedIndexOnOpen(props, state, 0)
      };
      break;

    case FunctionOpenMenu:
      changes = {
        isOpen: true,
        highlightedIndex: getHighlightedIndexOnOpen(props, state, 0)
      };
      break;

    case FunctionCloseMenu:
      changes = {
        isOpen: false
      };
      break;

    case FunctionSetHighlightedIndex:
      changes = {
        highlightedIndex: action.highlightedIndex
      };
      break;

    case FunctionSelectItem:
      changes = {
        selectedItem: action.selectedItem
      };
      break;

    case FunctionSetInputValue:
      changes = {
        inputValue: action.inputValue
      };
      break;

    case FunctionReset:
      changes = {
        highlightedIndex: getDefaultValue(props, 'highlightedIndex'),
        isOpen: getDefaultValue(props, 'isOpen'),
        selectedItem: getDefaultValue(props, 'selectedItem'),
        inputValue: getDefaultValue(props, 'inputValue')
      };
      break;

    default:
      throw new Error('Reducer called without proper action type.');
  }

  return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, state, {}, changes);
}
/* eslint-enable complexity */

var validatePropTypes =  false ?
/* istanbul ignore next */
0 : getPropTypesValidator(useSelect, propTypes);
useSelect.stateChangeTypes = stateChangeTypes$1;

function useSelect(userProps) {
  if (userProps === void 0) {
    userProps = {};
  }

  /* istanbul ignore else */
  if (true) {
    validatePropTypes(userProps);
  } // Props defaults and destructuring.


  var props = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, defaultProps$1, {}, userProps);

  var items = props.items,
      scrollIntoView = props.scrollIntoView,
      environment = props.environment,
      initialIsOpen = props.initialIsOpen,
      defaultIsOpen = props.defaultIsOpen,
      itemToString = props.itemToString,
      getA11ySelectionMessage = props.getA11ySelectionMessage,
      getA11yStatusMessage = props.getA11yStatusMessage; // Initial state depending on controlled props.

  var initialState = getInitialState(props); // Reducer init.

  var _useControlledState = useControlledState(downshiftSelectReducer, initialState, props),
      _useControlledState$ = _useControlledState[0],
      isOpen = _useControlledState$.isOpen,
      highlightedIndex = _useControlledState$.highlightedIndex,
      selectedItem = _useControlledState$.selectedItem,
      inputValue = _useControlledState$.inputValue,
      dispatch = _useControlledState[1]; // Refs


  var toggleButtonRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var menuRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var isInitialMount = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(true);
  var shouldScroll = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(true);
  var clearTimeout = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var mouseAndTouchTrackers = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)({
    isMouseDown: false,
    isTouchMove: false
  });
  var elementIds = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(getElementIds(props));
  var previousResultCountRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(); // Some utils.

  var getItemNodeFromIndex = function (index) {
    return environment.document.getElementById(elementIds.current.getItemId(index));
  }; // Effects.

  /* Sets a11y status message on changes in state. */


  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (isInitialMount.current) {
      return;
    }

    var previousResultCount = previousResultCountRef.current;
    updateA11yStatus(function () {
      return getA11yStatusMessage({
        isOpen: isOpen,
        highlightedIndex: highlightedIndex,
        selectedItem: selectedItem,
        inputValue: inputValue,
        highlightedItem: items[highlightedIndex],
        resultCount: items.length,
        itemToString: itemToString,
        previousResultCount: previousResultCount
      });
    }, environment.document); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [isOpen, highlightedIndex, selectedItem, inputValue]);
  /* Sets a11y status message on changes in selectedItem. */

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (isInitialMount.current) {
      return;
    }

    var previousResultCount = previousResultCountRef.current;
    updateA11yStatus(function () {
      return getA11ySelectionMessage({
        isOpen: isOpen,
        highlightedIndex: highlightedIndex,
        selectedItem: selectedItem,
        inputValue: inputValue,
        highlightedItem: items[highlightedIndex],
        resultCount: items.length,
        itemToString: itemToString,
        previousResultCount: previousResultCount
      });
    }, environment.document); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [selectedItem]);
  /* Sets cleanup for the keysSoFar after 500ms. */

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    // init the clean function here as we need access to dispatch.
    if (isInitialMount.current) {
      clearTimeout.current = debounce(function (outerDispatch) {
        outerDispatch({
          type: FunctionSetInputValue,
          inputValue: ''
        });
      }, 500);
    }

    if (!inputValue) {
      return;
    }

    clearTimeout.current(dispatch); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [inputValue]);
  /* Controls the focus on the menu or the toggle button. */

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    // Don't focus menu on first render.
    if (isInitialMount.current) {
      // Unless it was initialised as open.
      if ((initialIsOpen || defaultIsOpen || isOpen) && menuRef.current) {
        menuRef.current.focus();
      }

      return;
    } // Focus menu on open.
    // istanbul ignore next


    if (isOpen && menuRef.current) {
      menuRef.current.focus(); // Focus toggleButton on close.
    } else if (environment.document.activeElement === menuRef.current && toggleButtonRef.current) {
      toggleButtonRef.current.focus();
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [isOpen]);
  /* Scroll on highlighted item if change comes from keyboard. */

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (highlightedIndex < 0 || !isOpen || !items.length) {
      return;
    }

    if (shouldScroll.current === false) {
      shouldScroll.current = true;
    } else {
      scrollIntoView(getItemNodeFromIndex(highlightedIndex), menuRef.current);
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [highlightedIndex]);
  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (isInitialMount.current) {
      return;
    }

    previousResultCountRef.current = items.length;
  });
  /* Make initial ref false. */

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    isInitialMount.current = false;
  }, []);
  /* Add mouse/touch events to document. */

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    // The same strategy for checking if a click occurred inside or outside downsift
    // as in downshift.js.
    var onMouseDown = function () {
      mouseAndTouchTrackers.current.isMouseDown = true;
    };

    var onMouseUp = function (event) {
      mouseAndTouchTrackers.current.isMouseDown = false;

      if (isOpen && !targetWithinDownshift(event.target, [toggleButtonRef.current, menuRef.current], environment.document)) {
        dispatch({
          type: MenuBlur
        });
      }
    };

    var onTouchStart = function () {
      mouseAndTouchTrackers.current.isTouchMove = false;
    };

    var onTouchMove = function () {
      mouseAndTouchTrackers.current.isTouchMove = true;
    };

    var onTouchEnd = function (event) {
      if (isOpen && !mouseAndTouchTrackers.current.isTouchMove && !targetWithinDownshift(event.target, [toggleButtonRef.current, menuRef.current], environment.document, false)) {
        dispatch({
          type: MenuBlur
        });
      }
    };

    environment.addEventListener('mousedown', onMouseDown);
    environment.addEventListener('mouseup', onMouseUp);
    environment.addEventListener('touchstart', onTouchStart);
    environment.addEventListener('touchmove', onTouchMove);
    environment.addEventListener('touchend', onTouchEnd);
    return function () {
      environment.removeEventListener('mousedown', onMouseDown);
      environment.removeEventListener('mouseup', onMouseUp);
      environment.removeEventListener('touchstart', onTouchStart);
      environment.removeEventListener('touchmove', onTouchMove);
      environment.removeEventListener('touchend', onTouchEnd);
    };
  }); // Event handler functions.

  var toggleButtonKeyDownHandlers = {
    ArrowDown: function ArrowDown(event) {
      event.preventDefault();
      dispatch({
        type: ToggleButtonKeyDownArrowDown,
        getItemNodeFromIndex: getItemNodeFromIndex,
        shiftKey: event.shiftKey
      });
    },
    ArrowUp: function ArrowUp(event) {
      event.preventDefault();
      dispatch({
        type: ToggleButtonKeyDownArrowUp,
        getItemNodeFromIndex: getItemNodeFromIndex,
        shiftKey: event.shiftKey
      });
    }
  };
  var menuKeyDownHandlers = {
    ArrowDown: function ArrowDown(event) {
      event.preventDefault();
      dispatch({
        type: MenuKeyDownArrowDown,
        getItemNodeFromIndex: getItemNodeFromIndex,
        shiftKey: event.shiftKey
      });
    },
    ArrowUp: function ArrowUp(event) {
      event.preventDefault();
      dispatch({
        type: MenuKeyDownArrowUp,
        getItemNodeFromIndex: getItemNodeFromIndex,
        shiftKey: event.shiftKey
      });
    },
    Home: function Home(event) {
      event.preventDefault();
      dispatch({
        type: MenuKeyDownHome,
        getItemNodeFromIndex: getItemNodeFromIndex
      });
    },
    End: function End(event) {
      event.preventDefault();
      dispatch({
        type: MenuKeyDownEnd,
        getItemNodeFromIndex: getItemNodeFromIndex
      });
    },
    Escape: function Escape() {
      dispatch({
        type: MenuKeyDownEscape
      });
    },
    Enter: function Enter(event) {
      event.preventDefault();
      dispatch({
        type: MenuKeyDownEnter
      });
    },
    ' ': function _(event) {
      event.preventDefault();
      dispatch({
        type: MenuKeyDownSpaceButton
      });
    }
  }; // Event handlers.

  var menuHandleKeyDown = function (event) {
    var key = normalizeArrowKey(event);

    if (key && menuKeyDownHandlers[key]) {
      menuKeyDownHandlers[key](event);
    } else if (isAcceptedCharacterKey(key)) {
      dispatch({
        type: MenuKeyDownCharacter,
        key: key,
        getItemNodeFromIndex: getItemNodeFromIndex
      });
    }
  };

  var menuHandleBlur = function () {
    var shouldBlur = !mouseAndTouchTrackers.current.isMouseDown;
    /* istanbul ignore else */

    if (shouldBlur) {
      dispatch({
        type: MenuBlur
      });
    }
  };

  var menuHandleMouseLeave = function () {
    dispatch({
      type: MenuMouseLeave
    });
  };

  var toggleButtonHandleClick = function () {
    dispatch({
      type: ToggleButtonClick
    });
  };

  var toggleButtonHandleKeyDown = function (event) {
    var key = normalizeArrowKey(event);

    if (key && toggleButtonKeyDownHandlers[key]) {
      toggleButtonKeyDownHandlers[key](event);
    } else if (isAcceptedCharacterKey(key)) {
      dispatch({
        type: ToggleButtonKeyDownCharacter,
        key: key,
        getItemNodeFromIndex: getItemNodeFromIndex
      });
    }
  };

  var itemHandleMouseMove = function (index) {
    if (index === highlightedIndex) {
      return;
    }

    shouldScroll.current = false;
    dispatch({
      type: ItemMouseMove,
      index: index
    });
  };

  var itemHandleClick = function (index) {
    dispatch({
      type: ItemClick,
      index: index
    });
  }; // Action functions.


  return {
    // prop getters.
    getToggleButtonProps: function getToggleButtonProps(_temp2) {
      var _extends3;

      var _ref2 = _temp2 === void 0 ? {} : _temp2,
          onClick = _ref2.onClick,
          onKeyDown = _ref2.onKeyDown,
          _ref2$refKey = _ref2.refKey,
          refKey = _ref2$refKey === void 0 ? 'ref' : _ref2$refKey,
          ref = _ref2.ref,
          rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref2, ["onClick", "onKeyDown", "refKey", "ref"]);

      var toggleProps = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends3 = {}, _extends3[refKey] = handleRefs(ref, function (toggleButtonNode) {
        toggleButtonRef.current = toggleButtonNode;
      }), _extends3.id = elementIds.current.toggleButtonId, _extends3['aria-haspopup'] = 'listbox', _extends3['aria-expanded'] = isOpen, _extends3['aria-labelledby'] = elementIds.current.labelId + " " + elementIds.current.toggleButtonId, _extends3), rest);

      if (!rest.disabled) {
        toggleProps.onClick = callAllEventHandlers(onClick, toggleButtonHandleClick);
        toggleProps.onKeyDown = callAllEventHandlers(onKeyDown, toggleButtonHandleKeyDown);
      }

      return toggleProps;
    },
    getLabelProps: function getLabelProps(labelProps) {
      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
        id: elementIds.current.labelId,
        htmlFor: elementIds.current.toggleButtonId
      }, labelProps);
    },
    getMenuProps: function getMenuProps(_temp) {
      var _extends2;

      var _ref = _temp === void 0 ? {} : _temp,
          onMouseLeave = _ref.onMouseLeave,
          _ref$refKey = _ref.refKey,
          refKey = _ref$refKey === void 0 ? 'ref' : _ref$refKey,
          onKeyDown = _ref.onKeyDown,
          onBlur = _ref.onBlur,
          ref = _ref.ref,
          rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref, ["onMouseLeave", "refKey", "onKeyDown", "onBlur", "ref"]);

      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends2 = {}, _extends2[refKey] = handleRefs(ref, function (menuNode) {
        menuRef.current = menuNode;
      }), _extends2.id = elementIds.current.menuId, _extends2.role = 'listbox', _extends2['aria-labelledby'] = elementIds.current.labelId, _extends2.tabIndex = -1, _extends2), isOpen && highlightedIndex > -1 && {
        'aria-activedescendant': elementIds.current.getItemId(highlightedIndex)
      }, {
        onMouseLeave: callAllEventHandlers(onMouseLeave, menuHandleMouseLeave),
        onKeyDown: callAllEventHandlers(onKeyDown, menuHandleKeyDown),
        onBlur: callAllEventHandlers(onBlur, menuHandleBlur)
      }, rest);
    },
    getItemProps: function getItemProps(_temp3) {
      var _ref3 = _temp3 === void 0 ? {} : _temp3,
          item = _ref3.item,
          index = _ref3.index,
          onMouseMove = _ref3.onMouseMove,
          onClick = _ref3.onClick,
          rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref3, ["item", "index", "onMouseMove", "onClick"]);

      var itemIndex = getItemIndex(index, item, items);

      if (itemIndex < 0) {
        throw new Error('Pass either item or item index in getItemProps!');
      }

      var itemProps = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
        role: 'option',
        'aria-selected': "" + (itemIndex === highlightedIndex),
        id: elementIds.current.getItemId(itemIndex)
      }, rest);

      if (!rest.disabled) {
        itemProps.onMouseMove = callAllEventHandlers(onMouseMove, function () {
          return itemHandleMouseMove(itemIndex);
        });
        itemProps.onClick = callAllEventHandlers(onClick, function () {
          return itemHandleClick(itemIndex);
        });
      }

      return itemProps;
    },
    // actions.
    toggleMenu: function toggleMenu() {
      dispatch({
        type: FunctionToggleMenu
      });
    },
    openMenu: function openMenu() {
      dispatch({
        type: FunctionOpenMenu
      });
    },
    closeMenu: function closeMenu() {
      dispatch({
        type: FunctionCloseMenu
      });
    },
    setHighlightedIndex: function setHighlightedIndex(newHighlightedIndex) {
      dispatch({
        type: FunctionSetHighlightedIndex,
        highlightedIndex: newHighlightedIndex
      });
    },
    selectItem: function selectItem(newSelectedItem) {
      dispatch({
        type: FunctionSelectItem,
        selectedItem: newSelectedItem
      });
    },
    reset: function reset() {
      dispatch({
        type: FunctionReset
      });
    },
    setInputValue: function setInputValue(newInputValue) {
      dispatch({
        type: FunctionSetInputValue,
        inputValue: newInputValue
      });
    },
    // state.
    highlightedIndex: highlightedIndex,
    isOpen: isOpen,
    selectedItem: selectedItem,
    inputValue: inputValue
  };
}

var InputKeyDownArrowDown =  true ? '__input_keydown_arrow_down__' : 0;
var InputKeyDownArrowUp =  true ? '__input_keydown_arrow_up__' : 0;
var InputKeyDownEscape =  true ? '__input_keydown_escape__' : 0;
var InputKeyDownHome =  true ? '__input_keydown_home__' : 0;
var InputKeyDownEnd =  true ? '__input_keydown_end__' : 0;
var InputKeyDownEnter =  true ? '__input_keydown_enter__' : 0;
var InputChange =  true ? '__input_change__' : 0;
var InputBlur =  true ? '__input_blur__' : 0;
var MenuMouseLeave$1 =  true ? '__menu_mouse_leave__' : 0;
var ItemMouseMove$1 =  true ? '__item_mouse_move__' : 0;
var ItemClick$1 =  true ? '__item_click__' : 0;
var ToggleButtonClick$1 =  true ? '__togglebutton_click__' : 0;
var FunctionToggleMenu$1 =  true ? '__function_toggle_menu__' : 0;
var FunctionOpenMenu$1 =  true ? '__function_open_menu__' : 0;
var FunctionCloseMenu$1 =  true ? '__function_close_menu__' : 0;
var FunctionSetHighlightedIndex$1 =  true ? '__function_set_highlighted_index__' : 0;
var FunctionSelectItem$1 =  true ? '__function_select_item__' : 0;
var FunctionSetInputValue$1 =  true ? '__function_set_input_value__' : 0;
var FunctionReset$1 =  true ? '__function_reset__' : 0;
var ControlledPropUpdatedSelectedItem =  true ? '__controlled_prop_updated_selected_item__' : 0;

var stateChangeTypes$2 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  InputKeyDownArrowDown: InputKeyDownArrowDown,
  InputKeyDownArrowUp: InputKeyDownArrowUp,
  InputKeyDownEscape: InputKeyDownEscape,
  InputKeyDownHome: InputKeyDownHome,
  InputKeyDownEnd: InputKeyDownEnd,
  InputKeyDownEnter: InputKeyDownEnter,
  InputChange: InputChange,
  InputBlur: InputBlur,
  MenuMouseLeave: MenuMouseLeave$1,
  ItemMouseMove: ItemMouseMove$1,
  ItemClick: ItemClick$1,
  ToggleButtonClick: ToggleButtonClick$1,
  FunctionToggleMenu: FunctionToggleMenu$1,
  FunctionOpenMenu: FunctionOpenMenu$1,
  FunctionCloseMenu: FunctionCloseMenu$1,
  FunctionSetHighlightedIndex: FunctionSetHighlightedIndex$1,
  FunctionSelectItem: FunctionSelectItem$1,
  FunctionSetInputValue: FunctionSetInputValue$1,
  FunctionReset: FunctionReset$1,
  ControlledPropUpdatedSelectedItem: ControlledPropUpdatedSelectedItem
});

function getElementIds$1(_ref) {
  var id = _ref.id,
      inputId = _ref.inputId,
      rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref, ["id", "inputId"]);

  var uniqueId = id === undefined ? "downshift-" + generateId() : id;
  return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
    inputId: inputId || uniqueId + "-input"
  }, getElementIds((0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
    id: id
  }, rest)));
}
function getInitialState$1(props) {
  var initialState = getInitialState(props);
  var selectedItem = initialState.selectedItem;
  var inputValue = initialState.inputValue;

  if (inputValue === '' && selectedItem && props.defaultInputValue === undefined && props.initialInputValue === undefined && props.inputValue === undefined) {
    inputValue = props.itemToString(selectedItem);
  }

  return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, initialState, {
    inputValue: inputValue
  });
}
var propTypes$1 = {
  items: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().array.isRequired),
  itemToString: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  getA11yStatusMessage: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  getA11ySelectionMessage: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  circularNavigation: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  highlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  defaultHighlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  initialHighlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  isOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  defaultIsOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  initialIsOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  selectedItem: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
  initialSelectedItem: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
  defaultSelectedItem: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
  inputValue: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  defaultInputValue: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  initialInputValue: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  id: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  labelId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  menuId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  getItemId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  inputId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  toggleButtonId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  stateReducer: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onSelectedItemChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onHighlightedIndexChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onStateChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onIsOpenChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onInputValueChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  environment: prop_types__WEBPACK_IMPORTED_MODULE_7___default().shape({
    addEventListener: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    removeEventListener: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    document: prop_types__WEBPACK_IMPORTED_MODULE_7___default().shape({
      getElementById: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
      activeElement: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
      body: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any)
    })
  })
};
/**
 * The useCombobox version of useControlledState, which also
 * checks if the controlled prop selectedItem changed between
 * renders. If so, it will also update inputValue with its
 * string equivalent. It uses the common useControlledState to
 * compute the rest of the state.
 *
 * @param {Function} reducer Reducer function from downshift.
 * @param {Object} initialState Initial state of the hook.
 * @param {Object} props The hook props.
 * @returns {Array} An array with the state and an action dispatcher.
 */

function useControlledState$1(reducer, initialState, props) {
  var _useControlledStateCo = useControlledState(reducer, initialState, props),
      newState = _useControlledStateCo[0],
      dispatch = _useControlledStateCo[1];

  var previousSelectedItemRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var selectedItem = props.selectedItem,
      itemToString = props.itemToString; // ToDo: if needed, make same approach as selectedItemChanged from Downshift.

  if (isControlledProp(props, 'selectedItem') && previousSelectedItemRef.current !== selectedItem) {
    dispatch({
      type: ControlledPropUpdatedSelectedItem,
      inputValue: itemToString(selectedItem)
    });
  }

  previousSelectedItemRef.current = selectedItem;
  return [newState, dispatch];
}
var defaultProps$2 = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, defaultProps, {
  getA11yStatusMessage: getA11yStatusMessage,
  circularNavigation: true
});

/* eslint-disable complexity */

function downshiftUseComboboxReducer(state, action) {
  var type = action.type,
      props = action.props,
      shiftKey = action.shiftKey;
  var changes;

  switch (type) {
    case ItemMouseMove$1:
      changes = {
        highlightedIndex: action.index
      };
      break;

    case ItemClick$1:
      changes = {
        isOpen: getDefaultValue(props, 'isOpen'),
        highlightedIndex: getDefaultValue(props, 'highlightedIndex'),
        selectedItem: props.items[action.index],
        inputValue: props.itemToString(props.items[action.index])
      };
      break;

    case InputKeyDownArrowDown:
      if (state.isOpen) {
        changes = {
          highlightedIndex: getNextWrappingIndex(shiftKey ? 5 : 1, state.highlightedIndex, props.items.length, action.getItemNodeFromIndex, props.circularNavigation)
        };
      } else {
        changes = {
          highlightedIndex: getHighlightedIndexOnOpen(props, state, 1, action.getItemNodeFromIndex),
          isOpen: true
        };
      }

      break;

    case InputKeyDownArrowUp:
      if (state.isOpen) {
        changes = {
          highlightedIndex: getNextWrappingIndex(shiftKey ? -5 : -1, state.highlightedIndex, props.items.length, action.getItemNodeFromIndex, props.circularNavigation)
        };
      } else {
        changes = {
          highlightedIndex: getHighlightedIndexOnOpen(props, state, -1, action.getItemNodeFromIndex),
          isOpen: true
        };
      }

      break;

    case InputKeyDownEnter:
      changes = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, state.highlightedIndex >= 0 && {
        selectedItem: props.items[state.highlightedIndex],
        isOpen: getDefaultValue(props, 'isOpen'),
        highlightedIndex: getDefaultValue(props, 'highlightedIndex'),
        inputValue: props.itemToString(props.items[state.highlightedIndex])
      });
      break;

    case InputKeyDownEscape:
      changes = {
        isOpen: false,
        selectedItem: null,
        highlightedIndex: -1,
        inputValue: ''
      };
      break;

    case InputKeyDownHome:
      changes = {
        highlightedIndex: getNextNonDisabledIndex(1, 0, props.items.length, action.getItemNodeFromIndex, false)
      };
      break;

    case InputKeyDownEnd:
      changes = {
        highlightedIndex: getNextNonDisabledIndex(-1, props.items.length - 1, props.items.length, action.getItemNodeFromIndex, false)
      };
      break;

    case InputBlur:
      changes = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
        isOpen: false
      }, state.highlightedIndex >= 0 && {
        selectedItem: props.items[state.highlightedIndex],
        inputValue: props.itemToString(props.items[state.highlightedIndex]),
        highlightedIndex: -1
      });
      break;

    case InputChange:
      changes = {
        isOpen: true,
        highlightedIndex: getDefaultValue(props, 'highlightedIndex'),
        inputValue: action.inputValue
      };
      break;

    case MenuMouseLeave$1:
      changes = {
        highlightedIndex: -1
      };
      break;

    case ToggleButtonClick$1:
    case FunctionToggleMenu$1:
      changes = {
        isOpen: !state.isOpen,
        highlightedIndex: state.isOpen ? -1 : getHighlightedIndexOnOpen(props, state, 0)
      };
      break;

    case FunctionOpenMenu$1:
      changes = {
        isOpen: true,
        highlightedIndex: getHighlightedIndexOnOpen(props, state, 0)
      };
      break;

    case FunctionCloseMenu$1:
      changes = {
        isOpen: false
      };
      break;

    case FunctionSetHighlightedIndex$1:
      changes = {
        highlightedIndex: action.highlightedIndex
      };
      break;

    case FunctionSelectItem$1:
      changes = {
        selectedItem: action.selectedItem
      };
      break;

    case ControlledPropUpdatedSelectedItem:
    case FunctionSetInputValue$1:
      changes = {
        inputValue: action.inputValue
      };
      break;

    case FunctionReset$1:
      changes = {
        highlightedIndex: getDefaultValue(props, 'highlightedIndex'),
        isOpen: getDefaultValue(props, 'isOpen'),
        selectedItem: getDefaultValue(props, 'selectedItem'),
        inputValue: getDefaultValue(props, 'inputValue')
      };
      break;

    default:
      throw new Error('Reducer called without proper action type.');
  }

  return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, state, {}, changes);
}
/* eslint-enable complexity */

var validatePropTypes$1 =  false ?
/* istanbul ignore next */
0 : getPropTypesValidator(useCombobox, propTypes$1);
useCombobox.stateChangeTypes = stateChangeTypes$2;

function useCombobox(userProps) {
  if (userProps === void 0) {
    userProps = {};
  }

  /* istanbul ignore else */
  if (true) {
    validatePropTypes$1(userProps);
  } // Props defaults and destructuring.


  var props = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, defaultProps$2, {}, userProps);

  var initialIsOpen = props.initialIsOpen,
      defaultIsOpen = props.defaultIsOpen,
      items = props.items,
      scrollIntoView = props.scrollIntoView,
      environment = props.environment,
      getA11yStatusMessage = props.getA11yStatusMessage,
      getA11ySelectionMessage = props.getA11ySelectionMessage,
      itemToString = props.itemToString; // Initial state depending on controlled props.

  var initialState = getInitialState$1(props); // Reducer init.

  var _useControlledState = useControlledState$1(downshiftUseComboboxReducer, initialState, props),
      _useControlledState$ = _useControlledState[0],
      isOpen = _useControlledState$.isOpen,
      highlightedIndex = _useControlledState$.highlightedIndex,
      selectedItem = _useControlledState$.selectedItem,
      inputValue = _useControlledState$.inputValue,
      dispatch = _useControlledState[1];
  /* Refs */


  var menuRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var itemRefs = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)();
  var inputRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var toggleButtonRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var comboboxRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  itemRefs.current = [];
  var shouldScroll = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(true);
  var isInitialMount = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(true);
  var mouseAndTouchTrackers = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)({
    isMouseDown: false,
    isTouchMove: false
  });
  var elementIds = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(getElementIds$1(props));
  var previousResultCountRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)();
  /* Effects */

  /* Sets a11y status message on changes in state. */

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (isInitialMount.current) {
      return;
    }

    var previousResultCount = previousResultCountRef.current;
    updateA11yStatus(function () {
      return getA11yStatusMessage({
        isOpen: isOpen,
        highlightedIndex: highlightedIndex,
        selectedItem: selectedItem,
        inputValue: inputValue,
        highlightedItem: items[highlightedIndex],
        resultCount: items.length,
        itemToString: itemToString,
        previousResultCount: previousResultCount
      });
    }, environment.document); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [isOpen, highlightedIndex, selectedItem, inputValue]);
  /* Sets a11y status message on changes in selectedItem. */

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (isInitialMount.current) {
      return;
    }

    var previousResultCount = previousResultCountRef.current;
    updateA11yStatus(function () {
      return getA11ySelectionMessage({
        isOpen: isOpen,
        highlightedIndex: highlightedIndex,
        selectedItem: selectedItem,
        inputValue: inputValue,
        highlightedItem: items[highlightedIndex],
        resultCount: items.length,
        itemToString: itemToString,
        previousResultCount: previousResultCount
      });
    }, environment.document); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [selectedItem]);
  /* Scroll on highlighted item if change comes from keyboard. */

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (highlightedIndex < 0 || !isOpen || !itemRefs.current.length) {
      return;
    }

    if (shouldScroll.current === false) {
      shouldScroll.current = true;
    } else {
      scrollIntoView(itemRefs.current[highlightedIndex], menuRef.current);
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [highlightedIndex]);
  /* Controls the focus on the menu or the toggle button. */

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    // Don't focus menu on first render.
    if (isInitialMount.current) {
      // Unless it was initialised as open.
      if (initialIsOpen || defaultIsOpen || isOpen) {
        if (inputRef.current) {
          inputRef.current.focus();
        }
      }
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [isOpen]);
  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (isInitialMount.current) {
      return;
    }

    previousResultCountRef.current = items.length;
  });
  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    isInitialMount.current = false;
  }, []);
  /* Add mouse/touch events to document. */

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    // The same strategy for checking if a click occurred inside or outside downsift
    // as in downshift.js.
    var onMouseDown = function () {
      mouseAndTouchTrackers.current.isMouseDown = true;
    };

    var onMouseUp = function (event) {
      mouseAndTouchTrackers.current.isMouseDown = false;

      if (isOpen && !targetWithinDownshift(event.target, [comboboxRef.current, menuRef.current, toggleButtonRef.current], environment.document)) {
        dispatch({
          type: InputBlur
        });
      }
    };

    var onTouchStart = function () {
      mouseAndTouchTrackers.current.isTouchMove = false;
    };

    var onTouchMove = function () {
      mouseAndTouchTrackers.current.isTouchMove = true;
    };

    var onTouchEnd = function (event) {
      if (isOpen && !mouseAndTouchTrackers.current.isTouchMove && !targetWithinDownshift(event.target, [comboboxRef.current, menuRef.current, toggleButtonRef.current], environment.document, false)) {
        dispatch({
          type: InputBlur
        });
      }
    };

    environment.addEventListener('mousedown', onMouseDown);
    environment.addEventListener('mouseup', onMouseUp);
    environment.addEventListener('touchstart', onTouchStart);
    environment.addEventListener('touchmove', onTouchMove);
    environment.addEventListener('touchend', onTouchEnd);
    return function () {
      environment.removeEventListener('mousedown', onMouseDown);
      environment.removeEventListener('mouseup', onMouseUp);
      environment.removeEventListener('touchstart', onTouchStart);
      environment.removeEventListener('touchmove', onTouchMove);
      environment.removeEventListener('touchend', onTouchEnd);
    };
  });

  var getItemNodeFromIndex = function (index) {
    return itemRefs.current[index];
  };
  /* Event handler functions */


  var inputKeyDownHandlers = {
    ArrowDown: function ArrowDown(event) {
      event.preventDefault();
      dispatch({
        type: InputKeyDownArrowDown,
        shiftKey: event.shiftKey,
        getItemNodeFromIndex: getItemNodeFromIndex
      });
    },
    ArrowUp: function ArrowUp(event) {
      event.preventDefault();
      dispatch({
        type: InputKeyDownArrowUp,
        shiftKey: event.shiftKey,
        getItemNodeFromIndex: getItemNodeFromIndex
      });
    },
    Home: function Home(event) {
      event.preventDefault();
      dispatch({
        type: InputKeyDownHome,
        getItemNodeFromIndex: getItemNodeFromIndex
      });
    },
    End: function End(event) {
      event.preventDefault();
      dispatch({
        type: InputKeyDownEnd,
        getItemNodeFromIndex: getItemNodeFromIndex
      });
    },
    Escape: function Escape() {
      dispatch({
        type: InputKeyDownEscape
      });
    },
    Enter: function Enter(event) {
      // if IME composing, wait for next Enter keydown event.
      if (event.which === 229) {
        return;
      }

      event.preventDefault();
      dispatch({
        type: InputKeyDownEnter,
        getItemNodeFromIndex: getItemNodeFromIndex
      });
    }
  }; // Event handlers.

  var inputHandleKeyDown = function (event) {
    var key = normalizeArrowKey(event);

    if (key && inputKeyDownHandlers[key]) {
      inputKeyDownHandlers[key](event);
    }
  };

  var inputHandleChange = function (event) {
    dispatch({
      type: InputChange,
      inputValue: event.target.value
    });
  };

  var inputHandleBlur = function () {
    /* istanbul ignore else */
    if (!mouseAndTouchTrackers.current.isMouseDown) {
      dispatch({
        type: InputBlur
      });
    }
  };

  var menuHandleMouseLeave = function () {
    dispatch({
      type: MenuMouseLeave$1
    });
  };

  var itemHandleMouseMove = function (index) {
    if (index === highlightedIndex) {
      return;
    }

    shouldScroll.current = false;
    dispatch({
      type: ItemMouseMove$1,
      index: index
    });
  };

  var itemHandleClick = function (index) {
    dispatch({
      type: ItemClick$1,
      index: index
    });
  };

  var toggleButtonHandleClick = function () {
    dispatch({
      type: ToggleButtonClick$1
    });

    if (!isOpen && inputRef.current) {
      inputRef.current.focus();
    }
  }; // Getter props.


  return {
    // prop getters.
    getItemProps: function getItemProps(_temp2) {
      var _extends3, _ref3;

      var _ref2 = _temp2 === void 0 ? {} : _temp2,
          item = _ref2.item,
          index = _ref2.index,
          _ref2$refKey = _ref2.refKey,
          refKey = _ref2$refKey === void 0 ? 'ref' : _ref2$refKey,
          ref = _ref2.ref,
          onMouseMove = _ref2.onMouseMove,
          onClick = _ref2.onClick,
          onPress = _ref2.onPress,
          rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref2, ["item", "index", "refKey", "ref", "onMouseMove", "onClick", "onPress"]);

      var itemIndex = getItemIndex(index, item, items);

      if (itemIndex < 0) {
        throw new Error('Pass either item or item index in getItemProps!');
      }

      var onSelectKey = 'onClick';
      var customClickHandler = onClick;
      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends3 = {}, _extends3[refKey] = handleRefs(ref, function (itemNode) {
        if (itemNode) {
          itemRefs.current.push(itemNode);
        }
      }), _extends3.role = 'option', _extends3['aria-selected'] = "" + (itemIndex === highlightedIndex), _extends3.id = elementIds.current.getItemId(itemIndex), _extends3), !rest.disabled && (_ref3 = {
        onMouseMove: callAllEventHandlers(onMouseMove, function () {
          itemHandleMouseMove(itemIndex);
        })
      }, _ref3[onSelectKey] = callAllEventHandlers(customClickHandler, function () {
        itemHandleClick(itemIndex);
      }), _ref3), {}, rest);
    },
    getLabelProps: function getLabelProps(labelProps) {
      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
        id: elementIds.current.labelId,
        htmlFor: elementIds.current.inputId
      }, labelProps);
    },
    getMenuProps: function getMenuProps(_temp) {
      var _extends2;

      var _ref = _temp === void 0 ? {} : _temp,
          onMouseLeave = _ref.onMouseLeave,
          _ref$refKey = _ref.refKey,
          refKey = _ref$refKey === void 0 ? 'ref' : _ref$refKey,
          ref = _ref.ref,
          rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref, ["onMouseLeave", "refKey", "ref"]);

      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends2 = {}, _extends2[refKey] = handleRefs(ref, function (menuNode) {
        menuRef.current = menuNode;
      }), _extends2.id = elementIds.current.menuId, _extends2.role = 'listbox', _extends2['aria-labelledby'] = elementIds.current.labelId, _extends2.onMouseLeave = callAllEventHandlers(onMouseLeave, menuHandleMouseLeave), _extends2), rest);
    },
    getInputProps: function getInputProps(_temp4) {
      var _extends5;

      var _ref5 = _temp4 === void 0 ? {} : _temp4,
          onKeyDown = _ref5.onKeyDown,
          onChange = _ref5.onChange,
          onInput = _ref5.onInput,
          onBlur = _ref5.onBlur,
          onChangeText = _ref5.onChangeText,
          _ref5$refKey = _ref5.refKey,
          refKey = _ref5$refKey === void 0 ? 'ref' : _ref5$refKey,
          ref = _ref5.ref,
          rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref5, ["onKeyDown", "onChange", "onInput", "onBlur", "onChangeText", "refKey", "ref"]);

      /* istanbul ignore next (preact) */
      var onChangeKey = 'onChange';
      var eventHandlers = {};

      if (!rest.disabled) {
        var _eventHandlers;

        eventHandlers = (_eventHandlers = {}, _eventHandlers[onChangeKey] = callAllEventHandlers(onChange, onInput, inputHandleChange), _eventHandlers.onKeyDown = callAllEventHandlers(onKeyDown, inputHandleKeyDown), _eventHandlers.onBlur = callAllEventHandlers(onBlur, inputHandleBlur), _eventHandlers);
      }
      /* istanbul ignore if (react-native) */


      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends5 = {}, _extends5[refKey] = handleRefs(ref, function (inputNode) {
        inputRef.current = inputNode;
      }), _extends5.id = elementIds.current.inputId, _extends5['aria-autocomplete'] = 'list', _extends5['aria-controls'] = elementIds.current.menuId, _extends5), isOpen && highlightedIndex > -1 && {
        'aria-activedescendant': elementIds.current.getItemId(highlightedIndex)
      }, {
        'aria-labelledby': elementIds.current.labelId,
        // https://developer.mozilla.org/en-US/docs/Web/Security/Securing_your_site/Turning_off_form_autocompletion
        // revert back since autocomplete="nope" is ignored on latest Chrome and Opera
        autoComplete: 'off',
        value: inputValue
      }, eventHandlers, {}, rest);
    },
    getComboboxProps: function getComboboxProps(_temp5) {
      var _extends6;

      var _ref6 = _temp5 === void 0 ? {} : _temp5,
          _ref6$refKey = _ref6.refKey,
          refKey = _ref6$refKey === void 0 ? 'ref' : _ref6$refKey,
          ref = _ref6.ref,
          rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref6, ["refKey", "ref"]);

      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends6 = {}, _extends6[refKey] = handleRefs(ref, function (comboboxNode) {
        comboboxRef.current = comboboxNode;
      }), _extends6.role = 'combobox', _extends6['aria-haspopup'] = 'listbox', _extends6['aria-owns'] = elementIds.current.menuId, _extends6['aria-expanded'] = isOpen, _extends6), rest);
    },
    getToggleButtonProps: function getToggleButtonProps(_temp3) {
      var _extends4;

      var _ref4 = _temp3 === void 0 ? {} : _temp3,
          onClick = _ref4.onClick,
          onPress = _ref4.onPress,
          _ref4$refKey = _ref4.refKey,
          refKey = _ref4$refKey === void 0 ? 'ref' : _ref4$refKey,
          ref = _ref4.ref,
          rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref4, ["onClick", "onPress", "refKey", "ref"]);

      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends4 = {}, _extends4[refKey] = handleRefs(ref, function (toggleButtonNode) {
        toggleButtonRef.current = toggleButtonNode;
      }), _extends4.id = elementIds.current.toggleButtonId, _extends4.tabIndex = -1, _extends4), !rest.disabled && (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, {
        onClick: callAllEventHandlers(onClick, toggleButtonHandleClick)
      }), {}, rest);
    },
    // actions.
    toggleMenu: function toggleMenu() {
      dispatch({
        type: FunctionToggleMenu$1
      });
    },
    openMenu: function openMenu() {
      dispatch({
        type: FunctionOpenMenu$1
      });
    },
    closeMenu: function closeMenu() {
      dispatch({
        type: FunctionCloseMenu$1
      });
    },
    setHighlightedIndex: function setHighlightedIndex(newHighlightedIndex) {
      dispatch({
        type: FunctionSetHighlightedIndex$1,
        highlightedIndex: newHighlightedIndex
      });
    },
    setInputValue: function setInputValue(newInputValue) {
      dispatch({
        type: FunctionSetInputValue$1,
        inputValue: newInputValue
      });
    },
    selectItem: function selectItem(newSelectedItem) {
      dispatch({
        type: FunctionSelectItem$1,
        selectedItem: newSelectedItem
      });
    },
    reset: function reset() {
      dispatch({
        type: FunctionReset$1
      });
    },
    // state.
    highlightedIndex: highlightedIndex,
    isOpen: isOpen,
    selectedItem: selectedItem,
    inputValue: inputValue
  };
}

var defaultStateValues = {
  activeIndex: -1,
  selectedItems: []
};
/**
 * Returns the initial value for a state key in the following order:
 * 1. controlled prop, 2. initial prop, 3. default prop, 4. default
 * value from Downshift.
 *
 * @param {Object} props Props passed to the hook.
 * @param {string} propKey Props key to generate the value for.
 * @returns {any} The initial value for that prop.
 */

function getInitialValue$1(props, propKey) {
  return getInitialValue(props, propKey, defaultStateValues);
}
/**
 * Returns the default value for a state key in the following order:
 * 1. controlled prop, 2. default prop, 3. default value from Downshift.
 *
 * @param {Object} props Props passed to the hook.
 * @param {string} propKey Props key to generate the value for.
 * @returns {any} The initial value for that prop.
 */


function getDefaultValue$1(props, propKey) {
  return getDefaultValue(props, propKey, defaultStateValues);
}
/**
 * Gets the initial state based on the provided props. It uses initial, default
 * and controlled props related to state in order to compute the initial value.
 *
 * @param {Object} props Props passed to the hook.
 * @returns {Object} The initial state.
 */

function getInitialState$2(props) {
  var activeIndex = getInitialValue$1(props, 'activeIndex');
  var selectedItems = getInitialValue$1(props, 'selectedItems');
  return {
    activeIndex: activeIndex,
    selectedItems: selectedItems
  };
}
/**
 * Returns true if dropdown keydown operation is permitted. Should not be
 * allowed on keydown with modifier keys (ctrl, alt, shift, meta), on
 * input element with text content that is either highlighted or selection
 * cursor is not at the starting position.
 *
 * @param {KeyboardEvent} event The event from keydown.
 * @returns {boolean} Whether the operation is allowed.
 */

function isKeyDownOperationPermitted(event) {
  if (event.shiftKey || event.metaKey || event.ctrlKey || event.altKey) {
    return false;
  }

  var element = event.target;

  if (element instanceof HTMLInputElement && // if element is a text input
  element.value !== '' && ( // and we have text in it
  // and cursor is either not at the start or is currently highlighting text.
  element.selectionStart !== 0 || element.selectionEnd !== 0)) {
    return false;
  }

  return true;
}
/**
 * Returns a message to be added to aria-live region when item is removed.
 *
 * @param {Object} selectionParameters Parameters required to build the message.
 * @returns {string} The a11y message.
 */

function getA11yRemovalMessage(selectionParameters) {
  var removedSelectedItem = selectionParameters.removedSelectedItem,
      itemToStringLocal = selectionParameters.itemToString;
  return itemToStringLocal(removedSelectedItem) + " has been removed.";
}

var propTypes$2 = {
  selectedItems: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().array),
  initialSelectedItems: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().array),
  defaultSelectedItems: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().array),
  itemToString: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  getA11yRemovalMessage: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  stateReducer: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  activeIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  initialActiveIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  defaultActiveIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  onActiveIndexChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onSelectedItemsChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  keyNavigationNext: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  keyNavigationPrevious: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  environment: prop_types__WEBPACK_IMPORTED_MODULE_7___default().shape({
    addEventListener: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    removeEventListener: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    document: prop_types__WEBPACK_IMPORTED_MODULE_7___default().shape({
      getElementById: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
      activeElement: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
      body: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any)
    })
  })
};
var defaultProps$3 = {
  itemToString: defaultProps.itemToString,
  stateReducer: defaultProps.stateReducer,
  environment: defaultProps.environment,
  getA11yRemovalMessage: getA11yRemovalMessage,
  keyNavigationNext: 'ArrowRight',
  keyNavigationPrevious: 'ArrowLeft'
};

var SelectedItemClick =  true ? '__selected_item_click__' : 0;
var SelectedItemKeyDownDelete =  true ? '__selected_item_keydown_delete__' : 0;
var SelectedItemKeyDownBackspace =  true ? '__selected_item_keydown_backspace__' : 0;
var SelectedItemKeyDownNavigationNext =  true ? '__selected_item_keydown_navigation_next__' : 0;
var SelectedItemKeyDownNavigationPrevious =  true ? '__selected_item_keydown_navigation_previous__' : 0;
var DropdownKeyDownNavigationPrevious =  true ? '__dropdown_keydown_navigation_previous__' : 0;
var DropdownKeyDownBackspace =  true ? '__dropdown_keydown_backspace__' : 0;
var DropdownClick =  true ? '__dropdown_click__' : 0;
var FunctionAddSelectedItem =  true ? '__function_add_selected_item__' : 0;
var FunctionRemoveSelectedItem =  true ? '__function_remove_selected_item__' : 0;
var FunctionSetSelectedItems =  true ? '__function_set_selected_items__' : 0;
var FunctionSetActiveIndex =  true ? '__function_set_active_index__' : 0;
var FunctionReset$2 =  true ? '__function_reset__' : 0;

var stateChangeTypes$3 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  SelectedItemClick: SelectedItemClick,
  SelectedItemKeyDownDelete: SelectedItemKeyDownDelete,
  SelectedItemKeyDownBackspace: SelectedItemKeyDownBackspace,
  SelectedItemKeyDownNavigationNext: SelectedItemKeyDownNavigationNext,
  SelectedItemKeyDownNavigationPrevious: SelectedItemKeyDownNavigationPrevious,
  DropdownKeyDownNavigationPrevious: DropdownKeyDownNavigationPrevious,
  DropdownKeyDownBackspace: DropdownKeyDownBackspace,
  DropdownClick: DropdownClick,
  FunctionAddSelectedItem: FunctionAddSelectedItem,
  FunctionRemoveSelectedItem: FunctionRemoveSelectedItem,
  FunctionSetSelectedItems: FunctionSetSelectedItems,
  FunctionSetActiveIndex: FunctionSetActiveIndex,
  FunctionReset: FunctionReset$2
});

/* eslint-disable complexity */

function downshiftMultipleSelectionReducer(state, action) {
  var type = action.type,
      index = action.index,
      props = action.props,
      selectedItem = action.selectedItem;
  var activeIndex = state.activeIndex,
      selectedItems = state.selectedItems;
  var changes;

  switch (type) {
    case SelectedItemClick:
      changes = {
        activeIndex: index
      };
      break;

    case SelectedItemKeyDownNavigationPrevious:
      changes = {
        activeIndex: activeIndex - 1 < 0 ? 0 : activeIndex - 1
      };
      break;

    case SelectedItemKeyDownNavigationNext:
      changes = {
        activeIndex: activeIndex + 1 >= selectedItems.length ? -1 : activeIndex + 1
      };
      break;

    case SelectedItemKeyDownBackspace:
    case SelectedItemKeyDownDelete:
      {
        var newActiveIndex = activeIndex;

        if (selectedItems.length === 1) {
          newActiveIndex = -1;
        } else if (activeIndex === selectedItems.length - 1) {
          newActiveIndex = selectedItems.length - 2;
        }

        changes = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          selectedItems: [].concat(selectedItems.slice(0, activeIndex), selectedItems.slice(activeIndex + 1))
        }, {
          activeIndex: newActiveIndex
        });
        break;
      }

    case DropdownKeyDownNavigationPrevious:
      changes = {
        activeIndex: selectedItems.length - 1
      };
      break;

    case DropdownKeyDownBackspace:
      changes = {
        selectedItems: selectedItems.slice(0, selectedItems.length - 1)
      };
      break;

    case FunctionAddSelectedItem:
      changes = {
        selectedItems: [].concat(selectedItems, [selectedItem])
      };
      break;

    case DropdownClick:
      changes = {
        activeIndex: -1
      };
      break;

    case FunctionRemoveSelectedItem:
      {
        var _newActiveIndex = activeIndex;
        var selectedItemIndex = selectedItems.indexOf(selectedItem);

        if (selectedItems.length === 1) {
          _newActiveIndex = -1;
        } else if (selectedItemIndex === selectedItems.length - 1) {
          _newActiveIndex = selectedItems.length - 2;
        }

        changes = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          selectedItems: [].concat(selectedItems.slice(0, selectedItemIndex), selectedItems.slice(selectedItemIndex + 1))
        }, {
          activeIndex: _newActiveIndex
        });
        break;
      }

    case FunctionSetSelectedItems:
      {
        var newSelectedItems = action.selectedItems;
        changes = {
          selectedItems: newSelectedItems
        };
        break;
      }

    case FunctionSetActiveIndex:
      {
        var _newActiveIndex2 = action.activeIndex;
        changes = {
          activeIndex: _newActiveIndex2
        };
        break;
      }

    case FunctionReset$2:
      changes = {
        activeIndex: getDefaultValue$1(props, 'activeIndex'),
        selectedItems: getDefaultValue$1(props, 'selectedItems')
      };
      break;

    default:
      throw new Error('Reducer called without proper action type.');
  }

  return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, state, {}, changes);
}

useMultipleSelection.stateChangeTypes = stateChangeTypes$3;

function useMultipleSelection(userProps) {
  var _selectedItemKeyDownH, _dropdownKeyDownHandl;

  if (userProps === void 0) {
    userProps = {};
  }

  // Props defaults and destructuring.
  var props = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, defaultProps$3, {}, userProps);

  var getA11yRemovalMessage = props.getA11yRemovalMessage,
      itemToString = props.itemToString,
      environment = props.environment,
      keyNavigationNext = props.keyNavigationNext,
      keyNavigationPrevious = props.keyNavigationPrevious; // Reducer init.

  var _useControlledState = useControlledState(downshiftMultipleSelectionReducer, getInitialState$2(props), props),
      _useControlledState$ = _useControlledState[0],
      activeIndex = _useControlledState$.activeIndex,
      selectedItems = _useControlledState$.selectedItems,
      dispatch = _useControlledState[1]; // Refs.


  var isInitialMount = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(true);
  var dropdownRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var previousSelectedItemsRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(selectedItems);
  var selectedItemRefs = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)();
  selectedItemRefs.current = []; // Effects.

  /* Sets a11y status message on changes in selectedItem. */

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (isInitialMount.current) {
      return;
    }

    if (selectedItems.length < previousSelectedItemsRef.current.length) {
      var removedSelectedItem = previousSelectedItemsRef.current.find(function (item) {
        return selectedItems.indexOf(item) < 0;
      });
      setStatus(getA11yRemovalMessage({
        itemToString: itemToString,
        resultCount: selectedItems.length,
        removedSelectedItem: removedSelectedItem,
        activeIndex: activeIndex,
        activeSelectedItem: selectedItems[activeIndex]
      }), environment.document);
    }

    previousSelectedItemsRef.current = selectedItems; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [selectedItems.length]); // Sets focus on active item.

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (isInitialMount.current) {
      return;
    }

    if (activeIndex === -1 && dropdownRef.current) {
      dropdownRef.current.focus();
    } else if (selectedItemRefs.current[activeIndex]) {
      selectedItemRefs.current[activeIndex].focus();
    }
  }, [activeIndex]); // Make initial ref false.

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    isInitialMount.current = false;
  }, []); // Event handler functions.

  var selectedItemKeyDownHandlers = (_selectedItemKeyDownH = {}, _selectedItemKeyDownH[keyNavigationPrevious] = function () {
    dispatch({
      type: SelectedItemKeyDownNavigationPrevious
    });
  }, _selectedItemKeyDownH[keyNavigationNext] = function () {
    dispatch({
      type: SelectedItemKeyDownNavigationNext
    });
  }, _selectedItemKeyDownH.Delete = function Delete() {
    dispatch({
      type: SelectedItemKeyDownDelete
    });
  }, _selectedItemKeyDownH.Backspace = function Backspace() {
    dispatch({
      type: SelectedItemKeyDownBackspace
    });
  }, _selectedItemKeyDownH);
  var dropdownKeyDownHandlers = (_dropdownKeyDownHandl = {}, _dropdownKeyDownHandl[keyNavigationPrevious] = function (event) {
    if (isKeyDownOperationPermitted(event)) {
      dispatch({
        type: DropdownKeyDownNavigationPrevious
      });
    }
  }, _dropdownKeyDownHandl.Backspace = function Backspace(event) {
    if (isKeyDownOperationPermitted(event)) {
      dispatch({
        type: DropdownKeyDownBackspace
      });
    }
  }, _dropdownKeyDownHandl); // Event handlers.

  var selectedItemHandleClick = function (index) {
    dispatch({
      type: SelectedItemClick,
      index: index
    });
  };

  var selectedItemHandleKeyDown = function (event) {
    var key = normalizeArrowKey(event);

    if (key && selectedItemKeyDownHandlers[key]) {
      selectedItemKeyDownHandlers[key](event);
    }
  };

  var dropdownHandleKeyDown = function (event) {
    var key = normalizeArrowKey(event);

    if (key && dropdownKeyDownHandlers[key]) {
      dropdownKeyDownHandlers[key](event);
    }
  };

  var dropdownHandleClick = function () {
    dispatch({
      type: DropdownClick
    });
  }; // Getter props.


  return {
    getSelectedItemProps: function getSelectedItemProps(_temp) {
      var _extends2;

      var _ref = _temp === void 0 ? {} : _temp,
          _ref$refKey = _ref.refKey,
          refKey = _ref$refKey === void 0 ? 'ref' : _ref$refKey,
          ref = _ref.ref,
          onClick = _ref.onClick,
          onKeyDown = _ref.onKeyDown,
          selectedItem = _ref.selectedItem,
          index = _ref.index,
          rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref, ["refKey", "ref", "onClick", "onKeyDown", "selectedItem", "index"]);

      var itemIndex = getItemIndex(index, selectedItem, selectedItems);

      if (itemIndex < 0) {
        throw new Error('Pass either selectedItem or index in getSelectedItemProps!');
      }

      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends2 = {}, _extends2[refKey] = handleRefs(ref, function (selectedItemNode) {
        if (selectedItemNode) {
          selectedItemRefs.current.push(selectedItemNode);
        }
      }), _extends2.tabIndex = index === activeIndex ? 0 : -1, _extends2.onClick = callAllEventHandlers(onClick, function () {
        selectedItemHandleClick(index);
      }), _extends2.onKeyDown = callAllEventHandlers(onKeyDown, selectedItemHandleKeyDown), _extends2), rest);
    },
    getDropdownProps: function getDropdownProps(_temp2) {
      var _extends3;

      var _ref2 = _temp2 === void 0 ? {} : _temp2,
          _ref2$refKey = _ref2.refKey,
          refKey = _ref2$refKey === void 0 ? 'ref' : _ref2$refKey,
          ref = _ref2.ref,
          onKeyDown = _ref2.onKeyDown,
          onClick = _ref2.onClick,
          _ref2$preventKeyActio = _ref2.preventKeyAction,
          preventKeyAction = _ref2$preventKeyActio === void 0 ? false : _ref2$preventKeyActio,
          rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref2, ["refKey", "ref", "onKeyDown", "onClick", "preventKeyAction"]);

      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends3 = {}, _extends3[refKey] = handleRefs(ref, function (dropdownNode) {
        if (dropdownNode) {
          dropdownRef.current = dropdownNode;
        }
      }), _extends3), !preventKeyAction && {
        onKeyDown: callAllEventHandlers(onKeyDown, dropdownHandleKeyDown),
        onClick: callAllEventHandlers(onClick, dropdownHandleClick)
      }, {}, rest);
    },
    addSelectedItem: function addSelectedItem(selectedItem) {
      dispatch({
        type: FunctionAddSelectedItem,
        selectedItem: selectedItem
      });
    },
    removeSelectedItem: function removeSelectedItem(selectedItem) {
      dispatch({
        type: FunctionRemoveSelectedItem,
        selectedItem: selectedItem
      });
    },
    setSelectedItems: function setSelectedItems(newSelectedItems) {
      dispatch({
        type: FunctionSetSelectedItems,
        selectedItems: newSelectedItems
      });
    },
    setActiveIndex: function setActiveIndex(newActiveIndex) {
      dispatch({
        type: FunctionSetActiveIndex,
        activeIndex: newActiveIndex
      });
    },
    reset: function reset() {
      dispatch({
        type: FunctionReset$2
      });
    },
    selectedItems: selectedItems,
    activeIndex: activeIndex
  };
}

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Downshift);



/***/ }),

/***/ "../../node_modules/carbon-components-react/node_modules/downshift/node_modules/react-is/cjs/react-is.development.js":
/*!***************************************************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/node_modules/downshift/node_modules/react-is/cjs/react-is.development.js ***!
  \***************************************************************************************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";
/** @license React v16.13.1
 * react-is.development.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */





if (true) {
  (function() {
'use strict';

// The Symbol used to tag the ReactElement-like types. If there is no native Symbol
// nor polyfill, then a plain number is used for performance.
var hasSymbol = typeof Symbol === 'function' && Symbol.for;
var REACT_ELEMENT_TYPE = hasSymbol ? Symbol.for('react.element') : 0xeac7;
var REACT_PORTAL_TYPE = hasSymbol ? Symbol.for('react.portal') : 0xeaca;
var REACT_FRAGMENT_TYPE = hasSymbol ? Symbol.for('react.fragment') : 0xeacb;
var REACT_STRICT_MODE_TYPE = hasSymbol ? Symbol.for('react.strict_mode') : 0xeacc;
var REACT_PROFILER_TYPE = hasSymbol ? Symbol.for('react.profiler') : 0xead2;
var REACT_PROVIDER_TYPE = hasSymbol ? Symbol.for('react.provider') : 0xeacd;
var REACT_CONTEXT_TYPE = hasSymbol ? Symbol.for('react.context') : 0xeace; // TODO: We don't use AsyncMode or ConcurrentMode anymore. They were temporary
// (unstable) APIs that have been removed. Can we remove the symbols?

var REACT_ASYNC_MODE_TYPE = hasSymbol ? Symbol.for('react.async_mode') : 0xeacf;
var REACT_CONCURRENT_MODE_TYPE = hasSymbol ? Symbol.for('react.concurrent_mode') : 0xeacf;
var REACT_FORWARD_REF_TYPE = hasSymbol ? Symbol.for('react.forward_ref') : 0xead0;
var REACT_SUSPENSE_TYPE = hasSymbol ? Symbol.for('react.suspense') : 0xead1;
var REACT_SUSPENSE_LIST_TYPE = hasSymbol ? Symbol.for('react.suspense_list') : 0xead8;
var REACT_MEMO_TYPE = hasSymbol ? Symbol.for('react.memo') : 0xead3;
var REACT_LAZY_TYPE = hasSymbol ? Symbol.for('react.lazy') : 0xead4;
var REACT_BLOCK_TYPE = hasSymbol ? Symbol.for('react.block') : 0xead9;
var REACT_FUNDAMENTAL_TYPE = hasSymbol ? Symbol.for('react.fundamental') : 0xead5;
var REACT_RESPONDER_TYPE = hasSymbol ? Symbol.for('react.responder') : 0xead6;
var REACT_SCOPE_TYPE = hasSymbol ? Symbol.for('react.scope') : 0xead7;

function isValidElementType(type) {
  return typeof type === 'string' || typeof type === 'function' || // Note: its typeof might be other than 'symbol' or 'number' if it's a polyfill.
  type === REACT_FRAGMENT_TYPE || type === REACT_CONCURRENT_MODE_TYPE || type === REACT_PROFILER_TYPE || type === REACT_STRICT_MODE_TYPE || type === REACT_SUSPENSE_TYPE || type === REACT_SUSPENSE_LIST_TYPE || typeof type === 'object' && type !== null && (type.$$typeof === REACT_LAZY_TYPE || type.$$typeof === REACT_MEMO_TYPE || type.$$typeof === REACT_PROVIDER_TYPE || type.$$typeof === REACT_CONTEXT_TYPE || type.$$typeof === REACT_FORWARD_REF_TYPE || type.$$typeof === REACT_FUNDAMENTAL_TYPE || type.$$typeof === REACT_RESPONDER_TYPE || type.$$typeof === REACT_SCOPE_TYPE || type.$$typeof === REACT_BLOCK_TYPE);
}

function typeOf(object) {
  if (typeof object === 'object' && object !== null) {
    var $$typeof = object.$$typeof;

    switch ($$typeof) {
      case REACT_ELEMENT_TYPE:
        var type = object.type;

        switch (type) {
          case REACT_ASYNC_MODE_TYPE:
          case REACT_CONCURRENT_MODE_TYPE:
          case REACT_FRAGMENT_TYPE:
          case REACT_PROFILER_TYPE:
          case REACT_STRICT_MODE_TYPE:
          case REACT_SUSPENSE_TYPE:
            return type;

          default:
            var $$typeofType = type && type.$$typeof;

            switch ($$typeofType) {
              case REACT_CONTEXT_TYPE:
              case REACT_FORWARD_REF_TYPE:
              case REACT_LAZY_TYPE:
              case REACT_MEMO_TYPE:
              case REACT_PROVIDER_TYPE:
                return $$typeofType;

              default:
                return $$typeof;
            }

        }

      case REACT_PORTAL_TYPE:
        return $$typeof;
    }
  }

  return undefined;
} // AsyncMode is deprecated along with isAsyncMode

var AsyncMode = REACT_ASYNC_MODE_TYPE;
var ConcurrentMode = REACT_CONCURRENT_MODE_TYPE;
var ContextConsumer = REACT_CONTEXT_TYPE;
var ContextProvider = REACT_PROVIDER_TYPE;
var Element = REACT_ELEMENT_TYPE;
var ForwardRef = REACT_FORWARD_REF_TYPE;
var Fragment = REACT_FRAGMENT_TYPE;
var Lazy = REACT_LAZY_TYPE;
var Memo = REACT_MEMO_TYPE;
var Portal = REACT_PORTAL_TYPE;
var Profiler = REACT_PROFILER_TYPE;
var StrictMode = REACT_STRICT_MODE_TYPE;
var Suspense = REACT_SUSPENSE_TYPE;
var hasWarnedAboutDeprecatedIsAsyncMode = false; // AsyncMode should be deprecated

function isAsyncMode(object) {
  {
    if (!hasWarnedAboutDeprecatedIsAsyncMode) {
      hasWarnedAboutDeprecatedIsAsyncMode = true; // Using console['warn'] to evade Babel and ESLint

      console['warn']('The ReactIs.isAsyncMode() alias has been deprecated, ' + 'and will be removed in React 17+. Update your code to use ' + 'ReactIs.isConcurrentMode() instead. It has the exact same API.');
    }
  }

  return isConcurrentMode(object) || typeOf(object) === REACT_ASYNC_MODE_TYPE;
}
function isConcurrentMode(object) {
  return typeOf(object) === REACT_CONCURRENT_MODE_TYPE;
}
function isContextConsumer(object) {
  return typeOf(object) === REACT_CONTEXT_TYPE;
}
function isContextProvider(object) {
  return typeOf(object) === REACT_PROVIDER_TYPE;
}
function isElement(object) {
  return typeof object === 'object' && object !== null && object.$$typeof === REACT_ELEMENT_TYPE;
}
function isForwardRef(object) {
  return typeOf(object) === REACT_FORWARD_REF_TYPE;
}
function isFragment(object) {
  return typeOf(object) === REACT_FRAGMENT_TYPE;
}
function isLazy(object) {
  return typeOf(object) === REACT_LAZY_TYPE;
}
function isMemo(object) {
  return typeOf(object) === REACT_MEMO_TYPE;
}
function isPortal(object) {
  return typeOf(object) === REACT_PORTAL_TYPE;
}
function isProfiler(object) {
  return typeOf(object) === REACT_PROFILER_TYPE;
}
function isStrictMode(object) {
  return typeOf(object) === REACT_STRICT_MODE_TYPE;
}
function isSuspense(object) {
  return typeOf(object) === REACT_SUSPENSE_TYPE;
}

exports.AsyncMode = AsyncMode;
exports.ConcurrentMode = ConcurrentMode;
exports.ContextConsumer = ContextConsumer;
exports.ContextProvider = ContextProvider;
exports.Element = Element;
exports.ForwardRef = ForwardRef;
exports.Fragment = Fragment;
exports.Lazy = Lazy;
exports.Memo = Memo;
exports.Portal = Portal;
exports.Profiler = Profiler;
exports.StrictMode = StrictMode;
exports.Suspense = Suspense;
exports.isAsyncMode = isAsyncMode;
exports.isConcurrentMode = isConcurrentMode;
exports.isContextConsumer = isContextConsumer;
exports.isContextProvider = isContextProvider;
exports.isElement = isElement;
exports.isForwardRef = isForwardRef;
exports.isFragment = isFragment;
exports.isLazy = isLazy;
exports.isMemo = isMemo;
exports.isPortal = isPortal;
exports.isProfiler = isProfiler;
exports.isStrictMode = isStrictMode;
exports.isSuspense = isSuspense;
exports.isValidElementType = isValidElementType;
exports.typeOf = typeOf;
  })();
}


/***/ }),

/***/ "../../node_modules/carbon-components-react/node_modules/downshift/node_modules/react-is/index.js":
/*!********************************************************************************************************!*\
  !*** ../../node_modules/carbon-components-react/node_modules/downshift/node_modules/react-is/index.js ***!
  \********************************************************************************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

"use strict";


if (false) {} else {
  module.exports = __webpack_require__(/*! ./cjs/react-is.development.js */ "../../node_modules/carbon-components-react/node_modules/downshift/node_modules/react-is/cjs/react-is.development.js");
}


/***/ }),

/***/ "../../node_modules/classnames/index.js":
/*!**********************************************!*\
  !*** ../../node_modules/classnames/index.js ***!
  \**********************************************/
/***/ ((module, exports) => {

var __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;/*!
  Copyright (c) 2018 Jed Watson.
  Licensed under the MIT License (MIT), see
  http://jedwatson.github.io/classnames
*/
/* global define */

(function () {
	'use strict';

	var hasOwn = {}.hasOwnProperty;

	function classNames() {
		var classes = [];

		for (var i = 0; i < arguments.length; i++) {
			var arg = arguments[i];
			if (!arg) continue;

			var argType = typeof arg;

			if (argType === 'string' || argType === 'number') {
				classes.push(arg);
			} else if (Array.isArray(arg)) {
				if (arg.length) {
					var inner = classNames.apply(null, arg);
					if (inner) {
						classes.push(inner);
					}
				}
			} else if (argType === 'object') {
				if (arg.toString === Object.prototype.toString) {
					for (var key in arg) {
						if (hasOwn.call(arg, key) && arg[key]) {
							classes.push(key);
						}
					}
				} else {
					classes.push(arg.toString());
				}
			}
		}

		return classes.join(' ');
	}

	if ( true && module.exports) {
		classNames.default = classNames;
		module.exports = classNames;
	} else if (true) {
		// register as 'classnames', consistent with npm package name
		!(__WEBPACK_AMD_DEFINE_ARRAY__ = [], __WEBPACK_AMD_DEFINE_RESULT__ = (function () {
			return classNames;
		}).apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__),
		__WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	} else {}
}());


/***/ }),

/***/ "../../node_modules/compute-scroll-into-view/dist/index.module.js":
/*!************************************************************************!*\
  !*** ../../node_modules/compute-scroll-into-view/dist/index.module.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
function t(t){return"object"==typeof t&&null!=t&&1===t.nodeType}function e(t,e){return(!e||"hidden"!==t)&&"visible"!==t&&"clip"!==t}function n(t,n){if(t.clientHeight<t.scrollHeight||t.clientWidth<t.scrollWidth){var r=getComputedStyle(t,null);return e(r.overflowY,n)||e(r.overflowX,n)||function(t){var e=function(t){if(!t.ownerDocument||!t.ownerDocument.defaultView)return null;try{return t.ownerDocument.defaultView.frameElement}catch(t){return null}}(t);return!!e&&(e.clientHeight<t.scrollHeight||e.clientWidth<t.scrollWidth)}(t)}return!1}function r(t,e,n,r,i,o,l,d){return o<t&&l>e||o>t&&l<e?0:o<=t&&d<=n||l>=e&&d>=n?o-t-r:l>e&&d<n||o<t&&d>n?l-e+i:0}/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(e,i){var o=window,l=i.scrollMode,d=i.block,u=i.inline,h=i.boundary,a=i.skipOverflowHiddenElements,c="function"==typeof h?h:function(t){return t!==h};if(!t(e))throw new TypeError("Invalid target");for(var f=document.scrollingElement||document.documentElement,s=[],p=e;t(p)&&c(p);){if((p=p.parentElement)===f){s.push(p);break}null!=p&&p===document.body&&n(p)&&!n(document.documentElement)||null!=p&&n(p,a)&&s.push(p)}for(var m=o.visualViewport?o.visualViewport.width:innerWidth,g=o.visualViewport?o.visualViewport.height:innerHeight,w=window.scrollX||pageXOffset,v=window.scrollY||pageYOffset,W=e.getBoundingClientRect(),b=W.height,H=W.width,y=W.top,E=W.right,M=W.bottom,V=W.left,x="start"===d||"nearest"===d?y:"end"===d?M:y+b/2,I="center"===u?V+H/2:"end"===u?E:V,C=[],T=0;T<s.length;T++){var k=s[T],B=k.getBoundingClientRect(),D=B.height,O=B.width,R=B.top,X=B.right,Y=B.bottom,L=B.left;if("if-needed"===l&&y>=0&&V>=0&&M<=g&&E<=m&&y>=R&&M<=Y&&V>=L&&E<=X)return C;var S=getComputedStyle(k),j=parseInt(S.borderLeftWidth,10),q=parseInt(S.borderTopWidth,10),z=parseInt(S.borderRightWidth,10),A=parseInt(S.borderBottomWidth,10),F=0,G=0,J="offsetWidth"in k?k.offsetWidth-k.clientWidth-j-z:0,K="offsetHeight"in k?k.offsetHeight-k.clientHeight-q-A:0;if(f===k)F="start"===d?x:"end"===d?x-g:"nearest"===d?r(v,v+g,g,q,A,v+x,v+x+b,b):x-g/2,G="start"===u?I:"center"===u?I-m/2:"end"===u?I-m:r(w,w+m,m,j,z,w+I,w+I+H,H),F=Math.max(0,F+v),G=Math.max(0,G+w);else{F="start"===d?x-R-q:"end"===d?x-Y+A+K:"nearest"===d?r(R,Y,D,q,A+K,x,x+b,b):x-(R+D/2)+K/2,G="start"===u?I-L-j:"center"===u?I-(L+O/2)+J/2:"end"===u?I-X+z+J:r(L,X,O,j,z+J,I,I+H,H);var N=k.scrollLeft,P=k.scrollTop;x+=P-(F=Math.max(0,Math.min(P+F,k.scrollHeight-D+K))),I+=N-(G=Math.max(0,Math.min(N+G,k.scrollWidth-O+J)))}C.push({el:k,top:F,left:G})}return C}
//# sourceMappingURL=index.module.js.map


/***/ }),

/***/ "../../node_modules/css-loader/dist/cjs.js!../../node_modules/@elyra/canvas/dist/styles/common-canvas.min.css":
/*!********************************************************************************************************************!*\
  !*** ../../node_modules/css-loader/dist/cjs.js!../../node_modules/@elyra/canvas/dist/styles/common-canvas.min.css ***!
  \********************************************************************************************************************/
/***/ ((module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../../../css-loader/dist/runtime/cssWithMappingToString.js */ "../../node_modules/css-loader/dist/runtime/cssWithMappingToString.js");
/* harmony import */ var _css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../../css-loader/dist/runtime/api.js */ "../../node_modules/css-loader/dist/runtime/api.js");
/* harmony import */ var _css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__);
// Imports


var ___CSS_LOADER_EXPORT___ = _css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default()((_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0___default()));
// Module
___CSS_LOADER_EXPORT___.push([module.id, ".properties-action-button{display:inline-block}.properties-action-button.hide{display:none}.properties-control-item>.properties-action-button,.properties-ctrl-wrapper>.properties-action-button{padding-top:1rem}.properties-action-image{padding:0 0 0 .5rem;cursor:pointer;align-self:flex-end}.properties-action-image.left{order:-1;padding:0 .5rem 0 0}.properties-action-image.hide{display:none}.properties-action-image.disabled{cursor:not-allowed;opacity:.5}.properties-control-item.hide{display:none}.properties-control-item[disabled] .properties-label-container,.properties-control-item[disabled] .properties-control-description{opacity:.5;pointer-events:none}.properties-control-item .properties-action-image.right{margin-left:auto;float:right}.properties-control-item .properties-action-image.left{float:left}.properties-label-container{display:flex;align-items:center;padding-bottom:.5rem}.properties-label-container label,.properties-label-container .properties-required-indicator{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;color:#525252}.properties-label-container.table-control label,.properties-label-container.table-control .properties-required-indicator{font-size:.875rem;font-weight:600;line-height:1.28572;letter-spacing:.16px;color:#161616}.properties-label-container .tooltip-container,.properties-summary-link-container .tooltip-container{display:flex;width:16px;height:16px;margin-left:.5rem;cursor:pointer}.properties-control-description{font-size:.75rem;line-height:1.33333;letter-spacing:.32px;color:#525252;padding-bottom:.5rem}.bx--label .properties-label-container{padding-bottom:0}.properties-title-editor{padding:1rem 0;border-bottom:1px #e0e0e0 solid}.properties-title-heading{padding:0 1rem .25rem;height:1.5rem;display:flex;align-items:center}.properties-title-heading .properties-title-heading-icon{height:1.5rem;width:1.5rem;margin-right:.5rem}.properties-title-heading .properties-title-heading-label{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px}.properties-title-heading .properties-title-editor-btn.help.help{margin:0 0 0 .25rem}.properties-title-editor-input{width:calc(100% - 0.5rem);top:1px;position:relative;display:inline-flex;align-items:center}.properties-title-editor-input.properties-title-editor-with-help{width:calc(100% - 2rem - 0.5rem)}.properties-title-editor-input .bx--form-item.bx--text-input-wrapper{width:100%}.properties-title-editor-input .bx--form-item.bx--text-input-wrapper input{font-size:1rem;font-weight:600;line-height:1.375;letter-spacing:0;color:#161616;min-width:unset;background:unset;text-overflow:ellipsis;border-bottom:unset}.properties-title-editor-input .bx--form-item.bx--text-input-wrapper input[readonly]{box-shadow:unset;cursor:default}.properties-title-editor-input .bx--form-item.bx--text-input-wrapper .bx--form-requirement{margin:.25rem 0 0 1rem}.properties-title-editor-input .bx--form-item.bx--text-input-wrapper .bx--text-input__field-wrapper--warning input{border-bottom:1px solid #8d8d8d}.properties-title-editor-input .properties-title-editor-btn{position:absolute;right:.125rem}.properties-title-editor-with-warning,.properties-title-editor-with-error{width:calc(100% - 2px)}.properties-title-editor-btn.help,.properties-title-editor-btn.edit{fill:#525252;width:2rem;min-height:2rem;padding-left:.75rem;padding-right:.75rem}.properties-title-editor-btn.help:hover,.properties-title-editor-btn.edit:hover{background-color:#e0e0e0}.properties-title-editor-btn.help:active,.properties-title-editor-btn.edit:active{background-color:#e0e0e0}.properties-close-button{position:relative;display:flex;align-items:center;justify-content:flex-end;padding-right:.5rem}.properties-title-with-heading>.properties-close-button{position:absolute;top:.5rem;right:.5rem;display:flex;align-items:center;justify-content:center;padding:0}.properties-mr-button-container{width:16px;padding-left:2px;height:100%;display:flex;flex-direction:column;justify-content:center}.table-row-move-button.bx--btn--ghost{padding:0;min-height:24px;margin-bottom:8px}.table-row-move-button.bx--btn--ghost>svg{height:16px;width:16px;margin-left:0}.properties-mr-table-container{width:100%;display:inline-block}.properties-mr-table-container>tbody{width:100%;display:inline-block}.properties-mr-table-container>tbody .properties-mr-table-content{width:100%;display:flex;border-bottom:0}.properties-mr-table-container>tbody .properties-mr-table-content.disabled{pointer-events:none;opacity:.5}.properties-mr-table-container>tbody .properties-mr-table-content>td:first-of-type{width:100%}.properties-wf-content .properties-fp-table .properties-ft-container-wrapper{height:100%}.properties-fp-data{height:100%;display:flex;align-items:center}.properties-fp-field,.properties-fp-data{padding-left:1rem;display:flex;align-items:center}.properties-fp-schema{padding-left:1rem}.properties-fp-field-type-icon,.properties-fp-data-type-icon{display:flex;align-items:center;margin-right:.5rem}.properties-fp-field-type-icon>svg,.properties-fp-data-type-icon>svg{width:1rem;height:1rem}.properties-fp-filter-list{display:flex;align-items:center}.properties-fp-filter-list .properties-fp-filter-list-title.properties-fp-filter-list-li{width:auto;margin-left:1rem}.properties-fp-filter-list .properties-fp-filter-list-li{float:left;padding:.125rem}.properties-fp-filter-list .properties-fp-filter-list-li button{min-height:1rem;padding:0;border:0}.properties-fp-filter-list .properties-fp-filter-list-li svg{height:1rem;width:1rem;margin:.125rem}.properties-fp-filter-list .properties-fp-filter-list-li svg[disabled]{fill:#c6c6c6}.properties-fp-table{width:100%;height:100%}.properties-fp-table .properties-fp-top-row{width:50%;float:right;display:flex;justify-content:space-between}.properties-fp-table .properties-fp-top-row .properties-fp-reset-button-container span{margin-right:.25rem}.properties-modal .properties-fp-top-row{width:100%;margin-bottom:.5rem;display:flex;justify-content:space-between}.properties-modal .properties-fp-top-row .properties-fp-button-label{position:relative;top:.5rem}.properties-modal .properties-fp-top-row .properties-fp-back-button{height:2rem;width:2rem;padding:0;margin-right:.5rem}.properties-modal .properties-fp-top-row .properties-fp-back-button>svg{left:.5rem}.properties-modal .properties-fp-filter-list{float:right}.properties-modal .bx--modal-close{display:none}.properties-modal .bx--modal-container{padding:0}.properties-modal .bx--modal-content{margin-bottom:0;padding:0}.properties-modal.noButtons .bx--modal-footer{opacity:0;pointer-events:none}.properties-wf-overlay{position:fixed;display:none;top:0;left:0;right:0;bottom:0;background-color:#161616;z-index:1000;cursor:default}.properties-wf-overlay.show{display:block;opacity:.5}.properties-wf-content{position:fixed;display:block;width:675px;margin-right:-675px;z-index:1001;background-color:#fff;right:0;transition:margin-right .1s}.properties-wf-content.show{margin-right:0;transition:margin-right .3s}.properties-wf-content .properties-wf-title{font-size:.875rem;font-weight:600;line-height:1.28572;letter-spacing:.16px;padding-left:1.5rem;display:flex;align-items:center;height:41px;border-bottom:1px solid #e0e0e0}.properties-wf-content .properties-wf-children{padding:1rem;overflow-y:auto;height:calc(100% - 41px - 64px)}.properties-light-disabled{background-color:#f4f4f4}.properties-validation-message{margin-top:.25rem;display:flex}.properties-validation-message .icon{margin:0 .125rem}.properties-validation-message .icon .properties-validation-icon-warning{fill:#f1c21b}.properties-validation-message .icon .properties-validation-icon-warning [data-icon-path=inner-path]{fill:#161616;opacity:1}.properties-validation-message .icon .properties-validation-icon-error{fill:#da1e28}.properties-validation-message .icon .properties-validation-icon-info{fill:#0043ce}.properties-validation-message .icon .properties-validation-icon-success{fill:#198038}.properties-validation-message span{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;color:#161616}.properties-validation-message.error span{color:#da1e28}.properties-validation-message.hide{display:none}.properties-validation-message.inTable{margin-top:0;position:absolute;top:0}.properties-validation-message.inTable .icon svg{height:.5rem;width:.5rem}.properties-modal-buttons{justify-content:flex-end;display:flex;height:4rem;bottom:0;position:absolute;width:100%;left:0}.properties-modal-buttons.hide{display:none}.properties-modal-buttons .properties-apply-button,.properties-modal-buttons .properties-cancel-button{width:50%;max-width:unset;padding:0 0 1rem 1rem}.properties-primaryTabs .bx--tabs__nav-item{margin-left:1rem}.properties-category{padding:1rem}.properties-category-container{position:relative}.properties-category-container:last-of-type .properties-category-content.show{border-bottom:0}.properties-category-title{font-size:.875rem;font-weight:400;line-height:1.42857;letter-spacing:.16px;-webkit-text-decoration-color:#161616;text-decoration-color:#161616;color:#161616;height:46px;width:100%;display:flex;background-color:#f4f4f4;justify-content:space-between;align-items:center;padding:0 1rem;border:0;outline:none;border-bottom:1px solid #e0e0e0;cursor:pointer}.properties-category-title:hover{background-color:#e5e5e5}.properties-category-title>svg{height:20px;width:20px;fill:#161616}.properties-category-content{height:100%;padding:1rem;border-bottom:1px solid #e0e0e0;display:none}.properties-category-content.show{display:inherit}.properties-subtabs .bx--tabs__nav,.properties-primaryTabs .bx--tabs__nav{overflow-x:auto}.properties-static-text-container{display:flex;align-items:center;padding:.25rem 0}.properties-static-text-container .properties-static-text{font-size:.875rem;font-weight:400;line-height:1.28572;letter-spacing:.16px;color:#161616}.properties-static-text-container .properties-static-text.info{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;color:#525252}.properties-static-text-container svg{width:16px;height:16px;margin-right:.5rem}.properties-h-separator{margin-top:1rem;margin-bottom:1rem}.properties-link-text-container{display:flex;padding:.75rem 0 0 0}.properties-link-text-container svg{margin-right:1rem;margin-top:1px;width:16px;height:16px;flex-shrink:0}.properties-link-text-container .properties-link-text{font-size:.875rem;font-weight:400;line-height:1.28572;letter-spacing:.16px}.properties-light-enabled{background-color:#fff}.properties-custom-panel+.properties-control-panel{padding-top:1rem}.properties-ft-table-header{display:flex;justify-content:flex-end;height:2rem}.properties-ft-table-header .properties-ft-search-container{min-width:50%;flex-grow:1}.properties-ft-table-header .properties-ft-search-container .properties-ft-search-text svg{fill:#161616}.properties-ft-table-header .properties-ft-search-container .properties-ft-search-text input{background-color:#f4f4f4}.properties-ft-table-header .properties-ft-search-container.disabled{opacity:.5}.properties-ft-container-panel{height:calc(100% - 2rem)}.properties-ft-control-container{height:100%}.properties-ft-container-wrapper{height:400px;width:100%;position:relative;overflow:hidden}.properties-ft-container-absolute-noheader{position:absolute;height:100%;width:100%;overflow-y:auto;overflow-x:hidden;background-color:#fff;display:flex;flex-direction:column}.properties-ft-container-absolute-noheader.error{border:1px solid #da1e28}.properties-ft-container-absolute-noheader.warning{border:1px solid #f1c21b}.properties-ft-container-absolute{height:100%;width:100%;background-color:#fff}.properties-ft-container-absolute.error{border:1px solid #da1e28}.properties-ft-container-absolute.warning{border:1px solid #f1c21b}.properties-ft-container-absolute .properties-ft-container{height:100%}.properties-ft-container-absolute div[data-role=properties-header-row]{width:inherit;display:inline-flex}.properties-ft-container-absolute div[data-role=properties-header-row] .properties-autosized-vt-header:focus{outline:none}.properties-ft-container-absolute div[data-role=properties-header-row] .properties-autosized-vt-header .properties-ft-column-sort-icon svg:not(:root){display:none}.properties-ft-container-absolute div[data-role=properties-header-row] .properties-autosized-vt-header:hover:not([disabled]) .properties-ft-column-sort-icon svg:not(:root){display:inline}.properties-ft-container-absolute div[data-role=properties-header-row] .properties-autosized-vt-header .sort-column-active>.properties-ft-column-sort-icon svg:not(:root){display:inline}.properties-ft-container-absolute div[data-role=properties-header-row] .properties-tooltips-container{display:inline-flex;justify-content:space-between;width:100%;align-self:center;padding:0 1rem}.properties-ft-container-absolute div[data-role=properties-header-row] .tooltip-container{overflow:hidden}.properties-ft-container-absolute div[data-role=properties-header-row] .tooltip-trigger{overflow:hidden;text-overflow:ellipsis;white-space:nowrap;height:100%;font-weight:600}.properties-truncated-tooltip{overflow:hidden}.properties-truncated-tooltip .tooltip-trigger{width:inherit;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.properties-vt{width:100%;height:100%}.properties-vt .properties-autosized-vt>div[role=rowgroup]:focus{outline-style:none}.properties-vt .properties-autosized-vt .properties-vt-row-disabled{opacity:.5}.properties-vt .properties-autosized-vt .properties-vt-row-disabled:hover{border-bottom:1px solid #e0e0e0}.properties-vt .properties-vt-header-checkbox{height:2rem;display:flex;align-items:center;margin-left:1rem;margin-right:.25rem}.properties-vt div[data-role=properties-header-row]{background-color:#e0e0e0}.properties-vt div[data-role=properties-data-row]{background-color:#f4f4f4}.properties-vt .properties-autosized-vt-header{text-transform:none;margin-left:0}.properties-vt .properties-autosized-vt-header .properties-vt-column .bx--checkbox-wrapper{margin-top:0;margin-bottom:0}.properties-vt .properties-autosized-vt-header .properties-vt-column .bx--checkbox-wrapper .bx--checkbox-label{width:100%}.properties-vt .properties-autosized-vt-header .properties-vt-column .bx--checkbox-wrapper .bx--checkbox-label span{font-size:.875rem;font-weight:600;line-height:1.28572;letter-spacing:.16px;color:#161616;text-overflow:ellipsis;white-space:nowrap;overflow:hidden;width:100%;line-height:unset}.properties-vt .properties-vt-column-with-resize,.properties-vt .properties-vt-column-without-resize{display:inline-flex;width:100%}.properties-vt .properties-vt-column-with-resize .properties-vt-header-resize{flex:0 0 .25rem;z-index:2;cursor:col-resize}.properties-vt .properties-vt-column-with-resize .properties-vt-header-resize:hover{background-color:#6f6f6f}.properties-vt .properties-vt-column-with-resize .properties-vt-header-resize-active{z-index:3}.properties-vt .properties-vt-column-with-resize:hover{background-color:#c6c6c6}.properties-vt .properties-vt-column-with-resize:hover .properties-vt-header-resize{background-color:#6f6f6f}.properties-vt .properties-vt-row-checkbox{height:2rem;margin-left:1rem;margin-right:.25rem}.properties-vt .properties-vt-double-click:first-of-type .properties-vt-row-class{border-top:1px solid transparent}.properties-vt .properties-vt-double-click:first-of-type .properties-vt-row-class.properties-vt-row-selected{border-top:1px solid #cacaca}.properties-vt .properties-vt-row-class{line-height:20px;border-bottom:1px solid #e0e0e0}.properties-vt .properties-vt-row-class:hover:not(.properties-vt-row-non-interactive):not(.properties-vt-row-selected){background-color:#e5e5e5}.properties-vt .properties-vt-row-class .properties-table-cell-control .properties-numberfield input{margin-bottom:5px}.properties-vt .properties-vt-row-class .properties-table-cell-control .properties-textarea textarea{resize:none;height:42px;min-width:100%}.properties-vt .properties-vt-row-class .ReactVirtualized__Table__headerColumn{margin-right:0;display:flex;flex-direction:row;justify-content:center;height:100%}.properties-vt .properties-vt-row-class .ReactVirtualized__Table__rowColumn{margin-right:0;margin-left:0}.properties-vt .properties-vt-row-class .ReactVirtualized__Table__sortableHeaderColumn .properties-tooltips-container{padding:0;padding-left:1rem}.properties-vt .properties-vt-row-class .ReactVirtualized__Table__sortableHeaderColumn:hover{background-color:#c6c6c6}.properties-vt .properties-vt-row-class .ReactVirtualized__Table__headerTruncatedText{flex:auto}.properties-vt .properties-vt-row-selected{background-color:#e0e0e0;border-bottom:1px solid #cacaca}.properties-vt .properties-vt-row-selected:hover{background-color:#cacaca}.properties-vt .properties-vt-single-selection div[data-role=properties-header-row]{padding-left:3px}.properties-vt .properties-vt-single-selection .properties-vt-row-class{padding-left:3px}.properties-vt .properties-vt-single-selection .properties-vt-row-selected{border-left:4px solid #0f62fe;padding-left:0}.properties-vt .properties-vt-single-selection .properties-vt-row-selected:not(.properties-vt-row-disabled):hover{border-left:4px solid #0f62fe}.properties-vt .properties-vt-small-loading svg{stroke:#0f62fe}.properties-vt .properties-vt-autosizer{height:100%;width:100%}.properties-vt .properties-light-disabled div[data-role=properties-data-row]{background-color:#fff}.properties-vt .properties-light-disabled .bx--select--inline .bx--select-input[disabled]{background-color:#f4f4f4}.properties-vt .properties-ft-column-sort-icon{flex:0 0 1rem;align-self:center;height:1rem;margin-right:.5rem}.properties-empty-table{font-size:.875rem;font-weight:400;line-height:1.28572;letter-spacing:.16px}.properties-empty-table[disabled]{opacity:.5;pointer-events:none}.properties-empty-table .properties-empty-table-button{margin:1rem 0}.properties-custom-table-buttons .toolbar-div{height:2rem}.properties-custom-table-buttons .toolbar-div .toolbar-left-bar{padding-right:0}.properties-custom-table-buttons .toolbar-div .toolbar-left-bar .toolbar-item button{height:2rem}.properties-custom-table-buttons .toolbar-div .toolbar-left-bar .toolbar-item-content{padding:.25rem .5rem;height:2rem;min-width:2rem;align-items:center}.properties-custom-table-buttons .toolbar-div .toolbar-left-bar .toolbar-overflow-item button{height:2rem}.properties-custom-table-buttons .toolbar-div .toolbar-left-bar .toolbar-popover-list{top:2rem;right:0}.properties-custom-table-buttons .toolbar-div .toolbar-right-bar{display:none}.properties-readonly.hide{display:none}.properties-readonly .properties-tooltips{white-space:normal;overflow:visible;word-break:break-word;text-overflow:clip}.properties-readonly span{white-space:normal;line-height:1.5;overflow-wrap:break-word;-webkit-user-select:text;-moz-user-select:text;-ms-user-select:text;user-select:text;cursor:text}.properties-readonly span[disabled]{opacity:.5;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;cursor:default}.properties-readonly .properties-field-readonly{height:100%;width:inherit;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;display:flex;align-items:center}.properties-readonly .properties-field-readonly .properties-field-type-icon{width:15px;height:15px;float:left;margin-right:5px;flex-shrink:0}.properties-readonly .properties-field-readonly .properties-field-type-icon svg{width:16px;height:16px}.properties-readonly .tooltip-trigger span{white-space:nowrap}.properties-checkbox{display:flex;align-items:center;flex-wrap:wrap}.properties-checkbox .tooltip-container{margin-left:.5rem;cursor:pointer}.properties-checkbox .tooltip-container .tooltip-trigger{display:flex}.properties-checkbox .bx--form-item.bx--checkbox-wrapper{flex:initial}.properties-checkbox .properties-validation-message{flex:0 1 100%}.properties-checkbox.hide{display:none}.table .bx--form-item.bx--checkbox-wrapper:first-of-type{margin-top:0;padding:1px}.properties-checkboxset.hide{display:none}.properties-checkboxset .bx--checkbox-wrapper{margin-bottom:.5rem}.properties-checkboxset .properties-checkboxset-container.error:not([disabled]){padding-bottom:.25rem}.properties-checkboxset .properties-checkboxset-container.warning:not([disabled]){padding-bottom:.25rem}.properties-dropdown .bx--list-box--expanded .bx--list-box__menu{margin-bottom:1px}.properties-dropdown.hide{display:none}.properties-table-cell-control>.properties-dropdown{width:100%}.properties-table-cell-control>.properties-dropdown .bx--select.bx--select--inline{width:100%}.properties-table-cell-control>.properties-dropdown .bx--select.bx--select--inline .bx--select-input--inline__wrapper{width:100%}.properties-table-cell-control>.properties-dropdown .bx--select.bx--select--inline svg{right:0}.properties-table-cell-control>.properties-dropdown .bx--select-input{width:inherit;background-color:transparent;padding:0 1.25rem 0 0;box-shadow:0 2px 0 0 #0f62fe}.properties-table-cell-control>.properties-dropdown .bx--select-input:hover{background:unset}.properties-table-cell-control>.properties-dropdown .bx--select-input:focus{outline:unset}.properties-table-cell-control>.properties-dropdown.error .bx--select-input{box-shadow:0 2px 0 0 #da1e28}.properties-table-cell-control>.properties-dropdown.warning .bx--select-input{box-shadow:0 2px 0 0 #f1c21b}.properties-expression-selection-container,.properties-field-and-values-table-container,.properties-functions-table-container{width:100%}.properties-expression-selection-container tbody tr,.properties-field-and-values-table-container tbody tr,.properties-functions-table-container tbody tr{border-bottom:0}.properties-expression-selection-container{padding-top:.5rem}.properties-expression-selection-operator{padding-bottom:2rem}.properties-field-table-container{width:48%;float:left}.properties-field-table-container .properties-ft-search-container{width:100%}.properties-value-table-container{width:48%;margin-left:52%}.properties-value-table-container .properties-ft-search-container{width:100%}.properties-functions-table{width:68%;float:left}.properties-functions-table .properties-ft-search-container{width:100%}.properties-help-table-container{width:28%;margin-left:70%}.properties-function-help-command{font-weight:700;text-decoration:underline}.properties-function-help-text{overflow-wrap:break-word}.properties-operator-title{padding-top:1rem;padding-bottom:2rem;width:100%;font-weight:bold;text-align:center}.properties-operator-container{display:flex;flex-wrap:wrap}.properties-operator-container .properties-operator-tooltip-container{width:36px;margin-right:.5rem;margin-top:.5rem}.properties-operator-container .properties-operator-button{height:36px;width:36px;padding:0}.properties-operator-container .properties-operator-button .properties-operator-button-label{margin:0 auto}.properties-expression-selection-content-switcher{padding-bottom:2.5rem}.properties-expression-selection-content-switcher div{max-width:50%;float:right}.properties-expression-field-select,.properties-expression-function-select{padding-top:1.5rem;padding-bottom:1.5rem}.properties-expression-table-dropdown-header{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;padding-bottom:.25rem}.properties-primaryTabs .bx--tabs-trigger{margin-bottom:5px}.CodeMirror-hints{z-index:1110}.CodeMirror-placeholder{opacity:.5}.CodeMirror{width:100%;background:#f4f4f4;color:#161616}.CodeMirror-cursor{border-left:1px solid #161616}.cm-s-error.CodeMirror{border:.125rem solid #da1e28}.cm-s-warning.CodeMirror{border:.125rem solid #f1c21b}.cm-s-disabled.CodeMirror{opacity:.5}.cm-s-custom .cm-keyword{color:#0f62fe}.cm-s-custom .cm-number{color:#525252}.cm-s-custom .cm-def{color:#da1e28}.cm-s-custom .cm-comment{color:#198038}.cm-s-custom .cm-variable,.cm-s-custom .cm-punctuation,.cm-s-custom .cm-property,.cm-s-custom .cm-operator{color:#161616}.cm-s-custom .cm-variable-2{color:#161616}.cm-s-custom .cm-variable-3,.cm-s-custom .cm-type{color:#161616}.cm-s-custom .cm-string{color:#da1e28}.cm-s-custom .cm-string-2{color:#da1e28}.cm-s-custom .cm-meta{color:#fff}.properties-expression-editor{border:1px solid #e0e0e0}.properties-expression-editor.disabled{opacity:.5}.properties-expression-editor.error,.properties-expression-editor.warning{border:0}.properties-light-disabled .CodeMirror{background:#fff}.properties-expression-link-container{display:flex;justify-content:space-between}.properties-expression-link-container .properties-expression-validate{display:flex;flex-direction:row-reverse}.properties-expression-link-container .properties-expression-validate .icon{margin:.125rem}.properties-expression-link-container .properties-expression-validate .icon svg{height:10px;width:10px}.properties-expression-link-container .properties-expression-validate .validateLink{min-height:2rem;padding:.25rem}.properties-expression-header{position:relative;height:2rem}.properties-expression-header .properties-expression-title{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;position:absolute;bottom:5px;left:0}.properties-expression-header .properties-expression-link-container{position:absolute;bottom:0;right:0}.properties-expression-button.bx--btn--sm.bx--btn--ghost{padding:.25rem}.properties-expression-button.bx--btn--sm.bx--btn--ghost svg{height:20px;width:20px;margin-left:0}.properties-radioset.hide{display:none}.properties-radioset .bx--form-item{margin-bottom:.25rem}.properties-radio-button-group{display:block}.properties-radio-button-group.horizontal{display:inline-flex;flex-wrap:wrap}.properties-radio-button-group.horizontal .properties-radioset-panel{margin-bottom:0}.properties-radio-button-group .properties-radioset-panel{margin-bottom:.25rem;margin-right:.75rem}.properties-radio-button-group .properties-radioset-panel:last-of-type{margin-bottom:0}.properties-radio-button-group .properties-radioset-panel .bx--radio-button-wrapper>label{justify-content:left}.properties-radio-button-group.error:not([disabled]){padding-bottom:.25rem}.properties-radio-button-group.warning:not([disabled]){padding-bottom:.25rem}.properties-textarea .bx--form-item{margin-right:0;margin-bottom:0}.properties-textarea.hide{display:none}.properties-someofselect .properties-ft-container-absolute-noheader tr{border-bottom:0}.properties-someofselect .properties-ft-container-absolute-noheader tr:not(.disabled):hover{border:1px solid #0f62fe}.properties-someofselect.hide{display:none}.properties-someofselect.error .properties-ft-container-absolute-noheader{border:1px solid #da1e28}.properties-someofselect.warning .properties-ft-container-absolute-noheader{border:1px solid #f1c21b}.properties-someofselect .properties-vt-row-checkbox{margin-right:1rem}.properties-toggletext.hide{display:none}.properties-toggletext.error button{border-bottom:2px solid #da1e28}.properties-toggletext.warning button{border-bottom:2px solid #f1c21b}.properties-table-cell-control .properties-toggletext button{padding:0 .25rem}.properties-input-control.hide{display:none}.properties-input-control .bx--form-item{margin-right:0;margin-bottom:0}.properties-input-control input{min-width:unset}.properties-table-cell-control .properties-input-control{padding-bottom:5px;width:100%}.properties-table-cell-control .properties-input-control input{background:unset;background-color:unset;margin:0;padding:0;height:1.72rem}.properties-table-cell-control .properties-input-control input:focus{border-top:0;border-right:0;border-left:0}.properties-table-cell-control .properties-input-control.error input:not([disabled]){box-shadow:0 2px 0 0 #da1e28}.properties-table-cell-control .properties-input-control.warning input:not([disabled]){box-shadow:0 2px 0 0 #f1c21b}.properties-table-cell-control input:disabled:hover{box-shadow:0 2px 0 0 #525252}.properties-table-cell-control .properties-textinput-readonly{margin-bottom:-5px}.properties-table-cell-control .properties-textinput-readonly .properties-validation-message.inTable{margin-left:-0.75rem}.properties-table-cell-control>div>:first-child{padding:0 1rem}.properties-table-subcell{display:flex;align-items:center;height:100%}.properties-at-selectedEditRows{background-color:#393939}.properties-at-selectedEditRows .properties-selectedEditRows-title{padding-top:10px;padding-bottom:10px;padding-left:12px;color:#fff}.properties-at-selectedEditRows .properties-ft-table-header{display:none}.properties-at-selectedEditRows .properties-vt-row-checkbox{width:1.25rem}.properties-at-selectedEditRows .properties-vt-row-class{background-color:#e0e0e0}.properties-at-selectedEditRows .properties-vt-row-class:hover{border:1px solid transparent;background-color:#cacaca}.properties-numberfield .bx--form-item{margin-right:0;margin-bottom:0}.properties-numberfield .properties-number-generator{margin-left:1rem;right:.125rem;width:2.5rem;min-height:2.5rem;padding-left:.75rem;padding-right:.75rem}.properties-numberfield.numberfield-with-number-generator{width:100%;display:inline-flex;align-items:flex-end}.properties-numberfield.numberfield-with-number-generator.error,.properties-numberfield.numberfield-with-number-generator.warning{align-items:flex-start}.properties-numberfield.numberfield-with-number-generator.error .properties-number-generator,.properties-numberfield.numberfield-with-number-generator.warning .properties-number-generator{margin-top:1.5rem}.properties-table-cell-control .properties-numberfield .bx--number[data-invalid] .bx--form-requirement{display:none}.properties-table-cell-control .properties-numberfield.error input[type=number]:not([disabled]),.properties-table-cell-control .properties-numberfield.error input[type=number]:focus:not([disabled]){box-shadow:0 2px 0 0 #da1e28}.properties-table-cell-control .properties-numberfield.warning input[type=number]:not([disabled]),.properties-table-cell-control .properties-numberfield.warning input[type=number]:focus:not([disabled]){box-shadow:0 2px 0 0 #f1c21b}.properties-table-cell-control .properties-numberfield input[type=number]{background-color:unset;padding:0;height:1.5rem}.properties-table-cell-control .properties-numberfield .bx--number input[type=number]{min-width:0}.properties-structureeditor .hide{display:none}.properties-structureeditor-cell{padding-right:5px;vertical-align:middle}.properties-table-cell-control .properties-dropdown .bx--multi-select__wrapper>label{display:none}.properties-ctrl-wrapper{padding-bottom:1rem}.properties-ctrl-wrapper.action{display:flex}.properties-ctrl-wrapper.action>div:first-child{width:100%}.properties-ctrl-wrapper.hide{display:none}.properties-summary-panel.properties-summary-panel.hide{display:none}.properties-summary-panel.properties-summary-panel[disabled]{opacity:.5;pointer-events:none}.properties-summary-panel.properties-summary-panel .properties-summary-link-icon{width:16px;height:16px}.properties-summary-link-container{display:flex;align-items:center}.properties-summary-values{border-top:1px solid #e0e0e0;padding:1rem 0}.properties-summary-table{font-size:.875rem;font-weight:400;line-height:1.28572;letter-spacing:.16px;color:#161616;max-height:270px;width:100%;display:flex;margin:.5rem 0}.properties-summary-table>tbody{width:100%}.properties-summary-label{font-size:.875rem;font-weight:600;line-height:1.28572;letter-spacing:.16px;color:#161616;margin-bottom:1rem}.properties-summary-row-data>.tooltip-container{margin:1px 0}.properties-summary-row-data>.tooltip-container>div:first-child{text-overflow:ellipsis;white-space:nowrap;overflow:hidden}.properties-summary-row{display:flex;justify-content:space-between;padding:2px 0}button.properties-subpanel-button{padding:0;min-height:2rem;height:2rem;width:2rem;display:flex;justify-content:center}.properties-sub-tab-container .bx--tab-content{padding-left:0;padding-right:0}.properties-twisty-panel.hide{display:none}.properties-twisty-panel .bx--accordion__item{border-top:0;margin:0 -1rem}.properties-twisty-panel .bx--accordion__item--active .bx--accordion__content{padding:1.5rem 1rem 1rem}.properties-twisty-panel+.properties-control-panel{padding-top:1rem}.properties-text-panel :not(:empty){padding-bottom:1rem}.properties-text-panel .panel-label{font-size:.875rem;font-weight:600;line-height:1.28572;letter-spacing:.16px;color:#161616;padding-bottom:.5rem}.properties-text-panel .panel-description{font-size:.875rem;font-weight:400;line-height:1.28572;letter-spacing:.16px;color:#161616}.properties-text-panel[disabled]{opacity:.5;pointer-events:none}.properties-text-panel.hide{display:none}.properties-action-panel{display:flex;flex-wrap:wrap;padding-bottom:.5rem}.properties-action-panel:last-child{padding-bottom:1.5rem}.properties-action-panel[disabled]{opacity:.5;pointer-events:none}.properties-action-panel.hide{display:none}.properties-action-panel+.properties-control-panel{padding-top:.5rem}.properties-column-panel{display:grid;-moz-column-gap:1rem;column-gap:1rem}.properties-column-panel .properties-control-panel:not(:empty)+.properties-control-panel:not(:empty){padding-top:0}.properties-column-panel.hide{display:none}.properties-column-panel[disabled]{opacity:.5;pointer-events:none}.properties-control-panel{display:block}.properties-control-panel:last-child{padding-bottom:.5rem}.properties-control-panel.hide{display:none}.properties-control-panel[disabled]{opacity:.5;pointer-events:none}.properties-control-panel>.properties-control-panel:not(:empty):last-child{padding-bottom:0}.properties-control-panel+.properties-control-panel:not(:empty){padding-top:1.5rem}.properties-control-nested-panel{padding:0 0 0 1rem;border-left:1px solid #8d8d8d}.properties-control-nested-panel .properties-control-nested-panel{border-left:1px solid #e0e0e0}:export{flyoutWidthSmall:320px;flyoutWidthMedium:480px;flyoutWidthLarge:640px}.properties-right-flyout{font-size:14px;width:0;height:100%;overflow:hidden;border-left:1px solid #e0e0e0;outline:none}.properties-right-flyout.properties-small{width:320px}.properties-right-flyout.properties-medium{width:480px}.properties-right-flyout.properties-large{width:640px}.properties-right-flyout:hover .properties-btn-resize{visibility:visible;opacity:1}.properties-right-flyout .properties-btn-resize{transition:visibility 240ms,opacity 240ms;opacity:0;visibility:hidden;position:absolute;top:50%;left:-13px;z-index:1;min-height:24px;min-width:24px;background-color:#fff;border:1px #8d8d8d solid;padding:2px;justify-content:center}.properties-right-flyout .properties-btn-resize:hover{background-color:#e0e0e0}.properties-right-flyout .properties-btn-resize svg{fill:#161616;width:16px;height:16px}.properties-right-flyout>.properties-custom-container{height:calc(100% - 65px - 4rem);overflow-y:auto;transform:translateZ(0)}.properties-right-flyout>.properties-custom-container.properties-custom-container-with-heading{height:calc(100% - 89px - 4rem)}.properties-right-flyout>.properties-custom-container.properties-custom-container-applyOnBlur{height:calc(100% - 6rem)}.properties-right-flyout>.properties-custom-container.properties-custom-container-applyOnBlur-with-heading{height:calc(100% - 89px)}.properties-light-enabled{background-color:#fff}.properties-light-disabled{background-color:#f4f4f4}.properties-error-heading .properties-validation-message{padding:40px 10px 0;align-items:left;-webkit-box-align:left;display:flex}.properties-error-heading .properties-validation-message span{font-size:20px;font-weight:300;font-style:italic}.properties-error-heading .properties-validation-message svg{height:25px}.properties-error-content{padding:0 10px;font-size:14px;font-weight:300;line-height:16px}.properties-modal-container{height:70px;align-items:left}.properties-modal-error button:first-of-type{display:none}.properties-flyout-error-container{height:calc(100% - 46px)}.notification-panel-container{transition:.25s ease-in-out;opacity:1;margin-top:0}.notification-panel-container.panel-hidden{transition:.25s ease-in-out;display:block;opacity:0;visibility:hidden}.notification-panel{position:absolute;width:320px;height:-webkit-fit-content;height:-moz-fit-content;height:fit-content;right:0;top:41px}.notification-panel-header-container{min-height:35px;width:inherit;background-color:#fff;display:flex;flex-direction:column;justify-content:center;border:1px solid #e0e0e0;border-bottom:0;padding:1rem}.notification-panel-header-container .notification-panel-header{font-size:1rem;font-weight:600;line-height:1.375;letter-spacing:0}.notification-panel-header-container .notification-panel-subtitle{font-size:.75rem;line-height:1.33333;letter-spacing:.32px;color:#525252;padding-top:.25rem}.notification-panel-header-container .notification-panel-close-icon{position:absolute;right:1rem;top:1.25rem;cursor:pointer}.notification-panel-clear-all-container{width:100%;height:49px;background-color:#fff;display:flex;flex-direction:column;justify-content:center;border-left:1px solid #e0e0e0;border-right:1px solid #e0e0e0;border-bottom:1px solid #e0e0e0;font-weight:400;padding:.5rem 1rem}.notification-panel-clear-all-container .bx--btn--ghost.bx--btn--sm{width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;padding:0}.notification-panel-messages-container{width:inherit;max-height:calc(100% - 35px);height:-webkit-fit-content;height:-moz-fit-content;height:fit-content}.notification-panel-messages{max-height:500px;height:-webkit-fit-content;height:-moz-fit-content;height:fit-content;overflow-y:auto;line-height:normal;background-color:#fff;border:1px solid #e0e0e0}.notification-panel-messages .notifications-button-container{border-bottom:1px solid #e0e0e0;min-height:48px}.notification-panel-messages .notification-panel-empty-message-container{min-height:48px;display:flex;justify-content:center;align-items:center}.notification-panel-messages .notification-panel-empty-message-container .notification-panel-empty-message{font-size:.875rem;font-weight:400;line-height:1.28572;letter-spacing:.16px;text-align:center;padding-right:30px;padding-left:30px}.notification-panel-messages .notifications-button-container:nth-last-of-type(1){border-bottom:0}.notification-panel-messages .notifications{padding:1rem 1rem 1rem calc(1rem - 4px);display:inline-flex;width:100%;min-height:48px;background-color:#fff;border-style:none;border-left:4px solid #fff;cursor:default;margin-top:0;margin-bottom:0}.notification-panel-messages .notifications.clickable{cursor:pointer}.notification-panel-messages .notifications:active,.notification-panel-messages .notifications:focus{outline:none;border-style:none;border-left:4px solid #fff}.notification-panel-messages .notifications:hover{background-color:#e5e5e5}.notification-panel-messages .notifications:hover.unspecified{border-left:4px solid #fff}.notification-panel-messages .notifications:hover.error{border-left:4px solid #da1e28}.notification-panel-messages .notifications:hover.warning{border-left:4px solid #f1c21b}.notification-panel-messages .notifications:hover.success{border-left:4px solid #198038}.notification-panel-messages .notifications:hover.info{border-left:4px solid #0043ce}.notification-panel-messages .notifications .notification-message-type{display:flex;justify-content:center;height:18px;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;padding-right:.5rem}.notification-panel-messages .notifications .notification-message-type>svg{display:flex;justify-content:center;width:1rem;height:100%}.notification-panel-messages .notifications .notification-message-details{text-align:left;overflow-wrap:break-word;width:266px}.notification-panel-messages .notifications .notification-message-details .notification-message-title{font-size:.875rem;font-weight:600;line-height:1.28572;letter-spacing:.16px;color:#525252;padding-bottom:.25rem}.notification-panel-messages .notifications .notification-message-details .notification-message-subtitle{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;color:#161616}.notification-panel-messages .notifications .notification-message-details .notification-message-subtitle hr{margin-bottom:.5rem;border-bottom:0;border-top:solid 1px #e0e0e0}.notification-panel-messages .notifications .notification-message-details .notification-message-content{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;color:#525252}.notification-panel-messages+*{clear:both}.notification-message-timestamp{display:inline-flex;color:#525252}.notification-message-timestamp svg{width:10px;height:10px;margin-right:3px;margin-top:3px}.notification-message-timestamp .notification-message-string{font-size:10px;margin-top:auto;margin-bottom:auto}.notification-message-close:hover{text-decoration:underline}.canvas-icon .stroke,.canvas-icon.stroke{stroke:#161616}.canvas-icon .fill,.canvas-icon.fill{fill:#161616}.canvas-icon[disabled]{fill:#c6c6c6}svg.properties-icon,svg.canvas-icon{fill:#161616}svg.canvas-state-icon-error{fill:#da1e28}svg.canvas-state-icon-success{fill:#198038}svg.canvas-state-icon-warning{fill:#f1c21b}svg.canvas-state-icon-warning [data-icon-path=inner-path]{fill:#161616;opacity:1}svg.canvas-state-icon-info{fill:#0043ce}svg.canvas-state-icon-information-hollow{fill:#161616}.toolbar-div{height:40px;width:100%;background-color:#fff;border-bottom:1px solid #8d8d8d;box-sizing:content-box;position:relative;display:flex;justify-content:space-between;-webkit-user-drag:none}.toolbar-left-bar{flex-shrink:5000000;display:block;padding-right:42px;overflow:hidden;align-items:center}.toolbar-right-bar{display:flex;flex-direction:row-reverse;flex-wrap:wrap;justify-content:flex-start;flex-shrink:1;overflow:hidden}.toolbar-item{background-color:#fff;display:inline-block}.toolbar-item button{padding:0;height:40px;min-height:30px}.toolbar-item.default button,.toolbar-item.ghost button{background-color:#fff}.toolbar-item.default button:hover,.toolbar-item.ghost button:hover{background-color:#e5e5e5}.toolbar-item.default button:focus,.toolbar-item.ghost button:focus{background-color:#e5e5e5}.toolbar-item.default button:disabled:hover,.toolbar-item.ghost button:disabled:hover{background-color:#fff}.toolbar-item.tertiary button{color:#0f62fe;background-color:#fff}.toolbar-item.tertiary button:hover{background-color:#e5e5e5}.toolbar-item.tertiary button:disabled,.toolbar-item.tertiary button:disabled:hover{color:#c6c6c6;background-color:#fff}.toolbar-spacer{width:0;display:inline-block}.toolbar-overflow-item{background-color:#fff;display:inline-block}.toolbar-overflow-item button{padding:0;height:40px;min-height:30px;background-color:#fff;border-right:1px solid #e0e0e0}.toolbar-overflow-item button:hover{background-color:#e5e5e5}.toolbar-overflow-item button:disabled:hover{background-color:#fff}.toolbar-overflow-menu-item button{width:100%;padding-top:2px;padding-bottom:2px;min-height:20px}.toolbar-item-content{width:inherit;display:flex;justify-content:center;padding:11px}.toolbar-item-content.overflow{justify-content:left;padding:8px 0}.toolbar-item-content.default{color:#161616}.toolbar-item-content.disabled.default{color:#c6c6c6;fill:#c6c6c6}.toolbar-item-content .toolbar-icon{height:16px}.toolbar-item-content .toolbar-icon svg{height:16px;width:16px;-webkit-user-drag:none}.toolbar-text-content{position:absolute;top:14px;font-size:9px;line-height:9px;color:#161616}.toolbar-icon-label{line-height:16px}.toolbar-icon-label.before{padding-right:8px}.toolbar-icon-label.after{padding-left:8px}.toolbar-icon-label.overflow{padding-left:8px;word-break:break-word;-webkit-hyphens:auto;-ms-hyphens:auto;hyphens:auto}.toolbar-jsx-item{height:40px;display:inline-flex;align-items:center;vertical-align:top;position:relative;background-color:#fff;padding:0}.toolbar-overflow-jsx-item{width:100%;height:38px;display:inline-flex;align-items:center;vertical-align:top;position:relative;padding:0}.toolbar-item-selected.default button,.toolbar-item-selected.ghost button{background-color:#e0e0e0;border-color:transparent;box-shadow:none;border-bottom:2px solid #0f62fe}.toolbar-divider{border-right:1px solid #e0e0e0;background-color:#fff;display:inline-block;height:40px;width:0}.toolbar-divider-overflow{height:0;border-bottom:1px solid #e0e0e0}.toolbar-popover-list{width:200px;z-index:1;top:calc(40px + 1px);display:block;position:absolute;list-style-type:none;padding:0;border:1px solid #e0e0e0;background-color:#fff}.toolbar-popover-list-hide{display:none}.tooltip-container,.tooltip-trigger{height:100%}.common-canvas-tooltip{font-size:12px;position:fixed;padding:1rem;background-color:#393939;border:1px solid #393939;font-weight:400;opacity:90%;color:#fff;line-height:1.2;text-align:left;z-index:10000;pointer-events:none;word-wrap:break-word;max-width:228px;border-radius:2px}.common-canvas-tooltip .bx--link{display:block;color:#78a9ff;margin-top:1rem;pointer-events:auto;cursor:pointer}.common-canvas-tooltip .bx--link:hover{color:#78a9ff;text-decoration:underline}.common-canvas-tooltip[direction=right]{transform:translate3d(-22px, 0, 0)}.common-canvas-tooltip[direction=top]{transform:translate3d(0, 22px, 0)}.common-canvas-tooltip[direction=left]{transform:translate3d(22px, 0, 0)}.common-canvas-tooltip[direction=bottom]{transform:translate3d(0, -22px, 0)}.icon-tooltip{padding:.125rem 1rem}.definition-tooltip{padding:.5rem 1rem}.common-canvas-tooltip #tipArrow{position:absolute;width:10px;height:14px}.common-canvas-tooltip[direction=top] #tipArrow{transform:rotate(-90deg)}.common-canvas-tooltip[direction=left] #tipArrow{transform:rotate(180deg)}.common-canvas-tooltip[direction=bottom] #tipArrow{transform:rotate(90deg)}.common-canvas-tooltip #tipArrow polyline{fill:#393939;stroke-width:0}.common-canvas-tooltip #tipArrow polygon{fill:#393939}.common-canvas-tooltip[aria-hidden=false]{transform:scaleX(1) translate3d(0, 0, 0) rotate(0deg);visibility:visible;opacity:100}.common-canvas-tooltip[aria-hidden=true]{visibility:hidden;opacity:0}.tip-palette-item,.tip-node{min-width:80px;max-width:180px;text-align:left}.tip-palette-category{font-size:10px;padding-bottom:4px;color:#fff}.tip-palette-label,.tip-node-label{font-weight:600;color:#fff}.tip-palette-desc,.tip-node-desc{padding-top:4px}.tip-node-status{position:absolute;width:12px;height:12px;right:1rem;top:.5rem}.tip-node-status.warning{fill:#f1c21b}.tip-node-status.error{fill:#da1e28}.tip-port{min-width:90px}.properties-tooltips{background-color:#393939;color:#fff;max-width:250px}.properties-tooltips #tipArrow polyline{fill:#393939}.context-menu-popover{cursor:pointer;min-width:160px;background-color:#fff;background-clip:padding-box;border:0;outline:none;position:absolute;z-index:2;box-shadow:2px 2px 2px rgba(0,0,0,.2)}.context-menu-popover.popover>.arrow{display:none}.context-menu-popover.popover>.popover-content{padding:0}.react-contextmenu{min-width:160px;text-align:left;background-color:#f4f4f4;-webkit-background-clip:padding-box;background-clip:padding-box;border-radius:.25rem;outline:none;display:none;box-shadow:2px 2px 2px rgba(0,0,0,.2)}.react-contextmenu--visible{display:inline-grid}.react-contextmenu-item{height:30px;padding:0 1em;clear:both;color:#161616;text-align:inherit;white-space:nowrap;background:0 0;border:0;display:flex;align-items:center}.react-contextmenu-item.react-contextmenu-item--disabled{opacity:.5;cursor:not-allowed}.react-contextmenu-item:active,.react-contextmenu-item:focus,.react-contextmenu-item:hover{background:#e5e5e5;text-decoration:none;border:0;outline:none}.react-contextmenu-item.react-contextmenu-submenu{padding:0}.react-contextmenu-item.react-contextmenu-submenu>div{padding-right:27px}.react-contextmenu-item svg{color:#161616;position:absolute;right:12px}.react-contextmenu-item.contextmenu-divider{height:1px;display:block;overflow:hidden;background-color:#e0e0e0;padding:0}.palette-flyout-div{border-right:1px solid #e0e0e0;font-size:14px;position:relative;height:100%;padding-bottom:5px;background-color:#fff;transition:.2s;cursor:default;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-flyout-div-open .palette-flyout-content{width:256px;transition:.2s ease-in-out}.palette-flyout-div-closed{transition:.2s ease-in-out;width:0}.palette-flyout-div-narrow{width:72px}.palette-flyout-content{height:41px}.palette-flyout-content .palette-scroll{overflow-y:hidden}.palette-flyout-content .palette-content-list{border-bottom:1px solid #e0e0e0}.palette-flyout-content .palette-no-results-title{font-size:.875rem;font-weight:400;line-height:1.28572;letter-spacing:.16px;width:100%;padding:20px 20px 0;text-align:center}.palette-flyout-content .palette-no-results-desc{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;width:100%;padding:0 20px;text-align:center}.palette-flyout-content .palette-flyout-restrict-item{font-size:.75rem;line-height:1.33333;letter-spacing:.32px;width:100%;padding:2.5rem 20px}.palette-flyout-content .palette-list-item-desc-button{color:#0f62fe;cursor:pointer;padding:5px 0 0}.palette-flyout-content .palette-list-item{height:46px;border-width:0;display:flex;flex-direction:column;align-items:center;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-flyout-content .palette-list-item:hover{background-color:#e0e0e0}.palette-flyout-content .palette-list-item .palette-list-item-category-label{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;width:100%;padding:1rem 10px 0 58px}.palette-flyout-content .palette-list-item .palette-list-item-category-label mark{color:#0f62fe;background-color:#d0e2ff;font-weight:500}.palette-flyout-content .palette-list-item .palette-list-item-icon-and-text{display:flex;flex-direction:row;width:100%;min-height:46px;align-items:center}.palette-flyout-content .palette-list-item .palette-list-item-icon{width:28px;margin-left:20px;color:#525252}.palette-flyout-content .palette-list-item .palette-list-item-text-div{font-size:.875rem;font-weight:600;line-height:1.28572;letter-spacing:.16px;font-weight:400;padding:0 10px;width:calc(100% - 68px)}.palette-flyout-content .palette-list-item .palette-list-item-text-div mark{color:#0f62fe;background-color:#d0e2ff;font-weight:500}.palette-flyout-content .palette-list-item .palette-list-item-icon-warning{transform:scale(1.5);margin-left:25px}.palette-flyout-content .palette-list-item .palette-list-item-description{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;padding:0 10px 0 58px;word-break:break-word;width:100%}.palette-flyout-content .palette-list-item .palette-list-item-description mark{color:#0f62fe;background-color:#d0e2ff;font-weight:500}.palette-flyout-content .palette-list-item .highlight{background-color:#0f62fe}.palette-flyout-content .palette-list-item.search-result{min-height:46px;height:-webkit-fit-content;height:-moz-fit-content;height:fit-content;padding-bottom:1rem;border-bottom:1px solid #e0e0e0}.palette-flyout-content .palette-list-item.search-result .palette-list-item-icon-and-text{min-height:30px}.palette-flyout-category{cursor:pointer;border-width:0 0 0 1px;height:-webkit-fit-content;height:-moz-fit-content;height:fit-content;min-height:46px;align-items:center;justify-content:space-between;display:flex;border-bottom:1px solid #e0e0e0}.palette-flyout-category-caret{height:16px;width:16px;position:relative;right:16px;background-color:#fff;fill:#161616}.palette-flyout-category-caret-closed{top:0;right:16px}.palette-flyout-category-item{display:flex;align-items:center;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-flyout-category-item-loading{margin-left:16px}.palette-flyout-category-item-icon{width:20px;margin-left:16px;fill:#161616}.palette-flyout-text-container{max-width:205px;display:flex;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-flyout-category-text{width:165px;overflow-wrap:break-word;line-height:1.3;margin-left:16px}.palette-flyout-category-text-abbr{line-height:46px;margin-left:16px;width:35px}.palette-flyout-category-text-no-image{line-height:46px;margin-left:16px;width:170px}.palette-flyout-category-count{line-height:46px;padding-left:5px}.palette-flyout-category:hover{font-weight:600}.palette-flyout-search-container{height:100%}.palette-flyout-search-container .palette-flyout-search{height:100%;overflow:hidden}.palette-flyout-search-container .palette-flyout-search .bx--search-magnifier svg{margin-left:10px}.palette-flyout-search-container .palette-flyout-search svg{fill:#161616}.palette-flyout-search-container .palette-flyout-search input{background:#fff;height:100%;padding-right:3rem;padding-left:52px}.palette-flyout-search-container .palette-flyout-search button{margin-right:8px;margin-top:4px;border-bottom-width:0}.palette-flyout-search-container .palette-flyout-search button.bx--search-close::before{content:none}.palette-flyout-categories{height:calc(100% - 48px);width:100%;position:absolute;overflow-x:hidden;overflow-y:overlay}.palette-dialog-div{position:absolute;bottom:35px;left:60px;width:473px;height:450px;font-size:14px;border:3px solid transparent;cursor:default;z-index:2;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-dialog-div .palette-list-item{height:46px;border-width:1px;border-color:#e0e0e0;border-style:solid;display:flex;flex-direction:column;align-items:center;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-dialog-div .palette-list-item:hover{background-color:#e0e0e0}.palette-dialog-div .palette-list-item .palette-list-item-icon-and-text{display:flex;flex-direction:row;width:100%;height:46px;align-items:center}.palette-dialog-div .palette-list-item .palette-list-item-icon{width:28px;margin-left:20px;line-height:46px;color:#525252}.palette-dialog-div .palette-list-item .palette-list-item-text-div{margin-left:10px}.palette-dialog-div .palette-list-item .palette-list-item-text-span{overflow:hidden;text-overflow:ellipsis;white-space:nowrap;margin-left:10px;line-height:16px}.palette-dialog-div .palette-list-item .palette-list-item-icon-warning{transform:scale(1.5);margin-left:25px}.palette-dialog-topbar{height:40px;padding:10px;background-color:#e0e0e0;border-bottom:1px solid #e0e0e0}.palette-dialog-topbar .left-navbar{height:20px;float:left;vertical-align:middle;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-dialog-topbar .right-navbar{height:20px;float:right;vertical-align:middle}.palette-dialog-topbar .secondary-action{margin-left:10px;display:inline-block;cursor:pointer;width:20px}.palette-dialog-topbar .close-icon svg{fill:#393939}.palette-dialog-topbar .palette-three-way-icon-div{margin-left:5px;display:inline-block;cursor:pointer;width:20px;height:20px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-dialog-content{height:404px;display:flex;background-color:#fff;border-bottom:1px solid #e0e0e0;border-right:1px solid #e0e0e0}.palette-dialog-categories{background-color:#e0e0e0;width:130px;min-width:130px;border-right:1px solid #e0e0e0;overflow-x:hidden}.palette-dialog-category{padding:10px;border-width:0 0 0 1px;cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-dialog-category:hover{font-weight:600}.palette-dialog-category-selected{font-weight:600;border-color:#393939;border-width:0 0 0 1px;border-style:solid;width:130px;min-width:130px;padding-left:8px;padding-top:10px;padding-bottom:10px;cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-dialog-grid-node-outer{width:112px;height:134px;display:inline-block;vertical-align:middle;text-align:center;border-width:1px;border-color:#e0e0e0;border-style:solid;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-dialog-grid-node-outer:hover{border-color:#393939;color:#393939}.palette-dialog-grid-node-inner{padding-top:16px}.palette-dialog-grid-node-icon svg{display:inline-block}.palette-dialog-grid-node-icon .node-icon{width:64px;height:64px}.palette-dialog-grid-node-icon-warning{transform:scale(4);margin-top:25px}.palette-dialog-grid-node-text-warning{width:100%;padding-top:30px}.palette-dialog-grid-node-text{width:100%;padding-top:6px}.palette-scroll{overflow-y:auto}.palette-content-list{width:100%}.common-canvas{height:100%;width:100%;cursor:default;display:flex;position:relative;overflow-x:auto;overflow-y:hidden;font-size:14px}.common-canvas-items-container{height:100%;position:relative;width:100%}.common-canvas-right-side-items{width:100%;display:flex}.common-canvas-main{width:100%;height:100%}.common-canvas-with-bottom-panel{width:100%;position:relative}.common-canvas-drop-div{height:calc(100% - 41px);width:100%;min-width:inherit;position:absolute;cursor:default;top:41px;overflow:hidden}.common-canvas-drop-div.common-canvas-toolbar-none{height:100%;top:0}.common-canvas-drop-div.common-canvas-toolbar-none.common-canvas-bottom-panel-is-open{top:0}.right-flyout-panel{height:100%;position:relative;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;background-color:#fff}.bottom-panel{display:flex;flex-direction:column;height:393px;position:absolute;left:0;right:0;bottom:0;border-top:1px solid #e0e0e0;min-height:75px}.bottom-panel-drag{border-top:#e0e0e0;cursor:row-resize;flex:0 0 2px;border-top-width:1px;background:#fff;transition:all .2s ease-in}.bottom-panel-drag:hover{background:#0f62fe}.bottom-panel-contents{background-color:#fff;width:100%;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;height:100%}.common-canvas-right-side-items-under-toolbar{width:100%}.common-canvas-items-container-under-toolbar{height:calc(100% - 41px);width:100%;display:flex}.common-canvas-drop-div-under-toolbar{height:100%;width:100%;position:relative;cursor:default;overflow:hidden}.empty-canvas{position:absolute;line-height:1.5;left:50%;top:48%;cursor:default;transform:translate(-50%, -50%);pointer-events:none}.empty-canvas-image{color:#a8a8a8;opacity:.4;display:block;text-align:center}.empty-canvas-image svg{width:175px;height:175px}.empty-canvas-text1{font-size:1.25rem;font-weight:400;line-height:1.4;letter-spacing:0;padding-top:.25rem;color:#a8a8a8;display:block;text-align:center}.empty-canvas-text2{font-size:1rem;font-weight:400;line-height:1.375;letter-spacing:0;padding-top:.5rem;color:#a8a8a8;display:block;text-align:center}.dropzone-canvas{position:absolute;line-height:1.5;width:100%;height:100%;left:50%;top:50%;cursor:default;transform:translate(-50%, -50%);pointer-events:all;background-color:#f4f4f4;opacity:.75}.dropzone-canvas-rect{position:absolute;top:30px;left:30px;right:30px;bottom:30px;border-color:#8d8d8d;border-style:dashed;border-width:2px}.toolbar-item-content.notificationCounterIcon.error>div>svg>.dot{fill:#da1e28}.toolbar-item-content.notificationCounterIcon.warning>div>svg>.dot{fill:#f1c21b}.toolbar-item-content.notificationCounterIcon.success>div>svg>.dot{fill:#198038}.toolbar-item-content.notificationCounterIcon.info>div>svg>.dot{fill:#0043ce}.state-tag{font-size:.875rem;font-weight:600;line-height:1.28572;letter-spacing:.16px;color:#fff;background-color:#393939;height:40px;position:absolute;left:50%;top:16px;transform:translate(-50%, 0%);border-radius:20px;padding:9px 0;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.state-tag svg{color:#fff;position:relative;top:3px;margin-left:14px}.state-tag span{margin:0 16px 0 10px}.d3-svg-canvas-div{cursor:default;height:100%;background-color:#f4f4f4}.d3-svg-canvas-div:focus{outline:none}.d3-foreign-object{pointer-events:none;overflow:visible}.d3-region-selector{stroke:#161616;fill:#e0e0e0;opacity:.5}.d3-svg-background{fill:#f4f4f4}.d3-canvas-underlay{fill:#e0e0e0}.d3-temp-cursor-overlay{fill:transparent}.d3-back-to-previous-flow-box{stroke:#0f62fe;fill:#f4f4f4}.d3-back-to-previous-flow-box[data-pointer-hover=yes]{stroke:#0f62fe;fill:#e0e0e0}.d3-back-to-previous-flow-text{font-size:14px;font-weight:400;fill:#0f62fe}.d3-back-to-previous-flow-box,.d3-back-to-previous-flow-text{cursor:pointer}.d3-ghost-div{position:absolute;left:0;top:0;z-index:-10000}.d3-ghost-node{fill:#d0e2ff}.d3-node-group.d3-draggable,.d3-comment-group.d3-draggable{cursor:pointer}.d3-node-group-translucent{opacity:.5}.d3-node-sizing,.d3-comment-sizing{fill:transparent;stroke:transparent}.d3-node-body-outline{stroke:#161616;stroke-width:1;fill:#fff}.d3-node-group:hover>.d3-node-body-outline{stroke:#e0e0e0;stroke-width:1;fill:#cacaca}.d3-node-unavailable .d3-node-body-outline,.d3-node-unavailable .d3-node-label,.d3-node-unavailable svg path{stroke:#c6c6c6;fill:#8d8d8d;color:#c6c6c6}.d3-node-selection-highlight{stroke-width:0;fill:transparent;pointer-events:none}.d3-node-selection-highlight[data-selected=yes]{stroke:#78a9ff;stroke-dasharray:none;stroke-width:5;fill:transparent}.d3-node-image-outline{stroke:#161616;stroke-width:1;fill:#fff}.d3-node-label{color:#161616;font-size:12px;font-weight:500;resize:none;border-style:solid;border-color:transparent;padding:0;width:100%;height:100%;overflow:hidden;line-height:105%;letter-spacing:.16px;border-width:2px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.d3-node-label span{pointer-events:auto}.d3-node-label-entry{color:#161616;font-size:12px;font-weight:500;resize:none;border-style:solid;border-color:transparent;padding:0;width:100%;height:100%;overflow:hidden;line-height:105%;letter-spacing:.16px;background-color:#fff;border-width:6px;pointer-events:auto}.d3-node-label-entry:focus{outline:none;box-shadow:0 0 0 2px #0f62fe}.d3-node-group[data-new-link-over=yes] .d3-node-selection-highlight{stroke:#0f62fe;stroke-dasharray:4;stroke-width:2;fill:#fff;pointer-events:none}.d3-node-error-label{color:#da1e28}.d3-node-warning-label{color:#f1c21b}.d3-node-label-outline{border:solid 1px}.d3-label-single-line{white-space:nowrap;text-overflow:ellipsis}.d3-label-multi-line{white-space:pre-wrap;word-wrap:normal;word-break:break-word;display:-webkit-box;-webkit-line-clamp:2;-webkit-box-orient:vertical}.d3-label-multi-line .d3-label-full{display:inline-block}.d3-label-center{text-align:center}.d3-label-edit-icon-group .d3-label-edit-icon-background1{fill:transparent}.d3-label-edit-icon-group .d3-label-edit-icon-background2{fill:#f4f4f4}.d3-label-edit-icon-group:hover .d3-label-edit-icon-background2{fill:#e0e0e0}.d3-label-edit-icon-group svg{fill:currentColor;color:#161616}.d3-node-dec-outline,.d3-link-dec-outline{fill:transparent;stroke:#161616;stroke-width:1;stroke-dasharray:0}.d3-node-dec-label,.d3-link-dec-label{color:#161616;font-size:12px;font-weight:500;resize:none;border-style:solid;border-color:transparent;padding:0;width:100%;height:100%;overflow:hidden;line-height:105%;letter-spacing:.16px;border-width:2px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.d3-node-dec-label span,.d3-link-dec-label span{pointer-events:auto}.d3-dec-label-entry{color:#161616;font-size:12px;font-weight:500;resize:none;border-style:solid;border-color:transparent;padding:0;width:100%;height:100%;overflow:hidden;line-height:105%;letter-spacing:.16px;background-color:#fff;border-width:6px;pointer-events:auto}.d3-dec-label-entry:focus{outline:none;box-shadow:0 0 0 2px #0f62fe}.d3-node-dec-path,.d3-link-dec-path{fill:#161616;stroke:#161616;stroke-width:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.d3-node-dec-image,.d3-link-dec-image{stroke-width:1;stroke-dasharray:0;fill:currentColor;color:#161616}.d3-node-ellipsis-group .d3-node-ellipsis-background{fill:transparent;stroke-width:0;cursor:context-menu}.d3-node-ellipsis-group .d3-node-ellipsis{fill:#0f62fe;stroke-width:0;cursor:context-menu}.d3-node-ellipsis-group:hover .d3-node-ellipsis-background{fill:#e0e0e0}.d3-node-super-expand-icon-group .d3-node-super-expand-icon-background{fill:transparent;stroke-width:0;cursor:context-menu}.d3-node-super-expand-icon-group .d3-node-super-expand-icon{fill:#0f62fe;stroke-width:0;cursor:context-menu}.d3-node-super-expand-icon-group:hover .d3-node-super-expand-icon-background{fill:#e0e0e0}.d3-error-circle{stroke:#f4f4f4;stroke-width:2;fill:#da1e28}.d3-warning-circle{stroke:#f4f4f4;stroke-width:2;fill:#f1c21b}.d3-error-circle-off{display:none}.d3-node-port-output{stroke:#393939;fill:#fff;stroke-width:1.25}.d3-node-port-output[connected=yes]{stroke:#393939;fill:#393939;stroke-width:2}.d3-node-port-output:hover{stroke:#393939;fill:#393939}.d3-node-port-input{stroke:#393939;fill:#fff;stroke-width:1.25}.d3-node-port-input-assoc,.d3-node-port-output-assoc{stroke:#393939;fill:#fff;stroke-width:1.25}.d3-node-port-input-assoc:hover,.d3-node-port-output-assoc:hover{stroke:#393939;fill:#393939}.d3-node-port-input[connected=yes]{stroke:#fff;fill:#fff;stroke-width:1}.d3-node-port-input[connected=yes] .d3-node-port-input-arrow{stroke:#393939;stroke-width:1;fill:transparent}.d3-node-port-input[connected=yes][isSupernodeBinding=yes]{stroke:#393939;fill:#f4f4f4;stroke-width:1}.d3-node-port-input-arrow{stroke:transparent;fill:transparent}.d3-new-connection-line[linkType=nodeLink],.d3-new-connection-line[linkType=associationLink]{stroke:#78a9ff;stroke-width:2;stroke-dasharray:10 10;fill:none}.d3-new-connection-start[linkType=nodeLink],.d3-new-connection-start[linkType=associationLink]{stroke:#78a9ff;fill:#f4f4f4}.d3-new-connection-guide[linkType=nodeLink],.d3-new-connection-guide[linkType=associationLink]{stroke:#78a9ff;fill:#78a9ff}.d3-new-connection-line[linkType=commentLink]{stroke:#8d8d8d;stroke-width:1;stroke-dasharray:10 10;fill:none}.d3-new-connection-guide[linkType=commentLink]{stroke:#8d8d8d;stroke-width:4;fill:#8d8d8d}.d3-new-connection-arrow[linkType=commentLink]{stroke:#8d8d8d;stroke-width:2;fill:#8d8d8d}.d3-comment-port-circle{stroke:#8d8d8d;stroke-width:2;fill:#8d8d8d}.d3-comment-group:hover .d3-comment-rect{stroke:#4c4c4c}.d3-comment-rect{fill:#fff;stroke:#c6c6c6;stroke-width:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}g.bkg-col-white-0 .d3-comment-rect{fill:#fff}g.bkg-col-white-0 .d3-comment-entry{background-color:#fff;color:#161616}g.bkg-col-yellow-20 .d3-comment-rect{fill:#fddc69}g.bkg-col-yellow-20 .d3-comment-entry{background-color:#fddc69;color:#161616}g.bkg-col-gray-20 .d3-comment-rect{fill:#e0e0e0}g.bkg-col-gray-20 .d3-comment-entry{background-color:#e0e0e0;color:#161616}g.bkg-col-green-20 .d3-comment-rect{fill:#a7f0ba}g.bkg-col-green-20 .d3-comment-entry{background-color:#a7f0ba;color:#161616}g.bkg-col-teal-20 .d3-comment-rect{fill:#9ef0f0}g.bkg-col-teal-20 .d3-comment-entry{background-color:#9ef0f0;color:#161616}g.bkg-col-cyan-20 .d3-comment-rect{fill:#bae6ff}g.bkg-col-cyan-20 .d3-comment-entry{background-color:#bae6ff;color:#161616}g.bkg-col-red-50 .d3-comment-rect{fill:#fa4d56}g.bkg-col-red-50 .d3-comment-entry{background-color:#fa4d56;color:#161616}g.bkg-col-orange-40 .d3-comment-rect{fill:#ff832b}g.bkg-col-orange-40 .d3-comment-entry{background-color:#ff832b;color:#161616}g.bkg-col-gray-50 .d3-comment-rect{fill:#8d8d8d}g.bkg-col-gray-50 .d3-comment-entry{background-color:#8d8d8d;color:#161616}g.bkg-col-green-50 .d3-comment-rect{fill:#24a148}g.bkg-col-green-50 .d3-comment-entry{background-color:#24a148;color:#161616}g.bkg-col-teal-50 .d3-comment-rect{fill:#009d9a}g.bkg-col-teal-50 .d3-comment-entry{background-color:#009d9a;color:#161616}g.bkg-col-cyan-50 .d3-comment-rect{fill:#1192e8}g.bkg-col-cyan-50 .d3-comment-entry{background-color:#1192e8;color:#161616}.d3-comment-selection-highlight{stroke-width:0;fill:transparent;pointer-events:none}.d3-comment-selection-highlight[data-selected=yes]{stroke:#78a9ff;stroke-dasharray:none;stroke-width:3;fill:transparent;pointer-events:none}.d3-comment-text{color:#161616;background-color:transparent;font-size:12px;font-weight:400;font-family:\"ibm-plex-sans\",Helvetica Neue,Arial,sans-serif;resize:none;border-style:solid;border-color:transparent;width:100%;height:100%;pointer-events:auto;overflow:hidden;line-height:105%;letter-spacing:.15px;white-space:pre-wrap;word-wrap:normal;word-break:break-word;border-width:8px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.d3-comment-entry{color:#161616;background-color:transparent;font-size:12px;font-weight:400;font-family:\"ibm-plex-sans\",Helvetica Neue,Arial,sans-serif;resize:none;border-style:solid;border-color:transparent;width:100%;height:100%;pointer-events:auto;overflow:hidden;line-height:105%;letter-spacing:.15px;white-space:pre-wrap;word-wrap:normal;word-break:break-word;background-color:#fff;border-width:6px}.d3-comment-entry:focus{outline:none;box-shadow:0 0 0 2px #0f62fe}.d3-link-line,.d3-link-line-arrow-head{fill:none;pointer-events:none}.d3-comment-link .d3-link-line{stroke:#8d8d8d;stroke-width:1;stroke-dasharray:7.3}.d3-comment-link .d3-link-line-arrow-head{stroke:#8d8d8d;stroke-width:1;stroke-dasharray:0}.d3-object-link .d3-link-line{stroke:#161616;stroke-width:2;stroke-dasharray:5.5}.d3-association-link .d3-link-line{stroke:#8d8d8d;stroke-width:2}.d3-data-link .d3-link-line{stroke:#78a9ff;stroke-width:2}.d3-data-link .d3-link-line-arrow-head{stroke:#78a9ff;stroke-width:2;stroke-dasharray:0}.d3-link-selection-area{fill:none;stroke:transparent;stroke-width:12}.d3-link-selection-area.d3-extra-width{stroke-width:80}.d3-link-group:hover .d3-link-line,.d3-link-group:hover .d3-link-line-arrow-head{stroke:#0043ce;stroke-width:2}.d3-link-group[data-selected] .d3-link-line,.d3-link-group[data-selected] .d3-link-line-arrow-head{stroke:#0043ce;stroke-width:3}.d3-link-group[data-drag-node-over].d3-data-link .d3-link-line,.d3-link-group[data-drag-node-over].d3-data-link .d3-link-line-arrow-head,.d3-link-group[data-selected][data-drag-node-over].d3-data-link .d3-link-line,.d3-link-group[data-selected][data-drag-node-over].d3-data-link .d3-link-line-arrow-head{stroke:#0043ce;stroke-width:5}.d3-link-handle-start{display:none;stroke:transparent;fill:transparent;pointer-events:all}.d3-link-group:hover .d3-link-handle-start,.d3-link-group[data-selected] .d3-link-handle-start{display:inherit;stroke:#0043ce;fill:#78a9ff;pointer-events:all}.d3-link-handle-end{display:none;stroke:transparent;fill:transparent;pointer-events:all}.d3-link-group:hover .d3-link-handle-end,.d3-link-group[data-selected] .d3-link-handle-end{display:inherit;stroke:#0043ce;fill:#78a9ff;pointer-events:all}.color-picker-panel{width:100%;height:55px;display:flex;flex-wrap:wrap}.color-picker-panel .color-picker-item{width:20px;height:20px;margin:5px 0 0 5px;cursor:pointer}.color-picker-panel .color-picker-item.white-0{background-color:#fff;border:1px solid #8d8d8d}.color-picker-panel .color-picker-item.yellow-20{background-color:#fddc69}.color-picker-panel .color-picker-item.gray-20{background-color:#e0e0e0}.color-picker-panel .color-picker-item.green-20{background-color:#a7f0ba}.color-picker-panel .color-picker-item.teal-20{background-color:#9ef0f0}.color-picker-panel .color-picker-item.cyan-20{background-color:#bae6ff}.color-picker-panel .color-picker-item.red-50{background-color:#fa4d56}.color-picker-panel .color-picker-item.orange-40{background-color:#ff832b}.color-picker-panel .color-picker-item.gray-50{background-color:#8d8d8d}.color-picker-panel .color-picker-item.green-50{background-color:#24a148}.color-picker-panel .color-picker-item.teal-50{background-color:#009d9a}.color-picker-panel .color-picker-item.cyan-50{background-color:#1192e8}\n", "",{"version":3,"sources":["webpack://./../../node_modules/@elyra/canvas/dist/styles/common-canvas.min.css"],"names":[],"mappings":"AAAA,0BAA0B,oBAAoB,CAAC,+BAA+B,YAAY,CAAC,sGAAsG,gBAAgB,CAAC,yBAAyB,mBAAmB,CAAC,cAAc,CAAC,mBAAmB,CAAC,8BAA8B,QAAQ,CAAC,mBAAmB,CAAC,8BAA8B,YAAY,CAAC,kCAAkC,kBAAkB,CAAC,UAAU,CAAC,8BAA8B,YAAY,CAAC,kIAAkI,UAAU,CAAC,mBAAmB,CAAC,wDAAwD,gBAAgB,CAAC,WAAW,CAAC,uDAAuD,UAAU,CAAC,4BAA4B,YAAY,CAAC,kBAAkB,CAAC,oBAAoB,CAAC,6FAA6F,gBAAgB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,aAAa,CAAC,yHAAyH,iBAAiB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,aAAa,CAAC,qGAAqG,YAAY,CAAC,UAAU,CAAC,WAAW,CAAC,iBAAiB,CAAC,cAAc,CAAC,gCAAgC,gBAAgB,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,aAAa,CAAC,oBAAoB,CAAC,uCAAuC,gBAAgB,CAAC,yBAAyB,cAAc,CAAC,+BAA+B,CAAC,0BAA0B,qBAAqB,CAAC,aAAa,CAAC,YAAY,CAAC,kBAAkB,CAAC,yDAAyD,aAAa,CAAC,YAAY,CAAC,kBAAkB,CAAC,0DAA0D,gBAAgB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,iEAAiE,mBAAmB,CAAC,+BAA+B,yBAAyB,CAAC,OAAO,CAAC,iBAAiB,CAAC,mBAAmB,CAAC,kBAAkB,CAAC,iEAAiE,gCAAgC,CAAC,qEAAqE,UAAU,CAAC,2EAA2E,cAAc,CAAC,eAAe,CAAC,iBAAiB,CAAC,gBAAgB,CAAC,aAAa,CAAC,eAAe,CAAC,gBAAgB,CAAC,sBAAsB,CAAC,mBAAmB,CAAC,qFAAqF,gBAAgB,CAAC,cAAc,CAAC,2FAA2F,sBAAsB,CAAC,mHAAmH,+BAA+B,CAAC,4DAA4D,iBAAiB,CAAC,aAAa,CAAC,0EAA0E,sBAAsB,CAAC,oEAAoE,YAAY,CAAC,UAAU,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,gFAAgF,wBAAwB,CAAC,kFAAkF,wBAAwB,CAAC,yBAAyB,iBAAiB,CAAC,YAAY,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,mBAAmB,CAAC,wDAAwD,iBAAiB,CAAC,SAAS,CAAC,WAAW,CAAC,YAAY,CAAC,kBAAkB,CAAC,sBAAsB,CAAC,SAAS,CAAC,gCAAgC,UAAU,CAAC,gBAAgB,CAAC,WAAW,CAAC,YAAY,CAAC,qBAAqB,CAAC,sBAAsB,CAAC,sCAAsC,SAAS,CAAC,eAAe,CAAC,iBAAiB,CAAC,0CAA0C,WAAW,CAAC,UAAU,CAAC,aAAa,CAAC,+BAA+B,UAAU,CAAC,oBAAoB,CAAC,qCAAqC,UAAU,CAAC,oBAAoB,CAAC,kEAAkE,UAAU,CAAC,YAAY,CAAC,eAAe,CAAC,2EAA2E,mBAAmB,CAAC,UAAU,CAAC,mFAAmF,UAAU,CAAC,6EAA6E,WAAW,CAAC,oBAAoB,WAAW,CAAC,YAAY,CAAC,kBAAkB,CAAC,yCAAyC,iBAAiB,CAAC,YAAY,CAAC,kBAAkB,CAAC,sBAAsB,iBAAiB,CAAC,6DAA6D,YAAY,CAAC,kBAAkB,CAAC,kBAAkB,CAAC,qEAAqE,UAAU,CAAC,WAAW,CAAC,2BAA2B,YAAY,CAAC,kBAAkB,CAAC,yFAAyF,UAAU,CAAC,gBAAgB,CAAC,yDAAyD,UAAU,CAAC,eAAe,CAAC,gEAAgE,eAAe,CAAC,SAAS,CAAC,QAAQ,CAAC,6DAA6D,WAAW,CAAC,UAAU,CAAC,cAAc,CAAC,uEAAuE,YAAY,CAAC,qBAAqB,UAAU,CAAC,WAAW,CAAC,4CAA4C,SAAS,CAAC,WAAW,CAAC,YAAY,CAAC,6BAA6B,CAAC,uFAAuF,mBAAmB,CAAC,yCAAyC,UAAU,CAAC,mBAAmB,CAAC,YAAY,CAAC,6BAA6B,CAAC,qEAAqE,iBAAiB,CAAC,SAAS,CAAC,oEAAoE,WAAW,CAAC,UAAU,CAAC,SAAS,CAAC,kBAAkB,CAAC,wEAAwE,UAAU,CAAC,6CAA6C,WAAW,CAAC,mCAAmC,YAAY,CAAC,uCAAuC,SAAS,CAAC,qCAAqC,eAAe,CAAC,SAAS,CAAC,8CAA8C,SAAS,CAAC,mBAAmB,CAAC,uBAAuB,cAAc,CAAC,YAAY,CAAC,KAAK,CAAC,MAAM,CAAC,OAAO,CAAC,QAAQ,CAAC,wBAAwB,CAAC,YAAY,CAAC,cAAc,CAAC,4BAA4B,aAAa,CAAC,UAAU,CAAC,uBAAuB,cAAc,CAAC,aAAa,CAAC,WAAW,CAAC,mBAAmB,CAAC,YAAY,CAAC,qBAAqB,CAAC,OAAO,CAAC,2BAA2B,CAAC,4BAA4B,cAAc,CAAC,2BAA2B,CAAC,4CAA4C,iBAAiB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,mBAAmB,CAAC,YAAY,CAAC,kBAAkB,CAAC,WAAW,CAAC,+BAA+B,CAAC,+CAA+C,YAAY,CAAC,eAAe,CAAC,+BAA+B,CAAC,2BAA2B,wBAAwB,CAAC,+BAA+B,iBAAiB,CAAC,YAAY,CAAC,qCAAqC,gBAAgB,CAAC,yEAAyE,YAAY,CAAC,qGAAqG,YAAY,CAAC,SAAS,CAAC,uEAAuE,YAAY,CAAC,sEAAsE,YAAY,CAAC,yEAAyE,YAAY,CAAC,oCAAoC,gBAAgB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,aAAa,CAAC,0CAA0C,aAAa,CAAC,oCAAoC,YAAY,CAAC,uCAAuC,YAAY,CAAC,iBAAiB,CAAC,KAAK,CAAC,iDAAiD,YAAY,CAAC,WAAW,CAAC,0BAA0B,wBAAwB,CAAC,YAAY,CAAC,WAAW,CAAC,QAAQ,CAAC,iBAAiB,CAAC,UAAU,CAAC,MAAM,CAAC,+BAA+B,YAAY,CAAC,uGAAuG,SAAS,CAAC,eAAe,CAAC,qBAAqB,CAAC,4CAA4C,gBAAgB,CAAC,qBAAqB,YAAY,CAAC,+BAA+B,iBAAiB,CAAC,8EAA8E,eAAe,CAAC,2BAA2B,iBAAiB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,qCAAqC,CAAC,6BAA6B,CAAC,aAAa,CAAC,WAAW,CAAC,UAAU,CAAC,YAAY,CAAC,wBAAwB,CAAC,6BAA6B,CAAC,kBAAkB,CAAC,cAAc,CAAC,QAAQ,CAAC,YAAY,CAAC,+BAA+B,CAAC,cAAc,CAAC,iCAAiC,wBAAwB,CAAC,+BAA+B,WAAW,CAAC,UAAU,CAAC,YAAY,CAAC,6BAA6B,WAAW,CAAC,YAAY,CAAC,+BAA+B,CAAC,YAAY,CAAC,kCAAkC,eAAe,CAAC,0EAA0E,eAAe,CAAC,kCAAkC,YAAY,CAAC,kBAAkB,CAAC,gBAAgB,CAAC,0DAA0D,iBAAiB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,aAAa,CAAC,+DAA+D,gBAAgB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,aAAa,CAAC,sCAAsC,UAAU,CAAC,WAAW,CAAC,kBAAkB,CAAC,wBAAwB,eAAe,CAAC,kBAAkB,CAAC,gCAAgC,YAAY,CAAC,oBAAoB,CAAC,oCAAoC,iBAAiB,CAAC,cAAc,CAAC,UAAU,CAAC,WAAW,CAAC,aAAa,CAAC,sDAAsD,iBAAiB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,0BAA0B,qBAAqB,CAAC,mDAAmD,gBAAgB,CAAC,4BAA4B,YAAY,CAAC,wBAAwB,CAAC,WAAW,CAAC,4DAA4D,aAAa,CAAC,WAAW,CAAC,2FAA2F,YAAY,CAAC,6FAA6F,wBAAwB,CAAC,qEAAqE,UAAU,CAAC,+BAA+B,wBAAwB,CAAC,iCAAiC,WAAW,CAAC,iCAAiC,YAAY,CAAC,UAAU,CAAC,iBAAiB,CAAC,eAAe,CAAC,2CAA2C,iBAAiB,CAAC,WAAW,CAAC,UAAU,CAAC,eAAe,CAAC,iBAAiB,CAAC,qBAAqB,CAAC,YAAY,CAAC,qBAAqB,CAAC,iDAAiD,wBAAwB,CAAC,mDAAmD,wBAAwB,CAAC,kCAAkC,WAAW,CAAC,UAAU,CAAC,qBAAqB,CAAC,wCAAwC,wBAAwB,CAAC,0CAA0C,wBAAwB,CAAC,2DAA2D,WAAW,CAAC,uEAAuE,aAAa,CAAC,mBAAmB,CAAC,6GAA6G,YAAY,CAAC,sJAAsJ,YAAY,CAAC,4KAA4K,cAAc,CAAC,0KAA0K,cAAc,CAAC,sGAAsG,mBAAmB,CAAC,6BAA6B,CAAC,UAAU,CAAC,iBAAiB,CAAC,cAAc,CAAC,0FAA0F,eAAe,CAAC,wFAAwF,eAAe,CAAC,sBAAsB,CAAC,kBAAkB,CAAC,WAAW,CAAC,eAAe,CAAC,8BAA8B,eAAe,CAAC,+CAA+C,aAAa,CAAC,eAAe,CAAC,sBAAsB,CAAC,kBAAkB,CAAC,eAAe,UAAU,CAAC,WAAW,CAAC,iEAAiE,kBAAkB,CAAC,oEAAoE,UAAU,CAAC,0EAA0E,+BAA+B,CAAC,8CAA8C,WAAW,CAAC,YAAY,CAAC,kBAAkB,CAAC,gBAAgB,CAAC,mBAAmB,CAAC,oDAAoD,wBAAwB,CAAC,kDAAkD,wBAAwB,CAAC,+CAA+C,mBAAmB,CAAC,aAAa,CAAC,2FAA2F,YAAY,CAAC,eAAe,CAAC,+GAA+G,UAAU,CAAC,oHAAoH,iBAAiB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,aAAa,CAAC,sBAAsB,CAAC,kBAAkB,CAAC,eAAe,CAAC,UAAU,CAAC,iBAAiB,CAAC,qGAAqG,mBAAmB,CAAC,UAAU,CAAC,8EAA8E,eAAe,CAAC,SAAS,CAAC,iBAAiB,CAAC,oFAAoF,wBAAwB,CAAC,qFAAqF,SAAS,CAAC,uDAAuD,wBAAwB,CAAC,oFAAoF,wBAAwB,CAAC,2CAA2C,WAAW,CAAC,gBAAgB,CAAC,mBAAmB,CAAC,kFAAkF,gCAAgC,CAAC,6GAA6G,4BAA4B,CAAC,wCAAwC,gBAAgB,CAAC,+BAA+B,CAAC,uHAAuH,wBAAwB,CAAC,qGAAqG,iBAAiB,CAAC,qGAAqG,WAAW,CAAC,WAAW,CAAC,cAAc,CAAC,+EAA+E,cAAc,CAAC,YAAY,CAAC,kBAAkB,CAAC,sBAAsB,CAAC,WAAW,CAAC,4EAA4E,cAAc,CAAC,aAAa,CAAC,sHAAsH,SAAS,CAAC,iBAAiB,CAAC,6FAA6F,wBAAwB,CAAC,sFAAsF,SAAS,CAAC,2CAA2C,wBAAwB,CAAC,+BAA+B,CAAC,iDAAiD,wBAAwB,CAAC,oFAAoF,gBAAgB,CAAC,wEAAwE,gBAAgB,CAAC,2EAA2E,6BAA6B,CAAC,cAAc,CAAC,kHAAkH,6BAA6B,CAAC,gDAAgD,cAAc,CAAC,wCAAwC,WAAW,CAAC,UAAU,CAAC,6EAA6E,qBAAqB,CAAC,0FAA0F,wBAAwB,CAAC,+CAA+C,aAAa,CAAC,iBAAiB,CAAC,WAAW,CAAC,kBAAkB,CAAC,wBAAwB,iBAAiB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,kCAAkC,UAAU,CAAC,mBAAmB,CAAC,uDAAuD,aAAa,CAAC,8CAA8C,WAAW,CAAC,gEAAgE,eAAe,CAAC,qFAAqF,WAAW,CAAC,sFAAsF,oBAAoB,CAAC,WAAW,CAAC,cAAc,CAAC,kBAAkB,CAAC,8FAA8F,WAAW,CAAC,sFAAsF,QAAQ,CAAC,OAAO,CAAC,iEAAiE,YAAY,CAAC,0BAA0B,YAAY,CAAC,0CAA0C,kBAAkB,CAAC,gBAAgB,CAAC,qBAAqB,CAAC,kBAAkB,CAAC,0BAA0B,kBAAkB,CAAC,eAAe,CAAC,wBAAwB,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,WAAW,CAAC,oCAAoC,UAAU,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,cAAc,CAAC,gDAAgD,WAAW,CAAC,aAAa,CAAC,eAAe,CAAC,sBAAsB,CAAC,kBAAkB,CAAC,YAAY,CAAC,kBAAkB,CAAC,4EAA4E,UAAU,CAAC,WAAW,CAAC,UAAU,CAAC,gBAAgB,CAAC,aAAa,CAAC,gFAAgF,UAAU,CAAC,WAAW,CAAC,2CAA2C,kBAAkB,CAAC,qBAAqB,YAAY,CAAC,kBAAkB,CAAC,cAAc,CAAC,wCAAwC,iBAAiB,CAAC,cAAc,CAAC,yDAAyD,YAAY,CAAC,yDAAyD,YAAY,CAAC,oDAAoD,aAAa,CAAC,0BAA0B,YAAY,CAAC,yDAAyD,YAAY,CAAC,WAAW,CAAC,6BAA6B,YAAY,CAAC,8CAA8C,mBAAmB,CAAC,gFAAgF,qBAAqB,CAAC,kFAAkF,qBAAqB,CAAC,iEAAiE,iBAAiB,CAAC,0BAA0B,YAAY,CAAC,oDAAoD,UAAU,CAAC,mFAAmF,UAAU,CAAC,sHAAsH,UAAU,CAAC,uFAAuF,OAAO,CAAC,sEAAsE,aAAa,CAAC,4BAA4B,CAAC,qBAAqB,CAAC,4BAA4B,CAAC,4EAA4E,gBAAgB,CAAC,4EAA4E,aAAa,CAAC,4EAA4E,4BAA4B,CAAC,8EAA8E,4BAA4B,CAAC,8HAA8H,UAAU,CAAC,yJAAyJ,eAAe,CAAC,2CAA2C,iBAAiB,CAAC,0CAA0C,mBAAmB,CAAC,kCAAkC,SAAS,CAAC,UAAU,CAAC,kEAAkE,UAAU,CAAC,kCAAkC,SAAS,CAAC,eAAe,CAAC,kEAAkE,UAAU,CAAC,4BAA4B,SAAS,CAAC,UAAU,CAAC,4DAA4D,UAAU,CAAC,iCAAiC,SAAS,CAAC,eAAe,CAAC,kCAAkC,eAAe,CAAC,yBAAyB,CAAC,+BAA+B,wBAAwB,CAAC,2BAA2B,gBAAgB,CAAC,mBAAmB,CAAC,UAAU,CAAC,gBAAgB,CAAC,iBAAiB,CAAC,+BAA+B,YAAY,CAAC,cAAc,CAAC,sEAAsE,UAAU,CAAC,kBAAkB,CAAC,gBAAgB,CAAC,2DAA2D,WAAW,CAAC,UAAU,CAAC,SAAS,CAAC,6FAA6F,aAAa,CAAC,kDAAkD,qBAAqB,CAAC,sDAAsD,aAAa,CAAC,WAAW,CAAC,2EAA2E,kBAAkB,CAAC,qBAAqB,CAAC,6CAA6C,gBAAgB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,qBAAqB,CAAC,0CAA0C,iBAAiB,CAAC,kBAAkB,YAAY,CAAC,wBAAwB,UAAU,CAAC,YAAY,UAAU,CAAC,kBAAkB,CAAC,aAAa,CAAC,mBAAmB,6BAA6B,CAAC,uBAAuB,4BAA4B,CAAC,yBAAyB,4BAA4B,CAAC,0BAA0B,UAAU,CAAC,yBAAyB,aAAa,CAAC,wBAAwB,aAAa,CAAC,qBAAqB,aAAa,CAAC,yBAAyB,aAAa,CAAC,2GAA2G,aAAa,CAAC,4BAA4B,aAAa,CAAC,kDAAkD,aAAa,CAAC,wBAAwB,aAAa,CAAC,0BAA0B,aAAa,CAAC,sBAAsB,UAAU,CAAC,8BAA8B,wBAAwB,CAAC,uCAAuC,UAAU,CAAC,0EAA0E,QAAQ,CAAC,uCAAuC,eAAe,CAAC,sCAAsC,YAAY,CAAC,6BAA6B,CAAC,sEAAsE,YAAY,CAAC,0BAA0B,CAAC,4EAA4E,cAAc,CAAC,gFAAgF,WAAW,CAAC,UAAU,CAAC,oFAAoF,eAAe,CAAC,cAAc,CAAC,8BAA8B,iBAAiB,CAAC,WAAW,CAAC,2DAA2D,gBAAgB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,iBAAiB,CAAC,UAAU,CAAC,MAAM,CAAC,oEAAoE,iBAAiB,CAAC,QAAQ,CAAC,OAAO,CAAC,yDAAyD,cAAc,CAAC,6DAA6D,WAAW,CAAC,UAAU,CAAC,aAAa,CAAC,0BAA0B,YAAY,CAAC,oCAAoC,oBAAoB,CAAC,+BAA+B,aAAa,CAAC,0CAA0C,mBAAmB,CAAC,cAAc,CAAC,qEAAqE,eAAe,CAAC,0DAA0D,oBAAoB,CAAC,mBAAmB,CAAC,uEAAuE,eAAe,CAAC,0FAA0F,oBAAoB,CAAC,qDAAqD,qBAAqB,CAAC,uDAAuD,qBAAqB,CAAC,oCAAoC,cAAc,CAAC,eAAe,CAAC,0BAA0B,YAAY,CAAC,uEAAuE,eAAe,CAAC,4FAA4F,wBAAwB,CAAC,8BAA8B,YAAY,CAAC,0EAA0E,wBAAwB,CAAC,4EAA4E,wBAAwB,CAAC,qDAAqD,iBAAiB,CAAC,4BAA4B,YAAY,CAAC,oCAAoC,+BAA+B,CAAC,sCAAsC,+BAA+B,CAAC,6DAA6D,gBAAgB,CAAC,+BAA+B,YAAY,CAAC,yCAAyC,cAAc,CAAC,eAAe,CAAC,gCAAgC,eAAe,CAAC,yDAAyD,kBAAkB,CAAC,UAAU,CAAC,+DAA+D,gBAAgB,CAAC,sBAAsB,CAAC,QAAQ,CAAC,SAAS,CAAC,cAAc,CAAC,qEAAqE,YAAY,CAAC,cAAc,CAAC,aAAa,CAAC,qFAAqF,4BAA4B,CAAC,uFAAuF,4BAA4B,CAAC,oDAAoD,4BAA4B,CAAC,8DAA8D,kBAAkB,CAAC,qGAAqG,oBAAoB,CAAC,gDAAgD,cAAc,CAAC,0BAA0B,YAAY,CAAC,kBAAkB,CAAC,WAAW,CAAC,gCAAgC,wBAAwB,CAAC,mEAAmE,gBAAgB,CAAC,mBAAmB,CAAC,iBAAiB,CAAC,UAAU,CAAC,4DAA4D,YAAY,CAAC,4DAA4D,aAAa,CAAC,yDAAyD,wBAAwB,CAAC,+DAA+D,4BAA4B,CAAC,wBAAwB,CAAC,uCAAuC,cAAc,CAAC,eAAe,CAAC,qDAAqD,gBAAgB,CAAC,aAAa,CAAC,YAAY,CAAC,iBAAiB,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,0DAA0D,UAAU,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,kIAAkI,sBAAsB,CAAC,4LAA4L,iBAAiB,CAAC,uGAAuG,YAAY,CAAC,sMAAsM,4BAA4B,CAAC,0MAA0M,4BAA4B,CAAC,0EAA0E,sBAAsB,CAAC,SAAS,CAAC,aAAa,CAAC,sFAAsF,WAAW,CAAC,kCAAkC,YAAY,CAAC,iCAAiC,iBAAiB,CAAC,qBAAqB,CAAC,qFAAqF,YAAY,CAAC,yBAAyB,mBAAmB,CAAC,gCAAgC,YAAY,CAAC,gDAAgD,UAAU,CAAC,8BAA8B,YAAY,CAAC,wDAAwD,YAAY,CAAC,6DAA6D,UAAU,CAAC,mBAAmB,CAAC,iFAAiF,UAAU,CAAC,WAAW,CAAC,mCAAmC,YAAY,CAAC,kBAAkB,CAAC,2BAA2B,4BAA4B,CAAC,cAAc,CAAC,0BAA0B,iBAAiB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,aAAa,CAAC,gBAAgB,CAAC,UAAU,CAAC,YAAY,CAAC,cAAc,CAAC,gCAAgC,UAAU,CAAC,0BAA0B,iBAAiB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,aAAa,CAAC,kBAAkB,CAAC,gDAAgD,YAAY,CAAC,gEAAgE,sBAAsB,CAAC,kBAAkB,CAAC,eAAe,CAAC,wBAAwB,YAAY,CAAC,6BAA6B,CAAC,aAAa,CAAC,kCAAkC,SAAS,CAAC,eAAe,CAAC,WAAW,CAAC,UAAU,CAAC,YAAY,CAAC,sBAAsB,CAAC,+CAA+C,cAAc,CAAC,eAAe,CAAC,8BAA8B,YAAY,CAAC,8CAA8C,YAAY,CAAC,cAAc,CAAC,8EAA8E,wBAAwB,CAAC,mDAAmD,gBAAgB,CAAC,oCAAoC,mBAAmB,CAAC,oCAAoC,iBAAiB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,aAAa,CAAC,oBAAoB,CAAC,0CAA0C,iBAAiB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,aAAa,CAAC,iCAAiC,UAAU,CAAC,mBAAmB,CAAC,4BAA4B,YAAY,CAAC,yBAAyB,YAAY,CAAC,cAAc,CAAC,oBAAoB,CAAC,oCAAoC,qBAAqB,CAAC,mCAAmC,UAAU,CAAC,mBAAmB,CAAC,8BAA8B,YAAY,CAAC,mDAAmD,iBAAiB,CAAC,yBAAyB,YAAY,CAAC,oBAAoB,CAAC,eAAe,CAAC,qGAAqG,aAAa,CAAC,8BAA8B,YAAY,CAAC,mCAAmC,UAAU,CAAC,mBAAmB,CAAC,0BAA0B,aAAa,CAAC,qCAAqC,oBAAoB,CAAC,+BAA+B,YAAY,CAAC,oCAAoC,UAAU,CAAC,mBAAmB,CAAC,2EAA2E,gBAAgB,CAAC,gEAAgE,kBAAkB,CAAC,iCAAiC,kBAAkB,CAAC,6BAA6B,CAAC,kEAAkE,6BAA6B,CAAC,QAAQ,sBAAsB,CAAC,uBAAuB,CAAC,sBAAsB,CAAC,yBAAyB,cAAc,CAAC,OAAO,CAAC,WAAW,CAAC,eAAe,CAAC,6BAA6B,CAAC,YAAY,CAAC,0CAA0C,WAAW,CAAC,2CAA2C,WAAW,CAAC,0CAA0C,WAAW,CAAC,sDAAsD,kBAAkB,CAAC,SAAS,CAAC,gDAAgD,yCAAyC,CAAC,SAAS,CAAC,iBAAiB,CAAC,iBAAiB,CAAC,OAAO,CAAC,UAAU,CAAC,SAAS,CAAC,eAAe,CAAC,cAAc,CAAC,qBAAqB,CAAC,wBAAwB,CAAC,WAAW,CAAC,sBAAsB,CAAC,sDAAsD,wBAAwB,CAAC,oDAAoD,YAAY,CAAC,UAAU,CAAC,WAAW,CAAC,sDAAsD,+BAA+B,CAAC,eAAe,CAAC,uBAAuB,CAAC,+FAA+F,+BAA+B,CAAC,8FAA8F,wBAAwB,CAAC,2GAA2G,wBAAwB,CAAC,0BAA0B,qBAAqB,CAAC,2BAA2B,wBAAwB,CAAC,yDAAyD,mBAAmB,CAAC,gBAAgB,CAAC,sBAAsB,CAAC,YAAY,CAAC,8DAA8D,cAAc,CAAC,eAAe,CAAC,iBAAiB,CAAC,6DAA6D,WAAW,CAAC,0BAA0B,cAAc,CAAC,cAAc,CAAC,eAAe,CAAC,gBAAgB,CAAC,4BAA4B,WAAW,CAAC,gBAAgB,CAAC,6CAA6C,YAAY,CAAC,mCAAmC,wBAAwB,CAAC,8BAA8B,2BAA2B,CAAC,SAAS,CAAC,YAAY,CAAC,2CAA2C,2BAA2B,CAAC,aAAa,CAAC,SAAS,CAAC,iBAAiB,CAAC,oBAAoB,iBAAiB,CAAC,WAAW,CAAC,0BAA0B,CAAC,uBAAuB,CAAC,kBAAkB,CAAC,OAAO,CAAC,QAAQ,CAAC,qCAAqC,eAAe,CAAC,aAAa,CAAC,qBAAqB,CAAC,YAAY,CAAC,qBAAqB,CAAC,sBAAsB,CAAC,wBAAwB,CAAC,eAAe,CAAC,YAAY,CAAC,gEAAgE,cAAc,CAAC,eAAe,CAAC,iBAAiB,CAAC,gBAAgB,CAAC,kEAAkE,gBAAgB,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,aAAa,CAAC,kBAAkB,CAAC,oEAAoE,iBAAiB,CAAC,UAAU,CAAC,WAAW,CAAC,cAAc,CAAC,wCAAwC,UAAU,CAAC,WAAW,CAAC,qBAAqB,CAAC,YAAY,CAAC,qBAAqB,CAAC,sBAAsB,CAAC,6BAA6B,CAAC,8BAA8B,CAAC,+BAA+B,CAAC,eAAe,CAAC,kBAAkB,CAAC,oEAAoE,yBAAyB,CAAC,sBAAsB,CAAC,iBAAiB,CAAC,SAAS,CAAC,uCAAuC,aAAa,CAAC,4BAA4B,CAAC,0BAA0B,CAAC,uBAAuB,CAAC,kBAAkB,CAAC,6BAA6B,gBAAgB,CAAC,0BAA0B,CAAC,uBAAuB,CAAC,kBAAkB,CAAC,eAAe,CAAC,kBAAkB,CAAC,qBAAqB,CAAC,wBAAwB,CAAC,6DAA6D,+BAA+B,CAAC,eAAe,CAAC,yEAAyE,eAAe,CAAC,YAAY,CAAC,sBAAsB,CAAC,kBAAkB,CAAC,2GAA2G,iBAAiB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,iBAAiB,CAAC,kBAAkB,CAAC,iBAAiB,CAAC,iFAAiF,eAAe,CAAC,4CAA4C,uCAAuC,CAAC,mBAAmB,CAAC,UAAU,CAAC,eAAe,CAAC,qBAAqB,CAAC,iBAAiB,CAAC,0BAA0B,CAAC,cAAc,CAAC,YAAY,CAAC,eAAe,CAAC,sDAAsD,cAAc,CAAC,qGAAqG,YAAY,CAAC,iBAAiB,CAAC,0BAA0B,CAAC,kDAAkD,wBAAwB,CAAC,8DAA8D,0BAA0B,CAAC,wDAAwD,6BAA6B,CAAC,0DAA0D,6BAA6B,CAAC,0DAA0D,6BAA6B,CAAC,uDAAuD,6BAA6B,CAAC,uEAAuE,YAAY,CAAC,sBAAsB,CAAC,WAAW,CAAC,yBAAyB,CAAC,sBAAsB,CAAC,iBAAiB,CAAC,mBAAmB,CAAC,2EAA2E,YAAY,CAAC,sBAAsB,CAAC,UAAU,CAAC,WAAW,CAAC,0EAA0E,eAAe,CAAC,wBAAwB,CAAC,WAAW,CAAC,sGAAsG,iBAAiB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,aAAa,CAAC,qBAAqB,CAAC,yGAAyG,gBAAgB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,aAAa,CAAC,4GAA4G,mBAAmB,CAAC,eAAe,CAAC,4BAA4B,CAAC,wGAAwG,gBAAgB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,aAAa,CAAC,+BAA+B,UAAU,CAAC,gCAAgC,mBAAmB,CAAC,aAAa,CAAC,oCAAoC,UAAU,CAAC,WAAW,CAAC,gBAAgB,CAAC,cAAc,CAAC,6DAA6D,cAAc,CAAC,eAAe,CAAC,kBAAkB,CAAC,kCAAkC,yBAAyB,CAAC,yCAAyC,cAAc,CAAC,qCAAqC,YAAY,CAAC,uBAAuB,YAAY,CAAC,oCAAoC,YAAY,CAAC,4BAA4B,YAAY,CAAC,8BAA8B,YAAY,CAAC,8BAA8B,YAAY,CAAC,0DAA0D,YAAY,CAAC,SAAS,CAAC,2BAA2B,YAAY,CAAC,yCAAyC,YAAY,CAAC,aAAa,WAAW,CAAC,UAAU,CAAC,qBAAqB,CAAC,+BAA+B,CAAC,sBAAsB,CAAC,iBAAiB,CAAC,YAAY,CAAC,6BAA6B,CAAC,sBAAsB,CAAC,kBAAkB,mBAAmB,CAAC,aAAa,CAAC,kBAAkB,CAAC,eAAe,CAAC,kBAAkB,CAAC,mBAAmB,YAAY,CAAC,0BAA0B,CAAC,cAAc,CAAC,0BAA0B,CAAC,aAAa,CAAC,eAAe,CAAC,cAAc,qBAAqB,CAAC,oBAAoB,CAAC,qBAAqB,SAAS,CAAC,WAAW,CAAC,eAAe,CAAC,wDAAwD,qBAAqB,CAAC,oEAAoE,wBAAwB,CAAC,oEAAoE,wBAAwB,CAAC,sFAAsF,qBAAqB,CAAC,8BAA8B,aAAa,CAAC,qBAAqB,CAAC,oCAAoC,wBAAwB,CAAC,oFAAoF,aAAa,CAAC,qBAAqB,CAAC,gBAAgB,OAAO,CAAC,oBAAoB,CAAC,uBAAuB,qBAAqB,CAAC,oBAAoB,CAAC,8BAA8B,SAAS,CAAC,WAAW,CAAC,eAAe,CAAC,qBAAqB,CAAC,8BAA8B,CAAC,oCAAoC,wBAAwB,CAAC,6CAA6C,qBAAqB,CAAC,mCAAmC,UAAU,CAAC,eAAe,CAAC,kBAAkB,CAAC,eAAe,CAAC,sBAAsB,aAAa,CAAC,YAAY,CAAC,sBAAsB,CAAC,YAAY,CAAC,+BAA+B,oBAAoB,CAAC,aAAa,CAAC,8BAA8B,aAAa,CAAC,uCAAuC,aAAa,CAAC,YAAY,CAAC,oCAAoC,WAAW,CAAC,wCAAwC,WAAW,CAAC,UAAU,CAAC,sBAAsB,CAAC,sBAAsB,iBAAiB,CAAC,QAAQ,CAAC,aAAa,CAAC,eAAe,CAAC,aAAa,CAAC,oBAAoB,gBAAgB,CAAC,2BAA2B,iBAAiB,CAAC,0BAA0B,gBAAgB,CAAC,6BAA6B,gBAAgB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,YAAY,CAAC,kBAAkB,WAAW,CAAC,mBAAmB,CAAC,kBAAkB,CAAC,kBAAkB,CAAC,iBAAiB,CAAC,qBAAqB,CAAC,SAAS,CAAC,2BAA2B,UAAU,CAAC,WAAW,CAAC,mBAAmB,CAAC,kBAAkB,CAAC,kBAAkB,CAAC,iBAAiB,CAAC,SAAS,CAAC,0EAA0E,wBAAwB,CAAC,wBAAwB,CAAC,eAAe,CAAC,+BAA+B,CAAC,iBAAiB,8BAA8B,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,WAAW,CAAC,OAAO,CAAC,0BAA0B,QAAQ,CAAC,+BAA+B,CAAC,sBAAsB,WAAW,CAAC,SAAS,CAAC,oBAAoB,CAAC,aAAa,CAAC,iBAAiB,CAAC,oBAAoB,CAAC,SAAS,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,2BAA2B,YAAY,CAAC,oCAAoC,WAAW,CAAC,uBAAuB,cAAc,CAAC,cAAc,CAAC,YAAY,CAAC,wBAAwB,CAAC,wBAAwB,CAAC,eAAe,CAAC,WAAW,CAAC,UAAU,CAAC,eAAe,CAAC,eAAe,CAAC,aAAa,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,eAAe,CAAC,iBAAiB,CAAC,iCAAiC,aAAa,CAAC,aAAa,CAAC,eAAe,CAAC,mBAAmB,CAAC,cAAc,CAAC,uCAAuC,aAAa,CAAC,yBAAyB,CAAC,wCAAwC,kCAAkC,CAAC,sCAAsC,iCAAiC,CAAC,uCAAuC,iCAAiC,CAAC,yCAAyC,kCAAkC,CAAC,cAAc,oBAAoB,CAAC,oBAAoB,kBAAkB,CAAC,iCAAiC,iBAAiB,CAAC,UAAU,CAAC,WAAW,CAAC,gDAAgD,wBAAwB,CAAC,iDAAiD,wBAAwB,CAAC,mDAAmD,uBAAuB,CAAC,0CAA0C,YAAY,CAAC,cAAc,CAAC,yCAAyC,YAAY,CAAC,0CAA0C,qDAAqD,CAAC,kBAAkB,CAAC,WAAW,CAAC,yCAAyC,iBAAiB,CAAC,SAAS,CAAC,4BAA4B,cAAc,CAAC,eAAe,CAAC,eAAe,CAAC,sBAAsB,cAAc,CAAC,kBAAkB,CAAC,UAAU,CAAC,mCAAmC,eAAe,CAAC,UAAU,CAAC,iCAAiC,eAAe,CAAC,iBAAiB,iBAAiB,CAAC,UAAU,CAAC,WAAW,CAAC,UAAU,CAAC,SAAS,CAAC,yBAAyB,YAAY,CAAC,uBAAuB,YAAY,CAAC,UAAU,cAAc,CAAC,qBAAqB,wBAAwB,CAAC,UAAU,CAAC,eAAe,CAAC,wCAAwC,YAAY,CAAC,sBAAsB,cAAc,CAAC,eAAe,CAAC,qBAAqB,CAAC,2BAA2B,CAAC,QAAQ,CAAC,YAAY,CAAC,iBAAiB,CAAC,SAAS,CAAC,qCAAqC,CAAC,qCAAqC,YAAY,CAAC,+CAA+C,SAAS,CAAC,mBAAmB,eAAe,CAAC,eAAe,CAAC,wBAAwB,CAAC,mCAAmC,CAAC,2BAA2B,CAAC,oBAAoB,CAAC,YAAY,CAAC,YAAY,CAAC,qCAAqC,CAAC,4BAA4B,mBAAmB,CAAC,wBAAwB,WAAW,CAAC,aAAa,CAAC,UAAU,CAAC,aAAa,CAAC,kBAAkB,CAAC,kBAAkB,CAAC,cAAc,CAAC,QAAQ,CAAC,YAAY,CAAC,kBAAkB,CAAC,yDAAyD,UAAU,CAAC,kBAAkB,CAAC,2FAA2F,kBAAkB,CAAC,oBAAoB,CAAC,QAAQ,CAAC,YAAY,CAAC,kDAAkD,SAAS,CAAC,sDAAsD,kBAAkB,CAAC,4BAA4B,aAAa,CAAC,iBAAiB,CAAC,UAAU,CAAC,4CAA4C,UAAU,CAAC,aAAa,CAAC,eAAe,CAAC,wBAAwB,CAAC,SAAS,CAAC,oBAAoB,8BAA8B,CAAC,cAAc,CAAC,iBAAiB,CAAC,WAAW,CAAC,kBAAkB,CAAC,qBAAqB,CAAC,cAAc,CAAC,cAAc,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,iDAAiD,WAAW,CAAC,0BAA0B,CAAC,2BAA2B,0BAA0B,CAAC,OAAO,CAAC,2BAA2B,UAAU,CAAC,wBAAwB,WAAW,CAAC,wCAAwC,iBAAiB,CAAC,8CAA8C,+BAA+B,CAAC,kDAAkD,iBAAiB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,UAAU,CAAC,mBAAmB,CAAC,iBAAiB,CAAC,iDAAiD,gBAAgB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,UAAU,CAAC,cAAc,CAAC,iBAAiB,CAAC,sDAAsD,gBAAgB,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,UAAU,CAAC,mBAAmB,CAAC,uDAAuD,aAAa,CAAC,cAAc,CAAC,eAAe,CAAC,2CAA2C,WAAW,CAAC,cAAc,CAAC,YAAY,CAAC,qBAAqB,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,iDAAiD,wBAAwB,CAAC,6EAA6E,gBAAgB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,UAAU,CAAC,wBAAwB,CAAC,kFAAkF,aAAa,CAAC,wBAAwB,CAAC,eAAe,CAAC,4EAA4E,YAAY,CAAC,kBAAkB,CAAC,UAAU,CAAC,eAAe,CAAC,kBAAkB,CAAC,mEAAmE,UAAU,CAAC,gBAAgB,CAAC,aAAa,CAAC,uEAAuE,iBAAiB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,eAAe,CAAC,cAAc,CAAC,uBAAuB,CAAC,4EAA4E,aAAa,CAAC,wBAAwB,CAAC,eAAe,CAAC,2EAA2E,oBAAoB,CAAC,gBAAgB,CAAC,0EAA0E,gBAAgB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,qBAAqB,CAAC,qBAAqB,CAAC,UAAU,CAAC,+EAA+E,aAAa,CAAC,wBAAwB,CAAC,eAAe,CAAC,sDAAsD,wBAAwB,CAAC,yDAAyD,eAAe,CAAC,0BAA0B,CAAC,uBAAuB,CAAC,kBAAkB,CAAC,mBAAmB,CAAC,+BAA+B,CAAC,0FAA0F,eAAe,CAAC,yBAAyB,cAAc,CAAC,sBAAsB,CAAC,0BAA0B,CAAC,uBAAuB,CAAC,kBAAkB,CAAC,eAAe,CAAC,kBAAkB,CAAC,6BAA6B,CAAC,YAAY,CAAC,+BAA+B,CAAC,+BAA+B,WAAW,CAAC,UAAU,CAAC,iBAAiB,CAAC,UAAU,CAAC,qBAAqB,CAAC,YAAY,CAAC,sCAAsC,KAAK,CAAC,UAAU,CAAC,8BAA8B,YAAY,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,sCAAsC,gBAAgB,CAAC,mCAAmC,UAAU,CAAC,gBAAgB,CAAC,YAAY,CAAC,+BAA+B,eAAe,CAAC,YAAY,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,8BAA8B,WAAW,CAAC,wBAAwB,CAAC,eAAe,CAAC,gBAAgB,CAAC,mCAAmC,gBAAgB,CAAC,gBAAgB,CAAC,UAAU,CAAC,uCAAuC,gBAAgB,CAAC,gBAAgB,CAAC,WAAW,CAAC,+BAA+B,gBAAgB,CAAC,gBAAgB,CAAC,+BAA+B,eAAe,CAAC,iCAAiC,WAAW,CAAC,wDAAwD,WAAW,CAAC,eAAe,CAAC,kFAAkF,gBAAgB,CAAC,4DAA4D,YAAY,CAAC,8DAA8D,eAAe,CAAC,WAAW,CAAC,kBAAkB,CAAC,iBAAiB,CAAC,+DAA+D,gBAAgB,CAAC,cAAc,CAAC,qBAAqB,CAAC,wFAAwF,YAAY,CAAC,2BAA2B,wBAAwB,CAAC,UAAU,CAAC,iBAAiB,CAAC,iBAAiB,CAAC,kBAAkB,CAAC,oBAAoB,iBAAiB,CAAC,WAAW,CAAC,SAAS,CAAC,WAAW,CAAC,YAAY,CAAC,cAAc,CAAC,4BAA4B,CAAC,cAAc,CAAC,SAAS,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,uCAAuC,WAAW,CAAC,gBAAgB,CAAC,oBAAoB,CAAC,kBAAkB,CAAC,YAAY,CAAC,qBAAqB,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,6CAA6C,wBAAwB,CAAC,wEAAwE,YAAY,CAAC,kBAAkB,CAAC,UAAU,CAAC,WAAW,CAAC,kBAAkB,CAAC,+DAA+D,UAAU,CAAC,gBAAgB,CAAC,gBAAgB,CAAC,aAAa,CAAC,mEAAmE,gBAAgB,CAAC,oEAAoE,eAAe,CAAC,sBAAsB,CAAC,kBAAkB,CAAC,gBAAgB,CAAC,gBAAgB,CAAC,uEAAuE,oBAAoB,CAAC,gBAAgB,CAAC,uBAAuB,WAAW,CAAC,YAAY,CAAC,wBAAwB,CAAC,+BAA+B,CAAC,oCAAoC,WAAW,CAAC,UAAU,CAAC,qBAAqB,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,qCAAqC,WAAW,CAAC,WAAW,CAAC,qBAAqB,CAAC,yCAAyC,gBAAgB,CAAC,oBAAoB,CAAC,cAAc,CAAC,UAAU,CAAC,uCAAuC,YAAY,CAAC,mDAAmD,eAAe,CAAC,oBAAoB,CAAC,cAAc,CAAC,UAAU,CAAC,WAAW,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,wBAAwB,YAAY,CAAC,YAAY,CAAC,qBAAqB,CAAC,+BAA+B,CAAC,8BAA8B,CAAC,2BAA2B,wBAAwB,CAAC,WAAW,CAAC,eAAe,CAAC,8BAA8B,CAAC,iBAAiB,CAAC,yBAAyB,YAAY,CAAC,sBAAsB,CAAC,cAAc,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,+BAA+B,eAAe,CAAC,kCAAkC,eAAe,CAAC,oBAAoB,CAAC,sBAAsB,CAAC,kBAAkB,CAAC,WAAW,CAAC,eAAe,CAAC,gBAAgB,CAAC,gBAAgB,CAAC,mBAAmB,CAAC,cAAc,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,gCAAgC,WAAW,CAAC,YAAY,CAAC,oBAAoB,CAAC,qBAAqB,CAAC,iBAAiB,CAAC,gBAAgB,CAAC,oBAAoB,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,sCAAsC,oBAAoB,CAAC,aAAa,CAAC,gCAAgC,gBAAgB,CAAC,mCAAmC,oBAAoB,CAAC,0CAA0C,UAAU,CAAC,WAAW,CAAC,uCAAuC,kBAAkB,CAAC,eAAe,CAAC,uCAAuC,UAAU,CAAC,gBAAgB,CAAC,+BAA+B,UAAU,CAAC,eAAe,CAAC,gBAAgB,eAAe,CAAC,sBAAsB,UAAU,CAAC,eAAe,WAAW,CAAC,UAAU,CAAC,cAAc,CAAC,YAAY,CAAC,iBAAiB,CAAC,eAAe,CAAC,iBAAiB,CAAC,cAAc,CAAC,+BAA+B,WAAW,CAAC,iBAAiB,CAAC,UAAU,CAAC,gCAAgC,UAAU,CAAC,YAAY,CAAC,oBAAoB,UAAU,CAAC,WAAW,CAAC,iCAAiC,UAAU,CAAC,iBAAiB,CAAC,wBAAwB,wBAAwB,CAAC,UAAU,CAAC,iBAAiB,CAAC,iBAAiB,CAAC,cAAc,CAAC,QAAQ,CAAC,eAAe,CAAC,mDAAmD,WAAW,CAAC,KAAK,CAAC,sFAAsF,KAAK,CAAC,oBAAoB,WAAW,CAAC,iBAAiB,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,qBAAqB,CAAC,cAAc,YAAY,CAAC,qBAAqB,CAAC,YAAY,CAAC,iBAAiB,CAAC,MAAM,CAAC,OAAO,CAAC,QAAQ,CAAC,4BAA4B,CAAC,eAAe,CAAC,mBAAmB,kBAAkB,CAAC,iBAAiB,CAAC,YAAY,CAAC,oBAAoB,CAAC,eAAe,CAAC,0BAA0B,CAAC,yBAAyB,kBAAkB,CAAC,uBAAuB,qBAAqB,CAAC,UAAU,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,WAAW,CAAC,8CAA8C,UAAU,CAAC,6CAA6C,wBAAwB,CAAC,UAAU,CAAC,YAAY,CAAC,sCAAsC,WAAW,CAAC,UAAU,CAAC,iBAAiB,CAAC,cAAc,CAAC,eAAe,CAAC,cAAc,iBAAiB,CAAC,eAAe,CAAC,QAAQ,CAAC,OAAO,CAAC,cAAc,CAAC,+BAA+B,CAAC,mBAAmB,CAAC,oBAAoB,aAAa,CAAC,UAAU,CAAC,aAAa,CAAC,iBAAiB,CAAC,wBAAwB,WAAW,CAAC,YAAY,CAAC,oBAAoB,iBAAiB,CAAC,eAAe,CAAC,eAAe,CAAC,gBAAgB,CAAC,kBAAkB,CAAC,aAAa,CAAC,aAAa,CAAC,iBAAiB,CAAC,oBAAoB,cAAc,CAAC,eAAe,CAAC,iBAAiB,CAAC,gBAAgB,CAAC,iBAAiB,CAAC,aAAa,CAAC,aAAa,CAAC,iBAAiB,CAAC,iBAAiB,iBAAiB,CAAC,eAAe,CAAC,UAAU,CAAC,WAAW,CAAC,QAAQ,CAAC,OAAO,CAAC,cAAc,CAAC,+BAA+B,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,WAAW,CAAC,sBAAsB,iBAAiB,CAAC,QAAQ,CAAC,SAAS,CAAC,UAAU,CAAC,WAAW,CAAC,oBAAoB,CAAC,mBAAmB,CAAC,gBAAgB,CAAC,iEAAiE,YAAY,CAAC,mEAAmE,YAAY,CAAC,mEAAmE,YAAY,CAAC,gEAAgE,YAAY,CAAC,WAAW,iBAAiB,CAAC,eAAe,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,UAAU,CAAC,wBAAwB,CAAC,WAAW,CAAC,iBAAiB,CAAC,QAAQ,CAAC,QAAQ,CAAC,6BAA6B,CAAC,kBAAkB,CAAC,aAAa,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,eAAe,UAAU,CAAC,iBAAiB,CAAC,OAAO,CAAC,gBAAgB,CAAC,gBAAgB,oBAAoB,CAAC,mBAAmB,cAAc,CAAC,WAAW,CAAC,wBAAwB,CAAC,yBAAyB,YAAY,CAAC,mBAAmB,mBAAmB,CAAC,gBAAgB,CAAC,oBAAoB,cAAc,CAAC,YAAY,CAAC,UAAU,CAAC,mBAAmB,YAAY,CAAC,oBAAoB,YAAY,CAAC,wBAAwB,gBAAgB,CAAC,8BAA8B,cAAc,CAAC,YAAY,CAAC,sDAAsD,cAAc,CAAC,YAAY,CAAC,+BAA+B,cAAc,CAAC,eAAe,CAAC,YAAY,CAAC,6DAA6D,cAAc,CAAC,cAAc,iBAAiB,CAAC,MAAM,CAAC,KAAK,CAAC,cAAc,CAAC,eAAe,YAAY,CAAC,2DAA2D,cAAc,CAAC,2BAA2B,UAAU,CAAC,mCAAmC,gBAAgB,CAAC,kBAAkB,CAAC,sBAAsB,cAAc,CAAC,cAAc,CAAC,SAAS,CAAC,2CAA2C,cAAc,CAAC,cAAc,CAAC,YAAY,CAAC,6GAA6G,cAAc,CAAC,YAAY,CAAC,aAAa,CAAC,6BAA6B,cAAc,CAAC,gBAAgB,CAAC,mBAAmB,CAAC,gDAAgD,cAAc,CAAC,qBAAqB,CAAC,cAAc,CAAC,gBAAgB,CAAC,uBAAuB,cAAc,CAAC,cAAc,CAAC,SAAS,CAAC,eAAe,aAAa,CAAC,cAAc,CAAC,eAAe,CAAC,WAAW,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,SAAS,CAAC,UAAU,CAAC,WAAW,CAAC,eAAe,CAAC,gBAAgB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,oBAAoB,mBAAmB,CAAC,qBAAqB,aAAa,CAAC,cAAc,CAAC,eAAe,CAAC,WAAW,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,SAAS,CAAC,UAAU,CAAC,WAAW,CAAC,eAAe,CAAC,gBAAgB,CAAC,oBAAoB,CAAC,qBAAqB,CAAC,gBAAgB,CAAC,mBAAmB,CAAC,2BAA2B,YAAY,CAAC,4BAA4B,CAAC,oEAAoE,cAAc,CAAC,kBAAkB,CAAC,cAAc,CAAC,SAAS,CAAC,mBAAmB,CAAC,qBAAqB,aAAa,CAAC,uBAAuB,aAAa,CAAC,uBAAuB,gBAAgB,CAAC,sBAAsB,kBAAkB,CAAC,sBAAsB,CAAC,qBAAqB,oBAAoB,CAAC,gBAAgB,CAAC,qBAAqB,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,2BAA2B,CAAC,oCAAoC,oBAAoB,CAAC,iBAAiB,iBAAiB,CAAC,0DAA0D,gBAAgB,CAAC,0DAA0D,YAAY,CAAC,gEAAgE,YAAY,CAAC,8BAA8B,iBAAiB,CAAC,aAAa,CAAC,0CAA0C,gBAAgB,CAAC,cAAc,CAAC,cAAc,CAAC,kBAAkB,CAAC,sCAAsC,aAAa,CAAC,cAAc,CAAC,eAAe,CAAC,WAAW,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,SAAS,CAAC,UAAU,CAAC,WAAW,CAAC,eAAe,CAAC,gBAAgB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,gDAAgD,mBAAmB,CAAC,oBAAoB,aAAa,CAAC,cAAc,CAAC,eAAe,CAAC,WAAW,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,SAAS,CAAC,UAAU,CAAC,WAAW,CAAC,eAAe,CAAC,gBAAgB,CAAC,oBAAoB,CAAC,qBAAqB,CAAC,gBAAgB,CAAC,mBAAmB,CAAC,0BAA0B,YAAY,CAAC,4BAA4B,CAAC,oCAAoC,YAAY,CAAC,cAAc,CAAC,cAAc,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,sCAAsC,cAAc,CAAC,kBAAkB,CAAC,iBAAiB,CAAC,aAAa,CAAC,qDAAqD,gBAAgB,CAAC,cAAc,CAAC,mBAAmB,CAAC,0CAA0C,YAAY,CAAC,cAAc,CAAC,mBAAmB,CAAC,2DAA2D,YAAY,CAAC,uEAAuE,gBAAgB,CAAC,cAAc,CAAC,mBAAmB,CAAC,4DAA4D,YAAY,CAAC,cAAc,CAAC,mBAAmB,CAAC,6EAA6E,YAAY,CAAC,iBAAiB,cAAc,CAAC,cAAc,CAAC,YAAY,CAAC,mBAAmB,cAAc,CAAC,cAAc,CAAC,YAAY,CAAC,qBAAqB,YAAY,CAAC,qBAAqB,cAAc,CAAC,SAAS,CAAC,iBAAiB,CAAC,oCAAoC,cAAc,CAAC,YAAY,CAAC,cAAc,CAAC,2BAA2B,cAAc,CAAC,YAAY,CAAC,oBAAoB,cAAc,CAAC,SAAS,CAAC,iBAAiB,CAAC,qDAAqD,cAAc,CAAC,SAAS,CAAC,iBAAiB,CAAC,iEAAiE,cAAc,CAAC,YAAY,CAAC,mCAAmC,WAAW,CAAC,SAAS,CAAC,cAAc,CAAC,6DAA6D,cAAc,CAAC,cAAc,CAAC,gBAAgB,CAAC,2DAA2D,cAAc,CAAC,YAAY,CAAC,cAAc,CAAC,0BAA0B,kBAAkB,CAAC,gBAAgB,CAAC,6FAA6F,cAAc,CAAC,cAAc,CAAC,sBAAsB,CAAC,SAAS,CAAC,+FAA+F,cAAc,CAAC,YAAY,CAAC,+FAA+F,cAAc,CAAC,YAAY,CAAC,8CAA8C,cAAc,CAAC,cAAc,CAAC,sBAAsB,CAAC,SAAS,CAAC,+CAA+C,cAAc,CAAC,cAAc,CAAC,YAAY,CAAC,+CAA+C,cAAc,CAAC,cAAc,CAAC,YAAY,CAAC,wBAAwB,cAAc,CAAC,cAAc,CAAC,YAAY,CAAC,yCAAyC,cAAc,CAAC,iBAAiB,SAAS,CAAC,cAAc,CAAC,cAAc,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,mCAAmC,SAAS,CAAC,oCAAoC,qBAAqB,CAAC,aAAa,CAAC,qCAAqC,YAAY,CAAC,sCAAsC,wBAAwB,CAAC,aAAa,CAAC,mCAAmC,YAAY,CAAC,oCAAoC,wBAAwB,CAAC,aAAa,CAAC,oCAAoC,YAAY,CAAC,qCAAqC,wBAAwB,CAAC,aAAa,CAAC,mCAAmC,YAAY,CAAC,oCAAoC,wBAAwB,CAAC,aAAa,CAAC,mCAAmC,YAAY,CAAC,oCAAoC,wBAAwB,CAAC,aAAa,CAAC,kCAAkC,YAAY,CAAC,mCAAmC,wBAAwB,CAAC,aAAa,CAAC,qCAAqC,YAAY,CAAC,sCAAsC,wBAAwB,CAAC,aAAa,CAAC,mCAAmC,YAAY,CAAC,oCAAoC,wBAAwB,CAAC,aAAa,CAAC,oCAAoC,YAAY,CAAC,qCAAqC,wBAAwB,CAAC,aAAa,CAAC,mCAAmC,YAAY,CAAC,oCAAoC,wBAAwB,CAAC,aAAa,CAAC,mCAAmC,YAAY,CAAC,oCAAoC,wBAAwB,CAAC,aAAa,CAAC,gCAAgC,cAAc,CAAC,gBAAgB,CAAC,mBAAmB,CAAC,mDAAmD,cAAc,CAAC,qBAAqB,CAAC,cAAc,CAAC,gBAAgB,CAAC,mBAAmB,CAAC,iBAAiB,aAAa,CAAC,4BAA4B,CAAC,cAAc,CAAC,eAAe,CAAC,2DAA2D,CAAC,WAAW,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,UAAU,CAAC,WAAW,CAAC,mBAAmB,CAAC,eAAe,CAAC,gBAAgB,CAAC,oBAAoB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,qBAAqB,CAAC,gBAAgB,CAAC,wBAAwB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,kBAAkB,aAAa,CAAC,4BAA4B,CAAC,cAAc,CAAC,eAAe,CAAC,2DAA2D,CAAC,WAAW,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,UAAU,CAAC,WAAW,CAAC,mBAAmB,CAAC,eAAe,CAAC,gBAAgB,CAAC,oBAAoB,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,qBAAqB,CAAC,qBAAqB,CAAC,gBAAgB,CAAC,wBAAwB,YAAY,CAAC,4BAA4B,CAAC,uCAAuC,SAAS,CAAC,mBAAmB,CAAC,+BAA+B,cAAc,CAAC,cAAc,CAAC,oBAAoB,CAAC,0CAA0C,cAAc,CAAC,cAAc,CAAC,kBAAkB,CAAC,8BAA8B,cAAc,CAAC,cAAc,CAAC,oBAAoB,CAAC,mCAAmC,cAAc,CAAC,cAAc,CAAC,4BAA4B,cAAc,CAAC,cAAc,CAAC,uCAAuC,cAAc,CAAC,cAAc,CAAC,kBAAkB,CAAC,wBAAwB,SAAS,CAAC,kBAAkB,CAAC,eAAe,CAAC,uCAAuC,eAAe,CAAC,iFAAiF,cAAc,CAAC,cAAc,CAAC,mGAAmG,cAAc,CAAC,cAAc,CAAC,gTAAgT,cAAc,CAAC,cAAc,CAAC,sBAAsB,YAAY,CAAC,kBAAkB,CAAC,gBAAgB,CAAC,kBAAkB,CAAC,+FAA+F,eAAe,CAAC,cAAc,CAAC,YAAY,CAAC,kBAAkB,CAAC,oBAAoB,YAAY,CAAC,kBAAkB,CAAC,gBAAgB,CAAC,kBAAkB,CAAC,2FAA2F,eAAe,CAAC,cAAc,CAAC,YAAY,CAAC,kBAAkB,CAAC,oBAAoB,UAAU,CAAC,WAAW,CAAC,YAAY,CAAC,cAAc,CAAC,uCAAuC,UAAU,CAAC,WAAW,CAAC,kBAAkB,CAAC,cAAc,CAAC,+CAA+C,qBAAqB,CAAC,wBAAwB,CAAC,iDAAiD,wBAAwB,CAAC,+CAA+C,wBAAwB,CAAC,gDAAgD,wBAAwB,CAAC,+CAA+C,wBAAwB,CAAC,+CAA+C,wBAAwB,CAAC,8CAA8C,wBAAwB,CAAC,iDAAiD,wBAAwB,CAAC,+CAA+C,wBAAwB,CAAC,gDAAgD,wBAAwB,CAAC,+CAA+C,wBAAwB,CAAC,+CAA+C,wBAAwB","sourcesContent":[".properties-action-button{display:inline-block}.properties-action-button.hide{display:none}.properties-control-item>.properties-action-button,.properties-ctrl-wrapper>.properties-action-button{padding-top:1rem}.properties-action-image{padding:0 0 0 .5rem;cursor:pointer;align-self:flex-end}.properties-action-image.left{order:-1;padding:0 .5rem 0 0}.properties-action-image.hide{display:none}.properties-action-image.disabled{cursor:not-allowed;opacity:.5}.properties-control-item.hide{display:none}.properties-control-item[disabled] .properties-label-container,.properties-control-item[disabled] .properties-control-description{opacity:.5;pointer-events:none}.properties-control-item .properties-action-image.right{margin-left:auto;float:right}.properties-control-item .properties-action-image.left{float:left}.properties-label-container{display:flex;align-items:center;padding-bottom:.5rem}.properties-label-container label,.properties-label-container .properties-required-indicator{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;color:#525252}.properties-label-container.table-control label,.properties-label-container.table-control .properties-required-indicator{font-size:.875rem;font-weight:600;line-height:1.28572;letter-spacing:.16px;color:#161616}.properties-label-container .tooltip-container,.properties-summary-link-container .tooltip-container{display:flex;width:16px;height:16px;margin-left:.5rem;cursor:pointer}.properties-control-description{font-size:.75rem;line-height:1.33333;letter-spacing:.32px;color:#525252;padding-bottom:.5rem}.bx--label .properties-label-container{padding-bottom:0}.properties-title-editor{padding:1rem 0;border-bottom:1px #e0e0e0 solid}.properties-title-heading{padding:0 1rem .25rem;height:1.5rem;display:flex;align-items:center}.properties-title-heading .properties-title-heading-icon{height:1.5rem;width:1.5rem;margin-right:.5rem}.properties-title-heading .properties-title-heading-label{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px}.properties-title-heading .properties-title-editor-btn.help.help{margin:0 0 0 .25rem}.properties-title-editor-input{width:calc(100% - 0.5rem);top:1px;position:relative;display:inline-flex;align-items:center}.properties-title-editor-input.properties-title-editor-with-help{width:calc(100% - 2rem - 0.5rem)}.properties-title-editor-input .bx--form-item.bx--text-input-wrapper{width:100%}.properties-title-editor-input .bx--form-item.bx--text-input-wrapper input{font-size:1rem;font-weight:600;line-height:1.375;letter-spacing:0;color:#161616;min-width:unset;background:unset;text-overflow:ellipsis;border-bottom:unset}.properties-title-editor-input .bx--form-item.bx--text-input-wrapper input[readonly]{box-shadow:unset;cursor:default}.properties-title-editor-input .bx--form-item.bx--text-input-wrapper .bx--form-requirement{margin:.25rem 0 0 1rem}.properties-title-editor-input .bx--form-item.bx--text-input-wrapper .bx--text-input__field-wrapper--warning input{border-bottom:1px solid #8d8d8d}.properties-title-editor-input .properties-title-editor-btn{position:absolute;right:.125rem}.properties-title-editor-with-warning,.properties-title-editor-with-error{width:calc(100% - 2px)}.properties-title-editor-btn.help,.properties-title-editor-btn.edit{fill:#525252;width:2rem;min-height:2rem;padding-left:.75rem;padding-right:.75rem}.properties-title-editor-btn.help:hover,.properties-title-editor-btn.edit:hover{background-color:#e0e0e0}.properties-title-editor-btn.help:active,.properties-title-editor-btn.edit:active{background-color:#e0e0e0}.properties-close-button{position:relative;display:flex;align-items:center;justify-content:flex-end;padding-right:.5rem}.properties-title-with-heading>.properties-close-button{position:absolute;top:.5rem;right:.5rem;display:flex;align-items:center;justify-content:center;padding:0}.properties-mr-button-container{width:16px;padding-left:2px;height:100%;display:flex;flex-direction:column;justify-content:center}.table-row-move-button.bx--btn--ghost{padding:0;min-height:24px;margin-bottom:8px}.table-row-move-button.bx--btn--ghost>svg{height:16px;width:16px;margin-left:0}.properties-mr-table-container{width:100%;display:inline-block}.properties-mr-table-container>tbody{width:100%;display:inline-block}.properties-mr-table-container>tbody .properties-mr-table-content{width:100%;display:flex;border-bottom:0}.properties-mr-table-container>tbody .properties-mr-table-content.disabled{pointer-events:none;opacity:.5}.properties-mr-table-container>tbody .properties-mr-table-content>td:first-of-type{width:100%}.properties-wf-content .properties-fp-table .properties-ft-container-wrapper{height:100%}.properties-fp-data{height:100%;display:flex;align-items:center}.properties-fp-field,.properties-fp-data{padding-left:1rem;display:flex;align-items:center}.properties-fp-schema{padding-left:1rem}.properties-fp-field-type-icon,.properties-fp-data-type-icon{display:flex;align-items:center;margin-right:.5rem}.properties-fp-field-type-icon>svg,.properties-fp-data-type-icon>svg{width:1rem;height:1rem}.properties-fp-filter-list{display:flex;align-items:center}.properties-fp-filter-list .properties-fp-filter-list-title.properties-fp-filter-list-li{width:auto;margin-left:1rem}.properties-fp-filter-list .properties-fp-filter-list-li{float:left;padding:.125rem}.properties-fp-filter-list .properties-fp-filter-list-li button{min-height:1rem;padding:0;border:0}.properties-fp-filter-list .properties-fp-filter-list-li svg{height:1rem;width:1rem;margin:.125rem}.properties-fp-filter-list .properties-fp-filter-list-li svg[disabled]{fill:#c6c6c6}.properties-fp-table{width:100%;height:100%}.properties-fp-table .properties-fp-top-row{width:50%;float:right;display:flex;justify-content:space-between}.properties-fp-table .properties-fp-top-row .properties-fp-reset-button-container span{margin-right:.25rem}.properties-modal .properties-fp-top-row{width:100%;margin-bottom:.5rem;display:flex;justify-content:space-between}.properties-modal .properties-fp-top-row .properties-fp-button-label{position:relative;top:.5rem}.properties-modal .properties-fp-top-row .properties-fp-back-button{height:2rem;width:2rem;padding:0;margin-right:.5rem}.properties-modal .properties-fp-top-row .properties-fp-back-button>svg{left:.5rem}.properties-modal .properties-fp-filter-list{float:right}.properties-modal .bx--modal-close{display:none}.properties-modal .bx--modal-container{padding:0}.properties-modal .bx--modal-content{margin-bottom:0;padding:0}.properties-modal.noButtons .bx--modal-footer{opacity:0;pointer-events:none}.properties-wf-overlay{position:fixed;display:none;top:0;left:0;right:0;bottom:0;background-color:#161616;z-index:1000;cursor:default}.properties-wf-overlay.show{display:block;opacity:.5}.properties-wf-content{position:fixed;display:block;width:675px;margin-right:-675px;z-index:1001;background-color:#fff;right:0;transition:margin-right .1s}.properties-wf-content.show{margin-right:0;transition:margin-right .3s}.properties-wf-content .properties-wf-title{font-size:.875rem;font-weight:600;line-height:1.28572;letter-spacing:.16px;padding-left:1.5rem;display:flex;align-items:center;height:41px;border-bottom:1px solid #e0e0e0}.properties-wf-content .properties-wf-children{padding:1rem;overflow-y:auto;height:calc(100% - 41px - 64px)}.properties-light-disabled{background-color:#f4f4f4}.properties-validation-message{margin-top:.25rem;display:flex}.properties-validation-message .icon{margin:0 .125rem}.properties-validation-message .icon .properties-validation-icon-warning{fill:#f1c21b}.properties-validation-message .icon .properties-validation-icon-warning [data-icon-path=inner-path]{fill:#161616;opacity:1}.properties-validation-message .icon .properties-validation-icon-error{fill:#da1e28}.properties-validation-message .icon .properties-validation-icon-info{fill:#0043ce}.properties-validation-message .icon .properties-validation-icon-success{fill:#198038}.properties-validation-message span{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;color:#161616}.properties-validation-message.error span{color:#da1e28}.properties-validation-message.hide{display:none}.properties-validation-message.inTable{margin-top:0;position:absolute;top:0}.properties-validation-message.inTable .icon svg{height:.5rem;width:.5rem}.properties-modal-buttons{justify-content:flex-end;display:flex;height:4rem;bottom:0;position:absolute;width:100%;left:0}.properties-modal-buttons.hide{display:none}.properties-modal-buttons .properties-apply-button,.properties-modal-buttons .properties-cancel-button{width:50%;max-width:unset;padding:0 0 1rem 1rem}.properties-primaryTabs .bx--tabs__nav-item{margin-left:1rem}.properties-category{padding:1rem}.properties-category-container{position:relative}.properties-category-container:last-of-type .properties-category-content.show{border-bottom:0}.properties-category-title{font-size:.875rem;font-weight:400;line-height:1.42857;letter-spacing:.16px;-webkit-text-decoration-color:#161616;text-decoration-color:#161616;color:#161616;height:46px;width:100%;display:flex;background-color:#f4f4f4;justify-content:space-between;align-items:center;padding:0 1rem;border:0;outline:none;border-bottom:1px solid #e0e0e0;cursor:pointer}.properties-category-title:hover{background-color:#e5e5e5}.properties-category-title>svg{height:20px;width:20px;fill:#161616}.properties-category-content{height:100%;padding:1rem;border-bottom:1px solid #e0e0e0;display:none}.properties-category-content.show{display:inherit}.properties-subtabs .bx--tabs__nav,.properties-primaryTabs .bx--tabs__nav{overflow-x:auto}.properties-static-text-container{display:flex;align-items:center;padding:.25rem 0}.properties-static-text-container .properties-static-text{font-size:.875rem;font-weight:400;line-height:1.28572;letter-spacing:.16px;color:#161616}.properties-static-text-container .properties-static-text.info{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;color:#525252}.properties-static-text-container svg{width:16px;height:16px;margin-right:.5rem}.properties-h-separator{margin-top:1rem;margin-bottom:1rem}.properties-link-text-container{display:flex;padding:.75rem 0 0 0}.properties-link-text-container svg{margin-right:1rem;margin-top:1px;width:16px;height:16px;flex-shrink:0}.properties-link-text-container .properties-link-text{font-size:.875rem;font-weight:400;line-height:1.28572;letter-spacing:.16px}.properties-light-enabled{background-color:#fff}.properties-custom-panel+.properties-control-panel{padding-top:1rem}.properties-ft-table-header{display:flex;justify-content:flex-end;height:2rem}.properties-ft-table-header .properties-ft-search-container{min-width:50%;flex-grow:1}.properties-ft-table-header .properties-ft-search-container .properties-ft-search-text svg{fill:#161616}.properties-ft-table-header .properties-ft-search-container .properties-ft-search-text input{background-color:#f4f4f4}.properties-ft-table-header .properties-ft-search-container.disabled{opacity:.5}.properties-ft-container-panel{height:calc(100% - 2rem)}.properties-ft-control-container{height:100%}.properties-ft-container-wrapper{height:400px;width:100%;position:relative;overflow:hidden}.properties-ft-container-absolute-noheader{position:absolute;height:100%;width:100%;overflow-y:auto;overflow-x:hidden;background-color:#fff;display:flex;flex-direction:column}.properties-ft-container-absolute-noheader.error{border:1px solid #da1e28}.properties-ft-container-absolute-noheader.warning{border:1px solid #f1c21b}.properties-ft-container-absolute{height:100%;width:100%;background-color:#fff}.properties-ft-container-absolute.error{border:1px solid #da1e28}.properties-ft-container-absolute.warning{border:1px solid #f1c21b}.properties-ft-container-absolute .properties-ft-container{height:100%}.properties-ft-container-absolute div[data-role=properties-header-row]{width:inherit;display:inline-flex}.properties-ft-container-absolute div[data-role=properties-header-row] .properties-autosized-vt-header:focus{outline:none}.properties-ft-container-absolute div[data-role=properties-header-row] .properties-autosized-vt-header .properties-ft-column-sort-icon svg:not(:root){display:none}.properties-ft-container-absolute div[data-role=properties-header-row] .properties-autosized-vt-header:hover:not([disabled]) .properties-ft-column-sort-icon svg:not(:root){display:inline}.properties-ft-container-absolute div[data-role=properties-header-row] .properties-autosized-vt-header .sort-column-active>.properties-ft-column-sort-icon svg:not(:root){display:inline}.properties-ft-container-absolute div[data-role=properties-header-row] .properties-tooltips-container{display:inline-flex;justify-content:space-between;width:100%;align-self:center;padding:0 1rem}.properties-ft-container-absolute div[data-role=properties-header-row] .tooltip-container{overflow:hidden}.properties-ft-container-absolute div[data-role=properties-header-row] .tooltip-trigger{overflow:hidden;text-overflow:ellipsis;white-space:nowrap;height:100%;font-weight:600}.properties-truncated-tooltip{overflow:hidden}.properties-truncated-tooltip .tooltip-trigger{width:inherit;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.properties-vt{width:100%;height:100%}.properties-vt .properties-autosized-vt>div[role=rowgroup]:focus{outline-style:none}.properties-vt .properties-autosized-vt .properties-vt-row-disabled{opacity:.5}.properties-vt .properties-autosized-vt .properties-vt-row-disabled:hover{border-bottom:1px solid #e0e0e0}.properties-vt .properties-vt-header-checkbox{height:2rem;display:flex;align-items:center;margin-left:1rem;margin-right:.25rem}.properties-vt div[data-role=properties-header-row]{background-color:#e0e0e0}.properties-vt div[data-role=properties-data-row]{background-color:#f4f4f4}.properties-vt .properties-autosized-vt-header{text-transform:none;margin-left:0}.properties-vt .properties-autosized-vt-header .properties-vt-column .bx--checkbox-wrapper{margin-top:0;margin-bottom:0}.properties-vt .properties-autosized-vt-header .properties-vt-column .bx--checkbox-wrapper .bx--checkbox-label{width:100%}.properties-vt .properties-autosized-vt-header .properties-vt-column .bx--checkbox-wrapper .bx--checkbox-label span{font-size:.875rem;font-weight:600;line-height:1.28572;letter-spacing:.16px;color:#161616;text-overflow:ellipsis;white-space:nowrap;overflow:hidden;width:100%;line-height:unset}.properties-vt .properties-vt-column-with-resize,.properties-vt .properties-vt-column-without-resize{display:inline-flex;width:100%}.properties-vt .properties-vt-column-with-resize .properties-vt-header-resize{flex:0 0 .25rem;z-index:2;cursor:col-resize}.properties-vt .properties-vt-column-with-resize .properties-vt-header-resize:hover{background-color:#6f6f6f}.properties-vt .properties-vt-column-with-resize .properties-vt-header-resize-active{z-index:3}.properties-vt .properties-vt-column-with-resize:hover{background-color:#c6c6c6}.properties-vt .properties-vt-column-with-resize:hover .properties-vt-header-resize{background-color:#6f6f6f}.properties-vt .properties-vt-row-checkbox{height:2rem;margin-left:1rem;margin-right:.25rem}.properties-vt .properties-vt-double-click:first-of-type .properties-vt-row-class{border-top:1px solid transparent}.properties-vt .properties-vt-double-click:first-of-type .properties-vt-row-class.properties-vt-row-selected{border-top:1px solid #cacaca}.properties-vt .properties-vt-row-class{line-height:20px;border-bottom:1px solid #e0e0e0}.properties-vt .properties-vt-row-class:hover:not(.properties-vt-row-non-interactive):not(.properties-vt-row-selected){background-color:#e5e5e5}.properties-vt .properties-vt-row-class .properties-table-cell-control .properties-numberfield input{margin-bottom:5px}.properties-vt .properties-vt-row-class .properties-table-cell-control .properties-textarea textarea{resize:none;height:42px;min-width:100%}.properties-vt .properties-vt-row-class .ReactVirtualized__Table__headerColumn{margin-right:0;display:flex;flex-direction:row;justify-content:center;height:100%}.properties-vt .properties-vt-row-class .ReactVirtualized__Table__rowColumn{margin-right:0;margin-left:0}.properties-vt .properties-vt-row-class .ReactVirtualized__Table__sortableHeaderColumn .properties-tooltips-container{padding:0;padding-left:1rem}.properties-vt .properties-vt-row-class .ReactVirtualized__Table__sortableHeaderColumn:hover{background-color:#c6c6c6}.properties-vt .properties-vt-row-class .ReactVirtualized__Table__headerTruncatedText{flex:auto}.properties-vt .properties-vt-row-selected{background-color:#e0e0e0;border-bottom:1px solid #cacaca}.properties-vt .properties-vt-row-selected:hover{background-color:#cacaca}.properties-vt .properties-vt-single-selection div[data-role=properties-header-row]{padding-left:3px}.properties-vt .properties-vt-single-selection .properties-vt-row-class{padding-left:3px}.properties-vt .properties-vt-single-selection .properties-vt-row-selected{border-left:4px solid #0f62fe;padding-left:0}.properties-vt .properties-vt-single-selection .properties-vt-row-selected:not(.properties-vt-row-disabled):hover{border-left:4px solid #0f62fe}.properties-vt .properties-vt-small-loading svg{stroke:#0f62fe}.properties-vt .properties-vt-autosizer{height:100%;width:100%}.properties-vt .properties-light-disabled div[data-role=properties-data-row]{background-color:#fff}.properties-vt .properties-light-disabled .bx--select--inline .bx--select-input[disabled]{background-color:#f4f4f4}.properties-vt .properties-ft-column-sort-icon{flex:0 0 1rem;align-self:center;height:1rem;margin-right:.5rem}.properties-empty-table{font-size:.875rem;font-weight:400;line-height:1.28572;letter-spacing:.16px}.properties-empty-table[disabled]{opacity:.5;pointer-events:none}.properties-empty-table .properties-empty-table-button{margin:1rem 0}.properties-custom-table-buttons .toolbar-div{height:2rem}.properties-custom-table-buttons .toolbar-div .toolbar-left-bar{padding-right:0}.properties-custom-table-buttons .toolbar-div .toolbar-left-bar .toolbar-item button{height:2rem}.properties-custom-table-buttons .toolbar-div .toolbar-left-bar .toolbar-item-content{padding:.25rem .5rem;height:2rem;min-width:2rem;align-items:center}.properties-custom-table-buttons .toolbar-div .toolbar-left-bar .toolbar-overflow-item button{height:2rem}.properties-custom-table-buttons .toolbar-div .toolbar-left-bar .toolbar-popover-list{top:2rem;right:0}.properties-custom-table-buttons .toolbar-div .toolbar-right-bar{display:none}.properties-readonly.hide{display:none}.properties-readonly .properties-tooltips{white-space:normal;overflow:visible;word-break:break-word;text-overflow:clip}.properties-readonly span{white-space:normal;line-height:1.5;overflow-wrap:break-word;-webkit-user-select:text;-moz-user-select:text;-ms-user-select:text;user-select:text;cursor:text}.properties-readonly span[disabled]{opacity:.5;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;cursor:default}.properties-readonly .properties-field-readonly{height:100%;width:inherit;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;display:flex;align-items:center}.properties-readonly .properties-field-readonly .properties-field-type-icon{width:15px;height:15px;float:left;margin-right:5px;flex-shrink:0}.properties-readonly .properties-field-readonly .properties-field-type-icon svg{width:16px;height:16px}.properties-readonly .tooltip-trigger span{white-space:nowrap}.properties-checkbox{display:flex;align-items:center;flex-wrap:wrap}.properties-checkbox .tooltip-container{margin-left:.5rem;cursor:pointer}.properties-checkbox .tooltip-container .tooltip-trigger{display:flex}.properties-checkbox .bx--form-item.bx--checkbox-wrapper{flex:initial}.properties-checkbox .properties-validation-message{flex:0 1 100%}.properties-checkbox.hide{display:none}.table .bx--form-item.bx--checkbox-wrapper:first-of-type{margin-top:0;padding:1px}.properties-checkboxset.hide{display:none}.properties-checkboxset .bx--checkbox-wrapper{margin-bottom:.5rem}.properties-checkboxset .properties-checkboxset-container.error:not([disabled]){padding-bottom:.25rem}.properties-checkboxset .properties-checkboxset-container.warning:not([disabled]){padding-bottom:.25rem}.properties-dropdown .bx--list-box--expanded .bx--list-box__menu{margin-bottom:1px}.properties-dropdown.hide{display:none}.properties-table-cell-control>.properties-dropdown{width:100%}.properties-table-cell-control>.properties-dropdown .bx--select.bx--select--inline{width:100%}.properties-table-cell-control>.properties-dropdown .bx--select.bx--select--inline .bx--select-input--inline__wrapper{width:100%}.properties-table-cell-control>.properties-dropdown .bx--select.bx--select--inline svg{right:0}.properties-table-cell-control>.properties-dropdown .bx--select-input{width:inherit;background-color:transparent;padding:0 1.25rem 0 0;box-shadow:0 2px 0 0 #0f62fe}.properties-table-cell-control>.properties-dropdown .bx--select-input:hover{background:unset}.properties-table-cell-control>.properties-dropdown .bx--select-input:focus{outline:unset}.properties-table-cell-control>.properties-dropdown.error .bx--select-input{box-shadow:0 2px 0 0 #da1e28}.properties-table-cell-control>.properties-dropdown.warning .bx--select-input{box-shadow:0 2px 0 0 #f1c21b}.properties-expression-selection-container,.properties-field-and-values-table-container,.properties-functions-table-container{width:100%}.properties-expression-selection-container tbody tr,.properties-field-and-values-table-container tbody tr,.properties-functions-table-container tbody tr{border-bottom:0}.properties-expression-selection-container{padding-top:.5rem}.properties-expression-selection-operator{padding-bottom:2rem}.properties-field-table-container{width:48%;float:left}.properties-field-table-container .properties-ft-search-container{width:100%}.properties-value-table-container{width:48%;margin-left:52%}.properties-value-table-container .properties-ft-search-container{width:100%}.properties-functions-table{width:68%;float:left}.properties-functions-table .properties-ft-search-container{width:100%}.properties-help-table-container{width:28%;margin-left:70%}.properties-function-help-command{font-weight:700;text-decoration:underline}.properties-function-help-text{overflow-wrap:break-word}.properties-operator-title{padding-top:1rem;padding-bottom:2rem;width:100%;font-weight:bold;text-align:center}.properties-operator-container{display:flex;flex-wrap:wrap}.properties-operator-container .properties-operator-tooltip-container{width:36px;margin-right:.5rem;margin-top:.5rem}.properties-operator-container .properties-operator-button{height:36px;width:36px;padding:0}.properties-operator-container .properties-operator-button .properties-operator-button-label{margin:0 auto}.properties-expression-selection-content-switcher{padding-bottom:2.5rem}.properties-expression-selection-content-switcher div{max-width:50%;float:right}.properties-expression-field-select,.properties-expression-function-select{padding-top:1.5rem;padding-bottom:1.5rem}.properties-expression-table-dropdown-header{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;padding-bottom:.25rem}.properties-primaryTabs .bx--tabs-trigger{margin-bottom:5px}.CodeMirror-hints{z-index:1110}.CodeMirror-placeholder{opacity:.5}.CodeMirror{width:100%;background:#f4f4f4;color:#161616}.CodeMirror-cursor{border-left:1px solid #161616}.cm-s-error.CodeMirror{border:.125rem solid #da1e28}.cm-s-warning.CodeMirror{border:.125rem solid #f1c21b}.cm-s-disabled.CodeMirror{opacity:.5}.cm-s-custom .cm-keyword{color:#0f62fe}.cm-s-custom .cm-number{color:#525252}.cm-s-custom .cm-def{color:#da1e28}.cm-s-custom .cm-comment{color:#198038}.cm-s-custom .cm-variable,.cm-s-custom .cm-punctuation,.cm-s-custom .cm-property,.cm-s-custom .cm-operator{color:#161616}.cm-s-custom .cm-variable-2{color:#161616}.cm-s-custom .cm-variable-3,.cm-s-custom .cm-type{color:#161616}.cm-s-custom .cm-string{color:#da1e28}.cm-s-custom .cm-string-2{color:#da1e28}.cm-s-custom .cm-meta{color:#fff}.properties-expression-editor{border:1px solid #e0e0e0}.properties-expression-editor.disabled{opacity:.5}.properties-expression-editor.error,.properties-expression-editor.warning{border:0}.properties-light-disabled .CodeMirror{background:#fff}.properties-expression-link-container{display:flex;justify-content:space-between}.properties-expression-link-container .properties-expression-validate{display:flex;flex-direction:row-reverse}.properties-expression-link-container .properties-expression-validate .icon{margin:.125rem}.properties-expression-link-container .properties-expression-validate .icon svg{height:10px;width:10px}.properties-expression-link-container .properties-expression-validate .validateLink{min-height:2rem;padding:.25rem}.properties-expression-header{position:relative;height:2rem}.properties-expression-header .properties-expression-title{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;position:absolute;bottom:5px;left:0}.properties-expression-header .properties-expression-link-container{position:absolute;bottom:0;right:0}.properties-expression-button.bx--btn--sm.bx--btn--ghost{padding:.25rem}.properties-expression-button.bx--btn--sm.bx--btn--ghost svg{height:20px;width:20px;margin-left:0}.properties-radioset.hide{display:none}.properties-radioset .bx--form-item{margin-bottom:.25rem}.properties-radio-button-group{display:block}.properties-radio-button-group.horizontal{display:inline-flex;flex-wrap:wrap}.properties-radio-button-group.horizontal .properties-radioset-panel{margin-bottom:0}.properties-radio-button-group .properties-radioset-panel{margin-bottom:.25rem;margin-right:.75rem}.properties-radio-button-group .properties-radioset-panel:last-of-type{margin-bottom:0}.properties-radio-button-group .properties-radioset-panel .bx--radio-button-wrapper>label{justify-content:left}.properties-radio-button-group.error:not([disabled]){padding-bottom:.25rem}.properties-radio-button-group.warning:not([disabled]){padding-bottom:.25rem}.properties-textarea .bx--form-item{margin-right:0;margin-bottom:0}.properties-textarea.hide{display:none}.properties-someofselect .properties-ft-container-absolute-noheader tr{border-bottom:0}.properties-someofselect .properties-ft-container-absolute-noheader tr:not(.disabled):hover{border:1px solid #0f62fe}.properties-someofselect.hide{display:none}.properties-someofselect.error .properties-ft-container-absolute-noheader{border:1px solid #da1e28}.properties-someofselect.warning .properties-ft-container-absolute-noheader{border:1px solid #f1c21b}.properties-someofselect .properties-vt-row-checkbox{margin-right:1rem}.properties-toggletext.hide{display:none}.properties-toggletext.error button{border-bottom:2px solid #da1e28}.properties-toggletext.warning button{border-bottom:2px solid #f1c21b}.properties-table-cell-control .properties-toggletext button{padding:0 .25rem}.properties-input-control.hide{display:none}.properties-input-control .bx--form-item{margin-right:0;margin-bottom:0}.properties-input-control input{min-width:unset}.properties-table-cell-control .properties-input-control{padding-bottom:5px;width:100%}.properties-table-cell-control .properties-input-control input{background:unset;background-color:unset;margin:0;padding:0;height:1.72rem}.properties-table-cell-control .properties-input-control input:focus{border-top:0;border-right:0;border-left:0}.properties-table-cell-control .properties-input-control.error input:not([disabled]){box-shadow:0 2px 0 0 #da1e28}.properties-table-cell-control .properties-input-control.warning input:not([disabled]){box-shadow:0 2px 0 0 #f1c21b}.properties-table-cell-control input:disabled:hover{box-shadow:0 2px 0 0 #525252}.properties-table-cell-control .properties-textinput-readonly{margin-bottom:-5px}.properties-table-cell-control .properties-textinput-readonly .properties-validation-message.inTable{margin-left:-0.75rem}.properties-table-cell-control>div>:first-child{padding:0 1rem}.properties-table-subcell{display:flex;align-items:center;height:100%}.properties-at-selectedEditRows{background-color:#393939}.properties-at-selectedEditRows .properties-selectedEditRows-title{padding-top:10px;padding-bottom:10px;padding-left:12px;color:#fff}.properties-at-selectedEditRows .properties-ft-table-header{display:none}.properties-at-selectedEditRows .properties-vt-row-checkbox{width:1.25rem}.properties-at-selectedEditRows .properties-vt-row-class{background-color:#e0e0e0}.properties-at-selectedEditRows .properties-vt-row-class:hover{border:1px solid transparent;background-color:#cacaca}.properties-numberfield .bx--form-item{margin-right:0;margin-bottom:0}.properties-numberfield .properties-number-generator{margin-left:1rem;right:.125rem;width:2.5rem;min-height:2.5rem;padding-left:.75rem;padding-right:.75rem}.properties-numberfield.numberfield-with-number-generator{width:100%;display:inline-flex;align-items:flex-end}.properties-numberfield.numberfield-with-number-generator.error,.properties-numberfield.numberfield-with-number-generator.warning{align-items:flex-start}.properties-numberfield.numberfield-with-number-generator.error .properties-number-generator,.properties-numberfield.numberfield-with-number-generator.warning .properties-number-generator{margin-top:1.5rem}.properties-table-cell-control .properties-numberfield .bx--number[data-invalid] .bx--form-requirement{display:none}.properties-table-cell-control .properties-numberfield.error input[type=number]:not([disabled]),.properties-table-cell-control .properties-numberfield.error input[type=number]:focus:not([disabled]){box-shadow:0 2px 0 0 #da1e28}.properties-table-cell-control .properties-numberfield.warning input[type=number]:not([disabled]),.properties-table-cell-control .properties-numberfield.warning input[type=number]:focus:not([disabled]){box-shadow:0 2px 0 0 #f1c21b}.properties-table-cell-control .properties-numberfield input[type=number]{background-color:unset;padding:0;height:1.5rem}.properties-table-cell-control .properties-numberfield .bx--number input[type=number]{min-width:0}.properties-structureeditor .hide{display:none}.properties-structureeditor-cell{padding-right:5px;vertical-align:middle}.properties-table-cell-control .properties-dropdown .bx--multi-select__wrapper>label{display:none}.properties-ctrl-wrapper{padding-bottom:1rem}.properties-ctrl-wrapper.action{display:flex}.properties-ctrl-wrapper.action>div:first-child{width:100%}.properties-ctrl-wrapper.hide{display:none}.properties-summary-panel.properties-summary-panel.hide{display:none}.properties-summary-panel.properties-summary-panel[disabled]{opacity:.5;pointer-events:none}.properties-summary-panel.properties-summary-panel .properties-summary-link-icon{width:16px;height:16px}.properties-summary-link-container{display:flex;align-items:center}.properties-summary-values{border-top:1px solid #e0e0e0;padding:1rem 0}.properties-summary-table{font-size:.875rem;font-weight:400;line-height:1.28572;letter-spacing:.16px;color:#161616;max-height:270px;width:100%;display:flex;margin:.5rem 0}.properties-summary-table>tbody{width:100%}.properties-summary-label{font-size:.875rem;font-weight:600;line-height:1.28572;letter-spacing:.16px;color:#161616;margin-bottom:1rem}.properties-summary-row-data>.tooltip-container{margin:1px 0}.properties-summary-row-data>.tooltip-container>div:first-child{text-overflow:ellipsis;white-space:nowrap;overflow:hidden}.properties-summary-row{display:flex;justify-content:space-between;padding:2px 0}button.properties-subpanel-button{padding:0;min-height:2rem;height:2rem;width:2rem;display:flex;justify-content:center}.properties-sub-tab-container .bx--tab-content{padding-left:0;padding-right:0}.properties-twisty-panel.hide{display:none}.properties-twisty-panel .bx--accordion__item{border-top:0;margin:0 -1rem}.properties-twisty-panel .bx--accordion__item--active .bx--accordion__content{padding:1.5rem 1rem 1rem}.properties-twisty-panel+.properties-control-panel{padding-top:1rem}.properties-text-panel :not(:empty){padding-bottom:1rem}.properties-text-panel .panel-label{font-size:.875rem;font-weight:600;line-height:1.28572;letter-spacing:.16px;color:#161616;padding-bottom:.5rem}.properties-text-panel .panel-description{font-size:.875rem;font-weight:400;line-height:1.28572;letter-spacing:.16px;color:#161616}.properties-text-panel[disabled]{opacity:.5;pointer-events:none}.properties-text-panel.hide{display:none}.properties-action-panel{display:flex;flex-wrap:wrap;padding-bottom:.5rem}.properties-action-panel:last-child{padding-bottom:1.5rem}.properties-action-panel[disabled]{opacity:.5;pointer-events:none}.properties-action-panel.hide{display:none}.properties-action-panel+.properties-control-panel{padding-top:.5rem}.properties-column-panel{display:grid;-moz-column-gap:1rem;column-gap:1rem}.properties-column-panel .properties-control-panel:not(:empty)+.properties-control-panel:not(:empty){padding-top:0}.properties-column-panel.hide{display:none}.properties-column-panel[disabled]{opacity:.5;pointer-events:none}.properties-control-panel{display:block}.properties-control-panel:last-child{padding-bottom:.5rem}.properties-control-panel.hide{display:none}.properties-control-panel[disabled]{opacity:.5;pointer-events:none}.properties-control-panel>.properties-control-panel:not(:empty):last-child{padding-bottom:0}.properties-control-panel+.properties-control-panel:not(:empty){padding-top:1.5rem}.properties-control-nested-panel{padding:0 0 0 1rem;border-left:1px solid #8d8d8d}.properties-control-nested-panel .properties-control-nested-panel{border-left:1px solid #e0e0e0}:export{flyoutWidthSmall:320px;flyoutWidthMedium:480px;flyoutWidthLarge:640px}.properties-right-flyout{font-size:14px;width:0;height:100%;overflow:hidden;border-left:1px solid #e0e0e0;outline:none}.properties-right-flyout.properties-small{width:320px}.properties-right-flyout.properties-medium{width:480px}.properties-right-flyout.properties-large{width:640px}.properties-right-flyout:hover .properties-btn-resize{visibility:visible;opacity:1}.properties-right-flyout .properties-btn-resize{transition:visibility 240ms,opacity 240ms;opacity:0;visibility:hidden;position:absolute;top:50%;left:-13px;z-index:1;min-height:24px;min-width:24px;background-color:#fff;border:1px #8d8d8d solid;padding:2px;justify-content:center}.properties-right-flyout .properties-btn-resize:hover{background-color:#e0e0e0}.properties-right-flyout .properties-btn-resize svg{fill:#161616;width:16px;height:16px}.properties-right-flyout>.properties-custom-container{height:calc(100% - 65px - 4rem);overflow-y:auto;transform:translateZ(0)}.properties-right-flyout>.properties-custom-container.properties-custom-container-with-heading{height:calc(100% - 89px - 4rem)}.properties-right-flyout>.properties-custom-container.properties-custom-container-applyOnBlur{height:calc(100% - 6rem)}.properties-right-flyout>.properties-custom-container.properties-custom-container-applyOnBlur-with-heading{height:calc(100% - 89px)}.properties-light-enabled{background-color:#fff}.properties-light-disabled{background-color:#f4f4f4}.properties-error-heading .properties-validation-message{padding:40px 10px 0;align-items:left;-webkit-box-align:left;display:flex}.properties-error-heading .properties-validation-message span{font-size:20px;font-weight:300;font-style:italic}.properties-error-heading .properties-validation-message svg{height:25px}.properties-error-content{padding:0 10px;font-size:14px;font-weight:300;line-height:16px}.properties-modal-container{height:70px;align-items:left}.properties-modal-error button:first-of-type{display:none}.properties-flyout-error-container{height:calc(100% - 46px)}.notification-panel-container{transition:.25s ease-in-out;opacity:1;margin-top:0}.notification-panel-container.panel-hidden{transition:.25s ease-in-out;display:block;opacity:0;visibility:hidden}.notification-panel{position:absolute;width:320px;height:-webkit-fit-content;height:-moz-fit-content;height:fit-content;right:0;top:41px}.notification-panel-header-container{min-height:35px;width:inherit;background-color:#fff;display:flex;flex-direction:column;justify-content:center;border:1px solid #e0e0e0;border-bottom:0;padding:1rem}.notification-panel-header-container .notification-panel-header{font-size:1rem;font-weight:600;line-height:1.375;letter-spacing:0}.notification-panel-header-container .notification-panel-subtitle{font-size:.75rem;line-height:1.33333;letter-spacing:.32px;color:#525252;padding-top:.25rem}.notification-panel-header-container .notification-panel-close-icon{position:absolute;right:1rem;top:1.25rem;cursor:pointer}.notification-panel-clear-all-container{width:100%;height:49px;background-color:#fff;display:flex;flex-direction:column;justify-content:center;border-left:1px solid #e0e0e0;border-right:1px solid #e0e0e0;border-bottom:1px solid #e0e0e0;font-weight:400;padding:.5rem 1rem}.notification-panel-clear-all-container .bx--btn--ghost.bx--btn--sm{width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;padding:0}.notification-panel-messages-container{width:inherit;max-height:calc(100% - 35px);height:-webkit-fit-content;height:-moz-fit-content;height:fit-content}.notification-panel-messages{max-height:500px;height:-webkit-fit-content;height:-moz-fit-content;height:fit-content;overflow-y:auto;line-height:normal;background-color:#fff;border:1px solid #e0e0e0}.notification-panel-messages .notifications-button-container{border-bottom:1px solid #e0e0e0;min-height:48px}.notification-panel-messages .notification-panel-empty-message-container{min-height:48px;display:flex;justify-content:center;align-items:center}.notification-panel-messages .notification-panel-empty-message-container .notification-panel-empty-message{font-size:.875rem;font-weight:400;line-height:1.28572;letter-spacing:.16px;text-align:center;padding-right:30px;padding-left:30px}.notification-panel-messages .notifications-button-container:nth-last-of-type(1){border-bottom:0}.notification-panel-messages .notifications{padding:1rem 1rem 1rem calc(1rem - 4px);display:inline-flex;width:100%;min-height:48px;background-color:#fff;border-style:none;border-left:4px solid #fff;cursor:default;margin-top:0;margin-bottom:0}.notification-panel-messages .notifications.clickable{cursor:pointer}.notification-panel-messages .notifications:active,.notification-panel-messages .notifications:focus{outline:none;border-style:none;border-left:4px solid #fff}.notification-panel-messages .notifications:hover{background-color:#e5e5e5}.notification-panel-messages .notifications:hover.unspecified{border-left:4px solid #fff}.notification-panel-messages .notifications:hover.error{border-left:4px solid #da1e28}.notification-panel-messages .notifications:hover.warning{border-left:4px solid #f1c21b}.notification-panel-messages .notifications:hover.success{border-left:4px solid #198038}.notification-panel-messages .notifications:hover.info{border-left:4px solid #0043ce}.notification-panel-messages .notifications .notification-message-type{display:flex;justify-content:center;height:18px;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;padding-right:.5rem}.notification-panel-messages .notifications .notification-message-type>svg{display:flex;justify-content:center;width:1rem;height:100%}.notification-panel-messages .notifications .notification-message-details{text-align:left;overflow-wrap:break-word;width:266px}.notification-panel-messages .notifications .notification-message-details .notification-message-title{font-size:.875rem;font-weight:600;line-height:1.28572;letter-spacing:.16px;color:#525252;padding-bottom:.25rem}.notification-panel-messages .notifications .notification-message-details .notification-message-subtitle{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;color:#161616}.notification-panel-messages .notifications .notification-message-details .notification-message-subtitle hr{margin-bottom:.5rem;border-bottom:0;border-top:solid 1px #e0e0e0}.notification-panel-messages .notifications .notification-message-details .notification-message-content{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;color:#525252}.notification-panel-messages+*{clear:both}.notification-message-timestamp{display:inline-flex;color:#525252}.notification-message-timestamp svg{width:10px;height:10px;margin-right:3px;margin-top:3px}.notification-message-timestamp .notification-message-string{font-size:10px;margin-top:auto;margin-bottom:auto}.notification-message-close:hover{text-decoration:underline}.canvas-icon .stroke,.canvas-icon.stroke{stroke:#161616}.canvas-icon .fill,.canvas-icon.fill{fill:#161616}.canvas-icon[disabled]{fill:#c6c6c6}svg.properties-icon,svg.canvas-icon{fill:#161616}svg.canvas-state-icon-error{fill:#da1e28}svg.canvas-state-icon-success{fill:#198038}svg.canvas-state-icon-warning{fill:#f1c21b}svg.canvas-state-icon-warning [data-icon-path=inner-path]{fill:#161616;opacity:1}svg.canvas-state-icon-info{fill:#0043ce}svg.canvas-state-icon-information-hollow{fill:#161616}.toolbar-div{height:40px;width:100%;background-color:#fff;border-bottom:1px solid #8d8d8d;box-sizing:content-box;position:relative;display:flex;justify-content:space-between;-webkit-user-drag:none}.toolbar-left-bar{flex-shrink:5000000;display:block;padding-right:42px;overflow:hidden;align-items:center}.toolbar-right-bar{display:flex;flex-direction:row-reverse;flex-wrap:wrap;justify-content:flex-start;flex-shrink:1;overflow:hidden}.toolbar-item{background-color:#fff;display:inline-block}.toolbar-item button{padding:0;height:40px;min-height:30px}.toolbar-item.default button,.toolbar-item.ghost button{background-color:#fff}.toolbar-item.default button:hover,.toolbar-item.ghost button:hover{background-color:#e5e5e5}.toolbar-item.default button:focus,.toolbar-item.ghost button:focus{background-color:#e5e5e5}.toolbar-item.default button:disabled:hover,.toolbar-item.ghost button:disabled:hover{background-color:#fff}.toolbar-item.tertiary button{color:#0f62fe;background-color:#fff}.toolbar-item.tertiary button:hover{background-color:#e5e5e5}.toolbar-item.tertiary button:disabled,.toolbar-item.tertiary button:disabled:hover{color:#c6c6c6;background-color:#fff}.toolbar-spacer{width:0;display:inline-block}.toolbar-overflow-item{background-color:#fff;display:inline-block}.toolbar-overflow-item button{padding:0;height:40px;min-height:30px;background-color:#fff;border-right:1px solid #e0e0e0}.toolbar-overflow-item button:hover{background-color:#e5e5e5}.toolbar-overflow-item button:disabled:hover{background-color:#fff}.toolbar-overflow-menu-item button{width:100%;padding-top:2px;padding-bottom:2px;min-height:20px}.toolbar-item-content{width:inherit;display:flex;justify-content:center;padding:11px}.toolbar-item-content.overflow{justify-content:left;padding:8px 0}.toolbar-item-content.default{color:#161616}.toolbar-item-content.disabled.default{color:#c6c6c6;fill:#c6c6c6}.toolbar-item-content .toolbar-icon{height:16px}.toolbar-item-content .toolbar-icon svg{height:16px;width:16px;-webkit-user-drag:none}.toolbar-text-content{position:absolute;top:14px;font-size:9px;line-height:9px;color:#161616}.toolbar-icon-label{line-height:16px}.toolbar-icon-label.before{padding-right:8px}.toolbar-icon-label.after{padding-left:8px}.toolbar-icon-label.overflow{padding-left:8px;word-break:break-word;-webkit-hyphens:auto;-ms-hyphens:auto;hyphens:auto}.toolbar-jsx-item{height:40px;display:inline-flex;align-items:center;vertical-align:top;position:relative;background-color:#fff;padding:0}.toolbar-overflow-jsx-item{width:100%;height:38px;display:inline-flex;align-items:center;vertical-align:top;position:relative;padding:0}.toolbar-item-selected.default button,.toolbar-item-selected.ghost button{background-color:#e0e0e0;border-color:transparent;box-shadow:none;border-bottom:2px solid #0f62fe}.toolbar-divider{border-right:1px solid #e0e0e0;background-color:#fff;display:inline-block;height:40px;width:0}.toolbar-divider-overflow{height:0;border-bottom:1px solid #e0e0e0}.toolbar-popover-list{width:200px;z-index:1;top:calc(40px + 1px);display:block;position:absolute;list-style-type:none;padding:0;border:1px solid #e0e0e0;background-color:#fff}.toolbar-popover-list-hide{display:none}.tooltip-container,.tooltip-trigger{height:100%}.common-canvas-tooltip{font-size:12px;position:fixed;padding:1rem;background-color:#393939;border:1px solid #393939;font-weight:400;opacity:90%;color:#fff;line-height:1.2;text-align:left;z-index:10000;pointer-events:none;word-wrap:break-word;max-width:228px;border-radius:2px}.common-canvas-tooltip .bx--link{display:block;color:#78a9ff;margin-top:1rem;pointer-events:auto;cursor:pointer}.common-canvas-tooltip .bx--link:hover{color:#78a9ff;text-decoration:underline}.common-canvas-tooltip[direction=right]{transform:translate3d(-22px, 0, 0)}.common-canvas-tooltip[direction=top]{transform:translate3d(0, 22px, 0)}.common-canvas-tooltip[direction=left]{transform:translate3d(22px, 0, 0)}.common-canvas-tooltip[direction=bottom]{transform:translate3d(0, -22px, 0)}.icon-tooltip{padding:.125rem 1rem}.definition-tooltip{padding:.5rem 1rem}.common-canvas-tooltip #tipArrow{position:absolute;width:10px;height:14px}.common-canvas-tooltip[direction=top] #tipArrow{transform:rotate(-90deg)}.common-canvas-tooltip[direction=left] #tipArrow{transform:rotate(180deg)}.common-canvas-tooltip[direction=bottom] #tipArrow{transform:rotate(90deg)}.common-canvas-tooltip #tipArrow polyline{fill:#393939;stroke-width:0}.common-canvas-tooltip #tipArrow polygon{fill:#393939}.common-canvas-tooltip[aria-hidden=false]{transform:scaleX(1) translate3d(0, 0, 0) rotate(0deg);visibility:visible;opacity:100}.common-canvas-tooltip[aria-hidden=true]{visibility:hidden;opacity:0}.tip-palette-item,.tip-node{min-width:80px;max-width:180px;text-align:left}.tip-palette-category{font-size:10px;padding-bottom:4px;color:#fff}.tip-palette-label,.tip-node-label{font-weight:600;color:#fff}.tip-palette-desc,.tip-node-desc{padding-top:4px}.tip-node-status{position:absolute;width:12px;height:12px;right:1rem;top:.5rem}.tip-node-status.warning{fill:#f1c21b}.tip-node-status.error{fill:#da1e28}.tip-port{min-width:90px}.properties-tooltips{background-color:#393939;color:#fff;max-width:250px}.properties-tooltips #tipArrow polyline{fill:#393939}.context-menu-popover{cursor:pointer;min-width:160px;background-color:#fff;background-clip:padding-box;border:0;outline:none;position:absolute;z-index:2;box-shadow:2px 2px 2px rgba(0,0,0,.2)}.context-menu-popover.popover>.arrow{display:none}.context-menu-popover.popover>.popover-content{padding:0}.react-contextmenu{min-width:160px;text-align:left;background-color:#f4f4f4;-webkit-background-clip:padding-box;background-clip:padding-box;border-radius:.25rem;outline:none;display:none;box-shadow:2px 2px 2px rgba(0,0,0,.2)}.react-contextmenu--visible{display:inline-grid}.react-contextmenu-item{height:30px;padding:0 1em;clear:both;color:#161616;text-align:inherit;white-space:nowrap;background:0 0;border:0;display:flex;align-items:center}.react-contextmenu-item.react-contextmenu-item--disabled{opacity:.5;cursor:not-allowed}.react-contextmenu-item:active,.react-contextmenu-item:focus,.react-contextmenu-item:hover{background:#e5e5e5;text-decoration:none;border:0;outline:none}.react-contextmenu-item.react-contextmenu-submenu{padding:0}.react-contextmenu-item.react-contextmenu-submenu>div{padding-right:27px}.react-contextmenu-item svg{color:#161616;position:absolute;right:12px}.react-contextmenu-item.contextmenu-divider{height:1px;display:block;overflow:hidden;background-color:#e0e0e0;padding:0}.palette-flyout-div{border-right:1px solid #e0e0e0;font-size:14px;position:relative;height:100%;padding-bottom:5px;background-color:#fff;transition:.2s;cursor:default;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-flyout-div-open .palette-flyout-content{width:256px;transition:.2s ease-in-out}.palette-flyout-div-closed{transition:.2s ease-in-out;width:0}.palette-flyout-div-narrow{width:72px}.palette-flyout-content{height:41px}.palette-flyout-content .palette-scroll{overflow-y:hidden}.palette-flyout-content .palette-content-list{border-bottom:1px solid #e0e0e0}.palette-flyout-content .palette-no-results-title{font-size:.875rem;font-weight:400;line-height:1.28572;letter-spacing:.16px;width:100%;padding:20px 20px 0;text-align:center}.palette-flyout-content .palette-no-results-desc{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;width:100%;padding:0 20px;text-align:center}.palette-flyout-content .palette-flyout-restrict-item{font-size:.75rem;line-height:1.33333;letter-spacing:.32px;width:100%;padding:2.5rem 20px}.palette-flyout-content .palette-list-item-desc-button{color:#0f62fe;cursor:pointer;padding:5px 0 0}.palette-flyout-content .palette-list-item{height:46px;border-width:0;display:flex;flex-direction:column;align-items:center;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-flyout-content .palette-list-item:hover{background-color:#e0e0e0}.palette-flyout-content .palette-list-item .palette-list-item-category-label{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;width:100%;padding:1rem 10px 0 58px}.palette-flyout-content .palette-list-item .palette-list-item-category-label mark{color:#0f62fe;background-color:#d0e2ff;font-weight:500}.palette-flyout-content .palette-list-item .palette-list-item-icon-and-text{display:flex;flex-direction:row;width:100%;min-height:46px;align-items:center}.palette-flyout-content .palette-list-item .palette-list-item-icon{width:28px;margin-left:20px;color:#525252}.palette-flyout-content .palette-list-item .palette-list-item-text-div{font-size:.875rem;font-weight:600;line-height:1.28572;letter-spacing:.16px;font-weight:400;padding:0 10px;width:calc(100% - 68px)}.palette-flyout-content .palette-list-item .palette-list-item-text-div mark{color:#0f62fe;background-color:#d0e2ff;font-weight:500}.palette-flyout-content .palette-list-item .palette-list-item-icon-warning{transform:scale(1.5);margin-left:25px}.palette-flyout-content .palette-list-item .palette-list-item-description{font-size:.75rem;font-weight:400;line-height:1.33333;letter-spacing:.32px;padding:0 10px 0 58px;word-break:break-word;width:100%}.palette-flyout-content .palette-list-item .palette-list-item-description mark{color:#0f62fe;background-color:#d0e2ff;font-weight:500}.palette-flyout-content .palette-list-item .highlight{background-color:#0f62fe}.palette-flyout-content .palette-list-item.search-result{min-height:46px;height:-webkit-fit-content;height:-moz-fit-content;height:fit-content;padding-bottom:1rem;border-bottom:1px solid #e0e0e0}.palette-flyout-content .palette-list-item.search-result .palette-list-item-icon-and-text{min-height:30px}.palette-flyout-category{cursor:pointer;border-width:0 0 0 1px;height:-webkit-fit-content;height:-moz-fit-content;height:fit-content;min-height:46px;align-items:center;justify-content:space-between;display:flex;border-bottom:1px solid #e0e0e0}.palette-flyout-category-caret{height:16px;width:16px;position:relative;right:16px;background-color:#fff;fill:#161616}.palette-flyout-category-caret-closed{top:0;right:16px}.palette-flyout-category-item{display:flex;align-items:center;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-flyout-category-item-loading{margin-left:16px}.palette-flyout-category-item-icon{width:20px;margin-left:16px;fill:#161616}.palette-flyout-text-container{max-width:205px;display:flex;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-flyout-category-text{width:165px;overflow-wrap:break-word;line-height:1.3;margin-left:16px}.palette-flyout-category-text-abbr{line-height:46px;margin-left:16px;width:35px}.palette-flyout-category-text-no-image{line-height:46px;margin-left:16px;width:170px}.palette-flyout-category-count{line-height:46px;padding-left:5px}.palette-flyout-category:hover{font-weight:600}.palette-flyout-search-container{height:100%}.palette-flyout-search-container .palette-flyout-search{height:100%;overflow:hidden}.palette-flyout-search-container .palette-flyout-search .bx--search-magnifier svg{margin-left:10px}.palette-flyout-search-container .palette-flyout-search svg{fill:#161616}.palette-flyout-search-container .palette-flyout-search input{background:#fff;height:100%;padding-right:3rem;padding-left:52px}.palette-flyout-search-container .palette-flyout-search button{margin-right:8px;margin-top:4px;border-bottom-width:0}.palette-flyout-search-container .palette-flyout-search button.bx--search-close::before{content:none}.palette-flyout-categories{height:calc(100% - 48px);width:100%;position:absolute;overflow-x:hidden;overflow-y:overlay}.palette-dialog-div{position:absolute;bottom:35px;left:60px;width:473px;height:450px;font-size:14px;border:3px solid transparent;cursor:default;z-index:2;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-dialog-div .palette-list-item{height:46px;border-width:1px;border-color:#e0e0e0;border-style:solid;display:flex;flex-direction:column;align-items:center;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-dialog-div .palette-list-item:hover{background-color:#e0e0e0}.palette-dialog-div .palette-list-item .palette-list-item-icon-and-text{display:flex;flex-direction:row;width:100%;height:46px;align-items:center}.palette-dialog-div .palette-list-item .palette-list-item-icon{width:28px;margin-left:20px;line-height:46px;color:#525252}.palette-dialog-div .palette-list-item .palette-list-item-text-div{margin-left:10px}.palette-dialog-div .palette-list-item .palette-list-item-text-span{overflow:hidden;text-overflow:ellipsis;white-space:nowrap;margin-left:10px;line-height:16px}.palette-dialog-div .palette-list-item .palette-list-item-icon-warning{transform:scale(1.5);margin-left:25px}.palette-dialog-topbar{height:40px;padding:10px;background-color:#e0e0e0;border-bottom:1px solid #e0e0e0}.palette-dialog-topbar .left-navbar{height:20px;float:left;vertical-align:middle;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-dialog-topbar .right-navbar{height:20px;float:right;vertical-align:middle}.palette-dialog-topbar .secondary-action{margin-left:10px;display:inline-block;cursor:pointer;width:20px}.palette-dialog-topbar .close-icon svg{fill:#393939}.palette-dialog-topbar .palette-three-way-icon-div{margin-left:5px;display:inline-block;cursor:pointer;width:20px;height:20px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-dialog-content{height:404px;display:flex;background-color:#fff;border-bottom:1px solid #e0e0e0;border-right:1px solid #e0e0e0}.palette-dialog-categories{background-color:#e0e0e0;width:130px;min-width:130px;border-right:1px solid #e0e0e0;overflow-x:hidden}.palette-dialog-category{padding:10px;border-width:0 0 0 1px;cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-dialog-category:hover{font-weight:600}.palette-dialog-category-selected{font-weight:600;border-color:#393939;border-width:0 0 0 1px;border-style:solid;width:130px;min-width:130px;padding-left:8px;padding-top:10px;padding-bottom:10px;cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-dialog-grid-node-outer{width:112px;height:134px;display:inline-block;vertical-align:middle;text-align:center;border-width:1px;border-color:#e0e0e0;border-style:solid;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.palette-dialog-grid-node-outer:hover{border-color:#393939;color:#393939}.palette-dialog-grid-node-inner{padding-top:16px}.palette-dialog-grid-node-icon svg{display:inline-block}.palette-dialog-grid-node-icon .node-icon{width:64px;height:64px}.palette-dialog-grid-node-icon-warning{transform:scale(4);margin-top:25px}.palette-dialog-grid-node-text-warning{width:100%;padding-top:30px}.palette-dialog-grid-node-text{width:100%;padding-top:6px}.palette-scroll{overflow-y:auto}.palette-content-list{width:100%}.common-canvas{height:100%;width:100%;cursor:default;display:flex;position:relative;overflow-x:auto;overflow-y:hidden;font-size:14px}.common-canvas-items-container{height:100%;position:relative;width:100%}.common-canvas-right-side-items{width:100%;display:flex}.common-canvas-main{width:100%;height:100%}.common-canvas-with-bottom-panel{width:100%;position:relative}.common-canvas-drop-div{height:calc(100% - 41px);width:100%;min-width:inherit;position:absolute;cursor:default;top:41px;overflow:hidden}.common-canvas-drop-div.common-canvas-toolbar-none{height:100%;top:0}.common-canvas-drop-div.common-canvas-toolbar-none.common-canvas-bottom-panel-is-open{top:0}.right-flyout-panel{height:100%;position:relative;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;background-color:#fff}.bottom-panel{display:flex;flex-direction:column;height:393px;position:absolute;left:0;right:0;bottom:0;border-top:1px solid #e0e0e0;min-height:75px}.bottom-panel-drag{border-top:#e0e0e0;cursor:row-resize;flex:0 0 2px;border-top-width:1px;background:#fff;transition:all .2s ease-in}.bottom-panel-drag:hover{background:#0f62fe}.bottom-panel-contents{background-color:#fff;width:100%;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;height:100%}.common-canvas-right-side-items-under-toolbar{width:100%}.common-canvas-items-container-under-toolbar{height:calc(100% - 41px);width:100%;display:flex}.common-canvas-drop-div-under-toolbar{height:100%;width:100%;position:relative;cursor:default;overflow:hidden}.empty-canvas{position:absolute;line-height:1.5;left:50%;top:48%;cursor:default;transform:translate(-50%, -50%);pointer-events:none}.empty-canvas-image{color:#a8a8a8;opacity:.4;display:block;text-align:center}.empty-canvas-image svg{width:175px;height:175px}.empty-canvas-text1{font-size:1.25rem;font-weight:400;line-height:1.4;letter-spacing:0;padding-top:.25rem;color:#a8a8a8;display:block;text-align:center}.empty-canvas-text2{font-size:1rem;font-weight:400;line-height:1.375;letter-spacing:0;padding-top:.5rem;color:#a8a8a8;display:block;text-align:center}.dropzone-canvas{position:absolute;line-height:1.5;width:100%;height:100%;left:50%;top:50%;cursor:default;transform:translate(-50%, -50%);pointer-events:all;background-color:#f4f4f4;opacity:.75}.dropzone-canvas-rect{position:absolute;top:30px;left:30px;right:30px;bottom:30px;border-color:#8d8d8d;border-style:dashed;border-width:2px}.toolbar-item-content.notificationCounterIcon.error>div>svg>.dot{fill:#da1e28}.toolbar-item-content.notificationCounterIcon.warning>div>svg>.dot{fill:#f1c21b}.toolbar-item-content.notificationCounterIcon.success>div>svg>.dot{fill:#198038}.toolbar-item-content.notificationCounterIcon.info>div>svg>.dot{fill:#0043ce}.state-tag{font-size:.875rem;font-weight:600;line-height:1.28572;letter-spacing:.16px;color:#fff;background-color:#393939;height:40px;position:absolute;left:50%;top:16px;transform:translate(-50%, 0%);border-radius:20px;padding:9px 0;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.state-tag svg{color:#fff;position:relative;top:3px;margin-left:14px}.state-tag span{margin:0 16px 0 10px}.d3-svg-canvas-div{cursor:default;height:100%;background-color:#f4f4f4}.d3-svg-canvas-div:focus{outline:none}.d3-foreign-object{pointer-events:none;overflow:visible}.d3-region-selector{stroke:#161616;fill:#e0e0e0;opacity:.5}.d3-svg-background{fill:#f4f4f4}.d3-canvas-underlay{fill:#e0e0e0}.d3-temp-cursor-overlay{fill:transparent}.d3-back-to-previous-flow-box{stroke:#0f62fe;fill:#f4f4f4}.d3-back-to-previous-flow-box[data-pointer-hover=yes]{stroke:#0f62fe;fill:#e0e0e0}.d3-back-to-previous-flow-text{font-size:14px;font-weight:400;fill:#0f62fe}.d3-back-to-previous-flow-box,.d3-back-to-previous-flow-text{cursor:pointer}.d3-ghost-div{position:absolute;left:0;top:0;z-index:-10000}.d3-ghost-node{fill:#d0e2ff}.d3-node-group.d3-draggable,.d3-comment-group.d3-draggable{cursor:pointer}.d3-node-group-translucent{opacity:.5}.d3-node-sizing,.d3-comment-sizing{fill:transparent;stroke:transparent}.d3-node-body-outline{stroke:#161616;stroke-width:1;fill:#fff}.d3-node-group:hover>.d3-node-body-outline{stroke:#e0e0e0;stroke-width:1;fill:#cacaca}.d3-node-unavailable .d3-node-body-outline,.d3-node-unavailable .d3-node-label,.d3-node-unavailable svg path{stroke:#c6c6c6;fill:#8d8d8d;color:#c6c6c6}.d3-node-selection-highlight{stroke-width:0;fill:transparent;pointer-events:none}.d3-node-selection-highlight[data-selected=yes]{stroke:#78a9ff;stroke-dasharray:none;stroke-width:5;fill:transparent}.d3-node-image-outline{stroke:#161616;stroke-width:1;fill:#fff}.d3-node-label{color:#161616;font-size:12px;font-weight:500;resize:none;border-style:solid;border-color:transparent;padding:0;width:100%;height:100%;overflow:hidden;line-height:105%;letter-spacing:.16px;border-width:2px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.d3-node-label span{pointer-events:auto}.d3-node-label-entry{color:#161616;font-size:12px;font-weight:500;resize:none;border-style:solid;border-color:transparent;padding:0;width:100%;height:100%;overflow:hidden;line-height:105%;letter-spacing:.16px;background-color:#fff;border-width:6px;pointer-events:auto}.d3-node-label-entry:focus{outline:none;box-shadow:0 0 0 2px #0f62fe}.d3-node-group[data-new-link-over=yes] .d3-node-selection-highlight{stroke:#0f62fe;stroke-dasharray:4;stroke-width:2;fill:#fff;pointer-events:none}.d3-node-error-label{color:#da1e28}.d3-node-warning-label{color:#f1c21b}.d3-node-label-outline{border:solid 1px}.d3-label-single-line{white-space:nowrap;text-overflow:ellipsis}.d3-label-multi-line{white-space:pre-wrap;word-wrap:normal;word-break:break-word;display:-webkit-box;-webkit-line-clamp:2;-webkit-box-orient:vertical}.d3-label-multi-line .d3-label-full{display:inline-block}.d3-label-center{text-align:center}.d3-label-edit-icon-group .d3-label-edit-icon-background1{fill:transparent}.d3-label-edit-icon-group .d3-label-edit-icon-background2{fill:#f4f4f4}.d3-label-edit-icon-group:hover .d3-label-edit-icon-background2{fill:#e0e0e0}.d3-label-edit-icon-group svg{fill:currentColor;color:#161616}.d3-node-dec-outline,.d3-link-dec-outline{fill:transparent;stroke:#161616;stroke-width:1;stroke-dasharray:0}.d3-node-dec-label,.d3-link-dec-label{color:#161616;font-size:12px;font-weight:500;resize:none;border-style:solid;border-color:transparent;padding:0;width:100%;height:100%;overflow:hidden;line-height:105%;letter-spacing:.16px;border-width:2px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.d3-node-dec-label span,.d3-link-dec-label span{pointer-events:auto}.d3-dec-label-entry{color:#161616;font-size:12px;font-weight:500;resize:none;border-style:solid;border-color:transparent;padding:0;width:100%;height:100%;overflow:hidden;line-height:105%;letter-spacing:.16px;background-color:#fff;border-width:6px;pointer-events:auto}.d3-dec-label-entry:focus{outline:none;box-shadow:0 0 0 2px #0f62fe}.d3-node-dec-path,.d3-link-dec-path{fill:#161616;stroke:#161616;stroke-width:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.d3-node-dec-image,.d3-link-dec-image{stroke-width:1;stroke-dasharray:0;fill:currentColor;color:#161616}.d3-node-ellipsis-group .d3-node-ellipsis-background{fill:transparent;stroke-width:0;cursor:context-menu}.d3-node-ellipsis-group .d3-node-ellipsis{fill:#0f62fe;stroke-width:0;cursor:context-menu}.d3-node-ellipsis-group:hover .d3-node-ellipsis-background{fill:#e0e0e0}.d3-node-super-expand-icon-group .d3-node-super-expand-icon-background{fill:transparent;stroke-width:0;cursor:context-menu}.d3-node-super-expand-icon-group .d3-node-super-expand-icon{fill:#0f62fe;stroke-width:0;cursor:context-menu}.d3-node-super-expand-icon-group:hover .d3-node-super-expand-icon-background{fill:#e0e0e0}.d3-error-circle{stroke:#f4f4f4;stroke-width:2;fill:#da1e28}.d3-warning-circle{stroke:#f4f4f4;stroke-width:2;fill:#f1c21b}.d3-error-circle-off{display:none}.d3-node-port-output{stroke:#393939;fill:#fff;stroke-width:1.25}.d3-node-port-output[connected=yes]{stroke:#393939;fill:#393939;stroke-width:2}.d3-node-port-output:hover{stroke:#393939;fill:#393939}.d3-node-port-input{stroke:#393939;fill:#fff;stroke-width:1.25}.d3-node-port-input-assoc,.d3-node-port-output-assoc{stroke:#393939;fill:#fff;stroke-width:1.25}.d3-node-port-input-assoc:hover,.d3-node-port-output-assoc:hover{stroke:#393939;fill:#393939}.d3-node-port-input[connected=yes]{stroke:#fff;fill:#fff;stroke-width:1}.d3-node-port-input[connected=yes] .d3-node-port-input-arrow{stroke:#393939;stroke-width:1;fill:transparent}.d3-node-port-input[connected=yes][isSupernodeBinding=yes]{stroke:#393939;fill:#f4f4f4;stroke-width:1}.d3-node-port-input-arrow{stroke:transparent;fill:transparent}.d3-new-connection-line[linkType=nodeLink],.d3-new-connection-line[linkType=associationLink]{stroke:#78a9ff;stroke-width:2;stroke-dasharray:10 10;fill:none}.d3-new-connection-start[linkType=nodeLink],.d3-new-connection-start[linkType=associationLink]{stroke:#78a9ff;fill:#f4f4f4}.d3-new-connection-guide[linkType=nodeLink],.d3-new-connection-guide[linkType=associationLink]{stroke:#78a9ff;fill:#78a9ff}.d3-new-connection-line[linkType=commentLink]{stroke:#8d8d8d;stroke-width:1;stroke-dasharray:10 10;fill:none}.d3-new-connection-guide[linkType=commentLink]{stroke:#8d8d8d;stroke-width:4;fill:#8d8d8d}.d3-new-connection-arrow[linkType=commentLink]{stroke:#8d8d8d;stroke-width:2;fill:#8d8d8d}.d3-comment-port-circle{stroke:#8d8d8d;stroke-width:2;fill:#8d8d8d}.d3-comment-group:hover .d3-comment-rect{stroke:#4c4c4c}.d3-comment-rect{fill:#fff;stroke:#c6c6c6;stroke-width:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}g.bkg-col-white-0 .d3-comment-rect{fill:#fff}g.bkg-col-white-0 .d3-comment-entry{background-color:#fff;color:#161616}g.bkg-col-yellow-20 .d3-comment-rect{fill:#fddc69}g.bkg-col-yellow-20 .d3-comment-entry{background-color:#fddc69;color:#161616}g.bkg-col-gray-20 .d3-comment-rect{fill:#e0e0e0}g.bkg-col-gray-20 .d3-comment-entry{background-color:#e0e0e0;color:#161616}g.bkg-col-green-20 .d3-comment-rect{fill:#a7f0ba}g.bkg-col-green-20 .d3-comment-entry{background-color:#a7f0ba;color:#161616}g.bkg-col-teal-20 .d3-comment-rect{fill:#9ef0f0}g.bkg-col-teal-20 .d3-comment-entry{background-color:#9ef0f0;color:#161616}g.bkg-col-cyan-20 .d3-comment-rect{fill:#bae6ff}g.bkg-col-cyan-20 .d3-comment-entry{background-color:#bae6ff;color:#161616}g.bkg-col-red-50 .d3-comment-rect{fill:#fa4d56}g.bkg-col-red-50 .d3-comment-entry{background-color:#fa4d56;color:#161616}g.bkg-col-orange-40 .d3-comment-rect{fill:#ff832b}g.bkg-col-orange-40 .d3-comment-entry{background-color:#ff832b;color:#161616}g.bkg-col-gray-50 .d3-comment-rect{fill:#8d8d8d}g.bkg-col-gray-50 .d3-comment-entry{background-color:#8d8d8d;color:#161616}g.bkg-col-green-50 .d3-comment-rect{fill:#24a148}g.bkg-col-green-50 .d3-comment-entry{background-color:#24a148;color:#161616}g.bkg-col-teal-50 .d3-comment-rect{fill:#009d9a}g.bkg-col-teal-50 .d3-comment-entry{background-color:#009d9a;color:#161616}g.bkg-col-cyan-50 .d3-comment-rect{fill:#1192e8}g.bkg-col-cyan-50 .d3-comment-entry{background-color:#1192e8;color:#161616}.d3-comment-selection-highlight{stroke-width:0;fill:transparent;pointer-events:none}.d3-comment-selection-highlight[data-selected=yes]{stroke:#78a9ff;stroke-dasharray:none;stroke-width:3;fill:transparent;pointer-events:none}.d3-comment-text{color:#161616;background-color:transparent;font-size:12px;font-weight:400;font-family:\"ibm-plex-sans\",Helvetica Neue,Arial,sans-serif;resize:none;border-style:solid;border-color:transparent;width:100%;height:100%;pointer-events:auto;overflow:hidden;line-height:105%;letter-spacing:.15px;white-space:pre-wrap;word-wrap:normal;word-break:break-word;border-width:8px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.d3-comment-entry{color:#161616;background-color:transparent;font-size:12px;font-weight:400;font-family:\"ibm-plex-sans\",Helvetica Neue,Arial,sans-serif;resize:none;border-style:solid;border-color:transparent;width:100%;height:100%;pointer-events:auto;overflow:hidden;line-height:105%;letter-spacing:.15px;white-space:pre-wrap;word-wrap:normal;word-break:break-word;background-color:#fff;border-width:6px}.d3-comment-entry:focus{outline:none;box-shadow:0 0 0 2px #0f62fe}.d3-link-line,.d3-link-line-arrow-head{fill:none;pointer-events:none}.d3-comment-link .d3-link-line{stroke:#8d8d8d;stroke-width:1;stroke-dasharray:7.3}.d3-comment-link .d3-link-line-arrow-head{stroke:#8d8d8d;stroke-width:1;stroke-dasharray:0}.d3-object-link .d3-link-line{stroke:#161616;stroke-width:2;stroke-dasharray:5.5}.d3-association-link .d3-link-line{stroke:#8d8d8d;stroke-width:2}.d3-data-link .d3-link-line{stroke:#78a9ff;stroke-width:2}.d3-data-link .d3-link-line-arrow-head{stroke:#78a9ff;stroke-width:2;stroke-dasharray:0}.d3-link-selection-area{fill:none;stroke:transparent;stroke-width:12}.d3-link-selection-area.d3-extra-width{stroke-width:80}.d3-link-group:hover .d3-link-line,.d3-link-group:hover .d3-link-line-arrow-head{stroke:#0043ce;stroke-width:2}.d3-link-group[data-selected] .d3-link-line,.d3-link-group[data-selected] .d3-link-line-arrow-head{stroke:#0043ce;stroke-width:3}.d3-link-group[data-drag-node-over].d3-data-link .d3-link-line,.d3-link-group[data-drag-node-over].d3-data-link .d3-link-line-arrow-head,.d3-link-group[data-selected][data-drag-node-over].d3-data-link .d3-link-line,.d3-link-group[data-selected][data-drag-node-over].d3-data-link .d3-link-line-arrow-head{stroke:#0043ce;stroke-width:5}.d3-link-handle-start{display:none;stroke:transparent;fill:transparent;pointer-events:all}.d3-link-group:hover .d3-link-handle-start,.d3-link-group[data-selected] .d3-link-handle-start{display:inherit;stroke:#0043ce;fill:#78a9ff;pointer-events:all}.d3-link-handle-end{display:none;stroke:transparent;fill:transparent;pointer-events:all}.d3-link-group:hover .d3-link-handle-end,.d3-link-group[data-selected] .d3-link-handle-end{display:inherit;stroke:#0043ce;fill:#78a9ff;pointer-events:all}.color-picker-panel{width:100%;height:55px;display:flex;flex-wrap:wrap}.color-picker-panel .color-picker-item{width:20px;height:20px;margin:5px 0 0 5px;cursor:pointer}.color-picker-panel .color-picker-item.white-0{background-color:#fff;border:1px solid #8d8d8d}.color-picker-panel .color-picker-item.yellow-20{background-color:#fddc69}.color-picker-panel .color-picker-item.gray-20{background-color:#e0e0e0}.color-picker-panel .color-picker-item.green-20{background-color:#a7f0ba}.color-picker-panel .color-picker-item.teal-20{background-color:#9ef0f0}.color-picker-panel .color-picker-item.cyan-20{background-color:#bae6ff}.color-picker-panel .color-picker-item.red-50{background-color:#fa4d56}.color-picker-panel .color-picker-item.orange-40{background-color:#ff832b}.color-picker-panel .color-picker-item.gray-50{background-color:#8d8d8d}.color-picker-panel .color-picker-item.green-50{background-color:#24a148}.color-picker-panel .color-picker-item.teal-50{background-color:#009d9a}.color-picker-panel .color-picker-item.cyan-50{background-color:#1192e8}\n"],"sourceRoot":""}]);
// Exports
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (___CSS_LOADER_EXPORT___);


/***/ }),

/***/ "../../node_modules/dom-helpers/esm/canUseDOM.js":
/*!*******************************************************!*\
  !*** ../../node_modules/dom-helpers/esm/canUseDOM.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (!!(typeof window !== 'undefined' && window.document && window.document.createElement));

/***/ }),

/***/ "../../node_modules/dom-helpers/esm/scrollbarSize.js":
/*!***********************************************************!*\
  !*** ../../node_modules/dom-helpers/esm/scrollbarSize.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ scrollbarSize)
/* harmony export */ });
/* harmony import */ var _canUseDOM__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./canUseDOM */ "../../node_modules/dom-helpers/esm/canUseDOM.js");

var size;
function scrollbarSize(recalc) {
  if (!size && size !== 0 || recalc) {
    if (_canUseDOM__WEBPACK_IMPORTED_MODULE_0__["default"]) {
      var scrollDiv = document.createElement('div');
      scrollDiv.style.position = 'absolute';
      scrollDiv.style.top = '-9999px';
      scrollDiv.style.width = '50px';
      scrollDiv.style.height = '50px';
      scrollDiv.style.overflow = 'scroll';
      document.body.appendChild(scrollDiv);
      size = scrollDiv.offsetWidth - scrollDiv.clientWidth;
      document.body.removeChild(scrollDiv);
    }
  }

  return size;
}

/***/ }),

/***/ "../../node_modules/downshift/dist/downshift.esm.js":
/*!**********************************************************!*\
  !*** ../../node_modules/downshift/dist/downshift.esm.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ Downshift$1),
/* harmony export */   "resetIdCounter": () => (/* binding */ resetIdCounter),
/* harmony export */   "useCombobox": () => (/* binding */ useCombobox),
/* harmony export */   "useMultipleSelection": () => (/* binding */ useMultipleSelection),
/* harmony export */   "useSelect": () => (/* binding */ useSelect)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/esm/objectWithoutPropertiesLoose */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutPropertiesLoose.js");
/* harmony import */ var _babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/esm/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/esm/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/esm/inheritsLoose */ "../../node_modules/@babel/runtime/helpers/esm/inheritsLoose.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_7__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var react_is__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! react-is */ "../../node_modules/react-is/index.js");
/* harmony import */ var compute_scroll_into_view__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! compute-scroll-into-view */ "../../node_modules/compute-scroll-into-view/dist/index.module.js");
/* harmony import */ var tslib__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! tslib */ "../../node_modules/tslib/tslib.es6.js");










var idCounter = 0;
/**
 * Accepts a parameter and returns it if it's a function
 * or a noop function if it's not. This allows us to
 * accept a callback, but not worry about it if it's not
 * passed.
 * @param {Function} cb the callback
 * @return {Function} a function
 */

function cbToCb(cb) {
  return typeof cb === 'function' ? cb : noop;
}

function noop() {}
/**
 * Scroll node into view if necessary
 * @param {HTMLElement} node the element that should scroll into view
 * @param {HTMLElement} menuNode the menu element of the component
 */


function scrollIntoView(node, menuNode) {
  if (!node) {
    return;
  }

  var actions = (0,compute_scroll_into_view__WEBPACK_IMPORTED_MODULE_6__["default"])(node, {
    boundary: menuNode,
    block: 'nearest',
    scrollMode: 'if-needed'
  });
  actions.forEach(function (_ref) {
    var el = _ref.el,
        top = _ref.top,
        left = _ref.left;
    el.scrollTop = top;
    el.scrollLeft = left;
  });
}
/**
 * @param {HTMLElement} parent the parent node
 * @param {HTMLElement} child the child node
 * @param {Window} environment The window context where downshift renders.
 * @return {Boolean} whether the parent is the child or the child is in the parent
 */


function isOrContainsNode(parent, child, environment) {
  var result = parent === child || child instanceof environment.Node && parent.contains && parent.contains(child);
  return result;
}
/**
 * Simple debounce implementation. Will call the given
 * function once after the time given has passed since
 * it was last called.
 * @param {Function} fn the function to call after the time
 * @param {Number} time the time to wait
 * @return {Function} the debounced function
 */


function debounce(fn, time) {
  var timeoutId;

  function cancel() {
    if (timeoutId) {
      clearTimeout(timeoutId);
    }
  }

  function wrapper() {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    cancel();
    timeoutId = setTimeout(function () {
      timeoutId = null;
      fn.apply(void 0, args);
    }, time);
  }

  wrapper.cancel = cancel;
  return wrapper;
}
/**
 * This is intended to be used to compose event handlers.
 * They are executed in order until one of them sets
 * `event.preventDownshiftDefault = true`.
 * @param {...Function} fns the event handler functions
 * @return {Function} the event handler to add to an element
 */


function callAllEventHandlers() {
  for (var _len2 = arguments.length, fns = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
    fns[_key2] = arguments[_key2];
  }

  return function (event) {
    for (var _len3 = arguments.length, args = new Array(_len3 > 1 ? _len3 - 1 : 0), _key3 = 1; _key3 < _len3; _key3++) {
      args[_key3 - 1] = arguments[_key3];
    }

    return fns.some(function (fn) {
      if (fn) {
        fn.apply(void 0, [event].concat(args));
      }

      return event.preventDownshiftDefault || event.hasOwnProperty('nativeEvent') && event.nativeEvent.preventDownshiftDefault;
    });
  };
}

function handleRefs() {
  for (var _len4 = arguments.length, refs = new Array(_len4), _key4 = 0; _key4 < _len4; _key4++) {
    refs[_key4] = arguments[_key4];
  }

  return function (node) {
    refs.forEach(function (ref) {
      if (typeof ref === 'function') {
        ref(node);
      } else if (ref) {
        ref.current = node;
      }
    });
  };
}
/**
 * This generates a unique ID for an instance of Downshift
 * @return {String} the unique ID
 */


function generateId() {
  return String(idCounter++);
}
/**
 * Resets idCounter to 0. Used for SSR.
 */


function resetIdCounter() {
  idCounter = 0;
}
/**
 * Default implementation for status message. Only added when menu is open.
 * Will specify if there are results in the list, and if so, how many,
 * and what keys are relevant.
 *
 * @param {Object} param the downshift state and other relevant properties
 * @return {String} the a11y status message
 */


function getA11yStatusMessage$1(_ref2) {
  var isOpen = _ref2.isOpen,
      resultCount = _ref2.resultCount,
      previousResultCount = _ref2.previousResultCount;

  if (!isOpen) {
    return '';
  }

  if (!resultCount) {
    return 'No results are available.';
  }

  if (resultCount !== previousResultCount) {
    return resultCount + " result" + (resultCount === 1 ? ' is' : 's are') + " available, use up and down arrow keys to navigate. Press Enter key to select.";
  }

  return '';
}
/**
 * Takes an argument and if it's an array, returns the first item in the array
 * otherwise returns the argument
 * @param {*} arg the maybe-array
 * @param {*} defaultValue the value if arg is falsey not defined
 * @return {*} the arg or it's first item
 */


function unwrapArray(arg, defaultValue) {
  arg = Array.isArray(arg) ?
  /* istanbul ignore next (preact) */
  arg[0] : arg;

  if (!arg && defaultValue) {
    return defaultValue;
  } else {
    return arg;
  }
}
/**
 * @param {Object} element (P)react element
 * @return {Boolean} whether it's a DOM element
 */


function isDOMElement(element) {


  return typeof element.type === 'string';
}
/**
 * @param {Object} element (P)react element
 * @return {Object} the props
 */


function getElementProps(element) {

  return element.props;
}
/**
 * Throws a helpful error message for required properties. Useful
 * to be used as a default in destructuring or object params.
 * @param {String} fnName the function name
 * @param {String} propName the prop name
 */


function requiredProp(fnName, propName) {
  // eslint-disable-next-line no-console
  console.error("The property \"" + propName + "\" is required in \"" + fnName + "\"");
}

var stateKeys = ['highlightedIndex', 'inputValue', 'isOpen', 'selectedItem', 'type'];
/**
 * @param {Object} state the state object
 * @return {Object} state that is relevant to downshift
 */

function pickState(state) {
  if (state === void 0) {
    state = {};
  }

  var result = {};
  stateKeys.forEach(function (k) {
    if (state.hasOwnProperty(k)) {
      result[k] = state[k];
    }
  });
  return result;
}
/**
 * This will perform a shallow merge of the given state object
 * with the state coming from props
 * (for the controlled component scenario)
 * This is used in state updater functions so they're referencing
 * the right state regardless of where it comes from.
 *
 * @param {Object} state The state of the component/hook.
 * @param {Object} props The props that may contain controlled values.
 * @returns {Object} The merged controlled state.
 */


function getState(state, props) {
  return Object.keys(state).reduce(function (prevState, key) {
    prevState[key] = isControlledProp(props, key) ? props[key] : state[key];
    return prevState;
  }, {});
}
/**
 * This determines whether a prop is a "controlled prop" meaning it is
 * state which is controlled by the outside of this component rather
 * than within this component.
 *
 * @param {Object} props The props that may contain controlled values.
 * @param {String} key the key to check
 * @return {Boolean} whether it is a controlled controlled prop
 */


function isControlledProp(props, key) {
  return props[key] !== undefined;
}
/**
 * Normalizes the 'key' property of a KeyboardEvent in IE/Edge
 * @param {Object} event a keyboardEvent object
 * @return {String} keyboard key
 */


function normalizeArrowKey(event) {
  var key = event.key,
      keyCode = event.keyCode;
  /* istanbul ignore next (ie) */

  if (keyCode >= 37 && keyCode <= 40 && key.indexOf('Arrow') !== 0) {
    return "Arrow" + key;
  }

  return key;
}
/**
 * Simple check if the value passed is object literal
 * @param {*} obj any things
 * @return {Boolean} whether it's object literal
 */


function isPlainObject(obj) {
  return Object.prototype.toString.call(obj) === '[object Object]';
}
/**
 * Returns the new index in the list, in a circular way. If next value is out of bonds from the total,
 * it will wrap to either 0 or itemCount - 1.
 *
 * @param {number} moveAmount Number of positions to move. Negative to move backwards, positive forwards.
 * @param {number} baseIndex The initial position to move from.
 * @param {number} itemCount The total number of items.
 * @param {Function} getItemNodeFromIndex Used to check if item is disabled.
 * @param {boolean} circular Specify if navigation is circular. Default is true.
 * @returns {number} The new index after the move.
 */


function getNextWrappingIndex(moveAmount, baseIndex, itemCount, getItemNodeFromIndex, circular) {
  if (circular === void 0) {
    circular = true;
  }

  if (itemCount === 0) {
    return -1;
  }

  var itemsLastIndex = itemCount - 1;

  if (typeof baseIndex !== 'number' || baseIndex < 0 || baseIndex >= itemCount) {
    baseIndex = moveAmount > 0 ? -1 : itemsLastIndex + 1;
  }

  var newIndex = baseIndex + moveAmount;

  if (newIndex < 0) {
    newIndex = circular ? itemsLastIndex : 0;
  } else if (newIndex > itemsLastIndex) {
    newIndex = circular ? 0 : itemsLastIndex;
  }

  var nonDisabledNewIndex = getNextNonDisabledIndex(moveAmount, newIndex, itemCount, getItemNodeFromIndex, circular);

  if (nonDisabledNewIndex === -1) {
    return baseIndex >= itemCount ? -1 : baseIndex;
  }

  return nonDisabledNewIndex;
}
/**
 * Returns the next index in the list of an item that is not disabled.
 *
 * @param {number} moveAmount Number of positions to move. Negative to move backwards, positive forwards.
 * @param {number} baseIndex The initial position to move from.
 * @param {number} itemCount The total number of items.
 * @param {Function} getItemNodeFromIndex Used to check if item is disabled.
 * @param {boolean} circular Specify if navigation is circular. Default is true.
 * @returns {number} The new index. Returns baseIndex if item is not disabled. Returns next non-disabled item otherwise. If no non-disabled found it will return -1.
 */


function getNextNonDisabledIndex(moveAmount, baseIndex, itemCount, getItemNodeFromIndex, circular) {
  var currentElementNode = getItemNodeFromIndex(baseIndex);

  if (!currentElementNode || !currentElementNode.hasAttribute('disabled')) {
    return baseIndex;
  }

  if (moveAmount > 0) {
    for (var index = baseIndex + 1; index < itemCount; index++) {
      if (!getItemNodeFromIndex(index).hasAttribute('disabled')) {
        return index;
      }
    }
  } else {
    for (var _index = baseIndex - 1; _index >= 0; _index--) {
      if (!getItemNodeFromIndex(_index).hasAttribute('disabled')) {
        return _index;
      }
    }
  }

  if (circular) {
    return moveAmount > 0 ? getNextNonDisabledIndex(1, 0, itemCount, getItemNodeFromIndex, false) : getNextNonDisabledIndex(-1, itemCount - 1, itemCount, getItemNodeFromIndex, false);
  }

  return -1;
}
/**
 * Checks if event target is within the downshift elements.
 *
 * @param {EventTarget} target Target to check.
 * @param {HTMLElement[]} downshiftElements The elements that form downshift (list, toggle button etc).
 * @param {Window} environment The window context where downshift renders.
 * @param {boolean} checkActiveElement Whether to also check activeElement.
 *
 * @returns {boolean} Whether or not the target is within downshift elements.
 */


function targetWithinDownshift(target, downshiftElements, environment, checkActiveElement) {
  if (checkActiveElement === void 0) {
    checkActiveElement = true;
  }

  return downshiftElements.some(function (contextNode) {
    return contextNode && (isOrContainsNode(contextNode, target, environment) || checkActiveElement && isOrContainsNode(contextNode, environment.document.activeElement, environment));
  });
} // eslint-disable-next-line import/no-mutable-exports


var validateControlledUnchanged = noop;
/* istanbul ignore next */

if (true) {
  validateControlledUnchanged = function validateControlledUnchanged(state, prevProps, nextProps) {
    var warningDescription = "This prop should not switch from controlled to uncontrolled (or vice versa). Decide between using a controlled or uncontrolled Downshift element for the lifetime of the component. More info: https://github.com/downshift-js/downshift#control-props";
    Object.keys(state).forEach(function (propKey) {
      if (prevProps[propKey] !== undefined && nextProps[propKey] === undefined) {
        // eslint-disable-next-line no-console
        console.error("downshift: A component has changed the controlled prop \"" + propKey + "\" to be uncontrolled. " + warningDescription);
      } else if (prevProps[propKey] === undefined && nextProps[propKey] !== undefined) {
        // eslint-disable-next-line no-console
        console.error("downshift: A component has changed the uncontrolled prop \"" + propKey + "\" to be controlled. " + warningDescription);
      }
    });
  };
}

var cleanupStatus = debounce(function (documentProp) {
  getStatusDiv(documentProp).textContent = '';
}, 500);
/**
 * @param {String} status the status message
 * @param {Object} documentProp document passed by the user.
 */

function setStatus(status, documentProp) {
  var div = getStatusDiv(documentProp);

  if (!status) {
    return;
  }

  div.textContent = status;
  cleanupStatus(documentProp);
}
/**
 * Get the status node or create it if it does not already exist.
 * @param {Object} documentProp document passed by the user.
 * @return {HTMLElement} the status node.
 */


function getStatusDiv(documentProp) {
  if (documentProp === void 0) {
    documentProp = document;
  }

  var statusDiv = documentProp.getElementById('a11y-status-message');

  if (statusDiv) {
    return statusDiv;
  }

  statusDiv = documentProp.createElement('div');
  statusDiv.setAttribute('id', 'a11y-status-message');
  statusDiv.setAttribute('role', 'status');
  statusDiv.setAttribute('aria-live', 'polite');
  statusDiv.setAttribute('aria-relevant', 'additions text');
  Object.assign(statusDiv.style, {
    border: '0',
    clip: 'rect(0 0 0 0)',
    height: '1px',
    margin: '-1px',
    overflow: 'hidden',
    padding: '0',
    position: 'absolute',
    width: '1px'
  });
  documentProp.body.appendChild(statusDiv);
  return statusDiv;
}

var unknown =  true ? '__autocomplete_unknown__' : 0;
var mouseUp =  true ? '__autocomplete_mouseup__' : 0;
var itemMouseEnter =  true ? '__autocomplete_item_mouseenter__' : 0;
var keyDownArrowUp =  true ? '__autocomplete_keydown_arrow_up__' : 0;
var keyDownArrowDown =  true ? '__autocomplete_keydown_arrow_down__' : 0;
var keyDownEscape =  true ? '__autocomplete_keydown_escape__' : 0;
var keyDownEnter =  true ? '__autocomplete_keydown_enter__' : 0;
var keyDownHome =  true ? '__autocomplete_keydown_home__' : 0;
var keyDownEnd =  true ? '__autocomplete_keydown_end__' : 0;
var clickItem =  true ? '__autocomplete_click_item__' : 0;
var blurInput =  true ? '__autocomplete_blur_input__' : 0;
var changeInput =  true ? '__autocomplete_change_input__' : 0;
var keyDownSpaceButton =  true ? '__autocomplete_keydown_space_button__' : 0;
var clickButton =  true ? '__autocomplete_click_button__' : 0;
var blurButton =  true ? '__autocomplete_blur_button__' : 0;
var controlledPropUpdatedSelectedItem =  true ? '__autocomplete_controlled_prop_updated_selected_item__' : 0;
var touchEnd =  true ? '__autocomplete_touchend__' : 0;

var stateChangeTypes$3 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  unknown: unknown,
  mouseUp: mouseUp,
  itemMouseEnter: itemMouseEnter,
  keyDownArrowUp: keyDownArrowUp,
  keyDownArrowDown: keyDownArrowDown,
  keyDownEscape: keyDownEscape,
  keyDownEnter: keyDownEnter,
  keyDownHome: keyDownHome,
  keyDownEnd: keyDownEnd,
  clickItem: clickItem,
  blurInput: blurInput,
  changeInput: changeInput,
  keyDownSpaceButton: keyDownSpaceButton,
  clickButton: clickButton,
  blurButton: blurButton,
  controlledPropUpdatedSelectedItem: controlledPropUpdatedSelectedItem,
  touchEnd: touchEnd
});

var _excluded$4 = ["refKey", "ref"],
    _excluded2$3 = ["onClick", "onPress", "onKeyDown", "onKeyUp", "onBlur"],
    _excluded3$2 = ["onKeyDown", "onBlur", "onChange", "onInput", "onChangeText"],
    _excluded4$1 = ["refKey", "ref"],
    _excluded5$1 = ["onMouseMove", "onMouseDown", "onClick", "onPress", "index", "item"];

var Downshift = /*#__PURE__*/function () {
  var Downshift = /*#__PURE__*/function (_Component) {
    (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_3__["default"])(Downshift, _Component);

    function Downshift(_props) {
      var _this;

      _this = _Component.call(this, _props) || this; // fancy destructuring + defaults + aliases
      // this basically says each value of state should either be set to
      // the initial value or the default value if the initial value is not provided

      _this.id = _this.props.id || "downshift-" + generateId();
      _this.menuId = _this.props.menuId || _this.id + "-menu";
      _this.labelId = _this.props.labelId || _this.id + "-label";
      _this.inputId = _this.props.inputId || _this.id + "-input";

      _this.getItemId = _this.props.getItemId || function (index) {
        return _this.id + "-item-" + index;
      };

      _this.input = null;
      _this.items = [];
      _this.itemCount = null;
      _this.previousResultCount = 0;
      _this.timeoutIds = [];

      _this.internalSetTimeout = function (fn, time) {
        var id = setTimeout(function () {
          _this.timeoutIds = _this.timeoutIds.filter(function (i) {
            return i !== id;
          });
          fn();
        }, time);

        _this.timeoutIds.push(id);
      };

      _this.setItemCount = function (count) {
        _this.itemCount = count;
      };

      _this.unsetItemCount = function () {
        _this.itemCount = null;
      };

      _this.setHighlightedIndex = function (highlightedIndex, otherStateToSet) {
        if (highlightedIndex === void 0) {
          highlightedIndex = _this.props.defaultHighlightedIndex;
        }

        if (otherStateToSet === void 0) {
          otherStateToSet = {};
        }

        otherStateToSet = pickState(otherStateToSet);

        _this.internalSetState((0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          highlightedIndex: highlightedIndex
        }, otherStateToSet));
      };

      _this.clearSelection = function (cb) {
        _this.internalSetState({
          selectedItem: null,
          inputValue: '',
          highlightedIndex: _this.props.defaultHighlightedIndex,
          isOpen: _this.props.defaultIsOpen
        }, cb);
      };

      _this.selectItem = function (item, otherStateToSet, cb) {
        otherStateToSet = pickState(otherStateToSet);

        _this.internalSetState((0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          isOpen: _this.props.defaultIsOpen,
          highlightedIndex: _this.props.defaultHighlightedIndex,
          selectedItem: item,
          inputValue: _this.props.itemToString(item)
        }, otherStateToSet), cb);
      };

      _this.selectItemAtIndex = function (itemIndex, otherStateToSet, cb) {
        var item = _this.items[itemIndex];

        if (item == null) {
          return;
        }

        _this.selectItem(item, otherStateToSet, cb);
      };

      _this.selectHighlightedItem = function (otherStateToSet, cb) {
        return _this.selectItemAtIndex(_this.getState().highlightedIndex, otherStateToSet, cb);
      };

      _this.internalSetState = function (stateToSet, cb) {
        var isItemSelected, onChangeArg;
        var onStateChangeArg = {};
        var isStateToSetFunction = typeof stateToSet === 'function'; // we want to call `onInputValueChange` before the `setState` call
        // so someone controlling the `inputValue` state gets notified of
        // the input change as soon as possible. This avoids issues with
        // preserving the cursor position.
        // See https://github.com/downshift-js/downshift/issues/217 for more info.

        if (!isStateToSetFunction && stateToSet.hasOwnProperty('inputValue')) {
          _this.props.onInputValueChange(stateToSet.inputValue, (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, _this.getStateAndHelpers(), stateToSet));
        }

        return _this.setState(function (state) {
          state = _this.getState(state);
          var newStateToSet = isStateToSetFunction ? stateToSet(state) : stateToSet; // Your own function that could modify the state that will be set.

          newStateToSet = _this.props.stateReducer(state, newStateToSet); // checks if an item is selected, regardless of if it's different from
          // what was selected before
          // used to determine if onSelect and onChange callbacks should be called

          isItemSelected = newStateToSet.hasOwnProperty('selectedItem'); // this keeps track of the object we want to call with setState

          var nextState = {}; // this is just used to tell whether the state changed

          var nextFullState = {}; // we need to call on change if the outside world is controlling any of our state
          // and we're trying to update that state. OR if the selection has changed and we're
          // trying to update the selection

          if (isItemSelected && newStateToSet.selectedItem !== state.selectedItem) {
            onChangeArg = newStateToSet.selectedItem;
          }

          newStateToSet.type = newStateToSet.type || unknown;
          Object.keys(newStateToSet).forEach(function (key) {
            // onStateChangeArg should only have the state that is
            // actually changing
            if (state[key] !== newStateToSet[key]) {
              onStateChangeArg[key] = newStateToSet[key];
            } // the type is useful for the onStateChangeArg
            // but we don't actually want to set it in internal state.
            // this is an undocumented feature for now... Not all internalSetState
            // calls support it and I'm not certain we want them to yet.
            // But it enables users controlling the isOpen state to know when
            // the isOpen state changes due to mouseup events which is quite handy.


            if (key === 'type') {
              return;
            }

            nextFullState[key] = newStateToSet[key]; // if it's coming from props, then we don't care to set it internally

            if (!isControlledProp(_this.props, key)) {
              nextState[key] = newStateToSet[key];
            }
          }); // if stateToSet is a function, then we weren't able to call onInputValueChange
          // earlier, so we'll call it now that we know what the inputValue state will be.

          if (isStateToSetFunction && newStateToSet.hasOwnProperty('inputValue')) {
            _this.props.onInputValueChange(newStateToSet.inputValue, (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, _this.getStateAndHelpers(), newStateToSet));
          }

          return nextState;
        }, function () {
          // call the provided callback if it's a function
          cbToCb(cb)(); // only call the onStateChange and onChange callbacks if
          // we have relevant information to pass them.

          var hasMoreStateThanType = Object.keys(onStateChangeArg).length > 1;

          if (hasMoreStateThanType) {
            _this.props.onStateChange(onStateChangeArg, _this.getStateAndHelpers());
          }

          if (isItemSelected) {
            _this.props.onSelect(stateToSet.selectedItem, _this.getStateAndHelpers());
          }

          if (onChangeArg !== undefined) {
            _this.props.onChange(onChangeArg, _this.getStateAndHelpers());
          } // this is currently undocumented and therefore subject to change
          // We'll try to not break it, but just be warned.


          _this.props.onUserAction(onStateChangeArg, _this.getStateAndHelpers());
        });
      };

      _this.rootRef = function (node) {
        return _this._rootNode = node;
      };

      _this.getRootProps = function (_temp, _temp2) {
        var _extends2;

        var _ref = _temp === void 0 ? {} : _temp,
            _ref$refKey = _ref.refKey,
            refKey = _ref$refKey === void 0 ? 'ref' : _ref$refKey,
            ref = _ref.ref,
            rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref, _excluded$4);

        var _ref2 = _temp2 === void 0 ? {} : _temp2,
            _ref2$suppressRefErro = _ref2.suppressRefError,
            suppressRefError = _ref2$suppressRefErro === void 0 ? false : _ref2$suppressRefErro;

        // this is used in the render to know whether the user has called getRootProps.
        // It uses that to know whether to apply the props automatically
        _this.getRootProps.called = true;
        _this.getRootProps.refKey = refKey;
        _this.getRootProps.suppressRefError = suppressRefError;

        var _this$getState = _this.getState(),
            isOpen = _this$getState.isOpen;

        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends2 = {}, _extends2[refKey] = handleRefs(ref, _this.rootRef), _extends2.role = 'combobox', _extends2['aria-expanded'] = isOpen, _extends2['aria-haspopup'] = 'listbox', _extends2['aria-owns'] = isOpen ? _this.menuId : null, _extends2['aria-labelledby'] = _this.labelId, _extends2), rest);
      };

      _this.keyDownHandlers = {
        ArrowDown: function ArrowDown(event) {
          var _this2 = this;

          event.preventDefault();

          if (this.getState().isOpen) {
            var amount = event.shiftKey ? 5 : 1;
            this.moveHighlightedIndex(amount, {
              type: keyDownArrowDown
            });
          } else {
            this.internalSetState({
              isOpen: true,
              type: keyDownArrowDown
            }, function () {
              var itemCount = _this2.getItemCount();

              if (itemCount > 0) {
                var _this2$getState = _this2.getState(),
                    highlightedIndex = _this2$getState.highlightedIndex;

                var nextHighlightedIndex = getNextWrappingIndex(1, highlightedIndex, itemCount, function (index) {
                  return _this2.getItemNodeFromIndex(index);
                });

                _this2.setHighlightedIndex(nextHighlightedIndex, {
                  type: keyDownArrowDown
                });
              }
            });
          }
        },
        ArrowUp: function ArrowUp(event) {
          var _this3 = this;

          event.preventDefault();

          if (this.getState().isOpen) {
            var amount = event.shiftKey ? -5 : -1;
            this.moveHighlightedIndex(amount, {
              type: keyDownArrowUp
            });
          } else {
            this.internalSetState({
              isOpen: true,
              type: keyDownArrowUp
            }, function () {
              var itemCount = _this3.getItemCount();

              if (itemCount > 0) {
                var _this3$getState = _this3.getState(),
                    highlightedIndex = _this3$getState.highlightedIndex;

                var nextHighlightedIndex = getNextWrappingIndex(-1, highlightedIndex, itemCount, function (index) {
                  return _this3.getItemNodeFromIndex(index);
                });

                _this3.setHighlightedIndex(nextHighlightedIndex, {
                  type: keyDownArrowUp
                });
              }
            });
          }
        },
        Enter: function Enter(event) {
          if (event.which === 229) {
            return;
          }

          var _this$getState2 = this.getState(),
              isOpen = _this$getState2.isOpen,
              highlightedIndex = _this$getState2.highlightedIndex;

          if (isOpen && highlightedIndex != null) {
            event.preventDefault();
            var item = this.items[highlightedIndex];
            var itemNode = this.getItemNodeFromIndex(highlightedIndex);

            if (item == null || itemNode && itemNode.hasAttribute('disabled')) {
              return;
            }

            this.selectHighlightedItem({
              type: keyDownEnter
            });
          }
        },
        Escape: function Escape(event) {
          event.preventDefault();
          this.reset((0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
            type: keyDownEscape
          }, !this.state.isOpen && {
            selectedItem: null,
            inputValue: ''
          }));
        }
      };
      _this.buttonKeyDownHandlers = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, _this.keyDownHandlers, {
        ' ': function _(event) {
          event.preventDefault();
          this.toggleMenu({
            type: keyDownSpaceButton
          });
        }
      });
      _this.inputKeyDownHandlers = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, _this.keyDownHandlers, {
        Home: function Home(event) {
          var _this4 = this;

          var _this$getState3 = this.getState(),
              isOpen = _this$getState3.isOpen;

          if (!isOpen) {
            return;
          }

          event.preventDefault();
          var itemCount = this.getItemCount();

          if (itemCount <= 0 || !isOpen) {
            return;
          } // get next non-disabled starting downwards from 0 if that's disabled.


          var newHighlightedIndex = getNextNonDisabledIndex(1, 0, itemCount, function (index) {
            return _this4.getItemNodeFromIndex(index);
          }, false);
          this.setHighlightedIndex(newHighlightedIndex, {
            type: keyDownHome
          });
        },
        End: function End(event) {
          var _this5 = this;

          var _this$getState4 = this.getState(),
              isOpen = _this$getState4.isOpen;

          if (!isOpen) {
            return;
          }

          event.preventDefault();
          var itemCount = this.getItemCount();

          if (itemCount <= 0 || !isOpen) {
            return;
          } // get next non-disabled starting upwards from last index if that's disabled.


          var newHighlightedIndex = getNextNonDisabledIndex(-1, itemCount - 1, itemCount, function (index) {
            return _this5.getItemNodeFromIndex(index);
          }, false);
          this.setHighlightedIndex(newHighlightedIndex, {
            type: keyDownEnd
          });
        }
      });

      _this.getToggleButtonProps = function (_temp3) {
        var _ref3 = _temp3 === void 0 ? {} : _temp3,
            onClick = _ref3.onClick;
            _ref3.onPress;
            var onKeyDown = _ref3.onKeyDown,
            onKeyUp = _ref3.onKeyUp,
            onBlur = _ref3.onBlur,
            rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref3, _excluded2$3);

        var _this$getState5 = _this.getState(),
            isOpen = _this$getState5.isOpen;

        var enabledEventHandlers = {
          onClick: callAllEventHandlers(onClick, _this.buttonHandleClick),
          onKeyDown: callAllEventHandlers(onKeyDown, _this.buttonHandleKeyDown),
          onKeyUp: callAllEventHandlers(onKeyUp, _this.buttonHandleKeyUp),
          onBlur: callAllEventHandlers(onBlur, _this.buttonHandleBlur)
        };
        var eventHandlers = rest.disabled ? {} : enabledEventHandlers;
        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          type: 'button',
          role: 'button',
          'aria-label': isOpen ? 'close menu' : 'open menu',
          'aria-haspopup': true,
          'data-toggle': true
        }, eventHandlers, rest);
      };

      _this.buttonHandleKeyUp = function (event) {
        // Prevent click event from emitting in Firefox
        event.preventDefault();
      };

      _this.buttonHandleKeyDown = function (event) {
        var key = normalizeArrowKey(event);

        if (_this.buttonKeyDownHandlers[key]) {
          _this.buttonKeyDownHandlers[key].call((0,_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this), event);
        }
      };

      _this.buttonHandleClick = function (event) {
        event.preventDefault(); // handle odd case for Safari and Firefox which
        // don't give the button the focus properly.

        /* istanbul ignore if (can't reasonably test this) */

        if (_this.props.environment.document.activeElement === _this.props.environment.document.body) {
          event.target.focus();
        } // to simplify testing components that use downshift, we'll not wrap this in a setTimeout
        // if the NODE_ENV is test. With the proper build system, this should be dead code eliminated
        // when building for production and should therefore have no impact on production code.


        if (false) {} else {
          // Ensure that toggle of menu occurs after the potential blur event in iOS
          _this.internalSetTimeout(function () {
            return _this.toggleMenu({
              type: clickButton
            });
          });
        }
      };

      _this.buttonHandleBlur = function (event) {
        var blurTarget = event.target; // Save blur target for comparison with activeElement later
        // Need setTimeout, so that when the user presses Tab, the activeElement is the next focused element, not body element

        _this.internalSetTimeout(function () {
          if (!_this.isMouseDown && (_this.props.environment.document.activeElement == null || _this.props.environment.document.activeElement.id !== _this.inputId) && _this.props.environment.document.activeElement !== blurTarget // Do nothing if we refocus the same element again (to solve issue in Safari on iOS)
          ) {
            _this.reset({
              type: blurButton
            });
          }
        });
      };

      _this.getLabelProps = function (props) {
        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          htmlFor: _this.inputId,
          id: _this.labelId
        }, props);
      };

      _this.getInputProps = function (_temp4) {
        var _ref4 = _temp4 === void 0 ? {} : _temp4,
            onKeyDown = _ref4.onKeyDown,
            onBlur = _ref4.onBlur,
            onChange = _ref4.onChange,
            onInput = _ref4.onInput;
            _ref4.onChangeText;
            var rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref4, _excluded3$2);

        var onChangeKey;
        var eventHandlers = {};
        /* istanbul ignore next (preact) */

        {
          onChangeKey = 'onChange';
        }

        var _this$getState6 = _this.getState(),
            inputValue = _this$getState6.inputValue,
            isOpen = _this$getState6.isOpen,
            highlightedIndex = _this$getState6.highlightedIndex;

        if (!rest.disabled) {
          var _eventHandlers;

          eventHandlers = (_eventHandlers = {}, _eventHandlers[onChangeKey] = callAllEventHandlers(onChange, onInput, _this.inputHandleChange), _eventHandlers.onKeyDown = callAllEventHandlers(onKeyDown, _this.inputHandleKeyDown), _eventHandlers.onBlur = callAllEventHandlers(onBlur, _this.inputHandleBlur), _eventHandlers);
        }

        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          'aria-autocomplete': 'list',
          'aria-activedescendant': isOpen && typeof highlightedIndex === 'number' && highlightedIndex >= 0 ? _this.getItemId(highlightedIndex) : null,
          'aria-controls': isOpen ? _this.menuId : null,
          'aria-labelledby': _this.labelId,
          // https://developer.mozilla.org/en-US/docs/Web/Security/Securing_your_site/Turning_off_form_autocompletion
          // revert back since autocomplete="nope" is ignored on latest Chrome and Opera
          autoComplete: 'off',
          value: inputValue,
          id: _this.inputId
        }, eventHandlers, rest);
      };

      _this.inputHandleKeyDown = function (event) {
        var key = normalizeArrowKey(event);

        if (key && _this.inputKeyDownHandlers[key]) {
          _this.inputKeyDownHandlers[key].call((0,_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this), event);
        }
      };

      _this.inputHandleChange = function (event) {
        _this.internalSetState({
          type: changeInput,
          isOpen: true,
          inputValue: event.target.value,
          highlightedIndex: _this.props.defaultHighlightedIndex
        });
      };

      _this.inputHandleBlur = function () {
        // Need setTimeout, so that when the user presses Tab, the activeElement is the next focused element, not the body element
        _this.internalSetTimeout(function () {
          var downshiftButtonIsActive = _this.props.environment.document && !!_this.props.environment.document.activeElement && !!_this.props.environment.document.activeElement.dataset && _this.props.environment.document.activeElement.dataset.toggle && _this._rootNode && _this._rootNode.contains(_this.props.environment.document.activeElement);

          if (!_this.isMouseDown && !downshiftButtonIsActive) {
            _this.reset({
              type: blurInput
            });
          }
        });
      };

      _this.menuRef = function (node) {
        _this._menuNode = node;
      };

      _this.getMenuProps = function (_temp5, _temp6) {
        var _extends3;

        var _ref5 = _temp5 === void 0 ? {} : _temp5,
            _ref5$refKey = _ref5.refKey,
            refKey = _ref5$refKey === void 0 ? 'ref' : _ref5$refKey,
            ref = _ref5.ref,
            props = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref5, _excluded4$1);

        var _ref6 = _temp6 === void 0 ? {} : _temp6,
            _ref6$suppressRefErro = _ref6.suppressRefError,
            suppressRefError = _ref6$suppressRefErro === void 0 ? false : _ref6$suppressRefErro;

        _this.getMenuProps.called = true;
        _this.getMenuProps.refKey = refKey;
        _this.getMenuProps.suppressRefError = suppressRefError;
        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends3 = {}, _extends3[refKey] = handleRefs(ref, _this.menuRef), _extends3.role = 'listbox', _extends3['aria-labelledby'] = props && props['aria-label'] ? null : _this.labelId, _extends3.id = _this.menuId, _extends3), props);
      };

      _this.getItemProps = function (_temp7) {
        var _enabledEventHandlers;

        var _ref7 = _temp7 === void 0 ? {} : _temp7,
            onMouseMove = _ref7.onMouseMove,
            onMouseDown = _ref7.onMouseDown,
            onClick = _ref7.onClick;
            _ref7.onPress;
            var index = _ref7.index,
            _ref7$item = _ref7.item,
            item = _ref7$item === void 0 ?  false ?
        /* istanbul ignore next */
        0 : requiredProp('getItemProps', 'item') : _ref7$item,
            rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref7, _excluded5$1);

        if (index === undefined) {
          _this.items.push(item);

          index = _this.items.indexOf(item);
        } else {
          _this.items[index] = item;
        }

        var onSelectKey = 'onClick';
        var customClickHandler = onClick;
        var enabledEventHandlers = (_enabledEventHandlers = {
          // onMouseMove is used over onMouseEnter here. onMouseMove
          // is only triggered on actual mouse movement while onMouseEnter
          // can fire on DOM changes, interrupting keyboard navigation
          onMouseMove: callAllEventHandlers(onMouseMove, function () {
            if (index === _this.getState().highlightedIndex) {
              return;
            }

            _this.setHighlightedIndex(index, {
              type: itemMouseEnter
            }); // We never want to manually scroll when changing state based
            // on `onMouseMove` because we will be moving the element out
            // from under the user which is currently scrolling/moving the
            // cursor


            _this.avoidScrolling = true;

            _this.internalSetTimeout(function () {
              return _this.avoidScrolling = false;
            }, 250);
          }),
          onMouseDown: callAllEventHandlers(onMouseDown, function (event) {
            // This prevents the activeElement from being changed
            // to the item so it can remain with the current activeElement
            // which is a more common use case.
            event.preventDefault();
          })
        }, _enabledEventHandlers[onSelectKey] = callAllEventHandlers(customClickHandler, function () {
          _this.selectItemAtIndex(index, {
            type: clickItem
          });
        }), _enabledEventHandlers); // Passing down the onMouseDown handler to prevent redirect
        // of the activeElement if clicking on disabled items

        var eventHandlers = rest.disabled ? {
          onMouseDown: enabledEventHandlers.onMouseDown
        } : enabledEventHandlers;
        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          id: _this.getItemId(index),
          role: 'option',
          'aria-selected': _this.getState().highlightedIndex === index
        }, eventHandlers, rest);
      };

      _this.clearItems = function () {
        _this.items = [];
      };

      _this.reset = function (otherStateToSet, cb) {
        if (otherStateToSet === void 0) {
          otherStateToSet = {};
        }

        otherStateToSet = pickState(otherStateToSet);

        _this.internalSetState(function (_ref8) {
          var selectedItem = _ref8.selectedItem;
          return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
            isOpen: _this.props.defaultIsOpen,
            highlightedIndex: _this.props.defaultHighlightedIndex,
            inputValue: _this.props.itemToString(selectedItem)
          }, otherStateToSet);
        }, cb);
      };

      _this.toggleMenu = function (otherStateToSet, cb) {
        if (otherStateToSet === void 0) {
          otherStateToSet = {};
        }

        otherStateToSet = pickState(otherStateToSet);

        _this.internalSetState(function (_ref9) {
          var isOpen = _ref9.isOpen;
          return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
            isOpen: !isOpen
          }, isOpen && {
            highlightedIndex: _this.props.defaultHighlightedIndex
          }, otherStateToSet);
        }, function () {
          var _this$getState7 = _this.getState(),
              isOpen = _this$getState7.isOpen,
              highlightedIndex = _this$getState7.highlightedIndex;

          if (isOpen) {
            if (_this.getItemCount() > 0 && typeof highlightedIndex === 'number') {
              _this.setHighlightedIndex(highlightedIndex, otherStateToSet);
            }
          }

          cbToCb(cb)();
        });
      };

      _this.openMenu = function (cb) {
        _this.internalSetState({
          isOpen: true
        }, cb);
      };

      _this.closeMenu = function (cb) {
        _this.internalSetState({
          isOpen: false
        }, cb);
      };

      _this.updateStatus = debounce(function () {
        var state = _this.getState();

        var item = _this.items[state.highlightedIndex];

        var resultCount = _this.getItemCount();

        var status = _this.props.getA11yStatusMessage((0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          itemToString: _this.props.itemToString,
          previousResultCount: _this.previousResultCount,
          resultCount: resultCount,
          highlightedItem: item
        }, state));

        _this.previousResultCount = resultCount;
        setStatus(status, _this.props.environment.document);
      }, 200);

      var _this$props = _this.props,
          defaultHighlightedIndex = _this$props.defaultHighlightedIndex,
          _this$props$initialHi = _this$props.initialHighlightedIndex,
          _highlightedIndex = _this$props$initialHi === void 0 ? defaultHighlightedIndex : _this$props$initialHi,
          defaultIsOpen = _this$props.defaultIsOpen,
          _this$props$initialIs = _this$props.initialIsOpen,
          _isOpen = _this$props$initialIs === void 0 ? defaultIsOpen : _this$props$initialIs,
          _this$props$initialIn = _this$props.initialInputValue,
          _inputValue = _this$props$initialIn === void 0 ? '' : _this$props$initialIn,
          _this$props$initialSe = _this$props.initialSelectedItem,
          _selectedItem = _this$props$initialSe === void 0 ? null : _this$props$initialSe;

      var _state = _this.getState({
        highlightedIndex: _highlightedIndex,
        isOpen: _isOpen,
        inputValue: _inputValue,
        selectedItem: _selectedItem
      });

      if (_state.selectedItem != null && _this.props.initialInputValue === undefined) {
        _state.inputValue = _this.props.itemToString(_state.selectedItem);
      }

      _this.state = _state;
      return _this;
    }

    var _proto = Downshift.prototype;

    /**
     * Clear all running timeouts
     */
    _proto.internalClearTimeouts = function internalClearTimeouts() {
      this.timeoutIds.forEach(function (id) {
        clearTimeout(id);
      });
      this.timeoutIds = [];
    }
    /**
     * Gets the state based on internal state or props
     * If a state value is passed via props, then that
     * is the value given, otherwise it's retrieved from
     * stateToMerge
     *
     * @param {Object} stateToMerge defaults to this.state
     * @return {Object} the state
     */
    ;

    _proto.getState = function getState$1(stateToMerge) {
      if (stateToMerge === void 0) {
        stateToMerge = this.state;
      }

      return getState(stateToMerge, this.props);
    };

    _proto.getItemCount = function getItemCount() {
      // things read better this way. They're in priority order:
      // 1. `this.itemCount`
      // 2. `this.props.itemCount`
      // 3. `this.items.length`
      var itemCount = this.items.length;

      if (this.itemCount != null) {
        itemCount = this.itemCount;
      } else if (this.props.itemCount !== undefined) {
        itemCount = this.props.itemCount;
      }

      return itemCount;
    };

    _proto.getItemNodeFromIndex = function getItemNodeFromIndex(index) {
      return this.props.environment.document.getElementById(this.getItemId(index));
    };

    _proto.scrollHighlightedItemIntoView = function scrollHighlightedItemIntoView() {
      /* istanbul ignore else (react-native) */
      {
        var node = this.getItemNodeFromIndex(this.getState().highlightedIndex);
        this.props.scrollIntoView(node, this._menuNode);
      }
    };

    _proto.moveHighlightedIndex = function moveHighlightedIndex(amount, otherStateToSet) {
      var _this6 = this;

      var itemCount = this.getItemCount();

      var _this$getState8 = this.getState(),
          highlightedIndex = _this$getState8.highlightedIndex;

      if (itemCount > 0) {
        var nextHighlightedIndex = getNextWrappingIndex(amount, highlightedIndex, itemCount, function (index) {
          return _this6.getItemNodeFromIndex(index);
        });
        this.setHighlightedIndex(nextHighlightedIndex, otherStateToSet);
      }
    };

    _proto.getStateAndHelpers = function getStateAndHelpers() {
      var _this$getState9 = this.getState(),
          highlightedIndex = _this$getState9.highlightedIndex,
          inputValue = _this$getState9.inputValue,
          selectedItem = _this$getState9.selectedItem,
          isOpen = _this$getState9.isOpen;

      var itemToString = this.props.itemToString;
      var id = this.id;
      var getRootProps = this.getRootProps,
          getToggleButtonProps = this.getToggleButtonProps,
          getLabelProps = this.getLabelProps,
          getMenuProps = this.getMenuProps,
          getInputProps = this.getInputProps,
          getItemProps = this.getItemProps,
          openMenu = this.openMenu,
          closeMenu = this.closeMenu,
          toggleMenu = this.toggleMenu,
          selectItem = this.selectItem,
          selectItemAtIndex = this.selectItemAtIndex,
          selectHighlightedItem = this.selectHighlightedItem,
          setHighlightedIndex = this.setHighlightedIndex,
          clearSelection = this.clearSelection,
          clearItems = this.clearItems,
          reset = this.reset,
          setItemCount = this.setItemCount,
          unsetItemCount = this.unsetItemCount,
          setState = this.internalSetState;
      return {
        // prop getters
        getRootProps: getRootProps,
        getToggleButtonProps: getToggleButtonProps,
        getLabelProps: getLabelProps,
        getMenuProps: getMenuProps,
        getInputProps: getInputProps,
        getItemProps: getItemProps,
        // actions
        reset: reset,
        openMenu: openMenu,
        closeMenu: closeMenu,
        toggleMenu: toggleMenu,
        selectItem: selectItem,
        selectItemAtIndex: selectItemAtIndex,
        selectHighlightedItem: selectHighlightedItem,
        setHighlightedIndex: setHighlightedIndex,
        clearSelection: clearSelection,
        clearItems: clearItems,
        setItemCount: setItemCount,
        unsetItemCount: unsetItemCount,
        setState: setState,
        // props
        itemToString: itemToString,
        // derived
        id: id,
        // state
        highlightedIndex: highlightedIndex,
        inputValue: inputValue,
        isOpen: isOpen,
        selectedItem: selectedItem
      };
    } //////////////////////////// ROOT
    ;

    _proto.componentDidMount = function componentDidMount() {
      var _this7 = this;

      /* istanbul ignore if (react-native) */
      if ( true && this.getMenuProps.called && !this.getMenuProps.suppressRefError) {
        validateGetMenuPropsCalledCorrectly(this._menuNode, this.getMenuProps);
      }
      /* istanbul ignore if (react-native) */


      {
        // this.isMouseDown helps us track whether the mouse is currently held down.
        // This is useful when the user clicks on an item in the list, but holds the mouse
        // down long enough for the list to disappear (because the blur event fires on the input)
        // this.isMouseDown is used in the blur handler on the input to determine whether the blur event should
        // trigger hiding the menu.
        var onMouseDown = function onMouseDown() {
          _this7.isMouseDown = true;
        };

        var onMouseUp = function onMouseUp(event) {
          _this7.isMouseDown = false; // if the target element or the activeElement is within a downshift node
          // then we don't want to reset downshift

          var contextWithinDownshift = targetWithinDownshift(event.target, [_this7._rootNode, _this7._menuNode], _this7.props.environment);

          if (!contextWithinDownshift && _this7.getState().isOpen) {
            _this7.reset({
              type: mouseUp
            }, function () {
              return _this7.props.onOuterClick(_this7.getStateAndHelpers());
            });
          }
        }; // Touching an element in iOS gives focus and hover states, but touching out of
        // the element will remove hover, and persist the focus state, resulting in the
        // blur event not being triggered.
        // this.isTouchMove helps us track whether the user is tapping or swiping on a touch screen.
        // If the user taps outside of Downshift, the component should be reset,
        // but not if the user is swiping


        var onTouchStart = function onTouchStart() {
          _this7.isTouchMove = false;
        };

        var onTouchMove = function onTouchMove() {
          _this7.isTouchMove = true;
        };

        var onTouchEnd = function onTouchEnd(event) {
          var contextWithinDownshift = targetWithinDownshift(event.target, [_this7._rootNode, _this7._menuNode], _this7.props.environment, false);

          if (!_this7.isTouchMove && !contextWithinDownshift && _this7.getState().isOpen) {
            _this7.reset({
              type: touchEnd
            }, function () {
              return _this7.props.onOuterClick(_this7.getStateAndHelpers());
            });
          }
        };

        var environment = this.props.environment;
        environment.addEventListener('mousedown', onMouseDown);
        environment.addEventListener('mouseup', onMouseUp);
        environment.addEventListener('touchstart', onTouchStart);
        environment.addEventListener('touchmove', onTouchMove);
        environment.addEventListener('touchend', onTouchEnd);

        this.cleanup = function () {
          _this7.internalClearTimeouts();

          _this7.updateStatus.cancel();

          environment.removeEventListener('mousedown', onMouseDown);
          environment.removeEventListener('mouseup', onMouseUp);
          environment.removeEventListener('touchstart', onTouchStart);
          environment.removeEventListener('touchmove', onTouchMove);
          environment.removeEventListener('touchend', onTouchEnd);
        };
      }
    };

    _proto.shouldScroll = function shouldScroll(prevState, prevProps) {
      var _ref10 = this.props.highlightedIndex === undefined ? this.getState() : this.props,
          currentHighlightedIndex = _ref10.highlightedIndex;

      var _ref11 = prevProps.highlightedIndex === undefined ? prevState : prevProps,
          prevHighlightedIndex = _ref11.highlightedIndex;

      var scrollWhenOpen = currentHighlightedIndex && this.getState().isOpen && !prevState.isOpen;
      var scrollWhenNavigating = currentHighlightedIndex !== prevHighlightedIndex;
      return scrollWhenOpen || scrollWhenNavigating;
    };

    _proto.componentDidUpdate = function componentDidUpdate(prevProps, prevState) {
      if (true) {
        validateControlledUnchanged(this.state, prevProps, this.props);
        /* istanbul ignore if (react-native) */

        if (this.getMenuProps.called && !this.getMenuProps.suppressRefError) {
          validateGetMenuPropsCalledCorrectly(this._menuNode, this.getMenuProps);
        }
      }

      if (isControlledProp(this.props, 'selectedItem') && this.props.selectedItemChanged(prevProps.selectedItem, this.props.selectedItem)) {
        this.internalSetState({
          type: controlledPropUpdatedSelectedItem,
          inputValue: this.props.itemToString(this.props.selectedItem)
        });
      }

      if (!this.avoidScrolling && this.shouldScroll(prevState, prevProps)) {
        this.scrollHighlightedItemIntoView();
      }
      /* istanbul ignore else (react-native) */


      {
        this.updateStatus();
      }
    };

    _proto.componentWillUnmount = function componentWillUnmount() {
      this.cleanup(); // avoids memory leak
    };

    _proto.render = function render() {
      var children = unwrapArray(this.props.children, noop); // because the items are rerendered every time we call the children
      // we clear this out each render and it will be populated again as
      // getItemProps is called.

      this.clearItems(); // we reset this so we know whether the user calls getRootProps during
      // this render. If they do then we don't need to do anything,
      // if they don't then we need to clone the element they return and
      // apply the props for them.

      this.getRootProps.called = false;
      this.getRootProps.refKey = undefined;
      this.getRootProps.suppressRefError = undefined; // we do something similar for getMenuProps

      this.getMenuProps.called = false;
      this.getMenuProps.refKey = undefined;
      this.getMenuProps.suppressRefError = undefined; // we do something similar for getLabelProps

      this.getLabelProps.called = false; // and something similar for getInputProps

      this.getInputProps.called = false;
      var element = unwrapArray(children(this.getStateAndHelpers()));

      if (!element) {
        return null;
      }

      if (this.getRootProps.called || this.props.suppressRefError) {
        if ( true && !this.getRootProps.suppressRefError && !this.props.suppressRefError) {
          validateGetRootPropsCalledCorrectly(element, this.getRootProps);
        }

        return element;
      } else if (isDOMElement(element)) {
        // they didn't apply the root props, but we can clone
        // this and apply the props ourselves
        return /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_4__.cloneElement)(element, this.getRootProps(getElementProps(element)));
      }
      /* istanbul ignore else */


      if (true) {
        // they didn't apply the root props, but they need to
        // otherwise we can't query around the autocomplete
        throw new Error('downshift: If you return a non-DOM element, you must apply the getRootProps function');
      }
      /* istanbul ignore next */


      return undefined;
    };

    return Downshift;
  }(react__WEBPACK_IMPORTED_MODULE_4__.Component);

  Downshift.defaultProps = {
    defaultHighlightedIndex: null,
    defaultIsOpen: false,
    getA11yStatusMessage: getA11yStatusMessage$1,
    itemToString: function itemToString(i) {
      if (i == null) {
        return '';
      }

      if ( true && isPlainObject(i) && !i.hasOwnProperty('toString')) {
        // eslint-disable-next-line no-console
        console.warn('downshift: An object was passed to the default implementation of `itemToString`. You should probably provide your own `itemToString` implementation. Please refer to the `itemToString` API documentation.', 'The object that was passed:', i);
      }

      return String(i);
    },
    onStateChange: noop,
    onInputValueChange: noop,
    onUserAction: noop,
    onChange: noop,
    onSelect: noop,
    onOuterClick: noop,
    selectedItemChanged: function selectedItemChanged(prevItem, item) {
      return prevItem !== item;
    },
    environment:
    /* istanbul ignore next (ssr) */
    typeof window === 'undefined' ? {} : window,
    stateReducer: function stateReducer(state, stateToSet) {
      return stateToSet;
    },
    suppressRefError: false,
    scrollIntoView: scrollIntoView
  };
  Downshift.stateChangeTypes = stateChangeTypes$3;
  return Downshift;
}();

 true ? Downshift.propTypes = {
  children: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  defaultHighlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  defaultIsOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  initialHighlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  initialSelectedItem: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
  initialInputValue: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  initialIsOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  getA11yStatusMessage: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  itemToString: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onSelect: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onStateChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onInputValueChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onUserAction: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onOuterClick: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  selectedItemChanged: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  stateReducer: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  itemCount: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  id: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  environment: prop_types__WEBPACK_IMPORTED_MODULE_7___default().shape({
    addEventListener: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    removeEventListener: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    document: prop_types__WEBPACK_IMPORTED_MODULE_7___default().shape({
      getElementById: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
      activeElement: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
      body: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any)
    })
  }),
  suppressRefError: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  scrollIntoView: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  // things we keep in state for uncontrolled components
  // but can accept as props for controlled components

  /* eslint-disable react/no-unused-prop-types */
  selectedItem: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
  isOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  inputValue: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  highlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  labelId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  inputId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  menuId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  getItemId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func)
  /* eslint-enable react/no-unused-prop-types */

} : 0;
var Downshift$1 = Downshift;

function validateGetMenuPropsCalledCorrectly(node, _ref12) {
  var refKey = _ref12.refKey;

  if (!node) {
    // eslint-disable-next-line no-console
    console.error("downshift: The ref prop \"" + refKey + "\" from getMenuProps was not applied correctly on your menu element.");
  }
}

function validateGetRootPropsCalledCorrectly(element, _ref13) {
  var refKey = _ref13.refKey;
  var refKeySpecified = refKey !== 'ref';
  var isComposite = !isDOMElement(element);

  if (isComposite && !refKeySpecified && !(0,react_is__WEBPACK_IMPORTED_MODULE_5__.isForwardRef)(element)) {
    // eslint-disable-next-line no-console
    console.error('downshift: You returned a non-DOM element. You must specify a refKey in getRootProps');
  } else if (!isComposite && refKeySpecified) {
    // eslint-disable-next-line no-console
    console.error("downshift: You returned a DOM element. You should not specify a refKey in getRootProps. You specified \"" + refKey + "\"");
  }

  if (!(0,react_is__WEBPACK_IMPORTED_MODULE_5__.isForwardRef)(element) && !getElementProps(element)[refKey]) {
    // eslint-disable-next-line no-console
    console.error("downshift: You must apply the ref prop \"" + refKey + "\" from getRootProps onto your root element.");
  }
}

var _excluded$3 = ["isInitialMount", "highlightedIndex", "items", "environment"];
var dropdownDefaultStateValues = {
  highlightedIndex: -1,
  isOpen: false,
  selectedItem: null,
  inputValue: ''
};

function callOnChangeProps(action, state, newState) {
  var props = action.props,
      type = action.type;
  var changes = {};
  Object.keys(state).forEach(function (key) {
    invokeOnChangeHandler(key, action, state, newState);

    if (newState[key] !== state[key]) {
      changes[key] = newState[key];
    }
  });

  if (props.onStateChange && Object.keys(changes).length) {
    props.onStateChange((0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
      type: type
    }, changes));
  }
}

function invokeOnChangeHandler(key, action, state, newState) {
  var props = action.props,
      type = action.type;
  var handler = "on" + capitalizeString(key) + "Change";

  if (props[handler] && newState[key] !== undefined && newState[key] !== state[key]) {
    props[handler]((0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
      type: type
    }, newState));
  }
}
/**
 * Default state reducer that returns the changes.
 *
 * @param {Object} s state.
 * @param {Object} a action with changes.
 * @returns {Object} changes.
 */


function stateReducer(s, a) {
  return a.changes;
}
/**
 * Returns a message to be added to aria-live region when item is selected.
 *
 * @param {Object} selectionParameters Parameters required to build the message.
 * @returns {string} The a11y message.
 */


function getA11ySelectionMessage(selectionParameters) {
  var selectedItem = selectionParameters.selectedItem,
      itemToStringLocal = selectionParameters.itemToString;
  return selectedItem ? itemToStringLocal(selectedItem) + " has been selected." : '';
}
/**
 * Debounced call for updating the a11y message.
 */


var updateA11yStatus = debounce(function (getA11yMessage, document) {
  setStatus(getA11yMessage(), document);
}, 200); // istanbul ignore next

var useIsomorphicLayoutEffect = typeof window !== 'undefined' && typeof window.document !== 'undefined' && typeof window.document.createElement !== 'undefined' ? react__WEBPACK_IMPORTED_MODULE_4__.useLayoutEffect : react__WEBPACK_IMPORTED_MODULE_4__.useEffect;

function useElementIds(_ref) {
  var _ref$id = _ref.id,
      id = _ref$id === void 0 ? "downshift-" + generateId() : _ref$id,
      labelId = _ref.labelId,
      menuId = _ref.menuId,
      getItemId = _ref.getItemId,
      toggleButtonId = _ref.toggleButtonId,
      inputId = _ref.inputId;
  var elementIdsRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)({
    labelId: labelId || id + "-label",
    menuId: menuId || id + "-menu",
    getItemId: getItemId || function (index) {
      return id + "-item-" + index;
    },
    toggleButtonId: toggleButtonId || id + "-toggle-button",
    inputId: inputId || id + "-input"
  });
  return elementIdsRef.current;
}

function getItemIndex(index, item, items) {
  if (index !== undefined) {
    return index;
  }

  if (items.length === 0) {
    return -1;
  }

  return items.indexOf(item);
}

function itemToString(item) {
  return item ? String(item) : '';
}

function isAcceptedCharacterKey(key) {
  return /^\S{1}$/.test(key);
}

function capitalizeString(string) {
  return "" + string.slice(0, 1).toUpperCase() + string.slice(1);
}

function useLatestRef(val) {
  var ref = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(val); // technically this is not "concurrent mode safe" because we're manipulating
  // the value during render (so it's not idempotent). However, the places this
  // hook is used is to support memoizing callbacks which will be called
  // *during* render, so we need the latest values *during* render.
  // If not for this, then we'd probably want to use useLayoutEffect instead.

  ref.current = val;
  return ref;
}
/**
 * Computes the controlled state using a the previous state, props,
 * two reducers, one from downshift and an optional one from the user.
 * Also calls the onChange handlers for state values that have changed.
 *
 * @param {Function} reducer Reducer function from downshift.
 * @param {Object} initialState Initial state of the hook.
 * @param {Object} props The hook props.
 * @returns {Array} An array with the state and an action dispatcher.
 */


function useEnhancedReducer(reducer, initialState, props) {
  var prevStateRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)();
  var actionRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)();
  var enhancedReducer = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (state, action) {
    actionRef.current = action;
    state = getState(state, action.props);
    var changes = reducer(state, action);
    var newState = action.props.stateReducer(state, (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, action, {
      changes: changes
    }));
    return newState;
  }, [reducer]);

  var _useReducer = (0,react__WEBPACK_IMPORTED_MODULE_4__.useReducer)(enhancedReducer, initialState),
      state = _useReducer[0],
      dispatch = _useReducer[1];

  var propsRef = useLatestRef(props);
  var dispatchWithProps = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (action) {
    return dispatch((0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
      props: propsRef.current
    }, action));
  }, [propsRef]);
  var action = actionRef.current;
  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (action && prevStateRef.current && prevStateRef.current !== state) {
      callOnChangeProps(action, getState(prevStateRef.current, action.props), state);
    }

    prevStateRef.current = state;
  }, [state, props, action]);
  return [state, dispatchWithProps];
}
/**
 * Wraps the useEnhancedReducer and applies the controlled prop values before
 * returning the new state.
 *
 * @param {Function} reducer Reducer function from downshift.
 * @param {Object} initialState Initial state of the hook.
 * @param {Object} props The hook props.
 * @returns {Array} An array with the state and an action dispatcher.
 */


function useControlledReducer$1(reducer, initialState, props) {
  var _useEnhancedReducer = useEnhancedReducer(reducer, initialState, props),
      state = _useEnhancedReducer[0],
      dispatch = _useEnhancedReducer[1];

  return [getState(state, props), dispatch];
}

var defaultProps$3 = {
  itemToString: itemToString,
  stateReducer: stateReducer,
  getA11ySelectionMessage: getA11ySelectionMessage,
  scrollIntoView: scrollIntoView,
  circularNavigation: false,
  environment:
  /* istanbul ignore next (ssr) */
  typeof window === 'undefined' ? {} : window
};

function getDefaultValue$1(props, propKey, defaultStateValues) {
  if (defaultStateValues === void 0) {
    defaultStateValues = dropdownDefaultStateValues;
  }

  var defaultPropKey = "default" + capitalizeString(propKey);

  if (defaultPropKey in props) {
    return props[defaultPropKey];
  }

  return defaultStateValues[propKey];
}

function getInitialValue$1(props, propKey, defaultStateValues) {
  if (defaultStateValues === void 0) {
    defaultStateValues = dropdownDefaultStateValues;
  }

  if (propKey in props) {
    return props[propKey];
  }

  var initialPropKey = "initial" + capitalizeString(propKey);

  if (initialPropKey in props) {
    return props[initialPropKey];
  }

  return getDefaultValue$1(props, propKey, defaultStateValues);
}

function getInitialState$2(props) {
  var selectedItem = getInitialValue$1(props, 'selectedItem');
  var isOpen = getInitialValue$1(props, 'isOpen');
  var highlightedIndex = getInitialValue$1(props, 'highlightedIndex');
  var inputValue = getInitialValue$1(props, 'inputValue');
  return {
    highlightedIndex: highlightedIndex < 0 && selectedItem && isOpen ? props.items.indexOf(selectedItem) : highlightedIndex,
    isOpen: isOpen,
    selectedItem: selectedItem,
    inputValue: inputValue
  };
}

function getHighlightedIndexOnOpen(props, state, offset, getItemNodeFromIndex) {
  var items = props.items,
      initialHighlightedIndex = props.initialHighlightedIndex,
      defaultHighlightedIndex = props.defaultHighlightedIndex;
  var selectedItem = state.selectedItem,
      highlightedIndex = state.highlightedIndex;

  if (items.length === 0) {
    return -1;
  } // initialHighlightedIndex will give value to highlightedIndex on initial state only.


  if (initialHighlightedIndex !== undefined && highlightedIndex === initialHighlightedIndex) {
    return initialHighlightedIndex;
  }

  if (defaultHighlightedIndex !== undefined) {
    return defaultHighlightedIndex;
  }

  if (selectedItem) {
    if (offset === 0) {
      return items.indexOf(selectedItem);
    }

    return getNextWrappingIndex(offset, items.indexOf(selectedItem), items.length, getItemNodeFromIndex, false);
  }

  if (offset === 0) {
    return -1;
  }

  return offset < 0 ? items.length - 1 : 0;
}
/**
 * Reuse the movement tracking of mouse and touch events.
 *
 * @param {boolean} isOpen Whether the dropdown is open or not.
 * @param {Array<Object>} downshiftElementRefs Downshift element refs to track movement (toggleButton, menu etc.)
 * @param {Object} environment Environment where component/hook exists.
 * @param {Function} handleBlur Handler on blur from mouse or touch.
 * @returns {Object} Ref containing whether mouseDown or touchMove event is happening
 */


function useMouseAndTouchTracker(isOpen, downshiftElementRefs, environment, handleBlur) {
  var mouseAndTouchTrackersRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)({
    isMouseDown: false,
    isTouchMove: false
  });
  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    // The same strategy for checking if a click occurred inside or outside downsift
    // as in downshift.js.
    var onMouseDown = function onMouseDown() {
      mouseAndTouchTrackersRef.current.isMouseDown = true;
    };

    var onMouseUp = function onMouseUp(event) {
      mouseAndTouchTrackersRef.current.isMouseDown = false;

      if (isOpen && !targetWithinDownshift(event.target, downshiftElementRefs.map(function (ref) {
        return ref.current;
      }), environment)) {
        handleBlur();
      }
    };

    var onTouchStart = function onTouchStart() {
      mouseAndTouchTrackersRef.current.isTouchMove = false;
    };

    var onTouchMove = function onTouchMove() {
      mouseAndTouchTrackersRef.current.isTouchMove = true;
    };

    var onTouchEnd = function onTouchEnd(event) {
      if (isOpen && !mouseAndTouchTrackersRef.current.isTouchMove && !targetWithinDownshift(event.target, downshiftElementRefs.map(function (ref) {
        return ref.current;
      }), environment, false)) {
        handleBlur();
      }
    };

    environment.addEventListener('mousedown', onMouseDown);
    environment.addEventListener('mouseup', onMouseUp);
    environment.addEventListener('touchstart', onTouchStart);
    environment.addEventListener('touchmove', onTouchMove);
    environment.addEventListener('touchend', onTouchEnd);
    return function cleanup() {
      environment.removeEventListener('mousedown', onMouseDown);
      environment.removeEventListener('mouseup', onMouseUp);
      environment.removeEventListener('touchstart', onTouchStart);
      environment.removeEventListener('touchmove', onTouchMove);
      environment.removeEventListener('touchend', onTouchEnd);
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [isOpen, environment]);
  return mouseAndTouchTrackersRef;
}
/* istanbul ignore next */
// eslint-disable-next-line import/no-mutable-exports


var useGetterPropsCalledChecker = function useGetterPropsCalledChecker() {
  return noop;
};
/**
 * Custom hook that checks if getter props are called correctly.
 *
 * @param  {...any} propKeys Getter prop names to be handled.
 * @returns {Function} Setter function called inside getter props to set call information.
 */

/* istanbul ignore next */


if (true) {
  useGetterPropsCalledChecker = function useGetterPropsCalledChecker() {
    var isInitialMountRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(true);

    for (var _len = arguments.length, propKeys = new Array(_len), _key = 0; _key < _len; _key++) {
      propKeys[_key] = arguments[_key];
    }

    var getterPropsCalledRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(propKeys.reduce(function (acc, propKey) {
      acc[propKey] = {};
      return acc;
    }, {}));
    (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
      Object.keys(getterPropsCalledRef.current).forEach(function (propKey) {
        var propCallInfo = getterPropsCalledRef.current[propKey];

        if (isInitialMountRef.current) {
          if (!Object.keys(propCallInfo).length) {
            // eslint-disable-next-line no-console
            console.error("downshift: You forgot to call the " + propKey + " getter function on your component / element.");
            return;
          }
        }

        var suppressRefError = propCallInfo.suppressRefError,
            refKey = propCallInfo.refKey,
            elementRef = propCallInfo.elementRef;

        if ((!elementRef || !elementRef.current) && !suppressRefError) {
          // eslint-disable-next-line no-console
          console.error("downshift: The ref prop \"" + refKey + "\" from " + propKey + " was not applied correctly on your element.");
        }
      });
      isInitialMountRef.current = false;
    });
    var setGetterPropCallInfo = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (propKey, suppressRefError, refKey, elementRef) {
      getterPropsCalledRef.current[propKey] = {
        suppressRefError: suppressRefError,
        refKey: refKey,
        elementRef: elementRef
      };
    }, []);
    return setGetterPropCallInfo;
  };
}

function useA11yMessageSetter(getA11yMessage, dependencyArray, _ref2) {
  var isInitialMount = _ref2.isInitialMount,
      highlightedIndex = _ref2.highlightedIndex,
      items = _ref2.items,
      environment = _ref2.environment,
      rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref2, _excluded$3);

  // Sets a11y status message on changes in state.
  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (isInitialMount || false) {
      return;
    }

    updateA11yStatus(function () {
      return getA11yMessage((0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
        highlightedIndex: highlightedIndex,
        highlightedItem: items[highlightedIndex],
        resultCount: items.length
      }, rest));
    }, environment.document); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, dependencyArray);
}

function useScrollIntoView(_ref3) {
  var highlightedIndex = _ref3.highlightedIndex,
      isOpen = _ref3.isOpen,
      itemRefs = _ref3.itemRefs,
      getItemNodeFromIndex = _ref3.getItemNodeFromIndex,
      menuElement = _ref3.menuElement,
      scrollIntoViewProp = _ref3.scrollIntoView;
  // used not to scroll on highlight by mouse.
  var shouldScrollRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(true); // Scroll on highlighted item if change comes from keyboard.

  useIsomorphicLayoutEffect(function () {
    if (highlightedIndex < 0 || !isOpen || !Object.keys(itemRefs.current).length) {
      return;
    }

    if (shouldScrollRef.current === false) {
      shouldScrollRef.current = true;
    } else {
      scrollIntoViewProp(getItemNodeFromIndex(highlightedIndex), menuElement);
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [highlightedIndex]);
  return shouldScrollRef;
} // eslint-disable-next-line import/no-mutable-exports


var useControlPropsValidator = noop;
/* istanbul ignore next */

if (true) {
  useControlPropsValidator = function useControlPropsValidator(_ref4) {
    var isInitialMount = _ref4.isInitialMount,
        props = _ref4.props,
        state = _ref4.state;
    // used for checking when props are moving from controlled to uncontrolled.
    var prevPropsRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(props);
    (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
      if (isInitialMount) {
        return;
      }

      validateControlledUnchanged(state, prevPropsRef.current, props);
      prevPropsRef.current = props;
    }, [state, props, isInitialMount]);
  };
}

/* eslint-disable complexity */

function downshiftCommonReducer(state, action, stateChangeTypes) {
  var type = action.type,
      props = action.props;
  var changes;

  switch (type) {
    case stateChangeTypes.ItemMouseMove:
      changes = {
        highlightedIndex: action.index
      };
      break;

    case stateChangeTypes.MenuMouseLeave:
      changes = {
        highlightedIndex: -1
      };
      break;

    case stateChangeTypes.ToggleButtonClick:
    case stateChangeTypes.FunctionToggleMenu:
      changes = {
        isOpen: !state.isOpen,
        highlightedIndex: state.isOpen ? -1 : getHighlightedIndexOnOpen(props, state, 0)
      };
      break;

    case stateChangeTypes.FunctionOpenMenu:
      changes = {
        isOpen: true,
        highlightedIndex: getHighlightedIndexOnOpen(props, state, 0)
      };
      break;

    case stateChangeTypes.FunctionCloseMenu:
      changes = {
        isOpen: false
      };
      break;

    case stateChangeTypes.FunctionSetHighlightedIndex:
      changes = {
        highlightedIndex: action.highlightedIndex
      };
      break;

    case stateChangeTypes.FunctionSetInputValue:
      changes = {
        inputValue: action.inputValue
      };
      break;

    case stateChangeTypes.FunctionReset:
      changes = {
        highlightedIndex: getDefaultValue$1(props, 'highlightedIndex'),
        isOpen: getDefaultValue$1(props, 'isOpen'),
        selectedItem: getDefaultValue$1(props, 'selectedItem'),
        inputValue: getDefaultValue$1(props, 'inputValue')
      };
      break;

    default:
      throw new Error('Reducer called without proper action type.');
  }

  return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, state, changes);
}
/* eslint-enable complexity */

function getItemIndexByCharacterKey(_a) {
    var keysSoFar = _a.keysSoFar, highlightedIndex = _a.highlightedIndex, items = _a.items, itemToString = _a.itemToString, getItemNodeFromIndex = _a.getItemNodeFromIndex;
    var lowerCasedKeysSoFar = keysSoFar.toLowerCase();
    for (var index = 0; index < items.length; index++) {
        var offsetIndex = (index + highlightedIndex + 1) % items.length;
        var item = items[offsetIndex];
        if (item !== undefined &&
            itemToString(item)
                .toLowerCase()
                .startsWith(lowerCasedKeysSoFar)) {
            var element = getItemNodeFromIndex(offsetIndex);
            if (!(element === null || element === void 0 ? void 0 : element.hasAttribute('disabled'))) {
                return offsetIndex;
            }
        }
    }
    return highlightedIndex;
}
var propTypes$2 = {
    items: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().array.isRequired),
    itemToString: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    getA11yStatusMessage: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    getA11ySelectionMessage: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    circularNavigation: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
    highlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
    defaultHighlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
    initialHighlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
    isOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
    defaultIsOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
    initialIsOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
    selectedItem: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
    initialSelectedItem: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
    defaultSelectedItem: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
    id: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
    labelId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
    menuId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
    getItemId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    toggleButtonId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
    stateReducer: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    onSelectedItemChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    onHighlightedIndexChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    onStateChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    onIsOpenChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    environment: prop_types__WEBPACK_IMPORTED_MODULE_7___default().shape({
        addEventListener: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
        removeEventListener: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
        document: prop_types__WEBPACK_IMPORTED_MODULE_7___default().shape({
            getElementById: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
            activeElement: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
            body: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any)
        })
    })
};
/**
 * Default implementation for status message. Only added when menu is open.
 * Will specift if there are results in the list, and if so, how many,
 * and what keys are relevant.
 *
 * @param {Object} param the downshift state and other relevant properties
 * @return {String} the a11y status message
 */
function getA11yStatusMessage(_a) {
    var isOpen = _a.isOpen, resultCount = _a.resultCount, previousResultCount = _a.previousResultCount;
    if (!isOpen) {
        return '';
    }
    if (!resultCount) {
        return 'No results are available.';
    }
    if (resultCount !== previousResultCount) {
        return resultCount + " result" + (resultCount === 1 ? ' is' : 's are') + " available, use up and down arrow keys to navigate. Press Enter or Space Bar keys to select.";
    }
    return '';
}
var defaultProps$2 = (0,tslib__WEBPACK_IMPORTED_MODULE_8__.__assign)((0,tslib__WEBPACK_IMPORTED_MODULE_8__.__assign)({}, defaultProps$3), { getA11yStatusMessage: getA11yStatusMessage });
// eslint-disable-next-line import/no-mutable-exports
var validatePropTypes$2 = noop;
/* istanbul ignore next */
if (true) {
    validatePropTypes$2 = function (options, caller) {
        prop_types__WEBPACK_IMPORTED_MODULE_7___default().checkPropTypes(propTypes$2, options, 'prop', caller.name);
    };
}

var MenuKeyDownArrowDown =  true ? '__menu_keydown_arrow_down__' : 0;
var MenuKeyDownArrowUp =  true ? '__menu_keydown_arrow_up__' : 0;
var MenuKeyDownEscape =  true ? '__menu_keydown_escape__' : 0;
var MenuKeyDownHome =  true ? '__menu_keydown_home__' : 0;
var MenuKeyDownEnd =  true ? '__menu_keydown_end__' : 0;
var MenuKeyDownEnter =  true ? '__menu_keydown_enter__' : 0;
var MenuKeyDownSpaceButton =  true ? '__menu_keydown_space_button__' : 0;
var MenuKeyDownCharacter =  true ? '__menu_keydown_character__' : 0;
var MenuBlur =  true ? '__menu_blur__' : 0;
var MenuMouseLeave$1 =  true ? '__menu_mouse_leave__' : 0;
var ItemMouseMove$1 =  true ? '__item_mouse_move__' : 0;
var ItemClick$1 =  true ? '__item_click__' : 0;
var ToggleButtonClick$1 =  true ? '__togglebutton_click__' : 0;
var ToggleButtonKeyDownArrowDown =  true ? '__togglebutton_keydown_arrow_down__' : 0;
var ToggleButtonKeyDownArrowUp =  true ? '__togglebutton_keydown_arrow_up__' : 0;
var ToggleButtonKeyDownCharacter =  true ? '__togglebutton_keydown_character__' : 0;
var FunctionToggleMenu$1 =  true ? '__function_toggle_menu__' : 0;
var FunctionOpenMenu$1 =  true ? '__function_open_menu__' : 0;
var FunctionCloseMenu$1 =  true ? '__function_close_menu__' : 0;
var FunctionSetHighlightedIndex$1 =  true ? '__function_set_highlighted_index__' : 0;
var FunctionSelectItem$1 =  true ? '__function_select_item__' : 0;
var FunctionSetInputValue$1 =  true ? '__function_set_input_value__' : 0;
var FunctionReset$2 =  true ? '__function_reset__' : 0;

var stateChangeTypes$2 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  MenuKeyDownArrowDown: MenuKeyDownArrowDown,
  MenuKeyDownArrowUp: MenuKeyDownArrowUp,
  MenuKeyDownEscape: MenuKeyDownEscape,
  MenuKeyDownHome: MenuKeyDownHome,
  MenuKeyDownEnd: MenuKeyDownEnd,
  MenuKeyDownEnter: MenuKeyDownEnter,
  MenuKeyDownSpaceButton: MenuKeyDownSpaceButton,
  MenuKeyDownCharacter: MenuKeyDownCharacter,
  MenuBlur: MenuBlur,
  MenuMouseLeave: MenuMouseLeave$1,
  ItemMouseMove: ItemMouseMove$1,
  ItemClick: ItemClick$1,
  ToggleButtonClick: ToggleButtonClick$1,
  ToggleButtonKeyDownArrowDown: ToggleButtonKeyDownArrowDown,
  ToggleButtonKeyDownArrowUp: ToggleButtonKeyDownArrowUp,
  ToggleButtonKeyDownCharacter: ToggleButtonKeyDownCharacter,
  FunctionToggleMenu: FunctionToggleMenu$1,
  FunctionOpenMenu: FunctionOpenMenu$1,
  FunctionCloseMenu: FunctionCloseMenu$1,
  FunctionSetHighlightedIndex: FunctionSetHighlightedIndex$1,
  FunctionSelectItem: FunctionSelectItem$1,
  FunctionSetInputValue: FunctionSetInputValue$1,
  FunctionReset: FunctionReset$2
});

/* eslint-disable complexity */

function downshiftSelectReducer(state, action) {
  var type = action.type,
      props = action.props,
      shiftKey = action.shiftKey;
  var changes;

  switch (type) {
    case ItemClick$1:
      changes = {
        isOpen: getDefaultValue$1(props, 'isOpen'),
        highlightedIndex: getDefaultValue$1(props, 'highlightedIndex'),
        selectedItem: props.items[action.index]
      };
      break;

    case ToggleButtonKeyDownCharacter:
      {
        var lowercasedKey = action.key;
        var inputValue = "" + state.inputValue + lowercasedKey;
        var itemIndex = getItemIndexByCharacterKey({
          keysSoFar: inputValue,
          highlightedIndex: state.selectedItem ? props.items.indexOf(state.selectedItem) : -1,
          items: props.items,
          itemToString: props.itemToString,
          getItemNodeFromIndex: action.getItemNodeFromIndex
        });
        changes = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          inputValue: inputValue
        }, itemIndex >= 0 && {
          selectedItem: props.items[itemIndex]
        });
      }
      break;

    case ToggleButtonKeyDownArrowDown:
      changes = {
        highlightedIndex: getHighlightedIndexOnOpen(props, state, 1, action.getItemNodeFromIndex),
        isOpen: true
      };
      break;

    case ToggleButtonKeyDownArrowUp:
      changes = {
        highlightedIndex: getHighlightedIndexOnOpen(props, state, -1, action.getItemNodeFromIndex),
        isOpen: true
      };
      break;

    case MenuKeyDownEnter:
    case MenuKeyDownSpaceButton:
      changes = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
        isOpen: getDefaultValue$1(props, 'isOpen'),
        highlightedIndex: getDefaultValue$1(props, 'highlightedIndex')
      }, state.highlightedIndex >= 0 && {
        selectedItem: props.items[state.highlightedIndex]
      });
      break;

    case MenuKeyDownHome:
      changes = {
        highlightedIndex: getNextNonDisabledIndex(1, 0, props.items.length, action.getItemNodeFromIndex, false)
      };
      break;

    case MenuKeyDownEnd:
      changes = {
        highlightedIndex: getNextNonDisabledIndex(-1, props.items.length - 1, props.items.length, action.getItemNodeFromIndex, false)
      };
      break;

    case MenuKeyDownEscape:
      changes = {
        isOpen: false,
        highlightedIndex: -1
      };
      break;

    case MenuBlur:
      changes = {
        isOpen: false,
        highlightedIndex: -1
      };
      break;

    case MenuKeyDownCharacter:
      {
        var _lowercasedKey = action.key;

        var _inputValue = "" + state.inputValue + _lowercasedKey;

        var highlightedIndex = getItemIndexByCharacterKey({
          keysSoFar: _inputValue,
          highlightedIndex: state.highlightedIndex,
          items: props.items,
          itemToString: props.itemToString,
          getItemNodeFromIndex: action.getItemNodeFromIndex
        });
        changes = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          inputValue: _inputValue
        }, highlightedIndex >= 0 && {
          highlightedIndex: highlightedIndex
        });
      }
      break;

    case MenuKeyDownArrowDown:
      changes = {
        highlightedIndex: getNextWrappingIndex(shiftKey ? 5 : 1, state.highlightedIndex, props.items.length, action.getItemNodeFromIndex, props.circularNavigation)
      };
      break;

    case MenuKeyDownArrowUp:
      changes = {
        highlightedIndex: getNextWrappingIndex(shiftKey ? -5 : -1, state.highlightedIndex, props.items.length, action.getItemNodeFromIndex, props.circularNavigation)
      };
      break;

    case FunctionSelectItem$1:
      changes = {
        selectedItem: action.selectedItem
      };
      break;

    default:
      return downshiftCommonReducer(state, action, stateChangeTypes$2);
  }

  return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, state, changes);
}
/* eslint-enable complexity */

var _excluded$2 = ["onMouseLeave", "refKey", "onKeyDown", "onBlur", "ref"],
    _excluded2$2 = ["onClick", "onKeyDown", "refKey", "ref"],
    _excluded3$1 = ["item", "index", "onMouseMove", "onClick", "refKey", "ref"];
useSelect.stateChangeTypes = stateChangeTypes$2;

function useSelect(userProps) {
  if (userProps === void 0) {
    userProps = {};
  }

  validatePropTypes$2(userProps, useSelect); // Props defaults and destructuring.

  var props = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, defaultProps$2, userProps);

  var items = props.items,
      scrollIntoView = props.scrollIntoView,
      environment = props.environment,
      initialIsOpen = props.initialIsOpen,
      defaultIsOpen = props.defaultIsOpen,
      itemToString = props.itemToString,
      getA11ySelectionMessage = props.getA11ySelectionMessage,
      getA11yStatusMessage = props.getA11yStatusMessage; // Initial state depending on controlled props.

  var initialState = getInitialState$2(props);

  var _useControlledReducer = useControlledReducer$1(downshiftSelectReducer, initialState, props),
      state = _useControlledReducer[0],
      dispatch = _useControlledReducer[1];

  var isOpen = state.isOpen,
      highlightedIndex = state.highlightedIndex,
      selectedItem = state.selectedItem,
      inputValue = state.inputValue; // Element efs.

  var toggleButtonRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var menuRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var itemRefs = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)({}); // used not to trigger menu blur action in some scenarios.

  var shouldBlurRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(true); // used to keep the inputValue clearTimeout object between renders.

  var clearTimeoutRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null); // prevent id re-generation between renders.

  var elementIds = useElementIds(props); // used to keep track of how many items we had on previous cycle.

  var previousResultCountRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)();
  var isInitialMountRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(true); // utility callback to get item element.

  var latest = useLatestRef({
    state: state,
    props: props
  }); // Some utils.

  var getItemNodeFromIndex = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (index) {
    return itemRefs.current[elementIds.getItemId(index)];
  }, [elementIds]); // Effects.
  // Sets a11y status message on changes in state.

  useA11yMessageSetter(getA11yStatusMessage, [isOpen, highlightedIndex, inputValue, items], (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
    isInitialMount: isInitialMountRef.current,
    previousResultCount: previousResultCountRef.current,
    items: items,
    environment: environment,
    itemToString: itemToString
  }, state)); // Sets a11y status message on changes in selectedItem.

  useA11yMessageSetter(getA11ySelectionMessage, [selectedItem], (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
    isInitialMount: isInitialMountRef.current,
    previousResultCount: previousResultCountRef.current,
    items: items,
    environment: environment,
    itemToString: itemToString
  }, state)); // Scroll on highlighted item if change comes from keyboard.

  var shouldScrollRef = useScrollIntoView({
    menuElement: menuRef.current,
    highlightedIndex: highlightedIndex,
    isOpen: isOpen,
    itemRefs: itemRefs,
    scrollIntoView: scrollIntoView,
    getItemNodeFromIndex: getItemNodeFromIndex
  }); // Sets cleanup for the keysSoFar callback, debounded after 500ms.

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    // init the clean function here as we need access to dispatch.
    clearTimeoutRef.current = debounce(function (outerDispatch) {
      outerDispatch({
        type: FunctionSetInputValue$1,
        inputValue: ''
      });
    }, 500); // Cancel any pending debounced calls on mount

    return function () {
      clearTimeoutRef.current.cancel();
    };
  }, []); // Invokes the keysSoFar callback set up above.

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (!inputValue) {
      return;
    }

    clearTimeoutRef.current(dispatch);
  }, [dispatch, inputValue]);
  useControlPropsValidator({
    isInitialMount: isInitialMountRef.current,
    props: props,
    state: state
  });
  /* Controls the focus on the menu or the toggle button. */

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    // Don't focus menu on first render.
    if (isInitialMountRef.current) {
      // Unless it was initialised as open.
      if ((initialIsOpen || defaultIsOpen || isOpen) && menuRef.current) {
        menuRef.current.focus();
      }

      return;
    } // Focus menu on open.


    if (isOpen) {
      // istanbul ignore else
      if (menuRef.current) {
        menuRef.current.focus();
      }

      return;
    } // Focus toggleButton on close, but not if it was closed with (Shift+)Tab.


    if (environment.document.activeElement === menuRef.current) {
      // istanbul ignore else
      if (toggleButtonRef.current) {
        shouldBlurRef.current = false;
        toggleButtonRef.current.focus();
      }
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [isOpen]);
  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (isInitialMountRef.current) {
      return;
    }

    previousResultCountRef.current = items.length;
  }); // Add mouse/touch events to document.

  var mouseAndTouchTrackersRef = useMouseAndTouchTracker(isOpen, [menuRef, toggleButtonRef], environment, function () {
    dispatch({
      type: MenuBlur
    });
  });
  var setGetterPropCallInfo = useGetterPropsCalledChecker('getMenuProps', 'getToggleButtonProps'); // Make initial ref false.

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    isInitialMountRef.current = false;
  }, []); // Reset itemRefs on close.

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (!isOpen) {
      itemRefs.current = {};
    }
  }, [isOpen]); // Event handler functions.

  var toggleButtonKeyDownHandlers = (0,react__WEBPACK_IMPORTED_MODULE_4__.useMemo)(function () {
    return {
      ArrowDown: function ArrowDown(event) {
        event.preventDefault();
        dispatch({
          type: ToggleButtonKeyDownArrowDown,
          getItemNodeFromIndex: getItemNodeFromIndex,
          shiftKey: event.shiftKey
        });
      },
      ArrowUp: function ArrowUp(event) {
        event.preventDefault();
        dispatch({
          type: ToggleButtonKeyDownArrowUp,
          getItemNodeFromIndex: getItemNodeFromIndex,
          shiftKey: event.shiftKey
        });
      }
    };
  }, [dispatch, getItemNodeFromIndex]);
  var menuKeyDownHandlers = (0,react__WEBPACK_IMPORTED_MODULE_4__.useMemo)(function () {
    return {
      ArrowDown: function ArrowDown(event) {
        event.preventDefault();
        dispatch({
          type: MenuKeyDownArrowDown,
          getItemNodeFromIndex: getItemNodeFromIndex,
          shiftKey: event.shiftKey
        });
      },
      ArrowUp: function ArrowUp(event) {
        event.preventDefault();
        dispatch({
          type: MenuKeyDownArrowUp,
          getItemNodeFromIndex: getItemNodeFromIndex,
          shiftKey: event.shiftKey
        });
      },
      Home: function Home(event) {
        event.preventDefault();
        dispatch({
          type: MenuKeyDownHome,
          getItemNodeFromIndex: getItemNodeFromIndex
        });
      },
      End: function End(event) {
        event.preventDefault();
        dispatch({
          type: MenuKeyDownEnd,
          getItemNodeFromIndex: getItemNodeFromIndex
        });
      },
      Escape: function Escape() {
        dispatch({
          type: MenuKeyDownEscape
        });
      },
      Enter: function Enter(event) {
        event.preventDefault();
        dispatch({
          type: MenuKeyDownEnter
        });
      },
      ' ': function _(event) {
        event.preventDefault();
        dispatch({
          type: MenuKeyDownSpaceButton
        });
      }
    };
  }, [dispatch, getItemNodeFromIndex]); // Action functions.

  var toggleMenu = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function () {
    dispatch({
      type: FunctionToggleMenu$1
    });
  }, [dispatch]);
  var closeMenu = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function () {
    dispatch({
      type: FunctionCloseMenu$1
    });
  }, [dispatch]);
  var openMenu = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function () {
    dispatch({
      type: FunctionOpenMenu$1
    });
  }, [dispatch]);
  var setHighlightedIndex = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (newHighlightedIndex) {
    dispatch({
      type: FunctionSetHighlightedIndex$1,
      highlightedIndex: newHighlightedIndex
    });
  }, [dispatch]);
  var selectItem = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (newSelectedItem) {
    dispatch({
      type: FunctionSelectItem$1,
      selectedItem: newSelectedItem
    });
  }, [dispatch]);
  var reset = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function () {
    dispatch({
      type: FunctionReset$2
    });
  }, [dispatch]);
  var setInputValue = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (newInputValue) {
    dispatch({
      type: FunctionSetInputValue$1,
      inputValue: newInputValue
    });
  }, [dispatch]); // Getter functions.

  var getLabelProps = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (labelProps) {
    return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
      id: elementIds.labelId,
      htmlFor: elementIds.toggleButtonId
    }, labelProps);
  }, [elementIds]);
  var getMenuProps = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (_temp, _temp2) {
    var _extends2;

    var _ref = _temp === void 0 ? {} : _temp,
        onMouseLeave = _ref.onMouseLeave,
        _ref$refKey = _ref.refKey,
        refKey = _ref$refKey === void 0 ? 'ref' : _ref$refKey,
        onKeyDown = _ref.onKeyDown,
        onBlur = _ref.onBlur,
        ref = _ref.ref,
        rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref, _excluded$2);

    var _ref2 = _temp2 === void 0 ? {} : _temp2,
        _ref2$suppressRefErro = _ref2.suppressRefError,
        suppressRefError = _ref2$suppressRefErro === void 0 ? false : _ref2$suppressRefErro;

    var latestState = latest.current.state;

    var menuHandleKeyDown = function menuHandleKeyDown(event) {
      var key = normalizeArrowKey(event);

      if (key && menuKeyDownHandlers[key]) {
        menuKeyDownHandlers[key](event);
      } else if (isAcceptedCharacterKey(key)) {
        dispatch({
          type: MenuKeyDownCharacter,
          key: key,
          getItemNodeFromIndex: getItemNodeFromIndex
        });
      }
    };

    var menuHandleBlur = function menuHandleBlur() {
      // if the blur was a result of selection, we don't trigger this action.
      if (shouldBlurRef.current === false) {
        shouldBlurRef.current = true;
        return;
      }

      var shouldBlur = !mouseAndTouchTrackersRef.current.isMouseDown;
      /* istanbul ignore else */

      if (shouldBlur) {
        dispatch({
          type: MenuBlur
        });
      }
    };

    var menuHandleMouseLeave = function menuHandleMouseLeave() {
      dispatch({
        type: MenuMouseLeave$1
      });
    };

    setGetterPropCallInfo('getMenuProps', suppressRefError, refKey, menuRef);
    return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends2 = {}, _extends2[refKey] = handleRefs(ref, function (menuNode) {
      menuRef.current = menuNode;
    }), _extends2.id = elementIds.menuId, _extends2.role = 'listbox', _extends2['aria-labelledby'] = elementIds.labelId, _extends2.tabIndex = -1, _extends2), latestState.isOpen && latestState.highlightedIndex > -1 && {
      'aria-activedescendant': elementIds.getItemId(latestState.highlightedIndex)
    }, {
      onMouseLeave: callAllEventHandlers(onMouseLeave, menuHandleMouseLeave),
      onKeyDown: callAllEventHandlers(onKeyDown, menuHandleKeyDown),
      onBlur: callAllEventHandlers(onBlur, menuHandleBlur)
    }, rest);
  }, [dispatch, latest, menuKeyDownHandlers, mouseAndTouchTrackersRef, setGetterPropCallInfo, elementIds, getItemNodeFromIndex]);
  var getToggleButtonProps = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (_temp3, _temp4) {
    var _extends3;

    var _ref3 = _temp3 === void 0 ? {} : _temp3,
        onClick = _ref3.onClick,
        onKeyDown = _ref3.onKeyDown,
        _ref3$refKey = _ref3.refKey,
        refKey = _ref3$refKey === void 0 ? 'ref' : _ref3$refKey,
        ref = _ref3.ref,
        rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref3, _excluded2$2);

    var _ref4 = _temp4 === void 0 ? {} : _temp4,
        _ref4$suppressRefErro = _ref4.suppressRefError,
        suppressRefError = _ref4$suppressRefErro === void 0 ? false : _ref4$suppressRefErro;

    var toggleButtonHandleClick = function toggleButtonHandleClick() {
      dispatch({
        type: ToggleButtonClick$1
      });
    };

    var toggleButtonHandleKeyDown = function toggleButtonHandleKeyDown(event) {
      var key = normalizeArrowKey(event);

      if (key && toggleButtonKeyDownHandlers[key]) {
        toggleButtonKeyDownHandlers[key](event);
      } else if (isAcceptedCharacterKey(key)) {
        dispatch({
          type: ToggleButtonKeyDownCharacter,
          key: key,
          getItemNodeFromIndex: getItemNodeFromIndex
        });
      }
    };

    var toggleProps = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends3 = {}, _extends3[refKey] = handleRefs(ref, function (toggleButtonNode) {
      toggleButtonRef.current = toggleButtonNode;
    }), _extends3.id = elementIds.toggleButtonId, _extends3['aria-haspopup'] = 'listbox', _extends3['aria-expanded'] = latest.current.state.isOpen, _extends3['aria-labelledby'] = elementIds.labelId + " " + elementIds.toggleButtonId, _extends3), rest);

    if (!rest.disabled) {
      toggleProps.onClick = callAllEventHandlers(onClick, toggleButtonHandleClick);
      toggleProps.onKeyDown = callAllEventHandlers(onKeyDown, toggleButtonHandleKeyDown);
    }

    setGetterPropCallInfo('getToggleButtonProps', suppressRefError, refKey, toggleButtonRef);
    return toggleProps;
  }, [dispatch, latest, toggleButtonKeyDownHandlers, setGetterPropCallInfo, elementIds, getItemNodeFromIndex]);
  var getItemProps = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (_temp5) {
    var _extends4;

    var _ref5 = _temp5 === void 0 ? {} : _temp5,
        item = _ref5.item,
        index = _ref5.index,
        onMouseMove = _ref5.onMouseMove,
        onClick = _ref5.onClick,
        _ref5$refKey = _ref5.refKey,
        refKey = _ref5$refKey === void 0 ? 'ref' : _ref5$refKey,
        ref = _ref5.ref,
        rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref5, _excluded3$1);

    var _latest$current = latest.current,
        latestState = _latest$current.state,
        latestProps = _latest$current.props;

    var itemHandleMouseMove = function itemHandleMouseMove() {
      if (index === latestState.highlightedIndex) {
        return;
      }

      shouldScrollRef.current = false;
      dispatch({
        type: ItemMouseMove$1,
        index: index
      });
    };

    var itemHandleClick = function itemHandleClick() {
      dispatch({
        type: ItemClick$1,
        index: index
      });
    };

    var itemIndex = getItemIndex(index, item, latestProps.items);

    if (itemIndex < 0) {
      throw new Error('Pass either item or item index in getItemProps!');
    }

    var itemProps = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends4 = {
      role: 'option',
      'aria-selected': "" + (itemIndex === latestState.highlightedIndex),
      id: elementIds.getItemId(itemIndex)
    }, _extends4[refKey] = handleRefs(ref, function (itemNode) {
      if (itemNode) {
        itemRefs.current[elementIds.getItemId(itemIndex)] = itemNode;
      }
    }), _extends4), rest);

    if (!rest.disabled) {
      itemProps.onMouseMove = callAllEventHandlers(onMouseMove, itemHandleMouseMove);
      itemProps.onClick = callAllEventHandlers(onClick, itemHandleClick);
    }

    return itemProps;
  }, [dispatch, latest, shouldScrollRef, elementIds]);
  return {
    // prop getters.
    getToggleButtonProps: getToggleButtonProps,
    getLabelProps: getLabelProps,
    getMenuProps: getMenuProps,
    getItemProps: getItemProps,
    // actions.
    toggleMenu: toggleMenu,
    openMenu: openMenu,
    closeMenu: closeMenu,
    setHighlightedIndex: setHighlightedIndex,
    selectItem: selectItem,
    reset: reset,
    setInputValue: setInputValue,
    // state.
    highlightedIndex: highlightedIndex,
    isOpen: isOpen,
    selectedItem: selectedItem,
    inputValue: inputValue
  };
}

var InputKeyDownArrowDown =  true ? '__input_keydown_arrow_down__' : 0;
var InputKeyDownArrowUp =  true ? '__input_keydown_arrow_up__' : 0;
var InputKeyDownEscape =  true ? '__input_keydown_escape__' : 0;
var InputKeyDownHome =  true ? '__input_keydown_home__' : 0;
var InputKeyDownEnd =  true ? '__input_keydown_end__' : 0;
var InputKeyDownEnter =  true ? '__input_keydown_enter__' : 0;
var InputChange =  true ? '__input_change__' : 0;
var InputBlur =  true ? '__input_blur__' : 0;
var MenuMouseLeave =  true ? '__menu_mouse_leave__' : 0;
var ItemMouseMove =  true ? '__item_mouse_move__' : 0;
var ItemClick =  true ? '__item_click__' : 0;
var ToggleButtonClick =  true ? '__togglebutton_click__' : 0;
var FunctionToggleMenu =  true ? '__function_toggle_menu__' : 0;
var FunctionOpenMenu =  true ? '__function_open_menu__' : 0;
var FunctionCloseMenu =  true ? '__function_close_menu__' : 0;
var FunctionSetHighlightedIndex =  true ? '__function_set_highlighted_index__' : 0;
var FunctionSelectItem =  true ? '__function_select_item__' : 0;
var FunctionSetInputValue =  true ? '__function_set_input_value__' : 0;
var FunctionReset$1 =  true ? '__function_reset__' : 0;
var ControlledPropUpdatedSelectedItem =  true ? '__controlled_prop_updated_selected_item__' : 0;

var stateChangeTypes$1 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  InputKeyDownArrowDown: InputKeyDownArrowDown,
  InputKeyDownArrowUp: InputKeyDownArrowUp,
  InputKeyDownEscape: InputKeyDownEscape,
  InputKeyDownHome: InputKeyDownHome,
  InputKeyDownEnd: InputKeyDownEnd,
  InputKeyDownEnter: InputKeyDownEnter,
  InputChange: InputChange,
  InputBlur: InputBlur,
  MenuMouseLeave: MenuMouseLeave,
  ItemMouseMove: ItemMouseMove,
  ItemClick: ItemClick,
  ToggleButtonClick: ToggleButtonClick,
  FunctionToggleMenu: FunctionToggleMenu,
  FunctionOpenMenu: FunctionOpenMenu,
  FunctionCloseMenu: FunctionCloseMenu,
  FunctionSetHighlightedIndex: FunctionSetHighlightedIndex,
  FunctionSelectItem: FunctionSelectItem,
  FunctionSetInputValue: FunctionSetInputValue,
  FunctionReset: FunctionReset$1,
  ControlledPropUpdatedSelectedItem: ControlledPropUpdatedSelectedItem
});

function getInitialState$1(props) {
  var initialState = getInitialState$2(props);
  var selectedItem = initialState.selectedItem;
  var inputValue = initialState.inputValue;

  if (inputValue === '' && selectedItem && props.defaultInputValue === undefined && props.initialInputValue === undefined && props.inputValue === undefined) {
    inputValue = props.itemToString(selectedItem);
  }

  return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, initialState, {
    inputValue: inputValue
  });
}

var propTypes$1 = {
  items: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().array.isRequired),
  itemToString: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  getA11yStatusMessage: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  getA11ySelectionMessage: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  circularNavigation: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  highlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  defaultHighlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  initialHighlightedIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  isOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  defaultIsOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  initialIsOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
  selectedItem: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
  initialSelectedItem: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
  defaultSelectedItem: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
  inputValue: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  defaultInputValue: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  initialInputValue: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  id: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  labelId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  menuId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  getItemId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  inputId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  toggleButtonId: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  stateReducer: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onSelectedItemChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onHighlightedIndexChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onStateChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onIsOpenChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onInputValueChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  environment: prop_types__WEBPACK_IMPORTED_MODULE_7___default().shape({
    addEventListener: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    removeEventListener: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    document: prop_types__WEBPACK_IMPORTED_MODULE_7___default().shape({
      getElementById: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
      activeElement: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
      body: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any)
    })
  })
};
/**
 * The useCombobox version of useControlledReducer, which also
 * checks if the controlled prop selectedItem changed between
 * renders. If so, it will also update inputValue with its
 * string equivalent. It uses the common useEnhancedReducer to
 * compute the rest of the state.
 *
 * @param {Function} reducer Reducer function from downshift.
 * @param {Object} initialState Initial state of the hook.
 * @param {Object} props The hook props.
 * @returns {Array} An array with the state and an action dispatcher.
 */

function useControlledReducer(reducer, initialState, props) {
  var previousSelectedItemRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)();

  var _useEnhancedReducer = useEnhancedReducer(reducer, initialState, props),
      state = _useEnhancedReducer[0],
      dispatch = _useEnhancedReducer[1]; // ToDo: if needed, make same approach as selectedItemChanged from Downshift.


  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (isControlledProp(props, 'selectedItem')) {
      if (previousSelectedItemRef.current !== props.selectedItem) {
        dispatch({
          type: ControlledPropUpdatedSelectedItem,
          inputValue: props.itemToString(props.selectedItem)
        });
      }

      previousSelectedItemRef.current = state.selectedItem === previousSelectedItemRef.current ? props.selectedItem : state.selectedItem;
    }
  });
  return [getState(state, props), dispatch];
} // eslint-disable-next-line import/no-mutable-exports


var validatePropTypes$1 = noop;
/* istanbul ignore next */

if (true) {
  validatePropTypes$1 = function validatePropTypes(options, caller) {
    prop_types__WEBPACK_IMPORTED_MODULE_7___default().checkPropTypes(propTypes$1, options, 'prop', caller.name);
  };
}

var defaultProps$1 = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, defaultProps$3, {
  getA11yStatusMessage: getA11yStatusMessage$1,
  circularNavigation: true
});

/* eslint-disable complexity */

function downshiftUseComboboxReducer(state, action) {
  var type = action.type,
      props = action.props,
      shiftKey = action.shiftKey;
  var changes;

  switch (type) {
    case ItemClick:
      changes = {
        isOpen: getDefaultValue$1(props, 'isOpen'),
        highlightedIndex: getDefaultValue$1(props, 'highlightedIndex'),
        selectedItem: props.items[action.index],
        inputValue: props.itemToString(props.items[action.index])
      };
      break;

    case InputKeyDownArrowDown:
      if (state.isOpen) {
        changes = {
          highlightedIndex: getNextWrappingIndex(shiftKey ? 5 : 1, state.highlightedIndex, props.items.length, action.getItemNodeFromIndex, props.circularNavigation)
        };
      } else {
        changes = {
          highlightedIndex: getHighlightedIndexOnOpen(props, state, 1, action.getItemNodeFromIndex),
          isOpen: props.items.length >= 0
        };
      }

      break;

    case InputKeyDownArrowUp:
      if (state.isOpen) {
        changes = {
          highlightedIndex: getNextWrappingIndex(shiftKey ? -5 : -1, state.highlightedIndex, props.items.length, action.getItemNodeFromIndex, props.circularNavigation)
        };
      } else {
        changes = {
          highlightedIndex: getHighlightedIndexOnOpen(props, state, -1, action.getItemNodeFromIndex),
          isOpen: props.items.length >= 0
        };
      }

      break;

    case InputKeyDownEnter:
      changes = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, state.isOpen && state.highlightedIndex >= 0 && {
        selectedItem: props.items[state.highlightedIndex],
        isOpen: getDefaultValue$1(props, 'isOpen'),
        highlightedIndex: getDefaultValue$1(props, 'highlightedIndex'),
        inputValue: props.itemToString(props.items[state.highlightedIndex])
      });
      break;

    case InputKeyDownEscape:
      changes = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
        isOpen: false,
        highlightedIndex: -1
      }, !state.isOpen && {
        selectedItem: null,
        inputValue: ''
      });
      break;

    case InputKeyDownHome:
      changes = {
        highlightedIndex: getNextNonDisabledIndex(1, 0, props.items.length, action.getItemNodeFromIndex, false)
      };
      break;

    case InputKeyDownEnd:
      changes = {
        highlightedIndex: getNextNonDisabledIndex(-1, props.items.length - 1, props.items.length, action.getItemNodeFromIndex, false)
      };
      break;

    case InputBlur:
      changes = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
        isOpen: false,
        highlightedIndex: -1
      }, state.highlightedIndex >= 0 && action.selectItem && {
        selectedItem: props.items[state.highlightedIndex],
        inputValue: props.itemToString(props.items[state.highlightedIndex])
      });
      break;

    case InputChange:
      changes = {
        isOpen: true,
        highlightedIndex: getDefaultValue$1(props, 'highlightedIndex'),
        inputValue: action.inputValue
      };
      break;

    case FunctionSelectItem:
      changes = {
        selectedItem: action.selectedItem,
        inputValue: props.itemToString(action.selectedItem)
      };
      break;

    case ControlledPropUpdatedSelectedItem:
      changes = {
        inputValue: action.inputValue
      };
      break;

    default:
      return downshiftCommonReducer(state, action, stateChangeTypes$1);
  }

  return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, state, changes);
}
/* eslint-enable complexity */

var _excluded$1 = ["onMouseLeave", "refKey", "ref"],
    _excluded2$1 = ["item", "index", "refKey", "ref", "onMouseMove", "onClick", "onPress"],
    _excluded3 = ["onClick", "onPress", "refKey", "ref"],
    _excluded4 = ["onKeyDown", "onChange", "onInput", "onBlur", "onChangeText", "refKey", "ref"],
    _excluded5 = ["refKey", "ref"];
useCombobox.stateChangeTypes = stateChangeTypes$1;

function useCombobox(userProps) {
  if (userProps === void 0) {
    userProps = {};
  }

  validatePropTypes$1(userProps, useCombobox); // Props defaults and destructuring.

  var props = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, defaultProps$1, userProps);

  var initialIsOpen = props.initialIsOpen,
      defaultIsOpen = props.defaultIsOpen,
      items = props.items,
      scrollIntoView = props.scrollIntoView,
      environment = props.environment,
      getA11yStatusMessage = props.getA11yStatusMessage,
      getA11ySelectionMessage = props.getA11ySelectionMessage,
      itemToString = props.itemToString; // Initial state depending on controlled props.

  var initialState = getInitialState$1(props);

  var _useControlledReducer = useControlledReducer(downshiftUseComboboxReducer, initialState, props),
      state = _useControlledReducer[0],
      dispatch = _useControlledReducer[1];

  var isOpen = state.isOpen,
      highlightedIndex = state.highlightedIndex,
      selectedItem = state.selectedItem,
      inputValue = state.inputValue; // Element refs.

  var menuRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var itemRefs = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)({});
  var inputRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var toggleButtonRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var comboboxRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var isInitialMountRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(true); // prevent id re-generation between renders.

  var elementIds = useElementIds(props); // used to keep track of how many items we had on previous cycle.

  var previousResultCountRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(); // utility callback to get item element.

  var latest = useLatestRef({
    state: state,
    props: props
  });
  var getItemNodeFromIndex = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (index) {
    return itemRefs.current[elementIds.getItemId(index)];
  }, [elementIds]); // Effects.
  // Sets a11y status message on changes in state.

  useA11yMessageSetter(getA11yStatusMessage, [isOpen, highlightedIndex, inputValue, items], (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
    isInitialMount: isInitialMountRef.current,
    previousResultCount: previousResultCountRef.current,
    items: items,
    environment: environment,
    itemToString: itemToString
  }, state)); // Sets a11y status message on changes in selectedItem.

  useA11yMessageSetter(getA11ySelectionMessage, [selectedItem], (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
    isInitialMount: isInitialMountRef.current,
    previousResultCount: previousResultCountRef.current,
    items: items,
    environment: environment,
    itemToString: itemToString
  }, state)); // Scroll on highlighted item if change comes from keyboard.

  var shouldScrollRef = useScrollIntoView({
    menuElement: menuRef.current,
    highlightedIndex: highlightedIndex,
    isOpen: isOpen,
    itemRefs: itemRefs,
    scrollIntoView: scrollIntoView,
    getItemNodeFromIndex: getItemNodeFromIndex
  });
  useControlPropsValidator({
    isInitialMount: isInitialMountRef.current,
    props: props,
    state: state
  }); // Focus the input on first render if required.

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    var focusOnOpen = initialIsOpen || defaultIsOpen || isOpen;

    if (focusOnOpen && inputRef.current) {
      inputRef.current.focus();
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, []);
  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (isInitialMountRef.current) {
      return;
    }

    previousResultCountRef.current = items.length;
  }); // Add mouse/touch events to document.

  var mouseAndTouchTrackersRef = useMouseAndTouchTracker(isOpen, [comboboxRef, menuRef, toggleButtonRef], environment, function () {
    dispatch({
      type: InputBlur,
      selectItem: false
    });
  });
  var setGetterPropCallInfo = useGetterPropsCalledChecker('getInputProps', 'getComboboxProps', 'getMenuProps'); // Make initial ref false.

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    isInitialMountRef.current = false;
  }, []); // Reset itemRefs on close.

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (!isOpen) {
      itemRefs.current = {};
    }
  }, [isOpen]);
  /* Event handler functions */

  var inputKeyDownHandlers = (0,react__WEBPACK_IMPORTED_MODULE_4__.useMemo)(function () {
    return {
      ArrowDown: function ArrowDown(event) {
        event.preventDefault();
        dispatch({
          type: InputKeyDownArrowDown,
          shiftKey: event.shiftKey,
          getItemNodeFromIndex: getItemNodeFromIndex
        });
      },
      ArrowUp: function ArrowUp(event) {
        event.preventDefault();
        dispatch({
          type: InputKeyDownArrowUp,
          shiftKey: event.shiftKey,
          getItemNodeFromIndex: getItemNodeFromIndex
        });
      },
      Home: function Home(event) {
        if (!latest.current.state.isOpen) {
          return;
        }

        event.preventDefault();
        dispatch({
          type: InputKeyDownHome,
          getItemNodeFromIndex: getItemNodeFromIndex
        });
      },
      End: function End(event) {
        if (!latest.current.state.isOpen) {
          return;
        }

        event.preventDefault();
        dispatch({
          type: InputKeyDownEnd,
          getItemNodeFromIndex: getItemNodeFromIndex
        });
      },
      Escape: function Escape() {
        var latestState = latest.current.state;

        if (latestState.isOpen || latestState.inputValue || latestState.selectedItem || latestState.highlightedIndex > -1) {
          dispatch({
            type: InputKeyDownEscape
          });
        }
      },
      Enter: function Enter(event) {
        var latestState = latest.current.state; // if closed or no highlighted index, do nothing.

        if (!latestState.isOpen || latestState.highlightedIndex < 0 || event.which === 229 // if IME composing, wait for next Enter keydown event.
        ) {
          return;
        }

        event.preventDefault();
        dispatch({
          type: InputKeyDownEnter,
          getItemNodeFromIndex: getItemNodeFromIndex
        });
      }
    };
  }, [dispatch, latest, getItemNodeFromIndex]); // Getter props.

  var getLabelProps = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (labelProps) {
    return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
      id: elementIds.labelId,
      htmlFor: elementIds.inputId
    }, labelProps);
  }, [elementIds]);
  var getMenuProps = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (_temp, _temp2) {
    var _extends2;

    var _ref = _temp === void 0 ? {} : _temp,
        onMouseLeave = _ref.onMouseLeave,
        _ref$refKey = _ref.refKey,
        refKey = _ref$refKey === void 0 ? 'ref' : _ref$refKey,
        ref = _ref.ref,
        rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref, _excluded$1);

    var _ref2 = _temp2 === void 0 ? {} : _temp2,
        _ref2$suppressRefErro = _ref2.suppressRefError,
        suppressRefError = _ref2$suppressRefErro === void 0 ? false : _ref2$suppressRefErro;

    setGetterPropCallInfo('getMenuProps', suppressRefError, refKey, menuRef);
    return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends2 = {}, _extends2[refKey] = handleRefs(ref, function (menuNode) {
      menuRef.current = menuNode;
    }), _extends2.id = elementIds.menuId, _extends2.role = 'listbox', _extends2['aria-labelledby'] = elementIds.labelId, _extends2.onMouseLeave = callAllEventHandlers(onMouseLeave, function () {
      dispatch({
        type: MenuMouseLeave
      });
    }), _extends2), rest);
  }, [dispatch, setGetterPropCallInfo, elementIds]);
  var getItemProps = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (_temp3) {
    var _extends3, _ref4;

    var _ref3 = _temp3 === void 0 ? {} : _temp3,
        item = _ref3.item,
        index = _ref3.index,
        _ref3$refKey = _ref3.refKey,
        refKey = _ref3$refKey === void 0 ? 'ref' : _ref3$refKey,
        ref = _ref3.ref,
        onMouseMove = _ref3.onMouseMove,
        onClick = _ref3.onClick;
        _ref3.onPress;
        var rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref3, _excluded2$1);

    var _latest$current = latest.current,
        latestProps = _latest$current.props,
        latestState = _latest$current.state;
    var itemIndex = getItemIndex(index, item, latestProps.items);

    if (itemIndex < 0) {
      throw new Error('Pass either item or item index in getItemProps!');
    }

    var onSelectKey = 'onClick';
    var customClickHandler = onClick;

    var itemHandleMouseMove = function itemHandleMouseMove() {
      if (index === latestState.highlightedIndex) {
        return;
      }

      shouldScrollRef.current = false;
      dispatch({
        type: ItemMouseMove,
        index: index
      });
    };

    var itemHandleClick = function itemHandleClick() {
      dispatch({
        type: ItemClick,
        index: index
      });

      if (inputRef.current) {
        inputRef.current.focus();
      }
    };

    return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends3 = {}, _extends3[refKey] = handleRefs(ref, function (itemNode) {
      if (itemNode) {
        itemRefs.current[elementIds.getItemId(itemIndex)] = itemNode;
      }
    }), _extends3.role = 'option', _extends3['aria-selected'] = "" + (itemIndex === latestState.highlightedIndex), _extends3.id = elementIds.getItemId(itemIndex), _extends3), !rest.disabled && (_ref4 = {
      onMouseMove: callAllEventHandlers(onMouseMove, itemHandleMouseMove)
    }, _ref4[onSelectKey] = callAllEventHandlers(customClickHandler, itemHandleClick), _ref4), rest);
  }, [dispatch, latest, shouldScrollRef, elementIds]);
  var getToggleButtonProps = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (_temp4) {
    var _extends4;

    var _ref5 = _temp4 === void 0 ? {} : _temp4,
        onClick = _ref5.onClick;
        _ref5.onPress;
        var _ref5$refKey = _ref5.refKey,
        refKey = _ref5$refKey === void 0 ? 'ref' : _ref5$refKey,
        ref = _ref5.ref,
        rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref5, _excluded3);

    var toggleButtonHandleClick = function toggleButtonHandleClick() {
      dispatch({
        type: ToggleButtonClick
      });

      if (!latest.current.state.isOpen && inputRef.current) {
        inputRef.current.focus();
      }
    };

    return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends4 = {}, _extends4[refKey] = handleRefs(ref, function (toggleButtonNode) {
      toggleButtonRef.current = toggleButtonNode;
    }), _extends4.id = elementIds.toggleButtonId, _extends4.tabIndex = -1, _extends4), !rest.disabled && (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, {
      onClick: callAllEventHandlers(onClick, toggleButtonHandleClick)
    }), rest);
  }, [dispatch, latest, elementIds]);
  var getInputProps = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (_temp5, _temp6) {
    var _extends5;

    var _ref6 = _temp5 === void 0 ? {} : _temp5,
        onKeyDown = _ref6.onKeyDown,
        onChange = _ref6.onChange,
        onInput = _ref6.onInput,
        onBlur = _ref6.onBlur;
        _ref6.onChangeText;
        var _ref6$refKey = _ref6.refKey,
        refKey = _ref6$refKey === void 0 ? 'ref' : _ref6$refKey,
        ref = _ref6.ref,
        rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref6, _excluded4);

    var _ref7 = _temp6 === void 0 ? {} : _temp6,
        _ref7$suppressRefErro = _ref7.suppressRefError,
        suppressRefError = _ref7$suppressRefErro === void 0 ? false : _ref7$suppressRefErro;

    setGetterPropCallInfo('getInputProps', suppressRefError, refKey, inputRef);
    var latestState = latest.current.state;

    var inputHandleKeyDown = function inputHandleKeyDown(event) {
      var key = normalizeArrowKey(event);

      if (key && inputKeyDownHandlers[key]) {
        inputKeyDownHandlers[key](event);
      }
    };

    var inputHandleChange = function inputHandleChange(event) {
      dispatch({
        type: InputChange,
        inputValue: event.target.value
      });
    };

    var inputHandleBlur = function inputHandleBlur() {
      /* istanbul ignore else */
      if (latestState.isOpen && !mouseAndTouchTrackersRef.current.isMouseDown) {
        dispatch({
          type: InputBlur,
          selectItem: true
        });
      }
    };
    /* istanbul ignore next (preact) */


    var onChangeKey = 'onChange';
    var eventHandlers = {};

    if (!rest.disabled) {
      var _eventHandlers;

      eventHandlers = (_eventHandlers = {}, _eventHandlers[onChangeKey] = callAllEventHandlers(onChange, onInput, inputHandleChange), _eventHandlers.onKeyDown = callAllEventHandlers(onKeyDown, inputHandleKeyDown), _eventHandlers.onBlur = callAllEventHandlers(onBlur, inputHandleBlur), _eventHandlers);
    }

    return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends5 = {}, _extends5[refKey] = handleRefs(ref, function (inputNode) {
      inputRef.current = inputNode;
    }), _extends5.id = elementIds.inputId, _extends5['aria-autocomplete'] = 'list', _extends5['aria-controls'] = elementIds.menuId, _extends5), latestState.isOpen && latestState.highlightedIndex > -1 && {
      'aria-activedescendant': elementIds.getItemId(latestState.highlightedIndex)
    }, {
      'aria-labelledby': elementIds.labelId,
      // https://developer.mozilla.org/en-US/docs/Web/Security/Securing_your_site/Turning_off_form_autocompletion
      // revert back since autocomplete="nope" is ignored on latest Chrome and Opera
      autoComplete: 'off',
      value: latestState.inputValue
    }, eventHandlers, rest);
  }, [dispatch, inputKeyDownHandlers, latest, mouseAndTouchTrackersRef, setGetterPropCallInfo, elementIds]);
  var getComboboxProps = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (_temp7, _temp8) {
    var _extends6;

    var _ref8 = _temp7 === void 0 ? {} : _temp7,
        _ref8$refKey = _ref8.refKey,
        refKey = _ref8$refKey === void 0 ? 'ref' : _ref8$refKey,
        ref = _ref8.ref,
        rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref8, _excluded5);

    var _ref9 = _temp8 === void 0 ? {} : _temp8,
        _ref9$suppressRefErro = _ref9.suppressRefError,
        suppressRefError = _ref9$suppressRefErro === void 0 ? false : _ref9$suppressRefErro;

    setGetterPropCallInfo('getComboboxProps', suppressRefError, refKey, comboboxRef);
    return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends6 = {}, _extends6[refKey] = handleRefs(ref, function (comboboxNode) {
      comboboxRef.current = comboboxNode;
    }), _extends6.role = 'combobox', _extends6['aria-haspopup'] = 'listbox', _extends6['aria-owns'] = elementIds.menuId, _extends6['aria-expanded'] = latest.current.state.isOpen, _extends6), rest);
  }, [latest, setGetterPropCallInfo, elementIds]); // returns

  var toggleMenu = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function () {
    dispatch({
      type: FunctionToggleMenu
    });
  }, [dispatch]);
  var closeMenu = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function () {
    dispatch({
      type: FunctionCloseMenu
    });
  }, [dispatch]);
  var openMenu = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function () {
    dispatch({
      type: FunctionOpenMenu
    });
  }, [dispatch]);
  var setHighlightedIndex = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (newHighlightedIndex) {
    dispatch({
      type: FunctionSetHighlightedIndex,
      highlightedIndex: newHighlightedIndex
    });
  }, [dispatch]);
  var selectItem = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (newSelectedItem) {
    dispatch({
      type: FunctionSelectItem,
      selectedItem: newSelectedItem
    });
  }, [dispatch]);
  var setInputValue = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (newInputValue) {
    dispatch({
      type: FunctionSetInputValue,
      inputValue: newInputValue
    });
  }, [dispatch]);
  var reset = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function () {
    dispatch({
      type: FunctionReset$1
    });
  }, [dispatch]);
  return {
    // prop getters.
    getItemProps: getItemProps,
    getLabelProps: getLabelProps,
    getMenuProps: getMenuProps,
    getInputProps: getInputProps,
    getComboboxProps: getComboboxProps,
    getToggleButtonProps: getToggleButtonProps,
    // actions.
    toggleMenu: toggleMenu,
    openMenu: openMenu,
    closeMenu: closeMenu,
    setHighlightedIndex: setHighlightedIndex,
    setInputValue: setInputValue,
    selectItem: selectItem,
    reset: reset,
    // state.
    highlightedIndex: highlightedIndex,
    isOpen: isOpen,
    selectedItem: selectedItem,
    inputValue: inputValue
  };
}

var defaultStateValues = {
  activeIndex: -1,
  selectedItems: []
};
/**
 * Returns the initial value for a state key in the following order:
 * 1. controlled prop, 2. initial prop, 3. default prop, 4. default
 * value from Downshift.
 *
 * @param {Object} props Props passed to the hook.
 * @param {string} propKey Props key to generate the value for.
 * @returns {any} The initial value for that prop.
 */

function getInitialValue(props, propKey) {
  return getInitialValue$1(props, propKey, defaultStateValues);
}
/**
 * Returns the default value for a state key in the following order:
 * 1. controlled prop, 2. default prop, 3. default value from Downshift.
 *
 * @param {Object} props Props passed to the hook.
 * @param {string} propKey Props key to generate the value for.
 * @returns {any} The initial value for that prop.
 */


function getDefaultValue(props, propKey) {
  return getDefaultValue$1(props, propKey, defaultStateValues);
}
/**
 * Gets the initial state based on the provided props. It uses initial, default
 * and controlled props related to state in order to compute the initial value.
 *
 * @param {Object} props Props passed to the hook.
 * @returns {Object} The initial state.
 */


function getInitialState(props) {
  var activeIndex = getInitialValue(props, 'activeIndex');
  var selectedItems = getInitialValue(props, 'selectedItems');
  return {
    activeIndex: activeIndex,
    selectedItems: selectedItems
  };
}
/**
 * Returns true if dropdown keydown operation is permitted. Should not be
 * allowed on keydown with modifier keys (ctrl, alt, shift, meta), on
 * input element with text content that is either highlighted or selection
 * cursor is not at the starting position.
 *
 * @param {KeyboardEvent} event The event from keydown.
 * @returns {boolean} Whether the operation is allowed.
 */


function isKeyDownOperationPermitted(event) {
  if (event.shiftKey || event.metaKey || event.ctrlKey || event.altKey) {
    return false;
  }

  var element = event.target;

  if (element instanceof HTMLInputElement && // if element is a text input
  element.value !== '' && (element.selectionStart !== 0 || element.selectionEnd !== 0)) {
    return false;
  }

  return true;
}
/**
 * Returns a message to be added to aria-live region when item is removed.
 *
 * @param {Object} selectionParameters Parameters required to build the message.
 * @returns {string} The a11y message.
 */


function getA11yRemovalMessage(selectionParameters) {
  var removedSelectedItem = selectionParameters.removedSelectedItem,
      itemToStringLocal = selectionParameters.itemToString;
  return itemToStringLocal(removedSelectedItem) + " has been removed.";
}

var propTypes = {
  selectedItems: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().array),
  initialSelectedItems: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().array),
  defaultSelectedItems: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().array),
  itemToString: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  getA11yRemovalMessage: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  stateReducer: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  activeIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  initialActiveIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  defaultActiveIndex: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
  onActiveIndexChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  onSelectedItemsChange: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
  keyNavigationNext: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  keyNavigationPrevious: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
  environment: prop_types__WEBPACK_IMPORTED_MODULE_7___default().shape({
    addEventListener: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    removeEventListener: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    document: prop_types__WEBPACK_IMPORTED_MODULE_7___default().shape({
      getElementById: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
      activeElement: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any),
      body: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().any)
    })
  })
};
var defaultProps = {
  itemToString: defaultProps$3.itemToString,
  stateReducer: defaultProps$3.stateReducer,
  environment: defaultProps$3.environment,
  getA11yRemovalMessage: getA11yRemovalMessage,
  keyNavigationNext: 'ArrowRight',
  keyNavigationPrevious: 'ArrowLeft'
}; // eslint-disable-next-line import/no-mutable-exports

var validatePropTypes = noop;
/* istanbul ignore next */

if (true) {
  validatePropTypes = function validatePropTypes(options, caller) {
    prop_types__WEBPACK_IMPORTED_MODULE_7___default().checkPropTypes(propTypes, options, 'prop', caller.name);
  };
}

var SelectedItemClick =  true ? '__selected_item_click__' : 0;
var SelectedItemKeyDownDelete =  true ? '__selected_item_keydown_delete__' : 0;
var SelectedItemKeyDownBackspace =  true ? '__selected_item_keydown_backspace__' : 0;
var SelectedItemKeyDownNavigationNext =  true ? '__selected_item_keydown_navigation_next__' : 0;
var SelectedItemKeyDownNavigationPrevious =  true ? '__selected_item_keydown_navigation_previous__' : 0;
var DropdownKeyDownNavigationPrevious =  true ? '__dropdown_keydown_navigation_previous__' : 0;
var DropdownKeyDownBackspace =  true ? '__dropdown_keydown_backspace__' : 0;
var DropdownClick =  true ? '__dropdown_click__' : 0;
var FunctionAddSelectedItem =  true ? '__function_add_selected_item__' : 0;
var FunctionRemoveSelectedItem =  true ? '__function_remove_selected_item__' : 0;
var FunctionSetSelectedItems =  true ? '__function_set_selected_items__' : 0;
var FunctionSetActiveIndex =  true ? '__function_set_active_index__' : 0;
var FunctionReset =  true ? '__function_reset__' : 0;

var stateChangeTypes = /*#__PURE__*/Object.freeze({
  __proto__: null,
  SelectedItemClick: SelectedItemClick,
  SelectedItemKeyDownDelete: SelectedItemKeyDownDelete,
  SelectedItemKeyDownBackspace: SelectedItemKeyDownBackspace,
  SelectedItemKeyDownNavigationNext: SelectedItemKeyDownNavigationNext,
  SelectedItemKeyDownNavigationPrevious: SelectedItemKeyDownNavigationPrevious,
  DropdownKeyDownNavigationPrevious: DropdownKeyDownNavigationPrevious,
  DropdownKeyDownBackspace: DropdownKeyDownBackspace,
  DropdownClick: DropdownClick,
  FunctionAddSelectedItem: FunctionAddSelectedItem,
  FunctionRemoveSelectedItem: FunctionRemoveSelectedItem,
  FunctionSetSelectedItems: FunctionSetSelectedItems,
  FunctionSetActiveIndex: FunctionSetActiveIndex,
  FunctionReset: FunctionReset
});

/* eslint-disable complexity */

function downshiftMultipleSelectionReducer(state, action) {
  var type = action.type,
      index = action.index,
      props = action.props,
      selectedItem = action.selectedItem;
  var activeIndex = state.activeIndex,
      selectedItems = state.selectedItems;
  var changes;

  switch (type) {
    case SelectedItemClick:
      changes = {
        activeIndex: index
      };
      break;

    case SelectedItemKeyDownNavigationPrevious:
      changes = {
        activeIndex: activeIndex - 1 < 0 ? 0 : activeIndex - 1
      };
      break;

    case SelectedItemKeyDownNavigationNext:
      changes = {
        activeIndex: activeIndex + 1 >= selectedItems.length ? -1 : activeIndex + 1
      };
      break;

    case SelectedItemKeyDownBackspace:
    case SelectedItemKeyDownDelete:
      {
        var newActiveIndex = activeIndex;

        if (selectedItems.length === 1) {
          newActiveIndex = -1;
        } else if (activeIndex === selectedItems.length - 1) {
          newActiveIndex = selectedItems.length - 2;
        }

        changes = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          selectedItems: [].concat(selectedItems.slice(0, activeIndex), selectedItems.slice(activeIndex + 1))
        }, {
          activeIndex: newActiveIndex
        });
        break;
      }

    case DropdownKeyDownNavigationPrevious:
      changes = {
        activeIndex: selectedItems.length - 1
      };
      break;

    case DropdownKeyDownBackspace:
      changes = {
        selectedItems: selectedItems.slice(0, selectedItems.length - 1)
      };
      break;

    case FunctionAddSelectedItem:
      changes = {
        selectedItems: [].concat(selectedItems, [selectedItem])
      };
      break;

    case DropdownClick:
      changes = {
        activeIndex: -1
      };
      break;

    case FunctionRemoveSelectedItem:
      {
        var _newActiveIndex = activeIndex;
        var selectedItemIndex = selectedItems.indexOf(selectedItem);

        if (selectedItems.length === 1) {
          _newActiveIndex = -1;
        } else if (selectedItemIndex === selectedItems.length - 1) {
          _newActiveIndex = selectedItems.length - 2;
        }

        changes = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({
          selectedItems: [].concat(selectedItems.slice(0, selectedItemIndex), selectedItems.slice(selectedItemIndex + 1))
        }, {
          activeIndex: _newActiveIndex
        });
        break;
      }

    case FunctionSetSelectedItems:
      {
        var newSelectedItems = action.selectedItems;
        changes = {
          selectedItems: newSelectedItems
        };
        break;
      }

    case FunctionSetActiveIndex:
      {
        var _newActiveIndex2 = action.activeIndex;
        changes = {
          activeIndex: _newActiveIndex2
        };
        break;
      }

    case FunctionReset:
      changes = {
        activeIndex: getDefaultValue(props, 'activeIndex'),
        selectedItems: getDefaultValue(props, 'selectedItems')
      };
      break;

    default:
      throw new Error('Reducer called without proper action type.');
  }

  return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, state, changes);
}

var _excluded = ["refKey", "ref", "onClick", "onKeyDown", "selectedItem", "index"],
    _excluded2 = ["refKey", "ref", "onKeyDown", "onClick", "preventKeyAction"];
useMultipleSelection.stateChangeTypes = stateChangeTypes;

function useMultipleSelection(userProps) {
  if (userProps === void 0) {
    userProps = {};
  }

  validatePropTypes(userProps, useMultipleSelection); // Props defaults and destructuring.

  var props = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])({}, defaultProps, userProps);

  var getA11yRemovalMessage = props.getA11yRemovalMessage,
      itemToString = props.itemToString,
      environment = props.environment,
      keyNavigationNext = props.keyNavigationNext,
      keyNavigationPrevious = props.keyNavigationPrevious; // Reducer init.

  var _useControlledReducer = useControlledReducer$1(downshiftMultipleSelectionReducer, getInitialState(props), props),
      state = _useControlledReducer[0],
      dispatch = _useControlledReducer[1];

  var activeIndex = state.activeIndex,
      selectedItems = state.selectedItems; // Refs.

  var isInitialMountRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(true);
  var dropdownRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(null);
  var previousSelectedItemsRef = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)(selectedItems);
  var selectedItemRefs = (0,react__WEBPACK_IMPORTED_MODULE_4__.useRef)();
  selectedItemRefs.current = [];
  var latest = useLatestRef({
    state: state,
    props: props
  }); // Effects.

  /* Sets a11y status message on changes in selectedItem. */

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (isInitialMountRef.current) {
      return;
    }

    if (selectedItems.length < previousSelectedItemsRef.current.length) {
      var removedSelectedItem = previousSelectedItemsRef.current.find(function (item) {
        return selectedItems.indexOf(item) < 0;
      });
      setStatus(getA11yRemovalMessage({
        itemToString: itemToString,
        resultCount: selectedItems.length,
        removedSelectedItem: removedSelectedItem,
        activeIndex: activeIndex,
        activeSelectedItem: selectedItems[activeIndex]
      }), environment.document);
    }

    previousSelectedItemsRef.current = selectedItems; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [selectedItems.length]); // Sets focus on active item.

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    if (isInitialMountRef.current) {
      return;
    }

    if (activeIndex === -1 && dropdownRef.current) {
      dropdownRef.current.focus();
    } else if (selectedItemRefs.current[activeIndex]) {
      selectedItemRefs.current[activeIndex].focus();
    }
  }, [activeIndex]);
  useControlPropsValidator({
    isInitialMount: isInitialMountRef.current,
    props: props,
    state: state
  });
  var setGetterPropCallInfo = useGetterPropsCalledChecker('getDropdownProps'); // Make initial ref false.

  (0,react__WEBPACK_IMPORTED_MODULE_4__.useEffect)(function () {
    isInitialMountRef.current = false;
  }, []); // Event handler functions.

  var selectedItemKeyDownHandlers = (0,react__WEBPACK_IMPORTED_MODULE_4__.useMemo)(function () {
    var _ref;

    return _ref = {}, _ref[keyNavigationPrevious] = function () {
      dispatch({
        type: SelectedItemKeyDownNavigationPrevious
      });
    }, _ref[keyNavigationNext] = function () {
      dispatch({
        type: SelectedItemKeyDownNavigationNext
      });
    }, _ref.Delete = function Delete() {
      dispatch({
        type: SelectedItemKeyDownDelete
      });
    }, _ref.Backspace = function Backspace() {
      dispatch({
        type: SelectedItemKeyDownBackspace
      });
    }, _ref;
  }, [dispatch, keyNavigationNext, keyNavigationPrevious]);
  var dropdownKeyDownHandlers = (0,react__WEBPACK_IMPORTED_MODULE_4__.useMemo)(function () {
    var _ref2;

    return _ref2 = {}, _ref2[keyNavigationPrevious] = function (event) {
      if (isKeyDownOperationPermitted(event)) {
        dispatch({
          type: DropdownKeyDownNavigationPrevious
        });
      }
    }, _ref2.Backspace = function Backspace(event) {
      if (isKeyDownOperationPermitted(event)) {
        dispatch({
          type: DropdownKeyDownBackspace
        });
      }
    }, _ref2;
  }, [dispatch, keyNavigationPrevious]); // Getter props.

  var getSelectedItemProps = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (_temp) {
    var _extends2;

    var _ref3 = _temp === void 0 ? {} : _temp,
        _ref3$refKey = _ref3.refKey,
        refKey = _ref3$refKey === void 0 ? 'ref' : _ref3$refKey,
        ref = _ref3.ref,
        onClick = _ref3.onClick,
        onKeyDown = _ref3.onKeyDown,
        selectedItem = _ref3.selectedItem,
        index = _ref3.index,
        rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref3, _excluded);

    var latestState = latest.current.state;
    var itemIndex = getItemIndex(index, selectedItem, latestState.selectedItems);

    if (itemIndex < 0) {
      throw new Error('Pass either selectedItem or index in getSelectedItemProps!');
    }

    var selectedItemHandleClick = function selectedItemHandleClick() {
      dispatch({
        type: SelectedItemClick,
        index: index
      });
    };

    var selectedItemHandleKeyDown = function selectedItemHandleKeyDown(event) {
      var key = normalizeArrowKey(event);

      if (key && selectedItemKeyDownHandlers[key]) {
        selectedItemKeyDownHandlers[key](event);
      }
    };

    return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends2 = {}, _extends2[refKey] = handleRefs(ref, function (selectedItemNode) {
      if (selectedItemNode) {
        selectedItemRefs.current.push(selectedItemNode);
      }
    }), _extends2.tabIndex = index === latestState.activeIndex ? 0 : -1, _extends2.onClick = callAllEventHandlers(onClick, selectedItemHandleClick), _extends2.onKeyDown = callAllEventHandlers(onKeyDown, selectedItemHandleKeyDown), _extends2), rest);
  }, [dispatch, latest, selectedItemKeyDownHandlers]);
  var getDropdownProps = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (_temp2, _temp3) {
    var _extends3;

    var _ref4 = _temp2 === void 0 ? {} : _temp2,
        _ref4$refKey = _ref4.refKey,
        refKey = _ref4$refKey === void 0 ? 'ref' : _ref4$refKey,
        ref = _ref4.ref,
        onKeyDown = _ref4.onKeyDown,
        onClick = _ref4.onClick,
        _ref4$preventKeyActio = _ref4.preventKeyAction,
        preventKeyAction = _ref4$preventKeyActio === void 0 ? false : _ref4$preventKeyActio,
        rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref4, _excluded2);

    var _ref5 = _temp3 === void 0 ? {} : _temp3,
        _ref5$suppressRefErro = _ref5.suppressRefError,
        suppressRefError = _ref5$suppressRefErro === void 0 ? false : _ref5$suppressRefErro;

    setGetterPropCallInfo('getDropdownProps', suppressRefError, refKey, dropdownRef);

    var dropdownHandleKeyDown = function dropdownHandleKeyDown(event) {
      var key = normalizeArrowKey(event);

      if (key && dropdownKeyDownHandlers[key]) {
        dropdownKeyDownHandlers[key](event);
      }
    };

    var dropdownHandleClick = function dropdownHandleClick() {
      dispatch({
        type: DropdownClick
      });
    };

    return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__["default"])((_extends3 = {}, _extends3[refKey] = handleRefs(ref, function (dropdownNode) {
      if (dropdownNode) {
        dropdownRef.current = dropdownNode;
      }
    }), _extends3), !preventKeyAction && {
      onKeyDown: callAllEventHandlers(onKeyDown, dropdownHandleKeyDown),
      onClick: callAllEventHandlers(onClick, dropdownHandleClick)
    }, rest);
  }, [dispatch, dropdownKeyDownHandlers, setGetterPropCallInfo]); // returns

  var addSelectedItem = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (selectedItem) {
    dispatch({
      type: FunctionAddSelectedItem,
      selectedItem: selectedItem
    });
  }, [dispatch]);
  var removeSelectedItem = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (selectedItem) {
    dispatch({
      type: FunctionRemoveSelectedItem,
      selectedItem: selectedItem
    });
  }, [dispatch]);
  var setSelectedItems = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (newSelectedItems) {
    dispatch({
      type: FunctionSetSelectedItems,
      selectedItems: newSelectedItems
    });
  }, [dispatch]);
  var setActiveIndex = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function (newActiveIndex) {
    dispatch({
      type: FunctionSetActiveIndex,
      activeIndex: newActiveIndex
    });
  }, [dispatch]);
  var reset = (0,react__WEBPACK_IMPORTED_MODULE_4__.useCallback)(function () {
    dispatch({
      type: FunctionReset
    });
  }, [dispatch]);
  return {
    getSelectedItemProps: getSelectedItemProps,
    getDropdownProps: getDropdownProps,
    addSelectedItem: addSelectedItem,
    removeSelectedItem: removeSelectedItem,
    setSelectedItems: setSelectedItems,
    setActiveIndex: setActiveIndex,
    reset: reset,
    selectedItems: selectedItems,
    activeIndex: activeIndex
  };
}




/***/ }),

/***/ "../../node_modules/exenv/index.js":
/*!*****************************************!*\
  !*** ../../node_modules/exenv/index.js ***!
  \*****************************************/
/***/ ((module, exports, __webpack_require__) => {

var __WEBPACK_AMD_DEFINE_RESULT__;/*!
  Copyright (c) 2015 Jed Watson.
  Based on code that is Copyright 2013-2015, Facebook, Inc.
  All rights reserved.
*/
/* global define */

(function () {
	'use strict';

	var canUseDOM = !!(
		typeof window !== 'undefined' &&
		window.document &&
		window.document.createElement
	);

	var ExecutionEnvironment = {

		canUseDOM: canUseDOM,

		canUseWorkers: typeof Worker !== 'undefined',

		canUseEventListeners:
			canUseDOM && !!(window.addEventListener || window.attachEvent),

		canUseViewport: canUseDOM && !!window.screen

	};

	if (true) {
		!(__WEBPACK_AMD_DEFINE_RESULT__ = (function () {
			return ExecutionEnvironment;
		}).call(exports, __webpack_require__, exports, module),
		__WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	} else {}

}());


/***/ }),

/***/ "../../node_modules/immutable/dist/immutable.es.js":
/*!*********************************************************!*\
  !*** ../../node_modules/immutable/dist/immutable.es.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Collection": () => (/* binding */ Collection),
/* harmony export */   "Iterable": () => (/* binding */ Iterable),
/* harmony export */   "List": () => (/* binding */ List),
/* harmony export */   "Map": () => (/* binding */ Map),
/* harmony export */   "OrderedMap": () => (/* binding */ OrderedMap),
/* harmony export */   "OrderedSet": () => (/* binding */ OrderedSet),
/* harmony export */   "Range": () => (/* binding */ Range),
/* harmony export */   "Record": () => (/* binding */ Record),
/* harmony export */   "Repeat": () => (/* binding */ Repeat),
/* harmony export */   "Seq": () => (/* binding */ Seq),
/* harmony export */   "Set": () => (/* binding */ Set),
/* harmony export */   "Stack": () => (/* binding */ Stack),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__),
/* harmony export */   "fromJS": () => (/* binding */ fromJS),
/* harmony export */   "get": () => (/* binding */ get),
/* harmony export */   "getIn": () => (/* binding */ getIn$1),
/* harmony export */   "has": () => (/* binding */ has),
/* harmony export */   "hasIn": () => (/* binding */ hasIn$1),
/* harmony export */   "hash": () => (/* binding */ hash),
/* harmony export */   "is": () => (/* binding */ is),
/* harmony export */   "isAssociative": () => (/* binding */ isAssociative),
/* harmony export */   "isCollection": () => (/* binding */ isCollection),
/* harmony export */   "isImmutable": () => (/* binding */ isImmutable),
/* harmony export */   "isIndexed": () => (/* binding */ isIndexed),
/* harmony export */   "isKeyed": () => (/* binding */ isKeyed),
/* harmony export */   "isList": () => (/* binding */ isList),
/* harmony export */   "isMap": () => (/* binding */ isMap),
/* harmony export */   "isOrdered": () => (/* binding */ isOrdered),
/* harmony export */   "isOrderedMap": () => (/* binding */ isOrderedMap),
/* harmony export */   "isOrderedSet": () => (/* binding */ isOrderedSet),
/* harmony export */   "isPlainObject": () => (/* binding */ isPlainObject),
/* harmony export */   "isRecord": () => (/* binding */ isRecord),
/* harmony export */   "isSeq": () => (/* binding */ isSeq),
/* harmony export */   "isSet": () => (/* binding */ isSet),
/* harmony export */   "isStack": () => (/* binding */ isStack),
/* harmony export */   "isValueObject": () => (/* binding */ isValueObject),
/* harmony export */   "merge": () => (/* binding */ merge),
/* harmony export */   "mergeDeep": () => (/* binding */ mergeDeep$1),
/* harmony export */   "mergeDeepWith": () => (/* binding */ mergeDeepWith$1),
/* harmony export */   "mergeWith": () => (/* binding */ mergeWith),
/* harmony export */   "remove": () => (/* binding */ remove),
/* harmony export */   "removeIn": () => (/* binding */ removeIn),
/* harmony export */   "set": () => (/* binding */ set),
/* harmony export */   "setIn": () => (/* binding */ setIn$1),
/* harmony export */   "update": () => (/* binding */ update$1),
/* harmony export */   "updateIn": () => (/* binding */ updateIn$1),
/* harmony export */   "version": () => (/* binding */ version)
/* harmony export */ });
/**
 * MIT License
 * 
 * Copyright (c) 2014-present, Lee Byron and other contributors.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
var DELETE = 'delete';

// Constants describing the size of trie nodes.
var SHIFT = 5; // Resulted in best performance after ______?
var SIZE = 1 << SHIFT;
var MASK = SIZE - 1;

// A consistent shared value representing "not set" which equals nothing other
// than itself, and nothing that could be provided externally.
var NOT_SET = {};

// Boolean references, Rough equivalent of `bool &`.
function MakeRef() {
  return { value: false };
}

function SetRef(ref) {
  if (ref) {
    ref.value = true;
  }
}

// A function which returns a value representing an "owner" for transient writes
// to tries. The return value will only ever equal itself, and will not equal
// the return of any subsequent call of this function.
function OwnerID() {}

function ensureSize(iter) {
  if (iter.size === undefined) {
    iter.size = iter.__iterate(returnTrue);
  }
  return iter.size;
}

function wrapIndex(iter, index) {
  // This implements "is array index" which the ECMAString spec defines as:
  //
  //     A String property name P is an array index if and only if
  //     ToString(ToUint32(P)) is equal to P and ToUint32(P) is not equal
  //     to 2^32−1.
  //
  // http://www.ecma-international.org/ecma-262/6.0/#sec-array-exotic-objects
  if (typeof index !== 'number') {
    var uint32Index = index >>> 0; // N >>> 0 is shorthand for ToUint32
    if ('' + uint32Index !== index || uint32Index === 4294967295) {
      return NaN;
    }
    index = uint32Index;
  }
  return index < 0 ? ensureSize(iter) + index : index;
}

function returnTrue() {
  return true;
}

function wholeSlice(begin, end, size) {
  return (
    ((begin === 0 && !isNeg(begin)) ||
      (size !== undefined && begin <= -size)) &&
    (end === undefined || (size !== undefined && end >= size))
  );
}

function resolveBegin(begin, size) {
  return resolveIndex(begin, size, 0);
}

function resolveEnd(end, size) {
  return resolveIndex(end, size, size);
}

function resolveIndex(index, size, defaultIndex) {
  // Sanitize indices using this shorthand for ToInt32(argument)
  // http://www.ecma-international.org/ecma-262/6.0/#sec-toint32
  return index === undefined
    ? defaultIndex
    : isNeg(index)
    ? size === Infinity
      ? size
      : Math.max(0, size + index) | 0
    : size === undefined || size === index
    ? index
    : Math.min(size, index) | 0;
}

function isNeg(value) {
  // Account for -0 which is negative, but not less than 0.
  return value < 0 || (value === 0 && 1 / value === -Infinity);
}

var IS_COLLECTION_SYMBOL = '@@__IMMUTABLE_ITERABLE__@@';

function isCollection(maybeCollection) {
  return Boolean(maybeCollection && maybeCollection[IS_COLLECTION_SYMBOL]);
}

var IS_KEYED_SYMBOL = '@@__IMMUTABLE_KEYED__@@';

function isKeyed(maybeKeyed) {
  return Boolean(maybeKeyed && maybeKeyed[IS_KEYED_SYMBOL]);
}

var IS_INDEXED_SYMBOL = '@@__IMMUTABLE_INDEXED__@@';

function isIndexed(maybeIndexed) {
  return Boolean(maybeIndexed && maybeIndexed[IS_INDEXED_SYMBOL]);
}

function isAssociative(maybeAssociative) {
  return isKeyed(maybeAssociative) || isIndexed(maybeAssociative);
}

var Collection = function Collection(value) {
  return isCollection(value) ? value : Seq(value);
};

var KeyedCollection = /*@__PURE__*/(function (Collection) {
  function KeyedCollection(value) {
    return isKeyed(value) ? value : KeyedSeq(value);
  }

  if ( Collection ) KeyedCollection.__proto__ = Collection;
  KeyedCollection.prototype = Object.create( Collection && Collection.prototype );
  KeyedCollection.prototype.constructor = KeyedCollection;

  return KeyedCollection;
}(Collection));

var IndexedCollection = /*@__PURE__*/(function (Collection) {
  function IndexedCollection(value) {
    return isIndexed(value) ? value : IndexedSeq(value);
  }

  if ( Collection ) IndexedCollection.__proto__ = Collection;
  IndexedCollection.prototype = Object.create( Collection && Collection.prototype );
  IndexedCollection.prototype.constructor = IndexedCollection;

  return IndexedCollection;
}(Collection));

var SetCollection = /*@__PURE__*/(function (Collection) {
  function SetCollection(value) {
    return isCollection(value) && !isAssociative(value) ? value : SetSeq(value);
  }

  if ( Collection ) SetCollection.__proto__ = Collection;
  SetCollection.prototype = Object.create( Collection && Collection.prototype );
  SetCollection.prototype.constructor = SetCollection;

  return SetCollection;
}(Collection));

Collection.Keyed = KeyedCollection;
Collection.Indexed = IndexedCollection;
Collection.Set = SetCollection;

var IS_SEQ_SYMBOL = '@@__IMMUTABLE_SEQ__@@';

function isSeq(maybeSeq) {
  return Boolean(maybeSeq && maybeSeq[IS_SEQ_SYMBOL]);
}

var IS_RECORD_SYMBOL = '@@__IMMUTABLE_RECORD__@@';

function isRecord(maybeRecord) {
  return Boolean(maybeRecord && maybeRecord[IS_RECORD_SYMBOL]);
}

function isImmutable(maybeImmutable) {
  return isCollection(maybeImmutable) || isRecord(maybeImmutable);
}

var IS_ORDERED_SYMBOL = '@@__IMMUTABLE_ORDERED__@@';

function isOrdered(maybeOrdered) {
  return Boolean(maybeOrdered && maybeOrdered[IS_ORDERED_SYMBOL]);
}

var ITERATE_KEYS = 0;
var ITERATE_VALUES = 1;
var ITERATE_ENTRIES = 2;

var REAL_ITERATOR_SYMBOL = typeof Symbol === 'function' && Symbol.iterator;
var FAUX_ITERATOR_SYMBOL = '@@iterator';

var ITERATOR_SYMBOL = REAL_ITERATOR_SYMBOL || FAUX_ITERATOR_SYMBOL;

var Iterator = function Iterator(next) {
  this.next = next;
};

Iterator.prototype.toString = function toString () {
  return '[Iterator]';
};

Iterator.KEYS = ITERATE_KEYS;
Iterator.VALUES = ITERATE_VALUES;
Iterator.ENTRIES = ITERATE_ENTRIES;

Iterator.prototype.inspect = Iterator.prototype.toSource = function () {
  return this.toString();
};
Iterator.prototype[ITERATOR_SYMBOL] = function () {
  return this;
};

function iteratorValue(type, k, v, iteratorResult) {
  var value = type === 0 ? k : type === 1 ? v : [k, v];
  iteratorResult
    ? (iteratorResult.value = value)
    : (iteratorResult = {
        value: value,
        done: false,
      });
  return iteratorResult;
}

function iteratorDone() {
  return { value: undefined, done: true };
}

function hasIterator(maybeIterable) {
  if (Array.isArray(maybeIterable)) {
    // IE11 trick as it does not support `Symbol.iterator`
    return true;
  }

  return !!getIteratorFn(maybeIterable);
}

function isIterator(maybeIterator) {
  return maybeIterator && typeof maybeIterator.next === 'function';
}

function getIterator(iterable) {
  var iteratorFn = getIteratorFn(iterable);
  return iteratorFn && iteratorFn.call(iterable);
}

function getIteratorFn(iterable) {
  var iteratorFn =
    iterable &&
    ((REAL_ITERATOR_SYMBOL && iterable[REAL_ITERATOR_SYMBOL]) ||
      iterable[FAUX_ITERATOR_SYMBOL]);
  if (typeof iteratorFn === 'function') {
    return iteratorFn;
  }
}

function isEntriesIterable(maybeIterable) {
  var iteratorFn = getIteratorFn(maybeIterable);
  return iteratorFn && iteratorFn === maybeIterable.entries;
}

function isKeysIterable(maybeIterable) {
  var iteratorFn = getIteratorFn(maybeIterable);
  return iteratorFn && iteratorFn === maybeIterable.keys;
}

var hasOwnProperty = Object.prototype.hasOwnProperty;

function isArrayLike(value) {
  if (Array.isArray(value) || typeof value === 'string') {
    return true;
  }

  return (
    value &&
    typeof value === 'object' &&
    Number.isInteger(value.length) &&
    value.length >= 0 &&
    (value.length === 0
      ? // Only {length: 0} is considered Array-like.
        Object.keys(value).length === 1
      : // An object is only Array-like if it has a property where the last value
        // in the array-like may be found (which could be undefined).
        value.hasOwnProperty(value.length - 1))
  );
}

var Seq = /*@__PURE__*/(function (Collection) {
  function Seq(value) {
    return value === null || value === undefined
      ? emptySequence()
      : isImmutable(value)
      ? value.toSeq()
      : seqFromValue(value);
  }

  if ( Collection ) Seq.__proto__ = Collection;
  Seq.prototype = Object.create( Collection && Collection.prototype );
  Seq.prototype.constructor = Seq;

  Seq.prototype.toSeq = function toSeq () {
    return this;
  };

  Seq.prototype.toString = function toString () {
    return this.__toString('Seq {', '}');
  };

  Seq.prototype.cacheResult = function cacheResult () {
    if (!this._cache && this.__iterateUncached) {
      this._cache = this.entrySeq().toArray();
      this.size = this._cache.length;
    }
    return this;
  };

  // abstract __iterateUncached(fn, reverse)

  Seq.prototype.__iterate = function __iterate (fn, reverse) {
    var cache = this._cache;
    if (cache) {
      var size = cache.length;
      var i = 0;
      while (i !== size) {
        var entry = cache[reverse ? size - ++i : i++];
        if (fn(entry[1], entry[0], this) === false) {
          break;
        }
      }
      return i;
    }
    return this.__iterateUncached(fn, reverse);
  };

  // abstract __iteratorUncached(type, reverse)

  Seq.prototype.__iterator = function __iterator (type, reverse) {
    var cache = this._cache;
    if (cache) {
      var size = cache.length;
      var i = 0;
      return new Iterator(function () {
        if (i === size) {
          return iteratorDone();
        }
        var entry = cache[reverse ? size - ++i : i++];
        return iteratorValue(type, entry[0], entry[1]);
      });
    }
    return this.__iteratorUncached(type, reverse);
  };

  return Seq;
}(Collection));

var KeyedSeq = /*@__PURE__*/(function (Seq) {
  function KeyedSeq(value) {
    return value === null || value === undefined
      ? emptySequence().toKeyedSeq()
      : isCollection(value)
      ? isKeyed(value)
        ? value.toSeq()
        : value.fromEntrySeq()
      : isRecord(value)
      ? value.toSeq()
      : keyedSeqFromValue(value);
  }

  if ( Seq ) KeyedSeq.__proto__ = Seq;
  KeyedSeq.prototype = Object.create( Seq && Seq.prototype );
  KeyedSeq.prototype.constructor = KeyedSeq;

  KeyedSeq.prototype.toKeyedSeq = function toKeyedSeq () {
    return this;
  };

  return KeyedSeq;
}(Seq));

var IndexedSeq = /*@__PURE__*/(function (Seq) {
  function IndexedSeq(value) {
    return value === null || value === undefined
      ? emptySequence()
      : isCollection(value)
      ? isKeyed(value)
        ? value.entrySeq()
        : value.toIndexedSeq()
      : isRecord(value)
      ? value.toSeq().entrySeq()
      : indexedSeqFromValue(value);
  }

  if ( Seq ) IndexedSeq.__proto__ = Seq;
  IndexedSeq.prototype = Object.create( Seq && Seq.prototype );
  IndexedSeq.prototype.constructor = IndexedSeq;

  IndexedSeq.of = function of (/*...values*/) {
    return IndexedSeq(arguments);
  };

  IndexedSeq.prototype.toIndexedSeq = function toIndexedSeq () {
    return this;
  };

  IndexedSeq.prototype.toString = function toString () {
    return this.__toString('Seq [', ']');
  };

  return IndexedSeq;
}(Seq));

var SetSeq = /*@__PURE__*/(function (Seq) {
  function SetSeq(value) {
    return (
      isCollection(value) && !isAssociative(value) ? value : IndexedSeq(value)
    ).toSetSeq();
  }

  if ( Seq ) SetSeq.__proto__ = Seq;
  SetSeq.prototype = Object.create( Seq && Seq.prototype );
  SetSeq.prototype.constructor = SetSeq;

  SetSeq.of = function of (/*...values*/) {
    return SetSeq(arguments);
  };

  SetSeq.prototype.toSetSeq = function toSetSeq () {
    return this;
  };

  return SetSeq;
}(Seq));

Seq.isSeq = isSeq;
Seq.Keyed = KeyedSeq;
Seq.Set = SetSeq;
Seq.Indexed = IndexedSeq;

Seq.prototype[IS_SEQ_SYMBOL] = true;

// #pragma Root Sequences

var ArraySeq = /*@__PURE__*/(function (IndexedSeq) {
  function ArraySeq(array) {
    this._array = array;
    this.size = array.length;
  }

  if ( IndexedSeq ) ArraySeq.__proto__ = IndexedSeq;
  ArraySeq.prototype = Object.create( IndexedSeq && IndexedSeq.prototype );
  ArraySeq.prototype.constructor = ArraySeq;

  ArraySeq.prototype.get = function get (index, notSetValue) {
    return this.has(index) ? this._array[wrapIndex(this, index)] : notSetValue;
  };

  ArraySeq.prototype.__iterate = function __iterate (fn, reverse) {
    var array = this._array;
    var size = array.length;
    var i = 0;
    while (i !== size) {
      var ii = reverse ? size - ++i : i++;
      if (fn(array[ii], ii, this) === false) {
        break;
      }
    }
    return i;
  };

  ArraySeq.prototype.__iterator = function __iterator (type, reverse) {
    var array = this._array;
    var size = array.length;
    var i = 0;
    return new Iterator(function () {
      if (i === size) {
        return iteratorDone();
      }
      var ii = reverse ? size - ++i : i++;
      return iteratorValue(type, ii, array[ii]);
    });
  };

  return ArraySeq;
}(IndexedSeq));

var ObjectSeq = /*@__PURE__*/(function (KeyedSeq) {
  function ObjectSeq(object) {
    var keys = Object.keys(object);
    this._object = object;
    this._keys = keys;
    this.size = keys.length;
  }

  if ( KeyedSeq ) ObjectSeq.__proto__ = KeyedSeq;
  ObjectSeq.prototype = Object.create( KeyedSeq && KeyedSeq.prototype );
  ObjectSeq.prototype.constructor = ObjectSeq;

  ObjectSeq.prototype.get = function get (key, notSetValue) {
    if (notSetValue !== undefined && !this.has(key)) {
      return notSetValue;
    }
    return this._object[key];
  };

  ObjectSeq.prototype.has = function has (key) {
    return hasOwnProperty.call(this._object, key);
  };

  ObjectSeq.prototype.__iterate = function __iterate (fn, reverse) {
    var object = this._object;
    var keys = this._keys;
    var size = keys.length;
    var i = 0;
    while (i !== size) {
      var key = keys[reverse ? size - ++i : i++];
      if (fn(object[key], key, this) === false) {
        break;
      }
    }
    return i;
  };

  ObjectSeq.prototype.__iterator = function __iterator (type, reverse) {
    var object = this._object;
    var keys = this._keys;
    var size = keys.length;
    var i = 0;
    return new Iterator(function () {
      if (i === size) {
        return iteratorDone();
      }
      var key = keys[reverse ? size - ++i : i++];
      return iteratorValue(type, key, object[key]);
    });
  };

  return ObjectSeq;
}(KeyedSeq));
ObjectSeq.prototype[IS_ORDERED_SYMBOL] = true;

var CollectionSeq = /*@__PURE__*/(function (IndexedSeq) {
  function CollectionSeq(collection) {
    this._collection = collection;
    this.size = collection.length || collection.size;
  }

  if ( IndexedSeq ) CollectionSeq.__proto__ = IndexedSeq;
  CollectionSeq.prototype = Object.create( IndexedSeq && IndexedSeq.prototype );
  CollectionSeq.prototype.constructor = CollectionSeq;

  CollectionSeq.prototype.__iterateUncached = function __iterateUncached (fn, reverse) {
    if (reverse) {
      return this.cacheResult().__iterate(fn, reverse);
    }
    var collection = this._collection;
    var iterator = getIterator(collection);
    var iterations = 0;
    if (isIterator(iterator)) {
      var step;
      while (!(step = iterator.next()).done) {
        if (fn(step.value, iterations++, this) === false) {
          break;
        }
      }
    }
    return iterations;
  };

  CollectionSeq.prototype.__iteratorUncached = function __iteratorUncached (type, reverse) {
    if (reverse) {
      return this.cacheResult().__iterator(type, reverse);
    }
    var collection = this._collection;
    var iterator = getIterator(collection);
    if (!isIterator(iterator)) {
      return new Iterator(iteratorDone);
    }
    var iterations = 0;
    return new Iterator(function () {
      var step = iterator.next();
      return step.done ? step : iteratorValue(type, iterations++, step.value);
    });
  };

  return CollectionSeq;
}(IndexedSeq));

// # pragma Helper functions

var EMPTY_SEQ;

function emptySequence() {
  return EMPTY_SEQ || (EMPTY_SEQ = new ArraySeq([]));
}

function keyedSeqFromValue(value) {
  var seq = maybeIndexedSeqFromValue(value);
  if (seq) {
    return seq.fromEntrySeq();
  }
  if (typeof value === 'object') {
    return new ObjectSeq(value);
  }
  throw new TypeError(
    'Expected Array or collection object of [k, v] entries, or keyed object: ' +
      value
  );
}

function indexedSeqFromValue(value) {
  var seq = maybeIndexedSeqFromValue(value);
  if (seq) {
    return seq;
  }
  throw new TypeError(
    'Expected Array or collection object of values: ' + value
  );
}

function seqFromValue(value) {
  var seq = maybeIndexedSeqFromValue(value);
  if (seq) {
    return isEntriesIterable(value)
      ? seq.fromEntrySeq()
      : isKeysIterable(value)
      ? seq.toSetSeq()
      : seq;
  }
  if (typeof value === 'object') {
    return new ObjectSeq(value);
  }
  throw new TypeError(
    'Expected Array or collection object of values, or keyed object: ' + value
  );
}

function maybeIndexedSeqFromValue(value) {
  return isArrayLike(value)
    ? new ArraySeq(value)
    : hasIterator(value)
    ? new CollectionSeq(value)
    : undefined;
}

var IS_MAP_SYMBOL = '@@__IMMUTABLE_MAP__@@';

function isMap(maybeMap) {
  return Boolean(maybeMap && maybeMap[IS_MAP_SYMBOL]);
}

function isOrderedMap(maybeOrderedMap) {
  return isMap(maybeOrderedMap) && isOrdered(maybeOrderedMap);
}

function isValueObject(maybeValue) {
  return Boolean(
    maybeValue &&
      typeof maybeValue.equals === 'function' &&
      typeof maybeValue.hashCode === 'function'
  );
}

/**
 * An extension of the "same-value" algorithm as [described for use by ES6 Map
 * and Set](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Map#Key_equality)
 *
 * NaN is considered the same as NaN, however -0 and 0 are considered the same
 * value, which is different from the algorithm described by
 * [`Object.is`](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/is).
 *
 * This is extended further to allow Objects to describe the values they
 * represent, by way of `valueOf` or `equals` (and `hashCode`).
 *
 * Note: because of this extension, the key equality of Immutable.Map and the
 * value equality of Immutable.Set will differ from ES6 Map and Set.
 *
 * ### Defining custom values
 *
 * The easiest way to describe the value an object represents is by implementing
 * `valueOf`. For example, `Date` represents a value by returning a unix
 * timestamp for `valueOf`:
 *
 *     var date1 = new Date(1234567890000); // Fri Feb 13 2009 ...
 *     var date2 = new Date(1234567890000);
 *     date1.valueOf(); // 1234567890000
 *     assert( date1 !== date2 );
 *     assert( Immutable.is( date1, date2 ) );
 *
 * Note: overriding `valueOf` may have other implications if you use this object
 * where JavaScript expects a primitive, such as implicit string coercion.
 *
 * For more complex types, especially collections, implementing `valueOf` may
 * not be performant. An alternative is to implement `equals` and `hashCode`.
 *
 * `equals` takes another object, presumably of similar type, and returns true
 * if it is equal. Equality is symmetrical, so the same result should be
 * returned if this and the argument are flipped.
 *
 *     assert( a.equals(b) === b.equals(a) );
 *
 * `hashCode` returns a 32bit integer number representing the object which will
 * be used to determine how to store the value object in a Map or Set. You must
 * provide both or neither methods, one must not exist without the other.
 *
 * Also, an important relationship between these methods must be upheld: if two
 * values are equal, they *must* return the same hashCode. If the values are not
 * equal, they might have the same hashCode; this is called a hash collision,
 * and while undesirable for performance reasons, it is acceptable.
 *
 *     if (a.equals(b)) {
 *       assert( a.hashCode() === b.hashCode() );
 *     }
 *
 * All Immutable collections are Value Objects: they implement `equals()`
 * and `hashCode()`.
 */
function is(valueA, valueB) {
  if (valueA === valueB || (valueA !== valueA && valueB !== valueB)) {
    return true;
  }
  if (!valueA || !valueB) {
    return false;
  }
  if (
    typeof valueA.valueOf === 'function' &&
    typeof valueB.valueOf === 'function'
  ) {
    valueA = valueA.valueOf();
    valueB = valueB.valueOf();
    if (valueA === valueB || (valueA !== valueA && valueB !== valueB)) {
      return true;
    }
    if (!valueA || !valueB) {
      return false;
    }
  }
  return !!(
    isValueObject(valueA) &&
    isValueObject(valueB) &&
    valueA.equals(valueB)
  );
}

var imul =
  typeof Math.imul === 'function' && Math.imul(0xffffffff, 2) === -2
    ? Math.imul
    : function imul(a, b) {
        a |= 0; // int
        b |= 0; // int
        var c = a & 0xffff;
        var d = b & 0xffff;
        // Shift by 0 fixes the sign on the high part.
        return (c * d + ((((a >>> 16) * d + c * (b >>> 16)) << 16) >>> 0)) | 0; // int
      };

// v8 has an optimization for storing 31-bit signed numbers.
// Values which have either 00 or 11 as the high order bits qualify.
// This function drops the highest order bit in a signed number, maintaining
// the sign bit.
function smi(i32) {
  return ((i32 >>> 1) & 0x40000000) | (i32 & 0xbfffffff);
}

var defaultValueOf = Object.prototype.valueOf;

function hash(o) {
  if (o == null) {
    return hashNullish(o);
  }

  if (typeof o.hashCode === 'function') {
    // Drop any high bits from accidentally long hash codes.
    return smi(o.hashCode(o));
  }

  var v = valueOf(o);

  if (v == null) {
    return hashNullish(v);
  }

  switch (typeof v) {
    case 'boolean':
      // The hash values for built-in constants are a 1 value for each 5-byte
      // shift region expect for the first, which encodes the value. This
      // reduces the odds of a hash collision for these common values.
      return v ? 0x42108421 : 0x42108420;
    case 'number':
      return hashNumber(v);
    case 'string':
      return v.length > STRING_HASH_CACHE_MIN_STRLEN
        ? cachedHashString(v)
        : hashString(v);
    case 'object':
    case 'function':
      return hashJSObj(v);
    case 'symbol':
      return hashSymbol(v);
    default:
      if (typeof v.toString === 'function') {
        return hashString(v.toString());
      }
      throw new Error('Value type ' + typeof v + ' cannot be hashed.');
  }
}

function hashNullish(nullish) {
  return nullish === null ? 0x42108422 : /* undefined */ 0x42108423;
}

// Compress arbitrarily large numbers into smi hashes.
function hashNumber(n) {
  if (n !== n || n === Infinity) {
    return 0;
  }
  var hash = n | 0;
  if (hash !== n) {
    hash ^= n * 0xffffffff;
  }
  while (n > 0xffffffff) {
    n /= 0xffffffff;
    hash ^= n;
  }
  return smi(hash);
}

function cachedHashString(string) {
  var hashed = stringHashCache[string];
  if (hashed === undefined) {
    hashed = hashString(string);
    if (STRING_HASH_CACHE_SIZE === STRING_HASH_CACHE_MAX_SIZE) {
      STRING_HASH_CACHE_SIZE = 0;
      stringHashCache = {};
    }
    STRING_HASH_CACHE_SIZE++;
    stringHashCache[string] = hashed;
  }
  return hashed;
}

// http://jsperf.com/hashing-strings
function hashString(string) {
  // This is the hash from JVM
  // The hash code for a string is computed as
  // s[0] * 31 ^ (n - 1) + s[1] * 31 ^ (n - 2) + ... + s[n - 1],
  // where s[i] is the ith character of the string and n is the length of
  // the string. We "mod" the result to make it between 0 (inclusive) and 2^31
  // (exclusive) by dropping high bits.
  var hashed = 0;
  for (var ii = 0; ii < string.length; ii++) {
    hashed = (31 * hashed + string.charCodeAt(ii)) | 0;
  }
  return smi(hashed);
}

function hashSymbol(sym) {
  var hashed = symbolMap[sym];
  if (hashed !== undefined) {
    return hashed;
  }

  hashed = nextHash();

  symbolMap[sym] = hashed;

  return hashed;
}

function hashJSObj(obj) {
  var hashed;
  if (usingWeakMap) {
    hashed = weakMap.get(obj);
    if (hashed !== undefined) {
      return hashed;
    }
  }

  hashed = obj[UID_HASH_KEY];
  if (hashed !== undefined) {
    return hashed;
  }

  if (!canDefineProperty) {
    hashed = obj.propertyIsEnumerable && obj.propertyIsEnumerable[UID_HASH_KEY];
    if (hashed !== undefined) {
      return hashed;
    }

    hashed = getIENodeHash(obj);
    if (hashed !== undefined) {
      return hashed;
    }
  }

  hashed = nextHash();

  if (usingWeakMap) {
    weakMap.set(obj, hashed);
  } else if (isExtensible !== undefined && isExtensible(obj) === false) {
    throw new Error('Non-extensible objects are not allowed as keys.');
  } else if (canDefineProperty) {
    Object.defineProperty(obj, UID_HASH_KEY, {
      enumerable: false,
      configurable: false,
      writable: false,
      value: hashed,
    });
  } else if (
    obj.propertyIsEnumerable !== undefined &&
    obj.propertyIsEnumerable === obj.constructor.prototype.propertyIsEnumerable
  ) {
    // Since we can't define a non-enumerable property on the object
    // we'll hijack one of the less-used non-enumerable properties to
    // save our hash on it. Since this is a function it will not show up in
    // `JSON.stringify` which is what we want.
    obj.propertyIsEnumerable = function () {
      return this.constructor.prototype.propertyIsEnumerable.apply(
        this,
        arguments
      );
    };
    obj.propertyIsEnumerable[UID_HASH_KEY] = hashed;
  } else if (obj.nodeType !== undefined) {
    // At this point we couldn't get the IE `uniqueID` to use as a hash
    // and we couldn't use a non-enumerable property to exploit the
    // dontEnum bug so we simply add the `UID_HASH_KEY` on the node
    // itself.
    obj[UID_HASH_KEY] = hashed;
  } else {
    throw new Error('Unable to set a non-enumerable property on object.');
  }

  return hashed;
}

// Get references to ES5 object methods.
var isExtensible = Object.isExtensible;

// True if Object.defineProperty works as expected. IE8 fails this test.
var canDefineProperty = (function () {
  try {
    Object.defineProperty({}, '@', {});
    return true;
  } catch (e) {
    return false;
  }
})();

// IE has a `uniqueID` property on DOM nodes. We can construct the hash from it
// and avoid memory leaks from the IE cloneNode bug.
function getIENodeHash(node) {
  if (node && node.nodeType > 0) {
    switch (node.nodeType) {
      case 1: // Element
        return node.uniqueID;
      case 9: // Document
        return node.documentElement && node.documentElement.uniqueID;
    }
  }
}

function valueOf(obj) {
  return obj.valueOf !== defaultValueOf && typeof obj.valueOf === 'function'
    ? obj.valueOf(obj)
    : obj;
}

function nextHash() {
  var nextHash = ++_objHashUID;
  if (_objHashUID & 0x40000000) {
    _objHashUID = 0;
  }
  return nextHash;
}

// If possible, use a WeakMap.
var usingWeakMap = typeof WeakMap === 'function';
var weakMap;
if (usingWeakMap) {
  weakMap = new WeakMap();
}

var symbolMap = Object.create(null);

var _objHashUID = 0;

var UID_HASH_KEY = '__immutablehash__';
if (typeof Symbol === 'function') {
  UID_HASH_KEY = Symbol(UID_HASH_KEY);
}

var STRING_HASH_CACHE_MIN_STRLEN = 16;
var STRING_HASH_CACHE_MAX_SIZE = 255;
var STRING_HASH_CACHE_SIZE = 0;
var stringHashCache = {};

var ToKeyedSequence = /*@__PURE__*/(function (KeyedSeq) {
  function ToKeyedSequence(indexed, useKeys) {
    this._iter = indexed;
    this._useKeys = useKeys;
    this.size = indexed.size;
  }

  if ( KeyedSeq ) ToKeyedSequence.__proto__ = KeyedSeq;
  ToKeyedSequence.prototype = Object.create( KeyedSeq && KeyedSeq.prototype );
  ToKeyedSequence.prototype.constructor = ToKeyedSequence;

  ToKeyedSequence.prototype.get = function get (key, notSetValue) {
    return this._iter.get(key, notSetValue);
  };

  ToKeyedSequence.prototype.has = function has (key) {
    return this._iter.has(key);
  };

  ToKeyedSequence.prototype.valueSeq = function valueSeq () {
    return this._iter.valueSeq();
  };

  ToKeyedSequence.prototype.reverse = function reverse () {
    var this$1$1 = this;

    var reversedSequence = reverseFactory(this, true);
    if (!this._useKeys) {
      reversedSequence.valueSeq = function () { return this$1$1._iter.toSeq().reverse(); };
    }
    return reversedSequence;
  };

  ToKeyedSequence.prototype.map = function map (mapper, context) {
    var this$1$1 = this;

    var mappedSequence = mapFactory(this, mapper, context);
    if (!this._useKeys) {
      mappedSequence.valueSeq = function () { return this$1$1._iter.toSeq().map(mapper, context); };
    }
    return mappedSequence;
  };

  ToKeyedSequence.prototype.__iterate = function __iterate (fn, reverse) {
    var this$1$1 = this;

    return this._iter.__iterate(function (v, k) { return fn(v, k, this$1$1); }, reverse);
  };

  ToKeyedSequence.prototype.__iterator = function __iterator (type, reverse) {
    return this._iter.__iterator(type, reverse);
  };

  return ToKeyedSequence;
}(KeyedSeq));
ToKeyedSequence.prototype[IS_ORDERED_SYMBOL] = true;

var ToIndexedSequence = /*@__PURE__*/(function (IndexedSeq) {
  function ToIndexedSequence(iter) {
    this._iter = iter;
    this.size = iter.size;
  }

  if ( IndexedSeq ) ToIndexedSequence.__proto__ = IndexedSeq;
  ToIndexedSequence.prototype = Object.create( IndexedSeq && IndexedSeq.prototype );
  ToIndexedSequence.prototype.constructor = ToIndexedSequence;

  ToIndexedSequence.prototype.includes = function includes (value) {
    return this._iter.includes(value);
  };

  ToIndexedSequence.prototype.__iterate = function __iterate (fn, reverse) {
    var this$1$1 = this;

    var i = 0;
    reverse && ensureSize(this);
    return this._iter.__iterate(
      function (v) { return fn(v, reverse ? this$1$1.size - ++i : i++, this$1$1); },
      reverse
    );
  };

  ToIndexedSequence.prototype.__iterator = function __iterator (type, reverse) {
    var this$1$1 = this;

    var iterator = this._iter.__iterator(ITERATE_VALUES, reverse);
    var i = 0;
    reverse && ensureSize(this);
    return new Iterator(function () {
      var step = iterator.next();
      return step.done
        ? step
        : iteratorValue(
            type,
            reverse ? this$1$1.size - ++i : i++,
            step.value,
            step
          );
    });
  };

  return ToIndexedSequence;
}(IndexedSeq));

var ToSetSequence = /*@__PURE__*/(function (SetSeq) {
  function ToSetSequence(iter) {
    this._iter = iter;
    this.size = iter.size;
  }

  if ( SetSeq ) ToSetSequence.__proto__ = SetSeq;
  ToSetSequence.prototype = Object.create( SetSeq && SetSeq.prototype );
  ToSetSequence.prototype.constructor = ToSetSequence;

  ToSetSequence.prototype.has = function has (key) {
    return this._iter.includes(key);
  };

  ToSetSequence.prototype.__iterate = function __iterate (fn, reverse) {
    var this$1$1 = this;

    return this._iter.__iterate(function (v) { return fn(v, v, this$1$1); }, reverse);
  };

  ToSetSequence.prototype.__iterator = function __iterator (type, reverse) {
    var iterator = this._iter.__iterator(ITERATE_VALUES, reverse);
    return new Iterator(function () {
      var step = iterator.next();
      return step.done
        ? step
        : iteratorValue(type, step.value, step.value, step);
    });
  };

  return ToSetSequence;
}(SetSeq));

var FromEntriesSequence = /*@__PURE__*/(function (KeyedSeq) {
  function FromEntriesSequence(entries) {
    this._iter = entries;
    this.size = entries.size;
  }

  if ( KeyedSeq ) FromEntriesSequence.__proto__ = KeyedSeq;
  FromEntriesSequence.prototype = Object.create( KeyedSeq && KeyedSeq.prototype );
  FromEntriesSequence.prototype.constructor = FromEntriesSequence;

  FromEntriesSequence.prototype.entrySeq = function entrySeq () {
    return this._iter.toSeq();
  };

  FromEntriesSequence.prototype.__iterate = function __iterate (fn, reverse) {
    var this$1$1 = this;

    return this._iter.__iterate(function (entry) {
      // Check if entry exists first so array access doesn't throw for holes
      // in the parent iteration.
      if (entry) {
        validateEntry(entry);
        var indexedCollection = isCollection(entry);
        return fn(
          indexedCollection ? entry.get(1) : entry[1],
          indexedCollection ? entry.get(0) : entry[0],
          this$1$1
        );
      }
    }, reverse);
  };

  FromEntriesSequence.prototype.__iterator = function __iterator (type, reverse) {
    var iterator = this._iter.__iterator(ITERATE_VALUES, reverse);
    return new Iterator(function () {
      while (true) {
        var step = iterator.next();
        if (step.done) {
          return step;
        }
        var entry = step.value;
        // Check if entry exists first so array access doesn't throw for holes
        // in the parent iteration.
        if (entry) {
          validateEntry(entry);
          var indexedCollection = isCollection(entry);
          return iteratorValue(
            type,
            indexedCollection ? entry.get(0) : entry[0],
            indexedCollection ? entry.get(1) : entry[1],
            step
          );
        }
      }
    });
  };

  return FromEntriesSequence;
}(KeyedSeq));

ToIndexedSequence.prototype.cacheResult =
  ToKeyedSequence.prototype.cacheResult =
  ToSetSequence.prototype.cacheResult =
  FromEntriesSequence.prototype.cacheResult =
    cacheResultThrough;

function flipFactory(collection) {
  var flipSequence = makeSequence(collection);
  flipSequence._iter = collection;
  flipSequence.size = collection.size;
  flipSequence.flip = function () { return collection; };
  flipSequence.reverse = function () {
    var reversedSequence = collection.reverse.apply(this); // super.reverse()
    reversedSequence.flip = function () { return collection.reverse(); };
    return reversedSequence;
  };
  flipSequence.has = function (key) { return collection.includes(key); };
  flipSequence.includes = function (key) { return collection.has(key); };
  flipSequence.cacheResult = cacheResultThrough;
  flipSequence.__iterateUncached = function (fn, reverse) {
    var this$1$1 = this;

    return collection.__iterate(function (v, k) { return fn(k, v, this$1$1) !== false; }, reverse);
  };
  flipSequence.__iteratorUncached = function (type, reverse) {
    if (type === ITERATE_ENTRIES) {
      var iterator = collection.__iterator(type, reverse);
      return new Iterator(function () {
        var step = iterator.next();
        if (!step.done) {
          var k = step.value[0];
          step.value[0] = step.value[1];
          step.value[1] = k;
        }
        return step;
      });
    }
    return collection.__iterator(
      type === ITERATE_VALUES ? ITERATE_KEYS : ITERATE_VALUES,
      reverse
    );
  };
  return flipSequence;
}

function mapFactory(collection, mapper, context) {
  var mappedSequence = makeSequence(collection);
  mappedSequence.size = collection.size;
  mappedSequence.has = function (key) { return collection.has(key); };
  mappedSequence.get = function (key, notSetValue) {
    var v = collection.get(key, NOT_SET);
    return v === NOT_SET
      ? notSetValue
      : mapper.call(context, v, key, collection);
  };
  mappedSequence.__iterateUncached = function (fn, reverse) {
    var this$1$1 = this;

    return collection.__iterate(
      function (v, k, c) { return fn(mapper.call(context, v, k, c), k, this$1$1) !== false; },
      reverse
    );
  };
  mappedSequence.__iteratorUncached = function (type, reverse) {
    var iterator = collection.__iterator(ITERATE_ENTRIES, reverse);
    return new Iterator(function () {
      var step = iterator.next();
      if (step.done) {
        return step;
      }
      var entry = step.value;
      var key = entry[0];
      return iteratorValue(
        type,
        key,
        mapper.call(context, entry[1], key, collection),
        step
      );
    });
  };
  return mappedSequence;
}

function reverseFactory(collection, useKeys) {
  var this$1$1 = this;

  var reversedSequence = makeSequence(collection);
  reversedSequence._iter = collection;
  reversedSequence.size = collection.size;
  reversedSequence.reverse = function () { return collection; };
  if (collection.flip) {
    reversedSequence.flip = function () {
      var flipSequence = flipFactory(collection);
      flipSequence.reverse = function () { return collection.flip(); };
      return flipSequence;
    };
  }
  reversedSequence.get = function (key, notSetValue) { return collection.get(useKeys ? key : -1 - key, notSetValue); };
  reversedSequence.has = function (key) { return collection.has(useKeys ? key : -1 - key); };
  reversedSequence.includes = function (value) { return collection.includes(value); };
  reversedSequence.cacheResult = cacheResultThrough;
  reversedSequence.__iterate = function (fn, reverse) {
    var this$1$1 = this;

    var i = 0;
    reverse && ensureSize(collection);
    return collection.__iterate(
      function (v, k) { return fn(v, useKeys ? k : reverse ? this$1$1.size - ++i : i++, this$1$1); },
      !reverse
    );
  };
  reversedSequence.__iterator = function (type, reverse) {
    var i = 0;
    reverse && ensureSize(collection);
    var iterator = collection.__iterator(ITERATE_ENTRIES, !reverse);
    return new Iterator(function () {
      var step = iterator.next();
      if (step.done) {
        return step;
      }
      var entry = step.value;
      return iteratorValue(
        type,
        useKeys ? entry[0] : reverse ? this$1$1.size - ++i : i++,
        entry[1],
        step
      );
    });
  };
  return reversedSequence;
}

function filterFactory(collection, predicate, context, useKeys) {
  var filterSequence = makeSequence(collection);
  if (useKeys) {
    filterSequence.has = function (key) {
      var v = collection.get(key, NOT_SET);
      return v !== NOT_SET && !!predicate.call(context, v, key, collection);
    };
    filterSequence.get = function (key, notSetValue) {
      var v = collection.get(key, NOT_SET);
      return v !== NOT_SET && predicate.call(context, v, key, collection)
        ? v
        : notSetValue;
    };
  }
  filterSequence.__iterateUncached = function (fn, reverse) {
    var this$1$1 = this;

    var iterations = 0;
    collection.__iterate(function (v, k, c) {
      if (predicate.call(context, v, k, c)) {
        iterations++;
        return fn(v, useKeys ? k : iterations - 1, this$1$1);
      }
    }, reverse);
    return iterations;
  };
  filterSequence.__iteratorUncached = function (type, reverse) {
    var iterator = collection.__iterator(ITERATE_ENTRIES, reverse);
    var iterations = 0;
    return new Iterator(function () {
      while (true) {
        var step = iterator.next();
        if (step.done) {
          return step;
        }
        var entry = step.value;
        var key = entry[0];
        var value = entry[1];
        if (predicate.call(context, value, key, collection)) {
          return iteratorValue(type, useKeys ? key : iterations++, value, step);
        }
      }
    });
  };
  return filterSequence;
}

function countByFactory(collection, grouper, context) {
  var groups = Map().asMutable();
  collection.__iterate(function (v, k) {
    groups.update(grouper.call(context, v, k, collection), 0, function (a) { return a + 1; });
  });
  return groups.asImmutable();
}

function groupByFactory(collection, grouper, context) {
  var isKeyedIter = isKeyed(collection);
  var groups = (isOrdered(collection) ? OrderedMap() : Map()).asMutable();
  collection.__iterate(function (v, k) {
    groups.update(
      grouper.call(context, v, k, collection),
      function (a) { return ((a = a || []), a.push(isKeyedIter ? [k, v] : v), a); }
    );
  });
  var coerce = collectionClass(collection);
  return groups.map(function (arr) { return reify(collection, coerce(arr)); }).asImmutable();
}

function sliceFactory(collection, begin, end, useKeys) {
  var originalSize = collection.size;

  if (wholeSlice(begin, end, originalSize)) {
    return collection;
  }

  var resolvedBegin = resolveBegin(begin, originalSize);
  var resolvedEnd = resolveEnd(end, originalSize);

  // begin or end will be NaN if they were provided as negative numbers and
  // this collection's size is unknown. In that case, cache first so there is
  // a known size and these do not resolve to NaN.
  if (resolvedBegin !== resolvedBegin || resolvedEnd !== resolvedEnd) {
    return sliceFactory(collection.toSeq().cacheResult(), begin, end, useKeys);
  }

  // Note: resolvedEnd is undefined when the original sequence's length is
  // unknown and this slice did not supply an end and should contain all
  // elements after resolvedBegin.
  // In that case, resolvedSize will be NaN and sliceSize will remain undefined.
  var resolvedSize = resolvedEnd - resolvedBegin;
  var sliceSize;
  if (resolvedSize === resolvedSize) {
    sliceSize = resolvedSize < 0 ? 0 : resolvedSize;
  }

  var sliceSeq = makeSequence(collection);

  // If collection.size is undefined, the size of the realized sliceSeq is
  // unknown at this point unless the number of items to slice is 0
  sliceSeq.size =
    sliceSize === 0 ? sliceSize : (collection.size && sliceSize) || undefined;

  if (!useKeys && isSeq(collection) && sliceSize >= 0) {
    sliceSeq.get = function (index, notSetValue) {
      index = wrapIndex(this, index);
      return index >= 0 && index < sliceSize
        ? collection.get(index + resolvedBegin, notSetValue)
        : notSetValue;
    };
  }

  sliceSeq.__iterateUncached = function (fn, reverse) {
    var this$1$1 = this;

    if (sliceSize === 0) {
      return 0;
    }
    if (reverse) {
      return this.cacheResult().__iterate(fn, reverse);
    }
    var skipped = 0;
    var isSkipping = true;
    var iterations = 0;
    collection.__iterate(function (v, k) {
      if (!(isSkipping && (isSkipping = skipped++ < resolvedBegin))) {
        iterations++;
        return (
          fn(v, useKeys ? k : iterations - 1, this$1$1) !== false &&
          iterations !== sliceSize
        );
      }
    });
    return iterations;
  };

  sliceSeq.__iteratorUncached = function (type, reverse) {
    if (sliceSize !== 0 && reverse) {
      return this.cacheResult().__iterator(type, reverse);
    }
    // Don't bother instantiating parent iterator if taking 0.
    if (sliceSize === 0) {
      return new Iterator(iteratorDone);
    }
    var iterator = collection.__iterator(type, reverse);
    var skipped = 0;
    var iterations = 0;
    return new Iterator(function () {
      while (skipped++ < resolvedBegin) {
        iterator.next();
      }
      if (++iterations > sliceSize) {
        return iteratorDone();
      }
      var step = iterator.next();
      if (useKeys || type === ITERATE_VALUES || step.done) {
        return step;
      }
      if (type === ITERATE_KEYS) {
        return iteratorValue(type, iterations - 1, undefined, step);
      }
      return iteratorValue(type, iterations - 1, step.value[1], step);
    });
  };

  return sliceSeq;
}

function takeWhileFactory(collection, predicate, context) {
  var takeSequence = makeSequence(collection);
  takeSequence.__iterateUncached = function (fn, reverse) {
    var this$1$1 = this;

    if (reverse) {
      return this.cacheResult().__iterate(fn, reverse);
    }
    var iterations = 0;
    collection.__iterate(
      function (v, k, c) { return predicate.call(context, v, k, c) && ++iterations && fn(v, k, this$1$1); }
    );
    return iterations;
  };
  takeSequence.__iteratorUncached = function (type, reverse) {
    var this$1$1 = this;

    if (reverse) {
      return this.cacheResult().__iterator(type, reverse);
    }
    var iterator = collection.__iterator(ITERATE_ENTRIES, reverse);
    var iterating = true;
    return new Iterator(function () {
      if (!iterating) {
        return iteratorDone();
      }
      var step = iterator.next();
      if (step.done) {
        return step;
      }
      var entry = step.value;
      var k = entry[0];
      var v = entry[1];
      if (!predicate.call(context, v, k, this$1$1)) {
        iterating = false;
        return iteratorDone();
      }
      return type === ITERATE_ENTRIES ? step : iteratorValue(type, k, v, step);
    });
  };
  return takeSequence;
}

function skipWhileFactory(collection, predicate, context, useKeys) {
  var skipSequence = makeSequence(collection);
  skipSequence.__iterateUncached = function (fn, reverse) {
    var this$1$1 = this;

    if (reverse) {
      return this.cacheResult().__iterate(fn, reverse);
    }
    var isSkipping = true;
    var iterations = 0;
    collection.__iterate(function (v, k, c) {
      if (!(isSkipping && (isSkipping = predicate.call(context, v, k, c)))) {
        iterations++;
        return fn(v, useKeys ? k : iterations - 1, this$1$1);
      }
    });
    return iterations;
  };
  skipSequence.__iteratorUncached = function (type, reverse) {
    var this$1$1 = this;

    if (reverse) {
      return this.cacheResult().__iterator(type, reverse);
    }
    var iterator = collection.__iterator(ITERATE_ENTRIES, reverse);
    var skipping = true;
    var iterations = 0;
    return new Iterator(function () {
      var step;
      var k;
      var v;
      do {
        step = iterator.next();
        if (step.done) {
          if (useKeys || type === ITERATE_VALUES) {
            return step;
          }
          if (type === ITERATE_KEYS) {
            return iteratorValue(type, iterations++, undefined, step);
          }
          return iteratorValue(type, iterations++, step.value[1], step);
        }
        var entry = step.value;
        k = entry[0];
        v = entry[1];
        skipping && (skipping = predicate.call(context, v, k, this$1$1));
      } while (skipping);
      return type === ITERATE_ENTRIES ? step : iteratorValue(type, k, v, step);
    });
  };
  return skipSequence;
}

function concatFactory(collection, values) {
  var isKeyedCollection = isKeyed(collection);
  var iters = [collection]
    .concat(values)
    .map(function (v) {
      if (!isCollection(v)) {
        v = isKeyedCollection
          ? keyedSeqFromValue(v)
          : indexedSeqFromValue(Array.isArray(v) ? v : [v]);
      } else if (isKeyedCollection) {
        v = KeyedCollection(v);
      }
      return v;
    })
    .filter(function (v) { return v.size !== 0; });

  if (iters.length === 0) {
    return collection;
  }

  if (iters.length === 1) {
    var singleton = iters[0];
    if (
      singleton === collection ||
      (isKeyedCollection && isKeyed(singleton)) ||
      (isIndexed(collection) && isIndexed(singleton))
    ) {
      return singleton;
    }
  }

  var concatSeq = new ArraySeq(iters);
  if (isKeyedCollection) {
    concatSeq = concatSeq.toKeyedSeq();
  } else if (!isIndexed(collection)) {
    concatSeq = concatSeq.toSetSeq();
  }
  concatSeq = concatSeq.flatten(true);
  concatSeq.size = iters.reduce(function (sum, seq) {
    if (sum !== undefined) {
      var size = seq.size;
      if (size !== undefined) {
        return sum + size;
      }
    }
  }, 0);
  return concatSeq;
}

function flattenFactory(collection, depth, useKeys) {
  var flatSequence = makeSequence(collection);
  flatSequence.__iterateUncached = function (fn, reverse) {
    if (reverse) {
      return this.cacheResult().__iterate(fn, reverse);
    }
    var iterations = 0;
    var stopped = false;
    function flatDeep(iter, currentDepth) {
      iter.__iterate(function (v, k) {
        if ((!depth || currentDepth < depth) && isCollection(v)) {
          flatDeep(v, currentDepth + 1);
        } else {
          iterations++;
          if (fn(v, useKeys ? k : iterations - 1, flatSequence) === false) {
            stopped = true;
          }
        }
        return !stopped;
      }, reverse);
    }
    flatDeep(collection, 0);
    return iterations;
  };
  flatSequence.__iteratorUncached = function (type, reverse) {
    if (reverse) {
      return this.cacheResult().__iterator(type, reverse);
    }
    var iterator = collection.__iterator(type, reverse);
    var stack = [];
    var iterations = 0;
    return new Iterator(function () {
      while (iterator) {
        var step = iterator.next();
        if (step.done !== false) {
          iterator = stack.pop();
          continue;
        }
        var v = step.value;
        if (type === ITERATE_ENTRIES) {
          v = v[1];
        }
        if ((!depth || stack.length < depth) && isCollection(v)) {
          stack.push(iterator);
          iterator = v.__iterator(type, reverse);
        } else {
          return useKeys ? step : iteratorValue(type, iterations++, v, step);
        }
      }
      return iteratorDone();
    });
  };
  return flatSequence;
}

function flatMapFactory(collection, mapper, context) {
  var coerce = collectionClass(collection);
  return collection
    .toSeq()
    .map(function (v, k) { return coerce(mapper.call(context, v, k, collection)); })
    .flatten(true);
}

function interposeFactory(collection, separator) {
  var interposedSequence = makeSequence(collection);
  interposedSequence.size = collection.size && collection.size * 2 - 1;
  interposedSequence.__iterateUncached = function (fn, reverse) {
    var this$1$1 = this;

    var iterations = 0;
    collection.__iterate(
      function (v) { return (!iterations || fn(separator, iterations++, this$1$1) !== false) &&
        fn(v, iterations++, this$1$1) !== false; },
      reverse
    );
    return iterations;
  };
  interposedSequence.__iteratorUncached = function (type, reverse) {
    var iterator = collection.__iterator(ITERATE_VALUES, reverse);
    var iterations = 0;
    var step;
    return new Iterator(function () {
      if (!step || iterations % 2) {
        step = iterator.next();
        if (step.done) {
          return step;
        }
      }
      return iterations % 2
        ? iteratorValue(type, iterations++, separator)
        : iteratorValue(type, iterations++, step.value, step);
    });
  };
  return interposedSequence;
}

function sortFactory(collection, comparator, mapper) {
  if (!comparator) {
    comparator = defaultComparator;
  }
  var isKeyedCollection = isKeyed(collection);
  var index = 0;
  var entries = collection
    .toSeq()
    .map(function (v, k) { return [k, v, index++, mapper ? mapper(v, k, collection) : v]; })
    .valueSeq()
    .toArray();
  entries
    .sort(function (a, b) { return comparator(a[3], b[3]) || a[2] - b[2]; })
    .forEach(
      isKeyedCollection
        ? function (v, i) {
            entries[i].length = 2;
          }
        : function (v, i) {
            entries[i] = v[1];
          }
    );
  return isKeyedCollection
    ? KeyedSeq(entries)
    : isIndexed(collection)
    ? IndexedSeq(entries)
    : SetSeq(entries);
}

function maxFactory(collection, comparator, mapper) {
  if (!comparator) {
    comparator = defaultComparator;
  }
  if (mapper) {
    var entry = collection
      .toSeq()
      .map(function (v, k) { return [v, mapper(v, k, collection)]; })
      .reduce(function (a, b) { return (maxCompare(comparator, a[1], b[1]) ? b : a); });
    return entry && entry[0];
  }
  return collection.reduce(function (a, b) { return (maxCompare(comparator, a, b) ? b : a); });
}

function maxCompare(comparator, a, b) {
  var comp = comparator(b, a);
  // b is considered the new max if the comparator declares them equal, but
  // they are not equal and b is in fact a nullish value.
  return (
    (comp === 0 && b !== a && (b === undefined || b === null || b !== b)) ||
    comp > 0
  );
}

function zipWithFactory(keyIter, zipper, iters, zipAll) {
  var zipSequence = makeSequence(keyIter);
  var sizes = new ArraySeq(iters).map(function (i) { return i.size; });
  zipSequence.size = zipAll ? sizes.max() : sizes.min();
  // Note: this a generic base implementation of __iterate in terms of
  // __iterator which may be more generically useful in the future.
  zipSequence.__iterate = function (fn, reverse) {
    /* generic:
    var iterator = this.__iterator(ITERATE_ENTRIES, reverse);
    var step;
    var iterations = 0;
    while (!(step = iterator.next()).done) {
      iterations++;
      if (fn(step.value[1], step.value[0], this) === false) {
        break;
      }
    }
    return iterations;
    */
    // indexed:
    var iterator = this.__iterator(ITERATE_VALUES, reverse);
    var step;
    var iterations = 0;
    while (!(step = iterator.next()).done) {
      if (fn(step.value, iterations++, this) === false) {
        break;
      }
    }
    return iterations;
  };
  zipSequence.__iteratorUncached = function (type, reverse) {
    var iterators = iters.map(
      function (i) { return ((i = Collection(i)), getIterator(reverse ? i.reverse() : i)); }
    );
    var iterations = 0;
    var isDone = false;
    return new Iterator(function () {
      var steps;
      if (!isDone) {
        steps = iterators.map(function (i) { return i.next(); });
        isDone = zipAll ? steps.every(function (s) { return s.done; }) : steps.some(function (s) { return s.done; });
      }
      if (isDone) {
        return iteratorDone();
      }
      return iteratorValue(
        type,
        iterations++,
        zipper.apply(
          null,
          steps.map(function (s) { return s.value; })
        )
      );
    });
  };
  return zipSequence;
}

// #pragma Helper Functions

function reify(iter, seq) {
  return iter === seq ? iter : isSeq(iter) ? seq : iter.constructor(seq);
}

function validateEntry(entry) {
  if (entry !== Object(entry)) {
    throw new TypeError('Expected [K, V] tuple: ' + entry);
  }
}

function collectionClass(collection) {
  return isKeyed(collection)
    ? KeyedCollection
    : isIndexed(collection)
    ? IndexedCollection
    : SetCollection;
}

function makeSequence(collection) {
  return Object.create(
    (isKeyed(collection)
      ? KeyedSeq
      : isIndexed(collection)
      ? IndexedSeq
      : SetSeq
    ).prototype
  );
}

function cacheResultThrough() {
  if (this._iter.cacheResult) {
    this._iter.cacheResult();
    this.size = this._iter.size;
    return this;
  }
  return Seq.prototype.cacheResult.call(this);
}

function defaultComparator(a, b) {
  if (a === undefined && b === undefined) {
    return 0;
  }

  if (a === undefined) {
    return 1;
  }

  if (b === undefined) {
    return -1;
  }

  return a > b ? 1 : a < b ? -1 : 0;
}

function arrCopy(arr, offset) {
  offset = offset || 0;
  var len = Math.max(0, arr.length - offset);
  var newArr = new Array(len);
  for (var ii = 0; ii < len; ii++) {
    newArr[ii] = arr[ii + offset];
  }
  return newArr;
}

function invariant(condition, error) {
  if (!condition) { throw new Error(error); }
}

function assertNotInfinite(size) {
  invariant(
    size !== Infinity,
    'Cannot perform this action with an infinite size.'
  );
}

function coerceKeyPath(keyPath) {
  if (isArrayLike(keyPath) && typeof keyPath !== 'string') {
    return keyPath;
  }
  if (isOrdered(keyPath)) {
    return keyPath.toArray();
  }
  throw new TypeError(
    'Invalid keyPath: expected Ordered Collection or Array: ' + keyPath
  );
}

var toString = Object.prototype.toString;

function isPlainObject(value) {
  // The base prototype's toString deals with Argument objects and native namespaces like Math
  if (
    !value ||
    typeof value !== 'object' ||
    toString.call(value) !== '[object Object]'
  ) {
    return false;
  }

  var proto = Object.getPrototypeOf(value);
  if (proto === null) {
    return true;
  }

  // Iteratively going up the prototype chain is needed for cross-realm environments (differing contexts, iframes, etc)
  var parentProto = proto;
  var nextProto = Object.getPrototypeOf(proto);
  while (nextProto !== null) {
    parentProto = nextProto;
    nextProto = Object.getPrototypeOf(parentProto);
  }
  return parentProto === proto;
}

/**
 * Returns true if the value is a potentially-persistent data structure, either
 * provided by Immutable.js or a plain Array or Object.
 */
function isDataStructure(value) {
  return (
    typeof value === 'object' &&
    (isImmutable(value) || Array.isArray(value) || isPlainObject(value))
  );
}

function quoteString(value) {
  try {
    return typeof value === 'string' ? JSON.stringify(value) : String(value);
  } catch (_ignoreError) {
    return JSON.stringify(value);
  }
}

function has(collection, key) {
  return isImmutable(collection)
    ? collection.has(key)
    : isDataStructure(collection) && hasOwnProperty.call(collection, key);
}

function get(collection, key, notSetValue) {
  return isImmutable(collection)
    ? collection.get(key, notSetValue)
    : !has(collection, key)
    ? notSetValue
    : typeof collection.get === 'function'
    ? collection.get(key)
    : collection[key];
}

function shallowCopy(from) {
  if (Array.isArray(from)) {
    return arrCopy(from);
  }
  var to = {};
  for (var key in from) {
    if (hasOwnProperty.call(from, key)) {
      to[key] = from[key];
    }
  }
  return to;
}

function remove(collection, key) {
  if (!isDataStructure(collection)) {
    throw new TypeError(
      'Cannot update non-data-structure value: ' + collection
    );
  }
  if (isImmutable(collection)) {
    if (!collection.remove) {
      throw new TypeError(
        'Cannot update immutable value without .remove() method: ' + collection
      );
    }
    return collection.remove(key);
  }
  if (!hasOwnProperty.call(collection, key)) {
    return collection;
  }
  var collectionCopy = shallowCopy(collection);
  if (Array.isArray(collectionCopy)) {
    collectionCopy.splice(key, 1);
  } else {
    delete collectionCopy[key];
  }
  return collectionCopy;
}

function set(collection, key, value) {
  if (!isDataStructure(collection)) {
    throw new TypeError(
      'Cannot update non-data-structure value: ' + collection
    );
  }
  if (isImmutable(collection)) {
    if (!collection.set) {
      throw new TypeError(
        'Cannot update immutable value without .set() method: ' + collection
      );
    }
    return collection.set(key, value);
  }
  if (hasOwnProperty.call(collection, key) && value === collection[key]) {
    return collection;
  }
  var collectionCopy = shallowCopy(collection);
  collectionCopy[key] = value;
  return collectionCopy;
}

function updateIn$1(collection, keyPath, notSetValue, updater) {
  if (!updater) {
    updater = notSetValue;
    notSetValue = undefined;
  }
  var updatedValue = updateInDeeply(
    isImmutable(collection),
    collection,
    coerceKeyPath(keyPath),
    0,
    notSetValue,
    updater
  );
  return updatedValue === NOT_SET ? notSetValue : updatedValue;
}

function updateInDeeply(
  inImmutable,
  existing,
  keyPath,
  i,
  notSetValue,
  updater
) {
  var wasNotSet = existing === NOT_SET;
  if (i === keyPath.length) {
    var existingValue = wasNotSet ? notSetValue : existing;
    var newValue = updater(existingValue);
    return newValue === existingValue ? existing : newValue;
  }
  if (!wasNotSet && !isDataStructure(existing)) {
    throw new TypeError(
      'Cannot update within non-data-structure value in path [' +
        keyPath.slice(0, i).map(quoteString) +
        ']: ' +
        existing
    );
  }
  var key = keyPath[i];
  var nextExisting = wasNotSet ? NOT_SET : get(existing, key, NOT_SET);
  var nextUpdated = updateInDeeply(
    nextExisting === NOT_SET ? inImmutable : isImmutable(nextExisting),
    nextExisting,
    keyPath,
    i + 1,
    notSetValue,
    updater
  );
  return nextUpdated === nextExisting
    ? existing
    : nextUpdated === NOT_SET
    ? remove(existing, key)
    : set(
        wasNotSet ? (inImmutable ? emptyMap() : {}) : existing,
        key,
        nextUpdated
      );
}

function setIn$1(collection, keyPath, value) {
  return updateIn$1(collection, keyPath, NOT_SET, function () { return value; });
}

function setIn(keyPath, v) {
  return setIn$1(this, keyPath, v);
}

function removeIn(collection, keyPath) {
  return updateIn$1(collection, keyPath, function () { return NOT_SET; });
}

function deleteIn(keyPath) {
  return removeIn(this, keyPath);
}

function update$1(collection, key, notSetValue, updater) {
  return updateIn$1(collection, [key], notSetValue, updater);
}

function update(key, notSetValue, updater) {
  return arguments.length === 1
    ? key(this)
    : update$1(this, key, notSetValue, updater);
}

function updateIn(keyPath, notSetValue, updater) {
  return updateIn$1(this, keyPath, notSetValue, updater);
}

function merge$1() {
  var iters = [], len = arguments.length;
  while ( len-- ) iters[ len ] = arguments[ len ];

  return mergeIntoKeyedWith(this, iters);
}

function mergeWith$1(merger) {
  var iters = [], len = arguments.length - 1;
  while ( len-- > 0 ) iters[ len ] = arguments[ len + 1 ];

  if (typeof merger !== 'function') {
    throw new TypeError('Invalid merger function: ' + merger);
  }
  return mergeIntoKeyedWith(this, iters, merger);
}

function mergeIntoKeyedWith(collection, collections, merger) {
  var iters = [];
  for (var ii = 0; ii < collections.length; ii++) {
    var collection$1 = KeyedCollection(collections[ii]);
    if (collection$1.size !== 0) {
      iters.push(collection$1);
    }
  }
  if (iters.length === 0) {
    return collection;
  }
  if (
    collection.toSeq().size === 0 &&
    !collection.__ownerID &&
    iters.length === 1
  ) {
    return collection.constructor(iters[0]);
  }
  return collection.withMutations(function (collection) {
    var mergeIntoCollection = merger
      ? function (value, key) {
          update$1(collection, key, NOT_SET, function (oldVal) { return oldVal === NOT_SET ? value : merger(oldVal, value, key); }
          );
        }
      : function (value, key) {
          collection.set(key, value);
        };
    for (var ii = 0; ii < iters.length; ii++) {
      iters[ii].forEach(mergeIntoCollection);
    }
  });
}

function merge(collection) {
  var sources = [], len = arguments.length - 1;
  while ( len-- > 0 ) sources[ len ] = arguments[ len + 1 ];

  return mergeWithSources(collection, sources);
}

function mergeWith(merger, collection) {
  var sources = [], len = arguments.length - 2;
  while ( len-- > 0 ) sources[ len ] = arguments[ len + 2 ];

  return mergeWithSources(collection, sources, merger);
}

function mergeDeep$1(collection) {
  var sources = [], len = arguments.length - 1;
  while ( len-- > 0 ) sources[ len ] = arguments[ len + 1 ];

  return mergeDeepWithSources(collection, sources);
}

function mergeDeepWith$1(merger, collection) {
  var sources = [], len = arguments.length - 2;
  while ( len-- > 0 ) sources[ len ] = arguments[ len + 2 ];

  return mergeDeepWithSources(collection, sources, merger);
}

function mergeDeepWithSources(collection, sources, merger) {
  return mergeWithSources(collection, sources, deepMergerWith(merger));
}

function mergeWithSources(collection, sources, merger) {
  if (!isDataStructure(collection)) {
    throw new TypeError(
      'Cannot merge into non-data-structure value: ' + collection
    );
  }
  if (isImmutable(collection)) {
    return typeof merger === 'function' && collection.mergeWith
      ? collection.mergeWith.apply(collection, [ merger ].concat( sources ))
      : collection.merge
      ? collection.merge.apply(collection, sources)
      : collection.concat.apply(collection, sources);
  }
  var isArray = Array.isArray(collection);
  var merged = collection;
  var Collection = isArray ? IndexedCollection : KeyedCollection;
  var mergeItem = isArray
    ? function (value) {
        // Copy on write
        if (merged === collection) {
          merged = shallowCopy(merged);
        }
        merged.push(value);
      }
    : function (value, key) {
        var hasVal = hasOwnProperty.call(merged, key);
        var nextVal =
          hasVal && merger ? merger(merged[key], value, key) : value;
        if (!hasVal || nextVal !== merged[key]) {
          // Copy on write
          if (merged === collection) {
            merged = shallowCopy(merged);
          }
          merged[key] = nextVal;
        }
      };
  for (var i = 0; i < sources.length; i++) {
    Collection(sources[i]).forEach(mergeItem);
  }
  return merged;
}

function deepMergerWith(merger) {
  function deepMerger(oldValue, newValue, key) {
    return isDataStructure(oldValue) &&
      isDataStructure(newValue) &&
      areMergeable(oldValue, newValue)
      ? mergeWithSources(oldValue, [newValue], deepMerger)
      : merger
      ? merger(oldValue, newValue, key)
      : newValue;
  }
  return deepMerger;
}

/**
 * It's unclear what the desired behavior is for merging two collections that
 * fall into separate categories between keyed, indexed, or set-like, so we only
 * consider them mergeable if they fall into the same category.
 */
function areMergeable(oldDataStructure, newDataStructure) {
  var oldSeq = Seq(oldDataStructure);
  var newSeq = Seq(newDataStructure);
  // This logic assumes that a sequence can only fall into one of the three
  // categories mentioned above (since there's no `isSetLike()` method).
  return (
    isIndexed(oldSeq) === isIndexed(newSeq) &&
    isKeyed(oldSeq) === isKeyed(newSeq)
  );
}

function mergeDeep() {
  var iters = [], len = arguments.length;
  while ( len-- ) iters[ len ] = arguments[ len ];

  return mergeDeepWithSources(this, iters);
}

function mergeDeepWith(merger) {
  var iters = [], len = arguments.length - 1;
  while ( len-- > 0 ) iters[ len ] = arguments[ len + 1 ];

  return mergeDeepWithSources(this, iters, merger);
}

function mergeIn(keyPath) {
  var iters = [], len = arguments.length - 1;
  while ( len-- > 0 ) iters[ len ] = arguments[ len + 1 ];

  return updateIn$1(this, keyPath, emptyMap(), function (m) { return mergeWithSources(m, iters); });
}

function mergeDeepIn(keyPath) {
  var iters = [], len = arguments.length - 1;
  while ( len-- > 0 ) iters[ len ] = arguments[ len + 1 ];

  return updateIn$1(this, keyPath, emptyMap(), function (m) { return mergeDeepWithSources(m, iters); }
  );
}

function withMutations(fn) {
  var mutable = this.asMutable();
  fn(mutable);
  return mutable.wasAltered() ? mutable.__ensureOwner(this.__ownerID) : this;
}

function asMutable() {
  return this.__ownerID ? this : this.__ensureOwner(new OwnerID());
}

function asImmutable() {
  return this.__ensureOwner();
}

function wasAltered() {
  return this.__altered;
}

var Map = /*@__PURE__*/(function (KeyedCollection) {
  function Map(value) {
    return value === null || value === undefined
      ? emptyMap()
      : isMap(value) && !isOrdered(value)
      ? value
      : emptyMap().withMutations(function (map) {
          var iter = KeyedCollection(value);
          assertNotInfinite(iter.size);
          iter.forEach(function (v, k) { return map.set(k, v); });
        });
  }

  if ( KeyedCollection ) Map.__proto__ = KeyedCollection;
  Map.prototype = Object.create( KeyedCollection && KeyedCollection.prototype );
  Map.prototype.constructor = Map;

  Map.of = function of () {
    var keyValues = [], len = arguments.length;
    while ( len-- ) keyValues[ len ] = arguments[ len ];

    return emptyMap().withMutations(function (map) {
      for (var i = 0; i < keyValues.length; i += 2) {
        if (i + 1 >= keyValues.length) {
          throw new Error('Missing value for key: ' + keyValues[i]);
        }
        map.set(keyValues[i], keyValues[i + 1]);
      }
    });
  };

  Map.prototype.toString = function toString () {
    return this.__toString('Map {', '}');
  };

  // @pragma Access

  Map.prototype.get = function get (k, notSetValue) {
    return this._root
      ? this._root.get(0, undefined, k, notSetValue)
      : notSetValue;
  };

  // @pragma Modification

  Map.prototype.set = function set (k, v) {
    return updateMap(this, k, v);
  };

  Map.prototype.remove = function remove (k) {
    return updateMap(this, k, NOT_SET);
  };

  Map.prototype.deleteAll = function deleteAll (keys) {
    var collection = Collection(keys);

    if (collection.size === 0) {
      return this;
    }

    return this.withMutations(function (map) {
      collection.forEach(function (key) { return map.remove(key); });
    });
  };

  Map.prototype.clear = function clear () {
    if (this.size === 0) {
      return this;
    }
    if (this.__ownerID) {
      this.size = 0;
      this._root = null;
      this.__hash = undefined;
      this.__altered = true;
      return this;
    }
    return emptyMap();
  };

  // @pragma Composition

  Map.prototype.sort = function sort (comparator) {
    // Late binding
    return OrderedMap(sortFactory(this, comparator));
  };

  Map.prototype.sortBy = function sortBy (mapper, comparator) {
    // Late binding
    return OrderedMap(sortFactory(this, comparator, mapper));
  };

  Map.prototype.map = function map (mapper, context) {
    var this$1$1 = this;

    return this.withMutations(function (map) {
      map.forEach(function (value, key) {
        map.set(key, mapper.call(context, value, key, this$1$1));
      });
    });
  };

  // @pragma Mutability

  Map.prototype.__iterator = function __iterator (type, reverse) {
    return new MapIterator(this, type, reverse);
  };

  Map.prototype.__iterate = function __iterate (fn, reverse) {
    var this$1$1 = this;

    var iterations = 0;
    this._root &&
      this._root.iterate(function (entry) {
        iterations++;
        return fn(entry[1], entry[0], this$1$1);
      }, reverse);
    return iterations;
  };

  Map.prototype.__ensureOwner = function __ensureOwner (ownerID) {
    if (ownerID === this.__ownerID) {
      return this;
    }
    if (!ownerID) {
      if (this.size === 0) {
        return emptyMap();
      }
      this.__ownerID = ownerID;
      this.__altered = false;
      return this;
    }
    return makeMap(this.size, this._root, ownerID, this.__hash);
  };

  return Map;
}(KeyedCollection));

Map.isMap = isMap;

var MapPrototype = Map.prototype;
MapPrototype[IS_MAP_SYMBOL] = true;
MapPrototype[DELETE] = MapPrototype.remove;
MapPrototype.removeAll = MapPrototype.deleteAll;
MapPrototype.setIn = setIn;
MapPrototype.removeIn = MapPrototype.deleteIn = deleteIn;
MapPrototype.update = update;
MapPrototype.updateIn = updateIn;
MapPrototype.merge = MapPrototype.concat = merge$1;
MapPrototype.mergeWith = mergeWith$1;
MapPrototype.mergeDeep = mergeDeep;
MapPrototype.mergeDeepWith = mergeDeepWith;
MapPrototype.mergeIn = mergeIn;
MapPrototype.mergeDeepIn = mergeDeepIn;
MapPrototype.withMutations = withMutations;
MapPrototype.wasAltered = wasAltered;
MapPrototype.asImmutable = asImmutable;
MapPrototype['@@transducer/init'] = MapPrototype.asMutable = asMutable;
MapPrototype['@@transducer/step'] = function (result, arr) {
  return result.set(arr[0], arr[1]);
};
MapPrototype['@@transducer/result'] = function (obj) {
  return obj.asImmutable();
};

// #pragma Trie Nodes

var ArrayMapNode = function ArrayMapNode(ownerID, entries) {
  this.ownerID = ownerID;
  this.entries = entries;
};

ArrayMapNode.prototype.get = function get (shift, keyHash, key, notSetValue) {
  var entries = this.entries;
  for (var ii = 0, len = entries.length; ii < len; ii++) {
    if (is(key, entries[ii][0])) {
      return entries[ii][1];
    }
  }
  return notSetValue;
};

ArrayMapNode.prototype.update = function update (ownerID, shift, keyHash, key, value, didChangeSize, didAlter) {
  var removed = value === NOT_SET;

  var entries = this.entries;
  var idx = 0;
  var len = entries.length;
  for (; idx < len; idx++) {
    if (is(key, entries[idx][0])) {
      break;
    }
  }
  var exists = idx < len;

  if (exists ? entries[idx][1] === value : removed) {
    return this;
  }

  SetRef(didAlter);
  (removed || !exists) && SetRef(didChangeSize);

  if (removed && entries.length === 1) {
    return; // undefined
  }

  if (!exists && !removed && entries.length >= MAX_ARRAY_MAP_SIZE) {
    return createNodes(ownerID, entries, key, value);
  }

  var isEditable = ownerID && ownerID === this.ownerID;
  var newEntries = isEditable ? entries : arrCopy(entries);

  if (exists) {
    if (removed) {
      idx === len - 1
        ? newEntries.pop()
        : (newEntries[idx] = newEntries.pop());
    } else {
      newEntries[idx] = [key, value];
    }
  } else {
    newEntries.push([key, value]);
  }

  if (isEditable) {
    this.entries = newEntries;
    return this;
  }

  return new ArrayMapNode(ownerID, newEntries);
};

var BitmapIndexedNode = function BitmapIndexedNode(ownerID, bitmap, nodes) {
  this.ownerID = ownerID;
  this.bitmap = bitmap;
  this.nodes = nodes;
};

BitmapIndexedNode.prototype.get = function get (shift, keyHash, key, notSetValue) {
  if (keyHash === undefined) {
    keyHash = hash(key);
  }
  var bit = 1 << ((shift === 0 ? keyHash : keyHash >>> shift) & MASK);
  var bitmap = this.bitmap;
  return (bitmap & bit) === 0
    ? notSetValue
    : this.nodes[popCount(bitmap & (bit - 1))].get(
        shift + SHIFT,
        keyHash,
        key,
        notSetValue
      );
};

BitmapIndexedNode.prototype.update = function update (ownerID, shift, keyHash, key, value, didChangeSize, didAlter) {
  if (keyHash === undefined) {
    keyHash = hash(key);
  }
  var keyHashFrag = (shift === 0 ? keyHash : keyHash >>> shift) & MASK;
  var bit = 1 << keyHashFrag;
  var bitmap = this.bitmap;
  var exists = (bitmap & bit) !== 0;

  if (!exists && value === NOT_SET) {
    return this;
  }

  var idx = popCount(bitmap & (bit - 1));
  var nodes = this.nodes;
  var node = exists ? nodes[idx] : undefined;
  var newNode = updateNode(
    node,
    ownerID,
    shift + SHIFT,
    keyHash,
    key,
    value,
    didChangeSize,
    didAlter
  );

  if (newNode === node) {
    return this;
  }

  if (!exists && newNode && nodes.length >= MAX_BITMAP_INDEXED_SIZE) {
    return expandNodes(ownerID, nodes, bitmap, keyHashFrag, newNode);
  }

  if (
    exists &&
    !newNode &&
    nodes.length === 2 &&
    isLeafNode(nodes[idx ^ 1])
  ) {
    return nodes[idx ^ 1];
  }

  if (exists && newNode && nodes.length === 1 && isLeafNode(newNode)) {
    return newNode;
  }

  var isEditable = ownerID && ownerID === this.ownerID;
  var newBitmap = exists ? (newNode ? bitmap : bitmap ^ bit) : bitmap | bit;
  var newNodes = exists
    ? newNode
      ? setAt(nodes, idx, newNode, isEditable)
      : spliceOut(nodes, idx, isEditable)
    : spliceIn(nodes, idx, newNode, isEditable);

  if (isEditable) {
    this.bitmap = newBitmap;
    this.nodes = newNodes;
    return this;
  }

  return new BitmapIndexedNode(ownerID, newBitmap, newNodes);
};

var HashArrayMapNode = function HashArrayMapNode(ownerID, count, nodes) {
  this.ownerID = ownerID;
  this.count = count;
  this.nodes = nodes;
};

HashArrayMapNode.prototype.get = function get (shift, keyHash, key, notSetValue) {
  if (keyHash === undefined) {
    keyHash = hash(key);
  }
  var idx = (shift === 0 ? keyHash : keyHash >>> shift) & MASK;
  var node = this.nodes[idx];
  return node
    ? node.get(shift + SHIFT, keyHash, key, notSetValue)
    : notSetValue;
};

HashArrayMapNode.prototype.update = function update (ownerID, shift, keyHash, key, value, didChangeSize, didAlter) {
  if (keyHash === undefined) {
    keyHash = hash(key);
  }
  var idx = (shift === 0 ? keyHash : keyHash >>> shift) & MASK;
  var removed = value === NOT_SET;
  var nodes = this.nodes;
  var node = nodes[idx];

  if (removed && !node) {
    return this;
  }

  var newNode = updateNode(
    node,
    ownerID,
    shift + SHIFT,
    keyHash,
    key,
    value,
    didChangeSize,
    didAlter
  );
  if (newNode === node) {
    return this;
  }

  var newCount = this.count;
  if (!node) {
    newCount++;
  } else if (!newNode) {
    newCount--;
    if (newCount < MIN_HASH_ARRAY_MAP_SIZE) {
      return packNodes(ownerID, nodes, newCount, idx);
    }
  }

  var isEditable = ownerID && ownerID === this.ownerID;
  var newNodes = setAt(nodes, idx, newNode, isEditable);

  if (isEditable) {
    this.count = newCount;
    this.nodes = newNodes;
    return this;
  }

  return new HashArrayMapNode(ownerID, newCount, newNodes);
};

var HashCollisionNode = function HashCollisionNode(ownerID, keyHash, entries) {
  this.ownerID = ownerID;
  this.keyHash = keyHash;
  this.entries = entries;
};

HashCollisionNode.prototype.get = function get (shift, keyHash, key, notSetValue) {
  var entries = this.entries;
  for (var ii = 0, len = entries.length; ii < len; ii++) {
    if (is(key, entries[ii][0])) {
      return entries[ii][1];
    }
  }
  return notSetValue;
};

HashCollisionNode.prototype.update = function update (ownerID, shift, keyHash, key, value, didChangeSize, didAlter) {
  if (keyHash === undefined) {
    keyHash = hash(key);
  }

  var removed = value === NOT_SET;

  if (keyHash !== this.keyHash) {
    if (removed) {
      return this;
    }
    SetRef(didAlter);
    SetRef(didChangeSize);
    return mergeIntoNode(this, ownerID, shift, keyHash, [key, value]);
  }

  var entries = this.entries;
  var idx = 0;
  var len = entries.length;
  for (; idx < len; idx++) {
    if (is(key, entries[idx][0])) {
      break;
    }
  }
  var exists = idx < len;

  if (exists ? entries[idx][1] === value : removed) {
    return this;
  }

  SetRef(didAlter);
  (removed || !exists) && SetRef(didChangeSize);

  if (removed && len === 2) {
    return new ValueNode(ownerID, this.keyHash, entries[idx ^ 1]);
  }

  var isEditable = ownerID && ownerID === this.ownerID;
  var newEntries = isEditable ? entries : arrCopy(entries);

  if (exists) {
    if (removed) {
      idx === len - 1
        ? newEntries.pop()
        : (newEntries[idx] = newEntries.pop());
    } else {
      newEntries[idx] = [key, value];
    }
  } else {
    newEntries.push([key, value]);
  }

  if (isEditable) {
    this.entries = newEntries;
    return this;
  }

  return new HashCollisionNode(ownerID, this.keyHash, newEntries);
};

var ValueNode = function ValueNode(ownerID, keyHash, entry) {
  this.ownerID = ownerID;
  this.keyHash = keyHash;
  this.entry = entry;
};

ValueNode.prototype.get = function get (shift, keyHash, key, notSetValue) {
  return is(key, this.entry[0]) ? this.entry[1] : notSetValue;
};

ValueNode.prototype.update = function update (ownerID, shift, keyHash, key, value, didChangeSize, didAlter) {
  var removed = value === NOT_SET;
  var keyMatch = is(key, this.entry[0]);
  if (keyMatch ? value === this.entry[1] : removed) {
    return this;
  }

  SetRef(didAlter);

  if (removed) {
    SetRef(didChangeSize);
    return; // undefined
  }

  if (keyMatch) {
    if (ownerID && ownerID === this.ownerID) {
      this.entry[1] = value;
      return this;
    }
    return new ValueNode(ownerID, this.keyHash, [key, value]);
  }

  SetRef(didChangeSize);
  return mergeIntoNode(this, ownerID, shift, hash(key), [key, value]);
};

// #pragma Iterators

ArrayMapNode.prototype.iterate = HashCollisionNode.prototype.iterate =
  function (fn, reverse) {
    var entries = this.entries;
    for (var ii = 0, maxIndex = entries.length - 1; ii <= maxIndex; ii++) {
      if (fn(entries[reverse ? maxIndex - ii : ii]) === false) {
        return false;
      }
    }
  };

BitmapIndexedNode.prototype.iterate = HashArrayMapNode.prototype.iterate =
  function (fn, reverse) {
    var nodes = this.nodes;
    for (var ii = 0, maxIndex = nodes.length - 1; ii <= maxIndex; ii++) {
      var node = nodes[reverse ? maxIndex - ii : ii];
      if (node && node.iterate(fn, reverse) === false) {
        return false;
      }
    }
  };

// eslint-disable-next-line no-unused-vars
ValueNode.prototype.iterate = function (fn, reverse) {
  return fn(this.entry);
};

var MapIterator = /*@__PURE__*/(function (Iterator) {
  function MapIterator(map, type, reverse) {
    this._type = type;
    this._reverse = reverse;
    this._stack = map._root && mapIteratorFrame(map._root);
  }

  if ( Iterator ) MapIterator.__proto__ = Iterator;
  MapIterator.prototype = Object.create( Iterator && Iterator.prototype );
  MapIterator.prototype.constructor = MapIterator;

  MapIterator.prototype.next = function next () {
    var type = this._type;
    var stack = this._stack;
    while (stack) {
      var node = stack.node;
      var index = stack.index++;
      var maxIndex = (void 0);
      if (node.entry) {
        if (index === 0) {
          return mapIteratorValue(type, node.entry);
        }
      } else if (node.entries) {
        maxIndex = node.entries.length - 1;
        if (index <= maxIndex) {
          return mapIteratorValue(
            type,
            node.entries[this._reverse ? maxIndex - index : index]
          );
        }
      } else {
        maxIndex = node.nodes.length - 1;
        if (index <= maxIndex) {
          var subNode = node.nodes[this._reverse ? maxIndex - index : index];
          if (subNode) {
            if (subNode.entry) {
              return mapIteratorValue(type, subNode.entry);
            }
            stack = this._stack = mapIteratorFrame(subNode, stack);
          }
          continue;
        }
      }
      stack = this._stack = this._stack.__prev;
    }
    return iteratorDone();
  };

  return MapIterator;
}(Iterator));

function mapIteratorValue(type, entry) {
  return iteratorValue(type, entry[0], entry[1]);
}

function mapIteratorFrame(node, prev) {
  return {
    node: node,
    index: 0,
    __prev: prev,
  };
}

function makeMap(size, root, ownerID, hash) {
  var map = Object.create(MapPrototype);
  map.size = size;
  map._root = root;
  map.__ownerID = ownerID;
  map.__hash = hash;
  map.__altered = false;
  return map;
}

var EMPTY_MAP;
function emptyMap() {
  return EMPTY_MAP || (EMPTY_MAP = makeMap(0));
}

function updateMap(map, k, v) {
  var newRoot;
  var newSize;
  if (!map._root) {
    if (v === NOT_SET) {
      return map;
    }
    newSize = 1;
    newRoot = new ArrayMapNode(map.__ownerID, [[k, v]]);
  } else {
    var didChangeSize = MakeRef();
    var didAlter = MakeRef();
    newRoot = updateNode(
      map._root,
      map.__ownerID,
      0,
      undefined,
      k,
      v,
      didChangeSize,
      didAlter
    );
    if (!didAlter.value) {
      return map;
    }
    newSize = map.size + (didChangeSize.value ? (v === NOT_SET ? -1 : 1) : 0);
  }
  if (map.__ownerID) {
    map.size = newSize;
    map._root = newRoot;
    map.__hash = undefined;
    map.__altered = true;
    return map;
  }
  return newRoot ? makeMap(newSize, newRoot) : emptyMap();
}

function updateNode(
  node,
  ownerID,
  shift,
  keyHash,
  key,
  value,
  didChangeSize,
  didAlter
) {
  if (!node) {
    if (value === NOT_SET) {
      return node;
    }
    SetRef(didAlter);
    SetRef(didChangeSize);
    return new ValueNode(ownerID, keyHash, [key, value]);
  }
  return node.update(
    ownerID,
    shift,
    keyHash,
    key,
    value,
    didChangeSize,
    didAlter
  );
}

function isLeafNode(node) {
  return (
    node.constructor === ValueNode || node.constructor === HashCollisionNode
  );
}

function mergeIntoNode(node, ownerID, shift, keyHash, entry) {
  if (node.keyHash === keyHash) {
    return new HashCollisionNode(ownerID, keyHash, [node.entry, entry]);
  }

  var idx1 = (shift === 0 ? node.keyHash : node.keyHash >>> shift) & MASK;
  var idx2 = (shift === 0 ? keyHash : keyHash >>> shift) & MASK;

  var newNode;
  var nodes =
    idx1 === idx2
      ? [mergeIntoNode(node, ownerID, shift + SHIFT, keyHash, entry)]
      : ((newNode = new ValueNode(ownerID, keyHash, entry)),
        idx1 < idx2 ? [node, newNode] : [newNode, node]);

  return new BitmapIndexedNode(ownerID, (1 << idx1) | (1 << idx2), nodes);
}

function createNodes(ownerID, entries, key, value) {
  if (!ownerID) {
    ownerID = new OwnerID();
  }
  var node = new ValueNode(ownerID, hash(key), [key, value]);
  for (var ii = 0; ii < entries.length; ii++) {
    var entry = entries[ii];
    node = node.update(ownerID, 0, undefined, entry[0], entry[1]);
  }
  return node;
}

function packNodes(ownerID, nodes, count, excluding) {
  var bitmap = 0;
  var packedII = 0;
  var packedNodes = new Array(count);
  for (var ii = 0, bit = 1, len = nodes.length; ii < len; ii++, bit <<= 1) {
    var node = nodes[ii];
    if (node !== undefined && ii !== excluding) {
      bitmap |= bit;
      packedNodes[packedII++] = node;
    }
  }
  return new BitmapIndexedNode(ownerID, bitmap, packedNodes);
}

function expandNodes(ownerID, nodes, bitmap, including, node) {
  var count = 0;
  var expandedNodes = new Array(SIZE);
  for (var ii = 0; bitmap !== 0; ii++, bitmap >>>= 1) {
    expandedNodes[ii] = bitmap & 1 ? nodes[count++] : undefined;
  }
  expandedNodes[including] = node;
  return new HashArrayMapNode(ownerID, count + 1, expandedNodes);
}

function popCount(x) {
  x -= (x >> 1) & 0x55555555;
  x = (x & 0x33333333) + ((x >> 2) & 0x33333333);
  x = (x + (x >> 4)) & 0x0f0f0f0f;
  x += x >> 8;
  x += x >> 16;
  return x & 0x7f;
}

function setAt(array, idx, val, canEdit) {
  var newArray = canEdit ? array : arrCopy(array);
  newArray[idx] = val;
  return newArray;
}

function spliceIn(array, idx, val, canEdit) {
  var newLen = array.length + 1;
  if (canEdit && idx + 1 === newLen) {
    array[idx] = val;
    return array;
  }
  var newArray = new Array(newLen);
  var after = 0;
  for (var ii = 0; ii < newLen; ii++) {
    if (ii === idx) {
      newArray[ii] = val;
      after = -1;
    } else {
      newArray[ii] = array[ii + after];
    }
  }
  return newArray;
}

function spliceOut(array, idx, canEdit) {
  var newLen = array.length - 1;
  if (canEdit && idx === newLen) {
    array.pop();
    return array;
  }
  var newArray = new Array(newLen);
  var after = 0;
  for (var ii = 0; ii < newLen; ii++) {
    if (ii === idx) {
      after = 1;
    }
    newArray[ii] = array[ii + after];
  }
  return newArray;
}

var MAX_ARRAY_MAP_SIZE = SIZE / 4;
var MAX_BITMAP_INDEXED_SIZE = SIZE / 2;
var MIN_HASH_ARRAY_MAP_SIZE = SIZE / 4;

var IS_LIST_SYMBOL = '@@__IMMUTABLE_LIST__@@';

function isList(maybeList) {
  return Boolean(maybeList && maybeList[IS_LIST_SYMBOL]);
}

var List = /*@__PURE__*/(function (IndexedCollection) {
  function List(value) {
    var empty = emptyList();
    if (value === null || value === undefined) {
      return empty;
    }
    if (isList(value)) {
      return value;
    }
    var iter = IndexedCollection(value);
    var size = iter.size;
    if (size === 0) {
      return empty;
    }
    assertNotInfinite(size);
    if (size > 0 && size < SIZE) {
      return makeList(0, size, SHIFT, null, new VNode(iter.toArray()));
    }
    return empty.withMutations(function (list) {
      list.setSize(size);
      iter.forEach(function (v, i) { return list.set(i, v); });
    });
  }

  if ( IndexedCollection ) List.__proto__ = IndexedCollection;
  List.prototype = Object.create( IndexedCollection && IndexedCollection.prototype );
  List.prototype.constructor = List;

  List.of = function of (/*...values*/) {
    return this(arguments);
  };

  List.prototype.toString = function toString () {
    return this.__toString('List [', ']');
  };

  // @pragma Access

  List.prototype.get = function get (index, notSetValue) {
    index = wrapIndex(this, index);
    if (index >= 0 && index < this.size) {
      index += this._origin;
      var node = listNodeFor(this, index);
      return node && node.array[index & MASK];
    }
    return notSetValue;
  };

  // @pragma Modification

  List.prototype.set = function set (index, value) {
    return updateList(this, index, value);
  };

  List.prototype.remove = function remove (index) {
    return !this.has(index)
      ? this
      : index === 0
      ? this.shift()
      : index === this.size - 1
      ? this.pop()
      : this.splice(index, 1);
  };

  List.prototype.insert = function insert (index, value) {
    return this.splice(index, 0, value);
  };

  List.prototype.clear = function clear () {
    if (this.size === 0) {
      return this;
    }
    if (this.__ownerID) {
      this.size = this._origin = this._capacity = 0;
      this._level = SHIFT;
      this._root = this._tail = this.__hash = undefined;
      this.__altered = true;
      return this;
    }
    return emptyList();
  };

  List.prototype.push = function push (/*...values*/) {
    var values = arguments;
    var oldSize = this.size;
    return this.withMutations(function (list) {
      setListBounds(list, 0, oldSize + values.length);
      for (var ii = 0; ii < values.length; ii++) {
        list.set(oldSize + ii, values[ii]);
      }
    });
  };

  List.prototype.pop = function pop () {
    return setListBounds(this, 0, -1);
  };

  List.prototype.unshift = function unshift (/*...values*/) {
    var values = arguments;
    return this.withMutations(function (list) {
      setListBounds(list, -values.length);
      for (var ii = 0; ii < values.length; ii++) {
        list.set(ii, values[ii]);
      }
    });
  };

  List.prototype.shift = function shift () {
    return setListBounds(this, 1);
  };

  // @pragma Composition

  List.prototype.concat = function concat (/*...collections*/) {
    var arguments$1 = arguments;

    var seqs = [];
    for (var i = 0; i < arguments.length; i++) {
      var argument = arguments$1[i];
      var seq = IndexedCollection(
        typeof argument !== 'string' && hasIterator(argument)
          ? argument
          : [argument]
      );
      if (seq.size !== 0) {
        seqs.push(seq);
      }
    }
    if (seqs.length === 0) {
      return this;
    }
    if (this.size === 0 && !this.__ownerID && seqs.length === 1) {
      return this.constructor(seqs[0]);
    }
    return this.withMutations(function (list) {
      seqs.forEach(function (seq) { return seq.forEach(function (value) { return list.push(value); }); });
    });
  };

  List.prototype.setSize = function setSize (size) {
    return setListBounds(this, 0, size);
  };

  List.prototype.map = function map (mapper, context) {
    var this$1$1 = this;

    return this.withMutations(function (list) {
      for (var i = 0; i < this$1$1.size; i++) {
        list.set(i, mapper.call(context, list.get(i), i, this$1$1));
      }
    });
  };

  // @pragma Iteration

  List.prototype.slice = function slice (begin, end) {
    var size = this.size;
    if (wholeSlice(begin, end, size)) {
      return this;
    }
    return setListBounds(
      this,
      resolveBegin(begin, size),
      resolveEnd(end, size)
    );
  };

  List.prototype.__iterator = function __iterator (type, reverse) {
    var index = reverse ? this.size : 0;
    var values = iterateList(this, reverse);
    return new Iterator(function () {
      var value = values();
      return value === DONE
        ? iteratorDone()
        : iteratorValue(type, reverse ? --index : index++, value);
    });
  };

  List.prototype.__iterate = function __iterate (fn, reverse) {
    var index = reverse ? this.size : 0;
    var values = iterateList(this, reverse);
    var value;
    while ((value = values()) !== DONE) {
      if (fn(value, reverse ? --index : index++, this) === false) {
        break;
      }
    }
    return index;
  };

  List.prototype.__ensureOwner = function __ensureOwner (ownerID) {
    if (ownerID === this.__ownerID) {
      return this;
    }
    if (!ownerID) {
      if (this.size === 0) {
        return emptyList();
      }
      this.__ownerID = ownerID;
      this.__altered = false;
      return this;
    }
    return makeList(
      this._origin,
      this._capacity,
      this._level,
      this._root,
      this._tail,
      ownerID,
      this.__hash
    );
  };

  return List;
}(IndexedCollection));

List.isList = isList;

var ListPrototype = List.prototype;
ListPrototype[IS_LIST_SYMBOL] = true;
ListPrototype[DELETE] = ListPrototype.remove;
ListPrototype.merge = ListPrototype.concat;
ListPrototype.setIn = setIn;
ListPrototype.deleteIn = ListPrototype.removeIn = deleteIn;
ListPrototype.update = update;
ListPrototype.updateIn = updateIn;
ListPrototype.mergeIn = mergeIn;
ListPrototype.mergeDeepIn = mergeDeepIn;
ListPrototype.withMutations = withMutations;
ListPrototype.wasAltered = wasAltered;
ListPrototype.asImmutable = asImmutable;
ListPrototype['@@transducer/init'] = ListPrototype.asMutable = asMutable;
ListPrototype['@@transducer/step'] = function (result, arr) {
  return result.push(arr);
};
ListPrototype['@@transducer/result'] = function (obj) {
  return obj.asImmutable();
};

var VNode = function VNode(array, ownerID) {
  this.array = array;
  this.ownerID = ownerID;
};

// TODO: seems like these methods are very similar

VNode.prototype.removeBefore = function removeBefore (ownerID, level, index) {
  if (index === level ? 1 << level : this.array.length === 0) {
    return this;
  }
  var originIndex = (index >>> level) & MASK;
  if (originIndex >= this.array.length) {
    return new VNode([], ownerID);
  }
  var removingFirst = originIndex === 0;
  var newChild;
  if (level > 0) {
    var oldChild = this.array[originIndex];
    newChild =
      oldChild && oldChild.removeBefore(ownerID, level - SHIFT, index);
    if (newChild === oldChild && removingFirst) {
      return this;
    }
  }
  if (removingFirst && !newChild) {
    return this;
  }
  var editable = editableVNode(this, ownerID);
  if (!removingFirst) {
    for (var ii = 0; ii < originIndex; ii++) {
      editable.array[ii] = undefined;
    }
  }
  if (newChild) {
    editable.array[originIndex] = newChild;
  }
  return editable;
};

VNode.prototype.removeAfter = function removeAfter (ownerID, level, index) {
  if (index === (level ? 1 << level : 0) || this.array.length === 0) {
    return this;
  }
  var sizeIndex = ((index - 1) >>> level) & MASK;
  if (sizeIndex >= this.array.length) {
    return this;
  }

  var newChild;
  if (level > 0) {
    var oldChild = this.array[sizeIndex];
    newChild =
      oldChild && oldChild.removeAfter(ownerID, level - SHIFT, index);
    if (newChild === oldChild && sizeIndex === this.array.length - 1) {
      return this;
    }
  }

  var editable = editableVNode(this, ownerID);
  editable.array.splice(sizeIndex + 1);
  if (newChild) {
    editable.array[sizeIndex] = newChild;
  }
  return editable;
};

var DONE = {};

function iterateList(list, reverse) {
  var left = list._origin;
  var right = list._capacity;
  var tailPos = getTailOffset(right);
  var tail = list._tail;

  return iterateNodeOrLeaf(list._root, list._level, 0);

  function iterateNodeOrLeaf(node, level, offset) {
    return level === 0
      ? iterateLeaf(node, offset)
      : iterateNode(node, level, offset);
  }

  function iterateLeaf(node, offset) {
    var array = offset === tailPos ? tail && tail.array : node && node.array;
    var from = offset > left ? 0 : left - offset;
    var to = right - offset;
    if (to > SIZE) {
      to = SIZE;
    }
    return function () {
      if (from === to) {
        return DONE;
      }
      var idx = reverse ? --to : from++;
      return array && array[idx];
    };
  }

  function iterateNode(node, level, offset) {
    var values;
    var array = node && node.array;
    var from = offset > left ? 0 : (left - offset) >> level;
    var to = ((right - offset) >> level) + 1;
    if (to > SIZE) {
      to = SIZE;
    }
    return function () {
      while (true) {
        if (values) {
          var value = values();
          if (value !== DONE) {
            return value;
          }
          values = null;
        }
        if (from === to) {
          return DONE;
        }
        var idx = reverse ? --to : from++;
        values = iterateNodeOrLeaf(
          array && array[idx],
          level - SHIFT,
          offset + (idx << level)
        );
      }
    };
  }
}

function makeList(origin, capacity, level, root, tail, ownerID, hash) {
  var list = Object.create(ListPrototype);
  list.size = capacity - origin;
  list._origin = origin;
  list._capacity = capacity;
  list._level = level;
  list._root = root;
  list._tail = tail;
  list.__ownerID = ownerID;
  list.__hash = hash;
  list.__altered = false;
  return list;
}

var EMPTY_LIST;
function emptyList() {
  return EMPTY_LIST || (EMPTY_LIST = makeList(0, 0, SHIFT));
}

function updateList(list, index, value) {
  index = wrapIndex(list, index);

  if (index !== index) {
    return list;
  }

  if (index >= list.size || index < 0) {
    return list.withMutations(function (list) {
      index < 0
        ? setListBounds(list, index).set(0, value)
        : setListBounds(list, 0, index + 1).set(index, value);
    });
  }

  index += list._origin;

  var newTail = list._tail;
  var newRoot = list._root;
  var didAlter = MakeRef();
  if (index >= getTailOffset(list._capacity)) {
    newTail = updateVNode(newTail, list.__ownerID, 0, index, value, didAlter);
  } else {
    newRoot = updateVNode(
      newRoot,
      list.__ownerID,
      list._level,
      index,
      value,
      didAlter
    );
  }

  if (!didAlter.value) {
    return list;
  }

  if (list.__ownerID) {
    list._root = newRoot;
    list._tail = newTail;
    list.__hash = undefined;
    list.__altered = true;
    return list;
  }
  return makeList(list._origin, list._capacity, list._level, newRoot, newTail);
}

function updateVNode(node, ownerID, level, index, value, didAlter) {
  var idx = (index >>> level) & MASK;
  var nodeHas = node && idx < node.array.length;
  if (!nodeHas && value === undefined) {
    return node;
  }

  var newNode;

  if (level > 0) {
    var lowerNode = node && node.array[idx];
    var newLowerNode = updateVNode(
      lowerNode,
      ownerID,
      level - SHIFT,
      index,
      value,
      didAlter
    );
    if (newLowerNode === lowerNode) {
      return node;
    }
    newNode = editableVNode(node, ownerID);
    newNode.array[idx] = newLowerNode;
    return newNode;
  }

  if (nodeHas && node.array[idx] === value) {
    return node;
  }

  if (didAlter) {
    SetRef(didAlter);
  }

  newNode = editableVNode(node, ownerID);
  if (value === undefined && idx === newNode.array.length - 1) {
    newNode.array.pop();
  } else {
    newNode.array[idx] = value;
  }
  return newNode;
}

function editableVNode(node, ownerID) {
  if (ownerID && node && ownerID === node.ownerID) {
    return node;
  }
  return new VNode(node ? node.array.slice() : [], ownerID);
}

function listNodeFor(list, rawIndex) {
  if (rawIndex >= getTailOffset(list._capacity)) {
    return list._tail;
  }
  if (rawIndex < 1 << (list._level + SHIFT)) {
    var node = list._root;
    var level = list._level;
    while (node && level > 0) {
      node = node.array[(rawIndex >>> level) & MASK];
      level -= SHIFT;
    }
    return node;
  }
}

function setListBounds(list, begin, end) {
  // Sanitize begin & end using this shorthand for ToInt32(argument)
  // http://www.ecma-international.org/ecma-262/6.0/#sec-toint32
  if (begin !== undefined) {
    begin |= 0;
  }
  if (end !== undefined) {
    end |= 0;
  }
  var owner = list.__ownerID || new OwnerID();
  var oldOrigin = list._origin;
  var oldCapacity = list._capacity;
  var newOrigin = oldOrigin + begin;
  var newCapacity =
    end === undefined
      ? oldCapacity
      : end < 0
      ? oldCapacity + end
      : oldOrigin + end;
  if (newOrigin === oldOrigin && newCapacity === oldCapacity) {
    return list;
  }

  // If it's going to end after it starts, it's empty.
  if (newOrigin >= newCapacity) {
    return list.clear();
  }

  var newLevel = list._level;
  var newRoot = list._root;

  // New origin might need creating a higher root.
  var offsetShift = 0;
  while (newOrigin + offsetShift < 0) {
    newRoot = new VNode(
      newRoot && newRoot.array.length ? [undefined, newRoot] : [],
      owner
    );
    newLevel += SHIFT;
    offsetShift += 1 << newLevel;
  }
  if (offsetShift) {
    newOrigin += offsetShift;
    oldOrigin += offsetShift;
    newCapacity += offsetShift;
    oldCapacity += offsetShift;
  }

  var oldTailOffset = getTailOffset(oldCapacity);
  var newTailOffset = getTailOffset(newCapacity);

  // New size might need creating a higher root.
  while (newTailOffset >= 1 << (newLevel + SHIFT)) {
    newRoot = new VNode(
      newRoot && newRoot.array.length ? [newRoot] : [],
      owner
    );
    newLevel += SHIFT;
  }

  // Locate or create the new tail.
  var oldTail = list._tail;
  var newTail =
    newTailOffset < oldTailOffset
      ? listNodeFor(list, newCapacity - 1)
      : newTailOffset > oldTailOffset
      ? new VNode([], owner)
      : oldTail;

  // Merge Tail into tree.
  if (
    oldTail &&
    newTailOffset > oldTailOffset &&
    newOrigin < oldCapacity &&
    oldTail.array.length
  ) {
    newRoot = editableVNode(newRoot, owner);
    var node = newRoot;
    for (var level = newLevel; level > SHIFT; level -= SHIFT) {
      var idx = (oldTailOffset >>> level) & MASK;
      node = node.array[idx] = editableVNode(node.array[idx], owner);
    }
    node.array[(oldTailOffset >>> SHIFT) & MASK] = oldTail;
  }

  // If the size has been reduced, there's a chance the tail needs to be trimmed.
  if (newCapacity < oldCapacity) {
    newTail = newTail && newTail.removeAfter(owner, 0, newCapacity);
  }

  // If the new origin is within the tail, then we do not need a root.
  if (newOrigin >= newTailOffset) {
    newOrigin -= newTailOffset;
    newCapacity -= newTailOffset;
    newLevel = SHIFT;
    newRoot = null;
    newTail = newTail && newTail.removeBefore(owner, 0, newOrigin);

    // Otherwise, if the root has been trimmed, garbage collect.
  } else if (newOrigin > oldOrigin || newTailOffset < oldTailOffset) {
    offsetShift = 0;

    // Identify the new top root node of the subtree of the old root.
    while (newRoot) {
      var beginIndex = (newOrigin >>> newLevel) & MASK;
      if ((beginIndex !== newTailOffset >>> newLevel) & MASK) {
        break;
      }
      if (beginIndex) {
        offsetShift += (1 << newLevel) * beginIndex;
      }
      newLevel -= SHIFT;
      newRoot = newRoot.array[beginIndex];
    }

    // Trim the new sides of the new root.
    if (newRoot && newOrigin > oldOrigin) {
      newRoot = newRoot.removeBefore(owner, newLevel, newOrigin - offsetShift);
    }
    if (newRoot && newTailOffset < oldTailOffset) {
      newRoot = newRoot.removeAfter(
        owner,
        newLevel,
        newTailOffset - offsetShift
      );
    }
    if (offsetShift) {
      newOrigin -= offsetShift;
      newCapacity -= offsetShift;
    }
  }

  if (list.__ownerID) {
    list.size = newCapacity - newOrigin;
    list._origin = newOrigin;
    list._capacity = newCapacity;
    list._level = newLevel;
    list._root = newRoot;
    list._tail = newTail;
    list.__hash = undefined;
    list.__altered = true;
    return list;
  }
  return makeList(newOrigin, newCapacity, newLevel, newRoot, newTail);
}

function getTailOffset(size) {
  return size < SIZE ? 0 : ((size - 1) >>> SHIFT) << SHIFT;
}

var OrderedMap = /*@__PURE__*/(function (Map) {
  function OrderedMap(value) {
    return value === null || value === undefined
      ? emptyOrderedMap()
      : isOrderedMap(value)
      ? value
      : emptyOrderedMap().withMutations(function (map) {
          var iter = KeyedCollection(value);
          assertNotInfinite(iter.size);
          iter.forEach(function (v, k) { return map.set(k, v); });
        });
  }

  if ( Map ) OrderedMap.__proto__ = Map;
  OrderedMap.prototype = Object.create( Map && Map.prototype );
  OrderedMap.prototype.constructor = OrderedMap;

  OrderedMap.of = function of (/*...values*/) {
    return this(arguments);
  };

  OrderedMap.prototype.toString = function toString () {
    return this.__toString('OrderedMap {', '}');
  };

  // @pragma Access

  OrderedMap.prototype.get = function get (k, notSetValue) {
    var index = this._map.get(k);
    return index !== undefined ? this._list.get(index)[1] : notSetValue;
  };

  // @pragma Modification

  OrderedMap.prototype.clear = function clear () {
    if (this.size === 0) {
      return this;
    }
    if (this.__ownerID) {
      this.size = 0;
      this._map.clear();
      this._list.clear();
      this.__altered = true;
      return this;
    }
    return emptyOrderedMap();
  };

  OrderedMap.prototype.set = function set (k, v) {
    return updateOrderedMap(this, k, v);
  };

  OrderedMap.prototype.remove = function remove (k) {
    return updateOrderedMap(this, k, NOT_SET);
  };

  OrderedMap.prototype.__iterate = function __iterate (fn, reverse) {
    var this$1$1 = this;

    return this._list.__iterate(
      function (entry) { return entry && fn(entry[1], entry[0], this$1$1); },
      reverse
    );
  };

  OrderedMap.prototype.__iterator = function __iterator (type, reverse) {
    return this._list.fromEntrySeq().__iterator(type, reverse);
  };

  OrderedMap.prototype.__ensureOwner = function __ensureOwner (ownerID) {
    if (ownerID === this.__ownerID) {
      return this;
    }
    var newMap = this._map.__ensureOwner(ownerID);
    var newList = this._list.__ensureOwner(ownerID);
    if (!ownerID) {
      if (this.size === 0) {
        return emptyOrderedMap();
      }
      this.__ownerID = ownerID;
      this.__altered = false;
      this._map = newMap;
      this._list = newList;
      return this;
    }
    return makeOrderedMap(newMap, newList, ownerID, this.__hash);
  };

  return OrderedMap;
}(Map));

OrderedMap.isOrderedMap = isOrderedMap;

OrderedMap.prototype[IS_ORDERED_SYMBOL] = true;
OrderedMap.prototype[DELETE] = OrderedMap.prototype.remove;

function makeOrderedMap(map, list, ownerID, hash) {
  var omap = Object.create(OrderedMap.prototype);
  omap.size = map ? map.size : 0;
  omap._map = map;
  omap._list = list;
  omap.__ownerID = ownerID;
  omap.__hash = hash;
  omap.__altered = false;
  return omap;
}

var EMPTY_ORDERED_MAP;
function emptyOrderedMap() {
  return (
    EMPTY_ORDERED_MAP ||
    (EMPTY_ORDERED_MAP = makeOrderedMap(emptyMap(), emptyList()))
  );
}

function updateOrderedMap(omap, k, v) {
  var map = omap._map;
  var list = omap._list;
  var i = map.get(k);
  var has = i !== undefined;
  var newMap;
  var newList;
  if (v === NOT_SET) {
    // removed
    if (!has) {
      return omap;
    }
    if (list.size >= SIZE && list.size >= map.size * 2) {
      newList = list.filter(function (entry, idx) { return entry !== undefined && i !== idx; });
      newMap = newList
        .toKeyedSeq()
        .map(function (entry) { return entry[0]; })
        .flip()
        .toMap();
      if (omap.__ownerID) {
        newMap.__ownerID = newList.__ownerID = omap.__ownerID;
      }
    } else {
      newMap = map.remove(k);
      newList = i === list.size - 1 ? list.pop() : list.set(i, undefined);
    }
  } else if (has) {
    if (v === list.get(i)[1]) {
      return omap;
    }
    newMap = map;
    newList = list.set(i, [k, v]);
  } else {
    newMap = map.set(k, list.size);
    newList = list.set(list.size, [k, v]);
  }
  if (omap.__ownerID) {
    omap.size = newMap.size;
    omap._map = newMap;
    omap._list = newList;
    omap.__hash = undefined;
    omap.__altered = true;
    return omap;
  }
  return makeOrderedMap(newMap, newList);
}

var IS_STACK_SYMBOL = '@@__IMMUTABLE_STACK__@@';

function isStack(maybeStack) {
  return Boolean(maybeStack && maybeStack[IS_STACK_SYMBOL]);
}

var Stack = /*@__PURE__*/(function (IndexedCollection) {
  function Stack(value) {
    return value === null || value === undefined
      ? emptyStack()
      : isStack(value)
      ? value
      : emptyStack().pushAll(value);
  }

  if ( IndexedCollection ) Stack.__proto__ = IndexedCollection;
  Stack.prototype = Object.create( IndexedCollection && IndexedCollection.prototype );
  Stack.prototype.constructor = Stack;

  Stack.of = function of (/*...values*/) {
    return this(arguments);
  };

  Stack.prototype.toString = function toString () {
    return this.__toString('Stack [', ']');
  };

  // @pragma Access

  Stack.prototype.get = function get (index, notSetValue) {
    var head = this._head;
    index = wrapIndex(this, index);
    while (head && index--) {
      head = head.next;
    }
    return head ? head.value : notSetValue;
  };

  Stack.prototype.peek = function peek () {
    return this._head && this._head.value;
  };

  // @pragma Modification

  Stack.prototype.push = function push (/*...values*/) {
    var arguments$1 = arguments;

    if (arguments.length === 0) {
      return this;
    }
    var newSize = this.size + arguments.length;
    var head = this._head;
    for (var ii = arguments.length - 1; ii >= 0; ii--) {
      head = {
        value: arguments$1[ii],
        next: head,
      };
    }
    if (this.__ownerID) {
      this.size = newSize;
      this._head = head;
      this.__hash = undefined;
      this.__altered = true;
      return this;
    }
    return makeStack(newSize, head);
  };

  Stack.prototype.pushAll = function pushAll (iter) {
    iter = IndexedCollection(iter);
    if (iter.size === 0) {
      return this;
    }
    if (this.size === 0 && isStack(iter)) {
      return iter;
    }
    assertNotInfinite(iter.size);
    var newSize = this.size;
    var head = this._head;
    iter.__iterate(function (value) {
      newSize++;
      head = {
        value: value,
        next: head,
      };
    }, /* reverse */ true);
    if (this.__ownerID) {
      this.size = newSize;
      this._head = head;
      this.__hash = undefined;
      this.__altered = true;
      return this;
    }
    return makeStack(newSize, head);
  };

  Stack.prototype.pop = function pop () {
    return this.slice(1);
  };

  Stack.prototype.clear = function clear () {
    if (this.size === 0) {
      return this;
    }
    if (this.__ownerID) {
      this.size = 0;
      this._head = undefined;
      this.__hash = undefined;
      this.__altered = true;
      return this;
    }
    return emptyStack();
  };

  Stack.prototype.slice = function slice (begin, end) {
    if (wholeSlice(begin, end, this.size)) {
      return this;
    }
    var resolvedBegin = resolveBegin(begin, this.size);
    var resolvedEnd = resolveEnd(end, this.size);
    if (resolvedEnd !== this.size) {
      // super.slice(begin, end);
      return IndexedCollection.prototype.slice.call(this, begin, end);
    }
    var newSize = this.size - resolvedBegin;
    var head = this._head;
    while (resolvedBegin--) {
      head = head.next;
    }
    if (this.__ownerID) {
      this.size = newSize;
      this._head = head;
      this.__hash = undefined;
      this.__altered = true;
      return this;
    }
    return makeStack(newSize, head);
  };

  // @pragma Mutability

  Stack.prototype.__ensureOwner = function __ensureOwner (ownerID) {
    if (ownerID === this.__ownerID) {
      return this;
    }
    if (!ownerID) {
      if (this.size === 0) {
        return emptyStack();
      }
      this.__ownerID = ownerID;
      this.__altered = false;
      return this;
    }
    return makeStack(this.size, this._head, ownerID, this.__hash);
  };

  // @pragma Iteration

  Stack.prototype.__iterate = function __iterate (fn, reverse) {
    var this$1$1 = this;

    if (reverse) {
      return new ArraySeq(this.toArray()).__iterate(
        function (v, k) { return fn(v, k, this$1$1); },
        reverse
      );
    }
    var iterations = 0;
    var node = this._head;
    while (node) {
      if (fn(node.value, iterations++, this) === false) {
        break;
      }
      node = node.next;
    }
    return iterations;
  };

  Stack.prototype.__iterator = function __iterator (type, reverse) {
    if (reverse) {
      return new ArraySeq(this.toArray()).__iterator(type, reverse);
    }
    var iterations = 0;
    var node = this._head;
    return new Iterator(function () {
      if (node) {
        var value = node.value;
        node = node.next;
        return iteratorValue(type, iterations++, value);
      }
      return iteratorDone();
    });
  };

  return Stack;
}(IndexedCollection));

Stack.isStack = isStack;

var StackPrototype = Stack.prototype;
StackPrototype[IS_STACK_SYMBOL] = true;
StackPrototype.shift = StackPrototype.pop;
StackPrototype.unshift = StackPrototype.push;
StackPrototype.unshiftAll = StackPrototype.pushAll;
StackPrototype.withMutations = withMutations;
StackPrototype.wasAltered = wasAltered;
StackPrototype.asImmutable = asImmutable;
StackPrototype['@@transducer/init'] = StackPrototype.asMutable = asMutable;
StackPrototype['@@transducer/step'] = function (result, arr) {
  return result.unshift(arr);
};
StackPrototype['@@transducer/result'] = function (obj) {
  return obj.asImmutable();
};

function makeStack(size, head, ownerID, hash) {
  var map = Object.create(StackPrototype);
  map.size = size;
  map._head = head;
  map.__ownerID = ownerID;
  map.__hash = hash;
  map.__altered = false;
  return map;
}

var EMPTY_STACK;
function emptyStack() {
  return EMPTY_STACK || (EMPTY_STACK = makeStack(0));
}

var IS_SET_SYMBOL = '@@__IMMUTABLE_SET__@@';

function isSet(maybeSet) {
  return Boolean(maybeSet && maybeSet[IS_SET_SYMBOL]);
}

function isOrderedSet(maybeOrderedSet) {
  return isSet(maybeOrderedSet) && isOrdered(maybeOrderedSet);
}

function deepEqual(a, b) {
  if (a === b) {
    return true;
  }

  if (
    !isCollection(b) ||
    (a.size !== undefined && b.size !== undefined && a.size !== b.size) ||
    (a.__hash !== undefined &&
      b.__hash !== undefined &&
      a.__hash !== b.__hash) ||
    isKeyed(a) !== isKeyed(b) ||
    isIndexed(a) !== isIndexed(b) ||
    isOrdered(a) !== isOrdered(b)
  ) {
    return false;
  }

  if (a.size === 0 && b.size === 0) {
    return true;
  }

  var notAssociative = !isAssociative(a);

  if (isOrdered(a)) {
    var entries = a.entries();
    return (
      b.every(function (v, k) {
        var entry = entries.next().value;
        return entry && is(entry[1], v) && (notAssociative || is(entry[0], k));
      }) && entries.next().done
    );
  }

  var flipped = false;

  if (a.size === undefined) {
    if (b.size === undefined) {
      if (typeof a.cacheResult === 'function') {
        a.cacheResult();
      }
    } else {
      flipped = true;
      var _ = a;
      a = b;
      b = _;
    }
  }

  var allEqual = true;
  var bSize = b.__iterate(function (v, k) {
    if (
      notAssociative
        ? !a.has(v)
        : flipped
        ? !is(v, a.get(k, NOT_SET))
        : !is(a.get(k, NOT_SET), v)
    ) {
      allEqual = false;
      return false;
    }
  });

  return allEqual && a.size === bSize;
}

function mixin(ctor, methods) {
  var keyCopier = function (key) {
    ctor.prototype[key] = methods[key];
  };
  Object.keys(methods).forEach(keyCopier);
  Object.getOwnPropertySymbols &&
    Object.getOwnPropertySymbols(methods).forEach(keyCopier);
  return ctor;
}

function toJS(value) {
  if (!value || typeof value !== 'object') {
    return value;
  }
  if (!isCollection(value)) {
    if (!isDataStructure(value)) {
      return value;
    }
    value = Seq(value);
  }
  if (isKeyed(value)) {
    var result$1 = {};
    value.__iterate(function (v, k) {
      result$1[k] = toJS(v);
    });
    return result$1;
  }
  var result = [];
  value.__iterate(function (v) {
    result.push(toJS(v));
  });
  return result;
}

var Set = /*@__PURE__*/(function (SetCollection) {
  function Set(value) {
    return value === null || value === undefined
      ? emptySet()
      : isSet(value) && !isOrdered(value)
      ? value
      : emptySet().withMutations(function (set) {
          var iter = SetCollection(value);
          assertNotInfinite(iter.size);
          iter.forEach(function (v) { return set.add(v); });
        });
  }

  if ( SetCollection ) Set.__proto__ = SetCollection;
  Set.prototype = Object.create( SetCollection && SetCollection.prototype );
  Set.prototype.constructor = Set;

  Set.of = function of (/*...values*/) {
    return this(arguments);
  };

  Set.fromKeys = function fromKeys (value) {
    return this(KeyedCollection(value).keySeq());
  };

  Set.intersect = function intersect (sets) {
    sets = Collection(sets).toArray();
    return sets.length
      ? SetPrototype.intersect.apply(Set(sets.pop()), sets)
      : emptySet();
  };

  Set.union = function union (sets) {
    sets = Collection(sets).toArray();
    return sets.length
      ? SetPrototype.union.apply(Set(sets.pop()), sets)
      : emptySet();
  };

  Set.prototype.toString = function toString () {
    return this.__toString('Set {', '}');
  };

  // @pragma Access

  Set.prototype.has = function has (value) {
    return this._map.has(value);
  };

  // @pragma Modification

  Set.prototype.add = function add (value) {
    return updateSet(this, this._map.set(value, value));
  };

  Set.prototype.remove = function remove (value) {
    return updateSet(this, this._map.remove(value));
  };

  Set.prototype.clear = function clear () {
    return updateSet(this, this._map.clear());
  };

  // @pragma Composition

  Set.prototype.map = function map (mapper, context) {
    var this$1$1 = this;

    // keep track if the set is altered by the map function
    var didChanges = false;

    var newMap = updateSet(
      this,
      this._map.mapEntries(function (ref) {
        var v = ref[1];

        var mapped = mapper.call(context, v, v, this$1$1);

        if (mapped !== v) {
          didChanges = true;
        }

        return [mapped, mapped];
      }, context)
    );

    return didChanges ? newMap : this;
  };

  Set.prototype.union = function union () {
    var iters = [], len = arguments.length;
    while ( len-- ) iters[ len ] = arguments[ len ];

    iters = iters.filter(function (x) { return x.size !== 0; });
    if (iters.length === 0) {
      return this;
    }
    if (this.size === 0 && !this.__ownerID && iters.length === 1) {
      return this.constructor(iters[0]);
    }
    return this.withMutations(function (set) {
      for (var ii = 0; ii < iters.length; ii++) {
        SetCollection(iters[ii]).forEach(function (value) { return set.add(value); });
      }
    });
  };

  Set.prototype.intersect = function intersect () {
    var iters = [], len = arguments.length;
    while ( len-- ) iters[ len ] = arguments[ len ];

    if (iters.length === 0) {
      return this;
    }
    iters = iters.map(function (iter) { return SetCollection(iter); });
    var toRemove = [];
    this.forEach(function (value) {
      if (!iters.every(function (iter) { return iter.includes(value); })) {
        toRemove.push(value);
      }
    });
    return this.withMutations(function (set) {
      toRemove.forEach(function (value) {
        set.remove(value);
      });
    });
  };

  Set.prototype.subtract = function subtract () {
    var iters = [], len = arguments.length;
    while ( len-- ) iters[ len ] = arguments[ len ];

    if (iters.length === 0) {
      return this;
    }
    iters = iters.map(function (iter) { return SetCollection(iter); });
    var toRemove = [];
    this.forEach(function (value) {
      if (iters.some(function (iter) { return iter.includes(value); })) {
        toRemove.push(value);
      }
    });
    return this.withMutations(function (set) {
      toRemove.forEach(function (value) {
        set.remove(value);
      });
    });
  };

  Set.prototype.sort = function sort (comparator) {
    // Late binding
    return OrderedSet(sortFactory(this, comparator));
  };

  Set.prototype.sortBy = function sortBy (mapper, comparator) {
    // Late binding
    return OrderedSet(sortFactory(this, comparator, mapper));
  };

  Set.prototype.wasAltered = function wasAltered () {
    return this._map.wasAltered();
  };

  Set.prototype.__iterate = function __iterate (fn, reverse) {
    var this$1$1 = this;

    return this._map.__iterate(function (k) { return fn(k, k, this$1$1); }, reverse);
  };

  Set.prototype.__iterator = function __iterator (type, reverse) {
    return this._map.__iterator(type, reverse);
  };

  Set.prototype.__ensureOwner = function __ensureOwner (ownerID) {
    if (ownerID === this.__ownerID) {
      return this;
    }
    var newMap = this._map.__ensureOwner(ownerID);
    if (!ownerID) {
      if (this.size === 0) {
        return this.__empty();
      }
      this.__ownerID = ownerID;
      this._map = newMap;
      return this;
    }
    return this.__make(newMap, ownerID);
  };

  return Set;
}(SetCollection));

Set.isSet = isSet;

var SetPrototype = Set.prototype;
SetPrototype[IS_SET_SYMBOL] = true;
SetPrototype[DELETE] = SetPrototype.remove;
SetPrototype.merge = SetPrototype.concat = SetPrototype.union;
SetPrototype.withMutations = withMutations;
SetPrototype.asImmutable = asImmutable;
SetPrototype['@@transducer/init'] = SetPrototype.asMutable = asMutable;
SetPrototype['@@transducer/step'] = function (result, arr) {
  return result.add(arr);
};
SetPrototype['@@transducer/result'] = function (obj) {
  return obj.asImmutable();
};

SetPrototype.__empty = emptySet;
SetPrototype.__make = makeSet;

function updateSet(set, newMap) {
  if (set.__ownerID) {
    set.size = newMap.size;
    set._map = newMap;
    return set;
  }
  return newMap === set._map
    ? set
    : newMap.size === 0
    ? set.__empty()
    : set.__make(newMap);
}

function makeSet(map, ownerID) {
  var set = Object.create(SetPrototype);
  set.size = map ? map.size : 0;
  set._map = map;
  set.__ownerID = ownerID;
  return set;
}

var EMPTY_SET;
function emptySet() {
  return EMPTY_SET || (EMPTY_SET = makeSet(emptyMap()));
}

/**
 * Returns a lazy seq of nums from start (inclusive) to end
 * (exclusive), by step, where start defaults to 0, step to 1, and end to
 * infinity. When start is equal to end, returns empty list.
 */
var Range = /*@__PURE__*/(function (IndexedSeq) {
  function Range(start, end, step) {
    if (!(this instanceof Range)) {
      return new Range(start, end, step);
    }
    invariant(step !== 0, 'Cannot step a Range by 0');
    start = start || 0;
    if (end === undefined) {
      end = Infinity;
    }
    step = step === undefined ? 1 : Math.abs(step);
    if (end < start) {
      step = -step;
    }
    this._start = start;
    this._end = end;
    this._step = step;
    this.size = Math.max(0, Math.ceil((end - start) / step - 1) + 1);
    if (this.size === 0) {
      if (EMPTY_RANGE) {
        return EMPTY_RANGE;
      }
      EMPTY_RANGE = this;
    }
  }

  if ( IndexedSeq ) Range.__proto__ = IndexedSeq;
  Range.prototype = Object.create( IndexedSeq && IndexedSeq.prototype );
  Range.prototype.constructor = Range;

  Range.prototype.toString = function toString () {
    if (this.size === 0) {
      return 'Range []';
    }
    return (
      'Range [ ' +
      this._start +
      '...' +
      this._end +
      (this._step !== 1 ? ' by ' + this._step : '') +
      ' ]'
    );
  };

  Range.prototype.get = function get (index, notSetValue) {
    return this.has(index)
      ? this._start + wrapIndex(this, index) * this._step
      : notSetValue;
  };

  Range.prototype.includes = function includes (searchValue) {
    var possibleIndex = (searchValue - this._start) / this._step;
    return (
      possibleIndex >= 0 &&
      possibleIndex < this.size &&
      possibleIndex === Math.floor(possibleIndex)
    );
  };

  Range.prototype.slice = function slice (begin, end) {
    if (wholeSlice(begin, end, this.size)) {
      return this;
    }
    begin = resolveBegin(begin, this.size);
    end = resolveEnd(end, this.size);
    if (end <= begin) {
      return new Range(0, 0);
    }
    return new Range(
      this.get(begin, this._end),
      this.get(end, this._end),
      this._step
    );
  };

  Range.prototype.indexOf = function indexOf (searchValue) {
    var offsetValue = searchValue - this._start;
    if (offsetValue % this._step === 0) {
      var index = offsetValue / this._step;
      if (index >= 0 && index < this.size) {
        return index;
      }
    }
    return -1;
  };

  Range.prototype.lastIndexOf = function lastIndexOf (searchValue) {
    return this.indexOf(searchValue);
  };

  Range.prototype.__iterate = function __iterate (fn, reverse) {
    var size = this.size;
    var step = this._step;
    var value = reverse ? this._start + (size - 1) * step : this._start;
    var i = 0;
    while (i !== size) {
      if (fn(value, reverse ? size - ++i : i++, this) === false) {
        break;
      }
      value += reverse ? -step : step;
    }
    return i;
  };

  Range.prototype.__iterator = function __iterator (type, reverse) {
    var size = this.size;
    var step = this._step;
    var value = reverse ? this._start + (size - 1) * step : this._start;
    var i = 0;
    return new Iterator(function () {
      if (i === size) {
        return iteratorDone();
      }
      var v = value;
      value += reverse ? -step : step;
      return iteratorValue(type, reverse ? size - ++i : i++, v);
    });
  };

  Range.prototype.equals = function equals (other) {
    return other instanceof Range
      ? this._start === other._start &&
          this._end === other._end &&
          this._step === other._step
      : deepEqual(this, other);
  };

  return Range;
}(IndexedSeq));

var EMPTY_RANGE;

function getIn$1(collection, searchKeyPath, notSetValue) {
  var keyPath = coerceKeyPath(searchKeyPath);
  var i = 0;
  while (i !== keyPath.length) {
    collection = get(collection, keyPath[i++], NOT_SET);
    if (collection === NOT_SET) {
      return notSetValue;
    }
  }
  return collection;
}

function getIn(searchKeyPath, notSetValue) {
  return getIn$1(this, searchKeyPath, notSetValue);
}

function hasIn$1(collection, keyPath) {
  return getIn$1(collection, keyPath, NOT_SET) !== NOT_SET;
}

function hasIn(searchKeyPath) {
  return hasIn$1(this, searchKeyPath);
}

function toObject() {
  assertNotInfinite(this.size);
  var object = {};
  this.__iterate(function (v, k) {
    object[k] = v;
  });
  return object;
}

// Note: all of these methods are deprecated.
Collection.isIterable = isCollection;
Collection.isKeyed = isKeyed;
Collection.isIndexed = isIndexed;
Collection.isAssociative = isAssociative;
Collection.isOrdered = isOrdered;

Collection.Iterator = Iterator;

mixin(Collection, {
  // ### Conversion to other types

  toArray: function toArray() {
    assertNotInfinite(this.size);
    var array = new Array(this.size || 0);
    var useTuples = isKeyed(this);
    var i = 0;
    this.__iterate(function (v, k) {
      // Keyed collections produce an array of tuples.
      array[i++] = useTuples ? [k, v] : v;
    });
    return array;
  },

  toIndexedSeq: function toIndexedSeq() {
    return new ToIndexedSequence(this);
  },

  toJS: function toJS$1() {
    return toJS(this);
  },

  toKeyedSeq: function toKeyedSeq() {
    return new ToKeyedSequence(this, true);
  },

  toMap: function toMap() {
    // Use Late Binding here to solve the circular dependency.
    return Map(this.toKeyedSeq());
  },

  toObject: toObject,

  toOrderedMap: function toOrderedMap() {
    // Use Late Binding here to solve the circular dependency.
    return OrderedMap(this.toKeyedSeq());
  },

  toOrderedSet: function toOrderedSet() {
    // Use Late Binding here to solve the circular dependency.
    return OrderedSet(isKeyed(this) ? this.valueSeq() : this);
  },

  toSet: function toSet() {
    // Use Late Binding here to solve the circular dependency.
    return Set(isKeyed(this) ? this.valueSeq() : this);
  },

  toSetSeq: function toSetSeq() {
    return new ToSetSequence(this);
  },

  toSeq: function toSeq() {
    return isIndexed(this)
      ? this.toIndexedSeq()
      : isKeyed(this)
      ? this.toKeyedSeq()
      : this.toSetSeq();
  },

  toStack: function toStack() {
    // Use Late Binding here to solve the circular dependency.
    return Stack(isKeyed(this) ? this.valueSeq() : this);
  },

  toList: function toList() {
    // Use Late Binding here to solve the circular dependency.
    return List(isKeyed(this) ? this.valueSeq() : this);
  },

  // ### Common JavaScript methods and properties

  toString: function toString() {
    return '[Collection]';
  },

  __toString: function __toString(head, tail) {
    if (this.size === 0) {
      return head + tail;
    }
    return (
      head +
      ' ' +
      this.toSeq().map(this.__toStringMapper).join(', ') +
      ' ' +
      tail
    );
  },

  // ### ES6 Collection methods (ES6 Array and Map)

  concat: function concat() {
    var values = [], len = arguments.length;
    while ( len-- ) values[ len ] = arguments[ len ];

    return reify(this, concatFactory(this, values));
  },

  includes: function includes(searchValue) {
    return this.some(function (value) { return is(value, searchValue); });
  },

  entries: function entries() {
    return this.__iterator(ITERATE_ENTRIES);
  },

  every: function every(predicate, context) {
    assertNotInfinite(this.size);
    var returnValue = true;
    this.__iterate(function (v, k, c) {
      if (!predicate.call(context, v, k, c)) {
        returnValue = false;
        return false;
      }
    });
    return returnValue;
  },

  filter: function filter(predicate, context) {
    return reify(this, filterFactory(this, predicate, context, true));
  },

  find: function find(predicate, context, notSetValue) {
    var entry = this.findEntry(predicate, context);
    return entry ? entry[1] : notSetValue;
  },

  forEach: function forEach(sideEffect, context) {
    assertNotInfinite(this.size);
    return this.__iterate(context ? sideEffect.bind(context) : sideEffect);
  },

  join: function join(separator) {
    assertNotInfinite(this.size);
    separator = separator !== undefined ? '' + separator : ',';
    var joined = '';
    var isFirst = true;
    this.__iterate(function (v) {
      isFirst ? (isFirst = false) : (joined += separator);
      joined += v !== null && v !== undefined ? v.toString() : '';
    });
    return joined;
  },

  keys: function keys() {
    return this.__iterator(ITERATE_KEYS);
  },

  map: function map(mapper, context) {
    return reify(this, mapFactory(this, mapper, context));
  },

  reduce: function reduce$1(reducer, initialReduction, context) {
    return reduce(
      this,
      reducer,
      initialReduction,
      context,
      arguments.length < 2,
      false
    );
  },

  reduceRight: function reduceRight(reducer, initialReduction, context) {
    return reduce(
      this,
      reducer,
      initialReduction,
      context,
      arguments.length < 2,
      true
    );
  },

  reverse: function reverse() {
    return reify(this, reverseFactory(this, true));
  },

  slice: function slice(begin, end) {
    return reify(this, sliceFactory(this, begin, end, true));
  },

  some: function some(predicate, context) {
    return !this.every(not(predicate), context);
  },

  sort: function sort(comparator) {
    return reify(this, sortFactory(this, comparator));
  },

  values: function values() {
    return this.__iterator(ITERATE_VALUES);
  },

  // ### More sequential methods

  butLast: function butLast() {
    return this.slice(0, -1);
  },

  isEmpty: function isEmpty() {
    return this.size !== undefined ? this.size === 0 : !this.some(function () { return true; });
  },

  count: function count(predicate, context) {
    return ensureSize(
      predicate ? this.toSeq().filter(predicate, context) : this
    );
  },

  countBy: function countBy(grouper, context) {
    return countByFactory(this, grouper, context);
  },

  equals: function equals(other) {
    return deepEqual(this, other);
  },

  entrySeq: function entrySeq() {
    var collection = this;
    if (collection._cache) {
      // We cache as an entries array, so we can just return the cache!
      return new ArraySeq(collection._cache);
    }
    var entriesSequence = collection.toSeq().map(entryMapper).toIndexedSeq();
    entriesSequence.fromEntrySeq = function () { return collection.toSeq(); };
    return entriesSequence;
  },

  filterNot: function filterNot(predicate, context) {
    return this.filter(not(predicate), context);
  },

  findEntry: function findEntry(predicate, context, notSetValue) {
    var found = notSetValue;
    this.__iterate(function (v, k, c) {
      if (predicate.call(context, v, k, c)) {
        found = [k, v];
        return false;
      }
    });
    return found;
  },

  findKey: function findKey(predicate, context) {
    var entry = this.findEntry(predicate, context);
    return entry && entry[0];
  },

  findLast: function findLast(predicate, context, notSetValue) {
    return this.toKeyedSeq().reverse().find(predicate, context, notSetValue);
  },

  findLastEntry: function findLastEntry(predicate, context, notSetValue) {
    return this.toKeyedSeq()
      .reverse()
      .findEntry(predicate, context, notSetValue);
  },

  findLastKey: function findLastKey(predicate, context) {
    return this.toKeyedSeq().reverse().findKey(predicate, context);
  },

  first: function first(notSetValue) {
    return this.find(returnTrue, null, notSetValue);
  },

  flatMap: function flatMap(mapper, context) {
    return reify(this, flatMapFactory(this, mapper, context));
  },

  flatten: function flatten(depth) {
    return reify(this, flattenFactory(this, depth, true));
  },

  fromEntrySeq: function fromEntrySeq() {
    return new FromEntriesSequence(this);
  },

  get: function get(searchKey, notSetValue) {
    return this.find(function (_, key) { return is(key, searchKey); }, undefined, notSetValue);
  },

  getIn: getIn,

  groupBy: function groupBy(grouper, context) {
    return groupByFactory(this, grouper, context);
  },

  has: function has(searchKey) {
    return this.get(searchKey, NOT_SET) !== NOT_SET;
  },

  hasIn: hasIn,

  isSubset: function isSubset(iter) {
    iter = typeof iter.includes === 'function' ? iter : Collection(iter);
    return this.every(function (value) { return iter.includes(value); });
  },

  isSuperset: function isSuperset(iter) {
    iter = typeof iter.isSubset === 'function' ? iter : Collection(iter);
    return iter.isSubset(this);
  },

  keyOf: function keyOf(searchValue) {
    return this.findKey(function (value) { return is(value, searchValue); });
  },

  keySeq: function keySeq() {
    return this.toSeq().map(keyMapper).toIndexedSeq();
  },

  last: function last(notSetValue) {
    return this.toSeq().reverse().first(notSetValue);
  },

  lastKeyOf: function lastKeyOf(searchValue) {
    return this.toKeyedSeq().reverse().keyOf(searchValue);
  },

  max: function max(comparator) {
    return maxFactory(this, comparator);
  },

  maxBy: function maxBy(mapper, comparator) {
    return maxFactory(this, comparator, mapper);
  },

  min: function min(comparator) {
    return maxFactory(
      this,
      comparator ? neg(comparator) : defaultNegComparator
    );
  },

  minBy: function minBy(mapper, comparator) {
    return maxFactory(
      this,
      comparator ? neg(comparator) : defaultNegComparator,
      mapper
    );
  },

  rest: function rest() {
    return this.slice(1);
  },

  skip: function skip(amount) {
    return amount === 0 ? this : this.slice(Math.max(0, amount));
  },

  skipLast: function skipLast(amount) {
    return amount === 0 ? this : this.slice(0, -Math.max(0, amount));
  },

  skipWhile: function skipWhile(predicate, context) {
    return reify(this, skipWhileFactory(this, predicate, context, true));
  },

  skipUntil: function skipUntil(predicate, context) {
    return this.skipWhile(not(predicate), context);
  },

  sortBy: function sortBy(mapper, comparator) {
    return reify(this, sortFactory(this, comparator, mapper));
  },

  take: function take(amount) {
    return this.slice(0, Math.max(0, amount));
  },

  takeLast: function takeLast(amount) {
    return this.slice(-Math.max(0, amount));
  },

  takeWhile: function takeWhile(predicate, context) {
    return reify(this, takeWhileFactory(this, predicate, context));
  },

  takeUntil: function takeUntil(predicate, context) {
    return this.takeWhile(not(predicate), context);
  },

  update: function update(fn) {
    return fn(this);
  },

  valueSeq: function valueSeq() {
    return this.toIndexedSeq();
  },

  // ### Hashable Object

  hashCode: function hashCode() {
    return this.__hash || (this.__hash = hashCollection(this));
  },

  // ### Internal

  // abstract __iterate(fn, reverse)

  // abstract __iterator(type, reverse)
});

var CollectionPrototype = Collection.prototype;
CollectionPrototype[IS_COLLECTION_SYMBOL] = true;
CollectionPrototype[ITERATOR_SYMBOL] = CollectionPrototype.values;
CollectionPrototype.toJSON = CollectionPrototype.toArray;
CollectionPrototype.__toStringMapper = quoteString;
CollectionPrototype.inspect = CollectionPrototype.toSource = function () {
  return this.toString();
};
CollectionPrototype.chain = CollectionPrototype.flatMap;
CollectionPrototype.contains = CollectionPrototype.includes;

mixin(KeyedCollection, {
  // ### More sequential methods

  flip: function flip() {
    return reify(this, flipFactory(this));
  },

  mapEntries: function mapEntries(mapper, context) {
    var this$1$1 = this;

    var iterations = 0;
    return reify(
      this,
      this.toSeq()
        .map(function (v, k) { return mapper.call(context, [k, v], iterations++, this$1$1); })
        .fromEntrySeq()
    );
  },

  mapKeys: function mapKeys(mapper, context) {
    var this$1$1 = this;

    return reify(
      this,
      this.toSeq()
        .flip()
        .map(function (k, v) { return mapper.call(context, k, v, this$1$1); })
        .flip()
    );
  },
});

var KeyedCollectionPrototype = KeyedCollection.prototype;
KeyedCollectionPrototype[IS_KEYED_SYMBOL] = true;
KeyedCollectionPrototype[ITERATOR_SYMBOL] = CollectionPrototype.entries;
KeyedCollectionPrototype.toJSON = toObject;
KeyedCollectionPrototype.__toStringMapper = function (v, k) { return quoteString(k) + ': ' + quoteString(v); };

mixin(IndexedCollection, {
  // ### Conversion to other types

  toKeyedSeq: function toKeyedSeq() {
    return new ToKeyedSequence(this, false);
  },

  // ### ES6 Collection methods (ES6 Array and Map)

  filter: function filter(predicate, context) {
    return reify(this, filterFactory(this, predicate, context, false));
  },

  findIndex: function findIndex(predicate, context) {
    var entry = this.findEntry(predicate, context);
    return entry ? entry[0] : -1;
  },

  indexOf: function indexOf(searchValue) {
    var key = this.keyOf(searchValue);
    return key === undefined ? -1 : key;
  },

  lastIndexOf: function lastIndexOf(searchValue) {
    var key = this.lastKeyOf(searchValue);
    return key === undefined ? -1 : key;
  },

  reverse: function reverse() {
    return reify(this, reverseFactory(this, false));
  },

  slice: function slice(begin, end) {
    return reify(this, sliceFactory(this, begin, end, false));
  },

  splice: function splice(index, removeNum /*, ...values*/) {
    var numArgs = arguments.length;
    removeNum = Math.max(removeNum || 0, 0);
    if (numArgs === 0 || (numArgs === 2 && !removeNum)) {
      return this;
    }
    // If index is negative, it should resolve relative to the size of the
    // collection. However size may be expensive to compute if not cached, so
    // only call count() if the number is in fact negative.
    index = resolveBegin(index, index < 0 ? this.count() : this.size);
    var spliced = this.slice(0, index);
    return reify(
      this,
      numArgs === 1
        ? spliced
        : spliced.concat(arrCopy(arguments, 2), this.slice(index + removeNum))
    );
  },

  // ### More collection methods

  findLastIndex: function findLastIndex(predicate, context) {
    var entry = this.findLastEntry(predicate, context);
    return entry ? entry[0] : -1;
  },

  first: function first(notSetValue) {
    return this.get(0, notSetValue);
  },

  flatten: function flatten(depth) {
    return reify(this, flattenFactory(this, depth, false));
  },

  get: function get(index, notSetValue) {
    index = wrapIndex(this, index);
    return index < 0 ||
      this.size === Infinity ||
      (this.size !== undefined && index > this.size)
      ? notSetValue
      : this.find(function (_, key) { return key === index; }, undefined, notSetValue);
  },

  has: function has(index) {
    index = wrapIndex(this, index);
    return (
      index >= 0 &&
      (this.size !== undefined
        ? this.size === Infinity || index < this.size
        : this.indexOf(index) !== -1)
    );
  },

  interpose: function interpose(separator) {
    return reify(this, interposeFactory(this, separator));
  },

  interleave: function interleave(/*...collections*/) {
    var collections = [this].concat(arrCopy(arguments));
    var zipped = zipWithFactory(this.toSeq(), IndexedSeq.of, collections);
    var interleaved = zipped.flatten(true);
    if (zipped.size) {
      interleaved.size = zipped.size * collections.length;
    }
    return reify(this, interleaved);
  },

  keySeq: function keySeq() {
    return Range(0, this.size);
  },

  last: function last(notSetValue) {
    return this.get(-1, notSetValue);
  },

  skipWhile: function skipWhile(predicate, context) {
    return reify(this, skipWhileFactory(this, predicate, context, false));
  },

  zip: function zip(/*, ...collections */) {
    var collections = [this].concat(arrCopy(arguments));
    return reify(this, zipWithFactory(this, defaultZipper, collections));
  },

  zipAll: function zipAll(/*, ...collections */) {
    var collections = [this].concat(arrCopy(arguments));
    return reify(this, zipWithFactory(this, defaultZipper, collections, true));
  },

  zipWith: function zipWith(zipper /*, ...collections */) {
    var collections = arrCopy(arguments);
    collections[0] = this;
    return reify(this, zipWithFactory(this, zipper, collections));
  },
});

var IndexedCollectionPrototype = IndexedCollection.prototype;
IndexedCollectionPrototype[IS_INDEXED_SYMBOL] = true;
IndexedCollectionPrototype[IS_ORDERED_SYMBOL] = true;

mixin(SetCollection, {
  // ### ES6 Collection methods (ES6 Array and Map)

  get: function get(value, notSetValue) {
    return this.has(value) ? value : notSetValue;
  },

  includes: function includes(value) {
    return this.has(value);
  },

  // ### More sequential methods

  keySeq: function keySeq() {
    return this.valueSeq();
  },
});

var SetCollectionPrototype = SetCollection.prototype;
SetCollectionPrototype.has = CollectionPrototype.includes;
SetCollectionPrototype.contains = SetCollectionPrototype.includes;
SetCollectionPrototype.keys = SetCollectionPrototype.values;

// Mixin subclasses

mixin(KeyedSeq, KeyedCollectionPrototype);
mixin(IndexedSeq, IndexedCollectionPrototype);
mixin(SetSeq, SetCollectionPrototype);

// #pragma Helper functions

function reduce(collection, reducer, reduction, context, useFirst, reverse) {
  assertNotInfinite(collection.size);
  collection.__iterate(function (v, k, c) {
    if (useFirst) {
      useFirst = false;
      reduction = v;
    } else {
      reduction = reducer.call(context, reduction, v, k, c);
    }
  }, reverse);
  return reduction;
}

function keyMapper(v, k) {
  return k;
}

function entryMapper(v, k) {
  return [k, v];
}

function not(predicate) {
  return function () {
    return !predicate.apply(this, arguments);
  };
}

function neg(predicate) {
  return function () {
    return -predicate.apply(this, arguments);
  };
}

function defaultZipper() {
  return arrCopy(arguments);
}

function defaultNegComparator(a, b) {
  return a < b ? 1 : a > b ? -1 : 0;
}

function hashCollection(collection) {
  if (collection.size === Infinity) {
    return 0;
  }
  var ordered = isOrdered(collection);
  var keyed = isKeyed(collection);
  var h = ordered ? 1 : 0;
  var size = collection.__iterate(
    keyed
      ? ordered
        ? function (v, k) {
            h = (31 * h + hashMerge(hash(v), hash(k))) | 0;
          }
        : function (v, k) {
            h = (h + hashMerge(hash(v), hash(k))) | 0;
          }
      : ordered
      ? function (v) {
          h = (31 * h + hash(v)) | 0;
        }
      : function (v) {
          h = (h + hash(v)) | 0;
        }
  );
  return murmurHashOfSize(size, h);
}

function murmurHashOfSize(size, h) {
  h = imul(h, 0xcc9e2d51);
  h = imul((h << 15) | (h >>> -15), 0x1b873593);
  h = imul((h << 13) | (h >>> -13), 5);
  h = ((h + 0xe6546b64) | 0) ^ size;
  h = imul(h ^ (h >>> 16), 0x85ebca6b);
  h = imul(h ^ (h >>> 13), 0xc2b2ae35);
  h = smi(h ^ (h >>> 16));
  return h;
}

function hashMerge(a, b) {
  return (a ^ (b + 0x9e3779b9 + (a << 6) + (a >> 2))) | 0; // int
}

var OrderedSet = /*@__PURE__*/(function (Set) {
  function OrderedSet(value) {
    return value === null || value === undefined
      ? emptyOrderedSet()
      : isOrderedSet(value)
      ? value
      : emptyOrderedSet().withMutations(function (set) {
          var iter = SetCollection(value);
          assertNotInfinite(iter.size);
          iter.forEach(function (v) { return set.add(v); });
        });
  }

  if ( Set ) OrderedSet.__proto__ = Set;
  OrderedSet.prototype = Object.create( Set && Set.prototype );
  OrderedSet.prototype.constructor = OrderedSet;

  OrderedSet.of = function of (/*...values*/) {
    return this(arguments);
  };

  OrderedSet.fromKeys = function fromKeys (value) {
    return this(KeyedCollection(value).keySeq());
  };

  OrderedSet.prototype.toString = function toString () {
    return this.__toString('OrderedSet {', '}');
  };

  return OrderedSet;
}(Set));

OrderedSet.isOrderedSet = isOrderedSet;

var OrderedSetPrototype = OrderedSet.prototype;
OrderedSetPrototype[IS_ORDERED_SYMBOL] = true;
OrderedSetPrototype.zip = IndexedCollectionPrototype.zip;
OrderedSetPrototype.zipWith = IndexedCollectionPrototype.zipWith;
OrderedSetPrototype.zipAll = IndexedCollectionPrototype.zipAll;

OrderedSetPrototype.__empty = emptyOrderedSet;
OrderedSetPrototype.__make = makeOrderedSet;

function makeOrderedSet(map, ownerID) {
  var set = Object.create(OrderedSetPrototype);
  set.size = map ? map.size : 0;
  set._map = map;
  set.__ownerID = ownerID;
  return set;
}

var EMPTY_ORDERED_SET;
function emptyOrderedSet() {
  return (
    EMPTY_ORDERED_SET || (EMPTY_ORDERED_SET = makeOrderedSet(emptyOrderedMap()))
  );
}

function throwOnInvalidDefaultValues(defaultValues) {
  if (isRecord(defaultValues)) {
    throw new Error(
      'Can not call `Record` with an immutable Record as default values. Use a plain javascript object instead.'
    );
  }

  if (isImmutable(defaultValues)) {
    throw new Error(
      'Can not call `Record` with an immutable Collection as default values. Use a plain javascript object instead.'
    );
  }

  if (defaultValues === null || typeof defaultValues !== 'object') {
    throw new Error(
      'Can not call `Record` with a non-object as default values. Use a plain javascript object instead.'
    );
  }
}

var Record = function Record(defaultValues, name) {
  var hasInitialized;

  throwOnInvalidDefaultValues(defaultValues);

  var RecordType = function Record(values) {
    var this$1$1 = this;

    if (values instanceof RecordType) {
      return values;
    }
    if (!(this instanceof RecordType)) {
      return new RecordType(values);
    }
    if (!hasInitialized) {
      hasInitialized = true;
      var keys = Object.keys(defaultValues);
      var indices = (RecordTypePrototype._indices = {});
      // Deprecated: left to attempt not to break any external code which
      // relies on a ._name property existing on record instances.
      // Use Record.getDescriptiveName() instead
      RecordTypePrototype._name = name;
      RecordTypePrototype._keys = keys;
      RecordTypePrototype._defaultValues = defaultValues;
      for (var i = 0; i < keys.length; i++) {
        var propName = keys[i];
        indices[propName] = i;
        if (RecordTypePrototype[propName]) {
          /* eslint-disable no-console */
          typeof console === 'object' &&
            console.warn &&
            console.warn(
              'Cannot define ' +
                recordName(this) +
                ' with property "' +
                propName +
                '" since that property name is part of the Record API.'
            );
          /* eslint-enable no-console */
        } else {
          setProp(RecordTypePrototype, propName);
        }
      }
    }
    this.__ownerID = undefined;
    this._values = List().withMutations(function (l) {
      l.setSize(this$1$1._keys.length);
      KeyedCollection(values).forEach(function (v, k) {
        l.set(this$1$1._indices[k], v === this$1$1._defaultValues[k] ? undefined : v);
      });
    });
    return this;
  };

  var RecordTypePrototype = (RecordType.prototype =
    Object.create(RecordPrototype));
  RecordTypePrototype.constructor = RecordType;

  if (name) {
    RecordType.displayName = name;
  }

  return RecordType;
};

Record.prototype.toString = function toString () {
  var str = recordName(this) + ' { ';
  var keys = this._keys;
  var k;
  for (var i = 0, l = keys.length; i !== l; i++) {
    k = keys[i];
    str += (i ? ', ' : '') + k + ': ' + quoteString(this.get(k));
  }
  return str + ' }';
};

Record.prototype.equals = function equals (other) {
  return (
    this === other || (other && recordSeq(this).equals(recordSeq(other)))
  );
};

Record.prototype.hashCode = function hashCode () {
  return recordSeq(this).hashCode();
};

// @pragma Access

Record.prototype.has = function has (k) {
  return this._indices.hasOwnProperty(k);
};

Record.prototype.get = function get (k, notSetValue) {
  if (!this.has(k)) {
    return notSetValue;
  }
  var index = this._indices[k];
  var value = this._values.get(index);
  return value === undefined ? this._defaultValues[k] : value;
};

// @pragma Modification

Record.prototype.set = function set (k, v) {
  if (this.has(k)) {
    var newValues = this._values.set(
      this._indices[k],
      v === this._defaultValues[k] ? undefined : v
    );
    if (newValues !== this._values && !this.__ownerID) {
      return makeRecord(this, newValues);
    }
  }
  return this;
};

Record.prototype.remove = function remove (k) {
  return this.set(k);
};

Record.prototype.clear = function clear () {
  var newValues = this._values.clear().setSize(this._keys.length);

  return this.__ownerID ? this : makeRecord(this, newValues);
};

Record.prototype.wasAltered = function wasAltered () {
  return this._values.wasAltered();
};

Record.prototype.toSeq = function toSeq () {
  return recordSeq(this);
};

Record.prototype.toJS = function toJS$1 () {
  return toJS(this);
};

Record.prototype.entries = function entries () {
  return this.__iterator(ITERATE_ENTRIES);
};

Record.prototype.__iterator = function __iterator (type, reverse) {
  return recordSeq(this).__iterator(type, reverse);
};

Record.prototype.__iterate = function __iterate (fn, reverse) {
  return recordSeq(this).__iterate(fn, reverse);
};

Record.prototype.__ensureOwner = function __ensureOwner (ownerID) {
  if (ownerID === this.__ownerID) {
    return this;
  }
  var newValues = this._values.__ensureOwner(ownerID);
  if (!ownerID) {
    this.__ownerID = ownerID;
    this._values = newValues;
    return this;
  }
  return makeRecord(this, newValues, ownerID);
};

Record.isRecord = isRecord;
Record.getDescriptiveName = recordName;
var RecordPrototype = Record.prototype;
RecordPrototype[IS_RECORD_SYMBOL] = true;
RecordPrototype[DELETE] = RecordPrototype.remove;
RecordPrototype.deleteIn = RecordPrototype.removeIn = deleteIn;
RecordPrototype.getIn = getIn;
RecordPrototype.hasIn = CollectionPrototype.hasIn;
RecordPrototype.merge = merge$1;
RecordPrototype.mergeWith = mergeWith$1;
RecordPrototype.mergeIn = mergeIn;
RecordPrototype.mergeDeep = mergeDeep;
RecordPrototype.mergeDeepWith = mergeDeepWith;
RecordPrototype.mergeDeepIn = mergeDeepIn;
RecordPrototype.setIn = setIn;
RecordPrototype.update = update;
RecordPrototype.updateIn = updateIn;
RecordPrototype.withMutations = withMutations;
RecordPrototype.asMutable = asMutable;
RecordPrototype.asImmutable = asImmutable;
RecordPrototype[ITERATOR_SYMBOL] = RecordPrototype.entries;
RecordPrototype.toJSON = RecordPrototype.toObject =
  CollectionPrototype.toObject;
RecordPrototype.inspect = RecordPrototype.toSource = function () {
  return this.toString();
};

function makeRecord(likeRecord, values, ownerID) {
  var record = Object.create(Object.getPrototypeOf(likeRecord));
  record._values = values;
  record.__ownerID = ownerID;
  return record;
}

function recordName(record) {
  return record.constructor.displayName || record.constructor.name || 'Record';
}

function recordSeq(record) {
  return keyedSeqFromValue(record._keys.map(function (k) { return [k, record.get(k)]; }));
}

function setProp(prototype, name) {
  try {
    Object.defineProperty(prototype, name, {
      get: function () {
        return this.get(name);
      },
      set: function (value) {
        invariant(this.__ownerID, 'Cannot set on an immutable record.');
        this.set(name, value);
      },
    });
  } catch (error) {
    // Object.defineProperty failed. Probably IE8.
  }
}

/**
 * Returns a lazy Seq of `value` repeated `times` times. When `times` is
 * undefined, returns an infinite sequence of `value`.
 */
var Repeat = /*@__PURE__*/(function (IndexedSeq) {
  function Repeat(value, times) {
    if (!(this instanceof Repeat)) {
      return new Repeat(value, times);
    }
    this._value = value;
    this.size = times === undefined ? Infinity : Math.max(0, times);
    if (this.size === 0) {
      if (EMPTY_REPEAT) {
        return EMPTY_REPEAT;
      }
      EMPTY_REPEAT = this;
    }
  }

  if ( IndexedSeq ) Repeat.__proto__ = IndexedSeq;
  Repeat.prototype = Object.create( IndexedSeq && IndexedSeq.prototype );
  Repeat.prototype.constructor = Repeat;

  Repeat.prototype.toString = function toString () {
    if (this.size === 0) {
      return 'Repeat []';
    }
    return 'Repeat [ ' + this._value + ' ' + this.size + ' times ]';
  };

  Repeat.prototype.get = function get (index, notSetValue) {
    return this.has(index) ? this._value : notSetValue;
  };

  Repeat.prototype.includes = function includes (searchValue) {
    return is(this._value, searchValue);
  };

  Repeat.prototype.slice = function slice (begin, end) {
    var size = this.size;
    return wholeSlice(begin, end, size)
      ? this
      : new Repeat(
          this._value,
          resolveEnd(end, size) - resolveBegin(begin, size)
        );
  };

  Repeat.prototype.reverse = function reverse () {
    return this;
  };

  Repeat.prototype.indexOf = function indexOf (searchValue) {
    if (is(this._value, searchValue)) {
      return 0;
    }
    return -1;
  };

  Repeat.prototype.lastIndexOf = function lastIndexOf (searchValue) {
    if (is(this._value, searchValue)) {
      return this.size;
    }
    return -1;
  };

  Repeat.prototype.__iterate = function __iterate (fn, reverse) {
    var size = this.size;
    var i = 0;
    while (i !== size) {
      if (fn(this._value, reverse ? size - ++i : i++, this) === false) {
        break;
      }
    }
    return i;
  };

  Repeat.prototype.__iterator = function __iterator (type, reverse) {
    var this$1$1 = this;

    var size = this.size;
    var i = 0;
    return new Iterator(function () { return i === size
        ? iteratorDone()
        : iteratorValue(type, reverse ? size - ++i : i++, this$1$1._value); }
    );
  };

  Repeat.prototype.equals = function equals (other) {
    return other instanceof Repeat
      ? is(this._value, other._value)
      : deepEqual(other);
  };

  return Repeat;
}(IndexedSeq));

var EMPTY_REPEAT;

function fromJS(value, converter) {
  return fromJSWith(
    [],
    converter || defaultConverter,
    value,
    '',
    converter && converter.length > 2 ? [] : undefined,
    { '': value }
  );
}

function fromJSWith(stack, converter, value, key, keyPath, parentValue) {
  if (
    typeof value !== 'string' &&
    !isImmutable(value) &&
    (isArrayLike(value) || hasIterator(value) || isPlainObject(value))
  ) {
    if (~stack.indexOf(value)) {
      throw new TypeError('Cannot convert circular structure to Immutable');
    }
    stack.push(value);
    keyPath && key !== '' && keyPath.push(key);
    var converted = converter.call(
      parentValue,
      key,
      Seq(value).map(function (v, k) { return fromJSWith(stack, converter, v, k, keyPath, value); }
      ),
      keyPath && keyPath.slice()
    );
    stack.pop();
    keyPath && keyPath.pop();
    return converted;
  }
  return value;
}

function defaultConverter(k, v) {
  // Effectively the opposite of "Collection.toSeq()"
  return isIndexed(v) ? v.toList() : isKeyed(v) ? v.toMap() : v.toSet();
}

var version = "4.0.0";

var Immutable = {
  version: version,

  Collection: Collection,
  // Note: Iterable is deprecated
  Iterable: Collection,

  Seq: Seq,
  Map: Map,
  OrderedMap: OrderedMap,
  List: List,
  Stack: Stack,
  Set: Set,
  OrderedSet: OrderedSet,

  Record: Record,
  Range: Range,
  Repeat: Repeat,

  is: is,
  fromJS: fromJS,
  hash: hash,

  isImmutable: isImmutable,
  isCollection: isCollection,
  isKeyed: isKeyed,
  isIndexed: isIndexed,
  isAssociative: isAssociative,
  isOrdered: isOrdered,
  isValueObject: isValueObject,
  isPlainObject: isPlainObject,
  isSeq: isSeq,
  isList: isList,
  isMap: isMap,
  isOrderedMap: isOrderedMap,
  isStack: isStack,
  isSet: isSet,
  isOrderedSet: isOrderedSet,
  isRecord: isRecord,

  get: get,
  getIn: getIn$1,
  has: has,
  hasIn: hasIn$1,
  merge: merge,
  mergeDeep: mergeDeep$1,
  mergeWith: mergeWith,
  mergeDeepWith: mergeDeepWith$1,
  remove: remove,
  removeIn: removeIn,
  set: set,
  setIn: setIn$1,
  update: update$1,
  updateIn: updateIn$1,
};

// Note: Iterable is deprecated
var Iterable = Collection;

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Immutable);



/***/ }),

/***/ "../../node_modules/invariant/browser.js":
/*!***********************************************!*\
  !*** ../../node_modules/invariant/browser.js ***!
  \***********************************************/
/***/ ((module) => {

"use strict";
/**
 * Copyright (c) 2013-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */



/**
 * Use invariant() to assert state which your program assumes to be true.
 *
 * Provide sprintf-style format (only %s is supported) and arguments
 * to provide information about what broke and what you were
 * expecting.
 *
 * The invariant message will be stripped in production, but the invariant
 * will remain to ensure logic does not differ in production.
 */

var invariant = function(condition, format, a, b, c, d, e, f) {
  if (true) {
    if (format === undefined) {
      throw new Error('invariant requires an error message argument');
    }
  }

  if (!condition) {
    var error;
    if (format === undefined) {
      error = new Error(
        'Minified exception occurred; use the non-minified dev environment ' +
        'for the full error message and additional helpful warnings.'
      );
    } else {
      var args = [a, b, c, d, e, f];
      var argIndex = 0;
      error = new Error(
        format.replace(/%s/g, function() { return args[argIndex++]; })
      );
      error.name = 'Invariant Violation';
    }

    error.framesToPop = 1; // we don't care about invariant's own frame
    throw error;
  }
};

module.exports = invariant;


/***/ }),

/***/ "../../node_modules/jsonschema/lib/attribute.js":
/*!******************************************************!*\
  !*** ../../node_modules/jsonschema/lib/attribute.js ***!
  \******************************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

"use strict";


var helpers = __webpack_require__(/*! ./helpers */ "../../node_modules/jsonschema/lib/helpers.js");

/** @type ValidatorResult */
var ValidatorResult = helpers.ValidatorResult;
/** @type SchemaError */
var SchemaError = helpers.SchemaError;

var attribute = {};

attribute.ignoreProperties = {
  // informative properties
  'id': true,
  'default': true,
  'description': true,
  'title': true,
  // arguments to other properties
  'additionalItems': true,
  'then': true,
  'else': true,
  // special-handled properties
  '$schema': true,
  '$ref': true,
  'extends': true,
};

/**
 * @name validators
 */
var validators = attribute.validators = {};

/**
 * Validates whether the instance if of a certain type
 * @param instance
 * @param schema
 * @param options
 * @param ctx
 * @return {ValidatorResult|null}
 */
validators.type = function validateType (instance, schema, options, ctx) {
  // Ignore undefined instances
  if (instance === undefined) {
    return null;
  }
  var result = new ValidatorResult(instance, schema, options, ctx);
  var types = Array.isArray(schema.type) ? schema.type : [schema.type];
  if (!types.some(this.testType.bind(this, instance, schema, options, ctx))) {
    var list = types.map(function (v) {
      if(!v) return;
      var id = v.$id || v.id;
      return id ? ('<' + id + '>') : (v+'');
    });
    result.addError({
      name: 'type',
      argument: list,
      message: "is not of a type(s) " + list,
    });
  }
  return result;
};

function testSchemaNoThrow(instance, options, ctx, callback, schema){
  var throwError = options.throwError;
  var throwAll = options.throwAll;
  options.throwError = false;
  options.throwAll = false;
  var res = this.validateSchema(instance, schema, options, ctx);
  options.throwError = throwError;
  options.throwAll = throwAll;

  if (!res.valid && callback instanceof Function) {
    callback(res);
  }
  return res.valid;
}

/**
 * Validates whether the instance matches some of the given schemas
 * @param instance
 * @param schema
 * @param options
 * @param ctx
 * @return {ValidatorResult|null}
 */
validators.anyOf = function validateAnyOf (instance, schema, options, ctx) {
  // Ignore undefined instances
  if (instance === undefined) {
    return null;
  }
  var result = new ValidatorResult(instance, schema, options, ctx);
  var inner = new ValidatorResult(instance, schema, options, ctx);
  if (!Array.isArray(schema.anyOf)){
    throw new SchemaError("anyOf must be an array");
  }
  if (!schema.anyOf.some(
    testSchemaNoThrow.bind(
      this, instance, options, ctx, function(res){inner.importErrors(res);}
    ))) {
    var list = schema.anyOf.map(function (v, i) {
      var id = v.$id || v.id;
      if(id) return '<' + id + '>';
      return(v.title && JSON.stringify(v.title)) || (v['$ref'] && ('<' + v['$ref'] + '>')) || '[subschema '+i+']';
    });
    if (options.nestedErrors) {
      result.importErrors(inner);
    }
    result.addError({
      name: 'anyOf',
      argument: list,
      message: "is not any of " + list.join(','),
    });
  }
  return result;
};

/**
 * Validates whether the instance matches every given schema
 * @param instance
 * @param schema
 * @param options
 * @param ctx
 * @return {String|null}
 */
validators.allOf = function validateAllOf (instance, schema, options, ctx) {
  // Ignore undefined instances
  if (instance === undefined) {
    return null;
  }
  if (!Array.isArray(schema.allOf)){
    throw new SchemaError("allOf must be an array");
  }
  var result = new ValidatorResult(instance, schema, options, ctx);
  var self = this;
  schema.allOf.forEach(function(v, i){
    var valid = self.validateSchema(instance, v, options, ctx);
    if(!valid.valid){
      var id = v.$id || v.id;
      var msg = id || (v.title && JSON.stringify(v.title)) || (v['$ref'] && ('<' + v['$ref'] + '>')) || '[subschema '+i+']';
      result.addError({
        name: 'allOf',
        argument: { id: msg, length: valid.errors.length, valid: valid },
        message: 'does not match allOf schema ' + msg + ' with ' + valid.errors.length + ' error[s]:',
      });
      result.importErrors(valid);
    }
  });
  return result;
};

/**
 * Validates whether the instance matches exactly one of the given schemas
 * @param instance
 * @param schema
 * @param options
 * @param ctx
 * @return {String|null}
 */
validators.oneOf = function validateOneOf (instance, schema, options, ctx) {
  // Ignore undefined instances
  if (instance === undefined) {
    return null;
  }
  if (!Array.isArray(schema.oneOf)){
    throw new SchemaError("oneOf must be an array");
  }
  var result = new ValidatorResult(instance, schema, options, ctx);
  var inner = new ValidatorResult(instance, schema, options, ctx);
  var count = schema.oneOf.filter(
    testSchemaNoThrow.bind(
      this, instance, options, ctx, function(res) {inner.importErrors(res);}
    ) ).length;
  var list = schema.oneOf.map(function (v, i) {
    var id = v.$id || v.id;
    return id || (v.title && JSON.stringify(v.title)) || (v['$ref'] && ('<' + v['$ref'] + '>')) || '[subschema '+i+']';
  });
  if (count!==1) {
    if (options.nestedErrors) {
      result.importErrors(inner);
    }
    result.addError({
      name: 'oneOf',
      argument: list,
      message: "is not exactly one from " + list.join(','),
    });
  }
  return result;
};

/**
 * Validates "then" or "else" depending on the result of validating "if"
 * @param instance
 * @param schema
 * @param options
 * @param ctx
 * @return {String|null}
 */
validators.if = function validateIf (instance, schema, options, ctx) {
  // Ignore undefined instances
  if (instance === undefined) return null;
  if (!helpers.isSchema(schema.if)) throw new Error('Expected "if" keyword to be a schema');
  var ifValid = testSchemaNoThrow.call(this, instance, options, ctx, null, schema.if);
  var result = new ValidatorResult(instance, schema, options, ctx);
  var res;
  if(ifValid){
    if (schema.then === undefined) return;
    if (!helpers.isSchema(schema.then)) throw new Error('Expected "then" keyword to be a schema');
    res = this.validateSchema(instance, schema.then, options, ctx.makeChild(schema.then));
    result.importErrors(res);
  }else{
    if (schema.else === undefined) return;
    if (!helpers.isSchema(schema.else)) throw new Error('Expected "else" keyword to be a schema');
    res = this.validateSchema(instance, schema.else, options, ctx.makeChild(schema.else));
    result.importErrors(res);
  }
  return result;
};

function getEnumerableProperty(object, key){
  // Determine if `key` shows up in `for(var key in object)`
  // First test Object.hasOwnProperty.call as an optimization: that guarantees it does
  if(Object.hasOwnProperty.call(object, key)) return object[key];
  // Test `key in object` as an optimization; false means it won't
  if(!(key in object)) return;
  while( (object = Object.getPrototypeOf(object)) ){
    if(Object.propertyIsEnumerable.call(object, key)) return object[key];
  }
}

/**
 * Validates propertyNames
 * @param instance
 * @param schema
 * @param options
 * @param ctx
 * @return {String|null|ValidatorResult}
 */
validators.propertyNames = function validatePropertyNames (instance, schema, options, ctx) {
  if(!this.types.object(instance)) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  var subschema = schema.propertyNames!==undefined ? schema.propertyNames : {};
  if(!helpers.isSchema(subschema)) throw new SchemaError('Expected "propertyNames" to be a schema (object or boolean)');

  for (var property in instance) {
    if(getEnumerableProperty(instance, property) !== undefined){
      var res = this.validateSchema(property, subschema, options, ctx.makeChild(subschema));
      result.importErrors(res);
    }
  }

  return result;
};

/**
 * Validates properties
 * @param instance
 * @param schema
 * @param options
 * @param ctx
 * @return {String|null|ValidatorResult}
 */
validators.properties = function validateProperties (instance, schema, options, ctx) {
  if(!this.types.object(instance)) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  var properties = schema.properties || {};
  for (var property in properties) {
    var subschema = properties[property];
    if(subschema===undefined){
      continue;
    }else if(subschema===null){
      throw new SchemaError('Unexpected null, expected schema in "properties"');
    }
    if (typeof options.preValidateProperty == 'function') {
      options.preValidateProperty(instance, property, subschema, options, ctx);
    }
    var prop = getEnumerableProperty(instance, property);
    var res = this.validateSchema(prop, subschema, options, ctx.makeChild(subschema, property));
    if(res.instance !== result.instance[property]) result.instance[property] = res.instance;
    result.importErrors(res);
  }
  return result;
};

/**
 * Test a specific property within in instance against the additionalProperties schema attribute
 * This ignores properties with definitions in the properties schema attribute, but no other attributes.
 * If too many more types of property-existence tests pop up they may need their own class of tests (like `type` has)
 * @private
 * @return {boolean}
 */
function testAdditionalProperty (instance, schema, options, ctx, property, result) {
  if(!this.types.object(instance)) return;
  if (schema.properties && schema.properties[property] !== undefined) {
    return;
  }
  if (schema.additionalProperties === false) {
    result.addError({
      name: 'additionalProperties',
      argument: property,
      message: "is not allowed to have the additional property " + JSON.stringify(property),
    });
  } else {
    var additionalProperties = schema.additionalProperties || {};

    if (typeof options.preValidateProperty == 'function') {
      options.preValidateProperty(instance, property, additionalProperties, options, ctx);
    }

    var res = this.validateSchema(instance[property], additionalProperties, options, ctx.makeChild(additionalProperties, property));
    if(res.instance !== result.instance[property]) result.instance[property] = res.instance;
    result.importErrors(res);
  }
}

/**
 * Validates patternProperties
 * @param instance
 * @param schema
 * @param options
 * @param ctx
 * @return {String|null|ValidatorResult}
 */
validators.patternProperties = function validatePatternProperties (instance, schema, options, ctx) {
  if(!this.types.object(instance)) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  var patternProperties = schema.patternProperties || {};

  for (var property in instance) {
    var test = true;
    for (var pattern in patternProperties) {
      var subschema = patternProperties[pattern];
      if(subschema===undefined){
        continue;
      }else if(subschema===null){
        throw new SchemaError('Unexpected null, expected schema in "patternProperties"');
      }
      try {
        var regexp = new RegExp(pattern, 'u');
      } catch(_e) {
        // In the event the stricter handling causes an error, fall back on the forgiving handling
        // DEPRECATED
        regexp = new RegExp(pattern);
      }
      if (!regexp.test(property)) {
        continue;
      }
      test = false;

      if (typeof options.preValidateProperty == 'function') {
        options.preValidateProperty(instance, property, subschema, options, ctx);
      }

      var res = this.validateSchema(instance[property], subschema, options, ctx.makeChild(subschema, property));
      if(res.instance !== result.instance[property]) result.instance[property] = res.instance;
      result.importErrors(res);
    }
    if (test) {
      testAdditionalProperty.call(this, instance, schema, options, ctx, property, result);
    }
  }

  return result;
};

/**
 * Validates additionalProperties
 * @param instance
 * @param schema
 * @param options
 * @param ctx
 * @return {String|null|ValidatorResult}
 */
validators.additionalProperties = function validateAdditionalProperties (instance, schema, options, ctx) {
  if(!this.types.object(instance)) return;
  // if patternProperties is defined then we'll test when that one is called instead
  if (schema.patternProperties) {
    return null;
  }
  var result = new ValidatorResult(instance, schema, options, ctx);
  for (var property in instance) {
    testAdditionalProperty.call(this, instance, schema, options, ctx, property, result);
  }
  return result;
};

/**
 * Validates whether the instance value is at least of a certain length, when the instance value is a string.
 * @param instance
 * @param schema
 * @return {String|null}
 */
validators.minProperties = function validateMinProperties (instance, schema, options, ctx) {
  if (!this.types.object(instance)) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  var keys = Object.keys(instance);
  if (!(keys.length >= schema.minProperties)) {
    result.addError({
      name: 'minProperties',
      argument: schema.minProperties,
      message: "does not meet minimum property length of " + schema.minProperties,
    });
  }
  return result;
};

/**
 * Validates whether the instance value is at most of a certain length, when the instance value is a string.
 * @param instance
 * @param schema
 * @return {String|null}
 */
validators.maxProperties = function validateMaxProperties (instance, schema, options, ctx) {
  if (!this.types.object(instance)) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  var keys = Object.keys(instance);
  if (!(keys.length <= schema.maxProperties)) {
    result.addError({
      name: 'maxProperties',
      argument: schema.maxProperties,
      message: "does not meet maximum property length of " + schema.maxProperties,
    });
  }
  return result;
};

/**
 * Validates items when instance is an array
 * @param instance
 * @param schema
 * @param options
 * @param ctx
 * @return {String|null|ValidatorResult}
 */
validators.items = function validateItems (instance, schema, options, ctx) {
  var self = this;
  if (!this.types.array(instance)) return;
  if (!schema.items) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  instance.every(function (value, i) {
    var items = Array.isArray(schema.items) ? (schema.items[i] || schema.additionalItems) : schema.items;
    if (items === undefined) {
      return true;
    }
    if (items === false) {
      result.addError({
        name: 'items',
        message: "additionalItems not permitted",
      });
      return false;
    }
    var res = self.validateSchema(value, items, options, ctx.makeChild(items, i));
    if(res.instance !== result.instance[i]) result.instance[i] = res.instance;
    result.importErrors(res);
    return true;
  });
  return result;
};

/**
 * Validates minimum and exclusiveMinimum when the type of the instance value is a number.
 * @param instance
 * @param schema
 * @return {String|null}
 */
validators.minimum = function validateMinimum (instance, schema, options, ctx) {
  if (!this.types.number(instance)) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  if (schema.exclusiveMinimum && schema.exclusiveMinimum === true) {
    if(!(instance > schema.minimum)){
      result.addError({
        name: 'minimum',
        argument: schema.minimum,
        message: "must be greater than " + schema.minimum,
      });
    }
  } else {
    if(!(instance >= schema.minimum)){
      result.addError({
        name: 'minimum',
        argument: schema.minimum,
        message: "must be greater than or equal to " + schema.minimum,
      });
    }
  }
  return result;
};

/**
 * Validates maximum and exclusiveMaximum when the type of the instance value is a number.
 * @param instance
 * @param schema
 * @return {String|null}
 */
validators.maximum = function validateMaximum (instance, schema, options, ctx) {
  if (!this.types.number(instance)) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  if (schema.exclusiveMaximum && schema.exclusiveMaximum === true) {
    if(!(instance < schema.maximum)){
      result.addError({
        name: 'maximum',
        argument: schema.maximum,
        message: "must be less than " + schema.maximum,
      });
    }
  } else {
    if(!(instance <= schema.maximum)){
      result.addError({
        name: 'maximum',
        argument: schema.maximum,
        message: "must be less than or equal to " + schema.maximum,
      });
    }
  }
  return result;
};

/**
 * Validates the number form of exclusiveMinimum when the type of the instance value is a number.
 * @param instance
 * @param schema
 * @return {String|null}
 */
validators.exclusiveMinimum = function validateExclusiveMinimum (instance, schema, options, ctx) {
  // Support the boolean form of exclusiveMinimum, which is handled by the "minimum" keyword.
  if(typeof schema.exclusiveMaximum === 'boolean') return;
  if (!this.types.number(instance)) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  var valid = instance > schema.exclusiveMinimum;
  if (!valid) {
    result.addError({
      name: 'exclusiveMinimum',
      argument: schema.exclusiveMinimum,
      message: "must be strictly greater than " + schema.exclusiveMinimum,
    });
  }
  return result;
};

/**
 * Validates the number form of exclusiveMaximum when the type of the instance value is a number.
 * @param instance
 * @param schema
 * @return {String|null}
 */
validators.exclusiveMaximum = function validateExclusiveMaximum (instance, schema, options, ctx) {
  // Support the boolean form of exclusiveMaximum, which is handled by the "maximum" keyword.
  if(typeof schema.exclusiveMaximum === 'boolean') return;
  if (!this.types.number(instance)) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  var valid = instance < schema.exclusiveMaximum;
  if (!valid) {
    result.addError({
      name: 'exclusiveMaximum',
      argument: schema.exclusiveMaximum,
      message: "must be strictly less than " + schema.exclusiveMaximum,
    });
  }
  return result;
};

/**
 * Perform validation for multipleOf and divisibleBy, which are essentially the same.
 * @param instance
 * @param schema
 * @param validationType
 * @param errorMessage
 * @returns {String|null}
 */
var validateMultipleOfOrDivisbleBy = function validateMultipleOfOrDivisbleBy (instance, schema, options, ctx, validationType, errorMessage) {
  if (!this.types.number(instance)) return;

  var validationArgument = schema[validationType];
  if (validationArgument == 0) {
    throw new SchemaError(validationType + " cannot be zero");
  }

  var result = new ValidatorResult(instance, schema, options, ctx);

  var instanceDecimals = helpers.getDecimalPlaces(instance);
  var divisorDecimals = helpers.getDecimalPlaces(validationArgument);

  var maxDecimals = Math.max(instanceDecimals , divisorDecimals);
  var multiplier = Math.pow(10, maxDecimals);

  if (Math.round(instance * multiplier) % Math.round(validationArgument * multiplier) !== 0) {
    result.addError({
      name: validationType,
      argument:  validationArgument,
      message: errorMessage + JSON.stringify(validationArgument),
    });
  }

  return result;
};

/**
 * Validates divisibleBy when the type of the instance value is a number.
 * @param instance
 * @param schema
 * @return {String|null}
 */
validators.multipleOf = function validateMultipleOf (instance, schema, options, ctx) {
  return validateMultipleOfOrDivisbleBy.call(this, instance, schema, options, ctx, "multipleOf", "is not a multiple of (divisible by) ");
};

/**
 * Validates multipleOf when the type of the instance value is a number.
 * @param instance
 * @param schema
 * @return {String|null}
 */
validators.divisibleBy = function validateDivisibleBy (instance, schema, options, ctx) {
  return validateMultipleOfOrDivisbleBy.call(this, instance, schema, options, ctx, "divisibleBy", "is not divisible by (multiple of) ");
};

/**
 * Validates whether the instance value is present.
 * @param instance
 * @param schema
 * @return {String|null}
 */
validators.required = function validateRequired (instance, schema, options, ctx) {
  var result = new ValidatorResult(instance, schema, options, ctx);
  if (instance === undefined && schema.required === true) {
    // A boolean form is implemented for reverse-compatibility with schemas written against older drafts
    result.addError({
      name: 'required',
      message: "is required",
    });
  } else if (this.types.object(instance) && Array.isArray(schema.required)) {
    schema.required.forEach(function(n){
      if(getEnumerableProperty(instance, n)===undefined){
        result.addError({
          name: 'required',
          argument: n,
          message: "requires property " + JSON.stringify(n),
        });
      }
    });
  }
  return result;
};

/**
 * Validates whether the instance value matches the regular expression, when the instance value is a string.
 * @param instance
 * @param schema
 * @return {String|null}
 */
validators.pattern = function validatePattern (instance, schema, options, ctx) {
  if (!this.types.string(instance)) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  var pattern = schema.pattern;
  try {
    var regexp = new RegExp(pattern, 'u');
  } catch(_e) {
    // In the event the stricter handling causes an error, fall back on the forgiving handling
    // DEPRECATED
    regexp = new RegExp(pattern);
  }
  if (!instance.match(regexp)) {
    result.addError({
      name: 'pattern',
      argument: schema.pattern,
      message: "does not match pattern " + JSON.stringify(schema.pattern.toString()),
    });
  }
  return result;
};

/**
 * Validates whether the instance value is of a certain defined format or a custom
 * format.
 * The following formats are supported for string types:
 *   - date-time
 *   - date
 *   - time
 *   - ip-address
 *   - ipv6
 *   - uri
 *   - color
 *   - host-name
 *   - alpha
 *   - alpha-numeric
 *   - utc-millisec
 * @param instance
 * @param schema
 * @param [options]
 * @param [ctx]
 * @return {String|null}
 */
validators.format = function validateFormat (instance, schema, options, ctx) {
  if (instance===undefined) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  if (!result.disableFormat && !helpers.isFormat(instance, schema.format, this)) {
    result.addError({
      name: 'format',
      argument: schema.format,
      message: "does not conform to the " + JSON.stringify(schema.format) + " format",
    });
  }
  return result;
};

/**
 * Validates whether the instance value is at least of a certain length, when the instance value is a string.
 * @param instance
 * @param schema
 * @return {String|null}
 */
validators.minLength = function validateMinLength (instance, schema, options, ctx) {
  if (!this.types.string(instance)) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  var hsp = instance.match(/[\uDC00-\uDFFF]/g);
  var length = instance.length - (hsp ? hsp.length : 0);
  if (!(length >= schema.minLength)) {
    result.addError({
      name: 'minLength',
      argument: schema.minLength,
      message: "does not meet minimum length of " + schema.minLength,
    });
  }
  return result;
};

/**
 * Validates whether the instance value is at most of a certain length, when the instance value is a string.
 * @param instance
 * @param schema
 * @return {String|null}
 */
validators.maxLength = function validateMaxLength (instance, schema, options, ctx) {
  if (!this.types.string(instance)) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  // TODO if this was already computed in "minLength", use that value instead of re-computing
  var hsp = instance.match(/[\uDC00-\uDFFF]/g);
  var length = instance.length - (hsp ? hsp.length : 0);
  if (!(length <= schema.maxLength)) {
    result.addError({
      name: 'maxLength',
      argument: schema.maxLength,
      message: "does not meet maximum length of " + schema.maxLength,
    });
  }
  return result;
};

/**
 * Validates whether instance contains at least a minimum number of items, when the instance is an Array.
 * @param instance
 * @param schema
 * @return {String|null}
 */
validators.minItems = function validateMinItems (instance, schema, options, ctx) {
  if (!this.types.array(instance)) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  if (!(instance.length >= schema.minItems)) {
    result.addError({
      name: 'minItems',
      argument: schema.minItems,
      message: "does not meet minimum length of " + schema.minItems,
    });
  }
  return result;
};

/**
 * Validates whether instance contains no more than a maximum number of items, when the instance is an Array.
 * @param instance
 * @param schema
 * @return {String|null}
 */
validators.maxItems = function validateMaxItems (instance, schema, options, ctx) {
  if (!this.types.array(instance)) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  if (!(instance.length <= schema.maxItems)) {
    result.addError({
      name: 'maxItems',
      argument: schema.maxItems,
      message: "does not meet maximum length of " + schema.maxItems,
    });
  }
  return result;
};

/**
 * Deep compares arrays for duplicates
 * @param v
 * @param i
 * @param a
 * @private
 * @return {boolean}
 */
function testArrays (v, i, a) {
  var j, len = a.length;
  for (j = i + 1, len; j < len; j++) {
    if (helpers.deepCompareStrict(v, a[j])) {
      return false;
    }
  }
  return true;
}

/**
 * Validates whether there are no duplicates, when the instance is an Array.
 * @param instance
 * @return {String|null}
 */
validators.uniqueItems = function validateUniqueItems (instance, schema, options, ctx) {
  if (schema.uniqueItems!==true) return;
  if (!this.types.array(instance)) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  if (!instance.every(testArrays)) {
    result.addError({
      name: 'uniqueItems',
      message: "contains duplicate item",
    });
  }
  return result;
};

/**
 * Validate for the presence of dependency properties, if the instance is an object.
 * @param instance
 * @param schema
 * @param options
 * @param ctx
 * @return {null|ValidatorResult}
 */
validators.dependencies = function validateDependencies (instance, schema, options, ctx) {
  if (!this.types.object(instance)) return;
  var result = new ValidatorResult(instance, schema, options, ctx);
  for (var property in schema.dependencies) {
    if (instance[property] === undefined) {
      continue;
    }
    var dep = schema.dependencies[property];
    var childContext = ctx.makeChild(dep, property);
    if (typeof dep == 'string') {
      dep = [dep];
    }
    if (Array.isArray(dep)) {
      dep.forEach(function (prop) {
        if (instance[prop] === undefined) {
          result.addError({
            // FIXME there's two different "dependencies" errors here with slightly different outputs
            // Can we make these the same? Or should we create different error types?
            name: 'dependencies',
            argument: childContext.propertyPath,
            message: "property " + prop + " not found, required by " + childContext.propertyPath,
          });
        }
      });
    } else {
      var res = this.validateSchema(instance, dep, options, childContext);
      if(result.instance !== res.instance) result.instance = res.instance;
      if (res && res.errors.length) {
        result.addError({
          name: 'dependencies',
          argument: childContext.propertyPath,
          message: "does not meet dependency required by " + childContext.propertyPath,
        });
        result.importErrors(res);
      }
    }
  }
  return result;
};

/**
 * Validates whether the instance value is one of the enumerated values.
 *
 * @param instance
 * @param schema
 * @return {ValidatorResult|null}
 */
validators['enum'] = function validateEnum (instance, schema, options, ctx) {
  if (instance === undefined) {
    return null;
  }
  if (!Array.isArray(schema['enum'])) {
    throw new SchemaError("enum expects an array", schema);
  }
  var result = new ValidatorResult(instance, schema, options, ctx);
  if (!schema['enum'].some(helpers.deepCompareStrict.bind(null, instance))) {
    result.addError({
      name: 'enum',
      argument: schema['enum'],
      message: "is not one of enum values: " + schema['enum'].map(String).join(','),
    });
  }
  return result;
};

/**
 * Validates whether the instance exactly matches a given value
 *
 * @param instance
 * @param schema
 * @return {ValidatorResult|null}
 */
validators['const'] = function validateEnum (instance, schema, options, ctx) {
  if (instance === undefined) {
    return null;
  }
  var result = new ValidatorResult(instance, schema, options, ctx);
  if (!helpers.deepCompareStrict(schema['const'], instance)) {
    result.addError({
      name: 'const',
      argument: schema['const'],
      message: "does not exactly match expected constant: " + schema['const'],
    });
  }
  return result;
};

/**
 * Validates whether the instance if of a prohibited type.
 * @param instance
 * @param schema
 * @param options
 * @param ctx
 * @return {null|ValidatorResult}
 */
validators.not = validators.disallow = function validateNot (instance, schema, options, ctx) {
  var self = this;
  if(instance===undefined) return null;
  var result = new ValidatorResult(instance, schema, options, ctx);
  var notTypes = schema.not || schema.disallow;
  if(!notTypes) return null;
  if(!Array.isArray(notTypes)) notTypes=[notTypes];
  notTypes.forEach(function (type) {
    if (self.testType(instance, schema, options, ctx, type)) {
      var id = type && (type.$id || type.id);
      var schemaId = id || type;
      result.addError({
        name: 'not',
        argument: schemaId,
        message: "is of prohibited type " + schemaId,
      });
    }
  });
  return result;
};

module.exports = attribute;


/***/ }),

/***/ "../../node_modules/jsonschema/lib/helpers.js":
/*!****************************************************!*\
  !*** ../../node_modules/jsonschema/lib/helpers.js ***!
  \****************************************************/
/***/ ((module, exports, __webpack_require__) => {

"use strict";


var uri = __webpack_require__(/*! url */ "../../node_modules/url/url.js");

var ValidationError = exports.ValidationError = function ValidationError (message, instance, schema, path, name, argument) {
  if(Array.isArray(path)){
    this.path = path;
    this.property = path.reduce(function(sum, item){
      return sum + makeSuffix(item);
    }, 'instance');
  }else if(path !== undefined){
    this.property = path;
  }
  if (message) {
    this.message = message;
  }
  if (schema) {
    var id = schema.$id || schema.id;
    this.schema = id || schema;
  }
  if (instance !== undefined) {
    this.instance = instance;
  }
  this.name = name;
  this.argument = argument;
  this.stack = this.toString();
};

ValidationError.prototype.toString = function toString() {
  return this.property + ' ' + this.message;
};

var ValidatorResult = exports.ValidatorResult = function ValidatorResult(instance, schema, options, ctx) {
  this.instance = instance;
  this.schema = schema;
  this.options = options;
  this.path = ctx.path;
  this.propertyPath = ctx.propertyPath;
  this.errors = [];
  this.throwError = options && options.throwError;
  this.throwFirst = options && options.throwFirst;
  this.throwAll = options && options.throwAll;
  this.disableFormat = options && options.disableFormat === true;
};

ValidatorResult.prototype.addError = function addError(detail) {
  var err;
  if (typeof detail == 'string') {
    err = new ValidationError(detail, this.instance, this.schema, this.path);
  } else {
    if (!detail) throw new Error('Missing error detail');
    if (!detail.message) throw new Error('Missing error message');
    if (!detail.name) throw new Error('Missing validator type');
    err = new ValidationError(detail.message, this.instance, this.schema, this.path, detail.name, detail.argument);
  }

  this.errors.push(err);
  if (this.throwFirst) {
    throw new ValidatorResultError(this);
  }else if(this.throwError){
    throw err;
  }
  return err;
};

ValidatorResult.prototype.importErrors = function importErrors(res) {
  if (typeof res == 'string' || (res && res.validatorType)) {
    this.addError(res);
  } else if (res && res.errors) {
    Array.prototype.push.apply(this.errors, res.errors);
  }
};

function stringizer (v,i){
  return i+': '+v.toString()+'\n';
}
ValidatorResult.prototype.toString = function toString(res) {
  return this.errors.map(stringizer).join('');
};

Object.defineProperty(ValidatorResult.prototype, "valid", { get: function() {
  return !this.errors.length;
} });

module.exports.ValidatorResultError = ValidatorResultError;
function ValidatorResultError(result) {
  if(Error.captureStackTrace){
    Error.captureStackTrace(this, ValidatorResultError);
  }
  this.instance = result.instance;
  this.schema = result.schema;
  this.options = result.options;
  this.errors = result.errors;
}
ValidatorResultError.prototype = new Error();
ValidatorResultError.prototype.constructor = ValidatorResultError;
ValidatorResultError.prototype.name = "Validation Error";

/**
 * Describes a problem with a Schema which prevents validation of an instance
 * @name SchemaError
 * @constructor
 */
var SchemaError = exports.SchemaError = function SchemaError (msg, schema) {
  this.message = msg;
  this.schema = schema;
  Error.call(this, msg);
  Error.captureStackTrace(this, SchemaError);
};
SchemaError.prototype = Object.create(Error.prototype,
  {
    constructor: {value: SchemaError, enumerable: false},
    name: {value: 'SchemaError', enumerable: false},
  });

var SchemaContext = exports.SchemaContext = function SchemaContext (schema, options, path, base, schemas) {
  this.schema = schema;
  this.options = options;
  if(Array.isArray(path)){
    this.path = path;
    this.propertyPath = path.reduce(function(sum, item){
      return sum + makeSuffix(item);
    }, 'instance');
  }else{
    this.propertyPath = path;
  }
  this.base = base;
  this.schemas = schemas;
};

SchemaContext.prototype.resolve = function resolve (target) {
  return uri.resolve(this.base, target);
};

SchemaContext.prototype.makeChild = function makeChild(schema, propertyName){
  var path = (propertyName===undefined) ? this.path : this.path.concat([propertyName]);
  var id = schema.$id || schema.id;
  var base = uri.resolve(this.base, id||'');
  var ctx = new SchemaContext(schema, this.options, path, base, Object.create(this.schemas));
  if(id && !ctx.schemas[base]){
    ctx.schemas[base] = schema;
  }
  return ctx;
};

var FORMAT_REGEXPS = exports.FORMAT_REGEXPS = {
  'date-time': /^\d{4}-(?:0[0-9]{1}|1[0-2]{1})-(3[01]|0[1-9]|[12][0-9])[tT ](2[0-4]|[01][0-9]):([0-5][0-9]):(60|[0-5][0-9])(\.\d+)?([zZ]|[+-]([0-5][0-9]):(60|[0-5][0-9]))$/,
  'date': /^\d{4}-(?:0[0-9]{1}|1[0-2]{1})-(3[01]|0[1-9]|[12][0-9])$/,
  'time': /^(2[0-4]|[01][0-9]):([0-5][0-9]):(60|[0-5][0-9])$/,

  'email': /^(?:[\w\!\#\$\%\&\'\*\+\-\/\=\?\^\`\{\|\}\~]+\.)*[\w\!\#\$\%\&\'\*\+\-\/\=\?\^\`\{\|\}\~]+@(?:(?:(?:[a-zA-Z0-9](?:[a-zA-Z0-9\-](?!\.)){0,61}[a-zA-Z0-9]?\.)+[a-zA-Z0-9](?:[a-zA-Z0-9\-](?!$)){0,61}[a-zA-Z0-9]?)|(?:\[(?:(?:[01]?\d{1,2}|2[0-4]\d|25[0-5])\.){3}(?:[01]?\d{1,2}|2[0-4]\d|25[0-5])\]))$/,
  'ip-address': /^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/,
  'ipv6': /^\s*((([0-9A-Fa-f]{1,4}:){7}([0-9A-Fa-f]{1,4}|:))|(([0-9A-Fa-f]{1,4}:){6}(:[0-9A-Fa-f]{1,4}|((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){5}(((:[0-9A-Fa-f]{1,4}){1,2})|:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){4}(((:[0-9A-Fa-f]{1,4}){1,3})|((:[0-9A-Fa-f]{1,4})?:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){3}(((:[0-9A-Fa-f]{1,4}){1,4})|((:[0-9A-Fa-f]{1,4}){0,2}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){2}(((:[0-9A-Fa-f]{1,4}){1,5})|((:[0-9A-Fa-f]{1,4}){0,3}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){1}(((:[0-9A-Fa-f]{1,4}){1,6})|((:[0-9A-Fa-f]{1,4}){0,4}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(:(((:[0-9A-Fa-f]{1,4}){1,7})|((:[0-9A-Fa-f]{1,4}){0,5}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:)))(%.+)?\s*$/,

  // TODO: A more accurate regular expression for "uri" goes:
  // [A-Za-z][+\-.0-9A-Za-z]*:((/(/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~])+|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?)(:\d*)?)?)?#(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*|(/(/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~])+|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?)(:\d*)?[/?]|[!$&-.0-;=?-Z_a-z~])|/?%[0-9A-Fa-f]{2}|[!$&-.0-;=?-Z_a-z~])(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*(#(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*)?|/(/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~])+(:\d*)?|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?:\d*|\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?)?)?
  'uri': /^[a-zA-Z][a-zA-Z0-9+-.]*:[^\s]*$/,
  'uri-reference': /^(((([A-Za-z][+\-.0-9A-Za-z]*(:%[0-9A-Fa-f]{2}|:[!$&-.0-;=?-Z_a-z~]|[/?])|\?)(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*|([A-Za-z][+\-.0-9A-Za-z]*:?)?)|([A-Za-z][+\-.0-9A-Za-z]*:)?\/((%[0-9A-Fa-f]{2}|\/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~])+|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?)(:\d*)?[/?]|[!$&-.0-;=?-Z_a-z~])(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*|(\/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~])+|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?)(:\d*)?)?))#(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*|(([A-Za-z][+\-.0-9A-Za-z]*)?%[0-9A-Fa-f]{2}|[!$&-.0-9;=@_~]|[A-Za-z][+\-.0-9A-Za-z]*[!$&-*,;=@_~])(%[0-9A-Fa-f]{2}|[!$&-.0-9;=@-Z_a-z~])*((([/?](%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*)?#|[/?])(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*)?|([A-Za-z][+\-.0-9A-Za-z]*(:%[0-9A-Fa-f]{2}|:[!$&-.0-;=?-Z_a-z~]|[/?])|\?)(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*|([A-Za-z][+\-.0-9A-Za-z]*:)?\/((%[0-9A-Fa-f]{2}|\/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~])+|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?)(:\d*)?[/?]|[!$&-.0-;=?-Z_a-z~])(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*|\/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~])+(:\d*)?|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?:\d*|\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?)?|[A-Za-z][+\-.0-9A-Za-z]*:?)?$/,

  'color': /^(#?([0-9A-Fa-f]{3}){1,2}\b|aqua|black|blue|fuchsia|gray|green|lime|maroon|navy|olive|orange|purple|red|silver|teal|white|yellow|(rgb\(\s*\b([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\b\s*,\s*\b([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\b\s*,\s*\b([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\b\s*\))|(rgb\(\s*(\d?\d%|100%)+\s*,\s*(\d?\d%|100%)+\s*,\s*(\d?\d%|100%)+\s*\)))$/,

  // hostname regex from: http://stackoverflow.com/a/1420225/5628
  'hostname': /^(?=.{1,255}$)[0-9A-Za-z](?:(?:[0-9A-Za-z]|-){0,61}[0-9A-Za-z])?(?:\.[0-9A-Za-z](?:(?:[0-9A-Za-z]|-){0,61}[0-9A-Za-z])?)*\.?$/,
  'host-name': /^(?=.{1,255}$)[0-9A-Za-z](?:(?:[0-9A-Za-z]|-){0,61}[0-9A-Za-z])?(?:\.[0-9A-Za-z](?:(?:[0-9A-Za-z]|-){0,61}[0-9A-Za-z])?)*\.?$/,

  'alpha': /^[a-zA-Z]+$/,
  'alphanumeric': /^[a-zA-Z0-9]+$/,
  'utc-millisec': function (input) {
    return (typeof input === 'string') && parseFloat(input) === parseInt(input, 10) && !isNaN(input);
  },
  'regex': function (input) {
    var result = true;
    try {
      new RegExp(input);
    } catch (e) {
      result = false;
    }
    return result;
  },
  'style': /\s*(.+?):\s*([^;]+);?/,
  'phone': /^\+(?:[0-9] ?){6,14}[0-9]$/,
};

FORMAT_REGEXPS.regexp = FORMAT_REGEXPS.regex;
FORMAT_REGEXPS.pattern = FORMAT_REGEXPS.regex;
FORMAT_REGEXPS.ipv4 = FORMAT_REGEXPS['ip-address'];

exports.isFormat = function isFormat (input, format, validator) {
  if (typeof input === 'string' && FORMAT_REGEXPS[format] !== undefined) {
    if (FORMAT_REGEXPS[format] instanceof RegExp) {
      return FORMAT_REGEXPS[format].test(input);
    }
    if (typeof FORMAT_REGEXPS[format] === 'function') {
      return FORMAT_REGEXPS[format](input);
    }
  } else if (validator && validator.customFormats &&
      typeof validator.customFormats[format] === 'function') {
    return validator.customFormats[format](input);
  }
  return true;
};

var makeSuffix = exports.makeSuffix = function makeSuffix (key) {
  key = key.toString();
  // This function could be capable of outputting valid a ECMAScript string, but the
  // resulting code for testing which form to use would be tens of thousands of characters long
  // That means this will use the name form for some illegal forms
  if (!key.match(/[.\s\[\]]/) && !key.match(/^[\d]/)) {
    return '.' + key;
  }
  if (key.match(/^\d+$/)) {
    return '[' + key + ']';
  }
  return '[' + JSON.stringify(key) + ']';
};

exports.deepCompareStrict = function deepCompareStrict (a, b) {
  if (typeof a !== typeof b) {
    return false;
  }
  if (Array.isArray(a)) {
    if (!Array.isArray(b)) {
      return false;
    }
    if (a.length !== b.length) {
      return false;
    }
    return a.every(function (v, i) {
      return deepCompareStrict(a[i], b[i]);
    });
  }
  if (typeof a === 'object') {
    if (!a || !b) {
      return a === b;
    }
    var aKeys = Object.keys(a);
    var bKeys = Object.keys(b);
    if (aKeys.length !== bKeys.length) {
      return false;
    }
    return aKeys.every(function (v) {
      return deepCompareStrict(a[v], b[v]);
    });
  }
  return a === b;
};

function deepMerger (target, dst, e, i) {
  if (typeof e === 'object') {
    dst[i] = deepMerge(target[i], e);
  } else {
    if (target.indexOf(e) === -1) {
      dst.push(e);
    }
  }
}

function copyist (src, dst, key) {
  dst[key] = src[key];
}

function copyistWithDeepMerge (target, src, dst, key) {
  if (typeof src[key] !== 'object' || !src[key]) {
    dst[key] = src[key];
  }
  else {
    if (!target[key]) {
      dst[key] = src[key];
    } else {
      dst[key] = deepMerge(target[key], src[key]);
    }
  }
}

function deepMerge (target, src) {
  var array = Array.isArray(src);
  var dst = array && [] || {};

  if (array) {
    target = target || [];
    dst = dst.concat(target);
    src.forEach(deepMerger.bind(null, target, dst));
  } else {
    if (target && typeof target === 'object') {
      Object.keys(target).forEach(copyist.bind(null, target, dst));
    }
    Object.keys(src).forEach(copyistWithDeepMerge.bind(null, target, src, dst));
  }

  return dst;
}

module.exports.deepMerge = deepMerge;

/**
 * Validates instance against the provided schema
 * Implements URI+JSON Pointer encoding, e.g. "%7e"="~0"=>"~", "~1"="%2f"=>"/"
 * @param o
 * @param s The path to walk o along
 * @return any
 */
exports.objectGetPath = function objectGetPath(o, s) {
  var parts = s.split('/').slice(1);
  var k;
  while (typeof (k=parts.shift()) == 'string') {
    var n = decodeURIComponent(k.replace(/~0/,'~').replace(/~1/g,'/'));
    if (!(n in o)) return;
    o = o[n];
  }
  return o;
};

function pathEncoder (v) {
  return '/'+encodeURIComponent(v).replace(/~/g,'%7E');
}
/**
 * Accept an Array of property names and return a JSON Pointer URI fragment
 * @param Array a
 * @return {String}
 */
exports.encodePath = function encodePointer(a){
  // ~ must be encoded explicitly because hacks
  // the slash is encoded by encodeURIComponent
  return a.map(pathEncoder).join('');
};


/**
 * Calculate the number of decimal places a number uses
 * We need this to get correct results out of multipleOf and divisibleBy
 * when either figure is has decimal places, due to IEEE-754 float issues.
 * @param number
 * @returns {number}
 */
exports.getDecimalPlaces = function getDecimalPlaces(number) {

  var decimalPlaces = 0;
  if (isNaN(number)) return decimalPlaces;

  if (typeof number !== 'number') {
    number = Number(number);
  }

  var parts = number.toString().split('e');
  if (parts.length === 2) {
    if (parts[1][0] !== '-') {
      return decimalPlaces;
    } else {
      decimalPlaces = Number(parts[1].slice(1));
    }
  }

  var decimalParts = parts[0].split('.');
  if (decimalParts.length === 2) {
    decimalPlaces += decimalParts[1].length;
  }

  return decimalPlaces;
};

exports.isSchema = function isSchema(val){
  return (typeof val === 'object' && val) || (typeof val === 'boolean');
};



/***/ }),

/***/ "../../node_modules/jsonschema/lib/index.js":
/*!**************************************************!*\
  !*** ../../node_modules/jsonschema/lib/index.js ***!
  \**************************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

"use strict";


var Validator = module.exports.Validator = __webpack_require__(/*! ./validator */ "../../node_modules/jsonschema/lib/validator.js");

module.exports.ValidatorResult = __webpack_require__(/*! ./helpers */ "../../node_modules/jsonschema/lib/helpers.js").ValidatorResult;
module.exports.ValidatorResultError = __webpack_require__(/*! ./helpers */ "../../node_modules/jsonschema/lib/helpers.js").ValidatorResultError;
module.exports.ValidationError = __webpack_require__(/*! ./helpers */ "../../node_modules/jsonschema/lib/helpers.js").ValidationError;
module.exports.SchemaError = __webpack_require__(/*! ./helpers */ "../../node_modules/jsonschema/lib/helpers.js").SchemaError;
module.exports.SchemaScanResult = __webpack_require__(/*! ./scan */ "../../node_modules/jsonschema/lib/scan.js").SchemaScanResult;
module.exports.scan = __webpack_require__(/*! ./scan */ "../../node_modules/jsonschema/lib/scan.js").scan;

module.exports.validate = function (instance, schema, options) {
  var v = new Validator();
  return v.validate(instance, schema, options);
};


/***/ }),

/***/ "../../node_modules/jsonschema/lib/scan.js":
/*!*************************************************!*\
  !*** ../../node_modules/jsonschema/lib/scan.js ***!
  \*************************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

"use strict";


var urilib = __webpack_require__(/*! url */ "../../node_modules/url/url.js");
var helpers = __webpack_require__(/*! ./helpers */ "../../node_modules/jsonschema/lib/helpers.js");

module.exports.SchemaScanResult = SchemaScanResult;
function SchemaScanResult(found, ref){
  this.id = found;
  this.ref = ref;
}

/**
 * Adds a schema with a certain urn to the Validator instance.
 * @param string uri
 * @param object schema
 * @return {Object}
 */
module.exports.scan = function scan(base, schema){
  function scanSchema(baseuri, schema){
    if(!schema || typeof schema!='object') return;
    // Mark all referenced schemas so we can tell later which schemas are referred to, but never defined
    if(schema.$ref){
      var resolvedUri = urilib.resolve(baseuri, schema.$ref);
      ref[resolvedUri] = ref[resolvedUri] ? ref[resolvedUri]+1 : 0;
      return;
    }
    var id = schema.$id || schema.id;
    var ourBase = id ? urilib.resolve(baseuri, id) : baseuri;
    if (ourBase) {
      // If there's no fragment, append an empty one
      if(ourBase.indexOf('#')<0) ourBase += '#';
      if(found[ourBase]){
        if(!helpers.deepCompareStrict(found[ourBase], schema)){
          throw new Error('Schema <'+ourBase+'> already exists with different definition');
        }
        return found[ourBase];
      }
      found[ourBase] = schema;
      // strip trailing fragment
      if(ourBase[ourBase.length-1]=='#'){
        found[ourBase.substring(0, ourBase.length-1)] = schema;
      }
    }
    scanArray(ourBase+'/items', (Array.isArray(schema.items)?schema.items:[schema.items]));
    scanArray(ourBase+'/extends', (Array.isArray(schema.extends)?schema.extends:[schema.extends]));
    scanSchema(ourBase+'/additionalItems', schema.additionalItems);
    scanObject(ourBase+'/properties', schema.properties);
    scanSchema(ourBase+'/additionalProperties', schema.additionalProperties);
    scanObject(ourBase+'/definitions', schema.definitions);
    scanObject(ourBase+'/patternProperties', schema.patternProperties);
    scanObject(ourBase+'/dependencies', schema.dependencies);
    scanArray(ourBase+'/disallow', schema.disallow);
    scanArray(ourBase+'/allOf', schema.allOf);
    scanArray(ourBase+'/anyOf', schema.anyOf);
    scanArray(ourBase+'/oneOf', schema.oneOf);
    scanSchema(ourBase+'/not', schema.not);
  }
  function scanArray(baseuri, schemas){
    if(!Array.isArray(schemas)) return;
    for(var i=0; i<schemas.length; i++){
      scanSchema(baseuri+'/'+i, schemas[i]);
    }
  }
  function scanObject(baseuri, schemas){
    if(!schemas || typeof schemas!='object') return;
    for(var p in schemas){
      scanSchema(baseuri+'/'+p, schemas[p]);
    }
  }

  var found = {};
  var ref = {};
  scanSchema(base, schema);
  return new SchemaScanResult(found, ref);
};


/***/ }),

/***/ "../../node_modules/jsonschema/lib/validator.js":
/*!******************************************************!*\
  !*** ../../node_modules/jsonschema/lib/validator.js ***!
  \******************************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

"use strict";


var urilib = __webpack_require__(/*! url */ "../../node_modules/url/url.js");

var attribute = __webpack_require__(/*! ./attribute */ "../../node_modules/jsonschema/lib/attribute.js");
var helpers = __webpack_require__(/*! ./helpers */ "../../node_modules/jsonschema/lib/helpers.js");
var scanSchema = (__webpack_require__(/*! ./scan */ "../../node_modules/jsonschema/lib/scan.js").scan);
var ValidatorResult = helpers.ValidatorResult;
var ValidatorResultError = helpers.ValidatorResultError;
var SchemaError = helpers.SchemaError;
var SchemaContext = helpers.SchemaContext;
//var anonymousBase = 'vnd.jsonschema:///';
var anonymousBase = '/';

/**
 * Creates a new Validator object
 * @name Validator
 * @constructor
 */
var Validator = function Validator () {
  // Allow a validator instance to override global custom formats or to have their
  // own custom formats.
  this.customFormats = Object.create(Validator.prototype.customFormats);
  this.schemas = {};
  this.unresolvedRefs = [];

  // Use Object.create to make this extensible without Validator instances stepping on each other's toes.
  this.types = Object.create(types);
  this.attributes = Object.create(attribute.validators);
};

// Allow formats to be registered globally.
Validator.prototype.customFormats = {};

// Hint at the presence of a property
Validator.prototype.schemas = null;
Validator.prototype.types = null;
Validator.prototype.attributes = null;
Validator.prototype.unresolvedRefs = null;

/**
 * Adds a schema with a certain urn to the Validator instance.
 * @param schema
 * @param urn
 * @return {Object}
 */
Validator.prototype.addSchema = function addSchema (schema, base) {
  var self = this;
  if (!schema) {
    return null;
  }
  var scan = scanSchema(base||anonymousBase, schema);
  var ourUri = base || schema.$id || schema.id;
  for(var uri in scan.id){
    this.schemas[uri] = scan.id[uri];
  }
  for(var uri in scan.ref){
    // If this schema is already defined, it will be filtered out by the next step
    this.unresolvedRefs.push(uri);
  }
  // Remove newly defined schemas from unresolvedRefs
  this.unresolvedRefs = this.unresolvedRefs.filter(function(uri){
    return typeof self.schemas[uri]==='undefined';
  });
  return this.schemas[ourUri];
};

Validator.prototype.addSubSchemaArray = function addSubSchemaArray(baseuri, schemas) {
  if(!Array.isArray(schemas)) return;
  for(var i=0; i<schemas.length; i++){
    this.addSubSchema(baseuri, schemas[i]);
  }
};

Validator.prototype.addSubSchemaObject = function addSubSchemaArray(baseuri, schemas) {
  if(!schemas || typeof schemas!='object') return;
  for(var p in schemas){
    this.addSubSchema(baseuri, schemas[p]);
  }
};



/**
 * Sets all the schemas of the Validator instance.
 * @param schemas
 */
Validator.prototype.setSchemas = function setSchemas (schemas) {
  this.schemas = schemas;
};

/**
 * Returns the schema of a certain urn
 * @param urn
 */
Validator.prototype.getSchema = function getSchema (urn) {
  return this.schemas[urn];
};

/**
 * Validates instance against the provided schema
 * @param instance
 * @param schema
 * @param [options]
 * @param [ctx]
 * @return {Array}
 */
Validator.prototype.validate = function validate (instance, schema, options, ctx) {
  if((typeof schema !== 'boolean' && typeof schema !== 'object') || schema === null){
    throw new SchemaError('Expected `schema` to be an object or boolean');
  }
  if (!options) {
    options = {};
  }
  // This section indexes subschemas in the provided schema, so they don't need to be added with Validator#addSchema
  // This will work so long as the function at uri.resolve() will resolve a relative URI to a relative URI
  var id = schema.$id || schema.id;
  var base = urilib.resolve(options.base||anonymousBase, id||'');
  if(!ctx){
    ctx = new SchemaContext(schema, options, [], base, Object.create(this.schemas));
    if (!ctx.schemas[base]) {
      ctx.schemas[base] = schema;
    }
    var found = scanSchema(base, schema);
    for(var n in found.id){
      var sch = found.id[n];
      ctx.schemas[n] = sch;
    }
  }
  if(options.required && instance===undefined){
    var result = new ValidatorResult(instance, schema, options, ctx);
    result.addError('is required, but is undefined');
    return result;
  }
  var result = this.validateSchema(instance, schema, options, ctx);
  if (!result) {
    throw new Error('Result undefined');
  }else if(options.throwAll && result.errors.length){
    throw new ValidatorResultError(result);
  }
  return result;
};

/**
* @param Object schema
* @return mixed schema uri or false
*/
function shouldResolve(schema) {
  var ref = (typeof schema === 'string') ? schema : schema.$ref;
  if (typeof ref=='string') return ref;
  return false;
}

/**
 * Validates an instance against the schema (the actual work horse)
 * @param instance
 * @param schema
 * @param options
 * @param ctx
 * @private
 * @return {ValidatorResult}
 */
Validator.prototype.validateSchema = function validateSchema (instance, schema, options, ctx) {
  var result = new ValidatorResult(instance, schema, options, ctx);

  // Support for the true/false schemas
  if(typeof schema==='boolean') {
    if(schema===true){
      // `true` is always valid
      schema = {};
    }else if(schema===false){
      // `false` is always invalid
      schema = {type: []};
    }
  }else if(!schema){
    // This might be a string
    throw new Error("schema is undefined");
  }

  if (schema['extends']) {
    if (Array.isArray(schema['extends'])) {
      var schemaobj = {schema: schema, ctx: ctx};
      schema['extends'].forEach(this.schemaTraverser.bind(this, schemaobj));
      schema = schemaobj.schema;
      schemaobj.schema = null;
      schemaobj.ctx = null;
      schemaobj = null;
    } else {
      schema = helpers.deepMerge(schema, this.superResolve(schema['extends'], ctx));
    }
  }

  // If passed a string argument, load that schema URI
  var switchSchema = shouldResolve(schema);
  if (switchSchema) {
    var resolved = this.resolve(schema, switchSchema, ctx);
    var subctx = new SchemaContext(resolved.subschema, options, ctx.path, resolved.switchSchema, ctx.schemas);
    return this.validateSchema(instance, resolved.subschema, options, subctx);
  }

  var skipAttributes = options && options.skipAttributes || [];
  // Validate each schema attribute against the instance
  for (var key in schema) {
    if (!attribute.ignoreProperties[key] && skipAttributes.indexOf(key) < 0) {
      var validatorErr = null;
      var validator = this.attributes[key];
      if (validator) {
        validatorErr = validator.call(this, instance, schema, options, ctx);
      } else if (options.allowUnknownAttributes === false) {
        // This represents an error with the schema itself, not an invalid instance
        throw new SchemaError("Unsupported attribute: " + key, schema);
      }
      if (validatorErr) {
        result.importErrors(validatorErr);
      }
    }
  }

  if (typeof options.rewrite == 'function') {
    var value = options.rewrite.call(this, instance, schema, options, ctx);
    result.instance = value;
  }
  return result;
};

/**
* @private
* @param Object schema
* @param SchemaContext ctx
* @returns Object schema or resolved schema
*/
Validator.prototype.schemaTraverser = function schemaTraverser (schemaobj, s) {
  schemaobj.schema = helpers.deepMerge(schemaobj.schema, this.superResolve(s, schemaobj.ctx));
};

/**
* @private
* @param Object schema
* @param SchemaContext ctx
* @returns Object schema or resolved schema
*/
Validator.prototype.superResolve = function superResolve (schema, ctx) {
  var ref = shouldResolve(schema);
  if(ref) {
    return this.resolve(schema, ref, ctx).subschema;
  }
  return schema;
};

/**
* @private
* @param Object schema
* @param Object switchSchema
* @param SchemaContext ctx
* @return Object resolved schemas {subschema:String, switchSchema: String}
* @throws SchemaError
*/
Validator.prototype.resolve = function resolve (schema, switchSchema, ctx) {
  switchSchema = ctx.resolve(switchSchema);
  // First see if the schema exists under the provided URI
  if (ctx.schemas[switchSchema]) {
    return {subschema: ctx.schemas[switchSchema], switchSchema: switchSchema};
  }
  // Else try walking the property pointer
  var parsed = urilib.parse(switchSchema);
  var fragment = parsed && parsed.hash;
  var document = fragment && fragment.length && switchSchema.substr(0, switchSchema.length - fragment.length);
  if (!document || !ctx.schemas[document]) {
    throw new SchemaError("no such schema <" + switchSchema + ">", schema);
  }
  var subschema = helpers.objectGetPath(ctx.schemas[document], fragment.substr(1));
  if(subschema===undefined){
    throw new SchemaError("no such schema " + fragment + " located in <" + document + ">", schema);
  }
  return {subschema: subschema, switchSchema: switchSchema};
};

/**
 * Tests whether the instance if of a certain type.
 * @private
 * @param instance
 * @param schema
 * @param options
 * @param ctx
 * @param type
 * @return {boolean}
 */
Validator.prototype.testType = function validateType (instance, schema, options, ctx, type) {
  if(type===undefined){
    return;
  }else if(type===null){
    throw new SchemaError('Unexpected null in "type" keyword');
  }
  if (typeof this.types[type] == 'function') {
    return this.types[type].call(this, instance);
  }
  if (type && typeof type == 'object') {
    var res = this.validateSchema(instance, type, options, ctx);
    return res === undefined || !(res && res.errors.length);
  }
  // Undefined or properties not on the list are acceptable, same as not being defined
  return true;
};

var types = Validator.prototype.types = {};
types.string = function testString (instance) {
  return typeof instance == 'string';
};
types.number = function testNumber (instance) {
  // isFinite returns false for NaN, Infinity, and -Infinity
  return typeof instance == 'number' && isFinite(instance);
};
types.integer = function testInteger (instance) {
  return (typeof instance == 'number') && instance % 1 === 0;
};
types.boolean = function testBoolean (instance) {
  return typeof instance == 'boolean';
};
types.array = function testArray (instance) {
  return Array.isArray(instance);
};
types['null'] = function testNull (instance) {
  return instance === null;
};
types.date = function testDate (instance) {
  return instance instanceof Date;
};
types.any = function testAny (instance) {
  return true;
};
types.object = function testObject (instance) {
  // TODO: fix this - see #15
  return instance && (typeof instance === 'object') && !(Array.isArray(instance)) && !(instance instanceof Date);
};

module.exports = Validator;


/***/ }),

/***/ "../../node_modules/lodash.findlast/index.js":
/*!***************************************************!*\
  !*** ../../node_modules/lodash.findlast/index.js ***!
  \***************************************************/
/***/ ((module, exports, __webpack_require__) => {

/* module decorator */ module = __webpack_require__.nmd(module);
/**
 * lodash (Custom Build) <https://lodash.com/>
 * Build: `lodash modularize exports="npm" -o ./`
 * Copyright jQuery Foundation and other contributors <https://jquery.org/>
 * Released under MIT license <https://lodash.com/license>
 * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
 * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
 */

/** Used as the size to enable large array optimizations. */
var LARGE_ARRAY_SIZE = 200;

/** Used as the `TypeError` message for "Functions" methods. */
var FUNC_ERROR_TEXT = 'Expected a function';

/** Used to stand-in for `undefined` hash values. */
var HASH_UNDEFINED = '__lodash_hash_undefined__';

/** Used to compose bitmasks for comparison styles. */
var UNORDERED_COMPARE_FLAG = 1,
    PARTIAL_COMPARE_FLAG = 2;

/** Used as references for various `Number` constants. */
var INFINITY = 1 / 0,
    MAX_SAFE_INTEGER = 9007199254740991,
    MAX_INTEGER = 1.7976931348623157e+308,
    NAN = 0 / 0;

/** `Object#toString` result references. */
var argsTag = '[object Arguments]',
    arrayTag = '[object Array]',
    boolTag = '[object Boolean]',
    dateTag = '[object Date]',
    errorTag = '[object Error]',
    funcTag = '[object Function]',
    genTag = '[object GeneratorFunction]',
    mapTag = '[object Map]',
    numberTag = '[object Number]',
    objectTag = '[object Object]',
    promiseTag = '[object Promise]',
    regexpTag = '[object RegExp]',
    setTag = '[object Set]',
    stringTag = '[object String]',
    symbolTag = '[object Symbol]',
    weakMapTag = '[object WeakMap]';

var arrayBufferTag = '[object ArrayBuffer]',
    dataViewTag = '[object DataView]',
    float32Tag = '[object Float32Array]',
    float64Tag = '[object Float64Array]',
    int8Tag = '[object Int8Array]',
    int16Tag = '[object Int16Array]',
    int32Tag = '[object Int32Array]',
    uint8Tag = '[object Uint8Array]',
    uint8ClampedTag = '[object Uint8ClampedArray]',
    uint16Tag = '[object Uint16Array]',
    uint32Tag = '[object Uint32Array]';

/** Used to match property names within property paths. */
var reIsDeepProp = /\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,
    reIsPlainProp = /^\w*$/,
    reLeadingDot = /^\./,
    rePropName = /[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g;

/**
 * Used to match `RegExp`
 * [syntax characters](http://ecma-international.org/ecma-262/7.0/#sec-patterns).
 */
var reRegExpChar = /[\\^$.*+?()[\]{}|]/g;

/** Used to match leading and trailing whitespace. */
var reTrim = /^\s+|\s+$/g;

/** Used to match backslashes in property paths. */
var reEscapeChar = /\\(\\)?/g;

/** Used to detect bad signed hexadecimal string values. */
var reIsBadHex = /^[-+]0x[0-9a-f]+$/i;

/** Used to detect binary string values. */
var reIsBinary = /^0b[01]+$/i;

/** Used to detect host constructors (Safari). */
var reIsHostCtor = /^\[object .+?Constructor\]$/;

/** Used to detect octal string values. */
var reIsOctal = /^0o[0-7]+$/i;

/** Used to detect unsigned integer values. */
var reIsUint = /^(?:0|[1-9]\d*)$/;

/** Used to identify `toStringTag` values of typed arrays. */
var typedArrayTags = {};
typedArrayTags[float32Tag] = typedArrayTags[float64Tag] =
typedArrayTags[int8Tag] = typedArrayTags[int16Tag] =
typedArrayTags[int32Tag] = typedArrayTags[uint8Tag] =
typedArrayTags[uint8ClampedTag] = typedArrayTags[uint16Tag] =
typedArrayTags[uint32Tag] = true;
typedArrayTags[argsTag] = typedArrayTags[arrayTag] =
typedArrayTags[arrayBufferTag] = typedArrayTags[boolTag] =
typedArrayTags[dataViewTag] = typedArrayTags[dateTag] =
typedArrayTags[errorTag] = typedArrayTags[funcTag] =
typedArrayTags[mapTag] = typedArrayTags[numberTag] =
typedArrayTags[objectTag] = typedArrayTags[regexpTag] =
typedArrayTags[setTag] = typedArrayTags[stringTag] =
typedArrayTags[weakMapTag] = false;

/** Built-in method references without a dependency on `root`. */
var freeParseInt = parseInt;

/** Detect free variable `global` from Node.js. */
var freeGlobal = typeof __webpack_require__.g == 'object' && __webpack_require__.g && __webpack_require__.g.Object === Object && __webpack_require__.g;

/** Detect free variable `self`. */
var freeSelf = typeof self == 'object' && self && self.Object === Object && self;

/** Used as a reference to the global object. */
var root = freeGlobal || freeSelf || Function('return this')();

/** Detect free variable `exports`. */
var freeExports =  true && exports && !exports.nodeType && exports;

/** Detect free variable `module`. */
var freeModule = freeExports && "object" == 'object' && module && !module.nodeType && module;

/** Detect the popular CommonJS extension `module.exports`. */
var moduleExports = freeModule && freeModule.exports === freeExports;

/** Detect free variable `process` from Node.js. */
var freeProcess = moduleExports && freeGlobal.process;

/** Used to access faster Node.js helpers. */
var nodeUtil = (function() {
  try {
    return freeProcess && freeProcess.binding('util');
  } catch (e) {}
}());

/* Node.js helper references. */
var nodeIsTypedArray = nodeUtil && nodeUtil.isTypedArray;

/**
 * A specialized version of `_.some` for arrays without support for iteratee
 * shorthands.
 *
 * @private
 * @param {Array} [array] The array to iterate over.
 * @param {Function} predicate The function invoked per iteration.
 * @returns {boolean} Returns `true` if any element passes the predicate check,
 *  else `false`.
 */
function arraySome(array, predicate) {
  var index = -1,
      length = array ? array.length : 0;

  while (++index < length) {
    if (predicate(array[index], index, array)) {
      return true;
    }
  }
  return false;
}

/**
 * The base implementation of `_.findIndex` and `_.findLastIndex` without
 * support for iteratee shorthands.
 *
 * @private
 * @param {Array} array The array to inspect.
 * @param {Function} predicate The function invoked per iteration.
 * @param {number} fromIndex The index to search from.
 * @param {boolean} [fromRight] Specify iterating from right to left.
 * @returns {number} Returns the index of the matched value, else `-1`.
 */
function baseFindIndex(array, predicate, fromIndex, fromRight) {
  var length = array.length,
      index = fromIndex + (fromRight ? 1 : -1);

  while ((fromRight ? index-- : ++index < length)) {
    if (predicate(array[index], index, array)) {
      return index;
    }
  }
  return -1;
}

/**
 * The base implementation of `_.property` without support for deep paths.
 *
 * @private
 * @param {string} key The key of the property to get.
 * @returns {Function} Returns the new accessor function.
 */
function baseProperty(key) {
  return function(object) {
    return object == null ? undefined : object[key];
  };
}

/**
 * The base implementation of `_.times` without support for iteratee shorthands
 * or max array length checks.
 *
 * @private
 * @param {number} n The number of times to invoke `iteratee`.
 * @param {Function} iteratee The function invoked per iteration.
 * @returns {Array} Returns the array of results.
 */
function baseTimes(n, iteratee) {
  var index = -1,
      result = Array(n);

  while (++index < n) {
    result[index] = iteratee(index);
  }
  return result;
}

/**
 * The base implementation of `_.unary` without support for storing metadata.
 *
 * @private
 * @param {Function} func The function to cap arguments for.
 * @returns {Function} Returns the new capped function.
 */
function baseUnary(func) {
  return function(value) {
    return func(value);
  };
}

/**
 * Gets the value at `key` of `object`.
 *
 * @private
 * @param {Object} [object] The object to query.
 * @param {string} key The key of the property to get.
 * @returns {*} Returns the property value.
 */
function getValue(object, key) {
  return object == null ? undefined : object[key];
}

/**
 * Checks if `value` is a host object in IE < 9.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a host object, else `false`.
 */
function isHostObject(value) {
  // Many host objects are `Object` objects that can coerce to strings
  // despite having improperly defined `toString` methods.
  var result = false;
  if (value != null && typeof value.toString != 'function') {
    try {
      result = !!(value + '');
    } catch (e) {}
  }
  return result;
}

/**
 * Converts `map` to its key-value pairs.
 *
 * @private
 * @param {Object} map The map to convert.
 * @returns {Array} Returns the key-value pairs.
 */
function mapToArray(map) {
  var index = -1,
      result = Array(map.size);

  map.forEach(function(value, key) {
    result[++index] = [key, value];
  });
  return result;
}

/**
 * Creates a unary function that invokes `func` with its argument transformed.
 *
 * @private
 * @param {Function} func The function to wrap.
 * @param {Function} transform The argument transform.
 * @returns {Function} Returns the new function.
 */
function overArg(func, transform) {
  return function(arg) {
    return func(transform(arg));
  };
}

/**
 * Converts `set` to an array of its values.
 *
 * @private
 * @param {Object} set The set to convert.
 * @returns {Array} Returns the values.
 */
function setToArray(set) {
  var index = -1,
      result = Array(set.size);

  set.forEach(function(value) {
    result[++index] = value;
  });
  return result;
}

/** Used for built-in method references. */
var arrayProto = Array.prototype,
    funcProto = Function.prototype,
    objectProto = Object.prototype;

/** Used to detect overreaching core-js shims. */
var coreJsData = root['__core-js_shared__'];

/** Used to detect methods masquerading as native. */
var maskSrcKey = (function() {
  var uid = /[^.]+$/.exec(coreJsData && coreJsData.keys && coreJsData.keys.IE_PROTO || '');
  return uid ? ('Symbol(src)_1.' + uid) : '';
}());

/** Used to resolve the decompiled source of functions. */
var funcToString = funcProto.toString;

/** Used to check objects for own properties. */
var hasOwnProperty = objectProto.hasOwnProperty;

/**
 * Used to resolve the
 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
 * of values.
 */
var objectToString = objectProto.toString;

/** Used to detect if a method is native. */
var reIsNative = RegExp('^' +
  funcToString.call(hasOwnProperty).replace(reRegExpChar, '\\$&')
  .replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, '$1.*?') + '$'
);

/** Built-in value references. */
var Symbol = root.Symbol,
    Uint8Array = root.Uint8Array,
    propertyIsEnumerable = objectProto.propertyIsEnumerable,
    splice = arrayProto.splice;

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeKeys = overArg(Object.keys, Object),
    nativeMax = Math.max,
    nativeMin = Math.min;

/* Built-in method references that are verified to be native. */
var DataView = getNative(root, 'DataView'),
    Map = getNative(root, 'Map'),
    Promise = getNative(root, 'Promise'),
    Set = getNative(root, 'Set'),
    WeakMap = getNative(root, 'WeakMap'),
    nativeCreate = getNative(Object, 'create');

/** Used to detect maps, sets, and weakmaps. */
var dataViewCtorString = toSource(DataView),
    mapCtorString = toSource(Map),
    promiseCtorString = toSource(Promise),
    setCtorString = toSource(Set),
    weakMapCtorString = toSource(WeakMap);

/** Used to convert symbols to primitives and strings. */
var symbolProto = Symbol ? Symbol.prototype : undefined,
    symbolValueOf = symbolProto ? symbolProto.valueOf : undefined,
    symbolToString = symbolProto ? symbolProto.toString : undefined;

/**
 * Creates a hash object.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function Hash(entries) {
  var index = -1,
      length = entries ? entries.length : 0;

  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}

/**
 * Removes all key-value entries from the hash.
 *
 * @private
 * @name clear
 * @memberOf Hash
 */
function hashClear() {
  this.__data__ = nativeCreate ? nativeCreate(null) : {};
}

/**
 * Removes `key` and its value from the hash.
 *
 * @private
 * @name delete
 * @memberOf Hash
 * @param {Object} hash The hash to modify.
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function hashDelete(key) {
  return this.has(key) && delete this.__data__[key];
}

/**
 * Gets the hash value for `key`.
 *
 * @private
 * @name get
 * @memberOf Hash
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function hashGet(key) {
  var data = this.__data__;
  if (nativeCreate) {
    var result = data[key];
    return result === HASH_UNDEFINED ? undefined : result;
  }
  return hasOwnProperty.call(data, key) ? data[key] : undefined;
}

/**
 * Checks if a hash value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf Hash
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function hashHas(key) {
  var data = this.__data__;
  return nativeCreate ? data[key] !== undefined : hasOwnProperty.call(data, key);
}

/**
 * Sets the hash `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf Hash
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the hash instance.
 */
function hashSet(key, value) {
  var data = this.__data__;
  data[key] = (nativeCreate && value === undefined) ? HASH_UNDEFINED : value;
  return this;
}

// Add methods to `Hash`.
Hash.prototype.clear = hashClear;
Hash.prototype['delete'] = hashDelete;
Hash.prototype.get = hashGet;
Hash.prototype.has = hashHas;
Hash.prototype.set = hashSet;

/**
 * Creates an list cache object.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function ListCache(entries) {
  var index = -1,
      length = entries ? entries.length : 0;

  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}

/**
 * Removes all key-value entries from the list cache.
 *
 * @private
 * @name clear
 * @memberOf ListCache
 */
function listCacheClear() {
  this.__data__ = [];
}

/**
 * Removes `key` and its value from the list cache.
 *
 * @private
 * @name delete
 * @memberOf ListCache
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function listCacheDelete(key) {
  var data = this.__data__,
      index = assocIndexOf(data, key);

  if (index < 0) {
    return false;
  }
  var lastIndex = data.length - 1;
  if (index == lastIndex) {
    data.pop();
  } else {
    splice.call(data, index, 1);
  }
  return true;
}

/**
 * Gets the list cache value for `key`.
 *
 * @private
 * @name get
 * @memberOf ListCache
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function listCacheGet(key) {
  var data = this.__data__,
      index = assocIndexOf(data, key);

  return index < 0 ? undefined : data[index][1];
}

/**
 * Checks if a list cache value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf ListCache
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function listCacheHas(key) {
  return assocIndexOf(this.__data__, key) > -1;
}

/**
 * Sets the list cache `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf ListCache
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the list cache instance.
 */
function listCacheSet(key, value) {
  var data = this.__data__,
      index = assocIndexOf(data, key);

  if (index < 0) {
    data.push([key, value]);
  } else {
    data[index][1] = value;
  }
  return this;
}

// Add methods to `ListCache`.
ListCache.prototype.clear = listCacheClear;
ListCache.prototype['delete'] = listCacheDelete;
ListCache.prototype.get = listCacheGet;
ListCache.prototype.has = listCacheHas;
ListCache.prototype.set = listCacheSet;

/**
 * Creates a map cache object to store key-value pairs.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function MapCache(entries) {
  var index = -1,
      length = entries ? entries.length : 0;

  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}

/**
 * Removes all key-value entries from the map.
 *
 * @private
 * @name clear
 * @memberOf MapCache
 */
function mapCacheClear() {
  this.__data__ = {
    'hash': new Hash,
    'map': new (Map || ListCache),
    'string': new Hash
  };
}

/**
 * Removes `key` and its value from the map.
 *
 * @private
 * @name delete
 * @memberOf MapCache
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function mapCacheDelete(key) {
  return getMapData(this, key)['delete'](key);
}

/**
 * Gets the map value for `key`.
 *
 * @private
 * @name get
 * @memberOf MapCache
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function mapCacheGet(key) {
  return getMapData(this, key).get(key);
}

/**
 * Checks if a map value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf MapCache
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function mapCacheHas(key) {
  return getMapData(this, key).has(key);
}

/**
 * Sets the map `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf MapCache
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the map cache instance.
 */
function mapCacheSet(key, value) {
  getMapData(this, key).set(key, value);
  return this;
}

// Add methods to `MapCache`.
MapCache.prototype.clear = mapCacheClear;
MapCache.prototype['delete'] = mapCacheDelete;
MapCache.prototype.get = mapCacheGet;
MapCache.prototype.has = mapCacheHas;
MapCache.prototype.set = mapCacheSet;

/**
 *
 * Creates an array cache object to store unique values.
 *
 * @private
 * @constructor
 * @param {Array} [values] The values to cache.
 */
function SetCache(values) {
  var index = -1,
      length = values ? values.length : 0;

  this.__data__ = new MapCache;
  while (++index < length) {
    this.add(values[index]);
  }
}

/**
 * Adds `value` to the array cache.
 *
 * @private
 * @name add
 * @memberOf SetCache
 * @alias push
 * @param {*} value The value to cache.
 * @returns {Object} Returns the cache instance.
 */
function setCacheAdd(value) {
  this.__data__.set(value, HASH_UNDEFINED);
  return this;
}

/**
 * Checks if `value` is in the array cache.
 *
 * @private
 * @name has
 * @memberOf SetCache
 * @param {*} value The value to search for.
 * @returns {number} Returns `true` if `value` is found, else `false`.
 */
function setCacheHas(value) {
  return this.__data__.has(value);
}

// Add methods to `SetCache`.
SetCache.prototype.add = SetCache.prototype.push = setCacheAdd;
SetCache.prototype.has = setCacheHas;

/**
 * Creates a stack cache object to store key-value pairs.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function Stack(entries) {
  this.__data__ = new ListCache(entries);
}

/**
 * Removes all key-value entries from the stack.
 *
 * @private
 * @name clear
 * @memberOf Stack
 */
function stackClear() {
  this.__data__ = new ListCache;
}

/**
 * Removes `key` and its value from the stack.
 *
 * @private
 * @name delete
 * @memberOf Stack
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function stackDelete(key) {
  return this.__data__['delete'](key);
}

/**
 * Gets the stack value for `key`.
 *
 * @private
 * @name get
 * @memberOf Stack
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function stackGet(key) {
  return this.__data__.get(key);
}

/**
 * Checks if a stack value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf Stack
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function stackHas(key) {
  return this.__data__.has(key);
}

/**
 * Sets the stack `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf Stack
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the stack cache instance.
 */
function stackSet(key, value) {
  var cache = this.__data__;
  if (cache instanceof ListCache) {
    var pairs = cache.__data__;
    if (!Map || (pairs.length < LARGE_ARRAY_SIZE - 1)) {
      pairs.push([key, value]);
      return this;
    }
    cache = this.__data__ = new MapCache(pairs);
  }
  cache.set(key, value);
  return this;
}

// Add methods to `Stack`.
Stack.prototype.clear = stackClear;
Stack.prototype['delete'] = stackDelete;
Stack.prototype.get = stackGet;
Stack.prototype.has = stackHas;
Stack.prototype.set = stackSet;

/**
 * Creates an array of the enumerable property names of the array-like `value`.
 *
 * @private
 * @param {*} value The value to query.
 * @param {boolean} inherited Specify returning inherited property names.
 * @returns {Array} Returns the array of property names.
 */
function arrayLikeKeys(value, inherited) {
  // Safari 8.1 makes `arguments.callee` enumerable in strict mode.
  // Safari 9 makes `arguments.length` enumerable in strict mode.
  var result = (isArray(value) || isArguments(value))
    ? baseTimes(value.length, String)
    : [];

  var length = result.length,
      skipIndexes = !!length;

  for (var key in value) {
    if ((inherited || hasOwnProperty.call(value, key)) &&
        !(skipIndexes && (key == 'length' || isIndex(key, length)))) {
      result.push(key);
    }
  }
  return result;
}

/**
 * Gets the index at which the `key` is found in `array` of key-value pairs.
 *
 * @private
 * @param {Array} array The array to inspect.
 * @param {*} key The key to search for.
 * @returns {number} Returns the index of the matched value, else `-1`.
 */
function assocIndexOf(array, key) {
  var length = array.length;
  while (length--) {
    if (eq(array[length][0], key)) {
      return length;
    }
  }
  return -1;
}

/**
 * The base implementation of `_.get` without support for default values.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {Array|string} path The path of the property to get.
 * @returns {*} Returns the resolved value.
 */
function baseGet(object, path) {
  path = isKey(path, object) ? [path] : castPath(path);

  var index = 0,
      length = path.length;

  while (object != null && index < length) {
    object = object[toKey(path[index++])];
  }
  return (index && index == length) ? object : undefined;
}

/**
 * The base implementation of `getTag`.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the `toStringTag`.
 */
function baseGetTag(value) {
  return objectToString.call(value);
}

/**
 * The base implementation of `_.hasIn` without support for deep paths.
 *
 * @private
 * @param {Object} [object] The object to query.
 * @param {Array|string} key The key to check.
 * @returns {boolean} Returns `true` if `key` exists, else `false`.
 */
function baseHasIn(object, key) {
  return object != null && key in Object(object);
}

/**
 * The base implementation of `_.isEqual` which supports partial comparisons
 * and tracks traversed objects.
 *
 * @private
 * @param {*} value The value to compare.
 * @param {*} other The other value to compare.
 * @param {Function} [customizer] The function to customize comparisons.
 * @param {boolean} [bitmask] The bitmask of comparison flags.
 *  The bitmask may be composed of the following flags:
 *     1 - Unordered comparison
 *     2 - Partial comparison
 * @param {Object} [stack] Tracks traversed `value` and `other` objects.
 * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
 */
function baseIsEqual(value, other, customizer, bitmask, stack) {
  if (value === other) {
    return true;
  }
  if (value == null || other == null || (!isObject(value) && !isObjectLike(other))) {
    return value !== value && other !== other;
  }
  return baseIsEqualDeep(value, other, baseIsEqual, customizer, bitmask, stack);
}

/**
 * A specialized version of `baseIsEqual` for arrays and objects which performs
 * deep comparisons and tracks traversed objects enabling objects with circular
 * references to be compared.
 *
 * @private
 * @param {Object} object The object to compare.
 * @param {Object} other The other object to compare.
 * @param {Function} equalFunc The function to determine equivalents of values.
 * @param {Function} [customizer] The function to customize comparisons.
 * @param {number} [bitmask] The bitmask of comparison flags. See `baseIsEqual`
 *  for more details.
 * @param {Object} [stack] Tracks traversed `object` and `other` objects.
 * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
 */
function baseIsEqualDeep(object, other, equalFunc, customizer, bitmask, stack) {
  var objIsArr = isArray(object),
      othIsArr = isArray(other),
      objTag = arrayTag,
      othTag = arrayTag;

  if (!objIsArr) {
    objTag = getTag(object);
    objTag = objTag == argsTag ? objectTag : objTag;
  }
  if (!othIsArr) {
    othTag = getTag(other);
    othTag = othTag == argsTag ? objectTag : othTag;
  }
  var objIsObj = objTag == objectTag && !isHostObject(object),
      othIsObj = othTag == objectTag && !isHostObject(other),
      isSameTag = objTag == othTag;

  if (isSameTag && !objIsObj) {
    stack || (stack = new Stack);
    return (objIsArr || isTypedArray(object))
      ? equalArrays(object, other, equalFunc, customizer, bitmask, stack)
      : equalByTag(object, other, objTag, equalFunc, customizer, bitmask, stack);
  }
  if (!(bitmask & PARTIAL_COMPARE_FLAG)) {
    var objIsWrapped = objIsObj && hasOwnProperty.call(object, '__wrapped__'),
        othIsWrapped = othIsObj && hasOwnProperty.call(other, '__wrapped__');

    if (objIsWrapped || othIsWrapped) {
      var objUnwrapped = objIsWrapped ? object.value() : object,
          othUnwrapped = othIsWrapped ? other.value() : other;

      stack || (stack = new Stack);
      return equalFunc(objUnwrapped, othUnwrapped, customizer, bitmask, stack);
    }
  }
  if (!isSameTag) {
    return false;
  }
  stack || (stack = new Stack);
  return equalObjects(object, other, equalFunc, customizer, bitmask, stack);
}

/**
 * The base implementation of `_.isMatch` without support for iteratee shorthands.
 *
 * @private
 * @param {Object} object The object to inspect.
 * @param {Object} source The object of property values to match.
 * @param {Array} matchData The property names, values, and compare flags to match.
 * @param {Function} [customizer] The function to customize comparisons.
 * @returns {boolean} Returns `true` if `object` is a match, else `false`.
 */
function baseIsMatch(object, source, matchData, customizer) {
  var index = matchData.length,
      length = index,
      noCustomizer = !customizer;

  if (object == null) {
    return !length;
  }
  object = Object(object);
  while (index--) {
    var data = matchData[index];
    if ((noCustomizer && data[2])
          ? data[1] !== object[data[0]]
          : !(data[0] in object)
        ) {
      return false;
    }
  }
  while (++index < length) {
    data = matchData[index];
    var key = data[0],
        objValue = object[key],
        srcValue = data[1];

    if (noCustomizer && data[2]) {
      if (objValue === undefined && !(key in object)) {
        return false;
      }
    } else {
      var stack = new Stack;
      if (customizer) {
        var result = customizer(objValue, srcValue, key, object, source, stack);
      }
      if (!(result === undefined
            ? baseIsEqual(srcValue, objValue, customizer, UNORDERED_COMPARE_FLAG | PARTIAL_COMPARE_FLAG, stack)
            : result
          )) {
        return false;
      }
    }
  }
  return true;
}

/**
 * The base implementation of `_.isNative` without bad shim checks.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a native function,
 *  else `false`.
 */
function baseIsNative(value) {
  if (!isObject(value) || isMasked(value)) {
    return false;
  }
  var pattern = (isFunction(value) || isHostObject(value)) ? reIsNative : reIsHostCtor;
  return pattern.test(toSource(value));
}

/**
 * The base implementation of `_.isTypedArray` without Node.js optimizations.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
 */
function baseIsTypedArray(value) {
  return isObjectLike(value) &&
    isLength(value.length) && !!typedArrayTags[objectToString.call(value)];
}

/**
 * The base implementation of `_.iteratee`.
 *
 * @private
 * @param {*} [value=_.identity] The value to convert to an iteratee.
 * @returns {Function} Returns the iteratee.
 */
function baseIteratee(value) {
  // Don't store the `typeof` result in a variable to avoid a JIT bug in Safari 9.
  // See https://bugs.webkit.org/show_bug.cgi?id=156034 for more details.
  if (typeof value == 'function') {
    return value;
  }
  if (value == null) {
    return identity;
  }
  if (typeof value == 'object') {
    return isArray(value)
      ? baseMatchesProperty(value[0], value[1])
      : baseMatches(value);
  }
  return property(value);
}

/**
 * The base implementation of `_.keys` which doesn't treat sparse arrays as dense.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names.
 */
function baseKeys(object) {
  if (!isPrototype(object)) {
    return nativeKeys(object);
  }
  var result = [];
  for (var key in Object(object)) {
    if (hasOwnProperty.call(object, key) && key != 'constructor') {
      result.push(key);
    }
  }
  return result;
}

/**
 * The base implementation of `_.matches` which doesn't clone `source`.
 *
 * @private
 * @param {Object} source The object of property values to match.
 * @returns {Function} Returns the new spec function.
 */
function baseMatches(source) {
  var matchData = getMatchData(source);
  if (matchData.length == 1 && matchData[0][2]) {
    return matchesStrictComparable(matchData[0][0], matchData[0][1]);
  }
  return function(object) {
    return object === source || baseIsMatch(object, source, matchData);
  };
}

/**
 * The base implementation of `_.matchesProperty` which doesn't clone `srcValue`.
 *
 * @private
 * @param {string} path The path of the property to get.
 * @param {*} srcValue The value to match.
 * @returns {Function} Returns the new spec function.
 */
function baseMatchesProperty(path, srcValue) {
  if (isKey(path) && isStrictComparable(srcValue)) {
    return matchesStrictComparable(toKey(path), srcValue);
  }
  return function(object) {
    var objValue = get(object, path);
    return (objValue === undefined && objValue === srcValue)
      ? hasIn(object, path)
      : baseIsEqual(srcValue, objValue, undefined, UNORDERED_COMPARE_FLAG | PARTIAL_COMPARE_FLAG);
  };
}

/**
 * A specialized version of `baseProperty` which supports deep paths.
 *
 * @private
 * @param {Array|string} path The path of the property to get.
 * @returns {Function} Returns the new accessor function.
 */
function basePropertyDeep(path) {
  return function(object) {
    return baseGet(object, path);
  };
}

/**
 * The base implementation of `_.toString` which doesn't convert nullish
 * values to empty strings.
 *
 * @private
 * @param {*} value The value to process.
 * @returns {string} Returns the string.
 */
function baseToString(value) {
  // Exit early for strings to avoid a performance hit in some environments.
  if (typeof value == 'string') {
    return value;
  }
  if (isSymbol(value)) {
    return symbolToString ? symbolToString.call(value) : '';
  }
  var result = (value + '');
  return (result == '0' && (1 / value) == -INFINITY) ? '-0' : result;
}

/**
 * Casts `value` to a path array if it's not one.
 *
 * @private
 * @param {*} value The value to inspect.
 * @returns {Array} Returns the cast property path array.
 */
function castPath(value) {
  return isArray(value) ? value : stringToPath(value);
}

/**
 * Creates a `_.find` or `_.findLast` function.
 *
 * @private
 * @param {Function} findIndexFunc The function to find the collection index.
 * @returns {Function} Returns the new find function.
 */
function createFind(findIndexFunc) {
  return function(collection, predicate, fromIndex) {
    var iterable = Object(collection);
    if (!isArrayLike(collection)) {
      var iteratee = baseIteratee(predicate, 3);
      collection = keys(collection);
      predicate = function(key) { return iteratee(iterable[key], key, iterable); };
    }
    var index = findIndexFunc(collection, predicate, fromIndex);
    return index > -1 ? iterable[iteratee ? collection[index] : index] : undefined;
  };
}

/**
 * A specialized version of `baseIsEqualDeep` for arrays with support for
 * partial deep comparisons.
 *
 * @private
 * @param {Array} array The array to compare.
 * @param {Array} other The other array to compare.
 * @param {Function} equalFunc The function to determine equivalents of values.
 * @param {Function} customizer The function to customize comparisons.
 * @param {number} bitmask The bitmask of comparison flags. See `baseIsEqual`
 *  for more details.
 * @param {Object} stack Tracks traversed `array` and `other` objects.
 * @returns {boolean} Returns `true` if the arrays are equivalent, else `false`.
 */
function equalArrays(array, other, equalFunc, customizer, bitmask, stack) {
  var isPartial = bitmask & PARTIAL_COMPARE_FLAG,
      arrLength = array.length,
      othLength = other.length;

  if (arrLength != othLength && !(isPartial && othLength > arrLength)) {
    return false;
  }
  // Assume cyclic values are equal.
  var stacked = stack.get(array);
  if (stacked && stack.get(other)) {
    return stacked == other;
  }
  var index = -1,
      result = true,
      seen = (bitmask & UNORDERED_COMPARE_FLAG) ? new SetCache : undefined;

  stack.set(array, other);
  stack.set(other, array);

  // Ignore non-index properties.
  while (++index < arrLength) {
    var arrValue = array[index],
        othValue = other[index];

    if (customizer) {
      var compared = isPartial
        ? customizer(othValue, arrValue, index, other, array, stack)
        : customizer(arrValue, othValue, index, array, other, stack);
    }
    if (compared !== undefined) {
      if (compared) {
        continue;
      }
      result = false;
      break;
    }
    // Recursively compare arrays (susceptible to call stack limits).
    if (seen) {
      if (!arraySome(other, function(othValue, othIndex) {
            if (!seen.has(othIndex) &&
                (arrValue === othValue || equalFunc(arrValue, othValue, customizer, bitmask, stack))) {
              return seen.add(othIndex);
            }
          })) {
        result = false;
        break;
      }
    } else if (!(
          arrValue === othValue ||
            equalFunc(arrValue, othValue, customizer, bitmask, stack)
        )) {
      result = false;
      break;
    }
  }
  stack['delete'](array);
  stack['delete'](other);
  return result;
}

/**
 * A specialized version of `baseIsEqualDeep` for comparing objects of
 * the same `toStringTag`.
 *
 * **Note:** This function only supports comparing values with tags of
 * `Boolean`, `Date`, `Error`, `Number`, `RegExp`, or `String`.
 *
 * @private
 * @param {Object} object The object to compare.
 * @param {Object} other The other object to compare.
 * @param {string} tag The `toStringTag` of the objects to compare.
 * @param {Function} equalFunc The function to determine equivalents of values.
 * @param {Function} customizer The function to customize comparisons.
 * @param {number} bitmask The bitmask of comparison flags. See `baseIsEqual`
 *  for more details.
 * @param {Object} stack Tracks traversed `object` and `other` objects.
 * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
 */
function equalByTag(object, other, tag, equalFunc, customizer, bitmask, stack) {
  switch (tag) {
    case dataViewTag:
      if ((object.byteLength != other.byteLength) ||
          (object.byteOffset != other.byteOffset)) {
        return false;
      }
      object = object.buffer;
      other = other.buffer;

    case arrayBufferTag:
      if ((object.byteLength != other.byteLength) ||
          !equalFunc(new Uint8Array(object), new Uint8Array(other))) {
        return false;
      }
      return true;

    case boolTag:
    case dateTag:
    case numberTag:
      // Coerce booleans to `1` or `0` and dates to milliseconds.
      // Invalid dates are coerced to `NaN`.
      return eq(+object, +other);

    case errorTag:
      return object.name == other.name && object.message == other.message;

    case regexpTag:
    case stringTag:
      // Coerce regexes to strings and treat strings, primitives and objects,
      // as equal. See http://www.ecma-international.org/ecma-262/7.0/#sec-regexp.prototype.tostring
      // for more details.
      return object == (other + '');

    case mapTag:
      var convert = mapToArray;

    case setTag:
      var isPartial = bitmask & PARTIAL_COMPARE_FLAG;
      convert || (convert = setToArray);

      if (object.size != other.size && !isPartial) {
        return false;
      }
      // Assume cyclic values are equal.
      var stacked = stack.get(object);
      if (stacked) {
        return stacked == other;
      }
      bitmask |= UNORDERED_COMPARE_FLAG;

      // Recursively compare objects (susceptible to call stack limits).
      stack.set(object, other);
      var result = equalArrays(convert(object), convert(other), equalFunc, customizer, bitmask, stack);
      stack['delete'](object);
      return result;

    case symbolTag:
      if (symbolValueOf) {
        return symbolValueOf.call(object) == symbolValueOf.call(other);
      }
  }
  return false;
}

/**
 * A specialized version of `baseIsEqualDeep` for objects with support for
 * partial deep comparisons.
 *
 * @private
 * @param {Object} object The object to compare.
 * @param {Object} other The other object to compare.
 * @param {Function} equalFunc The function to determine equivalents of values.
 * @param {Function} customizer The function to customize comparisons.
 * @param {number} bitmask The bitmask of comparison flags. See `baseIsEqual`
 *  for more details.
 * @param {Object} stack Tracks traversed `object` and `other` objects.
 * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
 */
function equalObjects(object, other, equalFunc, customizer, bitmask, stack) {
  var isPartial = bitmask & PARTIAL_COMPARE_FLAG,
      objProps = keys(object),
      objLength = objProps.length,
      othProps = keys(other),
      othLength = othProps.length;

  if (objLength != othLength && !isPartial) {
    return false;
  }
  var index = objLength;
  while (index--) {
    var key = objProps[index];
    if (!(isPartial ? key in other : hasOwnProperty.call(other, key))) {
      return false;
    }
  }
  // Assume cyclic values are equal.
  var stacked = stack.get(object);
  if (stacked && stack.get(other)) {
    return stacked == other;
  }
  var result = true;
  stack.set(object, other);
  stack.set(other, object);

  var skipCtor = isPartial;
  while (++index < objLength) {
    key = objProps[index];
    var objValue = object[key],
        othValue = other[key];

    if (customizer) {
      var compared = isPartial
        ? customizer(othValue, objValue, key, other, object, stack)
        : customizer(objValue, othValue, key, object, other, stack);
    }
    // Recursively compare objects (susceptible to call stack limits).
    if (!(compared === undefined
          ? (objValue === othValue || equalFunc(objValue, othValue, customizer, bitmask, stack))
          : compared
        )) {
      result = false;
      break;
    }
    skipCtor || (skipCtor = key == 'constructor');
  }
  if (result && !skipCtor) {
    var objCtor = object.constructor,
        othCtor = other.constructor;

    // Non `Object` object instances with different constructors are not equal.
    if (objCtor != othCtor &&
        ('constructor' in object && 'constructor' in other) &&
        !(typeof objCtor == 'function' && objCtor instanceof objCtor &&
          typeof othCtor == 'function' && othCtor instanceof othCtor)) {
      result = false;
    }
  }
  stack['delete'](object);
  stack['delete'](other);
  return result;
}

/**
 * Gets the data for `map`.
 *
 * @private
 * @param {Object} map The map to query.
 * @param {string} key The reference key.
 * @returns {*} Returns the map data.
 */
function getMapData(map, key) {
  var data = map.__data__;
  return isKeyable(key)
    ? data[typeof key == 'string' ? 'string' : 'hash']
    : data.map;
}

/**
 * Gets the property names, values, and compare flags of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the match data of `object`.
 */
function getMatchData(object) {
  var result = keys(object),
      length = result.length;

  while (length--) {
    var key = result[length],
        value = object[key];

    result[length] = [key, value, isStrictComparable(value)];
  }
  return result;
}

/**
 * Gets the native function at `key` of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {string} key The key of the method to get.
 * @returns {*} Returns the function if it's native, else `undefined`.
 */
function getNative(object, key) {
  var value = getValue(object, key);
  return baseIsNative(value) ? value : undefined;
}

/**
 * Gets the `toStringTag` of `value`.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the `toStringTag`.
 */
var getTag = baseGetTag;

// Fallback for data views, maps, sets, and weak maps in IE 11,
// for data views in Edge < 14, and promises in Node.js.
if ((DataView && getTag(new DataView(new ArrayBuffer(1))) != dataViewTag) ||
    (Map && getTag(new Map) != mapTag) ||
    (Promise && getTag(Promise.resolve()) != promiseTag) ||
    (Set && getTag(new Set) != setTag) ||
    (WeakMap && getTag(new WeakMap) != weakMapTag)) {
  getTag = function(value) {
    var result = objectToString.call(value),
        Ctor = result == objectTag ? value.constructor : undefined,
        ctorString = Ctor ? toSource(Ctor) : undefined;

    if (ctorString) {
      switch (ctorString) {
        case dataViewCtorString: return dataViewTag;
        case mapCtorString: return mapTag;
        case promiseCtorString: return promiseTag;
        case setCtorString: return setTag;
        case weakMapCtorString: return weakMapTag;
      }
    }
    return result;
  };
}

/**
 * Checks if `path` exists on `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {Array|string} path The path to check.
 * @param {Function} hasFunc The function to check properties.
 * @returns {boolean} Returns `true` if `path` exists, else `false`.
 */
function hasPath(object, path, hasFunc) {
  path = isKey(path, object) ? [path] : castPath(path);

  var result,
      index = -1,
      length = path.length;

  while (++index < length) {
    var key = toKey(path[index]);
    if (!(result = object != null && hasFunc(object, key))) {
      break;
    }
    object = object[key];
  }
  if (result) {
    return result;
  }
  var length = object ? object.length : 0;
  return !!length && isLength(length) && isIndex(key, length) &&
    (isArray(object) || isArguments(object));
}

/**
 * Checks if `value` is a valid array-like index.
 *
 * @private
 * @param {*} value The value to check.
 * @param {number} [length=MAX_SAFE_INTEGER] The upper bounds of a valid index.
 * @returns {boolean} Returns `true` if `value` is a valid index, else `false`.
 */
function isIndex(value, length) {
  length = length == null ? MAX_SAFE_INTEGER : length;
  return !!length &&
    (typeof value == 'number' || reIsUint.test(value)) &&
    (value > -1 && value % 1 == 0 && value < length);
}

/**
 * Checks if `value` is a property name and not a property path.
 *
 * @private
 * @param {*} value The value to check.
 * @param {Object} [object] The object to query keys on.
 * @returns {boolean} Returns `true` if `value` is a property name, else `false`.
 */
function isKey(value, object) {
  if (isArray(value)) {
    return false;
  }
  var type = typeof value;
  if (type == 'number' || type == 'symbol' || type == 'boolean' ||
      value == null || isSymbol(value)) {
    return true;
  }
  return reIsPlainProp.test(value) || !reIsDeepProp.test(value) ||
    (object != null && value in Object(object));
}

/**
 * Checks if `value` is suitable for use as unique object key.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is suitable, else `false`.
 */
function isKeyable(value) {
  var type = typeof value;
  return (type == 'string' || type == 'number' || type == 'symbol' || type == 'boolean')
    ? (value !== '__proto__')
    : (value === null);
}

/**
 * Checks if `func` has its source masked.
 *
 * @private
 * @param {Function} func The function to check.
 * @returns {boolean} Returns `true` if `func` is masked, else `false`.
 */
function isMasked(func) {
  return !!maskSrcKey && (maskSrcKey in func);
}

/**
 * Checks if `value` is likely a prototype object.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a prototype, else `false`.
 */
function isPrototype(value) {
  var Ctor = value && value.constructor,
      proto = (typeof Ctor == 'function' && Ctor.prototype) || objectProto;

  return value === proto;
}

/**
 * Checks if `value` is suitable for strict equality comparisons, i.e. `===`.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` if suitable for strict
 *  equality comparisons, else `false`.
 */
function isStrictComparable(value) {
  return value === value && !isObject(value);
}

/**
 * A specialized version of `matchesProperty` for source values suitable
 * for strict equality comparisons, i.e. `===`.
 *
 * @private
 * @param {string} key The key of the property to get.
 * @param {*} srcValue The value to match.
 * @returns {Function} Returns the new spec function.
 */
function matchesStrictComparable(key, srcValue) {
  return function(object) {
    if (object == null) {
      return false;
    }
    return object[key] === srcValue &&
      (srcValue !== undefined || (key in Object(object)));
  };
}

/**
 * Converts `string` to a property path array.
 *
 * @private
 * @param {string} string The string to convert.
 * @returns {Array} Returns the property path array.
 */
var stringToPath = memoize(function(string) {
  string = toString(string);

  var result = [];
  if (reLeadingDot.test(string)) {
    result.push('');
  }
  string.replace(rePropName, function(match, number, quote, string) {
    result.push(quote ? string.replace(reEscapeChar, '$1') : (number || match));
  });
  return result;
});

/**
 * Converts `value` to a string key if it's not a string or symbol.
 *
 * @private
 * @param {*} value The value to inspect.
 * @returns {string|symbol} Returns the key.
 */
function toKey(value) {
  if (typeof value == 'string' || isSymbol(value)) {
    return value;
  }
  var result = (value + '');
  return (result == '0' && (1 / value) == -INFINITY) ? '-0' : result;
}

/**
 * Converts `func` to its source code.
 *
 * @private
 * @param {Function} func The function to process.
 * @returns {string} Returns the source code.
 */
function toSource(func) {
  if (func != null) {
    try {
      return funcToString.call(func);
    } catch (e) {}
    try {
      return (func + '');
    } catch (e) {}
  }
  return '';
}

/**
 * This method is like `_.findIndex` except that it iterates over elements
 * of `collection` from right to left.
 *
 * @static
 * @memberOf _
 * @since 2.0.0
 * @category Array
 * @param {Array} array The array to inspect.
 * @param {Function} [predicate=_.identity]
 *  The function invoked per iteration.
 * @param {number} [fromIndex=array.length-1] The index to search from.
 * @returns {number} Returns the index of the found element, else `-1`.
 * @example
 *
 * var users = [
 *   { 'user': 'barney',  'active': true },
 *   { 'user': 'fred',    'active': false },
 *   { 'user': 'pebbles', 'active': false }
 * ];
 *
 * _.findLastIndex(users, function(o) { return o.user == 'pebbles'; });
 * // => 2
 *
 * // The `_.matches` iteratee shorthand.
 * _.findLastIndex(users, { 'user': 'barney', 'active': true });
 * // => 0
 *
 * // The `_.matchesProperty` iteratee shorthand.
 * _.findLastIndex(users, ['active', false]);
 * // => 2
 *
 * // The `_.property` iteratee shorthand.
 * _.findLastIndex(users, 'active');
 * // => 0
 */
function findLastIndex(array, predicate, fromIndex) {
  var length = array ? array.length : 0;
  if (!length) {
    return -1;
  }
  var index = length - 1;
  if (fromIndex !== undefined) {
    index = toInteger(fromIndex);
    index = fromIndex < 0
      ? nativeMax(length + index, 0)
      : nativeMin(index, length - 1);
  }
  return baseFindIndex(array, baseIteratee(predicate, 3), index, true);
}

/**
 * This method is like `_.find` except that it iterates over elements of
 * `collection` from right to left.
 *
 * @static
 * @memberOf _
 * @since 2.0.0
 * @category Collection
 * @param {Array|Object} collection The collection to inspect.
 * @param {Function} [predicate=_.identity]
 *  The function invoked per iteration.
 * @param {number} [fromIndex=collection.length-1] The index to search from.
 * @returns {*} Returns the matched element, else `undefined`.
 * @example
 *
 * _.findLast([1, 2, 3, 4], function(n) {
 *   return n % 2 == 1;
 * });
 * // => 3
 */
var findLast = createFind(findLastIndex);

/**
 * Creates a function that memoizes the result of `func`. If `resolver` is
 * provided, it determines the cache key for storing the result based on the
 * arguments provided to the memoized function. By default, the first argument
 * provided to the memoized function is used as the map cache key. The `func`
 * is invoked with the `this` binding of the memoized function.
 *
 * **Note:** The cache is exposed as the `cache` property on the memoized
 * function. Its creation may be customized by replacing the `_.memoize.Cache`
 * constructor with one whose instances implement the
 * [`Map`](http://ecma-international.org/ecma-262/7.0/#sec-properties-of-the-map-prototype-object)
 * method interface of `delete`, `get`, `has`, and `set`.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Function
 * @param {Function} func The function to have its output memoized.
 * @param {Function} [resolver] The function to resolve the cache key.
 * @returns {Function} Returns the new memoized function.
 * @example
 *
 * var object = { 'a': 1, 'b': 2 };
 * var other = { 'c': 3, 'd': 4 };
 *
 * var values = _.memoize(_.values);
 * values(object);
 * // => [1, 2]
 *
 * values(other);
 * // => [3, 4]
 *
 * object.a = 2;
 * values(object);
 * // => [1, 2]
 *
 * // Modify the result cache.
 * values.cache.set(object, ['a', 'b']);
 * values(object);
 * // => ['a', 'b']
 *
 * // Replace `_.memoize.Cache`.
 * _.memoize.Cache = WeakMap;
 */
function memoize(func, resolver) {
  if (typeof func != 'function' || (resolver && typeof resolver != 'function')) {
    throw new TypeError(FUNC_ERROR_TEXT);
  }
  var memoized = function() {
    var args = arguments,
        key = resolver ? resolver.apply(this, args) : args[0],
        cache = memoized.cache;

    if (cache.has(key)) {
      return cache.get(key);
    }
    var result = func.apply(this, args);
    memoized.cache = cache.set(key, result);
    return result;
  };
  memoized.cache = new (memoize.Cache || MapCache);
  return memoized;
}

// Assign cache to `_.memoize`.
memoize.Cache = MapCache;

/**
 * Performs a
 * [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
 * comparison between two values to determine if they are equivalent.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to compare.
 * @param {*} other The other value to compare.
 * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
 * @example
 *
 * var object = { 'a': 1 };
 * var other = { 'a': 1 };
 *
 * _.eq(object, object);
 * // => true
 *
 * _.eq(object, other);
 * // => false
 *
 * _.eq('a', 'a');
 * // => true
 *
 * _.eq('a', Object('a'));
 * // => false
 *
 * _.eq(NaN, NaN);
 * // => true
 */
function eq(value, other) {
  return value === other || (value !== value && other !== other);
}

/**
 * Checks if `value` is likely an `arguments` object.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an `arguments` object,
 *  else `false`.
 * @example
 *
 * _.isArguments(function() { return arguments; }());
 * // => true
 *
 * _.isArguments([1, 2, 3]);
 * // => false
 */
function isArguments(value) {
  // Safari 8.1 makes `arguments.callee` enumerable in strict mode.
  return isArrayLikeObject(value) && hasOwnProperty.call(value, 'callee') &&
    (!propertyIsEnumerable.call(value, 'callee') || objectToString.call(value) == argsTag);
}

/**
 * Checks if `value` is classified as an `Array` object.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an array, else `false`.
 * @example
 *
 * _.isArray([1, 2, 3]);
 * // => true
 *
 * _.isArray(document.body.children);
 * // => false
 *
 * _.isArray('abc');
 * // => false
 *
 * _.isArray(_.noop);
 * // => false
 */
var isArray = Array.isArray;

/**
 * Checks if `value` is array-like. A value is considered array-like if it's
 * not a function and has a `value.length` that's an integer greater than or
 * equal to `0` and less than or equal to `Number.MAX_SAFE_INTEGER`.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is array-like, else `false`.
 * @example
 *
 * _.isArrayLike([1, 2, 3]);
 * // => true
 *
 * _.isArrayLike(document.body.children);
 * // => true
 *
 * _.isArrayLike('abc');
 * // => true
 *
 * _.isArrayLike(_.noop);
 * // => false
 */
function isArrayLike(value) {
  return value != null && isLength(value.length) && !isFunction(value);
}

/**
 * This method is like `_.isArrayLike` except that it also checks if `value`
 * is an object.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an array-like object,
 *  else `false`.
 * @example
 *
 * _.isArrayLikeObject([1, 2, 3]);
 * // => true
 *
 * _.isArrayLikeObject(document.body.children);
 * // => true
 *
 * _.isArrayLikeObject('abc');
 * // => false
 *
 * _.isArrayLikeObject(_.noop);
 * // => false
 */
function isArrayLikeObject(value) {
  return isObjectLike(value) && isArrayLike(value);
}

/**
 * Checks if `value` is classified as a `Function` object.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a function, else `false`.
 * @example
 *
 * _.isFunction(_);
 * // => true
 *
 * _.isFunction(/abc/);
 * // => false
 */
function isFunction(value) {
  // The use of `Object#toString` avoids issues with the `typeof` operator
  // in Safari 8-9 which returns 'object' for typed array and other constructors.
  var tag = isObject(value) ? objectToString.call(value) : '';
  return tag == funcTag || tag == genTag;
}

/**
 * Checks if `value` is a valid array-like length.
 *
 * **Note:** This method is loosely based on
 * [`ToLength`](http://ecma-international.org/ecma-262/7.0/#sec-tolength).
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a valid length, else `false`.
 * @example
 *
 * _.isLength(3);
 * // => true
 *
 * _.isLength(Number.MIN_VALUE);
 * // => false
 *
 * _.isLength(Infinity);
 * // => false
 *
 * _.isLength('3');
 * // => false
 */
function isLength(value) {
  return typeof value == 'number' &&
    value > -1 && value % 1 == 0 && value <= MAX_SAFE_INTEGER;
}

/**
 * Checks if `value` is the
 * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)
 * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an object, else `false`.
 * @example
 *
 * _.isObject({});
 * // => true
 *
 * _.isObject([1, 2, 3]);
 * // => true
 *
 * _.isObject(_.noop);
 * // => true
 *
 * _.isObject(null);
 * // => false
 */
function isObject(value) {
  var type = typeof value;
  return !!value && (type == 'object' || type == 'function');
}

/**
 * Checks if `value` is object-like. A value is object-like if it's not `null`
 * and has a `typeof` result of "object".
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
 * @example
 *
 * _.isObjectLike({});
 * // => true
 *
 * _.isObjectLike([1, 2, 3]);
 * // => true
 *
 * _.isObjectLike(_.noop);
 * // => false
 *
 * _.isObjectLike(null);
 * // => false
 */
function isObjectLike(value) {
  return !!value && typeof value == 'object';
}

/**
 * Checks if `value` is classified as a `Symbol` primitive or object.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a symbol, else `false`.
 * @example
 *
 * _.isSymbol(Symbol.iterator);
 * // => true
 *
 * _.isSymbol('abc');
 * // => false
 */
function isSymbol(value) {
  return typeof value == 'symbol' ||
    (isObjectLike(value) && objectToString.call(value) == symbolTag);
}

/**
 * Checks if `value` is classified as a typed array.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
 * @example
 *
 * _.isTypedArray(new Uint8Array);
 * // => true
 *
 * _.isTypedArray([]);
 * // => false
 */
var isTypedArray = nodeIsTypedArray ? baseUnary(nodeIsTypedArray) : baseIsTypedArray;

/**
 * Converts `value` to a finite number.
 *
 * @static
 * @memberOf _
 * @since 4.12.0
 * @category Lang
 * @param {*} value The value to convert.
 * @returns {number} Returns the converted number.
 * @example
 *
 * _.toFinite(3.2);
 * // => 3.2
 *
 * _.toFinite(Number.MIN_VALUE);
 * // => 5e-324
 *
 * _.toFinite(Infinity);
 * // => 1.7976931348623157e+308
 *
 * _.toFinite('3.2');
 * // => 3.2
 */
function toFinite(value) {
  if (!value) {
    return value === 0 ? value : 0;
  }
  value = toNumber(value);
  if (value === INFINITY || value === -INFINITY) {
    var sign = (value < 0 ? -1 : 1);
    return sign * MAX_INTEGER;
  }
  return value === value ? value : 0;
}

/**
 * Converts `value` to an integer.
 *
 * **Note:** This method is loosely based on
 * [`ToInteger`](http://www.ecma-international.org/ecma-262/7.0/#sec-tointeger).
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to convert.
 * @returns {number} Returns the converted integer.
 * @example
 *
 * _.toInteger(3.2);
 * // => 3
 *
 * _.toInteger(Number.MIN_VALUE);
 * // => 0
 *
 * _.toInteger(Infinity);
 * // => 1.7976931348623157e+308
 *
 * _.toInteger('3.2');
 * // => 3
 */
function toInteger(value) {
  var result = toFinite(value),
      remainder = result % 1;

  return result === result ? (remainder ? result - remainder : result) : 0;
}

/**
 * Converts `value` to a number.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to process.
 * @returns {number} Returns the number.
 * @example
 *
 * _.toNumber(3.2);
 * // => 3.2
 *
 * _.toNumber(Number.MIN_VALUE);
 * // => 5e-324
 *
 * _.toNumber(Infinity);
 * // => Infinity
 *
 * _.toNumber('3.2');
 * // => 3.2
 */
function toNumber(value) {
  if (typeof value == 'number') {
    return value;
  }
  if (isSymbol(value)) {
    return NAN;
  }
  if (isObject(value)) {
    var other = typeof value.valueOf == 'function' ? value.valueOf() : value;
    value = isObject(other) ? (other + '') : other;
  }
  if (typeof value != 'string') {
    return value === 0 ? value : +value;
  }
  value = value.replace(reTrim, '');
  var isBinary = reIsBinary.test(value);
  return (isBinary || reIsOctal.test(value))
    ? freeParseInt(value.slice(2), isBinary ? 2 : 8)
    : (reIsBadHex.test(value) ? NAN : +value);
}

/**
 * Converts `value` to a string. An empty string is returned for `null`
 * and `undefined` values. The sign of `-0` is preserved.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to process.
 * @returns {string} Returns the string.
 * @example
 *
 * _.toString(null);
 * // => ''
 *
 * _.toString(-0);
 * // => '-0'
 *
 * _.toString([1, 2, 3]);
 * // => '1,2,3'
 */
function toString(value) {
  return value == null ? '' : baseToString(value);
}

/**
 * Gets the value at `path` of `object`. If the resolved value is
 * `undefined`, the `defaultValue` is returned in its place.
 *
 * @static
 * @memberOf _
 * @since 3.7.0
 * @category Object
 * @param {Object} object The object to query.
 * @param {Array|string} path The path of the property to get.
 * @param {*} [defaultValue] The value returned for `undefined` resolved values.
 * @returns {*} Returns the resolved value.
 * @example
 *
 * var object = { 'a': [{ 'b': { 'c': 3 } }] };
 *
 * _.get(object, 'a[0].b.c');
 * // => 3
 *
 * _.get(object, ['a', '0', 'b', 'c']);
 * // => 3
 *
 * _.get(object, 'a.b.c', 'default');
 * // => 'default'
 */
function get(object, path, defaultValue) {
  var result = object == null ? undefined : baseGet(object, path);
  return result === undefined ? defaultValue : result;
}

/**
 * Checks if `path` is a direct or inherited property of `object`.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Object
 * @param {Object} object The object to query.
 * @param {Array|string} path The path to check.
 * @returns {boolean} Returns `true` if `path` exists, else `false`.
 * @example
 *
 * var object = _.create({ 'a': _.create({ 'b': 2 }) });
 *
 * _.hasIn(object, 'a');
 * // => true
 *
 * _.hasIn(object, 'a.b');
 * // => true
 *
 * _.hasIn(object, ['a', 'b']);
 * // => true
 *
 * _.hasIn(object, 'b');
 * // => false
 */
function hasIn(object, path) {
  return object != null && hasPath(object, path, baseHasIn);
}

/**
 * Creates an array of the own enumerable property names of `object`.
 *
 * **Note:** Non-object values are coerced to objects. See the
 * [ES spec](http://ecma-international.org/ecma-262/7.0/#sec-object.keys)
 * for more details.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Object
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names.
 * @example
 *
 * function Foo() {
 *   this.a = 1;
 *   this.b = 2;
 * }
 *
 * Foo.prototype.c = 3;
 *
 * _.keys(new Foo);
 * // => ['a', 'b'] (iteration order is not guaranteed)
 *
 * _.keys('hi');
 * // => ['0', '1']
 */
function keys(object) {
  return isArrayLike(object) ? arrayLikeKeys(object) : baseKeys(object);
}

/**
 * This method returns the first argument it receives.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Util
 * @param {*} value Any value.
 * @returns {*} Returns `value`.
 * @example
 *
 * var object = { 'a': 1 };
 *
 * console.log(_.identity(object) === object);
 * // => true
 */
function identity(value) {
  return value;
}

/**
 * Creates a function that returns the value at `path` of a given object.
 *
 * @static
 * @memberOf _
 * @since 2.4.0
 * @category Util
 * @param {Array|string} path The path of the property to get.
 * @returns {Function} Returns the new accessor function.
 * @example
 *
 * var objects = [
 *   { 'a': { 'b': 2 } },
 *   { 'a': { 'b': 1 } }
 * ];
 *
 * _.map(objects, _.property('a.b'));
 * // => [2, 1]
 *
 * _.map(_.sortBy(objects, _.property(['a', 'b'])), 'a.b');
 * // => [1, 2]
 */
function property(path) {
  return isKey(path) ? baseProperty(toKey(path)) : basePropertyDeep(path);
}

module.exports = findLast;


/***/ }),

/***/ "../../node_modules/lodash.isequal/index.js":
/*!**************************************************!*\
  !*** ../../node_modules/lodash.isequal/index.js ***!
  \**************************************************/
/***/ ((module, exports, __webpack_require__) => {

/* module decorator */ module = __webpack_require__.nmd(module);
/**
 * Lodash (Custom Build) <https://lodash.com/>
 * Build: `lodash modularize exports="npm" -o ./`
 * Copyright JS Foundation and other contributors <https://js.foundation/>
 * Released under MIT license <https://lodash.com/license>
 * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
 * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
 */

/** Used as the size to enable large array optimizations. */
var LARGE_ARRAY_SIZE = 200;

/** Used to stand-in for `undefined` hash values. */
var HASH_UNDEFINED = '__lodash_hash_undefined__';

/** Used to compose bitmasks for value comparisons. */
var COMPARE_PARTIAL_FLAG = 1,
    COMPARE_UNORDERED_FLAG = 2;

/** Used as references for various `Number` constants. */
var MAX_SAFE_INTEGER = 9007199254740991;

/** `Object#toString` result references. */
var argsTag = '[object Arguments]',
    arrayTag = '[object Array]',
    asyncTag = '[object AsyncFunction]',
    boolTag = '[object Boolean]',
    dateTag = '[object Date]',
    errorTag = '[object Error]',
    funcTag = '[object Function]',
    genTag = '[object GeneratorFunction]',
    mapTag = '[object Map]',
    numberTag = '[object Number]',
    nullTag = '[object Null]',
    objectTag = '[object Object]',
    promiseTag = '[object Promise]',
    proxyTag = '[object Proxy]',
    regexpTag = '[object RegExp]',
    setTag = '[object Set]',
    stringTag = '[object String]',
    symbolTag = '[object Symbol]',
    undefinedTag = '[object Undefined]',
    weakMapTag = '[object WeakMap]';

var arrayBufferTag = '[object ArrayBuffer]',
    dataViewTag = '[object DataView]',
    float32Tag = '[object Float32Array]',
    float64Tag = '[object Float64Array]',
    int8Tag = '[object Int8Array]',
    int16Tag = '[object Int16Array]',
    int32Tag = '[object Int32Array]',
    uint8Tag = '[object Uint8Array]',
    uint8ClampedTag = '[object Uint8ClampedArray]',
    uint16Tag = '[object Uint16Array]',
    uint32Tag = '[object Uint32Array]';

/**
 * Used to match `RegExp`
 * [syntax characters](http://ecma-international.org/ecma-262/7.0/#sec-patterns).
 */
var reRegExpChar = /[\\^$.*+?()[\]{}|]/g;

/** Used to detect host constructors (Safari). */
var reIsHostCtor = /^\[object .+?Constructor\]$/;

/** Used to detect unsigned integer values. */
var reIsUint = /^(?:0|[1-9]\d*)$/;

/** Used to identify `toStringTag` values of typed arrays. */
var typedArrayTags = {};
typedArrayTags[float32Tag] = typedArrayTags[float64Tag] =
typedArrayTags[int8Tag] = typedArrayTags[int16Tag] =
typedArrayTags[int32Tag] = typedArrayTags[uint8Tag] =
typedArrayTags[uint8ClampedTag] = typedArrayTags[uint16Tag] =
typedArrayTags[uint32Tag] = true;
typedArrayTags[argsTag] = typedArrayTags[arrayTag] =
typedArrayTags[arrayBufferTag] = typedArrayTags[boolTag] =
typedArrayTags[dataViewTag] = typedArrayTags[dateTag] =
typedArrayTags[errorTag] = typedArrayTags[funcTag] =
typedArrayTags[mapTag] = typedArrayTags[numberTag] =
typedArrayTags[objectTag] = typedArrayTags[regexpTag] =
typedArrayTags[setTag] = typedArrayTags[stringTag] =
typedArrayTags[weakMapTag] = false;

/** Detect free variable `global` from Node.js. */
var freeGlobal = typeof __webpack_require__.g == 'object' && __webpack_require__.g && __webpack_require__.g.Object === Object && __webpack_require__.g;

/** Detect free variable `self`. */
var freeSelf = typeof self == 'object' && self && self.Object === Object && self;

/** Used as a reference to the global object. */
var root = freeGlobal || freeSelf || Function('return this')();

/** Detect free variable `exports`. */
var freeExports =  true && exports && !exports.nodeType && exports;

/** Detect free variable `module`. */
var freeModule = freeExports && "object" == 'object' && module && !module.nodeType && module;

/** Detect the popular CommonJS extension `module.exports`. */
var moduleExports = freeModule && freeModule.exports === freeExports;

/** Detect free variable `process` from Node.js. */
var freeProcess = moduleExports && freeGlobal.process;

/** Used to access faster Node.js helpers. */
var nodeUtil = (function() {
  try {
    return freeProcess && freeProcess.binding && freeProcess.binding('util');
  } catch (e) {}
}());

/* Node.js helper references. */
var nodeIsTypedArray = nodeUtil && nodeUtil.isTypedArray;

/**
 * A specialized version of `_.filter` for arrays without support for
 * iteratee shorthands.
 *
 * @private
 * @param {Array} [array] The array to iterate over.
 * @param {Function} predicate The function invoked per iteration.
 * @returns {Array} Returns the new filtered array.
 */
function arrayFilter(array, predicate) {
  var index = -1,
      length = array == null ? 0 : array.length,
      resIndex = 0,
      result = [];

  while (++index < length) {
    var value = array[index];
    if (predicate(value, index, array)) {
      result[resIndex++] = value;
    }
  }
  return result;
}

/**
 * Appends the elements of `values` to `array`.
 *
 * @private
 * @param {Array} array The array to modify.
 * @param {Array} values The values to append.
 * @returns {Array} Returns `array`.
 */
function arrayPush(array, values) {
  var index = -1,
      length = values.length,
      offset = array.length;

  while (++index < length) {
    array[offset + index] = values[index];
  }
  return array;
}

/**
 * A specialized version of `_.some` for arrays without support for iteratee
 * shorthands.
 *
 * @private
 * @param {Array} [array] The array to iterate over.
 * @param {Function} predicate The function invoked per iteration.
 * @returns {boolean} Returns `true` if any element passes the predicate check,
 *  else `false`.
 */
function arraySome(array, predicate) {
  var index = -1,
      length = array == null ? 0 : array.length;

  while (++index < length) {
    if (predicate(array[index], index, array)) {
      return true;
    }
  }
  return false;
}

/**
 * The base implementation of `_.times` without support for iteratee shorthands
 * or max array length checks.
 *
 * @private
 * @param {number} n The number of times to invoke `iteratee`.
 * @param {Function} iteratee The function invoked per iteration.
 * @returns {Array} Returns the array of results.
 */
function baseTimes(n, iteratee) {
  var index = -1,
      result = Array(n);

  while (++index < n) {
    result[index] = iteratee(index);
  }
  return result;
}

/**
 * The base implementation of `_.unary` without support for storing metadata.
 *
 * @private
 * @param {Function} func The function to cap arguments for.
 * @returns {Function} Returns the new capped function.
 */
function baseUnary(func) {
  return function(value) {
    return func(value);
  };
}

/**
 * Checks if a `cache` value for `key` exists.
 *
 * @private
 * @param {Object} cache The cache to query.
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function cacheHas(cache, key) {
  return cache.has(key);
}

/**
 * Gets the value at `key` of `object`.
 *
 * @private
 * @param {Object} [object] The object to query.
 * @param {string} key The key of the property to get.
 * @returns {*} Returns the property value.
 */
function getValue(object, key) {
  return object == null ? undefined : object[key];
}

/**
 * Converts `map` to its key-value pairs.
 *
 * @private
 * @param {Object} map The map to convert.
 * @returns {Array} Returns the key-value pairs.
 */
function mapToArray(map) {
  var index = -1,
      result = Array(map.size);

  map.forEach(function(value, key) {
    result[++index] = [key, value];
  });
  return result;
}

/**
 * Creates a unary function that invokes `func` with its argument transformed.
 *
 * @private
 * @param {Function} func The function to wrap.
 * @param {Function} transform The argument transform.
 * @returns {Function} Returns the new function.
 */
function overArg(func, transform) {
  return function(arg) {
    return func(transform(arg));
  };
}

/**
 * Converts `set` to an array of its values.
 *
 * @private
 * @param {Object} set The set to convert.
 * @returns {Array} Returns the values.
 */
function setToArray(set) {
  var index = -1,
      result = Array(set.size);

  set.forEach(function(value) {
    result[++index] = value;
  });
  return result;
}

/** Used for built-in method references. */
var arrayProto = Array.prototype,
    funcProto = Function.prototype,
    objectProto = Object.prototype;

/** Used to detect overreaching core-js shims. */
var coreJsData = root['__core-js_shared__'];

/** Used to resolve the decompiled source of functions. */
var funcToString = funcProto.toString;

/** Used to check objects for own properties. */
var hasOwnProperty = objectProto.hasOwnProperty;

/** Used to detect methods masquerading as native. */
var maskSrcKey = (function() {
  var uid = /[^.]+$/.exec(coreJsData && coreJsData.keys && coreJsData.keys.IE_PROTO || '');
  return uid ? ('Symbol(src)_1.' + uid) : '';
}());

/**
 * Used to resolve the
 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
 * of values.
 */
var nativeObjectToString = objectProto.toString;

/** Used to detect if a method is native. */
var reIsNative = RegExp('^' +
  funcToString.call(hasOwnProperty).replace(reRegExpChar, '\\$&')
  .replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, '$1.*?') + '$'
);

/** Built-in value references. */
var Buffer = moduleExports ? root.Buffer : undefined,
    Symbol = root.Symbol,
    Uint8Array = root.Uint8Array,
    propertyIsEnumerable = objectProto.propertyIsEnumerable,
    splice = arrayProto.splice,
    symToStringTag = Symbol ? Symbol.toStringTag : undefined;

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeGetSymbols = Object.getOwnPropertySymbols,
    nativeIsBuffer = Buffer ? Buffer.isBuffer : undefined,
    nativeKeys = overArg(Object.keys, Object);

/* Built-in method references that are verified to be native. */
var DataView = getNative(root, 'DataView'),
    Map = getNative(root, 'Map'),
    Promise = getNative(root, 'Promise'),
    Set = getNative(root, 'Set'),
    WeakMap = getNative(root, 'WeakMap'),
    nativeCreate = getNative(Object, 'create');

/** Used to detect maps, sets, and weakmaps. */
var dataViewCtorString = toSource(DataView),
    mapCtorString = toSource(Map),
    promiseCtorString = toSource(Promise),
    setCtorString = toSource(Set),
    weakMapCtorString = toSource(WeakMap);

/** Used to convert symbols to primitives and strings. */
var symbolProto = Symbol ? Symbol.prototype : undefined,
    symbolValueOf = symbolProto ? symbolProto.valueOf : undefined;

/**
 * Creates a hash object.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function Hash(entries) {
  var index = -1,
      length = entries == null ? 0 : entries.length;

  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}

/**
 * Removes all key-value entries from the hash.
 *
 * @private
 * @name clear
 * @memberOf Hash
 */
function hashClear() {
  this.__data__ = nativeCreate ? nativeCreate(null) : {};
  this.size = 0;
}

/**
 * Removes `key` and its value from the hash.
 *
 * @private
 * @name delete
 * @memberOf Hash
 * @param {Object} hash The hash to modify.
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function hashDelete(key) {
  var result = this.has(key) && delete this.__data__[key];
  this.size -= result ? 1 : 0;
  return result;
}

/**
 * Gets the hash value for `key`.
 *
 * @private
 * @name get
 * @memberOf Hash
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function hashGet(key) {
  var data = this.__data__;
  if (nativeCreate) {
    var result = data[key];
    return result === HASH_UNDEFINED ? undefined : result;
  }
  return hasOwnProperty.call(data, key) ? data[key] : undefined;
}

/**
 * Checks if a hash value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf Hash
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function hashHas(key) {
  var data = this.__data__;
  return nativeCreate ? (data[key] !== undefined) : hasOwnProperty.call(data, key);
}

/**
 * Sets the hash `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf Hash
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the hash instance.
 */
function hashSet(key, value) {
  var data = this.__data__;
  this.size += this.has(key) ? 0 : 1;
  data[key] = (nativeCreate && value === undefined) ? HASH_UNDEFINED : value;
  return this;
}

// Add methods to `Hash`.
Hash.prototype.clear = hashClear;
Hash.prototype['delete'] = hashDelete;
Hash.prototype.get = hashGet;
Hash.prototype.has = hashHas;
Hash.prototype.set = hashSet;

/**
 * Creates an list cache object.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function ListCache(entries) {
  var index = -1,
      length = entries == null ? 0 : entries.length;

  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}

/**
 * Removes all key-value entries from the list cache.
 *
 * @private
 * @name clear
 * @memberOf ListCache
 */
function listCacheClear() {
  this.__data__ = [];
  this.size = 0;
}

/**
 * Removes `key` and its value from the list cache.
 *
 * @private
 * @name delete
 * @memberOf ListCache
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function listCacheDelete(key) {
  var data = this.__data__,
      index = assocIndexOf(data, key);

  if (index < 0) {
    return false;
  }
  var lastIndex = data.length - 1;
  if (index == lastIndex) {
    data.pop();
  } else {
    splice.call(data, index, 1);
  }
  --this.size;
  return true;
}

/**
 * Gets the list cache value for `key`.
 *
 * @private
 * @name get
 * @memberOf ListCache
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function listCacheGet(key) {
  var data = this.__data__,
      index = assocIndexOf(data, key);

  return index < 0 ? undefined : data[index][1];
}

/**
 * Checks if a list cache value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf ListCache
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function listCacheHas(key) {
  return assocIndexOf(this.__data__, key) > -1;
}

/**
 * Sets the list cache `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf ListCache
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the list cache instance.
 */
function listCacheSet(key, value) {
  var data = this.__data__,
      index = assocIndexOf(data, key);

  if (index < 0) {
    ++this.size;
    data.push([key, value]);
  } else {
    data[index][1] = value;
  }
  return this;
}

// Add methods to `ListCache`.
ListCache.prototype.clear = listCacheClear;
ListCache.prototype['delete'] = listCacheDelete;
ListCache.prototype.get = listCacheGet;
ListCache.prototype.has = listCacheHas;
ListCache.prototype.set = listCacheSet;

/**
 * Creates a map cache object to store key-value pairs.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function MapCache(entries) {
  var index = -1,
      length = entries == null ? 0 : entries.length;

  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}

/**
 * Removes all key-value entries from the map.
 *
 * @private
 * @name clear
 * @memberOf MapCache
 */
function mapCacheClear() {
  this.size = 0;
  this.__data__ = {
    'hash': new Hash,
    'map': new (Map || ListCache),
    'string': new Hash
  };
}

/**
 * Removes `key` and its value from the map.
 *
 * @private
 * @name delete
 * @memberOf MapCache
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function mapCacheDelete(key) {
  var result = getMapData(this, key)['delete'](key);
  this.size -= result ? 1 : 0;
  return result;
}

/**
 * Gets the map value for `key`.
 *
 * @private
 * @name get
 * @memberOf MapCache
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function mapCacheGet(key) {
  return getMapData(this, key).get(key);
}

/**
 * Checks if a map value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf MapCache
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function mapCacheHas(key) {
  return getMapData(this, key).has(key);
}

/**
 * Sets the map `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf MapCache
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the map cache instance.
 */
function mapCacheSet(key, value) {
  var data = getMapData(this, key),
      size = data.size;

  data.set(key, value);
  this.size += data.size == size ? 0 : 1;
  return this;
}

// Add methods to `MapCache`.
MapCache.prototype.clear = mapCacheClear;
MapCache.prototype['delete'] = mapCacheDelete;
MapCache.prototype.get = mapCacheGet;
MapCache.prototype.has = mapCacheHas;
MapCache.prototype.set = mapCacheSet;

/**
 *
 * Creates an array cache object to store unique values.
 *
 * @private
 * @constructor
 * @param {Array} [values] The values to cache.
 */
function SetCache(values) {
  var index = -1,
      length = values == null ? 0 : values.length;

  this.__data__ = new MapCache;
  while (++index < length) {
    this.add(values[index]);
  }
}

/**
 * Adds `value` to the array cache.
 *
 * @private
 * @name add
 * @memberOf SetCache
 * @alias push
 * @param {*} value The value to cache.
 * @returns {Object} Returns the cache instance.
 */
function setCacheAdd(value) {
  this.__data__.set(value, HASH_UNDEFINED);
  return this;
}

/**
 * Checks if `value` is in the array cache.
 *
 * @private
 * @name has
 * @memberOf SetCache
 * @param {*} value The value to search for.
 * @returns {number} Returns `true` if `value` is found, else `false`.
 */
function setCacheHas(value) {
  return this.__data__.has(value);
}

// Add methods to `SetCache`.
SetCache.prototype.add = SetCache.prototype.push = setCacheAdd;
SetCache.prototype.has = setCacheHas;

/**
 * Creates a stack cache object to store key-value pairs.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function Stack(entries) {
  var data = this.__data__ = new ListCache(entries);
  this.size = data.size;
}

/**
 * Removes all key-value entries from the stack.
 *
 * @private
 * @name clear
 * @memberOf Stack
 */
function stackClear() {
  this.__data__ = new ListCache;
  this.size = 0;
}

/**
 * Removes `key` and its value from the stack.
 *
 * @private
 * @name delete
 * @memberOf Stack
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function stackDelete(key) {
  var data = this.__data__,
      result = data['delete'](key);

  this.size = data.size;
  return result;
}

/**
 * Gets the stack value for `key`.
 *
 * @private
 * @name get
 * @memberOf Stack
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function stackGet(key) {
  return this.__data__.get(key);
}

/**
 * Checks if a stack value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf Stack
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function stackHas(key) {
  return this.__data__.has(key);
}

/**
 * Sets the stack `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf Stack
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the stack cache instance.
 */
function stackSet(key, value) {
  var data = this.__data__;
  if (data instanceof ListCache) {
    var pairs = data.__data__;
    if (!Map || (pairs.length < LARGE_ARRAY_SIZE - 1)) {
      pairs.push([key, value]);
      this.size = ++data.size;
      return this;
    }
    data = this.__data__ = new MapCache(pairs);
  }
  data.set(key, value);
  this.size = data.size;
  return this;
}

// Add methods to `Stack`.
Stack.prototype.clear = stackClear;
Stack.prototype['delete'] = stackDelete;
Stack.prototype.get = stackGet;
Stack.prototype.has = stackHas;
Stack.prototype.set = stackSet;

/**
 * Creates an array of the enumerable property names of the array-like `value`.
 *
 * @private
 * @param {*} value The value to query.
 * @param {boolean} inherited Specify returning inherited property names.
 * @returns {Array} Returns the array of property names.
 */
function arrayLikeKeys(value, inherited) {
  var isArr = isArray(value),
      isArg = !isArr && isArguments(value),
      isBuff = !isArr && !isArg && isBuffer(value),
      isType = !isArr && !isArg && !isBuff && isTypedArray(value),
      skipIndexes = isArr || isArg || isBuff || isType,
      result = skipIndexes ? baseTimes(value.length, String) : [],
      length = result.length;

  for (var key in value) {
    if ((inherited || hasOwnProperty.call(value, key)) &&
        !(skipIndexes && (
           // Safari 9 has enumerable `arguments.length` in strict mode.
           key == 'length' ||
           // Node.js 0.10 has enumerable non-index properties on buffers.
           (isBuff && (key == 'offset' || key == 'parent')) ||
           // PhantomJS 2 has enumerable non-index properties on typed arrays.
           (isType && (key == 'buffer' || key == 'byteLength' || key == 'byteOffset')) ||
           // Skip index properties.
           isIndex(key, length)
        ))) {
      result.push(key);
    }
  }
  return result;
}

/**
 * Gets the index at which the `key` is found in `array` of key-value pairs.
 *
 * @private
 * @param {Array} array The array to inspect.
 * @param {*} key The key to search for.
 * @returns {number} Returns the index of the matched value, else `-1`.
 */
function assocIndexOf(array, key) {
  var length = array.length;
  while (length--) {
    if (eq(array[length][0], key)) {
      return length;
    }
  }
  return -1;
}

/**
 * The base implementation of `getAllKeys` and `getAllKeysIn` which uses
 * `keysFunc` and `symbolsFunc` to get the enumerable property names and
 * symbols of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {Function} keysFunc The function to get the keys of `object`.
 * @param {Function} symbolsFunc The function to get the symbols of `object`.
 * @returns {Array} Returns the array of property names and symbols.
 */
function baseGetAllKeys(object, keysFunc, symbolsFunc) {
  var result = keysFunc(object);
  return isArray(object) ? result : arrayPush(result, symbolsFunc(object));
}

/**
 * The base implementation of `getTag` without fallbacks for buggy environments.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the `toStringTag`.
 */
function baseGetTag(value) {
  if (value == null) {
    return value === undefined ? undefinedTag : nullTag;
  }
  return (symToStringTag && symToStringTag in Object(value))
    ? getRawTag(value)
    : objectToString(value);
}

/**
 * The base implementation of `_.isArguments`.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an `arguments` object,
 */
function baseIsArguments(value) {
  return isObjectLike(value) && baseGetTag(value) == argsTag;
}

/**
 * The base implementation of `_.isEqual` which supports partial comparisons
 * and tracks traversed objects.
 *
 * @private
 * @param {*} value The value to compare.
 * @param {*} other The other value to compare.
 * @param {boolean} bitmask The bitmask flags.
 *  1 - Unordered comparison
 *  2 - Partial comparison
 * @param {Function} [customizer] The function to customize comparisons.
 * @param {Object} [stack] Tracks traversed `value` and `other` objects.
 * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
 */
function baseIsEqual(value, other, bitmask, customizer, stack) {
  if (value === other) {
    return true;
  }
  if (value == null || other == null || (!isObjectLike(value) && !isObjectLike(other))) {
    return value !== value && other !== other;
  }
  return baseIsEqualDeep(value, other, bitmask, customizer, baseIsEqual, stack);
}

/**
 * A specialized version of `baseIsEqual` for arrays and objects which performs
 * deep comparisons and tracks traversed objects enabling objects with circular
 * references to be compared.
 *
 * @private
 * @param {Object} object The object to compare.
 * @param {Object} other The other object to compare.
 * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
 * @param {Function} customizer The function to customize comparisons.
 * @param {Function} equalFunc The function to determine equivalents of values.
 * @param {Object} [stack] Tracks traversed `object` and `other` objects.
 * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
 */
function baseIsEqualDeep(object, other, bitmask, customizer, equalFunc, stack) {
  var objIsArr = isArray(object),
      othIsArr = isArray(other),
      objTag = objIsArr ? arrayTag : getTag(object),
      othTag = othIsArr ? arrayTag : getTag(other);

  objTag = objTag == argsTag ? objectTag : objTag;
  othTag = othTag == argsTag ? objectTag : othTag;

  var objIsObj = objTag == objectTag,
      othIsObj = othTag == objectTag,
      isSameTag = objTag == othTag;

  if (isSameTag && isBuffer(object)) {
    if (!isBuffer(other)) {
      return false;
    }
    objIsArr = true;
    objIsObj = false;
  }
  if (isSameTag && !objIsObj) {
    stack || (stack = new Stack);
    return (objIsArr || isTypedArray(object))
      ? equalArrays(object, other, bitmask, customizer, equalFunc, stack)
      : equalByTag(object, other, objTag, bitmask, customizer, equalFunc, stack);
  }
  if (!(bitmask & COMPARE_PARTIAL_FLAG)) {
    var objIsWrapped = objIsObj && hasOwnProperty.call(object, '__wrapped__'),
        othIsWrapped = othIsObj && hasOwnProperty.call(other, '__wrapped__');

    if (objIsWrapped || othIsWrapped) {
      var objUnwrapped = objIsWrapped ? object.value() : object,
          othUnwrapped = othIsWrapped ? other.value() : other;

      stack || (stack = new Stack);
      return equalFunc(objUnwrapped, othUnwrapped, bitmask, customizer, stack);
    }
  }
  if (!isSameTag) {
    return false;
  }
  stack || (stack = new Stack);
  return equalObjects(object, other, bitmask, customizer, equalFunc, stack);
}

/**
 * The base implementation of `_.isNative` without bad shim checks.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a native function,
 *  else `false`.
 */
function baseIsNative(value) {
  if (!isObject(value) || isMasked(value)) {
    return false;
  }
  var pattern = isFunction(value) ? reIsNative : reIsHostCtor;
  return pattern.test(toSource(value));
}

/**
 * The base implementation of `_.isTypedArray` without Node.js optimizations.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
 */
function baseIsTypedArray(value) {
  return isObjectLike(value) &&
    isLength(value.length) && !!typedArrayTags[baseGetTag(value)];
}

/**
 * The base implementation of `_.keys` which doesn't treat sparse arrays as dense.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names.
 */
function baseKeys(object) {
  if (!isPrototype(object)) {
    return nativeKeys(object);
  }
  var result = [];
  for (var key in Object(object)) {
    if (hasOwnProperty.call(object, key) && key != 'constructor') {
      result.push(key);
    }
  }
  return result;
}

/**
 * A specialized version of `baseIsEqualDeep` for arrays with support for
 * partial deep comparisons.
 *
 * @private
 * @param {Array} array The array to compare.
 * @param {Array} other The other array to compare.
 * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
 * @param {Function} customizer The function to customize comparisons.
 * @param {Function} equalFunc The function to determine equivalents of values.
 * @param {Object} stack Tracks traversed `array` and `other` objects.
 * @returns {boolean} Returns `true` if the arrays are equivalent, else `false`.
 */
function equalArrays(array, other, bitmask, customizer, equalFunc, stack) {
  var isPartial = bitmask & COMPARE_PARTIAL_FLAG,
      arrLength = array.length,
      othLength = other.length;

  if (arrLength != othLength && !(isPartial && othLength > arrLength)) {
    return false;
  }
  // Assume cyclic values are equal.
  var stacked = stack.get(array);
  if (stacked && stack.get(other)) {
    return stacked == other;
  }
  var index = -1,
      result = true,
      seen = (bitmask & COMPARE_UNORDERED_FLAG) ? new SetCache : undefined;

  stack.set(array, other);
  stack.set(other, array);

  // Ignore non-index properties.
  while (++index < arrLength) {
    var arrValue = array[index],
        othValue = other[index];

    if (customizer) {
      var compared = isPartial
        ? customizer(othValue, arrValue, index, other, array, stack)
        : customizer(arrValue, othValue, index, array, other, stack);
    }
    if (compared !== undefined) {
      if (compared) {
        continue;
      }
      result = false;
      break;
    }
    // Recursively compare arrays (susceptible to call stack limits).
    if (seen) {
      if (!arraySome(other, function(othValue, othIndex) {
            if (!cacheHas(seen, othIndex) &&
                (arrValue === othValue || equalFunc(arrValue, othValue, bitmask, customizer, stack))) {
              return seen.push(othIndex);
            }
          })) {
        result = false;
        break;
      }
    } else if (!(
          arrValue === othValue ||
            equalFunc(arrValue, othValue, bitmask, customizer, stack)
        )) {
      result = false;
      break;
    }
  }
  stack['delete'](array);
  stack['delete'](other);
  return result;
}

/**
 * A specialized version of `baseIsEqualDeep` for comparing objects of
 * the same `toStringTag`.
 *
 * **Note:** This function only supports comparing values with tags of
 * `Boolean`, `Date`, `Error`, `Number`, `RegExp`, or `String`.
 *
 * @private
 * @param {Object} object The object to compare.
 * @param {Object} other The other object to compare.
 * @param {string} tag The `toStringTag` of the objects to compare.
 * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
 * @param {Function} customizer The function to customize comparisons.
 * @param {Function} equalFunc The function to determine equivalents of values.
 * @param {Object} stack Tracks traversed `object` and `other` objects.
 * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
 */
function equalByTag(object, other, tag, bitmask, customizer, equalFunc, stack) {
  switch (tag) {
    case dataViewTag:
      if ((object.byteLength != other.byteLength) ||
          (object.byteOffset != other.byteOffset)) {
        return false;
      }
      object = object.buffer;
      other = other.buffer;

    case arrayBufferTag:
      if ((object.byteLength != other.byteLength) ||
          !equalFunc(new Uint8Array(object), new Uint8Array(other))) {
        return false;
      }
      return true;

    case boolTag:
    case dateTag:
    case numberTag:
      // Coerce booleans to `1` or `0` and dates to milliseconds.
      // Invalid dates are coerced to `NaN`.
      return eq(+object, +other);

    case errorTag:
      return object.name == other.name && object.message == other.message;

    case regexpTag:
    case stringTag:
      // Coerce regexes to strings and treat strings, primitives and objects,
      // as equal. See http://www.ecma-international.org/ecma-262/7.0/#sec-regexp.prototype.tostring
      // for more details.
      return object == (other + '');

    case mapTag:
      var convert = mapToArray;

    case setTag:
      var isPartial = bitmask & COMPARE_PARTIAL_FLAG;
      convert || (convert = setToArray);

      if (object.size != other.size && !isPartial) {
        return false;
      }
      // Assume cyclic values are equal.
      var stacked = stack.get(object);
      if (stacked) {
        return stacked == other;
      }
      bitmask |= COMPARE_UNORDERED_FLAG;

      // Recursively compare objects (susceptible to call stack limits).
      stack.set(object, other);
      var result = equalArrays(convert(object), convert(other), bitmask, customizer, equalFunc, stack);
      stack['delete'](object);
      return result;

    case symbolTag:
      if (symbolValueOf) {
        return symbolValueOf.call(object) == symbolValueOf.call(other);
      }
  }
  return false;
}

/**
 * A specialized version of `baseIsEqualDeep` for objects with support for
 * partial deep comparisons.
 *
 * @private
 * @param {Object} object The object to compare.
 * @param {Object} other The other object to compare.
 * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
 * @param {Function} customizer The function to customize comparisons.
 * @param {Function} equalFunc The function to determine equivalents of values.
 * @param {Object} stack Tracks traversed `object` and `other` objects.
 * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
 */
function equalObjects(object, other, bitmask, customizer, equalFunc, stack) {
  var isPartial = bitmask & COMPARE_PARTIAL_FLAG,
      objProps = getAllKeys(object),
      objLength = objProps.length,
      othProps = getAllKeys(other),
      othLength = othProps.length;

  if (objLength != othLength && !isPartial) {
    return false;
  }
  var index = objLength;
  while (index--) {
    var key = objProps[index];
    if (!(isPartial ? key in other : hasOwnProperty.call(other, key))) {
      return false;
    }
  }
  // Assume cyclic values are equal.
  var stacked = stack.get(object);
  if (stacked && stack.get(other)) {
    return stacked == other;
  }
  var result = true;
  stack.set(object, other);
  stack.set(other, object);

  var skipCtor = isPartial;
  while (++index < objLength) {
    key = objProps[index];
    var objValue = object[key],
        othValue = other[key];

    if (customizer) {
      var compared = isPartial
        ? customizer(othValue, objValue, key, other, object, stack)
        : customizer(objValue, othValue, key, object, other, stack);
    }
    // Recursively compare objects (susceptible to call stack limits).
    if (!(compared === undefined
          ? (objValue === othValue || equalFunc(objValue, othValue, bitmask, customizer, stack))
          : compared
        )) {
      result = false;
      break;
    }
    skipCtor || (skipCtor = key == 'constructor');
  }
  if (result && !skipCtor) {
    var objCtor = object.constructor,
        othCtor = other.constructor;

    // Non `Object` object instances with different constructors are not equal.
    if (objCtor != othCtor &&
        ('constructor' in object && 'constructor' in other) &&
        !(typeof objCtor == 'function' && objCtor instanceof objCtor &&
          typeof othCtor == 'function' && othCtor instanceof othCtor)) {
      result = false;
    }
  }
  stack['delete'](object);
  stack['delete'](other);
  return result;
}

/**
 * Creates an array of own enumerable property names and symbols of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names and symbols.
 */
function getAllKeys(object) {
  return baseGetAllKeys(object, keys, getSymbols);
}

/**
 * Gets the data for `map`.
 *
 * @private
 * @param {Object} map The map to query.
 * @param {string} key The reference key.
 * @returns {*} Returns the map data.
 */
function getMapData(map, key) {
  var data = map.__data__;
  return isKeyable(key)
    ? data[typeof key == 'string' ? 'string' : 'hash']
    : data.map;
}

/**
 * Gets the native function at `key` of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {string} key The key of the method to get.
 * @returns {*} Returns the function if it's native, else `undefined`.
 */
function getNative(object, key) {
  var value = getValue(object, key);
  return baseIsNative(value) ? value : undefined;
}

/**
 * A specialized version of `baseGetTag` which ignores `Symbol.toStringTag` values.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the raw `toStringTag`.
 */
function getRawTag(value) {
  var isOwn = hasOwnProperty.call(value, symToStringTag),
      tag = value[symToStringTag];

  try {
    value[symToStringTag] = undefined;
    var unmasked = true;
  } catch (e) {}

  var result = nativeObjectToString.call(value);
  if (unmasked) {
    if (isOwn) {
      value[symToStringTag] = tag;
    } else {
      delete value[symToStringTag];
    }
  }
  return result;
}

/**
 * Creates an array of the own enumerable symbols of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of symbols.
 */
var getSymbols = !nativeGetSymbols ? stubArray : function(object) {
  if (object == null) {
    return [];
  }
  object = Object(object);
  return arrayFilter(nativeGetSymbols(object), function(symbol) {
    return propertyIsEnumerable.call(object, symbol);
  });
};

/**
 * Gets the `toStringTag` of `value`.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the `toStringTag`.
 */
var getTag = baseGetTag;

// Fallback for data views, maps, sets, and weak maps in IE 11 and promises in Node.js < 6.
if ((DataView && getTag(new DataView(new ArrayBuffer(1))) != dataViewTag) ||
    (Map && getTag(new Map) != mapTag) ||
    (Promise && getTag(Promise.resolve()) != promiseTag) ||
    (Set && getTag(new Set) != setTag) ||
    (WeakMap && getTag(new WeakMap) != weakMapTag)) {
  getTag = function(value) {
    var result = baseGetTag(value),
        Ctor = result == objectTag ? value.constructor : undefined,
        ctorString = Ctor ? toSource(Ctor) : '';

    if (ctorString) {
      switch (ctorString) {
        case dataViewCtorString: return dataViewTag;
        case mapCtorString: return mapTag;
        case promiseCtorString: return promiseTag;
        case setCtorString: return setTag;
        case weakMapCtorString: return weakMapTag;
      }
    }
    return result;
  };
}

/**
 * Checks if `value` is a valid array-like index.
 *
 * @private
 * @param {*} value The value to check.
 * @param {number} [length=MAX_SAFE_INTEGER] The upper bounds of a valid index.
 * @returns {boolean} Returns `true` if `value` is a valid index, else `false`.
 */
function isIndex(value, length) {
  length = length == null ? MAX_SAFE_INTEGER : length;
  return !!length &&
    (typeof value == 'number' || reIsUint.test(value)) &&
    (value > -1 && value % 1 == 0 && value < length);
}

/**
 * Checks if `value` is suitable for use as unique object key.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is suitable, else `false`.
 */
function isKeyable(value) {
  var type = typeof value;
  return (type == 'string' || type == 'number' || type == 'symbol' || type == 'boolean')
    ? (value !== '__proto__')
    : (value === null);
}

/**
 * Checks if `func` has its source masked.
 *
 * @private
 * @param {Function} func The function to check.
 * @returns {boolean} Returns `true` if `func` is masked, else `false`.
 */
function isMasked(func) {
  return !!maskSrcKey && (maskSrcKey in func);
}

/**
 * Checks if `value` is likely a prototype object.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a prototype, else `false`.
 */
function isPrototype(value) {
  var Ctor = value && value.constructor,
      proto = (typeof Ctor == 'function' && Ctor.prototype) || objectProto;

  return value === proto;
}

/**
 * Converts `value` to a string using `Object.prototype.toString`.
 *
 * @private
 * @param {*} value The value to convert.
 * @returns {string} Returns the converted string.
 */
function objectToString(value) {
  return nativeObjectToString.call(value);
}

/**
 * Converts `func` to its source code.
 *
 * @private
 * @param {Function} func The function to convert.
 * @returns {string} Returns the source code.
 */
function toSource(func) {
  if (func != null) {
    try {
      return funcToString.call(func);
    } catch (e) {}
    try {
      return (func + '');
    } catch (e) {}
  }
  return '';
}

/**
 * Performs a
 * [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
 * comparison between two values to determine if they are equivalent.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to compare.
 * @param {*} other The other value to compare.
 * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
 * @example
 *
 * var object = { 'a': 1 };
 * var other = { 'a': 1 };
 *
 * _.eq(object, object);
 * // => true
 *
 * _.eq(object, other);
 * // => false
 *
 * _.eq('a', 'a');
 * // => true
 *
 * _.eq('a', Object('a'));
 * // => false
 *
 * _.eq(NaN, NaN);
 * // => true
 */
function eq(value, other) {
  return value === other || (value !== value && other !== other);
}

/**
 * Checks if `value` is likely an `arguments` object.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an `arguments` object,
 *  else `false`.
 * @example
 *
 * _.isArguments(function() { return arguments; }());
 * // => true
 *
 * _.isArguments([1, 2, 3]);
 * // => false
 */
var isArguments = baseIsArguments(function() { return arguments; }()) ? baseIsArguments : function(value) {
  return isObjectLike(value) && hasOwnProperty.call(value, 'callee') &&
    !propertyIsEnumerable.call(value, 'callee');
};

/**
 * Checks if `value` is classified as an `Array` object.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an array, else `false`.
 * @example
 *
 * _.isArray([1, 2, 3]);
 * // => true
 *
 * _.isArray(document.body.children);
 * // => false
 *
 * _.isArray('abc');
 * // => false
 *
 * _.isArray(_.noop);
 * // => false
 */
var isArray = Array.isArray;

/**
 * Checks if `value` is array-like. A value is considered array-like if it's
 * not a function and has a `value.length` that's an integer greater than or
 * equal to `0` and less than or equal to `Number.MAX_SAFE_INTEGER`.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is array-like, else `false`.
 * @example
 *
 * _.isArrayLike([1, 2, 3]);
 * // => true
 *
 * _.isArrayLike(document.body.children);
 * // => true
 *
 * _.isArrayLike('abc');
 * // => true
 *
 * _.isArrayLike(_.noop);
 * // => false
 */
function isArrayLike(value) {
  return value != null && isLength(value.length) && !isFunction(value);
}

/**
 * Checks if `value` is a buffer.
 *
 * @static
 * @memberOf _
 * @since 4.3.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a buffer, else `false`.
 * @example
 *
 * _.isBuffer(new Buffer(2));
 * // => true
 *
 * _.isBuffer(new Uint8Array(2));
 * // => false
 */
var isBuffer = nativeIsBuffer || stubFalse;

/**
 * Performs a deep comparison between two values to determine if they are
 * equivalent.
 *
 * **Note:** This method supports comparing arrays, array buffers, booleans,
 * date objects, error objects, maps, numbers, `Object` objects, regexes,
 * sets, strings, symbols, and typed arrays. `Object` objects are compared
 * by their own, not inherited, enumerable properties. Functions and DOM
 * nodes are compared by strict equality, i.e. `===`.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to compare.
 * @param {*} other The other value to compare.
 * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
 * @example
 *
 * var object = { 'a': 1 };
 * var other = { 'a': 1 };
 *
 * _.isEqual(object, other);
 * // => true
 *
 * object === other;
 * // => false
 */
function isEqual(value, other) {
  return baseIsEqual(value, other);
}

/**
 * Checks if `value` is classified as a `Function` object.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a function, else `false`.
 * @example
 *
 * _.isFunction(_);
 * // => true
 *
 * _.isFunction(/abc/);
 * // => false
 */
function isFunction(value) {
  if (!isObject(value)) {
    return false;
  }
  // The use of `Object#toString` avoids issues with the `typeof` operator
  // in Safari 9 which returns 'object' for typed arrays and other constructors.
  var tag = baseGetTag(value);
  return tag == funcTag || tag == genTag || tag == asyncTag || tag == proxyTag;
}

/**
 * Checks if `value` is a valid array-like length.
 *
 * **Note:** This method is loosely based on
 * [`ToLength`](http://ecma-international.org/ecma-262/7.0/#sec-tolength).
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a valid length, else `false`.
 * @example
 *
 * _.isLength(3);
 * // => true
 *
 * _.isLength(Number.MIN_VALUE);
 * // => false
 *
 * _.isLength(Infinity);
 * // => false
 *
 * _.isLength('3');
 * // => false
 */
function isLength(value) {
  return typeof value == 'number' &&
    value > -1 && value % 1 == 0 && value <= MAX_SAFE_INTEGER;
}

/**
 * Checks if `value` is the
 * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)
 * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an object, else `false`.
 * @example
 *
 * _.isObject({});
 * // => true
 *
 * _.isObject([1, 2, 3]);
 * // => true
 *
 * _.isObject(_.noop);
 * // => true
 *
 * _.isObject(null);
 * // => false
 */
function isObject(value) {
  var type = typeof value;
  return value != null && (type == 'object' || type == 'function');
}

/**
 * Checks if `value` is object-like. A value is object-like if it's not `null`
 * and has a `typeof` result of "object".
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
 * @example
 *
 * _.isObjectLike({});
 * // => true
 *
 * _.isObjectLike([1, 2, 3]);
 * // => true
 *
 * _.isObjectLike(_.noop);
 * // => false
 *
 * _.isObjectLike(null);
 * // => false
 */
function isObjectLike(value) {
  return value != null && typeof value == 'object';
}

/**
 * Checks if `value` is classified as a typed array.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
 * @example
 *
 * _.isTypedArray(new Uint8Array);
 * // => true
 *
 * _.isTypedArray([]);
 * // => false
 */
var isTypedArray = nodeIsTypedArray ? baseUnary(nodeIsTypedArray) : baseIsTypedArray;

/**
 * Creates an array of the own enumerable property names of `object`.
 *
 * **Note:** Non-object values are coerced to objects. See the
 * [ES spec](http://ecma-international.org/ecma-262/7.0/#sec-object.keys)
 * for more details.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Object
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names.
 * @example
 *
 * function Foo() {
 *   this.a = 1;
 *   this.b = 2;
 * }
 *
 * Foo.prototype.c = 3;
 *
 * _.keys(new Foo);
 * // => ['a', 'b'] (iteration order is not guaranteed)
 *
 * _.keys('hi');
 * // => ['0', '1']
 */
function keys(object) {
  return isArrayLike(object) ? arrayLikeKeys(object) : baseKeys(object);
}

/**
 * This method returns a new empty array.
 *
 * @static
 * @memberOf _
 * @since 4.13.0
 * @category Util
 * @returns {Array} Returns the new empty array.
 * @example
 *
 * var arrays = _.times(2, _.stubArray);
 *
 * console.log(arrays);
 * // => [[], []]
 *
 * console.log(arrays[0] === arrays[1]);
 * // => false
 */
function stubArray() {
  return [];
}

/**
 * This method returns `false`.
 *
 * @static
 * @memberOf _
 * @since 4.13.0
 * @category Util
 * @returns {boolean} Returns `false`.
 * @example
 *
 * _.times(2, _.stubFalse);
 * // => [false, false]
 */
function stubFalse() {
  return false;
}

module.exports = isEqual;


/***/ }),

/***/ "../../node_modules/lodash/_Symbol.js":
/*!********************************************!*\
  !*** ../../node_modules/lodash/_Symbol.js ***!
  \********************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var root = __webpack_require__(/*! ./_root */ "../../node_modules/lodash/_root.js");

/** Built-in value references. */
var Symbol = root.Symbol;

module.exports = Symbol;


/***/ }),

/***/ "../../node_modules/lodash/_baseGetTag.js":
/*!************************************************!*\
  !*** ../../node_modules/lodash/_baseGetTag.js ***!
  \************************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var Symbol = __webpack_require__(/*! ./_Symbol */ "../../node_modules/lodash/_Symbol.js"),
    getRawTag = __webpack_require__(/*! ./_getRawTag */ "../../node_modules/lodash/_getRawTag.js"),
    objectToString = __webpack_require__(/*! ./_objectToString */ "../../node_modules/lodash/_objectToString.js");

/** `Object#toString` result references. */
var nullTag = '[object Null]',
    undefinedTag = '[object Undefined]';

/** Built-in value references. */
var symToStringTag = Symbol ? Symbol.toStringTag : undefined;

/**
 * The base implementation of `getTag` without fallbacks for buggy environments.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the `toStringTag`.
 */
function baseGetTag(value) {
  if (value == null) {
    return value === undefined ? undefinedTag : nullTag;
  }
  return (symToStringTag && symToStringTag in Object(value))
    ? getRawTag(value)
    : objectToString(value);
}

module.exports = baseGetTag;


/***/ }),

/***/ "../../node_modules/lodash/_baseTrim.js":
/*!**********************************************!*\
  !*** ../../node_modules/lodash/_baseTrim.js ***!
  \**********************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var trimmedEndIndex = __webpack_require__(/*! ./_trimmedEndIndex */ "../../node_modules/lodash/_trimmedEndIndex.js");

/** Used to match leading whitespace. */
var reTrimStart = /^\s+/;

/**
 * The base implementation of `_.trim`.
 *
 * @private
 * @param {string} string The string to trim.
 * @returns {string} Returns the trimmed string.
 */
function baseTrim(string) {
  return string
    ? string.slice(0, trimmedEndIndex(string) + 1).replace(reTrimStart, '')
    : string;
}

module.exports = baseTrim;


/***/ }),

/***/ "../../node_modules/lodash/_freeGlobal.js":
/*!************************************************!*\
  !*** ../../node_modules/lodash/_freeGlobal.js ***!
  \************************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

/** Detect free variable `global` from Node.js. */
var freeGlobal = typeof __webpack_require__.g == 'object' && __webpack_require__.g && __webpack_require__.g.Object === Object && __webpack_require__.g;

module.exports = freeGlobal;


/***/ }),

/***/ "../../node_modules/lodash/_getRawTag.js":
/*!***********************************************!*\
  !*** ../../node_modules/lodash/_getRawTag.js ***!
  \***********************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var Symbol = __webpack_require__(/*! ./_Symbol */ "../../node_modules/lodash/_Symbol.js");

/** Used for built-in method references. */
var objectProto = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty = objectProto.hasOwnProperty;

/**
 * Used to resolve the
 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
 * of values.
 */
var nativeObjectToString = objectProto.toString;

/** Built-in value references. */
var symToStringTag = Symbol ? Symbol.toStringTag : undefined;

/**
 * A specialized version of `baseGetTag` which ignores `Symbol.toStringTag` values.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the raw `toStringTag`.
 */
function getRawTag(value) {
  var isOwn = hasOwnProperty.call(value, symToStringTag),
      tag = value[symToStringTag];

  try {
    value[symToStringTag] = undefined;
    var unmasked = true;
  } catch (e) {}

  var result = nativeObjectToString.call(value);
  if (unmasked) {
    if (isOwn) {
      value[symToStringTag] = tag;
    } else {
      delete value[symToStringTag];
    }
  }
  return result;
}

module.exports = getRawTag;


/***/ }),

/***/ "../../node_modules/lodash/_objectToString.js":
/*!****************************************************!*\
  !*** ../../node_modules/lodash/_objectToString.js ***!
  \****************************************************/
/***/ ((module) => {

/** Used for built-in method references. */
var objectProto = Object.prototype;

/**
 * Used to resolve the
 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
 * of values.
 */
var nativeObjectToString = objectProto.toString;

/**
 * Converts `value` to a string using `Object.prototype.toString`.
 *
 * @private
 * @param {*} value The value to convert.
 * @returns {string} Returns the converted string.
 */
function objectToString(value) {
  return nativeObjectToString.call(value);
}

module.exports = objectToString;


/***/ }),

/***/ "../../node_modules/lodash/_root.js":
/*!******************************************!*\
  !*** ../../node_modules/lodash/_root.js ***!
  \******************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var freeGlobal = __webpack_require__(/*! ./_freeGlobal */ "../../node_modules/lodash/_freeGlobal.js");

/** Detect free variable `self`. */
var freeSelf = typeof self == 'object' && self && self.Object === Object && self;

/** Used as a reference to the global object. */
var root = freeGlobal || freeSelf || Function('return this')();

module.exports = root;


/***/ }),

/***/ "../../node_modules/lodash/_trimmedEndIndex.js":
/*!*****************************************************!*\
  !*** ../../node_modules/lodash/_trimmedEndIndex.js ***!
  \*****************************************************/
/***/ ((module) => {

/** Used to match a single whitespace character. */
var reWhitespace = /\s/;

/**
 * Used by `_.trim` and `_.trimEnd` to get the index of the last non-whitespace
 * character of `string`.
 *
 * @private
 * @param {string} string The string to inspect.
 * @returns {number} Returns the index of the last non-whitespace character.
 */
function trimmedEndIndex(string) {
  var index = string.length;

  while (index-- && reWhitespace.test(string.charAt(index))) {}
  return index;
}

module.exports = trimmedEndIndex;


/***/ }),

/***/ "../../node_modules/lodash/debounce.js":
/*!*********************************************!*\
  !*** ../../node_modules/lodash/debounce.js ***!
  \*********************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var isObject = __webpack_require__(/*! ./isObject */ "../../node_modules/lodash/isObject.js"),
    now = __webpack_require__(/*! ./now */ "../../node_modules/lodash/now.js"),
    toNumber = __webpack_require__(/*! ./toNumber */ "../../node_modules/lodash/toNumber.js");

/** Error message constants. */
var FUNC_ERROR_TEXT = 'Expected a function';

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeMax = Math.max,
    nativeMin = Math.min;

/**
 * Creates a debounced function that delays invoking `func` until after `wait`
 * milliseconds have elapsed since the last time the debounced function was
 * invoked. The debounced function comes with a `cancel` method to cancel
 * delayed `func` invocations and a `flush` method to immediately invoke them.
 * Provide `options` to indicate whether `func` should be invoked on the
 * leading and/or trailing edge of the `wait` timeout. The `func` is invoked
 * with the last arguments provided to the debounced function. Subsequent
 * calls to the debounced function return the result of the last `func`
 * invocation.
 *
 * **Note:** If `leading` and `trailing` options are `true`, `func` is
 * invoked on the trailing edge of the timeout only if the debounced function
 * is invoked more than once during the `wait` timeout.
 *
 * If `wait` is `0` and `leading` is `false`, `func` invocation is deferred
 * until to the next tick, similar to `setTimeout` with a timeout of `0`.
 *
 * See [David Corbacho's article](https://css-tricks.com/debouncing-throttling-explained-examples/)
 * for details over the differences between `_.debounce` and `_.throttle`.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Function
 * @param {Function} func The function to debounce.
 * @param {number} [wait=0] The number of milliseconds to delay.
 * @param {Object} [options={}] The options object.
 * @param {boolean} [options.leading=false]
 *  Specify invoking on the leading edge of the timeout.
 * @param {number} [options.maxWait]
 *  The maximum time `func` is allowed to be delayed before it's invoked.
 * @param {boolean} [options.trailing=true]
 *  Specify invoking on the trailing edge of the timeout.
 * @returns {Function} Returns the new debounced function.
 * @example
 *
 * // Avoid costly calculations while the window size is in flux.
 * jQuery(window).on('resize', _.debounce(calculateLayout, 150));
 *
 * // Invoke `sendMail` when clicked, debouncing subsequent calls.
 * jQuery(element).on('click', _.debounce(sendMail, 300, {
 *   'leading': true,
 *   'trailing': false
 * }));
 *
 * // Ensure `batchLog` is invoked once after 1 second of debounced calls.
 * var debounced = _.debounce(batchLog, 250, { 'maxWait': 1000 });
 * var source = new EventSource('/stream');
 * jQuery(source).on('message', debounced);
 *
 * // Cancel the trailing debounced invocation.
 * jQuery(window).on('popstate', debounced.cancel);
 */
function debounce(func, wait, options) {
  var lastArgs,
      lastThis,
      maxWait,
      result,
      timerId,
      lastCallTime,
      lastInvokeTime = 0,
      leading = false,
      maxing = false,
      trailing = true;

  if (typeof func != 'function') {
    throw new TypeError(FUNC_ERROR_TEXT);
  }
  wait = toNumber(wait) || 0;
  if (isObject(options)) {
    leading = !!options.leading;
    maxing = 'maxWait' in options;
    maxWait = maxing ? nativeMax(toNumber(options.maxWait) || 0, wait) : maxWait;
    trailing = 'trailing' in options ? !!options.trailing : trailing;
  }

  function invokeFunc(time) {
    var args = lastArgs,
        thisArg = lastThis;

    lastArgs = lastThis = undefined;
    lastInvokeTime = time;
    result = func.apply(thisArg, args);
    return result;
  }

  function leadingEdge(time) {
    // Reset any `maxWait` timer.
    lastInvokeTime = time;
    // Start the timer for the trailing edge.
    timerId = setTimeout(timerExpired, wait);
    // Invoke the leading edge.
    return leading ? invokeFunc(time) : result;
  }

  function remainingWait(time) {
    var timeSinceLastCall = time - lastCallTime,
        timeSinceLastInvoke = time - lastInvokeTime,
        timeWaiting = wait - timeSinceLastCall;

    return maxing
      ? nativeMin(timeWaiting, maxWait - timeSinceLastInvoke)
      : timeWaiting;
  }

  function shouldInvoke(time) {
    var timeSinceLastCall = time - lastCallTime,
        timeSinceLastInvoke = time - lastInvokeTime;

    // Either this is the first call, activity has stopped and we're at the
    // trailing edge, the system time has gone backwards and we're treating
    // it as the trailing edge, or we've hit the `maxWait` limit.
    return (lastCallTime === undefined || (timeSinceLastCall >= wait) ||
      (timeSinceLastCall < 0) || (maxing && timeSinceLastInvoke >= maxWait));
  }

  function timerExpired() {
    var time = now();
    if (shouldInvoke(time)) {
      return trailingEdge(time);
    }
    // Restart the timer.
    timerId = setTimeout(timerExpired, remainingWait(time));
  }

  function trailingEdge(time) {
    timerId = undefined;

    // Only invoke if we have `lastArgs` which means `func` has been
    // debounced at least once.
    if (trailing && lastArgs) {
      return invokeFunc(time);
    }
    lastArgs = lastThis = undefined;
    return result;
  }

  function cancel() {
    if (timerId !== undefined) {
      clearTimeout(timerId);
    }
    lastInvokeTime = 0;
    lastArgs = lastCallTime = lastThis = timerId = undefined;
  }

  function flush() {
    return timerId === undefined ? result : trailingEdge(now());
  }

  function debounced() {
    var time = now(),
        isInvoking = shouldInvoke(time);

    lastArgs = arguments;
    lastThis = this;
    lastCallTime = time;

    if (isInvoking) {
      if (timerId === undefined) {
        return leadingEdge(lastCallTime);
      }
      if (maxing) {
        // Handle invocations in a tight loop.
        clearTimeout(timerId);
        timerId = setTimeout(timerExpired, wait);
        return invokeFunc(lastCallTime);
      }
    }
    if (timerId === undefined) {
      timerId = setTimeout(timerExpired, wait);
    }
    return result;
  }
  debounced.cancel = cancel;
  debounced.flush = flush;
  return debounced;
}

module.exports = debounce;


/***/ }),

/***/ "../../node_modules/lodash/isObject.js":
/*!*********************************************!*\
  !*** ../../node_modules/lodash/isObject.js ***!
  \*********************************************/
/***/ ((module) => {

/**
 * Checks if `value` is the
 * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)
 * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an object, else `false`.
 * @example
 *
 * _.isObject({});
 * // => true
 *
 * _.isObject([1, 2, 3]);
 * // => true
 *
 * _.isObject(_.noop);
 * // => true
 *
 * _.isObject(null);
 * // => false
 */
function isObject(value) {
  var type = typeof value;
  return value != null && (type == 'object' || type == 'function');
}

module.exports = isObject;


/***/ }),

/***/ "../../node_modules/lodash/isObjectLike.js":
/*!*************************************************!*\
  !*** ../../node_modules/lodash/isObjectLike.js ***!
  \*************************************************/
/***/ ((module) => {

/**
 * Checks if `value` is object-like. A value is object-like if it's not `null`
 * and has a `typeof` result of "object".
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
 * @example
 *
 * _.isObjectLike({});
 * // => true
 *
 * _.isObjectLike([1, 2, 3]);
 * // => true
 *
 * _.isObjectLike(_.noop);
 * // => false
 *
 * _.isObjectLike(null);
 * // => false
 */
function isObjectLike(value) {
  return value != null && typeof value == 'object';
}

module.exports = isObjectLike;


/***/ }),

/***/ "../../node_modules/lodash/isSymbol.js":
/*!*********************************************!*\
  !*** ../../node_modules/lodash/isSymbol.js ***!
  \*********************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var baseGetTag = __webpack_require__(/*! ./_baseGetTag */ "../../node_modules/lodash/_baseGetTag.js"),
    isObjectLike = __webpack_require__(/*! ./isObjectLike */ "../../node_modules/lodash/isObjectLike.js");

/** `Object#toString` result references. */
var symbolTag = '[object Symbol]';

/**
 * Checks if `value` is classified as a `Symbol` primitive or object.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a symbol, else `false`.
 * @example
 *
 * _.isSymbol(Symbol.iterator);
 * // => true
 *
 * _.isSymbol('abc');
 * // => false
 */
function isSymbol(value) {
  return typeof value == 'symbol' ||
    (isObjectLike(value) && baseGetTag(value) == symbolTag);
}

module.exports = isSymbol;


/***/ }),

/***/ "../../node_modules/lodash/now.js":
/*!****************************************!*\
  !*** ../../node_modules/lodash/now.js ***!
  \****************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var root = __webpack_require__(/*! ./_root */ "../../node_modules/lodash/_root.js");

/**
 * Gets the timestamp of the number of milliseconds that have elapsed since
 * the Unix epoch (1 January 1970 00:00:00 UTC).
 *
 * @static
 * @memberOf _
 * @since 2.4.0
 * @category Date
 * @returns {number} Returns the timestamp.
 * @example
 *
 * _.defer(function(stamp) {
 *   console.log(_.now() - stamp);
 * }, _.now());
 * // => Logs the number of milliseconds it took for the deferred invocation.
 */
var now = function() {
  return root.Date.now();
};

module.exports = now;


/***/ }),

/***/ "../../node_modules/lodash/throttle.js":
/*!*********************************************!*\
  !*** ../../node_modules/lodash/throttle.js ***!
  \*********************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var debounce = __webpack_require__(/*! ./debounce */ "../../node_modules/lodash/debounce.js"),
    isObject = __webpack_require__(/*! ./isObject */ "../../node_modules/lodash/isObject.js");

/** Error message constants. */
var FUNC_ERROR_TEXT = 'Expected a function';

/**
 * Creates a throttled function that only invokes `func` at most once per
 * every `wait` milliseconds. The throttled function comes with a `cancel`
 * method to cancel delayed `func` invocations and a `flush` method to
 * immediately invoke them. Provide `options` to indicate whether `func`
 * should be invoked on the leading and/or trailing edge of the `wait`
 * timeout. The `func` is invoked with the last arguments provided to the
 * throttled function. Subsequent calls to the throttled function return the
 * result of the last `func` invocation.
 *
 * **Note:** If `leading` and `trailing` options are `true`, `func` is
 * invoked on the trailing edge of the timeout only if the throttled function
 * is invoked more than once during the `wait` timeout.
 *
 * If `wait` is `0` and `leading` is `false`, `func` invocation is deferred
 * until to the next tick, similar to `setTimeout` with a timeout of `0`.
 *
 * See [David Corbacho's article](https://css-tricks.com/debouncing-throttling-explained-examples/)
 * for details over the differences between `_.throttle` and `_.debounce`.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Function
 * @param {Function} func The function to throttle.
 * @param {number} [wait=0] The number of milliseconds to throttle invocations to.
 * @param {Object} [options={}] The options object.
 * @param {boolean} [options.leading=true]
 *  Specify invoking on the leading edge of the timeout.
 * @param {boolean} [options.trailing=true]
 *  Specify invoking on the trailing edge of the timeout.
 * @returns {Function} Returns the new throttled function.
 * @example
 *
 * // Avoid excessively updating the position while scrolling.
 * jQuery(window).on('scroll', _.throttle(updatePosition, 100));
 *
 * // Invoke `renewToken` when the click event is fired, but not more than once every 5 minutes.
 * var throttled = _.throttle(renewToken, 300000, { 'trailing': false });
 * jQuery(element).on('click', throttled);
 *
 * // Cancel the trailing throttled invocation.
 * jQuery(window).on('popstate', throttled.cancel);
 */
function throttle(func, wait, options) {
  var leading = true,
      trailing = true;

  if (typeof func != 'function') {
    throw new TypeError(FUNC_ERROR_TEXT);
  }
  if (isObject(options)) {
    leading = 'leading' in options ? !!options.leading : leading;
    trailing = 'trailing' in options ? !!options.trailing : trailing;
  }
  return debounce(func, wait, {
    'leading': leading,
    'maxWait': wait,
    'trailing': trailing
  });
}

module.exports = throttle;


/***/ }),

/***/ "../../node_modules/lodash/toNumber.js":
/*!*********************************************!*\
  !*** ../../node_modules/lodash/toNumber.js ***!
  \*********************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var baseTrim = __webpack_require__(/*! ./_baseTrim */ "../../node_modules/lodash/_baseTrim.js"),
    isObject = __webpack_require__(/*! ./isObject */ "../../node_modules/lodash/isObject.js"),
    isSymbol = __webpack_require__(/*! ./isSymbol */ "../../node_modules/lodash/isSymbol.js");

/** Used as references for various `Number` constants. */
var NAN = 0 / 0;

/** Used to detect bad signed hexadecimal string values. */
var reIsBadHex = /^[-+]0x[0-9a-f]+$/i;

/** Used to detect binary string values. */
var reIsBinary = /^0b[01]+$/i;

/** Used to detect octal string values. */
var reIsOctal = /^0o[0-7]+$/i;

/** Built-in method references without a dependency on `root`. */
var freeParseInt = parseInt;

/**
 * Converts `value` to a number.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to process.
 * @returns {number} Returns the number.
 * @example
 *
 * _.toNumber(3.2);
 * // => 3.2
 *
 * _.toNumber(Number.MIN_VALUE);
 * // => 5e-324
 *
 * _.toNumber(Infinity);
 * // => Infinity
 *
 * _.toNumber('3.2');
 * // => 3.2
 */
function toNumber(value) {
  if (typeof value == 'number') {
    return value;
  }
  if (isSymbol(value)) {
    return NAN;
  }
  if (isObject(value)) {
    var other = typeof value.valueOf == 'function' ? value.valueOf() : value;
    value = isObject(other) ? (other + '') : other;
  }
  if (typeof value != 'string') {
    return value === 0 ? value : +value;
  }
  value = baseTrim(value);
  var isBinary = reIsBinary.test(value);
  return (isBinary || reIsOctal.test(value))
    ? freeParseInt(value.slice(2), isBinary ? 2 : 8)
    : (reIsBadHex.test(value) ? NAN : +value);
}

module.exports = toNumber;


/***/ }),

/***/ "../../node_modules/querystring/decode.js":
/*!************************************************!*\
  !*** ../../node_modules/querystring/decode.js ***!
  \************************************************/
/***/ ((module) => {

"use strict";
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.



// If obj.hasOwnProperty has been overridden, then calling
// obj.hasOwnProperty(prop) will break.
// See: https://github.com/joyent/node/issues/1707
function hasOwnProperty(obj, prop) {
  return Object.prototype.hasOwnProperty.call(obj, prop);
}

module.exports = function(qs, sep, eq, options) {
  sep = sep || '&';
  eq = eq || '=';
  var obj = {};

  if (typeof qs !== 'string' || qs.length === 0) {
    return obj;
  }

  var regexp = /\+/g;
  qs = qs.split(sep);

  var maxKeys = 1000;
  if (options && typeof options.maxKeys === 'number') {
    maxKeys = options.maxKeys;
  }

  var len = qs.length;
  // maxKeys <= 0 means that we should not limit keys count
  if (maxKeys > 0 && len > maxKeys) {
    len = maxKeys;
  }

  for (var i = 0; i < len; ++i) {
    var x = qs[i].replace(regexp, '%20'),
        idx = x.indexOf(eq),
        kstr, vstr, k, v;

    if (idx >= 0) {
      kstr = x.substr(0, idx);
      vstr = x.substr(idx + 1);
    } else {
      kstr = x;
      vstr = '';
    }

    k = decodeURIComponent(kstr);
    v = decodeURIComponent(vstr);

    if (!hasOwnProperty(obj, k)) {
      obj[k] = v;
    } else if (Array.isArray(obj[k])) {
      obj[k].push(v);
    } else {
      obj[k] = [obj[k], v];
    }
  }

  return obj;
};


/***/ }),

/***/ "../../node_modules/querystring/encode.js":
/*!************************************************!*\
  !*** ../../node_modules/querystring/encode.js ***!
  \************************************************/
/***/ ((module) => {

"use strict";
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.



var stringifyPrimitive = function(v) {
  switch (typeof v) {
    case 'string':
      return v;

    case 'boolean':
      return v ? 'true' : 'false';

    case 'number':
      return isFinite(v) ? v : '';

    default:
      return '';
  }
};

module.exports = function(obj, sep, eq, name) {
  sep = sep || '&';
  eq = eq || '=';
  if (obj === null) {
    obj = undefined;
  }

  if (typeof obj === 'object') {
    return Object.keys(obj).map(function(k) {
      var ks = encodeURIComponent(stringifyPrimitive(k)) + eq;
      if (Array.isArray(obj[k])) {
        return obj[k].map(function(v) {
          return ks + encodeURIComponent(stringifyPrimitive(v));
        }).join(sep);
      } else {
        return ks + encodeURIComponent(stringifyPrimitive(obj[k]));
      }
    }).join(sep);

  }

  if (!name) return '';
  return encodeURIComponent(stringifyPrimitive(name)) + eq +
         encodeURIComponent(stringifyPrimitive(obj));
};


/***/ }),

/***/ "../../node_modules/querystring/index.js":
/*!***********************************************!*\
  !*** ../../node_modules/querystring/index.js ***!
  \***********************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


exports.decode = exports.parse = __webpack_require__(/*! ./decode */ "../../node_modules/querystring/decode.js");
exports.encode = exports.stringify = __webpack_require__(/*! ./encode */ "../../node_modules/querystring/encode.js");


/***/ }),

/***/ "../../node_modules/raf-schd/dist/raf-schd.esm.js":
/*!********************************************************!*\
  !*** ../../node_modules/raf-schd/dist/raf-schd.esm.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
var rafSchd = function rafSchd(fn) {
  var lastArgs = [];
  var frameId = null;

  var wrapperFn = function wrapperFn() {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    lastArgs = args;

    if (frameId) {
      return;
    }

    frameId = requestAnimationFrame(function () {
      frameId = null;
      fn.apply(void 0, lastArgs);
    });
  };

  wrapperFn.cancel = function () {
    if (!frameId) {
      return;
    }

    cancelAnimationFrame(frameId);
    frameId = null;
  };

  return wrapperFn;
};

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (rafSchd);


/***/ }),

/***/ "../../node_modules/react-contextmenu/es6/AbstractMenu.js":
/*!****************************************************************!*\
  !*** ../../node_modules/react-contextmenu/es6/AbstractMenu.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _MenuItem__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./MenuItem */ "../../node_modules/react-contextmenu/es6/MenuItem.js");
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }






var AbstractMenu = function (_Component) {
    _inherits(AbstractMenu, _Component);

    function AbstractMenu(props) {
        _classCallCheck(this, AbstractMenu);

        var _this = _possibleConstructorReturn(this, (AbstractMenu.__proto__ || Object.getPrototypeOf(AbstractMenu)).call(this, props));

        _initialiseProps.call(_this);

        _this.seletedItemRef = null;
        _this.state = {
            selectedItem: null,
            forceSubMenuOpen: false
        };
        return _this;
    }

    return AbstractMenu;
}(react__WEBPACK_IMPORTED_MODULE_0__.Component);

AbstractMenu.propTypes = {
    children: (prop_types__WEBPACK_IMPORTED_MODULE_2___default().node.isRequired)
};

var _initialiseProps = function _initialiseProps() {
    var _this2 = this;

    this.handleKeyNavigation = function (e) {
        // check for isVisible strictly here as it might be undefined when this code executes in the context of SubMenu
        // but we only need to check when it runs in the ContextMenu context
        if (_this2.state.isVisible === false) {
            return;
        }

        switch (e.keyCode) {
            case 37: // left arrow
            case 27:
                // escape
                e.preventDefault();
                _this2.hideMenu(e);
                break;
            case 38:
                // up arrow
                e.preventDefault();
                _this2.selectChildren(true);
                break;
            case 40:
                // down arrow
                e.preventDefault();
                _this2.selectChildren(false);
                break;
            case 39:
                // right arrow
                _this2.tryToOpenSubMenu(e);
                break;
            case 13:
                // enter
                e.preventDefault();
                _this2.tryToOpenSubMenu(e);
                {
                    // determine the selected item is disabled or not
                    var disabled = _this2.seletedItemRef && _this2.seletedItemRef.props && _this2.seletedItemRef.props.disabled;

                    if (_this2.seletedItemRef && _this2.seletedItemRef.ref instanceof HTMLElement && !disabled) {
                        _this2.seletedItemRef.ref.click();
                    } else {
                        _this2.hideMenu(e);
                    }
                }
                break;
            default:
            // do nothing
        }
    };

    this.handleForceClose = function () {
        _this2.setState({ forceSubMenuOpen: false });
    };

    this.tryToOpenSubMenu = function (e) {
        if (_this2.state.selectedItem && _this2.state.selectedItem.type === _this2.getSubMenuType()) {
            e.preventDefault();
            _this2.setState({ forceSubMenuOpen: true });
        }
    };

    this.selectChildren = function (forward) {
        var selectedItem = _this2.state.selectedItem;

        var children = [];
        var disabledChildrenCount = 0;
        var disabledChildIndexes = {};

        var childCollector = function childCollector(child, index) {
            // child can be empty in case you do conditional rendering of components, in which
            // case it should not be accounted for as a real child
            if (!child) {
                return;
            }

            if ([_MenuItem__WEBPACK_IMPORTED_MODULE_1__["default"], _this2.getSubMenuType()].indexOf(child.type) < 0) {
                // Maybe the MenuItem or SubMenu is capsuled in a wrapper div or something else
                react__WEBPACK_IMPORTED_MODULE_0___default().Children.forEach(child.props.children, childCollector);
            } else if (!child.props.divider) {
                if (child.props.disabled) {
                    ++disabledChildrenCount;
                    disabledChildIndexes[index] = true;
                }

                children.push(child);
            }
        };

        react__WEBPACK_IMPORTED_MODULE_0___default().Children.forEach(_this2.props.children, childCollector);
        if (disabledChildrenCount === children.length) {
            // All menu items are disabled, so none can be selected, don't do anything
            return;
        }

        function findNextEnabledChildIndex(currentIndex) {
            var i = currentIndex;
            var incrementCounter = function incrementCounter() {
                if (forward) {
                    --i;
                } else {
                    ++i;
                }

                if (i < 0) {
                    i = children.length - 1;
                } else if (i >= children.length) {
                    i = 0;
                }
            };

            do {
                incrementCounter();
            } while (i !== currentIndex && disabledChildIndexes[i]);

            return i === currentIndex ? null : i;
        }

        var currentIndex = children.indexOf(selectedItem);
        var nextEnabledChildIndex = findNextEnabledChildIndex(currentIndex);

        if (nextEnabledChildIndex !== null) {
            _this2.setState({
                selectedItem: children[nextEnabledChildIndex],
                forceSubMenuOpen: false
            });
        }
    };

    this.onChildMouseMove = function (child) {
        if (_this2.state.selectedItem !== child) {
            _this2.setState({ selectedItem: child, forceSubMenuOpen: false });
        }
    };

    this.onChildMouseLeave = function () {
        _this2.setState({ selectedItem: null, forceSubMenuOpen: false });
    };

    this.renderChildren = function (children) {
        return react__WEBPACK_IMPORTED_MODULE_0___default().Children.map(children, function (child) {
            var props = {};
            if (!react__WEBPACK_IMPORTED_MODULE_0___default().isValidElement(child)) return child;
            if ([_MenuItem__WEBPACK_IMPORTED_MODULE_1__["default"], _this2.getSubMenuType()].indexOf(child.type) < 0) {
                // Maybe the MenuItem or SubMenu is capsuled in a wrapper div or something else
                props.children = _this2.renderChildren(child.props.children);
                return react__WEBPACK_IMPORTED_MODULE_0___default().cloneElement(child, props);
            }
            props.onMouseLeave = _this2.onChildMouseLeave.bind(_this2);
            if (child.type === _this2.getSubMenuType()) {
                // special props for SubMenu only
                props.forceOpen = _this2.state.forceSubMenuOpen && _this2.state.selectedItem === child;
                props.forceClose = _this2.handleForceClose;
                props.parentKeyNavigationHandler = _this2.handleKeyNavigation;
            }
            if (!child.props.divider && _this2.state.selectedItem === child) {
                // special props for selected item only
                props.selected = true;
                props.ref = function (ref) {
                    _this2.seletedItemRef = ref;
                };
                return react__WEBPACK_IMPORTED_MODULE_0___default().cloneElement(child, props);
            }
            // onMouseMove is only needed for non selected items
            props.onMouseMove = function () {
                return _this2.onChildMouseMove(child);
            };
            return react__WEBPACK_IMPORTED_MODULE_0___default().cloneElement(child, props);
        });
    };
};

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (AbstractMenu);

/***/ }),

/***/ "../../node_modules/react-contextmenu/es6/ContextMenu.js":
/*!***************************************************************!*\
  !*** ../../node_modules/react-contextmenu/es6/ContextMenu.js ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var object_assign__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! object-assign */ "../../node_modules/object-assign/index.js");
/* harmony import */ var object_assign__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(object_assign__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _globalEventListener__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./globalEventListener */ "../../node_modules/react-contextmenu/es6/globalEventListener.js");
/* harmony import */ var _AbstractMenu__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./AbstractMenu */ "../../node_modules/react-contextmenu/es6/AbstractMenu.js");
/* harmony import */ var _SubMenu__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./SubMenu */ "../../node_modules/react-contextmenu/es6/SubMenu.js");
/* harmony import */ var _actions__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./actions */ "../../node_modules/react-contextmenu/es6/actions.js");
/* harmony import */ var _helpers__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./helpers */ "../../node_modules/react-contextmenu/es6/helpers.js");
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }












var ContextMenu = function (_AbstractMenu) {
    _inherits(ContextMenu, _AbstractMenu);

    function ContextMenu(props) {
        _classCallCheck(this, ContextMenu);

        var _this = _possibleConstructorReturn(this, (ContextMenu.__proto__ || Object.getPrototypeOf(ContextMenu)).call(this, props));

        _this.registerHandlers = function () {
            document.addEventListener('mousedown', _this.handleOutsideClick);
            document.addEventListener('touchstart', _this.handleOutsideClick);
            if (!_this.props.preventHideOnScroll) document.addEventListener('scroll', _this.handleHide);
            if (!_this.props.preventHideOnContextMenu) document.addEventListener('contextmenu', _this.handleHide);
            document.addEventListener('keydown', _this.handleKeyNavigation);
            if (!_this.props.preventHideOnResize) window.addEventListener('resize', _this.handleHide);
        };

        _this.unregisterHandlers = function () {
            document.removeEventListener('mousedown', _this.handleOutsideClick);
            document.removeEventListener('touchstart', _this.handleOutsideClick);
            document.removeEventListener('scroll', _this.handleHide);
            document.removeEventListener('contextmenu', _this.handleHide);
            document.removeEventListener('keydown', _this.handleKeyNavigation);
            window.removeEventListener('resize', _this.handleHide);
        };

        _this.handleShow = function (e) {
            if (e.detail.id !== _this.props.id || _this.state.isVisible) return;

            var _e$detail$position = e.detail.position,
                x = _e$detail$position.x,
                y = _e$detail$position.y;


            _this.setState({ isVisible: true, x: x, y: y });
            _this.registerHandlers();
            (0,_helpers__WEBPACK_IMPORTED_MODULE_7__.callIfExists)(_this.props.onShow, e);
        };

        _this.handleHide = function (e) {
            if (_this.state.isVisible && (!e.detail || !e.detail.id || e.detail.id === _this.props.id)) {
                _this.unregisterHandlers();
                _this.setState({ isVisible: false, selectedItem: null, forceSubMenuOpen: false });
                (0,_helpers__WEBPACK_IMPORTED_MODULE_7__.callIfExists)(_this.props.onHide, e);
            }
        };

        _this.handleOutsideClick = function (e) {
            if (!_this.menu.contains(e.target)) (0,_actions__WEBPACK_IMPORTED_MODULE_6__.hideMenu)();
        };

        _this.handleMouseLeave = function (event) {
            event.preventDefault();

            (0,_helpers__WEBPACK_IMPORTED_MODULE_7__.callIfExists)(_this.props.onMouseLeave, event, object_assign__WEBPACK_IMPORTED_MODULE_2___default()({}, _this.props.data, _helpers__WEBPACK_IMPORTED_MODULE_7__.store.data), _helpers__WEBPACK_IMPORTED_MODULE_7__.store.target);

            if (_this.props.hideOnLeave) (0,_actions__WEBPACK_IMPORTED_MODULE_6__.hideMenu)();
        };

        _this.handleContextMenu = function (e) {
            if (false) {}
            _this.handleHide(e);
        };

        _this.hideMenu = function (e) {
            if (e.keyCode === 27 || e.keyCode === 13) {
                // ECS or enter
                (0,_actions__WEBPACK_IMPORTED_MODULE_6__.hideMenu)();
            }
        };

        _this.getMenuPosition = function () {
            var x = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
            var y = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;

            var menuStyles = {
                top: y,
                left: x
            };

            if (!_this.menu) return menuStyles;

            var _window = window,
                innerWidth = _window.innerWidth,
                innerHeight = _window.innerHeight;

            var rect = _this.menu.getBoundingClientRect();

            if (y + rect.height > innerHeight) {
                menuStyles.top -= rect.height;
            }

            if (x + rect.width > innerWidth) {
                menuStyles.left -= rect.width;
            }

            if (menuStyles.top < 0) {
                menuStyles.top = rect.height < innerHeight ? (innerHeight - rect.height) / 2 : 0;
            }

            if (menuStyles.left < 0) {
                menuStyles.left = rect.width < innerWidth ? (innerWidth - rect.width) / 2 : 0;
            }

            return menuStyles;
        };

        _this.getRTLMenuPosition = function () {
            var x = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
            var y = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;

            var menuStyles = {
                top: y,
                left: x
            };

            if (!_this.menu) return menuStyles;

            var _window2 = window,
                innerWidth = _window2.innerWidth,
                innerHeight = _window2.innerHeight;

            var rect = _this.menu.getBoundingClientRect();

            // Try to position the menu on the left side of the cursor
            menuStyles.left = x - rect.width;

            if (y + rect.height > innerHeight) {
                menuStyles.top -= rect.height;
            }

            if (menuStyles.left < 0) {
                menuStyles.left += rect.width;
            }

            if (menuStyles.top < 0) {
                menuStyles.top = rect.height < innerHeight ? (innerHeight - rect.height) / 2 : 0;
            }

            if (menuStyles.left + rect.width > innerWidth) {
                menuStyles.left = rect.width < innerWidth ? (innerWidth - rect.width) / 2 : 0;
            }

            return menuStyles;
        };

        _this.menuRef = function (c) {
            _this.menu = c;
        };

        _this.state = object_assign__WEBPACK_IMPORTED_MODULE_2___default()({}, _this.state, {
            x: 0,
            y: 0,
            isVisible: false
        });
        return _this;
    }

    _createClass(ContextMenu, [{
        key: 'getSubMenuType',
        value: function getSubMenuType() {
            // eslint-disable-line class-methods-use-this
            return _SubMenu__WEBPACK_IMPORTED_MODULE_5__["default"];
        }
    }, {
        key: 'componentDidMount',
        value: function componentDidMount() {
            this.listenId = _globalEventListener__WEBPACK_IMPORTED_MODULE_3__["default"].register(this.handleShow, this.handleHide);
        }
    }, {
        key: 'componentDidUpdate',
        value: function componentDidUpdate() {
            var _this2 = this;

            var wrapper = window.requestAnimationFrame || setTimeout;
            if (this.state.isVisible) {
                wrapper(function () {
                    var _state = _this2.state,
                        x = _state.x,
                        y = _state.y;

                    var _ref = _this2.props.rtl ? _this2.getRTLMenuPosition(x, y) : _this2.getMenuPosition(x, y),
                        top = _ref.top,
                        left = _ref.left;

                    wrapper(function () {
                        if (!_this2.menu) return;
                        _this2.menu.style.top = top + 'px';
                        _this2.menu.style.left = left + 'px';
                        _this2.menu.style.opacity = 1;
                        _this2.menu.style.pointerEvents = 'auto';
                    });
                });
            } else {
                wrapper(function () {
                    if (!_this2.menu) return;
                    _this2.menu.style.opacity = 0;
                    _this2.menu.style.pointerEvents = 'none';
                });
            }
        }
    }, {
        key: 'componentWillUnmount',
        value: function componentWillUnmount() {
            if (this.listenId) {
                _globalEventListener__WEBPACK_IMPORTED_MODULE_3__["default"].unregister(this.listenId);
            }

            this.unregisterHandlers();
        }
    }, {
        key: 'render',
        value: function render() {
            var _props = this.props,
                children = _props.children,
                className = _props.className,
                style = _props.style;
            var isVisible = this.state.isVisible;

            var inlineStyle = object_assign__WEBPACK_IMPORTED_MODULE_2___default()({}, style, { position: 'fixed', opacity: 0, pointerEvents: 'none' });
            var menuClassnames = classnames__WEBPACK_IMPORTED_MODULE_1___default()(_helpers__WEBPACK_IMPORTED_MODULE_7__.cssClasses.menu, className, _defineProperty({}, _helpers__WEBPACK_IMPORTED_MODULE_7__.cssClasses.menuVisible, isVisible));

            return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(
                'nav',
                {
                    role: 'menu', tabIndex: '-1', ref: this.menuRef, style: inlineStyle, className: menuClassnames,
                    onContextMenu: this.handleContextMenu, onMouseLeave: this.handleMouseLeave },
                this.renderChildren(children)
            );
        }
    }]);

    return ContextMenu;
}(_AbstractMenu__WEBPACK_IMPORTED_MODULE_4__["default"]);

ContextMenu.propTypes = {
    id: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().string.isRequired),
    children: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().node.isRequired),
    data: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().object),
    className: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().string),
    hideOnLeave: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().bool),
    rtl: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().bool),
    onHide: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().func),
    onMouseLeave: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().func),
    onShow: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().func),
    preventHideOnContextMenu: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().bool),
    preventHideOnResize: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().bool),
    preventHideOnScroll: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().bool),
    style: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().object)
};
ContextMenu.defaultProps = {
    className: '',
    data: {},
    hideOnLeave: false,
    rtl: false,
    onHide: function onHide() {
        return null;
    },
    onMouseLeave: function onMouseLeave() {
        return null;
    },
    onShow: function onShow() {
        return null;
    },

    preventHideOnContextMenu: false,
    preventHideOnResize: false,
    preventHideOnScroll: false,
    style: {}
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ContextMenu);

/***/ }),

/***/ "../../node_modules/react-contextmenu/es6/ContextMenuTrigger.js":
/*!**********************************************************************!*\
  !*** ../../node_modules/react-contextmenu/es6/ContextMenuTrigger.js ***!
  \**********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var object_assign__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! object-assign */ "../../node_modules/object-assign/index.js");
/* harmony import */ var object_assign__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(object_assign__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _actions__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./actions */ "../../node_modules/react-contextmenu/es6/actions.js");
/* harmony import */ var _helpers__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./helpers */ "../../node_modules/react-contextmenu/es6/helpers.js");
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }









var ContextMenuTrigger = function (_Component) {
    _inherits(ContextMenuTrigger, _Component);

    function ContextMenuTrigger() {
        var _ref;

        var _temp, _this, _ret;

        _classCallCheck(this, ContextMenuTrigger);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = ContextMenuTrigger.__proto__ || Object.getPrototypeOf(ContextMenuTrigger)).call.apply(_ref, [this].concat(args))), _this), _this.touchHandled = false, _this.handleMouseDown = function (event) {
            if (_this.props.holdToDisplay >= 0 && event.button === 0) {
                event.persist();
                event.stopPropagation();

                _this.mouseDownTimeoutId = setTimeout(function () {
                    return _this.handleContextClick(event);
                }, _this.props.holdToDisplay);
            }
            (0,_helpers__WEBPACK_IMPORTED_MODULE_4__.callIfExists)(_this.props.attributes.onMouseDown, event);
        }, _this.handleMouseUp = function (event) {
            if (event.button === 0) {
                clearTimeout(_this.mouseDownTimeoutId);
            }
            (0,_helpers__WEBPACK_IMPORTED_MODULE_4__.callIfExists)(_this.props.attributes.onMouseUp, event);
        }, _this.handleMouseOut = function (event) {
            if (event.button === 0) {
                clearTimeout(_this.mouseDownTimeoutId);
            }
            (0,_helpers__WEBPACK_IMPORTED_MODULE_4__.callIfExists)(_this.props.attributes.onMouseOut, event);
        }, _this.handleTouchstart = function (event) {
            _this.touchHandled = false;

            if (_this.props.holdToDisplay >= 0) {
                event.persist();
                event.stopPropagation();

                _this.touchstartTimeoutId = setTimeout(function () {
                    _this.handleContextClick(event);
                    _this.touchHandled = true;
                }, _this.props.holdToDisplay);
            }
            (0,_helpers__WEBPACK_IMPORTED_MODULE_4__.callIfExists)(_this.props.attributes.onTouchStart, event);
        }, _this.handleTouchEnd = function (event) {
            if (_this.touchHandled) {
                event.preventDefault();
            }
            clearTimeout(_this.touchstartTimeoutId);
            (0,_helpers__WEBPACK_IMPORTED_MODULE_4__.callIfExists)(_this.props.attributes.onTouchEnd, event);
        }, _this.handleContextMenu = function (event) {
            if (event.button === _this.props.mouseButton) {
                _this.handleContextClick(event);
            }
            (0,_helpers__WEBPACK_IMPORTED_MODULE_4__.callIfExists)(_this.props.attributes.onContextMenu, event);
        }, _this.handleMouseClick = function (event) {
            if (event.button === _this.props.mouseButton) {
                _this.handleContextClick(event);
            }
            (0,_helpers__WEBPACK_IMPORTED_MODULE_4__.callIfExists)(_this.props.attributes.onClick, event);
        }, _this.handleContextClick = function (event) {
            if (_this.props.disable) return;
            if (_this.props.disableIfShiftIsPressed && event.shiftKey) return;

            event.preventDefault();
            event.stopPropagation();

            var x = event.clientX || event.touches && event.touches[0].pageX;
            var y = event.clientY || event.touches && event.touches[0].pageY;

            if (_this.props.posX) {
                x -= _this.props.posX;
            }
            if (_this.props.posY) {
                y -= _this.props.posY;
            }

            (0,_actions__WEBPACK_IMPORTED_MODULE_3__.hideMenu)();

            var data = (0,_helpers__WEBPACK_IMPORTED_MODULE_4__.callIfExists)(_this.props.collect, _this.props);
            var showMenuConfig = {
                position: { x: x, y: y },
                target: _this.elem,
                id: _this.props.id
            };
            if (data && typeof data.then === 'function') {
                // it's promise
                data.then(function (resp) {
                    showMenuConfig.data = object_assign__WEBPACK_IMPORTED_MODULE_2___default()({}, resp, {
                        target: event.target
                    });
                    (0,_actions__WEBPACK_IMPORTED_MODULE_3__.showMenu)(showMenuConfig);
                });
            } else {
                showMenuConfig.data = object_assign__WEBPACK_IMPORTED_MODULE_2___default()({}, data, {
                    target: event.target
                });
                (0,_actions__WEBPACK_IMPORTED_MODULE_3__.showMenu)(showMenuConfig);
            }
        }, _this.elemRef = function (c) {
            _this.elem = c;
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(ContextMenuTrigger, [{
        key: 'render',
        value: function render() {
            var _props = this.props,
                renderTag = _props.renderTag,
                attributes = _props.attributes,
                children = _props.children;

            var newAttrs = object_assign__WEBPACK_IMPORTED_MODULE_2___default()({}, attributes, {
                className: classnames__WEBPACK_IMPORTED_MODULE_1___default()(_helpers__WEBPACK_IMPORTED_MODULE_4__.cssClasses.menuWrapper, attributes.className),
                onContextMenu: this.handleContextMenu,
                onClick: this.handleMouseClick,
                onMouseDown: this.handleMouseDown,
                onMouseUp: this.handleMouseUp,
                onTouchStart: this.handleTouchstart,
                onTouchEnd: this.handleTouchEnd,
                onMouseOut: this.handleMouseOut,
                ref: this.elemRef
            });

            return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(renderTag, newAttrs, children);
        }
    }]);

    return ContextMenuTrigger;
}(react__WEBPACK_IMPORTED_MODULE_0__.Component);

ContextMenuTrigger.propTypes = {
    id: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().string.isRequired),
    children: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().node.isRequired),
    attributes: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().object),
    collect: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().func),
    disable: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().bool),
    holdToDisplay: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().number),
    posX: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().number),
    posY: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().number),
    renderTag: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().elementType),
    mouseButton: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().number),
    disableIfShiftIsPressed: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().bool)
};
ContextMenuTrigger.defaultProps = {
    attributes: {},
    collect: function collect() {
        return null;
    },

    disable: false,
    holdToDisplay: 1000,
    renderTag: 'div',
    posX: 0,
    posY: 0,
    mouseButton: 2, // 0 is left click, 2 is right click
    disableIfShiftIsPressed: false
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ContextMenuTrigger);

/***/ }),

/***/ "../../node_modules/react-contextmenu/es6/MenuItem.js":
/*!************************************************************!*\
  !*** ../../node_modules/react-contextmenu/es6/MenuItem.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var object_assign__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! object-assign */ "../../node_modules/object-assign/index.js");
/* harmony import */ var object_assign__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(object_assign__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _actions__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./actions */ "../../node_modules/react-contextmenu/es6/actions.js");
/* harmony import */ var _helpers__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./helpers */ "../../node_modules/react-contextmenu/es6/helpers.js");
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }









var MenuItem = function (_Component) {
    _inherits(MenuItem, _Component);

    function MenuItem() {
        var _ref;

        var _temp, _this, _ret;

        _classCallCheck(this, MenuItem);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = MenuItem.__proto__ || Object.getPrototypeOf(MenuItem)).call.apply(_ref, [this].concat(args))), _this), _this.handleClick = function (event) {
            if (event.button !== 0 && event.button !== 1) {
                event.preventDefault();
            }

            if (_this.props.disabled || _this.props.divider) return;

            (0,_helpers__WEBPACK_IMPORTED_MODULE_4__.callIfExists)(_this.props.onClick, event, object_assign__WEBPACK_IMPORTED_MODULE_2___default()({}, _this.props.data, _helpers__WEBPACK_IMPORTED_MODULE_4__.store.data), _helpers__WEBPACK_IMPORTED_MODULE_4__.store.target);

            if (_this.props.preventClose) return;

            (0,_actions__WEBPACK_IMPORTED_MODULE_3__.hideMenu)();
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(MenuItem, [{
        key: 'render',
        value: function render() {
            var _cx,
                _this2 = this;

            var _props = this.props,
                attributes = _props.attributes,
                children = _props.children,
                className = _props.className,
                disabled = _props.disabled,
                divider = _props.divider,
                selected = _props.selected;


            var menuItemClassNames = classnames__WEBPACK_IMPORTED_MODULE_1___default()(className, _helpers__WEBPACK_IMPORTED_MODULE_4__.cssClasses.menuItem, attributes.className, (_cx = {}, _defineProperty(_cx, classnames__WEBPACK_IMPORTED_MODULE_1___default()(_helpers__WEBPACK_IMPORTED_MODULE_4__.cssClasses.menuItemDisabled, attributes.disabledClassName), disabled), _defineProperty(_cx, classnames__WEBPACK_IMPORTED_MODULE_1___default()(_helpers__WEBPACK_IMPORTED_MODULE_4__.cssClasses.menuItemDivider, attributes.dividerClassName), divider), _defineProperty(_cx, classnames__WEBPACK_IMPORTED_MODULE_1___default()(_helpers__WEBPACK_IMPORTED_MODULE_4__.cssClasses.menuItemSelected, attributes.selectedClassName), selected), _cx));

            return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(
                'div',
                _extends({}, attributes, { className: menuItemClassNames,
                    role: 'menuitem', tabIndex: '-1', 'aria-disabled': disabled ? 'true' : 'false',
                    'aria-orientation': divider ? 'horizontal' : null,
                    ref: function ref(_ref2) {
                        _this2.ref = _ref2;
                    },
                    onMouseMove: this.props.onMouseMove, onMouseLeave: this.props.onMouseLeave,
                    onTouchEnd: this.handleClick, onClick: this.handleClick }),
                divider ? null : children
            );
        }
    }]);

    return MenuItem;
}(react__WEBPACK_IMPORTED_MODULE_0__.Component);

MenuItem.propTypes = {
    attributes: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().object),
    children: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().node),
    className: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().string),
    data: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().object),
    disabled: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().bool),
    divider: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().bool),
    onClick: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().func),
    onMouseLeave: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().func),
    onMouseMove: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().func),
    preventClose: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().bool),
    selected: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().bool)
};
MenuItem.defaultProps = {
    attributes: {},
    children: null,
    className: '',
    data: {},
    disabled: false,
    divider: false,
    onClick: function onClick() {
        return null;
    },

    onMouseMove: function onMouseMove() {
        return null;
    },
    onMouseLeave: function onMouseLeave() {
        return null;
    },
    preventClose: false,
    selected: false
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (MenuItem);

/***/ }),

/***/ "../../node_modules/react-contextmenu/es6/SubMenu.js":
/*!***********************************************************!*\
  !*** ../../node_modules/react-contextmenu/es6/SubMenu.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_7__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! classnames */ "../../node_modules/classnames/index.js");
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var object_assign__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! object-assign */ "../../node_modules/object-assign/index.js");
/* harmony import */ var object_assign__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(object_assign__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _actions__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./actions */ "../../node_modules/react-contextmenu/es6/actions.js");
/* harmony import */ var _AbstractMenu__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./AbstractMenu */ "../../node_modules/react-contextmenu/es6/AbstractMenu.js");
/* harmony import */ var _helpers__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./helpers */ "../../node_modules/react-contextmenu/es6/helpers.js");
/* harmony import */ var _globalEventListener__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./globalEventListener */ "../../node_modules/react-contextmenu/es6/globalEventListener.js");
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }











var SubMenu = function (_AbstractMenu) {
    _inherits(SubMenu, _AbstractMenu);

    function SubMenu(props) {
        _classCallCheck(this, SubMenu);

        var _this = _possibleConstructorReturn(this, (SubMenu.__proto__ || Object.getPrototypeOf(SubMenu)).call(this, props));

        _this.getMenuPosition = function () {
            var _window = window,
                innerWidth = _window.innerWidth,
                innerHeight = _window.innerHeight;

            var rect = _this.subMenu.getBoundingClientRect();
            var position = {};

            if (rect.bottom > innerHeight) {
                position.bottom = 0;
            } else {
                position.top = 0;
            }

            if (rect.right < innerWidth) {
                position.left = '100%';
            } else {
                position.right = '100%';
            }

            return position;
        };

        _this.getRTLMenuPosition = function () {
            var _window2 = window,
                innerHeight = _window2.innerHeight;

            var rect = _this.subMenu.getBoundingClientRect();
            var position = {};

            if (rect.bottom > innerHeight) {
                position.bottom = 0;
            } else {
                position.top = 0;
            }

            if (rect.left < 0) {
                position.left = '100%';
            } else {
                position.right = '100%';
            }

            return position;
        };

        _this.hideSubMenu = function (e) {
            // avoid closing submenus of a different menu tree
            if (e.detail && e.detail.id && _this.menu && e.detail.id !== _this.menu.id) {
                return;
            }

            if (_this.props.forceOpen) {
                _this.props.forceClose();
            }
            _this.setState({ visible: false, selectedItem: null });
            _this.unregisterHandlers();
        };

        _this.handleClick = function (event) {
            event.preventDefault();

            if (_this.props.disabled) return;

            (0,_helpers__WEBPACK_IMPORTED_MODULE_5__.callIfExists)(_this.props.onClick, event, object_assign__WEBPACK_IMPORTED_MODULE_2___default()({}, _this.props.data, _helpers__WEBPACK_IMPORTED_MODULE_5__.store.data), _helpers__WEBPACK_IMPORTED_MODULE_5__.store.target);

            if (!_this.props.onClick || _this.props.preventCloseOnClick) return;

            (0,_actions__WEBPACK_IMPORTED_MODULE_3__.hideMenu)();
        };

        _this.handleMouseEnter = function () {
            if (_this.closetimer) clearTimeout(_this.closetimer);

            if (_this.props.disabled || _this.state.visible) return;

            _this.opentimer = setTimeout(function () {
                return _this.setState({
                    visible: true,
                    selectedItem: null
                });
            }, _this.props.hoverDelay);
        };

        _this.handleMouseLeave = function () {
            if (_this.opentimer) clearTimeout(_this.opentimer);

            if (!_this.state.visible) return;

            _this.closetimer = setTimeout(function () {
                return _this.setState({
                    visible: false,
                    selectedItem: null
                });
            }, _this.props.hoverDelay);
        };

        _this.menuRef = function (c) {
            _this.menu = c;
        };

        _this.subMenuRef = function (c) {
            _this.subMenu = c;
        };

        _this.registerHandlers = function () {
            document.removeEventListener('keydown', _this.props.parentKeyNavigationHandler);
            document.addEventListener('keydown', _this.handleKeyNavigation);
        };

        _this.unregisterHandlers = function (dismounting) {
            document.removeEventListener('keydown', _this.handleKeyNavigation);
            if (!dismounting) {
                document.addEventListener('keydown', _this.props.parentKeyNavigationHandler);
            }
        };

        _this.state = object_assign__WEBPACK_IMPORTED_MODULE_2___default()({}, _this.state, {
            visible: false
        });
        return _this;
    }

    _createClass(SubMenu, [{
        key: 'componentDidMount',
        value: function componentDidMount() {
            this.listenId = _globalEventListener__WEBPACK_IMPORTED_MODULE_6__["default"].register(function () {}, this.hideSubMenu);
        }
    }, {
        key: 'getSubMenuType',
        value: function getSubMenuType() {
            // eslint-disable-line class-methods-use-this
            return SubMenu;
        }
    }, {
        key: 'shouldComponentUpdate',
        value: function shouldComponentUpdate(nextProps, nextState) {
            this.isVisibilityChange = (this.state.visible !== nextState.visible || this.props.forceOpen !== nextProps.forceOpen) && !(this.state.visible && nextProps.forceOpen) && !(this.props.forceOpen && nextState.visible);
            return true;
        }
    }, {
        key: 'componentDidUpdate',
        value: function componentDidUpdate() {
            var _this2 = this;

            if (!this.isVisibilityChange) return;
            if (this.props.forceOpen || this.state.visible) {
                var wrapper = window.requestAnimationFrame || setTimeout;
                wrapper(function () {
                    var styles = _this2.props.rtl ? _this2.getRTLMenuPosition() : _this2.getMenuPosition();

                    _this2.subMenu.style.removeProperty('top');
                    _this2.subMenu.style.removeProperty('bottom');
                    _this2.subMenu.style.removeProperty('left');
                    _this2.subMenu.style.removeProperty('right');

                    if ((0,_helpers__WEBPACK_IMPORTED_MODULE_5__.hasOwnProp)(styles, 'top')) _this2.subMenu.style.top = styles.top;
                    if ((0,_helpers__WEBPACK_IMPORTED_MODULE_5__.hasOwnProp)(styles, 'left')) _this2.subMenu.style.left = styles.left;
                    if ((0,_helpers__WEBPACK_IMPORTED_MODULE_5__.hasOwnProp)(styles, 'bottom')) _this2.subMenu.style.bottom = styles.bottom;
                    if ((0,_helpers__WEBPACK_IMPORTED_MODULE_5__.hasOwnProp)(styles, 'right')) _this2.subMenu.style.right = styles.right;
                    _this2.subMenu.classList.add(_helpers__WEBPACK_IMPORTED_MODULE_5__.cssClasses.menuVisible);

                    _this2.registerHandlers();
                    _this2.setState({ selectedItem: null });
                });
            } else {
                var cleanup = function cleanup() {
                    _this2.subMenu.removeEventListener('transitionend', cleanup);
                    _this2.subMenu.style.removeProperty('bottom');
                    _this2.subMenu.style.removeProperty('right');
                    _this2.subMenu.style.top = 0;
                    _this2.subMenu.style.left = '100%';
                    _this2.unregisterHandlers();
                };
                this.subMenu.addEventListener('transitionend', cleanup);
                this.subMenu.classList.remove(_helpers__WEBPACK_IMPORTED_MODULE_5__.cssClasses.menuVisible);
            }
        }
    }, {
        key: 'componentWillUnmount',
        value: function componentWillUnmount() {
            if (this.listenId) {
                _globalEventListener__WEBPACK_IMPORTED_MODULE_6__["default"].unregister(this.listenId);
            }

            if (this.opentimer) clearTimeout(this.opentimer);

            if (this.closetimer) clearTimeout(this.closetimer);

            this.unregisterHandlers(true);
        }
    }, {
        key: 'render',
        value: function render() {
            var _cx;

            var _props = this.props,
                children = _props.children,
                attributes = _props.attributes,
                disabled = _props.disabled,
                title = _props.title,
                selected = _props.selected;
            var visible = this.state.visible;

            var menuProps = {
                ref: this.menuRef,
                onMouseEnter: this.handleMouseEnter,
                onMouseLeave: this.handleMouseLeave,
                className: classnames__WEBPACK_IMPORTED_MODULE_1___default()(_helpers__WEBPACK_IMPORTED_MODULE_5__.cssClasses.menuItem, _helpers__WEBPACK_IMPORTED_MODULE_5__.cssClasses.subMenu, attributes.listClassName),
                style: {
                    position: 'relative'
                }
            };
            var menuItemProps = {
                className: classnames__WEBPACK_IMPORTED_MODULE_1___default()(_helpers__WEBPACK_IMPORTED_MODULE_5__.cssClasses.menuItem, attributes.className, (_cx = {}, _defineProperty(_cx, classnames__WEBPACK_IMPORTED_MODULE_1___default()(_helpers__WEBPACK_IMPORTED_MODULE_5__.cssClasses.menuItemDisabled, attributes.disabledClassName), disabled), _defineProperty(_cx, classnames__WEBPACK_IMPORTED_MODULE_1___default()(_helpers__WEBPACK_IMPORTED_MODULE_5__.cssClasses.menuItemActive, attributes.visibleClassName), visible), _defineProperty(_cx, classnames__WEBPACK_IMPORTED_MODULE_1___default()(_helpers__WEBPACK_IMPORTED_MODULE_5__.cssClasses.menuItemSelected, attributes.selectedClassName), selected), _cx)),
                onMouseMove: this.props.onMouseMove,
                onMouseOut: this.props.onMouseOut,
                onClick: this.handleClick
            };
            var subMenuProps = {
                ref: this.subMenuRef,
                style: {
                    position: 'absolute',
                    transition: 'opacity 1ms', // trigger transitionend event
                    top: 0,
                    left: '100%'
                },
                className: classnames__WEBPACK_IMPORTED_MODULE_1___default()(_helpers__WEBPACK_IMPORTED_MODULE_5__.cssClasses.menu, this.props.className)
            };

            return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(
                'nav',
                _extends({}, menuProps, { role: 'menuitem', tabIndex: '-1', 'aria-haspopup': 'true' }),
                react__WEBPACK_IMPORTED_MODULE_0___default().createElement(
                    'div',
                    _extends({}, attributes, menuItemProps),
                    title
                ),
                react__WEBPACK_IMPORTED_MODULE_0___default().createElement(
                    'nav',
                    _extends({}, subMenuProps, { role: 'menu', tabIndex: '-1' }),
                    this.renderChildren(children)
                )
            );
        }
    }]);

    return SubMenu;
}(_AbstractMenu__WEBPACK_IMPORTED_MODULE_4__["default"]);

SubMenu.propTypes = {
    children: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().node.isRequired),
    attributes: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().object),
    title: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().node.isRequired),
    className: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().string),
    disabled: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
    hoverDelay: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),
    rtl: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
    selected: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
    onMouseMove: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    onMouseOut: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    forceOpen: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().bool),
    forceClose: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func),
    parentKeyNavigationHandler: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func)
};
SubMenu.defaultProps = {
    disabled: false,
    hoverDelay: 500,
    attributes: {},
    className: '',
    rtl: false,
    selected: false,
    onMouseMove: function onMouseMove() {
        return null;
    },
    onMouseOut: function onMouseOut() {
        return null;
    },
    forceOpen: false,
    forceClose: function forceClose() {
        return null;
    },
    parentKeyNavigationHandler: function parentKeyNavigationHandler() {
        return null;
    }
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (SubMenu);

/***/ }),

/***/ "../../node_modules/react-contextmenu/es6/actions.js":
/*!***********************************************************!*\
  !*** ../../node_modules/react-contextmenu/es6/actions.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "MENU_HIDE": () => (/* binding */ MENU_HIDE),
/* harmony export */   "MENU_SHOW": () => (/* binding */ MENU_SHOW),
/* harmony export */   "dispatchGlobalEvent": () => (/* binding */ dispatchGlobalEvent),
/* harmony export */   "hideMenu": () => (/* binding */ hideMenu),
/* harmony export */   "showMenu": () => (/* binding */ showMenu)
/* harmony export */ });
/* harmony import */ var object_assign__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! object-assign */ "../../node_modules/object-assign/index.js");
/* harmony import */ var object_assign__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(object_assign__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _helpers__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./helpers */ "../../node_modules/react-contextmenu/es6/helpers.js");




var MENU_SHOW = 'REACT_CONTEXTMENU_SHOW';
var MENU_HIDE = 'REACT_CONTEXTMENU_HIDE';

function dispatchGlobalEvent(eventName, opts) {
    var target = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : window;

    // Compatibale with IE
    // @see http://stackoverflow.com/questions/26596123/internet-explorer-9-10-11-event-constructor-doesnt-work
    var event = void 0;

    if (typeof window.CustomEvent === 'function') {
        event = new window.CustomEvent(eventName, { detail: opts });
    } else {
        event = document.createEvent('CustomEvent');
        event.initCustomEvent(eventName, false, true, opts);
    }

    if (target) {
        target.dispatchEvent(event);
        object_assign__WEBPACK_IMPORTED_MODULE_0___default()(_helpers__WEBPACK_IMPORTED_MODULE_1__.store, opts);
    }
}

function showMenu() {
    var opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var target = arguments[1];

    dispatchGlobalEvent(MENU_SHOW, object_assign__WEBPACK_IMPORTED_MODULE_0___default()({}, opts, { type: MENU_SHOW }), target);
}

function hideMenu() {
    var opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var target = arguments[1];

    dispatchGlobalEvent(MENU_HIDE, object_assign__WEBPACK_IMPORTED_MODULE_0___default()({}, opts, { type: MENU_HIDE }), target);
}

/***/ }),

/***/ "../../node_modules/react-contextmenu/es6/connectMenu.js":
/*!***************************************************************!*\
  !*** ../../node_modules/react-contextmenu/es6/connectMenu.js ***!
  \***************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* export default binding */ __WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _ContextMenuTrigger__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./ContextMenuTrigger */ "../../node_modules/react-contextmenu/es6/ContextMenuTrigger.js");
/* harmony import */ var _globalEventListener__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./globalEventListener */ "../../node_modules/react-contextmenu/es6/globalEventListener.js");
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }






// collect ContextMenuTrigger's expected props to NOT pass them on as part of the context
var ignoredTriggerProps = [].concat(_toConsumableArray(Object.keys(_ContextMenuTrigger__WEBPACK_IMPORTED_MODULE_1__["default"].propTypes)), ['children']);

// expect the id of the menu to be responsible for as outer parameter
/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(menuId) {
    // expect menu component to connect as inner parameter
    // <Child/> is presumably a wrapper of <ContextMenu/>
    return function connect(Child) {
        // return wrapper for <Child/> that forwards the ContextMenuTrigger's additional props
        return function (_Component) {
            _inherits(ConnectMenu, _Component);

            function ConnectMenu(props) {
                _classCallCheck(this, ConnectMenu);

                var _this = _possibleConstructorReturn(this, (ConnectMenu.__proto__ || Object.getPrototypeOf(ConnectMenu)).call(this, props));

                _this.handleShow = function (e) {
                    if (e.detail.id !== menuId) return;

                    // the onShow event's detail.data object holds all ContextMenuTrigger props
                    var data = e.detail.data;

                    var filteredData = {};

                    for (var key in data) {
                        // exclude props the ContextMenuTrigger is expecting itself
                        if (!ignoredTriggerProps.includes(key)) {
                            filteredData[key] = data[key];
                        }
                    }
                    _this.setState({ trigger: filteredData });
                };

                _this.handleHide = function () {
                    _this.setState({ trigger: null });
                };

                _this.state = { trigger: null };
                return _this;
            }

            _createClass(ConnectMenu, [{
                key: 'componentDidMount',
                value: function componentDidMount() {
                    this.listenId = _globalEventListener__WEBPACK_IMPORTED_MODULE_2__["default"].register(this.handleShow, this.handleHide);
                }
            }, {
                key: 'componentWillUnmount',
                value: function componentWillUnmount() {
                    if (this.listenId) {
                        _globalEventListener__WEBPACK_IMPORTED_MODULE_2__["default"].unregister(this.listenId);
                    }
                }
            }, {
                key: 'render',
                value: function render() {
                    return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Child, _extends({}, this.props, { id: menuId, trigger: this.state.trigger }));
                }
            }]);

            return ConnectMenu;
        }(react__WEBPACK_IMPORTED_MODULE_0__.Component);
    };
}

/***/ }),

/***/ "../../node_modules/react-contextmenu/es6/globalEventListener.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/react-contextmenu/es6/globalEventListener.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _actions__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./actions */ "../../node_modules/react-contextmenu/es6/actions.js");
/* harmony import */ var _helpers__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./helpers */ "../../node_modules/react-contextmenu/es6/helpers.js");
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }




var GlobalEventListener = function GlobalEventListener() {
    var _this = this;

    _classCallCheck(this, GlobalEventListener);

    this.handleShowEvent = function (event) {
        for (var id in _this.callbacks) {
            if ((0,_helpers__WEBPACK_IMPORTED_MODULE_1__.hasOwnProp)(_this.callbacks, id)) _this.callbacks[id].show(event);
        }
    };

    this.handleHideEvent = function (event) {
        for (var id in _this.callbacks) {
            if ((0,_helpers__WEBPACK_IMPORTED_MODULE_1__.hasOwnProp)(_this.callbacks, id)) _this.callbacks[id].hide(event);
        }
    };

    this.register = function (showCallback, hideCallback) {
        var id = (0,_helpers__WEBPACK_IMPORTED_MODULE_1__.uniqueId)();

        _this.callbacks[id] = {
            show: showCallback,
            hide: hideCallback
        };

        return id;
    };

    this.unregister = function (id) {
        if (id && _this.callbacks[id]) {
            delete _this.callbacks[id];
        }
    };

    this.callbacks = {};

    if (_helpers__WEBPACK_IMPORTED_MODULE_1__.canUseDOM) {
        window.addEventListener(_actions__WEBPACK_IMPORTED_MODULE_0__.MENU_SHOW, this.handleShowEvent);
        window.addEventListener(_actions__WEBPACK_IMPORTED_MODULE_0__.MENU_HIDE, this.handleHideEvent);
    }
};

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (new GlobalEventListener());

/***/ }),

/***/ "../../node_modules/react-contextmenu/es6/helpers.js":
/*!***********************************************************!*\
  !*** ../../node_modules/react-contextmenu/es6/helpers.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "callIfExists": () => (/* binding */ callIfExists),
/* harmony export */   "canUseDOM": () => (/* binding */ canUseDOM),
/* harmony export */   "cssClasses": () => (/* binding */ cssClasses),
/* harmony export */   "hasOwnProp": () => (/* binding */ hasOwnProp),
/* harmony export */   "store": () => (/* binding */ store),
/* harmony export */   "uniqueId": () => (/* binding */ uniqueId)
/* harmony export */ });
function callIfExists(func) {
    for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        args[_key - 1] = arguments[_key];
    }

    return typeof func === 'function' && func.apply(undefined, args);
}

function hasOwnProp(obj, prop) {
    return Object.prototype.hasOwnProperty.call(obj, prop);
}

function uniqueId() {
    return Math.random().toString(36).substring(7);
}

var cssClasses = {
    menu: 'react-contextmenu',
    menuVisible: 'react-contextmenu--visible',
    menuWrapper: 'react-contextmenu-wrapper',
    menuItem: 'react-contextmenu-item',
    menuItemActive: 'react-contextmenu-item--active',
    menuItemDisabled: 'react-contextmenu-item--disabled',
    menuItemDivider: 'react-contextmenu-item--divider',
    menuItemSelected: 'react-contextmenu-item--selected',
    subMenu: 'react-contextmenu-submenu'
};

var store = {};

var canUseDOM = Boolean(typeof window !== 'undefined' && window.document && window.document.createElement);

/***/ }),

/***/ "../../node_modules/react-contextmenu/es6/index.js":
/*!*********************************************************!*\
  !*** ../../node_modules/react-contextmenu/es6/index.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "ContextMenu": () => (/* reexport safe */ _ContextMenu__WEBPACK_IMPORTED_MODULE_0__["default"]),
/* harmony export */   "ContextMenuTrigger": () => (/* reexport safe */ _ContextMenuTrigger__WEBPACK_IMPORTED_MODULE_1__["default"]),
/* harmony export */   "MenuItem": () => (/* reexport safe */ _MenuItem__WEBPACK_IMPORTED_MODULE_2__["default"]),
/* harmony export */   "SubMenu": () => (/* reexport safe */ _SubMenu__WEBPACK_IMPORTED_MODULE_3__["default"]),
/* harmony export */   "connectMenu": () => (/* reexport safe */ _connectMenu__WEBPACK_IMPORTED_MODULE_4__["default"]),
/* harmony export */   "hideMenu": () => (/* reexport safe */ _actions__WEBPACK_IMPORTED_MODULE_5__.hideMenu),
/* harmony export */   "showMenu": () => (/* reexport safe */ _actions__WEBPACK_IMPORTED_MODULE_5__.showMenu)
/* harmony export */ });
/* harmony import */ var _ContextMenu__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./ContextMenu */ "../../node_modules/react-contextmenu/es6/ContextMenu.js");
/* harmony import */ var _ContextMenuTrigger__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./ContextMenuTrigger */ "../../node_modules/react-contextmenu/es6/ContextMenuTrigger.js");
/* harmony import */ var _MenuItem__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./MenuItem */ "../../node_modules/react-contextmenu/es6/MenuItem.js");
/* harmony import */ var _SubMenu__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./SubMenu */ "../../node_modules/react-contextmenu/es6/SubMenu.js");
/* harmony import */ var _connectMenu__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./connectMenu */ "../../node_modules/react-contextmenu/es6/connectMenu.js");
/* harmony import */ var _actions__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./actions */ "../../node_modules/react-contextmenu/es6/actions.js");







/***/ }),

/***/ "../../node_modules/react-draggable/build/cjs/Draggable.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/react-draggable/build/cjs/Draggable.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
Object.defineProperty(exports, "DraggableCore", ({
  enumerable: true,
  get: function get() {
    return _DraggableCore.default;
  }
}));
exports["default"] = void 0;

var React = _interopRequireWildcard(__webpack_require__(/*! react */ "webpack/sharing/consume/default/react"));

var _propTypes = _interopRequireDefault(__webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js"));

var _reactDom = _interopRequireDefault(__webpack_require__(/*! react-dom */ "webpack/sharing/consume/default/react-dom"));

var _clsx2 = _interopRequireDefault(__webpack_require__(/*! clsx */ "../../node_modules/clsx/dist/clsx.m.js"));

var _domFns = __webpack_require__(/*! ./utils/domFns */ "../../node_modules/react-draggable/build/cjs/utils/domFns.js");

var _positionFns = __webpack_require__(/*! ./utils/positionFns */ "../../node_modules/react-draggable/build/cjs/utils/positionFns.js");

var _shims = __webpack_require__(/*! ./utils/shims */ "../../node_modules/react-draggable/build/cjs/utils/shims.js");

var _DraggableCore = _interopRequireDefault(__webpack_require__(/*! ./DraggableCore */ "../../node_modules/react-draggable/build/cjs/DraggableCore.js"));

var _log = _interopRequireDefault(__webpack_require__(/*! ./utils/log */ "../../node_modules/react-draggable/build/cjs/utils/log.js"));

var _excluded = ["axis", "bounds", "children", "defaultPosition", "defaultClassName", "defaultClassNameDragging", "defaultClassNameDragged", "position", "positionOffset", "scale"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

//
// Define <Draggable>
//
var Draggable = /*#__PURE__*/function (_React$Component) {
  _inherits(Draggable, _React$Component);

  var _super = _createSuper(Draggable);

  function Draggable(props
  /*: DraggableProps*/
  ) {
    var _this;

    _classCallCheck(this, Draggable);

    _this = _super.call(this, props);

    _defineProperty(_assertThisInitialized(_this), "onDragStart", function (e, coreData) {
      (0, _log.default)('Draggable: onDragStart: %j', coreData); // Short-circuit if user's callback killed it.

      var shouldStart = _this.props.onStart(e, (0, _positionFns.createDraggableData)(_assertThisInitialized(_this), coreData)); // Kills start event on core as well, so move handlers are never bound.


      if (shouldStart === false) return false;

      _this.setState({
        dragging: true,
        dragged: true
      });
    });

    _defineProperty(_assertThisInitialized(_this), "onDrag", function (e, coreData) {
      if (!_this.state.dragging) return false;
      (0, _log.default)('Draggable: onDrag: %j', coreData);
      var uiData = (0, _positionFns.createDraggableData)(_assertThisInitialized(_this), coreData);
      var newState
      /*: $Shape<DraggableState>*/
      = {
        x: uiData.x,
        y: uiData.y
      }; // Keep within bounds.

      if (_this.props.bounds) {
        // Save original x and y.
        var x = newState.x,
            y = newState.y; // Add slack to the values used to calculate bound position. This will ensure that if
        // we start removing slack, the element won't react to it right away until it's been
        // completely removed.

        newState.x += _this.state.slackX;
        newState.y += _this.state.slackY; // Get bound position. This will ceil/floor the x and y within the boundaries.

        var _getBoundPosition = (0, _positionFns.getBoundPosition)(_assertThisInitialized(_this), newState.x, newState.y),
            _getBoundPosition2 = _slicedToArray(_getBoundPosition, 2),
            newStateX = _getBoundPosition2[0],
            newStateY = _getBoundPosition2[1];

        newState.x = newStateX;
        newState.y = newStateY; // Recalculate slack by noting how much was shaved by the boundPosition handler.

        newState.slackX = _this.state.slackX + (x - newState.x);
        newState.slackY = _this.state.slackY + (y - newState.y); // Update the event we fire to reflect what really happened after bounds took effect.

        uiData.x = newState.x;
        uiData.y = newState.y;
        uiData.deltaX = newState.x - _this.state.x;
        uiData.deltaY = newState.y - _this.state.y;
      } // Short-circuit if user's callback killed it.


      var shouldUpdate = _this.props.onDrag(e, uiData);

      if (shouldUpdate === false) return false;

      _this.setState(newState);
    });

    _defineProperty(_assertThisInitialized(_this), "onDragStop", function (e, coreData) {
      if (!_this.state.dragging) return false; // Short-circuit if user's callback killed it.

      var shouldContinue = _this.props.onStop(e, (0, _positionFns.createDraggableData)(_assertThisInitialized(_this), coreData));

      if (shouldContinue === false) return false;
      (0, _log.default)('Draggable: onDragStop: %j', coreData);
      var newState
      /*: $Shape<DraggableState>*/
      = {
        dragging: false,
        slackX: 0,
        slackY: 0
      }; // If this is a controlled component, the result of this operation will be to
      // revert back to the old position. We expect a handler on `onDragStop`, at the least.

      var controlled = Boolean(_this.props.position);

      if (controlled) {
        var _this$props$position = _this.props.position,
            x = _this$props$position.x,
            y = _this$props$position.y;
        newState.x = x;
        newState.y = y;
      }

      _this.setState(newState);
    });

    _this.state = {
      // Whether or not we are currently dragging.
      dragging: false,
      // Whether or not we have been dragged before.
      dragged: false,
      // Current transform x and y.
      x: props.position ? props.position.x : props.defaultPosition.x,
      y: props.position ? props.position.y : props.defaultPosition.y,
      prevPropsPosition: _objectSpread({}, props.position),
      // Used for compensating for out-of-bounds drags
      slackX: 0,
      slackY: 0,
      // Can only determine if SVG after mounting
      isElementSVG: false
    };

    if (props.position && !(props.onDrag || props.onStop)) {
      // eslint-disable-next-line no-console
      console.warn('A `position` was applied to this <Draggable>, without drag handlers. This will make this ' + 'component effectively undraggable. Please attach `onDrag` or `onStop` handlers so you can adjust the ' + '`position` of this element.');
    }

    return _this;
  }

  _createClass(Draggable, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      // Check to see if the element passed is an instanceof SVGElement
      if (typeof window.SVGElement !== 'undefined' && this.findDOMNode() instanceof window.SVGElement) {
        this.setState({
          isElementSVG: true
        });
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.setState({
        dragging: false
      }); // prevents invariant if unmounted while dragging
    } // React Strict Mode compatibility: if `nodeRef` is passed, we will use it instead of trying to find
    // the underlying DOM node ourselves. See the README for more information.

  }, {
    key: "findDOMNode",
    value: function findDOMNode()
    /*: ?HTMLElement*/
    {
      var _this$props$nodeRef$c, _this$props, _this$props$nodeRef;

      return (_this$props$nodeRef$c = (_this$props = this.props) === null || _this$props === void 0 ? void 0 : (_this$props$nodeRef = _this$props.nodeRef) === null || _this$props$nodeRef === void 0 ? void 0 : _this$props$nodeRef.current) !== null && _this$props$nodeRef$c !== void 0 ? _this$props$nodeRef$c : _reactDom.default.findDOMNode(this);
    }
  }, {
    key: "render",
    value: function render()
    /*: ReactElement<any>*/
    {
      var _clsx;

      var _this$props2 = this.props,
          axis = _this$props2.axis,
          bounds = _this$props2.bounds,
          children = _this$props2.children,
          defaultPosition = _this$props2.defaultPosition,
          defaultClassName = _this$props2.defaultClassName,
          defaultClassNameDragging = _this$props2.defaultClassNameDragging,
          defaultClassNameDragged = _this$props2.defaultClassNameDragged,
          position = _this$props2.position,
          positionOffset = _this$props2.positionOffset,
          scale = _this$props2.scale,
          draggableCoreProps = _objectWithoutProperties(_this$props2, _excluded);

      var style = {};
      var svgTransform = null; // If this is controlled, we don't want to move it - unless it's dragging.

      var controlled = Boolean(position);
      var draggable = !controlled || this.state.dragging;
      var validPosition = position || defaultPosition;
      var transformOpts = {
        // Set left if horizontal drag is enabled
        x: (0, _positionFns.canDragX)(this) && draggable ? this.state.x : validPosition.x,
        // Set top if vertical drag is enabled
        y: (0, _positionFns.canDragY)(this) && draggable ? this.state.y : validPosition.y
      }; // If this element was SVG, we use the `transform` attribute.

      if (this.state.isElementSVG) {
        svgTransform = (0, _domFns.createSVGTransform)(transformOpts, positionOffset);
      } else {
        // Add a CSS transform to move the element around. This allows us to move the element around
        // without worrying about whether or not it is relatively or absolutely positioned.
        // If the item you are dragging already has a transform set, wrap it in a <span> so <Draggable>
        // has a clean slate.
        style = (0, _domFns.createCSSTransform)(transformOpts, positionOffset);
      } // Mark with class while dragging


      var className = (0, _clsx2.default)(children.props.className || '', defaultClassName, (_clsx = {}, _defineProperty(_clsx, defaultClassNameDragging, this.state.dragging), _defineProperty(_clsx, defaultClassNameDragged, this.state.dragged), _clsx)); // Reuse the child provided
      // This makes it flexible to use whatever element is wanted (div, ul, etc)

      return /*#__PURE__*/React.createElement(_DraggableCore.default, _extends({}, draggableCoreProps, {
        onStart: this.onDragStart,
        onDrag: this.onDrag,
        onStop: this.onDragStop
      }), /*#__PURE__*/React.cloneElement(React.Children.only(children), {
        className: className,
        style: _objectSpread(_objectSpread({}, children.props.style), style),
        transform: svgTransform
      }));
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: // React 16.3+
    // Arity (props, state)
    function getDerivedStateFromProps(_ref, _ref2)
    /*: ?$Shape<DraggableState>*/
    {
      var position = _ref.position;
      var prevPropsPosition = _ref2.prevPropsPosition;

      // Set x/y if a new position is provided in props that is different than the previous.
      if (position && (!prevPropsPosition || position.x !== prevPropsPosition.x || position.y !== prevPropsPosition.y)) {
        (0, _log.default)('Draggable: getDerivedStateFromProps %j', {
          position: position,
          prevPropsPosition: prevPropsPosition
        });
        return {
          x: position.x,
          y: position.y,
          prevPropsPosition: _objectSpread({}, position)
        };
      }

      return null;
    }
  }]);

  return Draggable;
}(React.Component);

exports["default"] = Draggable;

_defineProperty(Draggable, "displayName", 'Draggable');

_defineProperty(Draggable, "propTypes", _objectSpread(_objectSpread({}, _DraggableCore.default.propTypes), {}, {
  /**
   * `axis` determines which axis the draggable can move.
   *
   *  Note that all callbacks will still return data as normal. This only
   *  controls flushing to the DOM.
   *
   * 'both' allows movement horizontally and vertically.
   * 'x' limits movement to horizontal axis.
   * 'y' limits movement to vertical axis.
   * 'none' limits all movement.
   *
   * Defaults to 'both'.
   */
  axis: _propTypes.default.oneOf(['both', 'x', 'y', 'none']),

  /**
   * `bounds` determines the range of movement available to the element.
   * Available values are:
   *
   * 'parent' restricts movement within the Draggable's parent node.
   *
   * Alternatively, pass an object with the following properties, all of which are optional:
   *
   * {left: LEFT_BOUND, right: RIGHT_BOUND, bottom: BOTTOM_BOUND, top: TOP_BOUND}
   *
   * All values are in px.
   *
   * Example:
   *
   * ```jsx
   *   let App = React.createClass({
   *       render: function () {
   *         return (
   *            <Draggable bounds={{right: 300, bottom: 300}}>
   *              <div>Content</div>
   *           </Draggable>
   *         );
   *       }
   *   });
   * ```
   */
  bounds: _propTypes.default.oneOfType([_propTypes.default.shape({
    left: _propTypes.default.number,
    right: _propTypes.default.number,
    top: _propTypes.default.number,
    bottom: _propTypes.default.number
  }), _propTypes.default.string, _propTypes.default.oneOf([false])]),
  defaultClassName: _propTypes.default.string,
  defaultClassNameDragging: _propTypes.default.string,
  defaultClassNameDragged: _propTypes.default.string,

  /**
   * `defaultPosition` specifies the x and y that the dragged item should start at
   *
   * Example:
   *
   * ```jsx
   *      let App = React.createClass({
   *          render: function () {
   *              return (
   *                  <Draggable defaultPosition={{x: 25, y: 25}}>
   *                      <div>I start with transformX: 25px and transformY: 25px;</div>
   *                  </Draggable>
   *              );
   *          }
   *      });
   * ```
   */
  defaultPosition: _propTypes.default.shape({
    x: _propTypes.default.number,
    y: _propTypes.default.number
  }),
  positionOffset: _propTypes.default.shape({
    x: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.string]),
    y: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.string])
  }),

  /**
   * `position`, if present, defines the current position of the element.
   *
   *  This is similar to how form elements in React work - if no `position` is supplied, the component
   *  is uncontrolled.
   *
   * Example:
   *
   * ```jsx
   *      let App = React.createClass({
   *          render: function () {
   *              return (
   *                  <Draggable position={{x: 25, y: 25}}>
   *                      <div>I start with transformX: 25px and transformY: 25px;</div>
   *                  </Draggable>
   *              );
   *          }
   *      });
   * ```
   */
  position: _propTypes.default.shape({
    x: _propTypes.default.number,
    y: _propTypes.default.number
  }),

  /**
   * These properties should be defined on the child, not here.
   */
  className: _shims.dontSetMe,
  style: _shims.dontSetMe,
  transform: _shims.dontSetMe
}));

_defineProperty(Draggable, "defaultProps", _objectSpread(_objectSpread({}, _DraggableCore.default.defaultProps), {}, {
  axis: 'both',
  bounds: false,
  defaultClassName: 'react-draggable',
  defaultClassNameDragging: 'react-draggable-dragging',
  defaultClassNameDragged: 'react-draggable-dragged',
  defaultPosition: {
    x: 0,
    y: 0
  },
  scale: 1
}));

/***/ }),

/***/ "../../node_modules/react-draggable/build/cjs/DraggableCore.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/react-draggable/build/cjs/DraggableCore.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var React = _interopRequireWildcard(__webpack_require__(/*! react */ "webpack/sharing/consume/default/react"));

var _propTypes = _interopRequireDefault(__webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js"));

var _reactDom = _interopRequireDefault(__webpack_require__(/*! react-dom */ "webpack/sharing/consume/default/react-dom"));

var _domFns = __webpack_require__(/*! ./utils/domFns */ "../../node_modules/react-draggable/build/cjs/utils/domFns.js");

var _positionFns = __webpack_require__(/*! ./utils/positionFns */ "../../node_modules/react-draggable/build/cjs/utils/positionFns.js");

var _shims = __webpack_require__(/*! ./utils/shims */ "../../node_modules/react-draggable/build/cjs/utils/shims.js");

var _log = _interopRequireDefault(__webpack_require__(/*! ./utils/log */ "../../node_modules/react-draggable/build/cjs/utils/log.js"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

// Simple abstraction for dragging events names.
var eventsFor = {
  touch: {
    start: 'touchstart',
    move: 'touchmove',
    stop: 'touchend'
  },
  mouse: {
    start: 'mousedown',
    move: 'mousemove',
    stop: 'mouseup'
  }
}; // Default to mouse events.

var dragEventFor = eventsFor.mouse;
/*:: type DraggableCoreState = {
  dragging: boolean,
  lastX: number,
  lastY: number,
  touchIdentifier: ?number
};*/

/*:: export type DraggableData = {
  node: HTMLElement,
  x: number, y: number,
  deltaX: number, deltaY: number,
  lastX: number, lastY: number,
};*/

/*:: export type DraggableEventHandler = (e: MouseEvent, data: DraggableData) => void | false;*/

/*:: export type ControlPosition = {x: number, y: number};*/

/*:: export type PositionOffsetControlPosition = {x: number|string, y: number|string};*/

/*:: export type DraggableCoreDefaultProps = {
  allowAnyClick: boolean,
  disabled: boolean,
  enableUserSelectHack: boolean,
  onStart: DraggableEventHandler,
  onDrag: DraggableEventHandler,
  onStop: DraggableEventHandler,
  onMouseDown: (e: MouseEvent) => void,
  scale: number,
};*/

/*:: export type DraggableCoreProps = {
  ...DraggableCoreDefaultProps,
  cancel: string,
  children: ReactElement<any>,
  offsetParent: HTMLElement,
  grid: [number, number],
  handle: string,
  nodeRef?: ?React.ElementRef<any>,
};*/

//
// Define <DraggableCore>.
//
// <DraggableCore> is for advanced usage of <Draggable>. It maintains minimal internal state so it can
// work well with libraries that require more control over the element.
//
var DraggableCore = /*#__PURE__*/function (_React$Component) {
  _inherits(DraggableCore, _React$Component);

  var _super = _createSuper(DraggableCore);

  function DraggableCore() {
    var _this;

    _classCallCheck(this, DraggableCore);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _super.call.apply(_super, [this].concat(args));

    _defineProperty(_assertThisInitialized(_this), "state", {
      dragging: false,
      // Used while dragging to determine deltas.
      lastX: NaN,
      lastY: NaN,
      touchIdentifier: null
    });

    _defineProperty(_assertThisInitialized(_this), "mounted", false);

    _defineProperty(_assertThisInitialized(_this), "handleDragStart", function (e) {
      // Make it possible to attach event handlers on top of this one.
      _this.props.onMouseDown(e); // Only accept left-clicks.


      if (!_this.props.allowAnyClick && typeof e.button === 'number' && e.button !== 0) return false; // Get nodes. Be sure to grab relative document (could be iframed)

      var thisNode = _this.findDOMNode();

      if (!thisNode || !thisNode.ownerDocument || !thisNode.ownerDocument.body) {
        throw new Error('<DraggableCore> not mounted on DragStart!');
      }

      var ownerDocument = thisNode.ownerDocument; // Short circuit if handle or cancel prop was provided and selector doesn't match.

      if (_this.props.disabled || !(e.target instanceof ownerDocument.defaultView.Node) || _this.props.handle && !(0, _domFns.matchesSelectorAndParentsTo)(e.target, _this.props.handle, thisNode) || _this.props.cancel && (0, _domFns.matchesSelectorAndParentsTo)(e.target, _this.props.cancel, thisNode)) {
        return;
      } // Prevent scrolling on mobile devices, like ipad/iphone.
      // Important that this is after handle/cancel.


      if (e.type === 'touchstart') e.preventDefault(); // Set touch identifier in component state if this is a touch event. This allows us to
      // distinguish between individual touches on multitouch screens by identifying which
      // touchpoint was set to this element.

      var touchIdentifier = (0, _domFns.getTouchIdentifier)(e);

      _this.setState({
        touchIdentifier: touchIdentifier
      }); // Get the current drag point from the event. This is used as the offset.


      var position = (0, _positionFns.getControlPosition)(e, touchIdentifier, _assertThisInitialized(_this));
      if (position == null) return; // not possible but satisfies flow

      var x = position.x,
          y = position.y; // Create an event object with all the data parents need to make a decision here.

      var coreEvent = (0, _positionFns.createCoreData)(_assertThisInitialized(_this), x, y);
      (0, _log.default)('DraggableCore: handleDragStart: %j', coreEvent); // Call event handler. If it returns explicit false, cancel.

      (0, _log.default)('calling', _this.props.onStart);

      var shouldUpdate = _this.props.onStart(e, coreEvent);

      if (shouldUpdate === false || _this.mounted === false) return; // Add a style to the body to disable user-select. This prevents text from
      // being selected all over the page.

      if (_this.props.enableUserSelectHack) (0, _domFns.addUserSelectStyles)(ownerDocument); // Initiate dragging. Set the current x and y as offsets
      // so we know how much we've moved during the drag. This allows us
      // to drag elements around even if they have been moved, without issue.

      _this.setState({
        dragging: true,
        lastX: x,
        lastY: y
      }); // Add events to the document directly so we catch when the user's mouse/touch moves outside of
      // this element. We use different events depending on whether or not we have detected that this
      // is a touch-capable device.


      (0, _domFns.addEvent)(ownerDocument, dragEventFor.move, _this.handleDrag);
      (0, _domFns.addEvent)(ownerDocument, dragEventFor.stop, _this.handleDragStop);
    });

    _defineProperty(_assertThisInitialized(_this), "handleDrag", function (e) {
      // Get the current drag point from the event. This is used as the offset.
      var position = (0, _positionFns.getControlPosition)(e, _this.state.touchIdentifier, _assertThisInitialized(_this));
      if (position == null) return;
      var x = position.x,
          y = position.y; // Snap to grid if prop has been provided

      if (Array.isArray(_this.props.grid)) {
        var deltaX = x - _this.state.lastX,
            deltaY = y - _this.state.lastY;

        var _snapToGrid = (0, _positionFns.snapToGrid)(_this.props.grid, deltaX, deltaY);

        var _snapToGrid2 = _slicedToArray(_snapToGrid, 2);

        deltaX = _snapToGrid2[0];
        deltaY = _snapToGrid2[1];
        if (!deltaX && !deltaY) return; // skip useless drag

        x = _this.state.lastX + deltaX, y = _this.state.lastY + deltaY;
      }

      var coreEvent = (0, _positionFns.createCoreData)(_assertThisInitialized(_this), x, y);
      (0, _log.default)('DraggableCore: handleDrag: %j', coreEvent); // Call event handler. If it returns explicit false, trigger end.

      var shouldUpdate = _this.props.onDrag(e, coreEvent);

      if (shouldUpdate === false || _this.mounted === false) {
        try {
          // $FlowIgnore
          _this.handleDragStop(new MouseEvent('mouseup'));
        } catch (err) {
          // Old browsers
          var event = ((document.createEvent('MouseEvents')
          /*: any*/
          )
          /*: MouseTouchEvent*/
          ); // I see why this insanity was deprecated
          // $FlowIgnore

          event.initMouseEvent('mouseup', true, true, window, 0, 0, 0, 0, 0, false, false, false, false, 0, null);

          _this.handleDragStop(event);
        }

        return;
      }

      _this.setState({
        lastX: x,
        lastY: y
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleDragStop", function (e) {
      if (!_this.state.dragging) return;
      var position = (0, _positionFns.getControlPosition)(e, _this.state.touchIdentifier, _assertThisInitialized(_this));
      if (position == null) return;
      var x = position.x,
          y = position.y; // Snap to grid if prop has been provided

      if (Array.isArray(_this.props.grid)) {
        var deltaX = x - _this.state.lastX || 0;
        var deltaY = y - _this.state.lastY || 0;

        var _snapToGrid3 = (0, _positionFns.snapToGrid)(_this.props.grid, deltaX, deltaY);

        var _snapToGrid4 = _slicedToArray(_snapToGrid3, 2);

        deltaX = _snapToGrid4[0];
        deltaY = _snapToGrid4[1];
        x = _this.state.lastX + deltaX, y = _this.state.lastY + deltaY;
      }

      var coreEvent = (0, _positionFns.createCoreData)(_assertThisInitialized(_this), x, y); // Call event handler

      var shouldContinue = _this.props.onStop(e, coreEvent);

      if (shouldContinue === false || _this.mounted === false) return false;

      var thisNode = _this.findDOMNode();

      if (thisNode) {
        // Remove user-select hack
        if (_this.props.enableUserSelectHack) (0, _domFns.removeUserSelectStyles)(thisNode.ownerDocument);
      }

      (0, _log.default)('DraggableCore: handleDragStop: %j', coreEvent); // Reset the el.

      _this.setState({
        dragging: false,
        lastX: NaN,
        lastY: NaN
      });

      if (thisNode) {
        // Remove event handlers
        (0, _log.default)('DraggableCore: Removing handlers');
        (0, _domFns.removeEvent)(thisNode.ownerDocument, dragEventFor.move, _this.handleDrag);
        (0, _domFns.removeEvent)(thisNode.ownerDocument, dragEventFor.stop, _this.handleDragStop);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "onMouseDown", function (e) {
      dragEventFor = eventsFor.mouse; // on touchscreen laptops we could switch back to mouse

      return _this.handleDragStart(e);
    });

    _defineProperty(_assertThisInitialized(_this), "onMouseUp", function (e) {
      dragEventFor = eventsFor.mouse;
      return _this.handleDragStop(e);
    });

    _defineProperty(_assertThisInitialized(_this), "onTouchStart", function (e) {
      // We're on a touch device now, so change the event handlers
      dragEventFor = eventsFor.touch;
      return _this.handleDragStart(e);
    });

    _defineProperty(_assertThisInitialized(_this), "onTouchEnd", function (e) {
      // We're on a touch device now, so change the event handlers
      dragEventFor = eventsFor.touch;
      return _this.handleDragStop(e);
    });

    return _this;
  }

  _createClass(DraggableCore, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.mounted = true; // Touch handlers must be added with {passive: false} to be cancelable.
      // https://developers.google.com/web/updates/2017/01/scrolling-intervention

      var thisNode = this.findDOMNode();

      if (thisNode) {
        (0, _domFns.addEvent)(thisNode, eventsFor.touch.start, this.onTouchStart, {
          passive: false
        });
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.mounted = false; // Remove any leftover event handlers. Remove both touch and mouse handlers in case
      // some browser quirk caused a touch event to fire during a mouse move, or vice versa.

      var thisNode = this.findDOMNode();

      if (thisNode) {
        var ownerDocument = thisNode.ownerDocument;
        (0, _domFns.removeEvent)(ownerDocument, eventsFor.mouse.move, this.handleDrag);
        (0, _domFns.removeEvent)(ownerDocument, eventsFor.touch.move, this.handleDrag);
        (0, _domFns.removeEvent)(ownerDocument, eventsFor.mouse.stop, this.handleDragStop);
        (0, _domFns.removeEvent)(ownerDocument, eventsFor.touch.stop, this.handleDragStop);
        (0, _domFns.removeEvent)(thisNode, eventsFor.touch.start, this.onTouchStart, {
          passive: false
        });
        if (this.props.enableUserSelectHack) (0, _domFns.removeUserSelectStyles)(ownerDocument);
      }
    } // React Strict Mode compatibility: if `nodeRef` is passed, we will use it instead of trying to find
    // the underlying DOM node ourselves. See the README for more information.

  }, {
    key: "findDOMNode",
    value: function findDOMNode()
    /*: ?HTMLElement*/
    {
      var _this$props, _this$props2, _this$props2$nodeRef;

      return (_this$props = this.props) !== null && _this$props !== void 0 && _this$props.nodeRef ? (_this$props2 = this.props) === null || _this$props2 === void 0 ? void 0 : (_this$props2$nodeRef = _this$props2.nodeRef) === null || _this$props2$nodeRef === void 0 ? void 0 : _this$props2$nodeRef.current : _reactDom.default.findDOMNode(this);
    }
  }, {
    key: "render",
    value: function render()
    /*: React.Element<any>*/
    {
      // Reuse the child provided
      // This makes it flexible to use whatever element is wanted (div, ul, etc)
      return /*#__PURE__*/React.cloneElement(React.Children.only(this.props.children), {
        // Note: mouseMove handler is attached to document so it will still function
        // when the user drags quickly and leaves the bounds of the element.
        onMouseDown: this.onMouseDown,
        onMouseUp: this.onMouseUp,
        // onTouchStart is added on `componentDidMount` so they can be added with
        // {passive: false}, which allows it to cancel. See
        // https://developers.google.com/web/updates/2017/01/scrolling-intervention
        onTouchEnd: this.onTouchEnd
      });
    }
  }]);

  return DraggableCore;
}(React.Component);

exports["default"] = DraggableCore;

_defineProperty(DraggableCore, "displayName", 'DraggableCore');

_defineProperty(DraggableCore, "propTypes", {
  /**
   * `allowAnyClick` allows dragging using any mouse button.
   * By default, we only accept the left button.
   *
   * Defaults to `false`.
   */
  allowAnyClick: _propTypes.default.bool,

  /**
   * `disabled`, if true, stops the <Draggable> from dragging. All handlers,
   * with the exception of `onMouseDown`, will not fire.
   */
  disabled: _propTypes.default.bool,

  /**
   * By default, we add 'user-select:none' attributes to the document body
   * to prevent ugly text selection during drag. If this is causing problems
   * for your app, set this to `false`.
   */
  enableUserSelectHack: _propTypes.default.bool,

  /**
   * `offsetParent`, if set, uses the passed DOM node to compute drag offsets
   * instead of using the parent node.
   */
  offsetParent: function offsetParent(props
  /*: DraggableCoreProps*/
  , propName
  /*: $Keys<DraggableCoreProps>*/
  ) {
    if (props[propName] && props[propName].nodeType !== 1) {
      throw new Error('Draggable\'s offsetParent must be a DOM Node.');
    }
  },

  /**
   * `grid` specifies the x and y that dragging should snap to.
   */
  grid: _propTypes.default.arrayOf(_propTypes.default.number),

  /**
   * `handle` specifies a selector to be used as the handle that initiates drag.
   *
   * Example:
   *
   * ```jsx
   *   let App = React.createClass({
   *       render: function () {
   *         return (
   *            <Draggable handle=".handle">
   *              <div>
   *                  <div className="handle">Click me to drag</div>
   *                  <div>This is some other content</div>
   *              </div>
   *           </Draggable>
   *         );
   *       }
   *   });
   * ```
   */
  handle: _propTypes.default.string,

  /**
   * `cancel` specifies a selector to be used to prevent drag initialization.
   *
   * Example:
   *
   * ```jsx
   *   let App = React.createClass({
   *       render: function () {
   *           return(
   *               <Draggable cancel=".cancel">
   *                   <div>
   *                     <div className="cancel">You can't drag from here</div>
   *                     <div>Dragging here works fine</div>
   *                   </div>
   *               </Draggable>
   *           );
   *       }
   *   });
   * ```
   */
  cancel: _propTypes.default.string,

  /* If running in React Strict mode, ReactDOM.findDOMNode() is deprecated.
   * Unfortunately, in order for <Draggable> to work properly, we need raw access
   * to the underlying DOM node. If you want to avoid the warning, pass a `nodeRef`
   * as in this example:
   *
   * function MyComponent() {
   *   const nodeRef = React.useRef(null);
   *   return (
   *     <Draggable nodeRef={nodeRef}>
   *       <div ref={nodeRef}>Example Target</div>
   *     </Draggable>
   *   );
   * }
   *
   * This can be used for arbitrarily nested components, so long as the ref ends up
   * pointing to the actual child DOM node and not a custom component.
   */
  nodeRef: _propTypes.default.object,

  /**
   * Called when dragging starts.
   * If this function returns the boolean false, dragging will be canceled.
   */
  onStart: _propTypes.default.func,

  /**
   * Called while dragging.
   * If this function returns the boolean false, dragging will be canceled.
   */
  onDrag: _propTypes.default.func,

  /**
   * Called when dragging stops.
   * If this function returns the boolean false, the drag will remain active.
   */
  onStop: _propTypes.default.func,

  /**
   * A workaround option which can be passed if onMouseDown needs to be accessed,
   * since it'll always be blocked (as there is internal use of onMouseDown)
   */
  onMouseDown: _propTypes.default.func,

  /**
   * `scale`, if set, applies scaling while dragging an element
   */
  scale: _propTypes.default.number,

  /**
   * These properties should be defined on the child, not here.
   */
  className: _shims.dontSetMe,
  style: _shims.dontSetMe,
  transform: _shims.dontSetMe
});

_defineProperty(DraggableCore, "defaultProps", {
  allowAnyClick: false,
  // by default only accept left click
  disabled: false,
  enableUserSelectHack: true,
  onStart: function onStart() {},
  onDrag: function onDrag() {},
  onStop: function onStop() {},
  onMouseDown: function onMouseDown() {},
  scale: 1
});

/***/ }),

/***/ "../../node_modules/react-draggable/build/cjs/cjs.js":
/*!***********************************************************!*\
  !*** ../../node_modules/react-draggable/build/cjs/cjs.js ***!
  \***********************************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

"use strict";


var _require = __webpack_require__(/*! ./Draggable */ "../../node_modules/react-draggable/build/cjs/Draggable.js"),
    Draggable = _require.default,
    DraggableCore = _require.DraggableCore; // Previous versions of this lib exported <Draggable> as the root export. As to no-// them, or TypeScript, we export *both* as the root and as 'default'.
// See https://github.com/mzabriskie/react-draggable/pull/254
// and https://github.com/mzabriskie/react-draggable/issues/266


module.exports = Draggable;
module.exports["default"] = Draggable;
module.exports.DraggableCore = DraggableCore;

/***/ }),

/***/ "../../node_modules/react-draggable/build/cjs/utils/domFns.js":
/*!********************************************************************!*\
  !*** ../../node_modules/react-draggable/build/cjs/utils/domFns.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports.addClassName = addClassName;
exports.addEvent = addEvent;
exports.addUserSelectStyles = addUserSelectStyles;
exports.createCSSTransform = createCSSTransform;
exports.createSVGTransform = createSVGTransform;
exports.getTouch = getTouch;
exports.getTouchIdentifier = getTouchIdentifier;
exports.getTranslation = getTranslation;
exports.innerHeight = innerHeight;
exports.innerWidth = innerWidth;
exports.matchesSelector = matchesSelector;
exports.matchesSelectorAndParentsTo = matchesSelectorAndParentsTo;
exports.offsetXYFromParent = offsetXYFromParent;
exports.outerHeight = outerHeight;
exports.outerWidth = outerWidth;
exports.removeClassName = removeClassName;
exports.removeEvent = removeEvent;
exports.removeUserSelectStyles = removeUserSelectStyles;

var _shims = __webpack_require__(/*! ./shims */ "../../node_modules/react-draggable/build/cjs/utils/shims.js");

var _getPrefix = _interopRequireWildcard(__webpack_require__(/*! ./getPrefix */ "../../node_modules/react-draggable/build/cjs/utils/getPrefix.js"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var matchesSelectorFunc = '';

function matchesSelector(el
/*: Node*/
, selector
/*: string*/
)
/*: boolean*/
{
  if (!matchesSelectorFunc) {
    matchesSelectorFunc = (0, _shims.findInArray)(['matches', 'webkitMatchesSelector', 'mozMatchesSelector', 'msMatchesSelector', 'oMatchesSelector'], function (method) {
      // $FlowIgnore: Doesn't think elements are indexable
      return (0, _shims.isFunction)(el[method]);
    });
  } // Might not be found entirely (not an Element?) - in that case, bail
  // $FlowIgnore: Doesn't think elements are indexable


  if (!(0, _shims.isFunction)(el[matchesSelectorFunc])) return false; // $FlowIgnore: Doesn't think elements are indexable

  return el[matchesSelectorFunc](selector);
} // Works up the tree to the draggable itself attempting to match selector.


function matchesSelectorAndParentsTo(el
/*: Node*/
, selector
/*: string*/
, baseNode
/*: Node*/
)
/*: boolean*/
{
  var node = el;

  do {
    if (matchesSelector(node, selector)) return true;
    if (node === baseNode) return false;
    node = node.parentNode;
  } while (node);

  return false;
}

function addEvent(el
/*: ?Node*/
, event
/*: string*/
, handler
/*: Function*/
, inputOptions
/*: Object*/
)
/*: void*/
{
  if (!el) return;

  var options = _objectSpread({
    capture: true
  }, inputOptions); // $FlowIgnore[method-unbinding]


  if (el.addEventListener) {
    el.addEventListener(event, handler, options);
  } else if (el.attachEvent) {
    el.attachEvent('on' + event, handler);
  } else {
    // $FlowIgnore: Doesn't think elements are indexable
    el['on' + event] = handler;
  }
}

function removeEvent(el
/*: ?Node*/
, event
/*: string*/
, handler
/*: Function*/
, inputOptions
/*: Object*/
)
/*: void*/
{
  if (!el) return;

  var options = _objectSpread({
    capture: true
  }, inputOptions); // $FlowIgnore[method-unbinding]


  if (el.removeEventListener) {
    el.removeEventListener(event, handler, options);
  } else if (el.detachEvent) {
    el.detachEvent('on' + event, handler);
  } else {
    // $FlowIgnore: Doesn't think elements are indexable
    el['on' + event] = null;
  }
}

function outerHeight(node
/*: HTMLElement*/
)
/*: number*/
{
  // This is deliberately excluding margin for our calculations, since we are using
  // offsetTop which is including margin. See getBoundPosition
  var height = node.clientHeight;
  var computedStyle = node.ownerDocument.defaultView.getComputedStyle(node);
  height += (0, _shims.int)(computedStyle.borderTopWidth);
  height += (0, _shims.int)(computedStyle.borderBottomWidth);
  return height;
}

function outerWidth(node
/*: HTMLElement*/
)
/*: number*/
{
  // This is deliberately excluding margin for our calculations, since we are using
  // offsetLeft which is including margin. See getBoundPosition
  var width = node.clientWidth;
  var computedStyle = node.ownerDocument.defaultView.getComputedStyle(node);
  width += (0, _shims.int)(computedStyle.borderLeftWidth);
  width += (0, _shims.int)(computedStyle.borderRightWidth);
  return width;
}

function innerHeight(node
/*: HTMLElement*/
)
/*: number*/
{
  var height = node.clientHeight;
  var computedStyle = node.ownerDocument.defaultView.getComputedStyle(node);
  height -= (0, _shims.int)(computedStyle.paddingTop);
  height -= (0, _shims.int)(computedStyle.paddingBottom);
  return height;
}

function innerWidth(node
/*: HTMLElement*/
)
/*: number*/
{
  var width = node.clientWidth;
  var computedStyle = node.ownerDocument.defaultView.getComputedStyle(node);
  width -= (0, _shims.int)(computedStyle.paddingLeft);
  width -= (0, _shims.int)(computedStyle.paddingRight);
  return width;
}
/*:: interface EventWithOffset {
  clientX: number, clientY: number
}*/


// Get from offsetParent
function offsetXYFromParent(evt
/*: EventWithOffset*/
, offsetParent
/*: HTMLElement*/
, scale
/*: number*/
)
/*: ControlPosition*/
{
  var isBody = offsetParent === offsetParent.ownerDocument.body;
  var offsetParentRect = isBody ? {
    left: 0,
    top: 0
  } : offsetParent.getBoundingClientRect();
  var x = (evt.clientX + offsetParent.scrollLeft - offsetParentRect.left) / scale;
  var y = (evt.clientY + offsetParent.scrollTop - offsetParentRect.top) / scale;
  return {
    x: x,
    y: y
  };
}

function createCSSTransform(controlPos
/*: ControlPosition*/
, positionOffset
/*: PositionOffsetControlPosition*/
)
/*: Object*/
{
  var translation = getTranslation(controlPos, positionOffset, 'px');
  return _defineProperty({}, (0, _getPrefix.browserPrefixToKey)('transform', _getPrefix.default), translation);
}

function createSVGTransform(controlPos
/*: ControlPosition*/
, positionOffset
/*: PositionOffsetControlPosition*/
)
/*: string*/
{
  var translation = getTranslation(controlPos, positionOffset, '');
  return translation;
}

function getTranslation(_ref2, positionOffset
/*: PositionOffsetControlPosition*/
, unitSuffix
/*: string*/
)
/*: string*/
{
  var x = _ref2.x,
      y = _ref2.y;
  var translation = "translate(".concat(x).concat(unitSuffix, ",").concat(y).concat(unitSuffix, ")");

  if (positionOffset) {
    var defaultX = "".concat(typeof positionOffset.x === 'string' ? positionOffset.x : positionOffset.x + unitSuffix);
    var defaultY = "".concat(typeof positionOffset.y === 'string' ? positionOffset.y : positionOffset.y + unitSuffix);
    translation = "translate(".concat(defaultX, ", ").concat(defaultY, ")") + translation;
  }

  return translation;
}

function getTouch(e
/*: MouseTouchEvent*/
, identifier
/*: number*/
)
/*: ?{clientX: number, clientY: number}*/
{
  return e.targetTouches && (0, _shims.findInArray)(e.targetTouches, function (t) {
    return identifier === t.identifier;
  }) || e.changedTouches && (0, _shims.findInArray)(e.changedTouches, function (t) {
    return identifier === t.identifier;
  });
}

function getTouchIdentifier(e
/*: MouseTouchEvent*/
)
/*: ?number*/
{
  if (e.targetTouches && e.targetTouches[0]) return e.targetTouches[0].identifier;
  if (e.changedTouches && e.changedTouches[0]) return e.changedTouches[0].identifier;
} // User-select Hacks:
//
// Useful for preventing blue highlights all over everything when dragging.
// Note we're passing `document` b/c we could be iframed


function addUserSelectStyles(doc
/*: ?Document*/
) {
  if (!doc) return;
  var styleEl = doc.getElementById('react-draggable-style-el');

  if (!styleEl) {
    styleEl = doc.createElement('style');
    styleEl.type = 'text/css';
    styleEl.id = 'react-draggable-style-el';
    styleEl.innerHTML = '.react-draggable-transparent-selection *::-moz-selection {all: inherit;}\n';
    styleEl.innerHTML += '.react-draggable-transparent-selection *::selection {all: inherit;}\n';
    doc.getElementsByTagName('head')[0].appendChild(styleEl);
  }

  if (doc.body) addClassName(doc.body, 'react-draggable-transparent-selection');
}

function removeUserSelectStyles(doc
/*: ?Document*/
) {
  if (!doc) return;

  try {
    if (doc.body) removeClassName(doc.body, 'react-draggable-transparent-selection'); // $FlowIgnore: IE

    if (doc.selection) {
      // $FlowIgnore: IE
      doc.selection.empty();
    } else {
      // Remove selection caused by scroll, unless it's a focused input
      // (we use doc.defaultView in case we're in an iframe)
      var selection = (doc.defaultView || window).getSelection();

      if (selection && selection.type !== 'Caret') {
        selection.removeAllRanges();
      }
    }
  } catch (e) {// probably IE
  }
}

function addClassName(el
/*: HTMLElement*/
, className
/*: string*/
) {
  if (el.classList) {
    el.classList.add(className);
  } else {
    if (!el.className.match(new RegExp("(?:^|\\s)".concat(className, "(?!\\S)")))) {
      el.className += " ".concat(className);
    }
  }
}

function removeClassName(el
/*: HTMLElement*/
, className
/*: string*/
) {
  if (el.classList) {
    el.classList.remove(className);
  } else {
    el.className = el.className.replace(new RegExp("(?:^|\\s)".concat(className, "(?!\\S)"), 'g'), '');
  }
}

/***/ }),

/***/ "../../node_modules/react-draggable/build/cjs/utils/getPrefix.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/react-draggable/build/cjs/utils/getPrefix.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";


Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports.browserPrefixToKey = browserPrefixToKey;
exports.browserPrefixToStyle = browserPrefixToStyle;
exports["default"] = void 0;
exports.getPrefix = getPrefix;
var prefixes = ['Moz', 'Webkit', 'O', 'ms'];

function getPrefix()
/*: string*/
{
  var _window$document, _window$document$docu;

  var prop
  /*: string*/
  = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'transform';
  // Ensure we're running in an environment where there is actually a global
  // `window` obj
  if (typeof window === 'undefined') return ''; // If we're in a pseudo-browser server-side environment, this access
  // path may not exist, so bail out if it doesn't.

  var style = (_window$document = window.document) === null || _window$document === void 0 ? void 0 : (_window$document$docu = _window$document.documentElement) === null || _window$document$docu === void 0 ? void 0 : _window$document$docu.style;
  if (!style) return '';
  if (prop in style) return '';

  for (var i = 0; i < prefixes.length; i++) {
    if (browserPrefixToKey(prop, prefixes[i]) in style) return prefixes[i];
  }

  return '';
}

function browserPrefixToKey(prop
/*: string*/
, prefix
/*: string*/
)
/*: string*/
{
  return prefix ? "".concat(prefix).concat(kebabToTitleCase(prop)) : prop;
}

function browserPrefixToStyle(prop
/*: string*/
, prefix
/*: string*/
)
/*: string*/
{
  return prefix ? "-".concat(prefix.toLowerCase(), "-").concat(prop) : prop;
}

function kebabToTitleCase(str
/*: string*/
)
/*: string*/
{
  var out = '';
  var shouldCapitalize = true;

  for (var i = 0; i < str.length; i++) {
    if (shouldCapitalize) {
      out += str[i].toUpperCase();
      shouldCapitalize = false;
    } else if (str[i] === '-') {
      shouldCapitalize = true;
    } else {
      out += str[i];
    }
  }

  return out;
} // Default export is the prefix itself, like 'Moz', 'Webkit', etc
// Note that you may have to re-test for certain things; for instance, Chrome 50
// can handle unprefixed `transform`, but not unprefixed `user-select`


var _default = (getPrefix()
/*: string*/
);

exports["default"] = _default;

/***/ }),

/***/ "../../node_modules/react-draggable/build/cjs/utils/log.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/react-draggable/build/cjs/utils/log.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";


Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = log;

/*eslint no-console:0*/
function log() {
  var _console;

  if (false) {}
}

/***/ }),

/***/ "../../node_modules/react-draggable/build/cjs/utils/positionFns.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/react-draggable/build/cjs/utils/positionFns.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports.canDragX = canDragX;
exports.canDragY = canDragY;
exports.createCoreData = createCoreData;
exports.createDraggableData = createDraggableData;
exports.getBoundPosition = getBoundPosition;
exports.getControlPosition = getControlPosition;
exports.snapToGrid = snapToGrid;

var _shims = __webpack_require__(/*! ./shims */ "../../node_modules/react-draggable/build/cjs/utils/shims.js");

var _domFns = __webpack_require__(/*! ./domFns */ "../../node_modules/react-draggable/build/cjs/utils/domFns.js");

function getBoundPosition(draggable
/*: Draggable*/
, x
/*: number*/
, y
/*: number*/
)
/*: [number, number]*/
{
  // If no bounds, short-circuit and move on
  if (!draggable.props.bounds) return [x, y]; // Clone new bounds

  var bounds = draggable.props.bounds;
  bounds = typeof bounds === 'string' ? bounds : cloneBounds(bounds);
  var node = findDOMNode(draggable);

  if (typeof bounds === 'string') {
    var ownerDocument = node.ownerDocument;
    var ownerWindow = ownerDocument.defaultView;
    var boundNode;

    if (bounds === 'parent') {
      boundNode = node.parentNode;
    } else {
      boundNode = ownerDocument.querySelector(bounds);
    }

    if (!(boundNode instanceof ownerWindow.HTMLElement)) {
      throw new Error('Bounds selector "' + bounds + '" could not find an element.');
    }

    var boundNodeEl
    /*: HTMLElement*/
    = boundNode; // for Flow, can't seem to refine correctly

    var nodeStyle = ownerWindow.getComputedStyle(node);
    var boundNodeStyle = ownerWindow.getComputedStyle(boundNodeEl); // Compute bounds. This is a pain with padding and offsets but this gets it exactly right.

    bounds = {
      left: -node.offsetLeft + (0, _shims.int)(boundNodeStyle.paddingLeft) + (0, _shims.int)(nodeStyle.marginLeft),
      top: -node.offsetTop + (0, _shims.int)(boundNodeStyle.paddingTop) + (0, _shims.int)(nodeStyle.marginTop),
      right: (0, _domFns.innerWidth)(boundNodeEl) - (0, _domFns.outerWidth)(node) - node.offsetLeft + (0, _shims.int)(boundNodeStyle.paddingRight) - (0, _shims.int)(nodeStyle.marginRight),
      bottom: (0, _domFns.innerHeight)(boundNodeEl) - (0, _domFns.outerHeight)(node) - node.offsetTop + (0, _shims.int)(boundNodeStyle.paddingBottom) - (0, _shims.int)(nodeStyle.marginBottom)
    };
  } // Keep x and y below right and bottom limits...


  if ((0, _shims.isNum)(bounds.right)) x = Math.min(x, bounds.right);
  if ((0, _shims.isNum)(bounds.bottom)) y = Math.min(y, bounds.bottom); // But above left and top limits.

  if ((0, _shims.isNum)(bounds.left)) x = Math.max(x, bounds.left);
  if ((0, _shims.isNum)(bounds.top)) y = Math.max(y, bounds.top);
  return [x, y];
}

function snapToGrid(grid
/*: [number, number]*/
, pendingX
/*: number*/
, pendingY
/*: number*/
)
/*: [number, number]*/
{
  var x = Math.round(pendingX / grid[0]) * grid[0];
  var y = Math.round(pendingY / grid[1]) * grid[1];
  return [x, y];
}

function canDragX(draggable
/*: Draggable*/
)
/*: boolean*/
{
  return draggable.props.axis === 'both' || draggable.props.axis === 'x';
}

function canDragY(draggable
/*: Draggable*/
)
/*: boolean*/
{
  return draggable.props.axis === 'both' || draggable.props.axis === 'y';
} // Get {x, y} positions from event.


function getControlPosition(e
/*: MouseTouchEvent*/
, touchIdentifier
/*: ?number*/
, draggableCore
/*: DraggableCore*/
)
/*: ?ControlPosition*/
{
  var touchObj = typeof touchIdentifier === 'number' ? (0, _domFns.getTouch)(e, touchIdentifier) : null;
  if (typeof touchIdentifier === 'number' && !touchObj) return null; // not the right touch

  var node = findDOMNode(draggableCore); // User can provide an offsetParent if desired.

  var offsetParent = draggableCore.props.offsetParent || node.offsetParent || node.ownerDocument.body;
  return (0, _domFns.offsetXYFromParent)(touchObj || e, offsetParent, draggableCore.props.scale);
} // Create an data object exposed by <DraggableCore>'s events


function createCoreData(draggable
/*: DraggableCore*/
, x
/*: number*/
, y
/*: number*/
)
/*: DraggableData*/
{
  var state = draggable.state;
  var isStart = !(0, _shims.isNum)(state.lastX);
  var node = findDOMNode(draggable);

  if (isStart) {
    // If this is our first move, use the x and y as last coords.
    return {
      node: node,
      deltaX: 0,
      deltaY: 0,
      lastX: x,
      lastY: y,
      x: x,
      y: y
    };
  } else {
    // Otherwise calculate proper values.
    return {
      node: node,
      deltaX: x - state.lastX,
      deltaY: y - state.lastY,
      lastX: state.lastX,
      lastY: state.lastY,
      x: x,
      y: y
    };
  }
} // Create an data exposed by <Draggable>'s events


function createDraggableData(draggable
/*: Draggable*/
, coreData
/*: DraggableData*/
)
/*: DraggableData*/
{
  var scale = draggable.props.scale;
  return {
    node: coreData.node,
    x: draggable.state.x + coreData.deltaX / scale,
    y: draggable.state.y + coreData.deltaY / scale,
    deltaX: coreData.deltaX / scale,
    deltaY: coreData.deltaY / scale,
    lastX: draggable.state.x,
    lastY: draggable.state.y
  };
} // A lot faster than stringify/parse


function cloneBounds(bounds
/*: Bounds*/
)
/*: Bounds*/
{
  return {
    left: bounds.left,
    top: bounds.top,
    right: bounds.right,
    bottom: bounds.bottom
  };
}

function findDOMNode(draggable
/*: Draggable | DraggableCore*/
)
/*: HTMLElement*/
{
  var node = draggable.findDOMNode();

  if (!node) {
    throw new Error('<DraggableCore>: Unmounted during event!');
  } // $FlowIgnore we can't assert on HTMLElement due to tests... FIXME


  return node;
}

/***/ }),

/***/ "../../node_modules/react-draggable/build/cjs/utils/shims.js":
/*!*******************************************************************!*\
  !*** ../../node_modules/react-draggable/build/cjs/utils/shims.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";


Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports.dontSetMe = dontSetMe;
exports.findInArray = findInArray;
exports.int = int;
exports.isFunction = isFunction;
exports.isNum = isNum;

// @credits https://gist.github.com/rogozhnikoff/a43cfed27c41e4e68cdc
function findInArray(array
/*: Array<any> | TouchList*/
, callback
/*: Function*/
)
/*: any*/
{
  for (var i = 0, length = array.length; i < length; i++) {
    if (callback.apply(callback, [array[i], i, array])) return array[i];
  }
}

function isFunction(func
/*: any*/
)
/*: boolean %checks*/
{
  // $FlowIgnore[method-unbinding]
  return typeof func === 'function' || Object.prototype.toString.call(func) === '[object Function]';
}

function isNum(num
/*: any*/
)
/*: boolean %checks*/
{
  return typeof num === 'number' && !isNaN(num);
}

function int(a
/*: string*/
)
/*: number*/
{
  return parseInt(a, 10);
}

function dontSetMe(props
/*: Object*/
, propName
/*: string*/
, componentName
/*: string*/
)
/*: ?Error*/
{
  if (props[propName]) {
    return new Error("Invalid prop ".concat(propName, " passed to ").concat(componentName, " - do not set this, set it on the child."));
  }
}

/***/ }),

/***/ "../../node_modules/react-from-dom/esm/helpers.js":
/*!********************************************************!*\
  !*** ../../node_modules/react-from-dom/esm/helpers.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "noTextChildNodes": () => (/* binding */ noTextChildNodes),
/* harmony export */   "possibleStandardNames": () => (/* binding */ possibleStandardNames),
/* harmony export */   "randomString": () => (/* binding */ randomString),
/* harmony export */   "styleToObject": () => (/* binding */ styleToObject)
/* harmony export */ });
var __read = (undefined && undefined.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var styleToObject = function (input) {
    var attributes = input.split(/ ?; ?/);
    return attributes.reduce(function (acc, d) {
        var _a = __read(d.split(/ ?: ?/), 2), key = _a[0], value = _a[1];
        if (key && value) {
            acc[key.replace(/-(\w)/g, function (_$0, $1) { return $1.toUpperCase(); })] = Number.isNaN(Number(value))
                ? value
                : Number(value);
        }
        return acc;
    }, {});
};
/* istanbul ignore next */
function randomString(length) {
    if (length === void 0) { length = 6; }
    var characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    var result = '';
    for (var index = length; index > 0; --index) {
        result += characters[Math.round(Math.random() * (characters.length - 1))];
    }
    return result;
}
var noTextChildNodes = [
    'br',
    'col',
    'colgroup',
    'dl',
    'hr',
    'iframe',
    'img',
    'input',
    'link',
    'menuitem',
    'meta',
    'ol',
    'param',
    'select',
    'table',
    'tbody',
    'tfoot',
    'thead',
    'tr',
    'ul',
    'wbr',
];
/**
 * Copyright (c) 2013-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
// Taken from https://raw.githubusercontent.com/facebook/react/baff5cc2f69d30589a5dc65b089e47765437294b/packages/react-dom/src/shared/possibleStandardNames.js
// tslint:disable:object-literal-sort-keys
var possibleStandardNames = {
    // HTML
    'accept-charset': 'acceptCharset',
    acceptcharset: 'acceptCharset',
    accesskey: 'accessKey',
    allowfullscreen: 'allowFullScreen',
    autocapitalize: 'autoCapitalize',
    autocomplete: 'autoComplete',
    autocorrect: 'autoCorrect',
    autofocus: 'autoFocus',
    autoplay: 'autoPlay',
    autosave: 'autoSave',
    cellpadding: 'cellPadding',
    cellspacing: 'cellSpacing',
    charset: 'charSet',
    class: 'className',
    classid: 'classID',
    classname: 'className',
    colspan: 'colSpan',
    contenteditable: 'contentEditable',
    contextmenu: 'contextMenu',
    controlslist: 'controlsList',
    crossorigin: 'crossOrigin',
    dangerouslysetinnerhtml: 'dangerouslySetInnerHTML',
    datetime: 'dateTime',
    defaultchecked: 'defaultChecked',
    defaultvalue: 'defaultValue',
    enctype: 'encType',
    for: 'htmlFor',
    formmethod: 'formMethod',
    formaction: 'formAction',
    formenctype: 'formEncType',
    formnovalidate: 'formNoValidate',
    formtarget: 'formTarget',
    frameborder: 'frameBorder',
    hreflang: 'hrefLang',
    htmlfor: 'htmlFor',
    httpequiv: 'httpEquiv',
    'http-equiv': 'httpEquiv',
    icon: 'icon',
    innerhtml: 'innerHTML',
    inputmode: 'inputMode',
    itemid: 'itemID',
    itemprop: 'itemProp',
    itemref: 'itemRef',
    itemscope: 'itemScope',
    itemtype: 'itemType',
    keyparams: 'keyParams',
    keytype: 'keyType',
    marginwidth: 'marginWidth',
    marginheight: 'marginHeight',
    maxlength: 'maxLength',
    mediagroup: 'mediaGroup',
    minlength: 'minLength',
    nomodule: 'noModule',
    novalidate: 'noValidate',
    playsinline: 'playsInline',
    radiogroup: 'radioGroup',
    readonly: 'readOnly',
    referrerpolicy: 'referrerPolicy',
    rowspan: 'rowSpan',
    spellcheck: 'spellCheck',
    srcdoc: 'srcDoc',
    srclang: 'srcLang',
    srcset: 'srcSet',
    tabindex: 'tabIndex',
    typemustmatch: 'typeMustMatch',
    usemap: 'useMap',
    // SVG
    accentheight: 'accentHeight',
    'accent-height': 'accentHeight',
    alignmentbaseline: 'alignmentBaseline',
    'alignment-baseline': 'alignmentBaseline',
    allowreorder: 'allowReorder',
    arabicform: 'arabicForm',
    'arabic-form': 'arabicForm',
    attributename: 'attributeName',
    attributetype: 'attributeType',
    autoreverse: 'autoReverse',
    basefrequency: 'baseFrequency',
    baselineshift: 'baselineShift',
    'baseline-shift': 'baselineShift',
    baseprofile: 'baseProfile',
    calcmode: 'calcMode',
    capheight: 'capHeight',
    'cap-height': 'capHeight',
    clippath: 'clipPath',
    'clip-path': 'clipPath',
    clippathunits: 'clipPathUnits',
    cliprule: 'clipRule',
    'clip-rule': 'clipRule',
    colorinterpolation: 'colorInterpolation',
    'color-interpolation': 'colorInterpolation',
    colorinterpolationfilters: 'colorInterpolationFilters',
    'color-interpolation-filters': 'colorInterpolationFilters',
    colorprofile: 'colorProfile',
    'color-profile': 'colorProfile',
    colorrendering: 'colorRendering',
    'color-rendering': 'colorRendering',
    contentscripttype: 'contentScriptType',
    contentstyletype: 'contentStyleType',
    diffuseconstant: 'diffuseConstant',
    dominantbaseline: 'dominantBaseline',
    'dominant-baseline': 'dominantBaseline',
    edgemode: 'edgeMode',
    enablebackground: 'enableBackground',
    'enable-background': 'enableBackground',
    externalresourcesrequired: 'externalResourcesRequired',
    fillopacity: 'fillOpacity',
    'fill-opacity': 'fillOpacity',
    fillrule: 'fillRule',
    'fill-rule': 'fillRule',
    filterres: 'filterRes',
    filterunits: 'filterUnits',
    floodopacity: 'floodOpacity',
    'flood-opacity': 'floodOpacity',
    floodcolor: 'floodColor',
    'flood-color': 'floodColor',
    fontfamily: 'fontFamily',
    'font-family': 'fontFamily',
    fontsize: 'fontSize',
    'font-size': 'fontSize',
    fontsizeadjust: 'fontSizeAdjust',
    'font-size-adjust': 'fontSizeAdjust',
    fontstretch: 'fontStretch',
    'font-stretch': 'fontStretch',
    fontstyle: 'fontStyle',
    'font-style': 'fontStyle',
    fontvariant: 'fontVariant',
    'font-variant': 'fontVariant',
    fontweight: 'fontWeight',
    'font-weight': 'fontWeight',
    glyphname: 'glyphName',
    'glyph-name': 'glyphName',
    glyphorientationhorizontal: 'glyphOrientationHorizontal',
    'glyph-orientation-horizontal': 'glyphOrientationHorizontal',
    glyphorientationvertical: 'glyphOrientationVertical',
    'glyph-orientation-vertical': 'glyphOrientationVertical',
    glyphref: 'glyphRef',
    gradienttransform: 'gradientTransform',
    gradientunits: 'gradientUnits',
    horizadvx: 'horizAdvX',
    'horiz-adv-x': 'horizAdvX',
    horizoriginx: 'horizOriginX',
    'horiz-origin-x': 'horizOriginX',
    imagerendering: 'imageRendering',
    'image-rendering': 'imageRendering',
    kernelmatrix: 'kernelMatrix',
    kernelunitlength: 'kernelUnitLength',
    keypoints: 'keyPoints',
    keysplines: 'keySplines',
    keytimes: 'keyTimes',
    lengthadjust: 'lengthAdjust',
    letterspacing: 'letterSpacing',
    'letter-spacing': 'letterSpacing',
    lightingcolor: 'lightingColor',
    'lighting-color': 'lightingColor',
    limitingconeangle: 'limitingConeAngle',
    markerend: 'markerEnd',
    'marker-end': 'markerEnd',
    markerheight: 'markerHeight',
    markermid: 'markerMid',
    'marker-mid': 'markerMid',
    markerstart: 'markerStart',
    'marker-start': 'markerStart',
    markerunits: 'markerUnits',
    markerwidth: 'markerWidth',
    maskcontentunits: 'maskContentUnits',
    maskunits: 'maskUnits',
    numoctaves: 'numOctaves',
    overlineposition: 'overlinePosition',
    'overline-position': 'overlinePosition',
    overlinethickness: 'overlineThickness',
    'overline-thickness': 'overlineThickness',
    paintorder: 'paintOrder',
    'paint-order': 'paintOrder',
    'panose-1': 'panose1',
    pathlength: 'pathLength',
    patterncontentunits: 'patternContentUnits',
    patterntransform: 'patternTransform',
    patternunits: 'patternUnits',
    pointerevents: 'pointerEvents',
    'pointer-events': 'pointerEvents',
    pointsatx: 'pointsAtX',
    pointsaty: 'pointsAtY',
    pointsatz: 'pointsAtZ',
    preservealpha: 'preserveAlpha',
    preserveaspectratio: 'preserveAspectRatio',
    primitiveunits: 'primitiveUnits',
    refx: 'refX',
    refy: 'refY',
    renderingintent: 'renderingIntent',
    'rendering-intent': 'renderingIntent',
    repeatcount: 'repeatCount',
    repeatdur: 'repeatDur',
    requiredextensions: 'requiredExtensions',
    requiredfeatures: 'requiredFeatures',
    shaperendering: 'shapeRendering',
    'shape-rendering': 'shapeRendering',
    specularconstant: 'specularConstant',
    specularexponent: 'specularExponent',
    spreadmethod: 'spreadMethod',
    startoffset: 'startOffset',
    stddeviation: 'stdDeviation',
    stitchtiles: 'stitchTiles',
    stopcolor: 'stopColor',
    'stop-color': 'stopColor',
    stopopacity: 'stopOpacity',
    'stop-opacity': 'stopOpacity',
    strikethroughposition: 'strikethroughPosition',
    'strikethrough-position': 'strikethroughPosition',
    strikethroughthickness: 'strikethroughThickness',
    'strikethrough-thickness': 'strikethroughThickness',
    strokedasharray: 'strokeDasharray',
    'stroke-dasharray': 'strokeDasharray',
    strokedashoffset: 'strokeDashoffset',
    'stroke-dashoffset': 'strokeDashoffset',
    strokelinecap: 'strokeLinecap',
    'stroke-linecap': 'strokeLinecap',
    strokelinejoin: 'strokeLinejoin',
    'stroke-linejoin': 'strokeLinejoin',
    strokemiterlimit: 'strokeMiterlimit',
    'stroke-miterlimit': 'strokeMiterlimit',
    strokewidth: 'strokeWidth',
    'stroke-width': 'strokeWidth',
    strokeopacity: 'strokeOpacity',
    'stroke-opacity': 'strokeOpacity',
    suppresscontenteditablewarning: 'suppressContentEditableWarning',
    suppresshydrationwarning: 'suppressHydrationWarning',
    surfacescale: 'surfaceScale',
    systemlanguage: 'systemLanguage',
    tablevalues: 'tableValues',
    targetx: 'targetX',
    targety: 'targetY',
    textanchor: 'textAnchor',
    'text-anchor': 'textAnchor',
    textdecoration: 'textDecoration',
    'text-decoration': 'textDecoration',
    textlength: 'textLength',
    textrendering: 'textRendering',
    'text-rendering': 'textRendering',
    underlineposition: 'underlinePosition',
    'underline-position': 'underlinePosition',
    underlinethickness: 'underlineThickness',
    'underline-thickness': 'underlineThickness',
    unicodebidi: 'unicodeBidi',
    'unicode-bidi': 'unicodeBidi',
    unicoderange: 'unicodeRange',
    'unicode-range': 'unicodeRange',
    unitsperem: 'unitsPerEm',
    'units-per-em': 'unitsPerEm',
    unselectable: 'unselectable',
    valphabetic: 'vAlphabetic',
    'v-alphabetic': 'vAlphabetic',
    vectoreffect: 'vectorEffect',
    'vector-effect': 'vectorEffect',
    vertadvy: 'vertAdvY',
    'vert-adv-y': 'vertAdvY',
    vertoriginx: 'vertOriginX',
    'vert-origin-x': 'vertOriginX',
    vertoriginy: 'vertOriginY',
    'vert-origin-y': 'vertOriginY',
    vhanging: 'vHanging',
    'v-hanging': 'vHanging',
    videographic: 'vIdeographic',
    'v-ideographic': 'vIdeographic',
    viewbox: 'viewBox',
    viewtarget: 'viewTarget',
    vmathematical: 'vMathematical',
    'v-mathematical': 'vMathematical',
    wordspacing: 'wordSpacing',
    'word-spacing': 'wordSpacing',
    writingmode: 'writingMode',
    'writing-mode': 'writingMode',
    xchannelselector: 'xChannelSelector',
    xheight: 'xHeight',
    'x-height': 'xHeight',
    xlinkactuate: 'xlinkActuate',
    'xlink:actuate': 'xlinkActuate',
    xlinkarcrole: 'xlinkArcrole',
    'xlink:arcrole': 'xlinkArcrole',
    xlinkhref: 'xlinkHref',
    'xlink:href': 'xlinkHref',
    xlinkrole: 'xlinkRole',
    'xlink:role': 'xlinkRole',
    xlinkshow: 'xlinkShow',
    'xlink:show': 'xlinkShow',
    xlinktitle: 'xlinkTitle',
    'xlink:title': 'xlinkTitle',
    xlinktype: 'xlinkType',
    'xlink:type': 'xlinkType',
    xmlbase: 'xmlBase',
    'xml:base': 'xmlBase',
    xmllang: 'xmlLang',
    'xml:lang': 'xmlLang',
    'xml:space': 'xmlSpace',
    xmlnsxlink: 'xmlnsXlink',
    'xmlns:xlink': 'xmlnsXlink',
    xmlspace: 'xmlSpace',
    ychannelselector: 'yChannelSelector',
    zoomandpan: 'zoomAndPan',
    // event handlers
    onblur: 'onBlur',
    onchange: 'onChange',
    onclick: 'onClick',
    oncontextmenu: 'onContextMenu',
    ondoubleclick: 'onDoubleClick',
    ondrag: 'onDrag',
    ondragend: 'onDragEnd',
    ondragenter: 'onDragEnter',
    ondragexit: 'onDragExit',
    ondragleave: 'onDragLeave',
    ondragover: 'onDragOver',
    ondragstart: 'onDragStart',
    ondrop: 'onDrop',
    onerror: 'onError',
    onfocus: 'onFocus',
    oninput: 'onInput',
    oninvalid: 'onInvalid',
    onkeydown: 'onKeyDown',
    onkeypress: 'onKeyPress',
    onkeyup: 'onKeyUp',
    onload: 'onLoad',
    onmousedown: 'onMouseDown',
    onmouseenter: 'onMouseEnter',
    onmouseleave: 'onMouseLeave',
    onmousemove: 'onMouseMove',
    onmouseout: 'onMouseOut',
    onmouseover: 'onMouseOver',
    onmouseup: 'onMouseUp',
    onscroll: 'onScroll',
    onsubmit: 'onSubmit',
    ontouchcancel: 'onTouchCancel',
    ontouchend: 'onTouchEnd',
    ontouchmove: 'onTouchMove',
    ontouchstart: 'onTouchStart',
    onwheel: 'onWheel',
};
//# sourceMappingURL=helpers.js.map

/***/ }),

/***/ "../../node_modules/react-from-dom/esm/index.js":
/*!******************************************************!*\
  !*** ../../node_modules/react-from-dom/esm/index.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "convertFromNode": () => (/* binding */ convertFromNode),
/* harmony export */   "convertFromString": () => (/* binding */ convertFromString),
/* harmony export */   "default": () => (/* binding */ convert)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _helpers__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./helpers */ "../../node_modules/react-from-dom/esm/helpers.js");
var __assign = (undefined && undefined.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __read = (undefined && undefined.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (undefined && undefined.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
/* eslint-disable @typescript-eslint/no-use-before-define */


function parseAttributes(node, reactKey) {
    var attributes = {
        key: reactKey,
    };
    /* istanbul ignore else */
    if (node instanceof Element) {
        var nodeClassNames = node.getAttribute('class');
        if (nodeClassNames) {
            attributes.className = nodeClassNames;
        }
        __spreadArray([], __read(node.attributes), false).forEach(function (d) {
            switch (d.name) {
                // this is manually handled above, so break;
                case 'class':
                    break;
                case 'style':
                    attributes[d.name] = (0,_helpers__WEBPACK_IMPORTED_MODULE_1__.styleToObject)(d.value);
                    break;
                case 'allowfullscreen':
                case 'allowpaymentrequest':
                case 'async':
                case 'autofocus':
                case 'autoplay':
                case 'checked':
                case 'controls':
                case 'default':
                case 'defer':
                case 'disabled':
                case 'formnovalidate':
                case 'hidden':
                case 'ismap':
                case 'itemscope':
                case 'loop':
                case 'multiple':
                case 'muted':
                case 'nomodule':
                case 'novalidate':
                case 'open':
                case 'readonly':
                case 'required':
                case 'reversed':
                case 'selected':
                case 'typemustmatch':
                    attributes[_helpers__WEBPACK_IMPORTED_MODULE_1__.possibleStandardNames[d.name] || d.name] = true;
                    break;
                default:
                    attributes[_helpers__WEBPACK_IMPORTED_MODULE_1__.possibleStandardNames[d.name] || d.name] = d.value;
            }
        });
    }
    return attributes;
}
function parseChildren(childNodeList, level, options) {
    var children = __spreadArray([], __read(childNodeList), false).map(function (node, index) {
        return convertFromNode(node, __assign(__assign({}, options), { index: index, level: level + 1 }));
    })
        .filter(Boolean);
    if (!children.length) {
        return null;
    }
    return children;
}
function parseName(nodeName) {
    if (/[a-z]+[A-Z]+[a-z]+/.test(nodeName)) {
        return nodeName;
    }
    return nodeName.toLowerCase();
}
function convertFromNode(input, options) {
    var _a;
    if (options === void 0) { options = {}; }
    if (!input || !(input instanceof Node)) {
        return null;
    }
    var _b = options.actions, actions = _b === void 0 ? [] : _b, _c = options.index, index = _c === void 0 ? 0 : _c, _d = options.level, level = _d === void 0 ? 0 : _d, randomKey = options.randomKey;
    var node = input;
    var key = "".concat(level, "-").concat(index);
    var result = [];
    if (randomKey && level === 0) {
        key = "".concat((0,_helpers__WEBPACK_IMPORTED_MODULE_1__.randomString)(), "-").concat(key);
    }
    /* istanbul ignore else */
    if (Array.isArray(actions)) {
        actions.forEach(function (action) {
            if (action.condition(node, key, level)) {
                if (typeof action.pre === 'function') {
                    node = action.pre(node, key, level);
                    if (!(node instanceof Node)) {
                        node = input;
                        /* istanbul ignore else */
                        if (true) {
                            // eslint-disable-next-line no-console
                            console.warn('The `pre` method always must return a valid DomNode (instanceof Node) - your modification will be ignored (Hint: if you want to render a React-component, use the `post` method instead)');
                        }
                    }
                }
                if (typeof action.post === 'function') {
                    result.push(action.post(node, key, level));
                }
            }
        });
    }
    if (result.length) {
        return result;
    }
    switch (node.nodeType) {
        case 1: {
            // regular dom-node
            return react__WEBPACK_IMPORTED_MODULE_0__.createElement(parseName(node.nodeName), parseAttributes(node, key), parseChildren(node.childNodes, level, options));
        }
        case 3: {
            // textnode
            var nodeText = ((_a = node.nodeValue) === null || _a === void 0 ? void 0 : _a.toString()) || '';
            /* istanbul ignore else */
            if (/^\s+$/.test(nodeText) && !/[\u00A0\u202F]/.test(nodeText)) {
                return null;
            }
            /* istanbul ignore next */
            if (!node.parentNode) {
                return nodeText;
            }
            var parentNodeName = node.parentNode.nodeName.toLowerCase();
            if (_helpers__WEBPACK_IMPORTED_MODULE_1__.noTextChildNodes.includes(parentNodeName)) {
                /* istanbul ignore else */
                if (/\S/.test(nodeText)) {
                    // eslint-disable-next-line no-console
                    console.warn("A textNode is not allowed inside '".concat(parentNodeName, "'. Your text \"").concat(nodeText, "\" will be ignored"));
                }
                return null;
            }
            return nodeText;
        }
        case 8: {
            // html-comment
            return null;
        }
        /* istanbul ignore next */
        default: {
            return null;
        }
    }
}
function convertFromString(input, options) {
    if (options === void 0) { options = {}; }
    if (!input || typeof input !== 'string') {
        return null;
    }
    var _a = options.nodeOnly, nodeOnly = _a === void 0 ? false : _a, _b = options.selector, selector = _b === void 0 ? 'body > *' : _b, _c = options.type, type = _c === void 0 ? 'text/html' : _c;
    try {
        var parser = new DOMParser();
        var document_1 = parser.parseFromString(input, type);
        var node = document_1.querySelector(selector);
        if (!(node instanceof Node)) {
            throw new TypeError('Error parsing input');
        }
        if (nodeOnly) {
            return node;
        }
        return convertFromNode(node, options);
    }
    catch (error) {
        /* istanbul ignore else */
        if (true) {
            // eslint-disable-next-line no-console
            console.error(error);
        }
    }
    return null;
}
function convert(input, options) {
    if (options === void 0) { options = {}; }
    if (typeof input === 'string') {
        return convertFromString(input, options);
    }
    if (input instanceof Node) {
        return convertFromNode(input, options);
    }
    return null;
}
//# sourceMappingURL=index.js.map

/***/ }),

/***/ "../../node_modules/react-inlinesvg/esm/helpers.js":
/*!*********************************************************!*\
  !*** ../../node_modules/react-inlinesvg/esm/helpers.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "STATUS": () => (/* binding */ STATUS),
/* harmony export */   "canUseDOM": () => (/* binding */ canUseDOM),
/* harmony export */   "isSupportedEnvironment": () => (/* binding */ isSupportedEnvironment),
/* harmony export */   "randomString": () => (/* binding */ randomString),
/* harmony export */   "removeProperties": () => (/* binding */ removeProperties),
/* harmony export */   "supportsInlineSVG": () => (/* binding */ supportsInlineSVG)
/* harmony export */ });
/* harmony import */ var exenv__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! exenv */ "../../node_modules/exenv/index.js");
/* harmony import */ var exenv__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(exenv__WEBPACK_IMPORTED_MODULE_0__);

var STATUS = {
    FAILED: 'failed',
    LOADED: 'loaded',
    LOADING: 'loading',
    PENDING: 'pending',
    READY: 'ready',
    UNSUPPORTED: 'unsupported',
};
function canUseDOM() {
    return exenv__WEBPACK_IMPORTED_MODULE_0__.canUseDOM;
}
function isSupportedEnvironment() {
    return supportsInlineSVG() && typeof window !== 'undefined' && window !== null;
}
function supportsInlineSVG() {
    /* istanbul ignore next */
    if (!document) {
        return false;
    }
    var div = document.createElement('div');
    div.innerHTML = '<svg />';
    return !!div.firstChild && div.firstChild.namespaceURI === 'http://www.w3.org/2000/svg';
}
function randomString(length) {
    var letters = 'abcdefghijklmnopqrstuvwxyz';
    var numbers = '1234567890';
    var charset = "" + letters + letters.toUpperCase() + numbers;
    var randomCharacter = function (character) {
        return character[Math.floor(Math.random() * character.length)];
    };
    var R = '';
    for (var i = 0; i < length; i++) {
        R += randomCharacter(charset);
    }
    return R;
}
/**
 *  Remove properties from an object
 */
function removeProperties(input) {
    var filter = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        filter[_i - 1] = arguments[_i];
    }
    var output = {};
    for (var key in input) {
        /* istanbul ignore else */
        if ({}.hasOwnProperty.call(input, key)) {
            if (!filter.includes(key)) {
                output[key] = input[key];
            }
        }
    }
    return output;
}
//# sourceMappingURL=helpers.js.map

/***/ }),

/***/ "../../node_modules/react-inlinesvg/esm/index.js":
/*!*******************************************************!*\
  !*** ../../node_modules/react-inlinesvg/esm/index.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "cacheStore": () => (/* binding */ cacheStore),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react_from_dom__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! react-from-dom */ "../../node_modules/react-from-dom/esm/index.js");
/* harmony import */ var _helpers__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./helpers */ "../../node_modules/react-inlinesvg/esm/helpers.js");
var __extends = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (undefined && undefined.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __read = (undefined && undefined.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (undefined && undefined.__spreadArray) || function (to, from) {
    for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
    return to;
};



var cacheStore = Object.create(null);
var InlineSVG = /** @class */ (function (_super) {
    __extends(InlineSVG, _super);
    function InlineSVG(props) {
        var _this = _super.call(this, props) || this;
        _this.isActive = false;
        _this.handleCacheQueue = function (content) {
            /* istanbul ignore else */
            if (typeof content === 'string') {
                _this.handleLoad(content);
                return;
            }
            _this.handleError(content);
        };
        _this.handleLoad = function (content) {
            /* istanbul ignore else */
            if (_this.isActive) {
                _this.setState({
                    content: content,
                    status: _helpers__WEBPACK_IMPORTED_MODULE_1__.STATUS.LOADED,
                }, _this.getElement);
            }
        };
        _this.handleError = function (error) {
            var onError = _this.props.onError;
            var status = error.message === 'Browser does not support SVG' ? _helpers__WEBPACK_IMPORTED_MODULE_1__.STATUS.UNSUPPORTED : _helpers__WEBPACK_IMPORTED_MODULE_1__.STATUS.FAILED;
            /* istanbul ignore else */
            if (_this.isActive) {
                _this.setState({ status: status }, function () {
                    /* istanbul ignore else */
                    if (typeof onError === 'function') {
                        onError(error);
                    }
                });
            }
        };
        _this.request = function () {
            var _a = _this.props, cacheRequests = _a.cacheRequests, fetchOptions = _a.fetchOptions, src = _a.src;
            try {
                if (cacheRequests) {
                    cacheStore[src] = { content: '', status: _helpers__WEBPACK_IMPORTED_MODULE_1__.STATUS.LOADING, queue: [] };
                }
                return fetch(src, fetchOptions)
                    .then(function (response) {
                    var contentType = response.headers.get('content-type');
                    var _a = __read((contentType || '').split(/ ?; ?/), 1), fileType = _a[0];
                    if (response.status > 299) {
                        throw new Error('Not found');
                    }
                    if (!['image/svg+xml', 'text/plain'].some(function (d) { return fileType.indexOf(d) >= 0; })) {
                        throw new Error("Content type isn't valid: " + fileType);
                    }
                    return response.text();
                })
                    .then(function (content) {
                    var currentSrc = _this.props.src;
                    // the current src don't match the previous one, skipping...
                    if (src !== currentSrc) {
                        return;
                    }
                    _this.handleLoad(content);
                    /* istanbul ignore else */
                    if (cacheRequests) {
                        var cache = cacheStore[src];
                        /* istanbul ignore else */
                        if (cache) {
                            cache.content = content;
                            cache.status = _helpers__WEBPACK_IMPORTED_MODULE_1__.STATUS.LOADED;
                            cache.queue = cache.queue.filter(function (cb) {
                                cb(content);
                                return false;
                            });
                        }
                    }
                })
                    .catch(function (error) {
                    _this.handleError(error);
                    /* istanbul ignore else */
                    if (cacheRequests) {
                        var cache = cacheStore[src];
                        /* istanbul ignore else */
                        if (cache) {
                            cache.queue.forEach(function (cb) {
                                cb(error);
                            });
                            delete cacheStore[src];
                        }
                    }
                });
            }
            catch (error) {
                return _this.handleError(new Error(error.message));
            }
        };
        _this.state = {
            content: '',
            element: null,
            hasCache: !!props.cacheRequests && !!cacheStore[props.src],
            status: _helpers__WEBPACK_IMPORTED_MODULE_1__.STATUS.PENDING,
        };
        _this.hash = props.uniqueHash || (0,_helpers__WEBPACK_IMPORTED_MODULE_1__.randomString)(8);
        return _this;
    }
    InlineSVG.prototype.componentDidMount = function () {
        this.isActive = true;
        if (!(0,_helpers__WEBPACK_IMPORTED_MODULE_1__.canUseDOM)()) {
            return;
        }
        var status = this.state.status;
        var src = this.props.src;
        try {
            /* istanbul ignore else */
            if (status === _helpers__WEBPACK_IMPORTED_MODULE_1__.STATUS.PENDING) {
                /* istanbul ignore else */
                if (!(0,_helpers__WEBPACK_IMPORTED_MODULE_1__.isSupportedEnvironment)()) {
                    throw new Error('Browser does not support SVG');
                }
                /* istanbul ignore else */
                if (!src) {
                    throw new Error('Missing src');
                }
                this.load();
            }
        }
        catch (error) {
            this.handleError(error);
        }
    };
    InlineSVG.prototype.componentDidUpdate = function (prevProps, prevState) {
        if (!(0,_helpers__WEBPACK_IMPORTED_MODULE_1__.canUseDOM)()) {
            return;
        }
        var _a = this.state, hasCache = _a.hasCache, status = _a.status;
        var _b = this.props, onLoad = _b.onLoad, src = _b.src;
        if (prevState.status !== _helpers__WEBPACK_IMPORTED_MODULE_1__.STATUS.READY && status === _helpers__WEBPACK_IMPORTED_MODULE_1__.STATUS.READY) {
            /* istanbul ignore else */
            if (onLoad) {
                onLoad(src, hasCache);
            }
        }
        if (prevProps.src !== src) {
            if (!src) {
                this.handleError(new Error('Missing src'));
                return;
            }
            this.load();
        }
    };
    InlineSVG.prototype.componentWillUnmount = function () {
        this.isActive = false;
    };
    InlineSVG.prototype.processSVG = function () {
        var content = this.state.content;
        var preProcessor = this.props.preProcessor;
        if (preProcessor) {
            return preProcessor(content);
        }
        return content;
    };
    InlineSVG.prototype.updateSVGAttributes = function (node) {
        var _this = this;
        var _a = this.props, _b = _a.baseURL, baseURL = _b === void 0 ? '' : _b, uniquifyIDs = _a.uniquifyIDs;
        var replaceableAttributes = ['id', 'href', 'xlink:href', 'xlink:role', 'xlink:arcrole'];
        var linkAttributes = ['href', 'xlink:href'];
        var isDataValue = function (name, value) {
            return linkAttributes.indexOf(name) >= 0 && (value ? value.indexOf('#') < 0 : false);
        };
        if (!uniquifyIDs) {
            return node;
        }
        __spreadArray([], __read(node.children)).map(function (d) {
            if (d.attributes && d.attributes.length) {
                var attributes_1 = Object.values(d.attributes).map(function (a) {
                    var attr = a;
                    var match = a.value.match(/url\((.*?)\)/);
                    if (match && match[1]) {
                        attr.value = a.value.replace(match[0], "url(" + baseURL + match[1] + "__" + _this.hash + ")");
                    }
                    return attr;
                });
                replaceableAttributes.forEach(function (r) {
                    var attribute = attributes_1.find(function (a) { return a.name === r; });
                    if (attribute && !isDataValue(r, attribute.value)) {
                        attribute.value = attribute.value + "__" + _this.hash;
                    }
                });
            }
            if (d.children.length) {
                return _this.updateSVGAttributes(d);
            }
            return d;
        });
        return node;
    };
    InlineSVG.prototype.getNode = function () {
        var _a = this.props, description = _a.description, title = _a.title;
        try {
            var svgText = this.processSVG();
            var node = (0,react_from_dom__WEBPACK_IMPORTED_MODULE_2__["default"])(svgText, { nodeOnly: true });
            if (!node || !(node instanceof SVGSVGElement)) {
                throw new Error('Could not convert the src to a DOM Node');
            }
            var svg = this.updateSVGAttributes(node);
            if (description) {
                var originalDesc = svg.querySelector('desc');
                if (originalDesc && originalDesc.parentNode) {
                    originalDesc.parentNode.removeChild(originalDesc);
                }
                var descElement = document.createElement('desc');
                descElement.innerHTML = description;
                svg.prepend(descElement);
            }
            if (title) {
                var originalTitle = svg.querySelector('title');
                if (originalTitle && originalTitle.parentNode) {
                    originalTitle.parentNode.removeChild(originalTitle);
                }
                var titleElement = document.createElement('title');
                titleElement.innerHTML = title;
                svg.prepend(titleElement);
            }
            return svg;
        }
        catch (error) {
            return this.handleError(error);
        }
    };
    InlineSVG.prototype.getElement = function () {
        try {
            var node = this.getNode();
            var element = (0,react_from_dom__WEBPACK_IMPORTED_MODULE_2__["default"])(node);
            if (!element || !react__WEBPACK_IMPORTED_MODULE_0__.isValidElement(element)) {
                throw new Error('Could not convert the src to a React element');
            }
            this.setState({
                element: element,
                status: _helpers__WEBPACK_IMPORTED_MODULE_1__.STATUS.READY,
            });
        }
        catch (error) {
            this.handleError(new Error(error.message));
        }
    };
    InlineSVG.prototype.load = function () {
        var _this = this;
        /* istanbul ignore else */
        if (this.isActive) {
            this.setState({
                content: '',
                element: null,
                status: _helpers__WEBPACK_IMPORTED_MODULE_1__.STATUS.LOADING,
            }, function () {
                var _a = _this.props, cacheRequests = _a.cacheRequests, src = _a.src;
                var cache = cacheRequests && cacheStore[src];
                if (cache) {
                    /* istanbul ignore else */
                    if (cache.status === _helpers__WEBPACK_IMPORTED_MODULE_1__.STATUS.LOADING) {
                        cache.queue.push(_this.handleCacheQueue);
                    }
                    else if (cache.status === _helpers__WEBPACK_IMPORTED_MODULE_1__.STATUS.LOADED) {
                        _this.handleLoad(cache.content);
                    }
                    return;
                }
                var dataURI = src.match(/data:image\/svg[^,]*?(;base64)?,(.*)/);
                var inlineSrc;
                if (dataURI) {
                    inlineSrc = dataURI[1] ? atob(dataURI[2]) : decodeURIComponent(dataURI[2]);
                }
                else if (src.indexOf('<svg') >= 0) {
                    inlineSrc = src;
                }
                if (inlineSrc) {
                    _this.handleLoad(inlineSrc);
                    return;
                }
                _this.request();
            });
        }
    };
    InlineSVG.prototype.render = function () {
        var _a = this.state, element = _a.element, status = _a.status;
        var _b = this.props, _c = _b.children, children = _c === void 0 ? null : _c, innerRef = _b.innerRef, _d = _b.loader, loader = _d === void 0 ? null : _d;
        var elementProps = (0,_helpers__WEBPACK_IMPORTED_MODULE_1__.removeProperties)(this.props, 'baseURL', 'cacheRequests', 'children', 'description', 'fetchOptions', 'innerRef', 'loader', 'onError', 'onLoad', 'preProcessor', 'src', 'title', 'uniqueHash', 'uniquifyIDs');
        if (!(0,_helpers__WEBPACK_IMPORTED_MODULE_1__.canUseDOM)()) {
            return loader;
        }
        if (element) {
            return react__WEBPACK_IMPORTED_MODULE_0__.cloneElement(element, __assign({ ref: innerRef }, elementProps));
        }
        if ([_helpers__WEBPACK_IMPORTED_MODULE_1__.STATUS.UNSUPPORTED, _helpers__WEBPACK_IMPORTED_MODULE_1__.STATUS.FAILED].indexOf(status) > -1) {
            return children;
        }
        return loader;
    };
    InlineSVG.defaultProps = {
        cacheRequests: true,
        uniquifyIDs: false,
    };
    return InlineSVG;
}(react__WEBPACK_IMPORTED_MODULE_0__.PureComponent));
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (InlineSVG);

//# sourceMappingURL=index.js.map

/***/ }),

/***/ "../../node_modules/react-lifecycles-compat/react-lifecycles-compat.es.js":
/*!********************************************************************************!*\
  !*** ../../node_modules/react-lifecycles-compat/react-lifecycles-compat.es.js ***!
  \********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "polyfill": () => (/* binding */ polyfill)
/* harmony export */ });
/**
 * Copyright (c) 2013-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

function componentWillMount() {
  // Call this.constructor.gDSFP to support sub-classes.
  var state = this.constructor.getDerivedStateFromProps(this.props, this.state);
  if (state !== null && state !== undefined) {
    this.setState(state);
  }
}

function componentWillReceiveProps(nextProps) {
  // Call this.constructor.gDSFP to support sub-classes.
  // Use the setState() updater to ensure state isn't stale in certain edge cases.
  function updater(prevState) {
    var state = this.constructor.getDerivedStateFromProps(nextProps, prevState);
    return state !== null && state !== undefined ? state : null;
  }
  // Binding "this" is important for shallow renderer support.
  this.setState(updater.bind(this));
}

function componentWillUpdate(nextProps, nextState) {
  try {
    var prevProps = this.props;
    var prevState = this.state;
    this.props = nextProps;
    this.state = nextState;
    this.__reactInternalSnapshotFlag = true;
    this.__reactInternalSnapshot = this.getSnapshotBeforeUpdate(
      prevProps,
      prevState
    );
  } finally {
    this.props = prevProps;
    this.state = prevState;
  }
}

// React may warn about cWM/cWRP/cWU methods being deprecated.
// Add a flag to suppress these warnings for this special case.
componentWillMount.__suppressDeprecationWarning = true;
componentWillReceiveProps.__suppressDeprecationWarning = true;
componentWillUpdate.__suppressDeprecationWarning = true;

function polyfill(Component) {
  var prototype = Component.prototype;

  if (!prototype || !prototype.isReactComponent) {
    throw new Error('Can only polyfill class components');
  }

  if (
    typeof Component.getDerivedStateFromProps !== 'function' &&
    typeof prototype.getSnapshotBeforeUpdate !== 'function'
  ) {
    return Component;
  }

  // If new component APIs are defined, "unsafe" lifecycles won't be called.
  // Error if any of these lifecycles are present,
  // Because they would work differently between older and newer (16.3+) versions of React.
  var foundWillMountName = null;
  var foundWillReceivePropsName = null;
  var foundWillUpdateName = null;
  if (typeof prototype.componentWillMount === 'function') {
    foundWillMountName = 'componentWillMount';
  } else if (typeof prototype.UNSAFE_componentWillMount === 'function') {
    foundWillMountName = 'UNSAFE_componentWillMount';
  }
  if (typeof prototype.componentWillReceiveProps === 'function') {
    foundWillReceivePropsName = 'componentWillReceiveProps';
  } else if (typeof prototype.UNSAFE_componentWillReceiveProps === 'function') {
    foundWillReceivePropsName = 'UNSAFE_componentWillReceiveProps';
  }
  if (typeof prototype.componentWillUpdate === 'function') {
    foundWillUpdateName = 'componentWillUpdate';
  } else if (typeof prototype.UNSAFE_componentWillUpdate === 'function') {
    foundWillUpdateName = 'UNSAFE_componentWillUpdate';
  }
  if (
    foundWillMountName !== null ||
    foundWillReceivePropsName !== null ||
    foundWillUpdateName !== null
  ) {
    var componentName = Component.displayName || Component.name;
    var newApiName =
      typeof Component.getDerivedStateFromProps === 'function'
        ? 'getDerivedStateFromProps()'
        : 'getSnapshotBeforeUpdate()';

    throw Error(
      'Unsafe legacy lifecycles will not be called for components using new component APIs.\n\n' +
        componentName +
        ' uses ' +
        newApiName +
        ' but also contains the following legacy lifecycles:' +
        (foundWillMountName !== null ? '\n  ' + foundWillMountName : '') +
        (foundWillReceivePropsName !== null
          ? '\n  ' + foundWillReceivePropsName
          : '') +
        (foundWillUpdateName !== null ? '\n  ' + foundWillUpdateName : '') +
        '\n\nThe above lifecycles should be removed. Learn more about this warning here:\n' +
        'https://fb.me/react-async-component-lifecycle-hooks'
    );
  }

  // React <= 16.2 does not support static getDerivedStateFromProps.
  // As a workaround, use cWM and cWRP to invoke the new static lifecycle.
  // Newer versions of React will ignore these lifecycles if gDSFP exists.
  if (typeof Component.getDerivedStateFromProps === 'function') {
    prototype.componentWillMount = componentWillMount;
    prototype.componentWillReceiveProps = componentWillReceiveProps;
  }

  // React <= 16.2 does not support getSnapshotBeforeUpdate.
  // As a workaround, use cWU to invoke the new lifecycle.
  // Newer versions of React will ignore that lifecycle if gSBU exists.
  if (typeof prototype.getSnapshotBeforeUpdate === 'function') {
    if (typeof prototype.componentDidUpdate !== 'function') {
      throw new Error(
        'Cannot polyfill getSnapshotBeforeUpdate() for components that do not define componentDidUpdate() on the prototype'
      );
    }

    prototype.componentWillUpdate = componentWillUpdate;

    var componentDidUpdate = prototype.componentDidUpdate;

    prototype.componentDidUpdate = function componentDidUpdatePolyfill(
      prevProps,
      prevState,
      maybeSnapshot
    ) {
      // 16.3+ will not execute our will-update method;
      // It will pass a snapshot value to did-update though.
      // Older versions will require our polyfilled will-update value.
      // We need to handle both cases, but can't just check for the presence of "maybeSnapshot",
      // Because for <= 15.x versions this might be a "prevContext" object.
      // We also can't just check "__reactInternalSnapshot",
      // Because get-snapshot might return a falsy value.
      // So check for the explicit __reactInternalSnapshotFlag flag to determine behavior.
      var snapshot = this.__reactInternalSnapshotFlag
        ? this.__reactInternalSnapshot
        : maybeSnapshot;

      componentDidUpdate.call(this, prevProps, prevState, snapshot);
    };
  }

  return Component;
}




/***/ }),

/***/ "../../node_modules/react-portal/es/LegacyPortal.js":
/*!**********************************************************!*\
  !*** ../../node_modules/react-portal/es/LegacyPortal.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react-dom */ "webpack/sharing/consume/default/react-dom");
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react_dom__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_2__);
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

// This file is a fallback for a consumer who is not yet on React 16
// as createPortal was introduced in React 16





var Portal = function (_React$Component) {
  _inherits(Portal, _React$Component);

  function Portal() {
    _classCallCheck(this, Portal);

    return _possibleConstructorReturn(this, (Portal.__proto__ || Object.getPrototypeOf(Portal)).apply(this, arguments));
  }

  _createClass(Portal, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      this.renderPortal();
    }
  }, {
    key: 'componentDidUpdate',
    value: function componentDidUpdate(props) {
      this.renderPortal();
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      react_dom__WEBPACK_IMPORTED_MODULE_1___default().unmountComponentAtNode(this.defaultNode || this.props.node);
      if (this.defaultNode) {
        document.body.removeChild(this.defaultNode);
      }
      this.defaultNode = null;
      this.portal = null;
    }
  }, {
    key: 'renderPortal',
    value: function renderPortal(props) {
      if (!this.props.node && !this.defaultNode) {
        this.defaultNode = document.createElement('div');
        document.body.appendChild(this.defaultNode);
      }

      var children = this.props.children;
      // https://gist.github.com/jimfb/d99e0678e9da715ccf6454961ef04d1b
      if (typeof this.props.children.type === 'function') {
        children = react__WEBPACK_IMPORTED_MODULE_0___default().cloneElement(this.props.children);
      }

      this.portal = react_dom__WEBPACK_IMPORTED_MODULE_1___default().unstable_renderSubtreeIntoContainer(this, children, this.props.node || this.defaultNode);
    }
  }, {
    key: 'render',
    value: function render() {
      return null;
    }
  }]);

  return Portal;
}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Portal);


Portal.propTypes = {
  children: (prop_types__WEBPACK_IMPORTED_MODULE_2___default().node.isRequired),
  node: (prop_types__WEBPACK_IMPORTED_MODULE_2___default().any)
};

/***/ }),

/***/ "../../node_modules/react-portal/es/Portal.js":
/*!****************************************************!*\
  !*** ../../node_modules/react-portal/es/Portal.js ***!
  \****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react-dom */ "webpack/sharing/consume/default/react-dom");
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react_dom__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./utils */ "../../node_modules/react-portal/es/utils.js");
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }






var Portal = function (_React$Component) {
  _inherits(Portal, _React$Component);

  function Portal() {
    _classCallCheck(this, Portal);

    return _possibleConstructorReturn(this, (Portal.__proto__ || Object.getPrototypeOf(Portal)).apply(this, arguments));
  }

  _createClass(Portal, [{
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      if (this.defaultNode) {
        document.body.removeChild(this.defaultNode);
      }
      this.defaultNode = null;
    }
  }, {
    key: 'render',
    value: function render() {
      if (!_utils__WEBPACK_IMPORTED_MODULE_2__.canUseDOM) {
        return null;
      }
      if (!this.props.node && !this.defaultNode) {
        this.defaultNode = document.createElement('div');
        document.body.appendChild(this.defaultNode);
      }
      return react_dom__WEBPACK_IMPORTED_MODULE_1___default().createPortal(this.props.children, this.props.node || this.defaultNode);
    }
  }]);

  return Portal;
}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));

Portal.propTypes = {
  children: (prop_types__WEBPACK_IMPORTED_MODULE_3___default().node.isRequired),
  node: (prop_types__WEBPACK_IMPORTED_MODULE_3___default().any)
};

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Portal);

/***/ }),

/***/ "../../node_modules/react-portal/es/PortalCompat.js":
/*!**********************************************************!*\
  !*** ../../node_modules/react-portal/es/PortalCompat.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react-dom */ "webpack/sharing/consume/default/react-dom");
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react_dom__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _Portal__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./Portal */ "../../node_modules/react-portal/es/Portal.js");
/* harmony import */ var _LegacyPortal__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./LegacyPortal */ "../../node_modules/react-portal/es/LegacyPortal.js");





var Portal = void 0;

if ((react_dom__WEBPACK_IMPORTED_MODULE_0___default().createPortal)) {
  Portal = _Portal__WEBPACK_IMPORTED_MODULE_1__["default"];
} else {
  Portal = _LegacyPortal__WEBPACK_IMPORTED_MODULE_2__["default"];
}

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Portal);

/***/ }),

/***/ "../../node_modules/react-portal/es/utils.js":
/*!***************************************************!*\
  !*** ../../node_modules/react-portal/es/utils.js ***!
  \***************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "canUseDOM": () => (/* binding */ canUseDOM)
/* harmony export */ });
var canUseDOM = !!(typeof window !== 'undefined' && window.document && window.document.createElement);

/***/ }),

/***/ "../../node_modules/react-resize-detector/lib/esm/components/ResizeDetector.js":
/*!*************************************************************************************!*\
  !*** ../../node_modules/react-resize-detector/lib/esm/components/ResizeDetector.js ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react-dom */ "webpack/sharing/consume/default/react-dom");
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react_dom__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var resize_observer_polyfill__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! resize-observer-polyfill */ "../../node_modules/resize-observer-polyfill/dist/ResizeObserver.es.js");
/* harmony import */ var raf_schd__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! raf-schd */ "../../node_modules/raf-schd/dist/raf-schd.esm.js");
/* harmony import */ var _lib_utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../lib/utils */ "../../node_modules/react-resize-detector/lib/esm/lib/utils.js");
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }







var ResizeDetector = /*#__PURE__*/function (_PureComponent) {
  _inherits(ResizeDetector, _PureComponent);

  var _super = _createSuper(ResizeDetector);

  function ResizeDetector(props) {
    var _this;

    _classCallCheck(this, ResizeDetector);

    _this = _super.call(this, props);

    _defineProperty(_assertThisInitialized(_this), "cancelHandler", function () {
      if (_this.resizeHandler && _this.resizeHandler.cancel) {
        // cancel debounced handler
        _this.resizeHandler.cancel();

        _this.resizeHandler = null;
      }
    });

    _defineProperty(_assertThisInitialized(_this), "rafClean", function () {
      if (_this.raf && _this.raf.cancel) {
        _this.raf.cancel();

        _this.raf = null;
      }
    });

    _defineProperty(_assertThisInitialized(_this), "attachObserver", function () {
      var targetRef = _this.props.targetRef;

      if (targetRef && targetRef.current) {
        _this.targetRef.current = targetRef.current;
      }

      var element = _this.getElement();

      if (!element) {
        // can't find element to observe
        return;
      }

      if (_this.observableElement && _this.observableElement === element) {
        // element is already observed
        return;
      }

      _this.observableElement = element;

      _this.resizeObserver.observe(element);
    });

    _defineProperty(_assertThisInitialized(_this), "getElement", function () {
      var _this$props = _this.props,
          querySelector = _this$props.querySelector,
          targetDomEl = _this$props.targetDomEl;
      if ((0,_lib_utils__WEBPACK_IMPORTED_MODULE_3__.isSSR)()) return undefined; // in case we pass a querySelector

      if (querySelector) return document.querySelector(querySelector); // in case we pass a DOM element

      if (targetDomEl && (0,_lib_utils__WEBPACK_IMPORTED_MODULE_3__.isDOMElement)(targetDomEl)) return targetDomEl; // in case we pass a React ref using React.createRef()

      if (_this.targetRef && (0,_lib_utils__WEBPACK_IMPORTED_MODULE_3__.isDOMElement)(_this.targetRef.current)) return _this.targetRef.current; // the worse case when we don't receive any information from the parent and the library doesn't add any wrappers
      // we have to use a deprecated `findDOMNode` method in order to find a DOM element to attach to
      // eslint-disable-next-line react/no-find-dom-node

      var currentElement = (0,react_dom__WEBPACK_IMPORTED_MODULE_1__.findDOMNode)(_assertThisInitialized(_this));
      if (!currentElement) return undefined;

      var renderType = _this.getRenderType();

      switch (renderType) {
        case 'renderProp':
          return currentElement;

        case 'childFunction':
          return currentElement;

        case 'child':
          return currentElement;

        case 'childArray':
          return currentElement;

        default:
          return currentElement.parentElement;
      }
    });

    _defineProperty(_assertThisInitialized(_this), "createUpdater", function () {
      _this.rafClean();

      _this.raf = (0,raf_schd__WEBPACK_IMPORTED_MODULE_4__["default"])(function (_ref) {
        var width = _ref.width,
            height = _ref.height;
        var onResize = _this.props.onResize;

        if ((0,_lib_utils__WEBPACK_IMPORTED_MODULE_3__.isFunction)(onResize)) {
          onResize(width, height);
        }

        _this.setState({
          width: width,
          height: height
        });
      });
      return _this.raf;
    });

    _defineProperty(_assertThisInitialized(_this), "createResizeHandler", function (entries) {
      var _this$state = _this.state,
          widthCurrent = _this$state.width,
          heightCurrent = _this$state.height;
      var _this$props2 = _this.props,
          handleWidth = _this$props2.handleWidth,
          handleHeight = _this$props2.handleHeight;
      if (!handleWidth && !handleHeight) return;

      var updater = _this.createUpdater();

      entries.forEach(function (entry) {
        var _ref2 = entry && entry.contentRect || {},
            width = _ref2.width,
            height = _ref2.height;

        var isWidthChanged = handleWidth && widthCurrent !== width;
        var isHeightChanged = handleHeight && heightCurrent !== height;
        var isSizeChanged = isWidthChanged || isHeightChanged;
        var shouldSetSize = !_this.skipOnMount && isSizeChanged && !(0,_lib_utils__WEBPACK_IMPORTED_MODULE_3__.isSSR)();

        if (shouldSetSize) {
          updater({
            width: width,
            height: height
          });
        }

        _this.skipOnMount = false;
      });
    });

    _defineProperty(_assertThisInitialized(_this), "getRenderType", function () {
      var _this$props3 = _this.props,
          render = _this$props3.render,
          children = _this$props3.children;

      if ((0,_lib_utils__WEBPACK_IMPORTED_MODULE_3__.isFunction)(render)) {
        // DEPRECATED. Use `Child Function Pattern` instead
        return 'renderProp';
      }

      if ((0,_lib_utils__WEBPACK_IMPORTED_MODULE_3__.isFunction)(children)) {
        return 'childFunction';
      }

      if ( /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_0__.isValidElement)(children)) {
        return 'child';
      }

      if (Array.isArray(children)) {
        // DEPRECATED. Wrap children with a single parent
        return 'childArray';
      } // DEPRECATED. Use `Child Function Pattern` instead


      return 'parent';
    });

    var skipOnMount = props.skipOnMount,
        refreshMode = props.refreshMode,
        refreshRate = props.refreshRate,
        refreshOptions = props.refreshOptions;
    _this.state = {
      width: undefined,
      height: undefined
    };
    _this.skipOnMount = skipOnMount;
    _this.raf = null;
    _this.unmounted = false;
    _this.targetRef = /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_0__.createRef)();
    _this.observableElement = null;
    var handle = (0,_lib_utils__WEBPACK_IMPORTED_MODULE_3__.getHandle)(refreshMode);
    _this.resizeHandler = handle ? handle(_this.createResizeHandler, refreshRate, refreshOptions) : _this.createResizeHandler;
    _this.resizeObserver = new resize_observer_polyfill__WEBPACK_IMPORTED_MODULE_2__["default"](_this.resizeHandler);
    return _this;
  }

  _createClass(ResizeDetector, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.attachObserver();
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      this.attachObserver();
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.resizeObserver.disconnect();
      this.rafClean();
      this.cancelHandler();
      this.unmounted = true;
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props4 = this.props,
          render = _this$props4.render,
          children = _this$props4.children,
          WrapperTag = _this$props4.nodeType;
      var _this$state2 = this.state,
          width = _this$state2.width,
          height = _this$state2.height;
      var childProps = {
        width: width,
        height: height,
        targetRef: this.targetRef
      };
      var renderType = this.getRenderType();

      switch (renderType) {
        case 'renderProp':
          return render(childProps);

        case 'childFunction':
          return children(childProps);

        case 'child':
          // @TODO bug prone logic
          if (typeof children.type === 'string') {
            // child is a native DOM elements such as div, span etc
            var targetRef = childProps.targetRef,
                nativeProps = _objectWithoutProperties(childProps, ["targetRef"]);

            return /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_0__.cloneElement)(children, nativeProps);
          } // class or functional component otherwise


          return /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_0__.cloneElement)(children, childProps);

        case 'childArray':
          return children.map(function (el) {
            return !!el && /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_0__.cloneElement)(el, childProps);
          });

        default:
          return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(WrapperTag, null);
      }
    }
  }]);

  return ResizeDetector;
}(react__WEBPACK_IMPORTED_MODULE_0__.PureComponent);

ResizeDetector.defaultProps = {
  handleWidth: true,
  handleHeight: true,
  skipOnMount: false,
  refreshRate: 1000,
  refreshMode: undefined,
  refreshOptions: undefined,
  querySelector: null,
  targetDomEl: null,
  targetRef: null,
  onResize: null,
  render: undefined,
  children: null,
  nodeType: 'div'
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ResizeDetector);

/***/ }),

/***/ "../../node_modules/react-resize-detector/lib/esm/hoc/withResizeDetector.js":
/*!**********************************************************************************!*\
  !*** ../../node_modules/react-resize-detector/lib/esm/hoc/withResizeDetector.js ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _components_ResizeDetector__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../components/ResizeDetector */ "../../node_modules/react-resize-detector/lib/esm/components/ResizeDetector.js");
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }




function withResizeDetector(Component) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
    handleWidth: true,
    handleHeight: true
  };

  var ResizeDetectorHOC = /*#__PURE__*/function (_React$Component) {
    _inherits(ResizeDetectorHOC, _React$Component);

    var _super = _createSuper(ResizeDetectorHOC);

    function ResizeDetectorHOC() {
      var _this;

      _classCallCheck(this, ResizeDetectorHOC);

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      _this = _super.call.apply(_super, [this].concat(args));

      _defineProperty(_assertThisInitialized(_this), "ref", /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_0__.createRef)());

      return _this;
    }

    _createClass(ResizeDetectorHOC, [{
      key: "render",
      value: function render() {
        var _this$props = this.props,
            forwardedRef = _this$props.forwardedRef,
            rest = _objectWithoutProperties(_this$props, ["forwardedRef"]);

        var targetRef = forwardedRef || this.ref;
        return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_components_ResizeDetector__WEBPACK_IMPORTED_MODULE_1__["default"], _extends({}, options, {
          targetRef: targetRef
        }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Component, _extends({
          targetRef: targetRef
        }, rest)));
      }
    }]);

    return ResizeDetectorHOC;
  }((react__WEBPACK_IMPORTED_MODULE_0___default().Component));

  function forwardRefWrapper(props, ref) {
    return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(ResizeDetectorHOC, _extends({}, props, {
      forwardedRef: ref
    }));
  }

  var name = Component.displayName || Component.name;
  forwardRefWrapper.displayName = "withResizeDetector(".concat(name, ")");
  ResizeDetectorHOC.defaultProps = {
    forwardedRef: undefined
  };
  return /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_0__.forwardRef)(forwardRefWrapper);
}

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (withResizeDetector);

/***/ }),

/***/ "../../node_modules/react-resize-detector/lib/esm/index.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/react-resize-detector/lib/esm/index.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__),
/* harmony export */   "withResizeDetector": () => (/* reexport safe */ _hoc_withResizeDetector__WEBPACK_IMPORTED_MODULE_0__["default"])
/* harmony export */ });
/* harmony import */ var _components_ResizeDetector__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./components/ResizeDetector */ "../../node_modules/react-resize-detector/lib/esm/components/ResizeDetector.js");
/* harmony import */ var _hoc_withResizeDetector__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./hoc/withResizeDetector */ "../../node_modules/react-resize-detector/lib/esm/hoc/withResizeDetector.js");



/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_components_ResizeDetector__WEBPACK_IMPORTED_MODULE_1__["default"]);

/***/ }),

/***/ "../../node_modules/react-resize-detector/lib/esm/lib/utils.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/react-resize-detector/lib/esm/lib/utils.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "getHandle": () => (/* binding */ getHandle),
/* harmony export */   "isDOMElement": () => (/* binding */ isDOMElement),
/* harmony export */   "isFunction": () => (/* binding */ isFunction),
/* harmony export */   "isSSR": () => (/* binding */ isSSR),
/* harmony export */   "listHandle": () => (/* binding */ listHandle)
/* harmony export */ });
/* harmony import */ var lodash_debounce__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lodash/debounce */ "../../node_modules/lodash/debounce.js");
/* harmony import */ var lodash_debounce__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash_debounce__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var lodash_throttle__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! lodash/throttle */ "../../node_modules/lodash/throttle.js");
/* harmony import */ var lodash_throttle__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(lodash_throttle__WEBPACK_IMPORTED_MODULE_1__);


var listHandle = {
  debounce: (lodash_debounce__WEBPACK_IMPORTED_MODULE_0___default()),
  throttle: (lodash_throttle__WEBPACK_IMPORTED_MODULE_1___default())
};
var getHandle = function getHandle(type) {
  return listHandle[type];
};
var isFunction = function isFunction(fn) {
  return typeof fn === 'function';
};
var isSSR = function isSSR() {
  return typeof window === 'undefined';
};
var isDOMElement = function isDOMElement(element) {
  return element instanceof Element || element instanceof HTMLDocument;
};

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/ArrowKeyStepper/ArrowKeyStepper.js":
/*!***************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/ArrowKeyStepper/ArrowKeyStepper.js ***!
  \***************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_7__);
/* harmony import */ var react_lifecycles_compat__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! react-lifecycles-compat */ "../../node_modules/react-lifecycles-compat/react-lifecycles-compat.es.js");
/* harmony import */ var _Grid__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../Grid */ "../../node_modules/react-virtualized/dist/es/Grid/index.js");
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/ArrowKeyStepper/types.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_9__);








var _class, _temp;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }



/**
 * This HOC decorates a virtualized component and responds to arrow-key events by scrolling one row or column at a time.
 */

var ArrowKeyStepper = (_temp = _class =
/*#__PURE__*/
function (_React$PureComponent) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(ArrowKeyStepper, _React$PureComponent);

  function ArrowKeyStepper() {
    var _getPrototypeOf2;

    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, ArrowKeyStepper);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__["default"])(this, (_getPrototypeOf2 = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(ArrowKeyStepper)).call.apply(_getPrototypeOf2, [this].concat(args)));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "state", {
      scrollToColumn: 0,
      scrollToRow: 0,
      instanceProps: {
        prevScrollToColumn: 0,
        prevScrollToRow: 0
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_columnStartIndex", 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_columnStopIndex", 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_rowStartIndex", 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_rowStopIndex", 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_onKeyDown", function (event) {
      var _this$props = _this.props,
          columnCount = _this$props.columnCount,
          disabled = _this$props.disabled,
          mode = _this$props.mode,
          rowCount = _this$props.rowCount;

      if (disabled) {
        return;
      }

      var _this$_getScrollState = _this._getScrollState(),
          scrollToColumnPrevious = _this$_getScrollState.scrollToColumn,
          scrollToRowPrevious = _this$_getScrollState.scrollToRow;

      var _this$_getScrollState2 = _this._getScrollState(),
          scrollToColumn = _this$_getScrollState2.scrollToColumn,
          scrollToRow = _this$_getScrollState2.scrollToRow; // The above cases all prevent default event event behavior.
      // This is to keep the grid from scrolling after the snap-to update.


      switch (event.key) {
        case 'ArrowDown':
          scrollToRow = mode === 'cells' ? Math.min(scrollToRow + 1, rowCount - 1) : Math.min(_this._rowStopIndex + 1, rowCount - 1);
          break;

        case 'ArrowLeft':
          scrollToColumn = mode === 'cells' ? Math.max(scrollToColumn - 1, 0) : Math.max(_this._columnStartIndex - 1, 0);
          break;

        case 'ArrowRight':
          scrollToColumn = mode === 'cells' ? Math.min(scrollToColumn + 1, columnCount - 1) : Math.min(_this._columnStopIndex + 1, columnCount - 1);
          break;

        case 'ArrowUp':
          scrollToRow = mode === 'cells' ? Math.max(scrollToRow - 1, 0) : Math.max(_this._rowStartIndex - 1, 0);
          break;
      }

      if (scrollToColumn !== scrollToColumnPrevious || scrollToRow !== scrollToRowPrevious) {
        event.preventDefault();

        _this._updateScrollState({
          scrollToColumn: scrollToColumn,
          scrollToRow: scrollToRow
        });
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_onSectionRendered", function (_ref) {
      var columnStartIndex = _ref.columnStartIndex,
          columnStopIndex = _ref.columnStopIndex,
          rowStartIndex = _ref.rowStartIndex,
          rowStopIndex = _ref.rowStopIndex;
      _this._columnStartIndex = columnStartIndex;
      _this._columnStopIndex = columnStopIndex;
      _this._rowStartIndex = rowStartIndex;
      _this._rowStopIndex = rowStopIndex;
    });

    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(ArrowKeyStepper, [{
    key: "setScrollIndexes",
    value: function setScrollIndexes(_ref2) {
      var scrollToColumn = _ref2.scrollToColumn,
          scrollToRow = _ref2.scrollToRow;
      this.setState({
        scrollToRow: scrollToRow,
        scrollToColumn: scrollToColumn
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          className = _this$props2.className,
          children = _this$props2.children;

      var _this$_getScrollState3 = this._getScrollState(),
          scrollToColumn = _this$_getScrollState3.scrollToColumn,
          scrollToRow = _this$_getScrollState3.scrollToRow;

      return react__WEBPACK_IMPORTED_MODULE_7__.createElement("div", {
        className: className,
        onKeyDown: this._onKeyDown
      }, children({
        onSectionRendered: this._onSectionRendered,
        scrollToColumn: scrollToColumn,
        scrollToRow: scrollToRow
      }));
    }
  }, {
    key: "_getScrollState",
    value: function _getScrollState() {
      return this.props.isControlled ? this.props : this.state;
    }
  }, {
    key: "_updateScrollState",
    value: function _updateScrollState(_ref3) {
      var scrollToColumn = _ref3.scrollToColumn,
          scrollToRow = _ref3.scrollToRow;
      var _this$props3 = this.props,
          isControlled = _this$props3.isControlled,
          onScrollToChange = _this$props3.onScrollToChange;

      if (typeof onScrollToChange === 'function') {
        onScrollToChange({
          scrollToColumn: scrollToColumn,
          scrollToRow: scrollToRow
        });
      }

      if (!isControlled) {
        this.setState({
          scrollToColumn: scrollToColumn,
          scrollToRow: scrollToRow
        });
      }
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(nextProps, prevState) {
      if (nextProps.isControlled) {
        return {};
      }

      if (nextProps.scrollToColumn !== prevState.instanceProps.prevScrollToColumn || nextProps.scrollToRow !== prevState.instanceProps.prevScrollToRow) {
        return _objectSpread({}, prevState, {
          scrollToColumn: nextProps.scrollToColumn,
          scrollToRow: nextProps.scrollToRow,
          instanceProps: {
            prevScrollToColumn: nextProps.scrollToColumn,
            prevScrollToRow: nextProps.scrollToRow
          }
        });
      }

      return {};
    }
  }]);

  return ArrowKeyStepper;
}(react__WEBPACK_IMPORTED_MODULE_7__.PureComponent), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(_class, "propTypes",  false ? 0 : {
  "children": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func.isRequired),
  "className": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),
  "columnCount": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number.isRequired),
  "disabled": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool.isRequired),
  "isControlled": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool.isRequired),
  "mode": prop_types__WEBPACK_IMPORTED_MODULE_9___default().oneOf(["cells", "edges"]).isRequired,
  "onScrollToChange": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func),
  "rowCount": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number.isRequired),
  "scrollToColumn": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number.isRequired),
  "scrollToRow": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number.isRequired)
}), _temp);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(ArrowKeyStepper, "defaultProps", {
  disabled: false,
  isControlled: false,
  mode: 'edges',
  scrollToColumn: 0,
  scrollToRow: 0
});

(0,react_lifecycles_compat__WEBPACK_IMPORTED_MODULE_8__.polyfill)(ArrowKeyStepper);
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ArrowKeyStepper);




/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/ArrowKeyStepper/index.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/ArrowKeyStepper/index.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "ArrowKeyStepper": () => (/* reexport safe */ _ArrowKeyStepper__WEBPACK_IMPORTED_MODULE_0__["default"]),
/* harmony export */   "bpfrpt_proptype_ScrollIndices": () => (/* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_1__.bpfrpt_proptype_ScrollIndices),
/* harmony export */   "default": () => (/* reexport safe */ _ArrowKeyStepper__WEBPACK_IMPORTED_MODULE_0__["default"])
/* harmony export */ });
/* harmony import */ var _ArrowKeyStepper__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./ArrowKeyStepper */ "../../node_modules/react-virtualized/dist/es/ArrowKeyStepper/ArrowKeyStepper.js");
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/ArrowKeyStepper/types.js");





/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/ArrowKeyStepper/types.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/ArrowKeyStepper/types.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "bpfrpt_proptype_ScrollIndices": () => (/* binding */ bpfrpt_proptype_ScrollIndices)
/* harmony export */ });
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_0__);
var bpfrpt_proptype_ScrollIndices =  false ? 0 : {
  "scrollToColumn": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().number.isRequired),
  "scrollToRow": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().number.isRequired)
};



/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/AutoSizer/AutoSizer.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/AutoSizer/AutoSizer.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ AutoSizer)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_7__);
/* harmony import */ var _vendor_detectElementResize__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../vendor/detectElementResize */ "../../node_modules/react-virtualized/dist/es/vendor/detectElementResize.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_9__);








var _class, _temp;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }



var AutoSizer = (_temp = _class =
/*#__PURE__*/
function (_React$Component) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(AutoSizer, _React$Component);

  function AutoSizer() {
    var _getPrototypeOf2;

    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, AutoSizer);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__["default"])(this, (_getPrototypeOf2 = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(AutoSizer)).call.apply(_getPrototypeOf2, [this].concat(args)));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "state", {
      height: _this.props.defaultHeight || 0,
      width: _this.props.defaultWidth || 0
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_parentNode", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_autoSizer", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_window", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_detectElementResize", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_onResize", function () {
      var _this$props = _this.props,
          disableHeight = _this$props.disableHeight,
          disableWidth = _this$props.disableWidth,
          onResize = _this$props.onResize;

      if (_this._parentNode) {
        // Guard against AutoSizer component being removed from the DOM immediately after being added.
        // This can result in invalid style values which can result in NaN values if we don't handle them.
        // See issue #150 for more context.
        var height = _this._parentNode.offsetHeight || 0;
        var width = _this._parentNode.offsetWidth || 0;
        var win = _this._window || window;
        var style = win.getComputedStyle(_this._parentNode) || {};
        var paddingLeft = parseInt(style.paddingLeft, 10) || 0;
        var paddingRight = parseInt(style.paddingRight, 10) || 0;
        var paddingTop = parseInt(style.paddingTop, 10) || 0;
        var paddingBottom = parseInt(style.paddingBottom, 10) || 0;
        var newHeight = height - paddingTop - paddingBottom;
        var newWidth = width - paddingLeft - paddingRight;

        if (!disableHeight && _this.state.height !== newHeight || !disableWidth && _this.state.width !== newWidth) {
          _this.setState({
            height: height - paddingTop - paddingBottom,
            width: width - paddingLeft - paddingRight
          });

          onResize({
            height: height,
            width: width
          });
        }
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_setRef", function (autoSizer) {
      _this._autoSizer = autoSizer;
    });

    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(AutoSizer, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var nonce = this.props.nonce;

      if (this._autoSizer && this._autoSizer.parentNode && this._autoSizer.parentNode.ownerDocument && this._autoSizer.parentNode.ownerDocument.defaultView && this._autoSizer.parentNode instanceof this._autoSizer.parentNode.ownerDocument.defaultView.HTMLElement) {
        // Delay access of parentNode until mount.
        // This handles edge-cases where the component has already been unmounted before its ref has been set,
        // As well as libraries like react-lite which have a slightly different lifecycle.
        this._parentNode = this._autoSizer.parentNode;
        this._window = this._autoSizer.parentNode.ownerDocument.defaultView; // Defer requiring resize handler in order to support server-side rendering.
        // See issue #41

        this._detectElementResize = (0,_vendor_detectElementResize__WEBPACK_IMPORTED_MODULE_8__["default"])(nonce, this._window);

        this._detectElementResize.addResizeListener(this._parentNode, this._onResize);

        this._onResize();
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      if (this._detectElementResize && this._parentNode) {
        this._detectElementResize.removeResizeListener(this._parentNode, this._onResize);
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          className = _this$props2.className,
          disableHeight = _this$props2.disableHeight,
          disableWidth = _this$props2.disableWidth,
          style = _this$props2.style;
      var _this$state = this.state,
          height = _this$state.height,
          width = _this$state.width; // Outer div should not force width/height since that may prevent containers from shrinking.
      // Inner component should overflow and use calculated width/height.
      // See issue #68 for more information.

      var outerStyle = {
        overflow: 'visible'
      };
      var childParams = {};

      if (!disableHeight) {
        outerStyle.height = 0;
        childParams.height = height;
      }

      if (!disableWidth) {
        outerStyle.width = 0;
        childParams.width = width;
      }
      /**
       * TODO: Avoid rendering children before the initial measurements have been collected.
       * At best this would just be wasting cycles.
       * Add this check into version 10 though as it could break too many ref callbacks in version 9.
       * Note that if default width/height props were provided this would still work with SSR.
      if (
        height !== 0 &&
        width !== 0
      ) {
        child = children({ height, width })
      }
      */


      return react__WEBPACK_IMPORTED_MODULE_7__.createElement("div", {
        className: className,
        ref: this._setRef,
        style: _objectSpread({}, outerStyle, {}, style)
      }, children(childParams));
    }
  }]);

  return AutoSizer;
}(react__WEBPACK_IMPORTED_MODULE_7__.Component), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(_class, "propTypes",  false ? 0 : {
  /** Function responsible for rendering children.*/
  "children": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func.isRequired),

  /** Optional custom CSS class name to attach to root AutoSizer element.  */
  "className": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),

  /** Default height to use for initial render; useful for SSR */
  "defaultHeight": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number),

  /** Default width to use for initial render; useful for SSR */
  "defaultWidth": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number),

  /** Disable dynamic :height property */
  "disableHeight": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool.isRequired),

  /** Disable dynamic :width property */
  "disableWidth": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool.isRequired),

  /** Nonce of the inlined stylesheet for Content Security Policy */
  "nonce": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),

  /** Callback to be invoked on-resize */
  "onResize": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func.isRequired),

  /** Optional inline style */
  "style": (prop_types__WEBPACK_IMPORTED_MODULE_9___default().object)
}), _temp);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(AutoSizer, "defaultProps", {
  onResize: function onResize() {},
  disableHeight: false,
  disableWidth: false,
  style: {}
});




/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/AutoSizer/index.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/AutoSizer/index.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "AutoSizer": () => (/* reexport safe */ _AutoSizer__WEBPACK_IMPORTED_MODULE_0__["default"]),
/* harmony export */   "default": () => (/* reexport safe */ _AutoSizer__WEBPACK_IMPORTED_MODULE_0__["default"])
/* harmony export */ });
/* harmony import */ var _AutoSizer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./AutoSizer */ "../../node_modules/react-virtualized/dist/es/AutoSizer/AutoSizer.js");



/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/CellMeasurer/CellMeasurer.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/CellMeasurer/CellMeasurer.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ CellMeasurer)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_7__);
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! react-dom */ "webpack/sharing/consume/default/react-dom");
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(react_dom__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/CellMeasurer/types.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_10___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_10__);








var _class, _temp;




/**
 * Wraps a cell and measures its rendered content.
 * Measurements are stored in a per-cell cache.
 * Cached-content is not be re-measured.
 */
var CellMeasurer = (_temp = _class =
/*#__PURE__*/
function (_React$PureComponent) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(CellMeasurer, _React$PureComponent);

  function CellMeasurer() {
    var _getPrototypeOf2;

    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, CellMeasurer);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__["default"])(this, (_getPrototypeOf2 = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(CellMeasurer)).call.apply(_getPrototypeOf2, [this].concat(args)));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_child", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_measure", function () {
      var _this$props = _this.props,
          cache = _this$props.cache,
          _this$props$columnInd = _this$props.columnIndex,
          columnIndex = _this$props$columnInd === void 0 ? 0 : _this$props$columnInd,
          parent = _this$props.parent,
          _this$props$rowIndex = _this$props.rowIndex,
          rowIndex = _this$props$rowIndex === void 0 ? _this.props.index || 0 : _this$props$rowIndex;

      var _this$_getCellMeasure = _this._getCellMeasurements(),
          height = _this$_getCellMeasure.height,
          width = _this$_getCellMeasure.width;

      if (height !== cache.getHeight(rowIndex, columnIndex) || width !== cache.getWidth(rowIndex, columnIndex)) {
        cache.set(rowIndex, columnIndex, width, height);

        if (parent && typeof parent.recomputeGridSize === 'function') {
          parent.recomputeGridSize({
            columnIndex: columnIndex,
            rowIndex: rowIndex
          });
        }
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_registerChild", function (element) {
      if (element && !(element instanceof Element)) {
        console.warn('CellMeasurer registerChild expects to be passed Element or null');
      }

      _this._child = element;

      if (element) {
        _this._maybeMeasureCell();
      }
    });

    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(CellMeasurer, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this._maybeMeasureCell();
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      this._maybeMeasureCell();
    }
  }, {
    key: "render",
    value: function render() {
      var children = this.props.children;
      return typeof children === 'function' ? children({
        measure: this._measure,
        registerChild: this._registerChild
      }) : children;
    }
  }, {
    key: "_getCellMeasurements",
    value: function _getCellMeasurements() {
      var cache = this.props.cache;
      var node = this._child || (0,react_dom__WEBPACK_IMPORTED_MODULE_8__.findDOMNode)(this); // TODO Check for a bad combination of fixedWidth and missing numeric width or vice versa with height

      if (node && node.ownerDocument && node.ownerDocument.defaultView && node instanceof node.ownerDocument.defaultView.HTMLElement) {
        var styleWidth = node.style.width;
        var styleHeight = node.style.height; // If we are re-measuring a cell that has already been measured,
        // It will have a hard-coded width/height from the previous measurement.
        // The fact that we are measuring indicates this measurement is probably stale,
        // So explicitly clear it out (eg set to "auto") so we can recalculate.
        // See issue #593 for more info.
        // Even if we are measuring initially- if we're inside of a MultiGrid component,
        // Explicitly clear width/height before measuring to avoid being tainted by another Grid.
        // eg top/left Grid renders before bottom/right Grid
        // Since the CellMeasurerCache is shared between them this taints derived cell size values.

        if (!cache.hasFixedWidth()) {
          node.style.width = 'auto';
        }

        if (!cache.hasFixedHeight()) {
          node.style.height = 'auto';
        }

        var height = Math.ceil(node.offsetHeight);
        var width = Math.ceil(node.offsetWidth); // Reset after measuring to avoid breaking styles; see #660

        if (styleWidth) {
          node.style.width = styleWidth;
        }

        if (styleHeight) {
          node.style.height = styleHeight;
        }

        return {
          height: height,
          width: width
        };
      } else {
        return {
          height: 0,
          width: 0
        };
      }
    }
  }, {
    key: "_maybeMeasureCell",
    value: function _maybeMeasureCell() {
      var _this$props2 = this.props,
          cache = _this$props2.cache,
          _this$props2$columnIn = _this$props2.columnIndex,
          columnIndex = _this$props2$columnIn === void 0 ? 0 : _this$props2$columnIn,
          parent = _this$props2.parent,
          _this$props2$rowIndex = _this$props2.rowIndex,
          rowIndex = _this$props2$rowIndex === void 0 ? this.props.index || 0 : _this$props2$rowIndex;

      if (!cache.has(rowIndex, columnIndex)) {
        var _this$_getCellMeasure2 = this._getCellMeasurements(),
            height = _this$_getCellMeasure2.height,
            width = _this$_getCellMeasure2.width;

        cache.set(rowIndex, columnIndex, width, height); // If size has changed, let Grid know to re-render.

        if (parent && typeof parent.invalidateCellSizeAfterRender === 'function') {
          parent.invalidateCellSizeAfterRender({
            columnIndex: columnIndex,
            rowIndex: rowIndex
          });
        }
      }
    }
  }]);

  return CellMeasurer;
}(react__WEBPACK_IMPORTED_MODULE_7__.PureComponent), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(_class, "propTypes",  false ? 0 : {
  "cache": function cache() {
    return (typeof _types__WEBPACK_IMPORTED_MODULE_9__.bpfrpt_proptype_CellMeasureCache === "function" ? _types__WEBPACK_IMPORTED_MODULE_9__.bpfrpt_proptype_CellMeasureCache.isRequired ? _types__WEBPACK_IMPORTED_MODULE_9__.bpfrpt_proptype_CellMeasureCache.isRequired : _types__WEBPACK_IMPORTED_MODULE_9__.bpfrpt_proptype_CellMeasureCache : prop_types__WEBPACK_IMPORTED_MODULE_10___default().shape(_types__WEBPACK_IMPORTED_MODULE_9__.bpfrpt_proptype_CellMeasureCache).isRequired).apply(this, arguments);
  },
  "children": prop_types__WEBPACK_IMPORTED_MODULE_10___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_10___default().func), (prop_types__WEBPACK_IMPORTED_MODULE_10___default().node)]).isRequired,
  "columnIndex": (prop_types__WEBPACK_IMPORTED_MODULE_10___default().number),
  "index": (prop_types__WEBPACK_IMPORTED_MODULE_10___default().number),
  "parent": prop_types__WEBPACK_IMPORTED_MODULE_10___default().shape({
    invalidateCellSizeAfterRender: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().func),
    recomputeGridSize: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().func)
  }).isRequired,
  "rowIndex": (prop_types__WEBPACK_IMPORTED_MODULE_10___default().number)
}), _temp); // Used for DEV mode warning check

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(CellMeasurer, "__internalCellMeasurerFlag", false);



if (true) {
  CellMeasurer.__internalCellMeasurerFlag = true;
}




/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/CellMeasurer/CellMeasurerCache.js":
/*!**************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/CellMeasurer/CellMeasurerCache.js ***!
  \**************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "DEFAULT_HEIGHT": () => (/* binding */ DEFAULT_HEIGHT),
/* harmony export */   "DEFAULT_WIDTH": () => (/* binding */ DEFAULT_WIDTH),
/* harmony export */   "default": () => (/* binding */ CellMeasurerCache)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/CellMeasurer/types.js");



var DEFAULT_HEIGHT = 30;
var DEFAULT_WIDTH = 100; // Enables more intelligent mapping of a given column and row index to an item ID.
// This prevents a cell cache from being invalidated when its parent collection is modified.

/**
 * Caches measurements for a given cell.
 */
var CellMeasurerCache =
/*#__PURE__*/
function () {
  function CellMeasurerCache() {
    var _this = this;

    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, CellMeasurerCache);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_cellHeightCache", {});

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_cellWidthCache", {});

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_columnWidthCache", {});

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_rowHeightCache", {});

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_defaultHeight", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_defaultWidth", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_minHeight", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_minWidth", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_keyMapper", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_hasFixedHeight", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_hasFixedWidth", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_columnCount", 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_rowCount", 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "columnWidth", function (_ref) {
      var index = _ref.index;

      var key = _this._keyMapper(0, index);

      return _this._columnWidthCache[key] !== undefined ? _this._columnWidthCache[key] : _this._defaultWidth;
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "rowHeight", function (_ref2) {
      var index = _ref2.index;

      var key = _this._keyMapper(index, 0);

      return _this._rowHeightCache[key] !== undefined ? _this._rowHeightCache[key] : _this._defaultHeight;
    });

    var defaultHeight = params.defaultHeight,
        defaultWidth = params.defaultWidth,
        fixedHeight = params.fixedHeight,
        fixedWidth = params.fixedWidth,
        keyMapper = params.keyMapper,
        minHeight = params.minHeight,
        minWidth = params.minWidth;
    this._hasFixedHeight = fixedHeight === true;
    this._hasFixedWidth = fixedWidth === true;
    this._minHeight = minHeight || 0;
    this._minWidth = minWidth || 0;
    this._keyMapper = keyMapper || defaultKeyMapper;
    this._defaultHeight = Math.max(this._minHeight, typeof defaultHeight === 'number' ? defaultHeight : DEFAULT_HEIGHT);
    this._defaultWidth = Math.max(this._minWidth, typeof defaultWidth === 'number' ? defaultWidth : DEFAULT_WIDTH);

    if (true) {
      if (this._hasFixedHeight === false && this._hasFixedWidth === false) {
        console.warn("CellMeasurerCache should only measure a cell's width or height. " + 'You have configured CellMeasurerCache to measure both. ' + 'This will result in poor performance.');
      }

      if (this._hasFixedHeight === false && this._defaultHeight === 0) {
        console.warn('Fixed height CellMeasurerCache should specify a :defaultHeight greater than 0. ' + 'Failing to do so will lead to unnecessary layout and poor performance.');
      }

      if (this._hasFixedWidth === false && this._defaultWidth === 0) {
        console.warn('Fixed width CellMeasurerCache should specify a :defaultWidth greater than 0. ' + 'Failing to do so will lead to unnecessary layout and poor performance.');
      }
    }
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(CellMeasurerCache, [{
    key: "clear",
    value: function clear(rowIndex) {
      var columnIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;

      var key = this._keyMapper(rowIndex, columnIndex);

      delete this._cellHeightCache[key];
      delete this._cellWidthCache[key];

      this._updateCachedColumnAndRowSizes(rowIndex, columnIndex);
    }
  }, {
    key: "clearAll",
    value: function clearAll() {
      this._cellHeightCache = {};
      this._cellWidthCache = {};
      this._columnWidthCache = {};
      this._rowHeightCache = {};
      this._rowCount = 0;
      this._columnCount = 0;
    }
  }, {
    key: "hasFixedHeight",
    value: function hasFixedHeight() {
      return this._hasFixedHeight;
    }
  }, {
    key: "hasFixedWidth",
    value: function hasFixedWidth() {
      return this._hasFixedWidth;
    }
  }, {
    key: "getHeight",
    value: function getHeight(rowIndex) {
      var columnIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;

      if (this._hasFixedHeight) {
        return this._defaultHeight;
      } else {
        var _key = this._keyMapper(rowIndex, columnIndex);

        return this._cellHeightCache[_key] !== undefined ? Math.max(this._minHeight, this._cellHeightCache[_key]) : this._defaultHeight;
      }
    }
  }, {
    key: "getWidth",
    value: function getWidth(rowIndex) {
      var columnIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;

      if (this._hasFixedWidth) {
        return this._defaultWidth;
      } else {
        var _key2 = this._keyMapper(rowIndex, columnIndex);

        return this._cellWidthCache[_key2] !== undefined ? Math.max(this._minWidth, this._cellWidthCache[_key2]) : this._defaultWidth;
      }
    }
  }, {
    key: "has",
    value: function has(rowIndex) {
      var columnIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;

      var key = this._keyMapper(rowIndex, columnIndex);

      return this._cellHeightCache[key] !== undefined;
    }
  }, {
    key: "set",
    value: function set(rowIndex, columnIndex, width, height) {
      var key = this._keyMapper(rowIndex, columnIndex);

      if (columnIndex >= this._columnCount) {
        this._columnCount = columnIndex + 1;
      }

      if (rowIndex >= this._rowCount) {
        this._rowCount = rowIndex + 1;
      } // Size is cached per cell so we don't have to re-measure if cells are re-ordered.


      this._cellHeightCache[key] = height;
      this._cellWidthCache[key] = width;

      this._updateCachedColumnAndRowSizes(rowIndex, columnIndex);
    }
  }, {
    key: "_updateCachedColumnAndRowSizes",
    value: function _updateCachedColumnAndRowSizes(rowIndex, columnIndex) {
      // :columnWidth and :rowHeight are derived based on all cells in a column/row.
      // Pre-cache these derived values for faster lookup later.
      // Reads are expected to occur more frequently than writes in this case.
      // Only update non-fixed dimensions though to avoid doing unnecessary work.
      if (!this._hasFixedWidth) {
        var columnWidth = 0;

        for (var i = 0; i < this._rowCount; i++) {
          columnWidth = Math.max(columnWidth, this.getWidth(i, columnIndex));
        }

        var columnKey = this._keyMapper(0, columnIndex);

        this._columnWidthCache[columnKey] = columnWidth;
      }

      if (!this._hasFixedHeight) {
        var rowHeight = 0;

        for (var _i = 0; _i < this._columnCount; _i++) {
          rowHeight = Math.max(rowHeight, this.getHeight(rowIndex, _i));
        }

        var rowKey = this._keyMapper(rowIndex, 0);

        this._rowHeightCache[rowKey] = rowHeight;
      }
    }
  }, {
    key: "defaultHeight",
    get: function get() {
      return this._defaultHeight;
    }
  }, {
    key: "defaultWidth",
    get: function get() {
      return this._defaultWidth;
    }
  }]);

  return CellMeasurerCache;
}();



function defaultKeyMapper(rowIndex, columnIndex) {
  return "".concat(rowIndex, "-").concat(columnIndex);
}



/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/CellMeasurer/index.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/CellMeasurer/index.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "CellMeasurer": () => (/* reexport safe */ _CellMeasurer__WEBPACK_IMPORTED_MODULE_0__["default"]),
/* harmony export */   "CellMeasurerCache": () => (/* reexport safe */ _CellMeasurerCache__WEBPACK_IMPORTED_MODULE_1__["default"]),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _CellMeasurer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./CellMeasurer */ "../../node_modules/react-virtualized/dist/es/CellMeasurer/CellMeasurer.js");
/* harmony import */ var _CellMeasurerCache__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./CellMeasurerCache */ "../../node_modules/react-virtualized/dist/es/CellMeasurer/CellMeasurerCache.js");


/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_CellMeasurer__WEBPACK_IMPORTED_MODULE_0__["default"]);


/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/CellMeasurer/types.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/CellMeasurer/types.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "bpfrpt_proptype_CellMeasureCache": () => (/* binding */ bpfrpt_proptype_CellMeasureCache)
/* harmony export */ });
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_0__);
var bpfrpt_proptype_CellMeasureCache =  false ? 0 : {
  "hasFixedWidth": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().func.isRequired),
  "hasFixedHeight": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().func.isRequired),
  "has": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().func.isRequired),
  "set": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().func.isRequired),
  "getHeight": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().func.isRequired),
  "getWidth": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().func.isRequired)
};



/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Collection/Collection.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Collection/Collection.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ Collection)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_12___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_12__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */ var _CollectionView__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./CollectionView */ "../../node_modules/react-virtualized/dist/es/Collection/CollectionView.js");
/* harmony import */ var _utils_calculateSizeAndPositionData__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./utils/calculateSizeAndPositionData */ "../../node_modules/react-virtualized/dist/es/Collection/utils/calculateSizeAndPositionData.js");
/* harmony import */ var _utils_getUpdatedOffsetForIndex__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../utils/getUpdatedOffsetForIndex */ "../../node_modules/react-virtualized/dist/es/utils/getUpdatedOffsetForIndex.js");
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/Collection/types.js");














/**
 * Renders scattered or non-linear data.
 * Unlike Grid, which renders checkerboard data, Collection can render arbitrarily positioned- even overlapping- data.
 */
var Collection =
/*#__PURE__*/
function (_React$PureComponent) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_6__["default"])(Collection, _React$PureComponent);

  function Collection(props, context) {
    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_1__["default"])(this, Collection);

    _this = (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_3__["default"])(this, (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_4__["default"])(Collection).call(this, props, context));
    _this._cellMetadata = [];
    _this._lastRenderedCellIndices = []; // Cell cache during scroll (for performance)

    _this._cellCache = [];
    _this._isScrollingChange = _this._isScrollingChange.bind((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this));
    _this._setCollectionViewRef = _this._setCollectionViewRef.bind((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this));
    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(Collection, [{
    key: "forceUpdate",
    value: function forceUpdate() {
      if (this._collectionView !== undefined) {
        this._collectionView.forceUpdate();
      }
    }
    /** See Collection#recomputeCellSizesAndPositions */

  }, {
    key: "recomputeCellSizesAndPositions",
    value: function recomputeCellSizesAndPositions() {
      this._cellCache = [];

      this._collectionView.recomputeCellSizesAndPositions();
    }
    /** React lifecycle methods */

  }, {
    key: "render",
    value: function render() {
      var props = (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, this.props);

      return react__WEBPACK_IMPORTED_MODULE_8__.createElement(_CollectionView__WEBPACK_IMPORTED_MODULE_9__["default"], (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
        cellLayoutManager: this,
        isScrollingChange: this._isScrollingChange,
        ref: this._setCollectionViewRef
      }, props));
    }
    /** CellLayoutManager interface */

  }, {
    key: "calculateSizeAndPositionData",
    value: function calculateSizeAndPositionData() {
      var _this$props = this.props,
          cellCount = _this$props.cellCount,
          cellSizeAndPositionGetter = _this$props.cellSizeAndPositionGetter,
          sectionSize = _this$props.sectionSize;

      var data = (0,_utils_calculateSizeAndPositionData__WEBPACK_IMPORTED_MODULE_10__["default"])({
        cellCount: cellCount,
        cellSizeAndPositionGetter: cellSizeAndPositionGetter,
        sectionSize: sectionSize
      });

      this._cellMetadata = data.cellMetadata;
      this._sectionManager = data.sectionManager;
      this._height = data.height;
      this._width = data.width;
    }
    /**
     * Returns the most recently rendered set of cell indices.
     */

  }, {
    key: "getLastRenderedIndices",
    value: function getLastRenderedIndices() {
      return this._lastRenderedCellIndices;
    }
    /**
     * Calculates the minimum amount of change from the current scroll position to ensure the specified cell is (fully) visible.
     */

  }, {
    key: "getScrollPositionForCell",
    value: function getScrollPositionForCell(_ref) {
      var align = _ref.align,
          cellIndex = _ref.cellIndex,
          height = _ref.height,
          scrollLeft = _ref.scrollLeft,
          scrollTop = _ref.scrollTop,
          width = _ref.width;
      var cellCount = this.props.cellCount;

      if (cellIndex >= 0 && cellIndex < cellCount) {
        var cellMetadata = this._cellMetadata[cellIndex];
        scrollLeft = (0,_utils_getUpdatedOffsetForIndex__WEBPACK_IMPORTED_MODULE_11__["default"])({
          align: align,
          cellOffset: cellMetadata.x,
          cellSize: cellMetadata.width,
          containerSize: width,
          currentOffset: scrollLeft,
          targetIndex: cellIndex
        });
        scrollTop = (0,_utils_getUpdatedOffsetForIndex__WEBPACK_IMPORTED_MODULE_11__["default"])({
          align: align,
          cellOffset: cellMetadata.y,
          cellSize: cellMetadata.height,
          containerSize: height,
          currentOffset: scrollTop,
          targetIndex: cellIndex
        });
      }

      return {
        scrollLeft: scrollLeft,
        scrollTop: scrollTop
      };
    }
  }, {
    key: "getTotalSize",
    value: function getTotalSize() {
      return {
        height: this._height,
        width: this._width
      };
    }
  }, {
    key: "cellRenderers",
    value: function cellRenderers(_ref2) {
      var _this2 = this;

      var height = _ref2.height,
          isScrolling = _ref2.isScrolling,
          width = _ref2.width,
          x = _ref2.x,
          y = _ref2.y;
      var _this$props2 = this.props,
          cellGroupRenderer = _this$props2.cellGroupRenderer,
          cellRenderer = _this$props2.cellRenderer; // Store for later calls to getLastRenderedIndices()

      this._lastRenderedCellIndices = this._sectionManager.getCellIndices({
        height: height,
        width: width,
        x: x,
        y: y
      });
      return cellGroupRenderer({
        cellCache: this._cellCache,
        cellRenderer: cellRenderer,
        cellSizeAndPositionGetter: function cellSizeAndPositionGetter(_ref3) {
          var index = _ref3.index;
          return _this2._sectionManager.getCellMetadata({
            index: index
          });
        },
        indices: this._lastRenderedCellIndices,
        isScrolling: isScrolling
      });
    }
  }, {
    key: "_isScrollingChange",
    value: function _isScrollingChange(isScrolling) {
      if (!isScrolling) {
        this._cellCache = [];
      }
    }
  }, {
    key: "_setCollectionViewRef",
    value: function _setCollectionViewRef(ref) {
      this._collectionView = ref;
    }
  }]);

  return Collection;
}(react__WEBPACK_IMPORTED_MODULE_8__.PureComponent);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(Collection, "defaultProps", {
  'aria-label': 'grid',
  cellGroupRenderer: defaultCellGroupRenderer
});


Collection.propTypes =  true ? {
  'aria-label': (prop_types__WEBPACK_IMPORTED_MODULE_12___default().string),

  /**
   * Number of cells in Collection.
   */
  cellCount: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired),

  /**
   * Responsible for rendering a group of cells given their indices.
   * Should implement the following interface: ({
   *   cellSizeAndPositionGetter:Function,
   *   indices: Array<number>,
   *   cellRenderer: Function
   * }): Array<PropTypes.node>
   */
  cellGroupRenderer: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func.isRequired),

  /**
   * Responsible for rendering a cell given an row and column index.
   * Should implement the following interface: ({ index: number, key: string, style: object }): PropTypes.element
   */
  cellRenderer: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func.isRequired),

  /**
   * Callback responsible for returning size and offset/position information for a given cell (index).
   * ({ index: number }): { height: number, width: number, x: number, y: number }
   */
  cellSizeAndPositionGetter: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func.isRequired),

  /**
   * Optionally override the size of the sections a Collection's cells are split into.
   */
  sectionSize: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number)
} : 0;

function defaultCellGroupRenderer(_ref4) {
  var cellCache = _ref4.cellCache,
      cellRenderer = _ref4.cellRenderer,
      cellSizeAndPositionGetter = _ref4.cellSizeAndPositionGetter,
      indices = _ref4.indices,
      isScrolling = _ref4.isScrolling;
  return indices.map(function (index) {
    var cellMetadata = cellSizeAndPositionGetter({
      index: index
    });
    var cellRendererProps = {
      index: index,
      isScrolling: isScrolling,
      key: index,
      style: {
        height: cellMetadata.height,
        left: cellMetadata.x,
        position: 'absolute',
        top: cellMetadata.y,
        width: cellMetadata.width
      }
    }; // Avoid re-creating cells while scrolling.
    // This can lead to the same cell being created many times and can cause performance issues for "heavy" cells.
    // If a scroll is in progress- cache and reuse cells.
    // This cache will be thrown away once scrolling complets.

    if (isScrolling) {
      if (!(index in cellCache)) {
        cellCache[index] = cellRenderer(cellRendererProps);
      }

      return cellCache[index];
    } else {
      return cellRenderer(cellRendererProps);
    }
  }).filter(function (renderedCell) {
    return !!renderedCell;
  });
}




/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Collection/CollectionView.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Collection/CollectionView.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var clsx__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! clsx */ "../../node_modules/clsx/dist/clsx.m.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_12___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_12__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */ var react_lifecycles_compat__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! react-lifecycles-compat */ "../../node_modules/react-lifecycles-compat/react-lifecycles-compat.es.js");
/* harmony import */ var _utils_createCallbackMemoizer__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../utils/createCallbackMemoizer */ "../../node_modules/react-virtualized/dist/es/utils/createCallbackMemoizer.js");
/* harmony import */ var dom_helpers_scrollbarSize__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! dom-helpers/scrollbarSize */ "../../node_modules/dom-helpers/esm/scrollbarSize.js");








function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }






 // @TODO Merge Collection and CollectionView

/**
 * Specifies the number of milliseconds during which to disable pointer events while a scroll is in progress.
 * This improves performance and makes scrolling smoother.
 */

var IS_SCROLLING_TIMEOUT = 150;
/**
 * Controls whether the Grid updates the DOM element's scrollLeft/scrollTop based on the current state or just observes it.
 * This prevents Grid from interrupting mouse-wheel animations (see issue #2).
 */

var SCROLL_POSITION_CHANGE_REASONS = {
  OBSERVED: 'observed',
  REQUESTED: 'requested'
};
/**
 * Monitors changes in properties (eg. cellCount) and state (eg. scroll offsets) to determine when rendering needs to occur.
 * This component does not render any visible content itself; it defers to the specified :cellLayoutManager.
 */

var CollectionView =
/*#__PURE__*/
function (_React$PureComponent) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(CollectionView, _React$PureComponent);

  // Invokes callbacks only when their values have changed.
  function CollectionView() {
    var _getPrototypeOf2;

    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, CollectionView);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__["default"])(this, (_getPrototypeOf2 = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(CollectionView)).call.apply(_getPrototypeOf2, [this].concat(args))); // If this component is being rendered server-side, getScrollbarSize() will return undefined.
    // We handle this case in componentDidMount()

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "state", {
      isScrolling: false,
      scrollLeft: 0,
      scrollTop: 0
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_calculateSizeAndPositionDataOnNextUpdate", false);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_onSectionRenderedMemoizer", (0,_utils_createCallbackMemoizer__WEBPACK_IMPORTED_MODULE_10__["default"])());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_onScrollMemoizer", (0,_utils_createCallbackMemoizer__WEBPACK_IMPORTED_MODULE_10__["default"])(false));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_invokeOnSectionRenderedHelper", function () {
      var _this$props = _this.props,
          cellLayoutManager = _this$props.cellLayoutManager,
          onSectionRendered = _this$props.onSectionRendered;

      _this._onSectionRenderedMemoizer({
        callback: onSectionRendered,
        indices: {
          indices: cellLayoutManager.getLastRenderedIndices()
        }
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_setScrollingContainerRef", function (ref) {
      _this._scrollingContainer = ref;
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_updateScrollPositionForScrollToCell", function () {
      var _this$props2 = _this.props,
          cellLayoutManager = _this$props2.cellLayoutManager,
          height = _this$props2.height,
          scrollToAlignment = _this$props2.scrollToAlignment,
          scrollToCell = _this$props2.scrollToCell,
          width = _this$props2.width;
      var _this$state = _this.state,
          scrollLeft = _this$state.scrollLeft,
          scrollTop = _this$state.scrollTop;

      if (scrollToCell >= 0) {
        var scrollPosition = cellLayoutManager.getScrollPositionForCell({
          align: scrollToAlignment,
          cellIndex: scrollToCell,
          height: height,
          scrollLeft: scrollLeft,
          scrollTop: scrollTop,
          width: width
        });

        if (scrollPosition.scrollLeft !== scrollLeft || scrollPosition.scrollTop !== scrollTop) {
          _this._setScrollPosition(scrollPosition);
        }
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_onScroll", function (event) {
      // In certain edge-cases React dispatches an onScroll event with an invalid target.scrollLeft / target.scrollTop.
      // This invalid event can be detected by comparing event.target to this component's scrollable DOM element.
      // See issue #404 for more information.
      if (event.target !== _this._scrollingContainer) {
        return;
      } // Prevent pointer events from interrupting a smooth scroll


      _this._enablePointerEventsAfterDelay(); // When this component is shrunk drastically, React dispatches a series of back-to-back scroll events,
      // Gradually converging on a scrollTop that is within the bounds of the new, smaller height.
      // This causes a series of rapid renders that is slow for long lists.
      // We can avoid that by doing some simple bounds checking to ensure that scrollTop never exceeds the total height.


      var _this$props3 = _this.props,
          cellLayoutManager = _this$props3.cellLayoutManager,
          height = _this$props3.height,
          isScrollingChange = _this$props3.isScrollingChange,
          width = _this$props3.width;
      var scrollbarSize = _this._scrollbarSize;

      var _cellLayoutManager$ge = cellLayoutManager.getTotalSize(),
          totalHeight = _cellLayoutManager$ge.height,
          totalWidth = _cellLayoutManager$ge.width;

      var scrollLeft = Math.max(0, Math.min(totalWidth - width + scrollbarSize, event.target.scrollLeft));
      var scrollTop = Math.max(0, Math.min(totalHeight - height + scrollbarSize, event.target.scrollTop)); // Certain devices (like Apple touchpad) rapid-fire duplicate events.
      // Don't force a re-render if this is the case.
      // The mouse may move faster then the animation frame does.
      // Use requestAnimationFrame to avoid over-updating.

      if (_this.state.scrollLeft !== scrollLeft || _this.state.scrollTop !== scrollTop) {
        // Browsers with cancelable scroll events (eg. Firefox) interrupt scrolling animations if scrollTop/scrollLeft is set.
        // Other browsers (eg. Safari) don't scroll as well without the help under certain conditions (DOM or style changes during scrolling).
        // All things considered, this seems to be the best current work around that I'm aware of.
        // For more information see https://github.com/bvaughn/react-virtualized/pull/124
        var scrollPositionChangeReason = event.cancelable ? SCROLL_POSITION_CHANGE_REASONS.OBSERVED : SCROLL_POSITION_CHANGE_REASONS.REQUESTED; // Synchronously set :isScrolling the first time (since _setNextState will reschedule its animation frame each time it's called)

        if (!_this.state.isScrolling) {
          isScrollingChange(true);
        }

        _this.setState({
          isScrolling: true,
          scrollLeft: scrollLeft,
          scrollPositionChangeReason: scrollPositionChangeReason,
          scrollTop: scrollTop
        });
      }

      _this._invokeOnScrollMemoizer({
        scrollLeft: scrollLeft,
        scrollTop: scrollTop,
        totalWidth: totalWidth,
        totalHeight: totalHeight
      });
    });

    _this._scrollbarSize = (0,dom_helpers_scrollbarSize__WEBPACK_IMPORTED_MODULE_11__["default"])();

    if (_this._scrollbarSize === undefined) {
      _this._scrollbarSizeMeasured = false;
      _this._scrollbarSize = 0;
    } else {
      _this._scrollbarSizeMeasured = true;
    }

    return _this;
  }
  /**
   * Forced recompute of cell sizes and positions.
   * This function should be called if cell sizes have changed but nothing else has.
   * Since cell positions are calculated by callbacks, the collection view has no way of detecting when the underlying data has changed.
   */


  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(CollectionView, [{
    key: "recomputeCellSizesAndPositions",
    value: function recomputeCellSizesAndPositions() {
      this._calculateSizeAndPositionDataOnNextUpdate = true;
      this.forceUpdate();
    }
    /* ---------------------------- Component lifecycle methods ---------------------------- */

    /**
     * @private
     * This method updates scrollLeft/scrollTop in state for the following conditions:
     * 1) Empty content (0 rows or columns)
     * 2) New scroll props overriding the current state
     * 3) Cells-count or cells-size has changed, making previous scroll offsets invalid
     */

  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this$props4 = this.props,
          cellLayoutManager = _this$props4.cellLayoutManager,
          scrollLeft = _this$props4.scrollLeft,
          scrollToCell = _this$props4.scrollToCell,
          scrollTop = _this$props4.scrollTop; // If this component was first rendered server-side, scrollbar size will be undefined.
      // In that event we need to remeasure.

      if (!this._scrollbarSizeMeasured) {
        this._scrollbarSize = (0,dom_helpers_scrollbarSize__WEBPACK_IMPORTED_MODULE_11__["default"])();
        this._scrollbarSizeMeasured = true;
        this.setState({});
      }

      if (scrollToCell >= 0) {
        this._updateScrollPositionForScrollToCell();
      } else if (scrollLeft >= 0 || scrollTop >= 0) {
        this._setScrollPosition({
          scrollLeft: scrollLeft,
          scrollTop: scrollTop
        });
      } // Update onSectionRendered callback.


      this._invokeOnSectionRenderedHelper();

      var _cellLayoutManager$ge2 = cellLayoutManager.getTotalSize(),
          totalHeight = _cellLayoutManager$ge2.height,
          totalWidth = _cellLayoutManager$ge2.width; // Initialize onScroll callback.


      this._invokeOnScrollMemoizer({
        scrollLeft: scrollLeft || 0,
        scrollTop: scrollTop || 0,
        totalHeight: totalHeight,
        totalWidth: totalWidth
      });
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps, prevState) {
      var _this$props5 = this.props,
          height = _this$props5.height,
          scrollToAlignment = _this$props5.scrollToAlignment,
          scrollToCell = _this$props5.scrollToCell,
          width = _this$props5.width;
      var _this$state2 = this.state,
          scrollLeft = _this$state2.scrollLeft,
          scrollPositionChangeReason = _this$state2.scrollPositionChangeReason,
          scrollTop = _this$state2.scrollTop; // Make sure requested changes to :scrollLeft or :scrollTop get applied.
      // Assigning to scrollLeft/scrollTop tells the browser to interrupt any running scroll animations,
      // And to discard any pending async changes to the scroll position that may have happened in the meantime (e.g. on a separate scrolling thread).
      // So we only set these when we require an adjustment of the scroll position.
      // See issue #2 for more information.

      if (scrollPositionChangeReason === SCROLL_POSITION_CHANGE_REASONS.REQUESTED) {
        if (scrollLeft >= 0 && scrollLeft !== prevState.scrollLeft && scrollLeft !== this._scrollingContainer.scrollLeft) {
          this._scrollingContainer.scrollLeft = scrollLeft;
        }

        if (scrollTop >= 0 && scrollTop !== prevState.scrollTop && scrollTop !== this._scrollingContainer.scrollTop) {
          this._scrollingContainer.scrollTop = scrollTop;
        }
      } // Update scroll offsets if the current :scrollToCell values requires it


      if (height !== prevProps.height || scrollToAlignment !== prevProps.scrollToAlignment || scrollToCell !== prevProps.scrollToCell || width !== prevProps.width) {
        this._updateScrollPositionForScrollToCell();
      } // Update onRowsRendered callback if start/stop indices have changed


      this._invokeOnSectionRenderedHelper();
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      if (this._disablePointerEventsTimeoutId) {
        clearTimeout(this._disablePointerEventsTimeoutId);
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props6 = this.props,
          autoHeight = _this$props6.autoHeight,
          cellCount = _this$props6.cellCount,
          cellLayoutManager = _this$props6.cellLayoutManager,
          className = _this$props6.className,
          height = _this$props6.height,
          horizontalOverscanSize = _this$props6.horizontalOverscanSize,
          id = _this$props6.id,
          noContentRenderer = _this$props6.noContentRenderer,
          style = _this$props6.style,
          verticalOverscanSize = _this$props6.verticalOverscanSize,
          width = _this$props6.width;
      var _this$state3 = this.state,
          isScrolling = _this$state3.isScrolling,
          scrollLeft = _this$state3.scrollLeft,
          scrollTop = _this$state3.scrollTop; // Memoization reset

      if (this._lastRenderedCellCount !== cellCount || this._lastRenderedCellLayoutManager !== cellLayoutManager || this._calculateSizeAndPositionDataOnNextUpdate) {
        this._lastRenderedCellCount = cellCount;
        this._lastRenderedCellLayoutManager = cellLayoutManager;
        this._calculateSizeAndPositionDataOnNextUpdate = false;
        cellLayoutManager.calculateSizeAndPositionData();
      }

      var _cellLayoutManager$ge3 = cellLayoutManager.getTotalSize(),
          totalHeight = _cellLayoutManager$ge3.height,
          totalWidth = _cellLayoutManager$ge3.width; // Safely expand the rendered area by the specified overscan amount


      var left = Math.max(0, scrollLeft - horizontalOverscanSize);
      var top = Math.max(0, scrollTop - verticalOverscanSize);
      var right = Math.min(totalWidth, scrollLeft + width + horizontalOverscanSize);
      var bottom = Math.min(totalHeight, scrollTop + height + verticalOverscanSize);
      var childrenToDisplay = height > 0 && width > 0 ? cellLayoutManager.cellRenderers({
        height: bottom - top,
        isScrolling: isScrolling,
        width: right - left,
        x: left,
        y: top
      }) : [];
      var collectionStyle = {
        boxSizing: 'border-box',
        direction: 'ltr',
        height: autoHeight ? 'auto' : height,
        position: 'relative',
        WebkitOverflowScrolling: 'touch',
        width: width,
        willChange: 'transform'
      }; // Force browser to hide scrollbars when we know they aren't necessary.
      // Otherwise once scrollbars appear they may not disappear again.
      // For more info see issue #116

      var verticalScrollBarSize = totalHeight > height ? this._scrollbarSize : 0;
      var horizontalScrollBarSize = totalWidth > width ? this._scrollbarSize : 0; // Also explicitly init styles to 'auto' if scrollbars are required.
      // This works around an obscure edge case where external CSS styles have not yet been loaded,
      // But an initial scroll index of offset is set as an external prop.
      // Without this style, Grid would render the correct range of cells but would NOT update its internal offset.
      // This was originally reported via clauderic/react-infinite-calendar/issues/23

      collectionStyle.overflowX = totalWidth + verticalScrollBarSize <= width ? 'hidden' : 'auto';
      collectionStyle.overflowY = totalHeight + horizontalScrollBarSize <= height ? 'hidden' : 'auto';
      return react__WEBPACK_IMPORTED_MODULE_8__.createElement("div", {
        ref: this._setScrollingContainerRef,
        "aria-label": this.props['aria-label'],
        className: (0,clsx__WEBPACK_IMPORTED_MODULE_7__["default"])('ReactVirtualized__Collection', className),
        id: id,
        onScroll: this._onScroll,
        role: "grid",
        style: _objectSpread({}, collectionStyle, {}, style),
        tabIndex: 0
      }, cellCount > 0 && react__WEBPACK_IMPORTED_MODULE_8__.createElement("div", {
        className: "ReactVirtualized__Collection__innerScrollContainer",
        style: {
          height: totalHeight,
          maxHeight: totalHeight,
          maxWidth: totalWidth,
          overflow: 'hidden',
          pointerEvents: isScrolling ? 'none' : '',
          width: totalWidth
        }
      }, childrenToDisplay), cellCount === 0 && noContentRenderer());
    }
    /* ---------------------------- Helper methods ---------------------------- */

    /**
     * Sets an :isScrolling flag for a small window of time.
     * This flag is used to disable pointer events on the scrollable portion of the Collection.
     * This prevents jerky/stuttery mouse-wheel scrolling.
     */

  }, {
    key: "_enablePointerEventsAfterDelay",
    value: function _enablePointerEventsAfterDelay() {
      var _this2 = this;

      if (this._disablePointerEventsTimeoutId) {
        clearTimeout(this._disablePointerEventsTimeoutId);
      }

      this._disablePointerEventsTimeoutId = setTimeout(function () {
        var isScrollingChange = _this2.props.isScrollingChange;
        isScrollingChange(false);
        _this2._disablePointerEventsTimeoutId = null;

        _this2.setState({
          isScrolling: false
        });
      }, IS_SCROLLING_TIMEOUT);
    }
  }, {
    key: "_invokeOnScrollMemoizer",
    value: function _invokeOnScrollMemoizer(_ref) {
      var _this3 = this;

      var scrollLeft = _ref.scrollLeft,
          scrollTop = _ref.scrollTop,
          totalHeight = _ref.totalHeight,
          totalWidth = _ref.totalWidth;

      this._onScrollMemoizer({
        callback: function callback(_ref2) {
          var scrollLeft = _ref2.scrollLeft,
              scrollTop = _ref2.scrollTop;
          var _this3$props = _this3.props,
              height = _this3$props.height,
              onScroll = _this3$props.onScroll,
              width = _this3$props.width;
          onScroll({
            clientHeight: height,
            clientWidth: width,
            scrollHeight: totalHeight,
            scrollLeft: scrollLeft,
            scrollTop: scrollTop,
            scrollWidth: totalWidth
          });
        },
        indices: {
          scrollLeft: scrollLeft,
          scrollTop: scrollTop
        }
      });
    }
  }, {
    key: "_setScrollPosition",
    value: function _setScrollPosition(_ref3) {
      var scrollLeft = _ref3.scrollLeft,
          scrollTop = _ref3.scrollTop;
      var newState = {
        scrollPositionChangeReason: SCROLL_POSITION_CHANGE_REASONS.REQUESTED
      };

      if (scrollLeft >= 0) {
        newState.scrollLeft = scrollLeft;
      }

      if (scrollTop >= 0) {
        newState.scrollTop = scrollTop;
      }

      if (scrollLeft >= 0 && scrollLeft !== this.state.scrollLeft || scrollTop >= 0 && scrollTop !== this.state.scrollTop) {
        this.setState(newState);
      }
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(nextProps, prevState) {
      if (nextProps.cellCount === 0 && (prevState.scrollLeft !== 0 || prevState.scrollTop !== 0)) {
        return {
          scrollLeft: 0,
          scrollTop: 0,
          scrollPositionChangeReason: SCROLL_POSITION_CHANGE_REASONS.REQUESTED
        };
      } else if (nextProps.scrollLeft !== prevState.scrollLeft || nextProps.scrollTop !== prevState.scrollTop) {
        return {
          scrollLeft: nextProps.scrollLeft != null ? nextProps.scrollLeft : prevState.scrollLeft,
          scrollTop: nextProps.scrollTop != null ? nextProps.scrollTop : prevState.scrollTop,
          scrollPositionChangeReason: SCROLL_POSITION_CHANGE_REASONS.REQUESTED
        };
      }

      return null;
    }
  }]);

  return CollectionView;
}(react__WEBPACK_IMPORTED_MODULE_8__.PureComponent);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(CollectionView, "defaultProps", {
  'aria-label': 'grid',
  horizontalOverscanSize: 0,
  noContentRenderer: function noContentRenderer() {
    return null;
  },
  onScroll: function onScroll() {
    return null;
  },
  onSectionRendered: function onSectionRendered() {
    return null;
  },
  scrollToAlignment: 'auto',
  scrollToCell: -1,
  style: {},
  verticalOverscanSize: 0
});

CollectionView.propTypes =  true ? {
  'aria-label': (prop_types__WEBPACK_IMPORTED_MODULE_12___default().string),

  /**
   * Removes fixed height from the scrollingContainer so that the total height
   * of rows can stretch the window. Intended for use with WindowScroller
   */
  autoHeight: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().bool),

  /**
   * Number of cells in collection.
   */
  cellCount: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired),

  /**
   * Calculates cell sizes and positions and manages rendering the appropriate cells given a specified window.
   */
  cellLayoutManager: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().object.isRequired),

  /**
   * Optional custom CSS class name to attach to root Collection element.
   */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().string),

  /**
   * Height of Collection; this property determines the number of visible (vs virtualized) rows.
   */
  height: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired),

  /**
   * Optional custom id to attach to root Collection element.
   */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().string),

  /**
   * Enables the `Collection` to horiontally "overscan" its content similar to how `Grid` does.
   * This can reduce flicker around the edges when a user scrolls quickly.
   */
  horizontalOverscanSize: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired),
  isScrollingChange: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func),

  /**
   * Optional renderer to be used in place of rows when either :rowCount or :cellCount is 0.
   */
  noContentRenderer: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func.isRequired),

  /**
   * Callback invoked whenever the scroll offset changes within the inner scrollable region.
   * This callback can be used to sync scrolling between lists, tables, or grids.
   * ({ clientHeight, clientWidth, scrollHeight, scrollLeft, scrollTop, scrollWidth }): void
   */
  onScroll: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func.isRequired),

  /**
   * Callback invoked with information about the section of the Collection that was just rendered.
   * This callback is passed a named :indices parameter which is an Array of the most recently rendered section indices.
   */
  onSectionRendered: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func.isRequired),

  /**
   * Horizontal offset.
   */
  scrollLeft: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number),

  /**
   * Controls scroll-to-cell behavior of the Grid.
   * The default ("auto") scrolls the least amount possible to ensure that the specified cell is fully visible.
   * Use "start" to align cells to the top/left of the Grid and "end" to align bottom/right.
   */
  scrollToAlignment: prop_types__WEBPACK_IMPORTED_MODULE_12___default().oneOf(['auto', 'end', 'start', 'center']).isRequired,

  /**
   * Cell index to ensure visible (by forcefully scrolling if necessary).
   */
  scrollToCell: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired),

  /**
   * Vertical offset.
   */
  scrollTop: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number),

  /**
   * Optional custom inline style to attach to root Collection element.
   */
  style: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().object),

  /**
   * Enables the `Collection` to vertically "overscan" its content similar to how `Grid` does.
   * This can reduce flicker around the edges when a user scrolls quickly.
   */
  verticalOverscanSize: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired),

  /**
   * Width of Collection; this property determines the number of visible (vs virtualized) columns.
   */
  width: (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired)
} : 0;
(0,react_lifecycles_compat__WEBPACK_IMPORTED_MODULE_9__.polyfill)(CollectionView);
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (CollectionView);

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Collection/Section.js":
/*!**************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Collection/Section.js ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ Section)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/Collection/types.js");



/**
 * A section of the Window.
 * Window Sections are used to group nearby cells.
 * This enables us to more quickly determine which cells to display in a given region of the Window.
 * Sections have a fixed size and contain 0 to many cells (tracked by their indices).
 */
var Section =
/*#__PURE__*/
function () {
  function Section(_ref) {
    var height = _ref.height,
        width = _ref.width,
        x = _ref.x,
        y = _ref.y;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, Section);

    this.height = height;
    this.width = width;
    this.x = x;
    this.y = y;
    this._indexMap = {};
    this._indices = [];
  }
  /** Add a cell to this section. */


  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(Section, [{
    key: "addCellIndex",
    value: function addCellIndex(_ref2) {
      var index = _ref2.index;

      if (!this._indexMap[index]) {
        this._indexMap[index] = true;

        this._indices.push(index);
      }
    }
    /** Get all cell indices that have been added to this section. */

  }, {
    key: "getCellIndices",
    value: function getCellIndices() {
      return this._indices;
    }
    /** Intended for debugger/test purposes only */

  }, {
    key: "toString",
    value: function toString() {
      return "".concat(this.x, ",").concat(this.y, " ").concat(this.width, "x").concat(this.height);
    }
  }]);

  return Section;
}();





/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Collection/SectionManager.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Collection/SectionManager.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ SectionManager)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _Section__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./Section */ "../../node_modules/react-virtualized/dist/es/Collection/Section.js");
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/Collection/types.js");



/**
 * Window Sections are used to group nearby cells.
 * This enables us to more quickly determine which cells to display in a given region of the Window.
 * 
 */

var SECTION_SIZE = 100;

/**
 * Contains 0 to many Sections.
 * Grows (and adds Sections) dynamically as cells are registered.
 * Automatically adds cells to the appropriate Section(s).
 */
var SectionManager =
/*#__PURE__*/
function () {
  function SectionManager() {
    var sectionSize = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : SECTION_SIZE;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, SectionManager);

    this._sectionSize = sectionSize;
    this._cellMetadata = [];
    this._sections = {};
  }
  /**
   * Gets all cell indices contained in the specified region.
   * A region may encompass 1 or more Sections.
   */


  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(SectionManager, [{
    key: "getCellIndices",
    value: function getCellIndices(_ref) {
      var height = _ref.height,
          width = _ref.width,
          x = _ref.x,
          y = _ref.y;
      var indices = {};
      this.getSections({
        height: height,
        width: width,
        x: x,
        y: y
      }).forEach(function (section) {
        return section.getCellIndices().forEach(function (index) {
          indices[index] = index;
        });
      }); // Object keys are strings; this function returns numbers

      return Object.keys(indices).map(function (index) {
        return indices[index];
      });
    }
    /** Get size and position information for the cell specified. */

  }, {
    key: "getCellMetadata",
    value: function getCellMetadata(_ref2) {
      var index = _ref2.index;
      return this._cellMetadata[index];
    }
    /** Get all Sections overlapping the specified region. */

  }, {
    key: "getSections",
    value: function getSections(_ref3) {
      var height = _ref3.height,
          width = _ref3.width,
          x = _ref3.x,
          y = _ref3.y;
      var sectionXStart = Math.floor(x / this._sectionSize);
      var sectionXStop = Math.floor((x + width - 1) / this._sectionSize);
      var sectionYStart = Math.floor(y / this._sectionSize);
      var sectionYStop = Math.floor((y + height - 1) / this._sectionSize);
      var sections = [];

      for (var sectionX = sectionXStart; sectionX <= sectionXStop; sectionX++) {
        for (var sectionY = sectionYStart; sectionY <= sectionYStop; sectionY++) {
          var key = "".concat(sectionX, ".").concat(sectionY);

          if (!this._sections[key]) {
            this._sections[key] = new _Section__WEBPACK_IMPORTED_MODULE_2__["default"]({
              height: this._sectionSize,
              width: this._sectionSize,
              x: sectionX * this._sectionSize,
              y: sectionY * this._sectionSize
            });
          }

          sections.push(this._sections[key]);
        }
      }

      return sections;
    }
    /** Total number of Sections based on the currently registered cells. */

  }, {
    key: "getTotalSectionCount",
    value: function getTotalSectionCount() {
      return Object.keys(this._sections).length;
    }
    /** Intended for debugger/test purposes only */

  }, {
    key: "toString",
    value: function toString() {
      var _this = this;

      return Object.keys(this._sections).map(function (index) {
        return _this._sections[index].toString();
      });
    }
    /** Adds a cell to the appropriate Sections and registers it metadata for later retrievable. */

  }, {
    key: "registerCell",
    value: function registerCell(_ref4) {
      var cellMetadatum = _ref4.cellMetadatum,
          index = _ref4.index;
      this._cellMetadata[index] = cellMetadatum;
      this.getSections(cellMetadatum).forEach(function (section) {
        return section.addCellIndex({
          index: index
        });
      });
    }
  }]);

  return SectionManager;
}();





/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Collection/index.js":
/*!************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Collection/index.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Collection": () => (/* reexport safe */ _Collection__WEBPACK_IMPORTED_MODULE_0__["default"]),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _Collection__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./Collection */ "../../node_modules/react-virtualized/dist/es/Collection/Collection.js");

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_Collection__WEBPACK_IMPORTED_MODULE_0__["default"]);


/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Collection/types.js":
/*!************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Collection/types.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "bpfrpt_proptype_Index": () => (/* binding */ bpfrpt_proptype_Index),
/* harmony export */   "bpfrpt_proptype_PositionInfo": () => (/* binding */ bpfrpt_proptype_PositionInfo),
/* harmony export */   "bpfrpt_proptype_ScrollPosition": () => (/* binding */ bpfrpt_proptype_ScrollPosition),
/* harmony export */   "bpfrpt_proptype_SizeAndPositionInfo": () => (/* binding */ bpfrpt_proptype_SizeAndPositionInfo),
/* harmony export */   "bpfrpt_proptype_SizeInfo": () => (/* binding */ bpfrpt_proptype_SizeInfo)
/* harmony export */ });
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_0__);
var bpfrpt_proptype_Index =  false ? 0 : {
  "index": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().number.isRequired)
};
var bpfrpt_proptype_PositionInfo =  false ? 0 : {
  "x": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().number.isRequired),
  "y": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().number.isRequired)
};
var bpfrpt_proptype_ScrollPosition =  false ? 0 : {
  "scrollLeft": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().number.isRequired),
  "scrollTop": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().number.isRequired)
};
var bpfrpt_proptype_SizeAndPositionInfo =  false ? 0 : {
  "height": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().number.isRequired),
  "width": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().number.isRequired),
  "x": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().number.isRequired),
  "y": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().number.isRequired)
};
var bpfrpt_proptype_SizeInfo =  false ? 0 : {
  "height": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().number.isRequired),
  "width": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().number.isRequired)
};







/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Collection/utils/calculateSizeAndPositionData.js":
/*!*****************************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Collection/utils/calculateSizeAndPositionData.js ***!
  \*****************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ calculateSizeAndPositionData)
/* harmony export */ });
/* harmony import */ var _SectionManager__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../SectionManager */ "../../node_modules/react-virtualized/dist/es/Collection/SectionManager.js");

function calculateSizeAndPositionData(_ref) {
  var cellCount = _ref.cellCount,
      cellSizeAndPositionGetter = _ref.cellSizeAndPositionGetter,
      sectionSize = _ref.sectionSize;
  var cellMetadata = [];
  var sectionManager = new _SectionManager__WEBPACK_IMPORTED_MODULE_0__["default"](sectionSize);
  var height = 0;
  var width = 0;

  for (var index = 0; index < cellCount; index++) {
    var cellMetadatum = cellSizeAndPositionGetter({
      index: index
    });

    if (cellMetadatum.height == null || isNaN(cellMetadatum.height) || cellMetadatum.width == null || isNaN(cellMetadatum.width) || cellMetadatum.x == null || isNaN(cellMetadatum.x) || cellMetadatum.y == null || isNaN(cellMetadatum.y)) {
      throw Error("Invalid metadata returned for cell ".concat(index, ":\n        x:").concat(cellMetadatum.x, ", y:").concat(cellMetadatum.y, ", width:").concat(cellMetadatum.width, ", height:").concat(cellMetadatum.height));
    }

    height = Math.max(height, cellMetadatum.y + cellMetadatum.height);
    width = Math.max(width, cellMetadatum.x + cellMetadatum.width);
    cellMetadata[index] = cellMetadatum;
    sectionManager.registerCell({
      cellMetadatum: cellMetadatum,
      index: index
    });
  }

  return {
    cellMetadata: cellMetadata,
    height: height,
    sectionManager: sectionManager,
    width: width
  };
}

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/ColumnSizer/ColumnSizer.js":
/*!*******************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/ColumnSizer/ColumnSizer.js ***!
  \*******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ ColumnSizer)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_7__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_6__);








/**
 * High-order component that auto-calculates column-widths for `Grid` cells.
 */

var ColumnSizer =
/*#__PURE__*/
function (_React$PureComponent) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(ColumnSizer, _React$PureComponent);

  function ColumnSizer(props, context) {
    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, ColumnSizer);

    _this = (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__["default"])(this, (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(ColumnSizer).call(this, props, context));
    _this._registerChild = _this._registerChild.bind((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this));
    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(ColumnSizer, [{
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps) {
      var _this$props = this.props,
          columnMaxWidth = _this$props.columnMaxWidth,
          columnMinWidth = _this$props.columnMinWidth,
          columnCount = _this$props.columnCount,
          width = _this$props.width;

      if (columnMaxWidth !== prevProps.columnMaxWidth || columnMinWidth !== prevProps.columnMinWidth || columnCount !== prevProps.columnCount || width !== prevProps.width) {
        if (this._registeredChild) {
          this._registeredChild.recomputeGridSize();
        }
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          columnMaxWidth = _this$props2.columnMaxWidth,
          columnMinWidth = _this$props2.columnMinWidth,
          columnCount = _this$props2.columnCount,
          width = _this$props2.width;
      var safeColumnMinWidth = columnMinWidth || 1;
      var safeColumnMaxWidth = columnMaxWidth ? Math.min(columnMaxWidth, width) : width;
      var columnWidth = width / columnCount;
      columnWidth = Math.max(safeColumnMinWidth, columnWidth);
      columnWidth = Math.min(safeColumnMaxWidth, columnWidth);
      columnWidth = Math.floor(columnWidth);
      var adjustedWidth = Math.min(width, columnWidth * columnCount);
      return children({
        adjustedWidth: adjustedWidth,
        columnWidth: columnWidth,
        getColumnWidth: function getColumnWidth() {
          return columnWidth;
        },
        registerChild: this._registerChild
      });
    }
  }, {
    key: "_registerChild",
    value: function _registerChild(child) {
      if (child && typeof child.recomputeGridSize !== 'function') {
        throw Error('Unexpected child type registered; only Grid/MultiGrid children are supported.');
      }

      this._registeredChild = child;

      if (this._registeredChild) {
        this._registeredChild.recomputeGridSize();
      }
    }
  }]);

  return ColumnSizer;
}(react__WEBPACK_IMPORTED_MODULE_6__.PureComponent);


ColumnSizer.propTypes =  true ? {
  /**
   * Function responsible for rendering a virtualized Grid.
   * This function should implement the following signature:
   * ({ adjustedWidth, getColumnWidth, registerChild }) => PropTypes.element
   *
   * The specified :getColumnWidth function should be passed to the Grid's :columnWidth property.
   * The :registerChild should be passed to the Grid's :ref property.
   * The :adjustedWidth property is optional; it reflects the lesser of the overall width or the width of all columns.
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func.isRequired),

  /** Optional maximum allowed column width */
  columnMaxWidth: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),

  /** Optional minimum allowed column width */
  columnMinWidth: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number),

  /** Number of columns in Grid or Table child */
  columnCount: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number.isRequired),

  /** Width of Grid or Table child */
  width: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().number.isRequired)
} : 0;

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/ColumnSizer/index.js":
/*!*************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/ColumnSizer/index.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "ColumnSizer": () => (/* reexport safe */ _ColumnSizer__WEBPACK_IMPORTED_MODULE_0__["default"]),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _ColumnSizer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./ColumnSizer */ "../../node_modules/react-virtualized/dist/es/ColumnSizer/ColumnSizer.js");

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_ColumnSizer__WEBPACK_IMPORTED_MODULE_0__["default"]);


/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Grid/Grid.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Grid/Grid.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "DEFAULT_SCROLLING_RESET_TIME_INTERVAL": () => (/* binding */ DEFAULT_SCROLLING_RESET_TIME_INTERVAL),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */ var clsx__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! clsx */ "../../node_modules/clsx/dist/clsx.m.js");
/* harmony import */ var _utils_calculateSizeAndPositionDataAndUpdateScrollOffset__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./utils/calculateSizeAndPositionDataAndUpdateScrollOffset */ "../../node_modules/react-virtualized/dist/es/Grid/utils/calculateSizeAndPositionDataAndUpdateScrollOffset.js");
/* harmony import */ var _utils_ScalingCellSizeAndPositionManager__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./utils/ScalingCellSizeAndPositionManager */ "../../node_modules/react-virtualized/dist/es/Grid/utils/ScalingCellSizeAndPositionManager.js");
/* harmony import */ var _utils_createCallbackMemoizer__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../utils/createCallbackMemoizer */ "../../node_modules/react-virtualized/dist/es/utils/createCallbackMemoizer.js");
/* harmony import */ var _defaultOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./defaultOverscanIndicesGetter */ "../../node_modules/react-virtualized/dist/es/Grid/defaultOverscanIndicesGetter.js");
/* harmony import */ var _utils_updateScrollIndexHelper__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./utils/updateScrollIndexHelper */ "../../node_modules/react-virtualized/dist/es/Grid/utils/updateScrollIndexHelper.js");
/* harmony import */ var _defaultCellRangeRenderer__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./defaultCellRangeRenderer */ "../../node_modules/react-virtualized/dist/es/Grid/defaultCellRangeRenderer.js");
/* harmony import */ var dom_helpers_scrollbarSize__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! dom-helpers/scrollbarSize */ "../../node_modules/dom-helpers/esm/scrollbarSize.js");
/* harmony import */ var react_lifecycles_compat__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! react-lifecycles-compat */ "../../node_modules/react-lifecycles-compat/react-lifecycles-compat.es.js");
/* harmony import */ var _utils_requestAnimationTimeout__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ../utils/requestAnimationTimeout */ "../../node_modules/react-virtualized/dist/es/utils/requestAnimationTimeout.js");
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/Grid/types.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_19___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_19__);









var _class, _temp;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }












/**
 * Specifies the number of milliseconds during which to disable pointer events while a scroll is in progress.
 * This improves performance and makes scrolling smoother.
 */

var DEFAULT_SCROLLING_RESET_TIME_INTERVAL = 150;
/**
 * Controls whether the Grid updates the DOM element's scrollLeft/scrollTop based on the current state or just observes it.
 * This prevents Grid from interrupting mouse-wheel animations (see issue #2).
 */

var SCROLL_POSITION_CHANGE_REASONS = {
  OBSERVED: 'observed',
  REQUESTED: 'requested'
};

var renderNull = function renderNull() {
  return null;
};

/**
 * Renders tabular data with virtualization along the vertical and horizontal axes.
 * Row heights and column widths must be known ahead of time and specified as properties.
 */
var Grid = (_temp = _class =
/*#__PURE__*/
function (_React$PureComponent) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_6__["default"])(Grid, _React$PureComponent);

  // Invokes onSectionRendered callback only when start/stop row or column indices change
  function Grid(props) {
    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_1__["default"])(this, Grid);

    _this = (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_3__["default"])(this, (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_4__["default"])(Grid).call(this, props));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_onGridRenderedMemoizer", (0,_utils_createCallbackMemoizer__WEBPACK_IMPORTED_MODULE_12__["default"])());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_onScrollMemoizer", (0,_utils_createCallbackMemoizer__WEBPACK_IMPORTED_MODULE_12__["default"])(false));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_deferredInvalidateColumnIndex", null);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_deferredInvalidateRowIndex", null);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_recomputeScrollLeftFlag", false);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_recomputeScrollTopFlag", false);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_horizontalScrollBarSize", 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_verticalScrollBarSize", 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_scrollbarPresenceChanged", false);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_scrollingContainer", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_childrenToDisplay", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_columnStartIndex", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_columnStopIndex", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_rowStartIndex", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_rowStopIndex", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_renderedColumnStartIndex", 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_renderedColumnStopIndex", 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_renderedRowStartIndex", 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_renderedRowStopIndex", 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_initialScrollTop", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_initialScrollLeft", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_disablePointerEventsTimeoutId", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_styleCache", {});

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_cellCache", {});

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_debounceScrollEndedCallback", function () {
      _this._disablePointerEventsTimeoutId = null; // isScrolling is used to determine if we reset styleCache

      _this.setState({
        isScrolling: false,
        needToResetStyleCache: false
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_invokeOnGridRenderedHelper", function () {
      var onSectionRendered = _this.props.onSectionRendered;

      _this._onGridRenderedMemoizer({
        callback: onSectionRendered,
        indices: {
          columnOverscanStartIndex: _this._columnStartIndex,
          columnOverscanStopIndex: _this._columnStopIndex,
          columnStartIndex: _this._renderedColumnStartIndex,
          columnStopIndex: _this._renderedColumnStopIndex,
          rowOverscanStartIndex: _this._rowStartIndex,
          rowOverscanStopIndex: _this._rowStopIndex,
          rowStartIndex: _this._renderedRowStartIndex,
          rowStopIndex: _this._renderedRowStopIndex
        }
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_setScrollingContainerRef", function (ref) {
      _this._scrollingContainer = ref;
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_onScroll", function (event) {
      // In certain edge-cases React dispatches an onScroll event with an invalid target.scrollLeft / target.scrollTop.
      // This invalid event can be detected by comparing event.target to this component's scrollable DOM element.
      // See issue #404 for more information.
      if (event.target === _this._scrollingContainer) {
        _this.handleScrollEvent(event.target);
      }
    });

    var columnSizeAndPositionManager = new _utils_ScalingCellSizeAndPositionManager__WEBPACK_IMPORTED_MODULE_11__["default"]({
      cellCount: props.columnCount,
      cellSizeGetter: function cellSizeGetter(params) {
        return Grid._wrapSizeGetter(props.columnWidth)(params);
      },
      estimatedCellSize: Grid._getEstimatedColumnSize(props)
    });
    var rowSizeAndPositionManager = new _utils_ScalingCellSizeAndPositionManager__WEBPACK_IMPORTED_MODULE_11__["default"]({
      cellCount: props.rowCount,
      cellSizeGetter: function cellSizeGetter(params) {
        return Grid._wrapSizeGetter(props.rowHeight)(params);
      },
      estimatedCellSize: Grid._getEstimatedRowSize(props)
    });
    _this.state = {
      instanceProps: {
        columnSizeAndPositionManager: columnSizeAndPositionManager,
        rowSizeAndPositionManager: rowSizeAndPositionManager,
        prevColumnWidth: props.columnWidth,
        prevRowHeight: props.rowHeight,
        prevColumnCount: props.columnCount,
        prevRowCount: props.rowCount,
        prevIsScrolling: props.isScrolling === true,
        prevScrollToColumn: props.scrollToColumn,
        prevScrollToRow: props.scrollToRow,
        scrollbarSize: 0,
        scrollbarSizeMeasured: false
      },
      isScrolling: false,
      scrollDirectionHorizontal: _defaultOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_13__.SCROLL_DIRECTION_FORWARD,
      scrollDirectionVertical: _defaultOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_13__.SCROLL_DIRECTION_FORWARD,
      scrollLeft: 0,
      scrollTop: 0,
      scrollPositionChangeReason: null,
      needToResetStyleCache: false
    };

    if (props.scrollToRow > 0) {
      _this._initialScrollTop = _this._getCalculatedScrollTop(props, _this.state);
    }

    if (props.scrollToColumn > 0) {
      _this._initialScrollLeft = _this._getCalculatedScrollLeft(props, _this.state);
    }

    return _this;
  }
  /**
   * Gets offsets for a given cell and alignment.
   */


  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(Grid, [{
    key: "getOffsetForCell",
    value: function getOffsetForCell() {
      var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
          _ref$alignment = _ref.alignment,
          alignment = _ref$alignment === void 0 ? this.props.scrollToAlignment : _ref$alignment,
          _ref$columnIndex = _ref.columnIndex,
          columnIndex = _ref$columnIndex === void 0 ? this.props.scrollToColumn : _ref$columnIndex,
          _ref$rowIndex = _ref.rowIndex,
          rowIndex = _ref$rowIndex === void 0 ? this.props.scrollToRow : _ref$rowIndex;

      var offsetProps = _objectSpread({}, this.props, {
        scrollToAlignment: alignment,
        scrollToColumn: columnIndex,
        scrollToRow: rowIndex
      });

      return {
        scrollLeft: this._getCalculatedScrollLeft(offsetProps),
        scrollTop: this._getCalculatedScrollTop(offsetProps)
      };
    }
    /**
     * Gets estimated total rows' height.
     */

  }, {
    key: "getTotalRowsHeight",
    value: function getTotalRowsHeight() {
      return this.state.instanceProps.rowSizeAndPositionManager.getTotalSize();
    }
    /**
     * Gets estimated total columns' width.
     */

  }, {
    key: "getTotalColumnsWidth",
    value: function getTotalColumnsWidth() {
      return this.state.instanceProps.columnSizeAndPositionManager.getTotalSize();
    }
    /**
     * This method handles a scroll event originating from an external scroll control.
     * It's an advanced method and should probably not be used unless you're implementing a custom scroll-bar solution.
     */

  }, {
    key: "handleScrollEvent",
    value: function handleScrollEvent(_ref2) {
      var _ref2$scrollLeft = _ref2.scrollLeft,
          scrollLeftParam = _ref2$scrollLeft === void 0 ? 0 : _ref2$scrollLeft,
          _ref2$scrollTop = _ref2.scrollTop,
          scrollTopParam = _ref2$scrollTop === void 0 ? 0 : _ref2$scrollTop;

      // On iOS, we can arrive at negative offsets by swiping past the start.
      // To prevent flicker here, we make playing in the negative offset zone cause nothing to happen.
      if (scrollTopParam < 0) {
        return;
      } // Prevent pointer events from interrupting a smooth scroll


      this._debounceScrollEnded();

      var _this$props = this.props,
          autoHeight = _this$props.autoHeight,
          autoWidth = _this$props.autoWidth,
          height = _this$props.height,
          width = _this$props.width;
      var instanceProps = this.state.instanceProps; // When this component is shrunk drastically, React dispatches a series of back-to-back scroll events,
      // Gradually converging on a scrollTop that is within the bounds of the new, smaller height.
      // This causes a series of rapid renders that is slow for long lists.
      // We can avoid that by doing some simple bounds checking to ensure that scroll offsets never exceed their bounds.

      var scrollbarSize = instanceProps.scrollbarSize;
      var totalRowsHeight = instanceProps.rowSizeAndPositionManager.getTotalSize();
      var totalColumnsWidth = instanceProps.columnSizeAndPositionManager.getTotalSize();
      var scrollLeft = Math.min(Math.max(0, totalColumnsWidth - width + scrollbarSize), scrollLeftParam);
      var scrollTop = Math.min(Math.max(0, totalRowsHeight - height + scrollbarSize), scrollTopParam); // Certain devices (like Apple touchpad) rapid-fire duplicate events.
      // Don't force a re-render if this is the case.
      // The mouse may move faster then the animation frame does.
      // Use requestAnimationFrame to avoid over-updating.

      if (this.state.scrollLeft !== scrollLeft || this.state.scrollTop !== scrollTop) {
        // Track scrolling direction so we can more efficiently overscan rows to reduce empty space around the edges while scrolling.
        // Don't change direction for an axis unless scroll offset has changed.
        var scrollDirectionHorizontal = scrollLeft !== this.state.scrollLeft ? scrollLeft > this.state.scrollLeft ? _defaultOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_13__.SCROLL_DIRECTION_FORWARD : _defaultOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_13__.SCROLL_DIRECTION_BACKWARD : this.state.scrollDirectionHorizontal;
        var scrollDirectionVertical = scrollTop !== this.state.scrollTop ? scrollTop > this.state.scrollTop ? _defaultOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_13__.SCROLL_DIRECTION_FORWARD : _defaultOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_13__.SCROLL_DIRECTION_BACKWARD : this.state.scrollDirectionVertical;
        var newState = {
          isScrolling: true,
          scrollDirectionHorizontal: scrollDirectionHorizontal,
          scrollDirectionVertical: scrollDirectionVertical,
          scrollPositionChangeReason: SCROLL_POSITION_CHANGE_REASONS.OBSERVED
        };

        if (!autoHeight) {
          newState.scrollTop = scrollTop;
        }

        if (!autoWidth) {
          newState.scrollLeft = scrollLeft;
        }

        newState.needToResetStyleCache = false;
        this.setState(newState);
      }

      this._invokeOnScrollMemoizer({
        scrollLeft: scrollLeft,
        scrollTop: scrollTop,
        totalColumnsWidth: totalColumnsWidth,
        totalRowsHeight: totalRowsHeight
      });
    }
    /**
     * Invalidate Grid size and recompute visible cells.
     * This is a deferred wrapper for recomputeGridSize().
     * It sets a flag to be evaluated on cDM/cDU to avoid unnecessary renders.
     * This method is intended for advanced use-cases like CellMeasurer.
     */
    // @TODO (bvaughn) Add automated test coverage for this.

  }, {
    key: "invalidateCellSizeAfterRender",
    value: function invalidateCellSizeAfterRender(_ref3) {
      var columnIndex = _ref3.columnIndex,
          rowIndex = _ref3.rowIndex;
      this._deferredInvalidateColumnIndex = typeof this._deferredInvalidateColumnIndex === 'number' ? Math.min(this._deferredInvalidateColumnIndex, columnIndex) : columnIndex;
      this._deferredInvalidateRowIndex = typeof this._deferredInvalidateRowIndex === 'number' ? Math.min(this._deferredInvalidateRowIndex, rowIndex) : rowIndex;
    }
    /**
     * Pre-measure all columns and rows in a Grid.
     * Typically cells are only measured as needed and estimated sizes are used for cells that have not yet been measured.
     * This method ensures that the next call to getTotalSize() returns an exact size (as opposed to just an estimated one).
     */

  }, {
    key: "measureAllCells",
    value: function measureAllCells() {
      var _this$props2 = this.props,
          columnCount = _this$props2.columnCount,
          rowCount = _this$props2.rowCount;
      var instanceProps = this.state.instanceProps;
      instanceProps.columnSizeAndPositionManager.getSizeAndPositionOfCell(columnCount - 1);
      instanceProps.rowSizeAndPositionManager.getSizeAndPositionOfCell(rowCount - 1);
    }
    /**
     * Forced recompute of row heights and column widths.
     * This function should be called if dynamic column or row sizes have changed but nothing else has.
     * Since Grid only receives :columnCount and :rowCount it has no way of detecting when the underlying data changes.
     */

  }, {
    key: "recomputeGridSize",
    value: function recomputeGridSize() {
      var _ref4 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
          _ref4$columnIndex = _ref4.columnIndex,
          columnIndex = _ref4$columnIndex === void 0 ? 0 : _ref4$columnIndex,
          _ref4$rowIndex = _ref4.rowIndex,
          rowIndex = _ref4$rowIndex === void 0 ? 0 : _ref4$rowIndex;

      var _this$props3 = this.props,
          scrollToColumn = _this$props3.scrollToColumn,
          scrollToRow = _this$props3.scrollToRow;
      var instanceProps = this.state.instanceProps;
      instanceProps.columnSizeAndPositionManager.resetCell(columnIndex);
      instanceProps.rowSizeAndPositionManager.resetCell(rowIndex); // Cell sizes may be determined by a function property.
      // In this case the cDU handler can't know if they changed.
      // Store this flag to let the next cDU pass know it needs to recompute the scroll offset.

      this._recomputeScrollLeftFlag = scrollToColumn >= 0 && (this.state.scrollDirectionHorizontal === _defaultOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_13__.SCROLL_DIRECTION_FORWARD ? columnIndex <= scrollToColumn : columnIndex >= scrollToColumn);
      this._recomputeScrollTopFlag = scrollToRow >= 0 && (this.state.scrollDirectionVertical === _defaultOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_13__.SCROLL_DIRECTION_FORWARD ? rowIndex <= scrollToRow : rowIndex >= scrollToRow); // Clear cell cache in case we are scrolling;
      // Invalid row heights likely mean invalid cached content as well.

      this._styleCache = {};
      this._cellCache = {};
      this.forceUpdate();
    }
    /**
     * Ensure column and row are visible.
     */

  }, {
    key: "scrollToCell",
    value: function scrollToCell(_ref5) {
      var columnIndex = _ref5.columnIndex,
          rowIndex = _ref5.rowIndex;
      var columnCount = this.props.columnCount;
      var props = this.props; // Don't adjust scroll offset for single-column grids (eg List, Table).
      // This can cause a funky scroll offset because of the vertical scrollbar width.

      if (columnCount > 1 && columnIndex !== undefined) {
        this._updateScrollLeftForScrollToColumn(_objectSpread({}, props, {
          scrollToColumn: columnIndex
        }));
      }

      if (rowIndex !== undefined) {
        this._updateScrollTopForScrollToRow(_objectSpread({}, props, {
          scrollToRow: rowIndex
        }));
      }
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this$props4 = this.props,
          getScrollbarSize = _this$props4.getScrollbarSize,
          height = _this$props4.height,
          scrollLeft = _this$props4.scrollLeft,
          scrollToColumn = _this$props4.scrollToColumn,
          scrollTop = _this$props4.scrollTop,
          scrollToRow = _this$props4.scrollToRow,
          width = _this$props4.width;
      var instanceProps = this.state.instanceProps; // Reset initial offsets to be ignored in browser

      this._initialScrollTop = 0;
      this._initialScrollLeft = 0; // If cell sizes have been invalidated (eg we are using CellMeasurer) then reset cached positions.
      // We must do this at the start of the method as we may calculate and update scroll position below.

      this._handleInvalidatedGridSize(); // If this component was first rendered server-side, scrollbar size will be undefined.
      // In that event we need to remeasure.


      if (!instanceProps.scrollbarSizeMeasured) {
        this.setState(function (prevState) {
          var stateUpdate = _objectSpread({}, prevState, {
            needToResetStyleCache: false
          });

          stateUpdate.instanceProps.scrollbarSize = getScrollbarSize();
          stateUpdate.instanceProps.scrollbarSizeMeasured = true;
          return stateUpdate;
        });
      }

      if (typeof scrollLeft === 'number' && scrollLeft >= 0 || typeof scrollTop === 'number' && scrollTop >= 0) {
        var stateUpdate = Grid._getScrollToPositionStateUpdate({
          prevState: this.state,
          scrollLeft: scrollLeft,
          scrollTop: scrollTop
        });

        if (stateUpdate) {
          stateUpdate.needToResetStyleCache = false;
          this.setState(stateUpdate);
        }
      } // refs don't work in `react-test-renderer`


      if (this._scrollingContainer) {
        // setting the ref's scrollLeft and scrollTop.
        // Somehow in MultiGrid the main grid doesn't trigger a update on mount.
        if (this._scrollingContainer.scrollLeft !== this.state.scrollLeft) {
          this._scrollingContainer.scrollLeft = this.state.scrollLeft;
        }

        if (this._scrollingContainer.scrollTop !== this.state.scrollTop) {
          this._scrollingContainer.scrollTop = this.state.scrollTop;
        }
      } // Don't update scroll offset if the size is 0; we don't render any cells in this case.
      // Setting a state may cause us to later thing we've updated the offce when we haven't.


      var sizeIsBiggerThanZero = height > 0 && width > 0;

      if (scrollToColumn >= 0 && sizeIsBiggerThanZero) {
        this._updateScrollLeftForScrollToColumn();
      }

      if (scrollToRow >= 0 && sizeIsBiggerThanZero) {
        this._updateScrollTopForScrollToRow();
      } // Update onRowsRendered callback


      this._invokeOnGridRenderedHelper(); // Initialize onScroll callback


      this._invokeOnScrollMemoizer({
        scrollLeft: scrollLeft || 0,
        scrollTop: scrollTop || 0,
        totalColumnsWidth: instanceProps.columnSizeAndPositionManager.getTotalSize(),
        totalRowsHeight: instanceProps.rowSizeAndPositionManager.getTotalSize()
      });

      this._maybeCallOnScrollbarPresenceChange();
    }
    /**
     * @private
     * This method updates scrollLeft/scrollTop in state for the following conditions:
     * 1) New scroll-to-cell props have been set
     */

  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps, prevState) {
      var _this2 = this;

      var _this$props5 = this.props,
          autoHeight = _this$props5.autoHeight,
          autoWidth = _this$props5.autoWidth,
          columnCount = _this$props5.columnCount,
          height = _this$props5.height,
          rowCount = _this$props5.rowCount,
          scrollToAlignment = _this$props5.scrollToAlignment,
          scrollToColumn = _this$props5.scrollToColumn,
          scrollToRow = _this$props5.scrollToRow,
          width = _this$props5.width;
      var _this$state = this.state,
          scrollLeft = _this$state.scrollLeft,
          scrollPositionChangeReason = _this$state.scrollPositionChangeReason,
          scrollTop = _this$state.scrollTop,
          instanceProps = _this$state.instanceProps; // If cell sizes have been invalidated (eg we are using CellMeasurer) then reset cached positions.
      // We must do this at the start of the method as we may calculate and update scroll position below.

      this._handleInvalidatedGridSize(); // Handle edge case where column or row count has only just increased over 0.
      // In this case we may have to restore a previously-specified scroll offset.
      // For more info see bvaughn/react-virtualized/issues/218


      var columnOrRowCountJustIncreasedFromZero = columnCount > 0 && prevProps.columnCount === 0 || rowCount > 0 && prevProps.rowCount === 0; // Make sure requested changes to :scrollLeft or :scrollTop get applied.
      // Assigning to scrollLeft/scrollTop tells the browser to interrupt any running scroll animations,
      // And to discard any pending async changes to the scroll position that may have happened in the meantime (e.g. on a separate scrolling thread).
      // So we only set these when we require an adjustment of the scroll position.
      // See issue #2 for more information.

      if (scrollPositionChangeReason === SCROLL_POSITION_CHANGE_REASONS.REQUESTED) {
        // @TRICKY :autoHeight and :autoWidth properties instructs Grid to leave :scrollTop and :scrollLeft management to an external HOC (eg WindowScroller).
        // In this case we should avoid checking scrollingContainer.scrollTop and scrollingContainer.scrollLeft since it forces layout/flow.
        if (!autoWidth && scrollLeft >= 0 && (scrollLeft !== this._scrollingContainer.scrollLeft || columnOrRowCountJustIncreasedFromZero)) {
          this._scrollingContainer.scrollLeft = scrollLeft;
        }

        if (!autoHeight && scrollTop >= 0 && (scrollTop !== this._scrollingContainer.scrollTop || columnOrRowCountJustIncreasedFromZero)) {
          this._scrollingContainer.scrollTop = scrollTop;
        }
      } // Special case where the previous size was 0:
      // In this case we don't show any windowed cells at all.
      // So we should always recalculate offset afterwards.


      var sizeJustIncreasedFromZero = (prevProps.width === 0 || prevProps.height === 0) && height > 0 && width > 0; // Update scroll offsets if the current :scrollToColumn or :scrollToRow values requires it
      // @TODO Do we also need this check or can the one in componentWillUpdate() suffice?

      if (this._recomputeScrollLeftFlag) {
        this._recomputeScrollLeftFlag = false;

        this._updateScrollLeftForScrollToColumn(this.props);
      } else {
        (0,_utils_updateScrollIndexHelper__WEBPACK_IMPORTED_MODULE_14__["default"])({
          cellSizeAndPositionManager: instanceProps.columnSizeAndPositionManager,
          previousCellsCount: prevProps.columnCount,
          previousCellSize: prevProps.columnWidth,
          previousScrollToAlignment: prevProps.scrollToAlignment,
          previousScrollToIndex: prevProps.scrollToColumn,
          previousSize: prevProps.width,
          scrollOffset: scrollLeft,
          scrollToAlignment: scrollToAlignment,
          scrollToIndex: scrollToColumn,
          size: width,
          sizeJustIncreasedFromZero: sizeJustIncreasedFromZero,
          updateScrollIndexCallback: function updateScrollIndexCallback() {
            return _this2._updateScrollLeftForScrollToColumn(_this2.props);
          }
        });
      }

      if (this._recomputeScrollTopFlag) {
        this._recomputeScrollTopFlag = false;

        this._updateScrollTopForScrollToRow(this.props);
      } else {
        (0,_utils_updateScrollIndexHelper__WEBPACK_IMPORTED_MODULE_14__["default"])({
          cellSizeAndPositionManager: instanceProps.rowSizeAndPositionManager,
          previousCellsCount: prevProps.rowCount,
          previousCellSize: prevProps.rowHeight,
          previousScrollToAlignment: prevProps.scrollToAlignment,
          previousScrollToIndex: prevProps.scrollToRow,
          previousSize: prevProps.height,
          scrollOffset: scrollTop,
          scrollToAlignment: scrollToAlignment,
          scrollToIndex: scrollToRow,
          size: height,
          sizeJustIncreasedFromZero: sizeJustIncreasedFromZero,
          updateScrollIndexCallback: function updateScrollIndexCallback() {
            return _this2._updateScrollTopForScrollToRow(_this2.props);
          }
        });
      } // Update onRowsRendered callback if start/stop indices have changed


      this._invokeOnGridRenderedHelper(); // Changes to :scrollLeft or :scrollTop should also notify :onScroll listeners


      if (scrollLeft !== prevState.scrollLeft || scrollTop !== prevState.scrollTop) {
        var totalRowsHeight = instanceProps.rowSizeAndPositionManager.getTotalSize();
        var totalColumnsWidth = instanceProps.columnSizeAndPositionManager.getTotalSize();

        this._invokeOnScrollMemoizer({
          scrollLeft: scrollLeft,
          scrollTop: scrollTop,
          totalColumnsWidth: totalColumnsWidth,
          totalRowsHeight: totalRowsHeight
        });
      }

      this._maybeCallOnScrollbarPresenceChange();
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      if (this._disablePointerEventsTimeoutId) {
        (0,_utils_requestAnimationTimeout__WEBPACK_IMPORTED_MODULE_18__.cancelAnimationTimeout)(this._disablePointerEventsTimeoutId);
      }
    }
    /**
     * This method updates scrollLeft/scrollTop in state for the following conditions:
     * 1) Empty content (0 rows or columns)
     * 2) New scroll props overriding the current state
     * 3) Cells-count or cells-size has changed, making previous scroll offsets invalid
     */

  }, {
    key: "render",
    value: function render() {
      var _this$props6 = this.props,
          autoContainerWidth = _this$props6.autoContainerWidth,
          autoHeight = _this$props6.autoHeight,
          autoWidth = _this$props6.autoWidth,
          className = _this$props6.className,
          containerProps = _this$props6.containerProps,
          containerRole = _this$props6.containerRole,
          containerStyle = _this$props6.containerStyle,
          height = _this$props6.height,
          id = _this$props6.id,
          noContentRenderer = _this$props6.noContentRenderer,
          role = _this$props6.role,
          style = _this$props6.style,
          tabIndex = _this$props6.tabIndex,
          width = _this$props6.width;
      var _this$state2 = this.state,
          instanceProps = _this$state2.instanceProps,
          needToResetStyleCache = _this$state2.needToResetStyleCache;

      var isScrolling = this._isScrolling();

      var gridStyle = {
        boxSizing: 'border-box',
        direction: 'ltr',
        height: autoHeight ? 'auto' : height,
        position: 'relative',
        width: autoWidth ? 'auto' : width,
        WebkitOverflowScrolling: 'touch',
        willChange: 'transform'
      };

      if (needToResetStyleCache) {
        this._styleCache = {};
      } // calculate _styleCache here
      // if state.isScrolling (not from _isScrolling) then reset


      if (!this.state.isScrolling) {
        this._resetStyleCache();
      } // calculate children to render here


      this._calculateChildrenToRender(this.props, this.state);

      var totalColumnsWidth = instanceProps.columnSizeAndPositionManager.getTotalSize();
      var totalRowsHeight = instanceProps.rowSizeAndPositionManager.getTotalSize(); // Force browser to hide scrollbars when we know they aren't necessary.
      // Otherwise once scrollbars appear they may not disappear again.
      // For more info see issue #116

      var verticalScrollBarSize = totalRowsHeight > height ? instanceProps.scrollbarSize : 0;
      var horizontalScrollBarSize = totalColumnsWidth > width ? instanceProps.scrollbarSize : 0;

      if (horizontalScrollBarSize !== this._horizontalScrollBarSize || verticalScrollBarSize !== this._verticalScrollBarSize) {
        this._horizontalScrollBarSize = horizontalScrollBarSize;
        this._verticalScrollBarSize = verticalScrollBarSize;
        this._scrollbarPresenceChanged = true;
      } // Also explicitly init styles to 'auto' if scrollbars are required.
      // This works around an obscure edge case where external CSS styles have not yet been loaded,
      // But an initial scroll index of offset is set as an external prop.
      // Without this style, Grid would render the correct range of cells but would NOT update its internal offset.
      // This was originally reported via clauderic/react-infinite-calendar/issues/23


      gridStyle.overflowX = totalColumnsWidth + verticalScrollBarSize <= width ? 'hidden' : 'auto';
      gridStyle.overflowY = totalRowsHeight + horizontalScrollBarSize <= height ? 'hidden' : 'auto';
      var childrenToDisplay = this._childrenToDisplay;
      var showNoContentRenderer = childrenToDisplay.length === 0 && height > 0 && width > 0;
      return react__WEBPACK_IMPORTED_MODULE_8__.createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({
        ref: this._setScrollingContainerRef
      }, containerProps, {
        "aria-label": this.props['aria-label'],
        "aria-readonly": this.props['aria-readonly'],
        className: (0,clsx__WEBPACK_IMPORTED_MODULE_9__["default"])('ReactVirtualized__Grid', className),
        id: id,
        onScroll: this._onScroll,
        role: role,
        style: _objectSpread({}, gridStyle, {}, style),
        tabIndex: tabIndex
      }), childrenToDisplay.length > 0 && react__WEBPACK_IMPORTED_MODULE_8__.createElement("div", {
        className: "ReactVirtualized__Grid__innerScrollContainer",
        role: containerRole,
        style: _objectSpread({
          width: autoContainerWidth ? 'auto' : totalColumnsWidth,
          height: totalRowsHeight,
          maxWidth: totalColumnsWidth,
          maxHeight: totalRowsHeight,
          overflow: 'hidden',
          pointerEvents: isScrolling ? 'none' : '',
          position: 'relative'
        }, containerStyle)
      }, childrenToDisplay), showNoContentRenderer && noContentRenderer());
    }
    /* ---------------------------- Helper methods ---------------------------- */

  }, {
    key: "_calculateChildrenToRender",
    value: function _calculateChildrenToRender() {
      var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.props;
      var state = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : this.state;
      var cellRenderer = props.cellRenderer,
          cellRangeRenderer = props.cellRangeRenderer,
          columnCount = props.columnCount,
          deferredMeasurementCache = props.deferredMeasurementCache,
          height = props.height,
          overscanColumnCount = props.overscanColumnCount,
          overscanIndicesGetter = props.overscanIndicesGetter,
          overscanRowCount = props.overscanRowCount,
          rowCount = props.rowCount,
          width = props.width,
          isScrollingOptOut = props.isScrollingOptOut;
      var scrollDirectionHorizontal = state.scrollDirectionHorizontal,
          scrollDirectionVertical = state.scrollDirectionVertical,
          instanceProps = state.instanceProps;
      var scrollTop = this._initialScrollTop > 0 ? this._initialScrollTop : state.scrollTop;
      var scrollLeft = this._initialScrollLeft > 0 ? this._initialScrollLeft : state.scrollLeft;

      var isScrolling = this._isScrolling(props, state);

      this._childrenToDisplay = []; // Render only enough columns and rows to cover the visible area of the grid.

      if (height > 0 && width > 0) {
        var visibleColumnIndices = instanceProps.columnSizeAndPositionManager.getVisibleCellRange({
          containerSize: width,
          offset: scrollLeft
        });
        var visibleRowIndices = instanceProps.rowSizeAndPositionManager.getVisibleCellRange({
          containerSize: height,
          offset: scrollTop
        });
        var horizontalOffsetAdjustment = instanceProps.columnSizeAndPositionManager.getOffsetAdjustment({
          containerSize: width,
          offset: scrollLeft
        });
        var verticalOffsetAdjustment = instanceProps.rowSizeAndPositionManager.getOffsetAdjustment({
          containerSize: height,
          offset: scrollTop
        }); // Store for _invokeOnGridRenderedHelper()

        this._renderedColumnStartIndex = visibleColumnIndices.start;
        this._renderedColumnStopIndex = visibleColumnIndices.stop;
        this._renderedRowStartIndex = visibleRowIndices.start;
        this._renderedRowStopIndex = visibleRowIndices.stop;
        var overscanColumnIndices = overscanIndicesGetter({
          direction: 'horizontal',
          cellCount: columnCount,
          overscanCellsCount: overscanColumnCount,
          scrollDirection: scrollDirectionHorizontal,
          startIndex: typeof visibleColumnIndices.start === 'number' ? visibleColumnIndices.start : 0,
          stopIndex: typeof visibleColumnIndices.stop === 'number' ? visibleColumnIndices.stop : -1
        });
        var overscanRowIndices = overscanIndicesGetter({
          direction: 'vertical',
          cellCount: rowCount,
          overscanCellsCount: overscanRowCount,
          scrollDirection: scrollDirectionVertical,
          startIndex: typeof visibleRowIndices.start === 'number' ? visibleRowIndices.start : 0,
          stopIndex: typeof visibleRowIndices.stop === 'number' ? visibleRowIndices.stop : -1
        }); // Store for _invokeOnGridRenderedHelper()

        var columnStartIndex = overscanColumnIndices.overscanStartIndex;
        var columnStopIndex = overscanColumnIndices.overscanStopIndex;
        var rowStartIndex = overscanRowIndices.overscanStartIndex;
        var rowStopIndex = overscanRowIndices.overscanStopIndex; // Advanced use-cases (eg CellMeasurer) require batched measurements to determine accurate sizes.

        if (deferredMeasurementCache) {
          // If rows have a dynamic height, scan the rows we are about to render.
          // If any have not yet been measured, then we need to render all columns initially,
          // Because the height of the row is equal to the tallest cell within that row,
          // (And so we can't know the height without measuring all column-cells first).
          if (!deferredMeasurementCache.hasFixedHeight()) {
            for (var rowIndex = rowStartIndex; rowIndex <= rowStopIndex; rowIndex++) {
              if (!deferredMeasurementCache.has(rowIndex, 0)) {
                columnStartIndex = 0;
                columnStopIndex = columnCount - 1;
                break;
              }
            }
          } // If columns have a dynamic width, scan the columns we are about to render.
          // If any have not yet been measured, then we need to render all rows initially,
          // Because the width of the column is equal to the widest cell within that column,
          // (And so we can't know the width without measuring all row-cells first).


          if (!deferredMeasurementCache.hasFixedWidth()) {
            for (var columnIndex = columnStartIndex; columnIndex <= columnStopIndex; columnIndex++) {
              if (!deferredMeasurementCache.has(0, columnIndex)) {
                rowStartIndex = 0;
                rowStopIndex = rowCount - 1;
                break;
              }
            }
          }
        }

        this._childrenToDisplay = cellRangeRenderer({
          cellCache: this._cellCache,
          cellRenderer: cellRenderer,
          columnSizeAndPositionManager: instanceProps.columnSizeAndPositionManager,
          columnStartIndex: columnStartIndex,
          columnStopIndex: columnStopIndex,
          deferredMeasurementCache: deferredMeasurementCache,
          horizontalOffsetAdjustment: horizontalOffsetAdjustment,
          isScrolling: isScrolling,
          isScrollingOptOut: isScrollingOptOut,
          parent: this,
          rowSizeAndPositionManager: instanceProps.rowSizeAndPositionManager,
          rowStartIndex: rowStartIndex,
          rowStopIndex: rowStopIndex,
          scrollLeft: scrollLeft,
          scrollTop: scrollTop,
          styleCache: this._styleCache,
          verticalOffsetAdjustment: verticalOffsetAdjustment,
          visibleColumnIndices: visibleColumnIndices,
          visibleRowIndices: visibleRowIndices
        }); // update the indices

        this._columnStartIndex = columnStartIndex;
        this._columnStopIndex = columnStopIndex;
        this._rowStartIndex = rowStartIndex;
        this._rowStopIndex = rowStopIndex;
      }
    }
    /**
     * Sets an :isScrolling flag for a small window of time.
     * This flag is used to disable pointer events on the scrollable portion of the Grid.
     * This prevents jerky/stuttery mouse-wheel scrolling.
     */

  }, {
    key: "_debounceScrollEnded",
    value: function _debounceScrollEnded() {
      var scrollingResetTimeInterval = this.props.scrollingResetTimeInterval;

      if (this._disablePointerEventsTimeoutId) {
        (0,_utils_requestAnimationTimeout__WEBPACK_IMPORTED_MODULE_18__.cancelAnimationTimeout)(this._disablePointerEventsTimeoutId);
      }

      this._disablePointerEventsTimeoutId = (0,_utils_requestAnimationTimeout__WEBPACK_IMPORTED_MODULE_18__.requestAnimationTimeout)(this._debounceScrollEndedCallback, scrollingResetTimeInterval);
    }
  }, {
    key: "_handleInvalidatedGridSize",

    /**
     * Check for batched CellMeasurer size invalidations.
     * This will occur the first time one or more previously unmeasured cells are rendered.
     */
    value: function _handleInvalidatedGridSize() {
      if (typeof this._deferredInvalidateColumnIndex === 'number' && typeof this._deferredInvalidateRowIndex === 'number') {
        var columnIndex = this._deferredInvalidateColumnIndex;
        var rowIndex = this._deferredInvalidateRowIndex;
        this._deferredInvalidateColumnIndex = null;
        this._deferredInvalidateRowIndex = null;
        this.recomputeGridSize({
          columnIndex: columnIndex,
          rowIndex: rowIndex
        });
      }
    }
  }, {
    key: "_invokeOnScrollMemoizer",
    value: function _invokeOnScrollMemoizer(_ref6) {
      var _this3 = this;

      var scrollLeft = _ref6.scrollLeft,
          scrollTop = _ref6.scrollTop,
          totalColumnsWidth = _ref6.totalColumnsWidth,
          totalRowsHeight = _ref6.totalRowsHeight;

      this._onScrollMemoizer({
        callback: function callback(_ref7) {
          var scrollLeft = _ref7.scrollLeft,
              scrollTop = _ref7.scrollTop;
          var _this3$props = _this3.props,
              height = _this3$props.height,
              onScroll = _this3$props.onScroll,
              width = _this3$props.width;
          onScroll({
            clientHeight: height,
            clientWidth: width,
            scrollHeight: totalRowsHeight,
            scrollLeft: scrollLeft,
            scrollTop: scrollTop,
            scrollWidth: totalColumnsWidth
          });
        },
        indices: {
          scrollLeft: scrollLeft,
          scrollTop: scrollTop
        }
      });
    }
  }, {
    key: "_isScrolling",
    value: function _isScrolling() {
      var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.props;
      var state = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : this.state;
      // If isScrolling is defined in props, use it to override the value in state
      // This is a performance optimization for WindowScroller + Grid
      return Object.hasOwnProperty.call(props, 'isScrolling') ? Boolean(props.isScrolling) : Boolean(state.isScrolling);
    }
  }, {
    key: "_maybeCallOnScrollbarPresenceChange",
    value: function _maybeCallOnScrollbarPresenceChange() {
      if (this._scrollbarPresenceChanged) {
        var onScrollbarPresenceChange = this.props.onScrollbarPresenceChange;
        this._scrollbarPresenceChanged = false;
        onScrollbarPresenceChange({
          horizontal: this._horizontalScrollBarSize > 0,
          size: this.state.instanceProps.scrollbarSize,
          vertical: this._verticalScrollBarSize > 0
        });
      }
    }
  }, {
    key: "scrollToPosition",

    /**
     * Scroll to the specified offset(s).
     * Useful for animating position changes.
     */
    value: function scrollToPosition(_ref8) {
      var scrollLeft = _ref8.scrollLeft,
          scrollTop = _ref8.scrollTop;

      var stateUpdate = Grid._getScrollToPositionStateUpdate({
        prevState: this.state,
        scrollLeft: scrollLeft,
        scrollTop: scrollTop
      });

      if (stateUpdate) {
        stateUpdate.needToResetStyleCache = false;
        this.setState(stateUpdate);
      }
    }
  }, {
    key: "_getCalculatedScrollLeft",
    value: function _getCalculatedScrollLeft() {
      var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.props;
      var state = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : this.state;
      return Grid._getCalculatedScrollLeft(props, state);
    }
  }, {
    key: "_updateScrollLeftForScrollToColumn",
    value: function _updateScrollLeftForScrollToColumn() {
      var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.props;
      var state = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : this.state;

      var stateUpdate = Grid._getScrollLeftForScrollToColumnStateUpdate(props, state);

      if (stateUpdate) {
        stateUpdate.needToResetStyleCache = false;
        this.setState(stateUpdate);
      }
    }
  }, {
    key: "_getCalculatedScrollTop",
    value: function _getCalculatedScrollTop() {
      var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.props;
      var state = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : this.state;
      return Grid._getCalculatedScrollTop(props, state);
    }
  }, {
    key: "_resetStyleCache",
    value: function _resetStyleCache() {
      var styleCache = this._styleCache;
      var cellCache = this._cellCache;
      var isScrollingOptOut = this.props.isScrollingOptOut; // Reset cell and style caches once scrolling stops.
      // This makes Grid simpler to use (since cells commonly change).
      // And it keeps the caches from growing too large.
      // Performance is most sensitive when a user is scrolling.
      // Don't clear visible cells from cellCache if isScrollingOptOut is specified.
      // This keeps the cellCache to a resonable size.

      this._cellCache = {};
      this._styleCache = {}; // Copy over the visible cell styles so avoid unnecessary re-render.

      for (var rowIndex = this._rowStartIndex; rowIndex <= this._rowStopIndex; rowIndex++) {
        for (var columnIndex = this._columnStartIndex; columnIndex <= this._columnStopIndex; columnIndex++) {
          var key = "".concat(rowIndex, "-").concat(columnIndex);
          this._styleCache[key] = styleCache[key];

          if (isScrollingOptOut) {
            this._cellCache[key] = cellCache[key];
          }
        }
      }
    }
  }, {
    key: "_updateScrollTopForScrollToRow",
    value: function _updateScrollTopForScrollToRow() {
      var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.props;
      var state = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : this.state;

      var stateUpdate = Grid._getScrollTopForScrollToRowStateUpdate(props, state);

      if (stateUpdate) {
        stateUpdate.needToResetStyleCache = false;
        this.setState(stateUpdate);
      }
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(nextProps, prevState) {
      var newState = {};

      if (nextProps.columnCount === 0 && prevState.scrollLeft !== 0 || nextProps.rowCount === 0 && prevState.scrollTop !== 0) {
        newState.scrollLeft = 0;
        newState.scrollTop = 0; // only use scroll{Left,Top} from props if scrollTo{Column,Row} isn't specified
        // scrollTo{Column,Row} should override scroll{Left,Top}
      } else if (nextProps.scrollLeft !== prevState.scrollLeft && nextProps.scrollToColumn < 0 || nextProps.scrollTop !== prevState.scrollTop && nextProps.scrollToRow < 0) {
        Object.assign(newState, Grid._getScrollToPositionStateUpdate({
          prevState: prevState,
          scrollLeft: nextProps.scrollLeft,
          scrollTop: nextProps.scrollTop
        }));
      }

      var instanceProps = prevState.instanceProps; // Initially we should not clearStyleCache

      newState.needToResetStyleCache = false;

      if (nextProps.columnWidth !== instanceProps.prevColumnWidth || nextProps.rowHeight !== instanceProps.prevRowHeight) {
        // Reset cache. set it to {} in render
        newState.needToResetStyleCache = true;
      }

      instanceProps.columnSizeAndPositionManager.configure({
        cellCount: nextProps.columnCount,
        estimatedCellSize: Grid._getEstimatedColumnSize(nextProps),
        cellSizeGetter: Grid._wrapSizeGetter(nextProps.columnWidth)
      });
      instanceProps.rowSizeAndPositionManager.configure({
        cellCount: nextProps.rowCount,
        estimatedCellSize: Grid._getEstimatedRowSize(nextProps),
        cellSizeGetter: Grid._wrapSizeGetter(nextProps.rowHeight)
      });

      if (instanceProps.prevColumnCount === 0 || instanceProps.prevRowCount === 0) {
        instanceProps.prevColumnCount = 0;
        instanceProps.prevRowCount = 0;
      } // If scrolling is controlled outside this component, clear cache when scrolling stops


      if (nextProps.autoHeight && nextProps.isScrolling === false && instanceProps.prevIsScrolling === true) {
        Object.assign(newState, {
          isScrolling: false
        });
      }

      var maybeStateA;
      var maybeStateB;
      (0,_utils_calculateSizeAndPositionDataAndUpdateScrollOffset__WEBPACK_IMPORTED_MODULE_10__["default"])({
        cellCount: instanceProps.prevColumnCount,
        cellSize: typeof instanceProps.prevColumnWidth === 'number' ? instanceProps.prevColumnWidth : null,
        computeMetadataCallback: function computeMetadataCallback() {
          return instanceProps.columnSizeAndPositionManager.resetCell(0);
        },
        computeMetadataCallbackProps: nextProps,
        nextCellsCount: nextProps.columnCount,
        nextCellSize: typeof nextProps.columnWidth === 'number' ? nextProps.columnWidth : null,
        nextScrollToIndex: nextProps.scrollToColumn,
        scrollToIndex: instanceProps.prevScrollToColumn,
        updateScrollOffsetForScrollToIndex: function updateScrollOffsetForScrollToIndex() {
          maybeStateA = Grid._getScrollLeftForScrollToColumnStateUpdate(nextProps, prevState);
        }
      });
      (0,_utils_calculateSizeAndPositionDataAndUpdateScrollOffset__WEBPACK_IMPORTED_MODULE_10__["default"])({
        cellCount: instanceProps.prevRowCount,
        cellSize: typeof instanceProps.prevRowHeight === 'number' ? instanceProps.prevRowHeight : null,
        computeMetadataCallback: function computeMetadataCallback() {
          return instanceProps.rowSizeAndPositionManager.resetCell(0);
        },
        computeMetadataCallbackProps: nextProps,
        nextCellsCount: nextProps.rowCount,
        nextCellSize: typeof nextProps.rowHeight === 'number' ? nextProps.rowHeight : null,
        nextScrollToIndex: nextProps.scrollToRow,
        scrollToIndex: instanceProps.prevScrollToRow,
        updateScrollOffsetForScrollToIndex: function updateScrollOffsetForScrollToIndex() {
          maybeStateB = Grid._getScrollTopForScrollToRowStateUpdate(nextProps, prevState);
        }
      });
      instanceProps.prevColumnCount = nextProps.columnCount;
      instanceProps.prevColumnWidth = nextProps.columnWidth;
      instanceProps.prevIsScrolling = nextProps.isScrolling === true;
      instanceProps.prevRowCount = nextProps.rowCount;
      instanceProps.prevRowHeight = nextProps.rowHeight;
      instanceProps.prevScrollToColumn = nextProps.scrollToColumn;
      instanceProps.prevScrollToRow = nextProps.scrollToRow; // getting scrollBarSize (moved from componentWillMount)

      instanceProps.scrollbarSize = nextProps.getScrollbarSize();

      if (instanceProps.scrollbarSize === undefined) {
        instanceProps.scrollbarSizeMeasured = false;
        instanceProps.scrollbarSize = 0;
      } else {
        instanceProps.scrollbarSizeMeasured = true;
      }

      newState.instanceProps = instanceProps;
      return _objectSpread({}, newState, {}, maybeStateA, {}, maybeStateB);
    }
  }, {
    key: "_getEstimatedColumnSize",
    value: function _getEstimatedColumnSize(props) {
      return typeof props.columnWidth === 'number' ? props.columnWidth : props.estimatedColumnSize;
    }
  }, {
    key: "_getEstimatedRowSize",
    value: function _getEstimatedRowSize(props) {
      return typeof props.rowHeight === 'number' ? props.rowHeight : props.estimatedRowSize;
    }
  }, {
    key: "_getScrollToPositionStateUpdate",

    /**
     * Get the updated state after scrolling to
     * scrollLeft and scrollTop
     */
    value: function _getScrollToPositionStateUpdate(_ref9) {
      var prevState = _ref9.prevState,
          scrollLeft = _ref9.scrollLeft,
          scrollTop = _ref9.scrollTop;
      var newState = {
        scrollPositionChangeReason: SCROLL_POSITION_CHANGE_REASONS.REQUESTED
      };

      if (typeof scrollLeft === 'number' && scrollLeft >= 0) {
        newState.scrollDirectionHorizontal = scrollLeft > prevState.scrollLeft ? _defaultOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_13__.SCROLL_DIRECTION_FORWARD : _defaultOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_13__.SCROLL_DIRECTION_BACKWARD;
        newState.scrollLeft = scrollLeft;
      }

      if (typeof scrollTop === 'number' && scrollTop >= 0) {
        newState.scrollDirectionVertical = scrollTop > prevState.scrollTop ? _defaultOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_13__.SCROLL_DIRECTION_FORWARD : _defaultOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_13__.SCROLL_DIRECTION_BACKWARD;
        newState.scrollTop = scrollTop;
      }

      if (typeof scrollLeft === 'number' && scrollLeft >= 0 && scrollLeft !== prevState.scrollLeft || typeof scrollTop === 'number' && scrollTop >= 0 && scrollTop !== prevState.scrollTop) {
        return newState;
      }

      return {};
    }
  }, {
    key: "_wrapSizeGetter",
    value: function _wrapSizeGetter(value) {
      return typeof value === 'function' ? value : function () {
        return value;
      };
    }
  }, {
    key: "_getCalculatedScrollLeft",
    value: function _getCalculatedScrollLeft(nextProps, prevState) {
      var columnCount = nextProps.columnCount,
          height = nextProps.height,
          scrollToAlignment = nextProps.scrollToAlignment,
          scrollToColumn = nextProps.scrollToColumn,
          width = nextProps.width;
      var scrollLeft = prevState.scrollLeft,
          instanceProps = prevState.instanceProps;

      if (columnCount > 0) {
        var finalColumn = columnCount - 1;
        var targetIndex = scrollToColumn < 0 ? finalColumn : Math.min(finalColumn, scrollToColumn);
        var totalRowsHeight = instanceProps.rowSizeAndPositionManager.getTotalSize();
        var scrollBarSize = instanceProps.scrollbarSizeMeasured && totalRowsHeight > height ? instanceProps.scrollbarSize : 0;
        return instanceProps.columnSizeAndPositionManager.getUpdatedOffsetForIndex({
          align: scrollToAlignment,
          containerSize: width - scrollBarSize,
          currentOffset: scrollLeft,
          targetIndex: targetIndex
        });
      }

      return 0;
    }
  }, {
    key: "_getScrollLeftForScrollToColumnStateUpdate",
    value: function _getScrollLeftForScrollToColumnStateUpdate(nextProps, prevState) {
      var scrollLeft = prevState.scrollLeft;

      var calculatedScrollLeft = Grid._getCalculatedScrollLeft(nextProps, prevState);

      if (typeof calculatedScrollLeft === 'number' && calculatedScrollLeft >= 0 && scrollLeft !== calculatedScrollLeft) {
        return Grid._getScrollToPositionStateUpdate({
          prevState: prevState,
          scrollLeft: calculatedScrollLeft,
          scrollTop: -1
        });
      }

      return {};
    }
  }, {
    key: "_getCalculatedScrollTop",
    value: function _getCalculatedScrollTop(nextProps, prevState) {
      var height = nextProps.height,
          rowCount = nextProps.rowCount,
          scrollToAlignment = nextProps.scrollToAlignment,
          scrollToRow = nextProps.scrollToRow,
          width = nextProps.width;
      var scrollTop = prevState.scrollTop,
          instanceProps = prevState.instanceProps;

      if (rowCount > 0) {
        var finalRow = rowCount - 1;
        var targetIndex = scrollToRow < 0 ? finalRow : Math.min(finalRow, scrollToRow);
        var totalColumnsWidth = instanceProps.columnSizeAndPositionManager.getTotalSize();
        var scrollBarSize = instanceProps.scrollbarSizeMeasured && totalColumnsWidth > width ? instanceProps.scrollbarSize : 0;
        return instanceProps.rowSizeAndPositionManager.getUpdatedOffsetForIndex({
          align: scrollToAlignment,
          containerSize: height - scrollBarSize,
          currentOffset: scrollTop,
          targetIndex: targetIndex
        });
      }

      return 0;
    }
  }, {
    key: "_getScrollTopForScrollToRowStateUpdate",
    value: function _getScrollTopForScrollToRowStateUpdate(nextProps, prevState) {
      var scrollTop = prevState.scrollTop;

      var calculatedScrollTop = Grid._getCalculatedScrollTop(nextProps, prevState);

      if (typeof calculatedScrollTop === 'number' && calculatedScrollTop >= 0 && scrollTop !== calculatedScrollTop) {
        return Grid._getScrollToPositionStateUpdate({
          prevState: prevState,
          scrollLeft: -1,
          scrollTop: calculatedScrollTop
        });
      }

      return {};
    }
  }]);

  return Grid;
}(react__WEBPACK_IMPORTED_MODULE_8__.PureComponent), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_class, "propTypes",  false ? 0 : {
  "aria-label": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().string.isRequired),
  "aria-readonly": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().bool),

  /**
   * Set the width of the inner scrollable container to 'auto'.
   * This is useful for single-column Grids to ensure that the column doesn't extend below a vertical scrollbar.
   */
  "autoContainerWidth": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().bool.isRequired),

  /**
   * Removes fixed height from the scrollingContainer so that the total height of rows can stretch the window.
   * Intended for use with WindowScroller
   */
  "autoHeight": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().bool.isRequired),

  /**
   * Removes fixed width from the scrollingContainer so that the total width of rows can stretch the window.
   * Intended for use with WindowScroller
   */
  "autoWidth": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().bool.isRequired),

  /** Responsible for rendering a cell given an row and column index.  */
  "cellRenderer": function cellRenderer() {
    return (typeof _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellRenderer === "function" ? _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellRenderer.isRequired ? _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellRenderer.isRequired : _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellRenderer : prop_types__WEBPACK_IMPORTED_MODULE_19___default().shape(_types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellRenderer).isRequired).apply(this, arguments);
  },

  /** Responsible for rendering a group of cells given their index ranges.  */
  "cellRangeRenderer": function cellRangeRenderer() {
    return (typeof _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellRangeRenderer === "function" ? _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellRangeRenderer.isRequired ? _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellRangeRenderer.isRequired : _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellRangeRenderer : prop_types__WEBPACK_IMPORTED_MODULE_19___default().shape(_types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellRangeRenderer).isRequired).apply(this, arguments);
  },

  /** Optional custom CSS class name to attach to root Grid element.  */
  "className": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().string),

  /** Number of columns in grid.  */
  "columnCount": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().number.isRequired),

  /** Either a fixed column width (number) or a function that returns the width of a column given its index.  */
  "columnWidth": function columnWidth() {
    return (typeof _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellSize === "function" ? _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellSize.isRequired ? _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellSize.isRequired : _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellSize : prop_types__WEBPACK_IMPORTED_MODULE_19___default().shape(_types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellSize).isRequired).apply(this, arguments);
  },

  /** Unfiltered props for the Grid container. */
  "containerProps": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().object),

  /** ARIA role for the cell-container.  */
  "containerRole": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().string.isRequired),

  /** Optional inline style applied to inner cell-container */
  "containerStyle": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().object.isRequired),

  /**
   * If CellMeasurer is used to measure this Grid's children, this should be a pointer to its CellMeasurerCache.
   * A shared CellMeasurerCache reference enables Grid and CellMeasurer to share measurement data.
   */
  "deferredMeasurementCache": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().object),

  /**
   * Used to estimate the total width of a Grid before all of its columns have actually been measured.
   * The estimated total width is adjusted as columns are rendered.
   */
  "estimatedColumnSize": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().number.isRequired),

  /**
   * Used to estimate the total height of a Grid before all of its rows have actually been measured.
   * The estimated total height is adjusted as rows are rendered.
   */
  "estimatedRowSize": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().number.isRequired),

  /** Exposed for testing purposes only.  */
  "getScrollbarSize": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().func.isRequired),

  /** Height of Grid; this property determines the number of visible (vs virtualized) rows.  */
  "height": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().number.isRequired),

  /** Optional custom id to attach to root Grid element.  */
  "id": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().string),

  /**
   * Override internal is-scrolling state tracking.
   * This property is primarily intended for use with the WindowScroller component.
   */
  "isScrolling": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().bool),

  /**
   * Opt-out of isScrolling param passed to cellRangeRenderer.
   * To avoid the extra render when scroll stops.
   */
  "isScrollingOptOut": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().bool.isRequired),

  /** Optional renderer to be used in place of rows when either :rowCount or :columnCount is 0.  */
  "noContentRenderer": function noContentRenderer() {
    return (typeof _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_NoContentRenderer === "function" ? _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_NoContentRenderer.isRequired ? _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_NoContentRenderer.isRequired : _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_NoContentRenderer : prop_types__WEBPACK_IMPORTED_MODULE_19___default().shape(_types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_NoContentRenderer).isRequired).apply(this, arguments);
  },

  /**
   * Callback invoked whenever the scroll offset changes within the inner scrollable region.
   * This callback can be used to sync scrolling between lists, tables, or grids.
   */
  "onScroll": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().func.isRequired),

  /**
   * Called whenever a horizontal or vertical scrollbar is added or removed.
   * This prop is not intended for end-user use;
   * It is used by MultiGrid to support fixed-row/fixed-column scroll syncing.
   */
  "onScrollbarPresenceChange": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().func.isRequired),

  /** Callback invoked with information about the section of the Grid that was just rendered.  */
  "onSectionRendered": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().func.isRequired),

  /**
   * Number of columns to render before/after the visible section of the grid.
   * These columns can help for smoother scrolling on touch devices or browsers that send scroll events infrequently.
   */
  "overscanColumnCount": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().number.isRequired),

  /**
   * Calculates the number of cells to overscan before and after a specified range.
   * This function ensures that overscanning doesn't exceed the available cells.
   */
  "overscanIndicesGetter": function overscanIndicesGetter() {
    return (typeof _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_OverscanIndicesGetter === "function" ? _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_OverscanIndicesGetter.isRequired ? _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_OverscanIndicesGetter.isRequired : _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_OverscanIndicesGetter : prop_types__WEBPACK_IMPORTED_MODULE_19___default().shape(_types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_OverscanIndicesGetter).isRequired).apply(this, arguments);
  },

  /**
   * Number of rows to render above/below the visible section of the grid.
   * These rows can help for smoother scrolling on touch devices or browsers that send scroll events infrequently.
   */
  "overscanRowCount": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().number.isRequired),

  /** ARIA role for the grid element.  */
  "role": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().string.isRequired),

  /**
   * Either a fixed row height (number) or a function that returns the height of a row given its index.
   * Should implement the following interface: ({ index: number }): number
   */
  "rowHeight": function rowHeight() {
    return (typeof _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellSize === "function" ? _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellSize.isRequired ? _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellSize.isRequired : _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellSize : prop_types__WEBPACK_IMPORTED_MODULE_19___default().shape(_types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_CellSize).isRequired).apply(this, arguments);
  },

  /** Number of rows in grid.  */
  "rowCount": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().number.isRequired),

  /** Wait this amount of time after the last scroll event before resetting Grid `pointer-events`. */
  "scrollingResetTimeInterval": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().number.isRequired),

  /** Horizontal offset. */
  "scrollLeft": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().number),

  /**
   * Controls scroll-to-cell behavior of the Grid.
   * The default ("auto") scrolls the least amount possible to ensure that the specified cell is fully visible.
   * Use "start" to align cells to the top/left of the Grid and "end" to align bottom/right.
   */
  "scrollToAlignment": function scrollToAlignment() {
    return (typeof _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_Alignment === "function" ? _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_Alignment.isRequired ? _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_Alignment.isRequired : _types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_Alignment : prop_types__WEBPACK_IMPORTED_MODULE_19___default().shape(_types__WEBPACK_IMPORTED_MODULE_20__.bpfrpt_proptype_Alignment).isRequired).apply(this, arguments);
  },

  /** Column index to ensure visible (by forcefully scrolling if necessary) */
  "scrollToColumn": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().number.isRequired),

  /** Vertical offset. */
  "scrollTop": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().number),

  /** Row index to ensure visible (by forcefully scrolling if necessary) */
  "scrollToRow": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().number.isRequired),

  /** Optional inline style */
  "style": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().object.isRequired),

  /** Tab index for focus */
  "tabIndex": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().number),

  /** Width of Grid; this property determines the number of visible (vs virtualized) columns.  */
  "width": (prop_types__WEBPACK_IMPORTED_MODULE_19___default().number.isRequired)
}), _temp);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(Grid, "defaultProps", {
  'aria-label': 'grid',
  'aria-readonly': true,
  autoContainerWidth: false,
  autoHeight: false,
  autoWidth: false,
  cellRangeRenderer: _defaultCellRangeRenderer__WEBPACK_IMPORTED_MODULE_15__["default"],
  containerRole: 'rowgroup',
  containerStyle: {},
  estimatedColumnSize: 100,
  estimatedRowSize: 30,
  getScrollbarSize: dom_helpers_scrollbarSize__WEBPACK_IMPORTED_MODULE_16__["default"],
  noContentRenderer: renderNull,
  onScroll: function onScroll() {},
  onScrollbarPresenceChange: function onScrollbarPresenceChange() {},
  onSectionRendered: function onSectionRendered() {},
  overscanColumnCount: 0,
  overscanIndicesGetter: _defaultOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_13__["default"],
  overscanRowCount: 10,
  role: 'grid',
  scrollingResetTimeInterval: DEFAULT_SCROLLING_RESET_TIME_INTERVAL,
  scrollToAlignment: 'auto',
  scrollToColumn: -1,
  scrollToRow: -1,
  style: {},
  tabIndex: 0,
  isScrollingOptOut: false
});

(0,react_lifecycles_compat__WEBPACK_IMPORTED_MODULE_17__.polyfill)(Grid);
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Grid);
















/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Grid/accessibilityOverscanIndicesGetter.js":
/*!***********************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Grid/accessibilityOverscanIndicesGetter.js ***!
  \***********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "SCROLL_DIRECTION_BACKWARD": () => (/* binding */ SCROLL_DIRECTION_BACKWARD),
/* harmony export */   "SCROLL_DIRECTION_FORWARD": () => (/* binding */ SCROLL_DIRECTION_FORWARD),
/* harmony export */   "SCROLL_DIRECTION_HORIZONTAL": () => (/* binding */ SCROLL_DIRECTION_HORIZONTAL),
/* harmony export */   "SCROLL_DIRECTION_VERTICAL": () => (/* binding */ SCROLL_DIRECTION_VERTICAL),
/* harmony export */   "default": () => (/* binding */ defaultOverscanIndicesGetter)
/* harmony export */ });
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/Grid/types.js");
var SCROLL_DIRECTION_BACKWARD = -1;
var SCROLL_DIRECTION_FORWARD = 1;
var SCROLL_DIRECTION_HORIZONTAL = 'horizontal';
var SCROLL_DIRECTION_VERTICAL = 'vertical';
/**
 * Calculates the number of cells to overscan before and after a specified range.
 * This function ensures that overscanning doesn't exceed the available cells.
 */

function defaultOverscanIndicesGetter(_ref) {
  var cellCount = _ref.cellCount,
      overscanCellsCount = _ref.overscanCellsCount,
      scrollDirection = _ref.scrollDirection,
      startIndex = _ref.startIndex,
      stopIndex = _ref.stopIndex;
  // Make sure we render at least 1 cell extra before and after (except near boundaries)
  // This is necessary in order to support keyboard navigation (TAB/SHIFT+TAB) in some cases
  // For more info see issues #625
  overscanCellsCount = Math.max(1, overscanCellsCount);

  if (scrollDirection === SCROLL_DIRECTION_FORWARD) {
    return {
      overscanStartIndex: Math.max(0, startIndex - 1),
      overscanStopIndex: Math.min(cellCount - 1, stopIndex + overscanCellsCount)
    };
  } else {
    return {
      overscanStartIndex: Math.max(0, startIndex - overscanCellsCount),
      overscanStopIndex: Math.min(cellCount - 1, stopIndex + 1)
    };
  }
}



/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Grid/defaultCellRangeRenderer.js":
/*!*************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Grid/defaultCellRangeRenderer.js ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ defaultCellRangeRenderer)
/* harmony export */ });
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/Grid/types.js");
/**
 * Default implementation of cellRangeRenderer used by Grid.
 * This renderer supports cell-caching while the user is scrolling.
 */
function defaultCellRangeRenderer(_ref) {
  var cellCache = _ref.cellCache,
      cellRenderer = _ref.cellRenderer,
      columnSizeAndPositionManager = _ref.columnSizeAndPositionManager,
      columnStartIndex = _ref.columnStartIndex,
      columnStopIndex = _ref.columnStopIndex,
      deferredMeasurementCache = _ref.deferredMeasurementCache,
      horizontalOffsetAdjustment = _ref.horizontalOffsetAdjustment,
      isScrolling = _ref.isScrolling,
      isScrollingOptOut = _ref.isScrollingOptOut,
      parent = _ref.parent,
      rowSizeAndPositionManager = _ref.rowSizeAndPositionManager,
      rowStartIndex = _ref.rowStartIndex,
      rowStopIndex = _ref.rowStopIndex,
      styleCache = _ref.styleCache,
      verticalOffsetAdjustment = _ref.verticalOffsetAdjustment,
      visibleColumnIndices = _ref.visibleColumnIndices,
      visibleRowIndices = _ref.visibleRowIndices;
  var renderedCells = []; // Browsers have native size limits for elements (eg Chrome 33M pixels, IE 1.5M pixes).
  // User cannot scroll beyond these size limitations.
  // In order to work around this, ScalingCellSizeAndPositionManager compresses offsets.
  // We should never cache styles for compressed offsets though as this can lead to bugs.
  // See issue #576 for more.

  var areOffsetsAdjusted = columnSizeAndPositionManager.areOffsetsAdjusted() || rowSizeAndPositionManager.areOffsetsAdjusted();
  var canCacheStyle = !isScrolling && !areOffsetsAdjusted;

  for (var rowIndex = rowStartIndex; rowIndex <= rowStopIndex; rowIndex++) {
    var rowDatum = rowSizeAndPositionManager.getSizeAndPositionOfCell(rowIndex);

    for (var columnIndex = columnStartIndex; columnIndex <= columnStopIndex; columnIndex++) {
      var columnDatum = columnSizeAndPositionManager.getSizeAndPositionOfCell(columnIndex);
      var isVisible = columnIndex >= visibleColumnIndices.start && columnIndex <= visibleColumnIndices.stop && rowIndex >= visibleRowIndices.start && rowIndex <= visibleRowIndices.stop;
      var key = "".concat(rowIndex, "-").concat(columnIndex);
      var style = void 0; // Cache style objects so shallow-compare doesn't re-render unnecessarily.

      if (canCacheStyle && styleCache[key]) {
        style = styleCache[key];
      } else {
        // In deferred mode, cells will be initially rendered before we know their size.
        // Don't interfere with CellMeasurer's measurements by setting an invalid size.
        if (deferredMeasurementCache && !deferredMeasurementCache.has(rowIndex, columnIndex)) {
          // Position not-yet-measured cells at top/left 0,0,
          // And give them width/height of 'auto' so they can grow larger than the parent Grid if necessary.
          // Positioning them further to the right/bottom influences their measured size.
          style = {
            height: 'auto',
            left: 0,
            position: 'absolute',
            top: 0,
            width: 'auto'
          };
        } else {
          style = {
            height: rowDatum.size,
            left: columnDatum.offset + horizontalOffsetAdjustment,
            position: 'absolute',
            top: rowDatum.offset + verticalOffsetAdjustment,
            width: columnDatum.size
          };
          styleCache[key] = style;
        }
      }

      var cellRendererParams = {
        columnIndex: columnIndex,
        isScrolling: isScrolling,
        isVisible: isVisible,
        key: key,
        parent: parent,
        rowIndex: rowIndex,
        style: style
      };
      var renderedCell = void 0; // Avoid re-creating cells while scrolling.
      // This can lead to the same cell being created many times and can cause performance issues for "heavy" cells.
      // If a scroll is in progress- cache and reuse cells.
      // This cache will be thrown away once scrolling completes.
      // However if we are scaling scroll positions and sizes, we should also avoid caching.
      // This is because the offset changes slightly as scroll position changes and caching leads to stale values.
      // For more info refer to issue #395
      //
      // If isScrollingOptOut is specified, we always cache cells.
      // For more info refer to issue #1028

      if ((isScrollingOptOut || isScrolling) && !horizontalOffsetAdjustment && !verticalOffsetAdjustment) {
        if (!cellCache[key]) {
          cellCache[key] = cellRenderer(cellRendererParams);
        }

        renderedCell = cellCache[key]; // If the user is no longer scrolling, don't cache cells.
        // This makes dynamic cell content difficult for users and would also lead to a heavier memory footprint.
      } else {
        renderedCell = cellRenderer(cellRendererParams);
      }

      if (renderedCell == null || renderedCell === false) {
        continue;
      }

      if (true) {
        warnAboutMissingStyle(parent, renderedCell);
      }

      renderedCells.push(renderedCell);
    }
  }

  return renderedCells;
}

function warnAboutMissingStyle(parent, renderedCell) {
  if (true) {
    if (renderedCell) {
      // If the direct child is a CellMeasurer, then we should check its child
      // See issue #611
      if (renderedCell.type && renderedCell.type.__internalCellMeasurerFlag) {
        renderedCell = renderedCell.props.children;
      }

      if (renderedCell && renderedCell.props && renderedCell.props.style === undefined && parent.__warnedAboutMissingStyle !== true) {
        parent.__warnedAboutMissingStyle = true;
        console.warn('Rendered cell should include style property for positioning.');
      }
    }
  }
}



/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Grid/defaultOverscanIndicesGetter.js":
/*!*****************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Grid/defaultOverscanIndicesGetter.js ***!
  \*****************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "SCROLL_DIRECTION_BACKWARD": () => (/* binding */ SCROLL_DIRECTION_BACKWARD),
/* harmony export */   "SCROLL_DIRECTION_FORWARD": () => (/* binding */ SCROLL_DIRECTION_FORWARD),
/* harmony export */   "SCROLL_DIRECTION_HORIZONTAL": () => (/* binding */ SCROLL_DIRECTION_HORIZONTAL),
/* harmony export */   "SCROLL_DIRECTION_VERTICAL": () => (/* binding */ SCROLL_DIRECTION_VERTICAL),
/* harmony export */   "default": () => (/* binding */ defaultOverscanIndicesGetter)
/* harmony export */ });
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/Grid/types.js");
var SCROLL_DIRECTION_BACKWARD = -1;
var SCROLL_DIRECTION_FORWARD = 1;
var SCROLL_DIRECTION_HORIZONTAL = 'horizontal';
var SCROLL_DIRECTION_VERTICAL = 'vertical';
/**
 * Calculates the number of cells to overscan before and after a specified range.
 * This function ensures that overscanning doesn't exceed the available cells.
 */

function defaultOverscanIndicesGetter(_ref) {
  var cellCount = _ref.cellCount,
      overscanCellsCount = _ref.overscanCellsCount,
      scrollDirection = _ref.scrollDirection,
      startIndex = _ref.startIndex,
      stopIndex = _ref.stopIndex;

  if (scrollDirection === SCROLL_DIRECTION_FORWARD) {
    return {
      overscanStartIndex: Math.max(0, startIndex),
      overscanStopIndex: Math.min(cellCount - 1, stopIndex + overscanCellsCount)
    };
  } else {
    return {
      overscanStartIndex: Math.max(0, startIndex - overscanCellsCount),
      overscanStopIndex: Math.min(cellCount - 1, stopIndex)
    };
  }
}



/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Grid/index.js":
/*!******************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Grid/index.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Grid": () => (/* reexport safe */ _Grid__WEBPACK_IMPORTED_MODULE_0__["default"]),
/* harmony export */   "accessibilityOverscanIndicesGetter": () => (/* reexport safe */ _accessibilityOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_1__["default"]),
/* harmony export */   "bpfrpt_proptype_Alignment": () => (/* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_4__.bpfrpt_proptype_Alignment),
/* harmony export */   "bpfrpt_proptype_CellPosition": () => (/* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_4__.bpfrpt_proptype_CellPosition),
/* harmony export */   "bpfrpt_proptype_CellRendererParams": () => (/* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_4__.bpfrpt_proptype_CellRendererParams),
/* harmony export */   "bpfrpt_proptype_CellSize": () => (/* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_4__.bpfrpt_proptype_CellSize),
/* harmony export */   "bpfrpt_proptype_NoContentRenderer": () => (/* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_4__.bpfrpt_proptype_NoContentRenderer),
/* harmony export */   "bpfrpt_proptype_OverscanIndicesGetter": () => (/* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_4__.bpfrpt_proptype_OverscanIndicesGetter),
/* harmony export */   "bpfrpt_proptype_RenderedSection": () => (/* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_4__.bpfrpt_proptype_RenderedSection),
/* harmony export */   "bpfrpt_proptype_Scroll": () => (/* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_4__.bpfrpt_proptype_Scroll),
/* harmony export */   "default": () => (/* reexport safe */ _Grid__WEBPACK_IMPORTED_MODULE_0__["default"]),
/* harmony export */   "defaultCellRangeRenderer": () => (/* reexport safe */ _defaultCellRangeRenderer__WEBPACK_IMPORTED_MODULE_2__["default"]),
/* harmony export */   "defaultOverscanIndicesGetter": () => (/* reexport safe */ _defaultOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_3__["default"])
/* harmony export */ });
/* harmony import */ var _Grid__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./Grid */ "../../node_modules/react-virtualized/dist/es/Grid/Grid.js");
/* harmony import */ var _accessibilityOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./accessibilityOverscanIndicesGetter */ "../../node_modules/react-virtualized/dist/es/Grid/accessibilityOverscanIndicesGetter.js");
/* harmony import */ var _defaultCellRangeRenderer__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./defaultCellRangeRenderer */ "../../node_modules/react-virtualized/dist/es/Grid/defaultCellRangeRenderer.js");
/* harmony import */ var _defaultOverscanIndicesGetter__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./defaultOverscanIndicesGetter */ "../../node_modules/react-virtualized/dist/es/Grid/defaultOverscanIndicesGetter.js");
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/Grid/types.js");






















/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Grid/types.js":
/*!******************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Grid/types.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "bpfrpt_proptype_Alignment": () => (/* binding */ bpfrpt_proptype_Alignment),
/* harmony export */   "bpfrpt_proptype_CellCache": () => (/* binding */ bpfrpt_proptype_CellCache),
/* harmony export */   "bpfrpt_proptype_CellPosition": () => (/* binding */ bpfrpt_proptype_CellPosition),
/* harmony export */   "bpfrpt_proptype_CellRangeRenderer": () => (/* binding */ bpfrpt_proptype_CellRangeRenderer),
/* harmony export */   "bpfrpt_proptype_CellRangeRendererParams": () => (/* binding */ bpfrpt_proptype_CellRangeRendererParams),
/* harmony export */   "bpfrpt_proptype_CellRenderer": () => (/* binding */ bpfrpt_proptype_CellRenderer),
/* harmony export */   "bpfrpt_proptype_CellRendererParams": () => (/* binding */ bpfrpt_proptype_CellRendererParams),
/* harmony export */   "bpfrpt_proptype_CellSize": () => (/* binding */ bpfrpt_proptype_CellSize),
/* harmony export */   "bpfrpt_proptype_CellSizeGetter": () => (/* binding */ bpfrpt_proptype_CellSizeGetter),
/* harmony export */   "bpfrpt_proptype_NoContentRenderer": () => (/* binding */ bpfrpt_proptype_NoContentRenderer),
/* harmony export */   "bpfrpt_proptype_OverscanIndices": () => (/* binding */ bpfrpt_proptype_OverscanIndices),
/* harmony export */   "bpfrpt_proptype_OverscanIndicesGetter": () => (/* binding */ bpfrpt_proptype_OverscanIndicesGetter),
/* harmony export */   "bpfrpt_proptype_OverscanIndicesGetterParams": () => (/* binding */ bpfrpt_proptype_OverscanIndicesGetterParams),
/* harmony export */   "bpfrpt_proptype_RenderedSection": () => (/* binding */ bpfrpt_proptype_RenderedSection),
/* harmony export */   "bpfrpt_proptype_Scroll": () => (/* binding */ bpfrpt_proptype_Scroll),
/* harmony export */   "bpfrpt_proptype_ScrollbarPresenceChange": () => (/* binding */ bpfrpt_proptype_ScrollbarPresenceChange),
/* harmony export */   "bpfrpt_proptype_StyleCache": () => (/* binding */ bpfrpt_proptype_StyleCache),
/* harmony export */   "bpfrpt_proptype_VisibleCellRange": () => (/* binding */ bpfrpt_proptype_VisibleCellRange)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _utils_ScalingCellSizeAndPositionManager__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./utils/ScalingCellSizeAndPositionManager */ "../../node_modules/react-virtualized/dist/es/Grid/utils/ScalingCellSizeAndPositionManager.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_2__);


var bpfrpt_proptype_CellPosition =  false ? 0 : {
  "columnIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "rowIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired)
};
var bpfrpt_proptype_CellRendererParams =  false ? 0 : {
  "columnIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "isScrolling": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().bool.isRequired),
  "isVisible": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().bool.isRequired),
  "key": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().string.isRequired),
  "parent": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().object.isRequired),
  "rowIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "style": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().object.isRequired)
};
var bpfrpt_proptype_CellRenderer =  false ? 0 : (prop_types__WEBPACK_IMPORTED_MODULE_2___default().func);
var bpfrpt_proptype_CellCache =  false ? 0 : prop_types__WEBPACK_IMPORTED_MODULE_2___default().objectOf((prop_types__WEBPACK_IMPORTED_MODULE_2___default().node.isRequired));
var bpfrpt_proptype_StyleCache =  false ? 0 : prop_types__WEBPACK_IMPORTED_MODULE_2___default().objectOf((prop_types__WEBPACK_IMPORTED_MODULE_2___default().object.isRequired));
var bpfrpt_proptype_CellRangeRendererParams =  false ? 0 : {
  "cellCache": prop_types__WEBPACK_IMPORTED_MODULE_2___default().objectOf((prop_types__WEBPACK_IMPORTED_MODULE_2___default().node.isRequired)).isRequired,
  "cellRenderer": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().func.isRequired),
  "columnSizeAndPositionManager": function columnSizeAndPositionManager() {
    return (typeof _utils_ScalingCellSizeAndPositionManager__WEBPACK_IMPORTED_MODULE_1__["default"] === "function" ? prop_types__WEBPACK_IMPORTED_MODULE_2___default().instanceOf(_utils_ScalingCellSizeAndPositionManager__WEBPACK_IMPORTED_MODULE_1__["default"]).isRequired : (prop_types__WEBPACK_IMPORTED_MODULE_2___default().any.isRequired)).apply(this, arguments);
  },
  "columnStartIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "columnStopIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "deferredMeasurementCache": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().object),
  "horizontalOffsetAdjustment": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "isScrolling": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().bool.isRequired),
  "isScrollingOptOut": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().bool.isRequired),
  "parent": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().object.isRequired),
  "rowSizeAndPositionManager": function rowSizeAndPositionManager() {
    return (typeof _utils_ScalingCellSizeAndPositionManager__WEBPACK_IMPORTED_MODULE_1__["default"] === "function" ? prop_types__WEBPACK_IMPORTED_MODULE_2___default().instanceOf(_utils_ScalingCellSizeAndPositionManager__WEBPACK_IMPORTED_MODULE_1__["default"]).isRequired : (prop_types__WEBPACK_IMPORTED_MODULE_2___default().any.isRequired)).apply(this, arguments);
  },
  "rowStartIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "rowStopIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "scrollLeft": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "scrollTop": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "styleCache": prop_types__WEBPACK_IMPORTED_MODULE_2___default().objectOf((prop_types__WEBPACK_IMPORTED_MODULE_2___default().object.isRequired)).isRequired,
  "verticalOffsetAdjustment": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "visibleColumnIndices": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().object.isRequired),
  "visibleRowIndices": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().object.isRequired)
};
var bpfrpt_proptype_CellRangeRenderer =  false ? 0 : (prop_types__WEBPACK_IMPORTED_MODULE_2___default().func);
var bpfrpt_proptype_CellSizeGetter =  false ? 0 : (prop_types__WEBPACK_IMPORTED_MODULE_2___default().func);
var bpfrpt_proptype_CellSize =  false ? 0 : prop_types__WEBPACK_IMPORTED_MODULE_2___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_2___default().func), (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number)]);
var bpfrpt_proptype_NoContentRenderer =  false ? 0 : (prop_types__WEBPACK_IMPORTED_MODULE_2___default().func);
var bpfrpt_proptype_Scroll =  false ? 0 : {
  "clientHeight": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "clientWidth": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "scrollHeight": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "scrollLeft": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "scrollTop": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "scrollWidth": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired)
};
var bpfrpt_proptype_ScrollbarPresenceChange =  false ? 0 : {
  "horizontal": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().bool.isRequired),
  "vertical": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().bool.isRequired),
  "size": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired)
};
var bpfrpt_proptype_RenderedSection =  false ? 0 : {
  "columnOverscanStartIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "columnOverscanStopIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "columnStartIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "columnStopIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "rowOverscanStartIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "rowOverscanStopIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "rowStartIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "rowStopIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired)
};
var bpfrpt_proptype_OverscanIndicesGetterParams =  false ? 0 : {
  // One of SCROLL_DIRECTION_HORIZONTAL or SCROLL_DIRECTION_VERTICAL
  "direction": prop_types__WEBPACK_IMPORTED_MODULE_2___default().oneOf(["horizontal", "vertical"]).isRequired,
  // One of SCROLL_DIRECTION_BACKWARD or SCROLL_DIRECTION_FORWARD
  "scrollDirection": prop_types__WEBPACK_IMPORTED_MODULE_2___default().oneOf([-1, 1]).isRequired,
  // Number of rows or columns in the current axis
  "cellCount": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  // Maximum number of cells to over-render in either direction
  "overscanCellsCount": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  // Begin of range of visible cells
  "startIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  // End of range of visible cells
  "stopIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired)
};
var bpfrpt_proptype_OverscanIndices =  false ? 0 : {
  "overscanStartIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired),
  "overscanStopIndex": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number.isRequired)
};
var bpfrpt_proptype_OverscanIndicesGetter =  false ? 0 : (prop_types__WEBPACK_IMPORTED_MODULE_2___default().func);
var bpfrpt_proptype_Alignment =  false ? 0 : prop_types__WEBPACK_IMPORTED_MODULE_2___default().oneOf(["auto", "end", "start", "center"]);
var bpfrpt_proptype_VisibleCellRange =  false ? 0 : {
  "start": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number),
  "stop": (prop_types__WEBPACK_IMPORTED_MODULE_2___default().number)
};




















/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Grid/utils/CellSizeAndPositionManager.js":
/*!*********************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Grid/utils/CellSizeAndPositionManager.js ***!
  \*********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ CellSizeAndPositionManager)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../types */ "../../node_modules/react-virtualized/dist/es/Grid/types.js");




/**
 * Just-in-time calculates and caches size and position information for a collection of cells.
 */
var CellSizeAndPositionManager =
/*#__PURE__*/
function () {
  // Cache of size and position data for cells, mapped by cell index.
  // Note that invalid values may exist in this map so only rely on cells up to this._lastMeasuredIndex
  // Measurements for cells up to this index can be trusted; cells afterward should be estimated.
  // Used in deferred mode to track which cells have been queued for measurement.
  function CellSizeAndPositionManager(_ref) {
    var cellCount = _ref.cellCount,
        cellSizeGetter = _ref.cellSizeGetter,
        estimatedCellSize = _ref.estimatedCellSize;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, CellSizeAndPositionManager);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_cellSizeAndPositionData", {});

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_lastMeasuredIndex", -1);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_lastBatchedIndex", -1);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_cellCount", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_cellSizeGetter", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_estimatedCellSize", void 0);

    this._cellSizeGetter = cellSizeGetter;
    this._cellCount = cellCount;
    this._estimatedCellSize = estimatedCellSize;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(CellSizeAndPositionManager, [{
    key: "areOffsetsAdjusted",
    value: function areOffsetsAdjusted() {
      return false;
    }
  }, {
    key: "configure",
    value: function configure(_ref2) {
      var cellCount = _ref2.cellCount,
          estimatedCellSize = _ref2.estimatedCellSize,
          cellSizeGetter = _ref2.cellSizeGetter;
      this._cellCount = cellCount;
      this._estimatedCellSize = estimatedCellSize;
      this._cellSizeGetter = cellSizeGetter;
    }
  }, {
    key: "getCellCount",
    value: function getCellCount() {
      return this._cellCount;
    }
  }, {
    key: "getEstimatedCellSize",
    value: function getEstimatedCellSize() {
      return this._estimatedCellSize;
    }
  }, {
    key: "getLastMeasuredIndex",
    value: function getLastMeasuredIndex() {
      return this._lastMeasuredIndex;
    }
  }, {
    key: "getOffsetAdjustment",
    value: function getOffsetAdjustment() {
      return 0;
    }
    /**
     * This method returns the size and position for the cell at the specified index.
     * It just-in-time calculates (or used cached values) for cells leading up to the index.
     */

  }, {
    key: "getSizeAndPositionOfCell",
    value: function getSizeAndPositionOfCell(index) {
      if (index < 0 || index >= this._cellCount) {
        throw Error("Requested index ".concat(index, " is outside of range 0..").concat(this._cellCount));
      }

      if (index > this._lastMeasuredIndex) {
        var lastMeasuredCellSizeAndPosition = this.getSizeAndPositionOfLastMeasuredCell();
        var offset = lastMeasuredCellSizeAndPosition.offset + lastMeasuredCellSizeAndPosition.size;

        for (var i = this._lastMeasuredIndex + 1; i <= index; i++) {
          var size = this._cellSizeGetter({
            index: i
          }); // undefined or NaN probably means a logic error in the size getter.
          // null means we're using CellMeasurer and haven't yet measured a given index.


          if (size === undefined || isNaN(size)) {
            throw Error("Invalid size returned for cell ".concat(i, " of value ").concat(size));
          } else if (size === null) {
            this._cellSizeAndPositionData[i] = {
              offset: offset,
              size: 0
            };
            this._lastBatchedIndex = index;
          } else {
            this._cellSizeAndPositionData[i] = {
              offset: offset,
              size: size
            };
            offset += size;
            this._lastMeasuredIndex = index;
          }
        }
      }

      return this._cellSizeAndPositionData[index];
    }
  }, {
    key: "getSizeAndPositionOfLastMeasuredCell",
    value: function getSizeAndPositionOfLastMeasuredCell() {
      return this._lastMeasuredIndex >= 0 ? this._cellSizeAndPositionData[this._lastMeasuredIndex] : {
        offset: 0,
        size: 0
      };
    }
    /**
     * Total size of all cells being measured.
     * This value will be completely estimated initially.
     * As cells are measured, the estimate will be updated.
     */

  }, {
    key: "getTotalSize",
    value: function getTotalSize() {
      var lastMeasuredCellSizeAndPosition = this.getSizeAndPositionOfLastMeasuredCell();
      var totalSizeOfMeasuredCells = lastMeasuredCellSizeAndPosition.offset + lastMeasuredCellSizeAndPosition.size;
      var numUnmeasuredCells = this._cellCount - this._lastMeasuredIndex - 1;
      var totalSizeOfUnmeasuredCells = numUnmeasuredCells * this._estimatedCellSize;
      return totalSizeOfMeasuredCells + totalSizeOfUnmeasuredCells;
    }
    /**
     * Determines a new offset that ensures a certain cell is visible, given the current offset.
     * If the cell is already visible then the current offset will be returned.
     * If the current offset is too great or small, it will be adjusted just enough to ensure the specified index is visible.
     *
     * @param align Desired alignment within container; one of "auto" (default), "start", or "end"
     * @param containerSize Size (width or height) of the container viewport
     * @param currentOffset Container's current (x or y) offset
     * @param totalSize Total size (width or height) of all cells
     * @return Offset to use to ensure the specified cell is visible
     */

  }, {
    key: "getUpdatedOffsetForIndex",
    value: function getUpdatedOffsetForIndex(_ref3) {
      var _ref3$align = _ref3.align,
          align = _ref3$align === void 0 ? 'auto' : _ref3$align,
          containerSize = _ref3.containerSize,
          currentOffset = _ref3.currentOffset,
          targetIndex = _ref3.targetIndex;

      if (containerSize <= 0) {
        return 0;
      }

      var datum = this.getSizeAndPositionOfCell(targetIndex);
      var maxOffset = datum.offset;
      var minOffset = maxOffset - containerSize + datum.size;
      var idealOffset;

      switch (align) {
        case 'start':
          idealOffset = maxOffset;
          break;

        case 'end':
          idealOffset = minOffset;
          break;

        case 'center':
          idealOffset = maxOffset - (containerSize - datum.size) / 2;
          break;

        default:
          idealOffset = Math.max(minOffset, Math.min(maxOffset, currentOffset));
          break;
      }

      var totalSize = this.getTotalSize();
      return Math.max(0, Math.min(totalSize - containerSize, idealOffset));
    }
  }, {
    key: "getVisibleCellRange",
    value: function getVisibleCellRange(params) {
      var containerSize = params.containerSize,
          offset = params.offset;
      var totalSize = this.getTotalSize();

      if (totalSize === 0) {
        return {};
      }

      var maxOffset = offset + containerSize;

      var start = this._findNearestCell(offset);

      var datum = this.getSizeAndPositionOfCell(start);
      offset = datum.offset + datum.size;
      var stop = start;

      while (offset < maxOffset && stop < this._cellCount - 1) {
        stop++;
        offset += this.getSizeAndPositionOfCell(stop).size;
      }

      return {
        start: start,
        stop: stop
      };
    }
    /**
     * Clear all cached values for cells after the specified index.
     * This method should be called for any cell that has changed its size.
     * It will not immediately perform any calculations; they'll be performed the next time getSizeAndPositionOfCell() is called.
     */

  }, {
    key: "resetCell",
    value: function resetCell(index) {
      this._lastMeasuredIndex = Math.min(this._lastMeasuredIndex, index - 1);
    }
  }, {
    key: "_binarySearch",
    value: function _binarySearch(high, low, offset) {
      while (low <= high) {
        var middle = low + Math.floor((high - low) / 2);
        var currentOffset = this.getSizeAndPositionOfCell(middle).offset;

        if (currentOffset === offset) {
          return middle;
        } else if (currentOffset < offset) {
          low = middle + 1;
        } else if (currentOffset > offset) {
          high = middle - 1;
        }
      }

      if (low > 0) {
        return low - 1;
      } else {
        return 0;
      }
    }
  }, {
    key: "_exponentialSearch",
    value: function _exponentialSearch(index, offset) {
      var interval = 1;

      while (index < this._cellCount && this.getSizeAndPositionOfCell(index).offset < offset) {
        index += interval;
        interval *= 2;
      }

      return this._binarySearch(Math.min(index, this._cellCount - 1), Math.floor(index / 2), offset);
    }
    /**
     * Searches for the cell (index) nearest the specified offset.
     *
     * If no exact match is found the next lowest cell index will be returned.
     * This allows partially visible cells (with offsets just before/above the fold) to be visible.
     */

  }, {
    key: "_findNearestCell",
    value: function _findNearestCell(offset) {
      if (isNaN(offset)) {
        throw Error("Invalid offset ".concat(offset, " specified"));
      } // Our search algorithms find the nearest match at or below the specified offset.
      // So make sure the offset is at least 0 or no match will be found.


      offset = Math.max(0, offset);
      var lastMeasuredCellSizeAndPosition = this.getSizeAndPositionOfLastMeasuredCell();
      var lastMeasuredIndex = Math.max(0, this._lastMeasuredIndex);

      if (lastMeasuredCellSizeAndPosition.offset >= offset) {
        // If we've already measured cells within this range just use a binary search as it's faster.
        return this._binarySearch(lastMeasuredIndex, 0, offset);
      } else {
        // If we haven't yet measured this high, fallback to an exponential search with an inner binary search.
        // The exponential search avoids pre-computing sizes for the full set of cells as a binary search would.
        // The overall complexity for this approach is O(log n).
        return this._exponentialSearch(lastMeasuredIndex, offset);
      }
    }
  }]);

  return CellSizeAndPositionManager;
}();






/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Grid/utils/ScalingCellSizeAndPositionManager.js":
/*!****************************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Grid/utils/ScalingCellSizeAndPositionManager.js ***!
  \****************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ ScalingCellSizeAndPositionManager)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _CellSizeAndPositionManager__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./CellSizeAndPositionManager */ "../../node_modules/react-virtualized/dist/es/Grid/utils/CellSizeAndPositionManager.js");
/* harmony import */ var _maxElementSize_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./maxElementSize.js */ "../../node_modules/react-virtualized/dist/es/Grid/utils/maxElementSize.js");
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../types */ "../../node_modules/react-virtualized/dist/es/Grid/types.js");







/**
 * Extends CellSizeAndPositionManager and adds scaling behavior for lists that are too large to fit within a browser's native limits.
 */
var ScalingCellSizeAndPositionManager =
/*#__PURE__*/
function () {
  function ScalingCellSizeAndPositionManager(_ref) {
    var _ref$maxScrollSize = _ref.maxScrollSize,
        maxScrollSize = _ref$maxScrollSize === void 0 ? (0,_maxElementSize_js__WEBPACK_IMPORTED_MODULE_5__.getMaxElementSize)() : _ref$maxScrollSize,
        params = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref, ["maxScrollSize"]);

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_1__["default"])(this, ScalingCellSizeAndPositionManager);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_3__["default"])(this, "_cellSizeAndPositionManager", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_3__["default"])(this, "_maxScrollSize", void 0);

    // Favor composition over inheritance to simplify IE10 support
    this._cellSizeAndPositionManager = new _CellSizeAndPositionManager__WEBPACK_IMPORTED_MODULE_4__["default"](params);
    this._maxScrollSize = maxScrollSize;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(ScalingCellSizeAndPositionManager, [{
    key: "areOffsetsAdjusted",
    value: function areOffsetsAdjusted() {
      return this._cellSizeAndPositionManager.getTotalSize() > this._maxScrollSize;
    }
  }, {
    key: "configure",
    value: function configure(params) {
      this._cellSizeAndPositionManager.configure(params);
    }
  }, {
    key: "getCellCount",
    value: function getCellCount() {
      return this._cellSizeAndPositionManager.getCellCount();
    }
  }, {
    key: "getEstimatedCellSize",
    value: function getEstimatedCellSize() {
      return this._cellSizeAndPositionManager.getEstimatedCellSize();
    }
  }, {
    key: "getLastMeasuredIndex",
    value: function getLastMeasuredIndex() {
      return this._cellSizeAndPositionManager.getLastMeasuredIndex();
    }
    /**
     * Number of pixels a cell at the given position (offset) should be shifted in order to fit within the scaled container.
     * The offset passed to this function is scaled (safe) as well.
     */

  }, {
    key: "getOffsetAdjustment",
    value: function getOffsetAdjustment(_ref2) {
      var containerSize = _ref2.containerSize,
          offset = _ref2.offset;

      var totalSize = this._cellSizeAndPositionManager.getTotalSize();

      var safeTotalSize = this.getTotalSize();

      var offsetPercentage = this._getOffsetPercentage({
        containerSize: containerSize,
        offset: offset,
        totalSize: safeTotalSize
      });

      return Math.round(offsetPercentage * (safeTotalSize - totalSize));
    }
  }, {
    key: "getSizeAndPositionOfCell",
    value: function getSizeAndPositionOfCell(index) {
      return this._cellSizeAndPositionManager.getSizeAndPositionOfCell(index);
    }
  }, {
    key: "getSizeAndPositionOfLastMeasuredCell",
    value: function getSizeAndPositionOfLastMeasuredCell() {
      return this._cellSizeAndPositionManager.getSizeAndPositionOfLastMeasuredCell();
    }
    /** See CellSizeAndPositionManager#getTotalSize */

  }, {
    key: "getTotalSize",
    value: function getTotalSize() {
      return Math.min(this._maxScrollSize, this._cellSizeAndPositionManager.getTotalSize());
    }
    /** See CellSizeAndPositionManager#getUpdatedOffsetForIndex */

  }, {
    key: "getUpdatedOffsetForIndex",
    value: function getUpdatedOffsetForIndex(_ref3) {
      var _ref3$align = _ref3.align,
          align = _ref3$align === void 0 ? 'auto' : _ref3$align,
          containerSize = _ref3.containerSize,
          currentOffset = _ref3.currentOffset,
          targetIndex = _ref3.targetIndex;
      currentOffset = this._safeOffsetToOffset({
        containerSize: containerSize,
        offset: currentOffset
      });

      var offset = this._cellSizeAndPositionManager.getUpdatedOffsetForIndex({
        align: align,
        containerSize: containerSize,
        currentOffset: currentOffset,
        targetIndex: targetIndex
      });

      return this._offsetToSafeOffset({
        containerSize: containerSize,
        offset: offset
      });
    }
    /** See CellSizeAndPositionManager#getVisibleCellRange */

  }, {
    key: "getVisibleCellRange",
    value: function getVisibleCellRange(_ref4) {
      var containerSize = _ref4.containerSize,
          offset = _ref4.offset;
      offset = this._safeOffsetToOffset({
        containerSize: containerSize,
        offset: offset
      });
      return this._cellSizeAndPositionManager.getVisibleCellRange({
        containerSize: containerSize,
        offset: offset
      });
    }
  }, {
    key: "resetCell",
    value: function resetCell(index) {
      this._cellSizeAndPositionManager.resetCell(index);
    }
  }, {
    key: "_getOffsetPercentage",
    value: function _getOffsetPercentage(_ref5) {
      var containerSize = _ref5.containerSize,
          offset = _ref5.offset,
          totalSize = _ref5.totalSize;
      return totalSize <= containerSize ? 0 : offset / (totalSize - containerSize);
    }
  }, {
    key: "_offsetToSafeOffset",
    value: function _offsetToSafeOffset(_ref6) {
      var containerSize = _ref6.containerSize,
          offset = _ref6.offset;

      var totalSize = this._cellSizeAndPositionManager.getTotalSize();

      var safeTotalSize = this.getTotalSize();

      if (totalSize === safeTotalSize) {
        return offset;
      } else {
        var offsetPercentage = this._getOffsetPercentage({
          containerSize: containerSize,
          offset: offset,
          totalSize: totalSize
        });

        return Math.round(offsetPercentage * (safeTotalSize - containerSize));
      }
    }
  }, {
    key: "_safeOffsetToOffset",
    value: function _safeOffsetToOffset(_ref7) {
      var containerSize = _ref7.containerSize,
          offset = _ref7.offset;

      var totalSize = this._cellSizeAndPositionManager.getTotalSize();

      var safeTotalSize = this.getTotalSize();

      if (totalSize === safeTotalSize) {
        return offset;
      } else {
        var offsetPercentage = this._getOffsetPercentage({
          containerSize: containerSize,
          offset: offset,
          totalSize: safeTotalSize
        });

        return Math.round(offsetPercentage * (totalSize - containerSize));
      }
    }
  }]);

  return ScalingCellSizeAndPositionManager;
}();






/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Grid/utils/calculateSizeAndPositionDataAndUpdateScrollOffset.js":
/*!********************************************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Grid/utils/calculateSizeAndPositionDataAndUpdateScrollOffset.js ***!
  \********************************************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ calculateSizeAndPositionDataAndUpdateScrollOffset)
/* harmony export */ });
/**
 * Helper method that determines when to recalculate row or column metadata.
 */
function calculateSizeAndPositionDataAndUpdateScrollOffset(_ref) {
  var cellCount = _ref.cellCount,
      cellSize = _ref.cellSize,
      computeMetadataCallback = _ref.computeMetadataCallback,
      computeMetadataCallbackProps = _ref.computeMetadataCallbackProps,
      nextCellsCount = _ref.nextCellsCount,
      nextCellSize = _ref.nextCellSize,
      nextScrollToIndex = _ref.nextScrollToIndex,
      scrollToIndex = _ref.scrollToIndex,
      updateScrollOffsetForScrollToIndex = _ref.updateScrollOffsetForScrollToIndex;

  // Don't compare cell sizes if they are functions because inline functions would cause infinite loops.
  // In that event users should use the manual recompute methods to inform of changes.
  if (cellCount !== nextCellsCount || (typeof cellSize === 'number' || typeof nextCellSize === 'number') && cellSize !== nextCellSize) {
    computeMetadataCallback(computeMetadataCallbackProps); // Updated cell metadata may have hidden the previous scrolled-to item.
    // In this case we should also update the scrollTop to ensure it stays visible.

    if (scrollToIndex >= 0 && scrollToIndex === nextScrollToIndex) {
      updateScrollOffsetForScrollToIndex();
    }
  }
}

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Grid/utils/maxElementSize.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Grid/utils/maxElementSize.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "getMaxElementSize": () => (/* binding */ getMaxElementSize)
/* harmony export */ });
var DEFAULT_MAX_ELEMENT_SIZE = 1500000;
var CHROME_MAX_ELEMENT_SIZE = 1.67771e7;

var isBrowser = function isBrowser() {
  return typeof window !== 'undefined';
};

var isChrome = function isChrome() {
  return !!window.chrome;
};

var getMaxElementSize = function getMaxElementSize() {
  if (isBrowser()) {
    if (isChrome()) {
      return CHROME_MAX_ELEMENT_SIZE;
    }
  }

  return DEFAULT_MAX_ELEMENT_SIZE;
};

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Grid/utils/updateScrollIndexHelper.js":
/*!******************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Grid/utils/updateScrollIndexHelper.js ***!
  \******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ updateScrollIndexHelper)
/* harmony export */ });
/* harmony import */ var _ScalingCellSizeAndPositionManager_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./ScalingCellSizeAndPositionManager.js */ "../../node_modules/react-virtualized/dist/es/Grid/utils/ScalingCellSizeAndPositionManager.js");
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../types */ "../../node_modules/react-virtualized/dist/es/Grid/types.js");

/**
 * Helper function that determines when to update scroll offsets to ensure that a scroll-to-index remains visible.
 * This function also ensures that the scroll ofset isn't past the last column/row of cells.
 */

function updateScrollIndexHelper(_ref) {
  var cellSize = _ref.cellSize,
      cellSizeAndPositionManager = _ref.cellSizeAndPositionManager,
      previousCellsCount = _ref.previousCellsCount,
      previousCellSize = _ref.previousCellSize,
      previousScrollToAlignment = _ref.previousScrollToAlignment,
      previousScrollToIndex = _ref.previousScrollToIndex,
      previousSize = _ref.previousSize,
      scrollOffset = _ref.scrollOffset,
      scrollToAlignment = _ref.scrollToAlignment,
      scrollToIndex = _ref.scrollToIndex,
      size = _ref.size,
      sizeJustIncreasedFromZero = _ref.sizeJustIncreasedFromZero,
      updateScrollIndexCallback = _ref.updateScrollIndexCallback;
  var cellCount = cellSizeAndPositionManager.getCellCount();
  var hasScrollToIndex = scrollToIndex >= 0 && scrollToIndex < cellCount;
  var sizeHasChanged = size !== previousSize || sizeJustIncreasedFromZero || !previousCellSize || typeof cellSize === 'number' && cellSize !== previousCellSize; // If we have a new scroll target OR if height/row-height has changed,
  // We should ensure that the scroll target is visible.

  if (hasScrollToIndex && (sizeHasChanged || scrollToAlignment !== previousScrollToAlignment || scrollToIndex !== previousScrollToIndex)) {
    updateScrollIndexCallback(scrollToIndex); // If we don't have a selected item but list size or number of children have decreased,
    // Make sure we aren't scrolled too far past the current content.
  } else if (!hasScrollToIndex && cellCount > 0 && (size < previousSize || cellCount < previousCellsCount)) {
    // We need to ensure that the current scroll offset is still within the collection's range.
    // To do this, we don't need to measure everything; CellMeasurer would perform poorly.
    // Just check to make sure we're still okay.
    // Only adjust the scroll position if we've scrolled below the last set of rows.
    if (scrollOffset > cellSizeAndPositionManager.getTotalSize() - size) {
      updateScrollIndexCallback(cellCount - 1);
    }
  }
}



/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/InfiniteLoader/InfiniteLoader.js":
/*!*************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/InfiniteLoader/InfiniteLoader.js ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ InfiniteLoader),
/* harmony export */   "forceUpdateReactVirtualizedComponent": () => (/* binding */ forceUpdateReactVirtualizedComponent),
/* harmony export */   "isRangeVisible": () => (/* binding */ isRangeVisible),
/* harmony export */   "scanForUnloadedRanges": () => (/* binding */ scanForUnloadedRanges)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/toConsumableArray */ "../../node_modules/@babel/runtime/helpers/esm/toConsumableArray.js");
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_10___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_10__);
/* harmony import */ var _utils_createCallbackMemoizer__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../utils/createCallbackMemoizer */ "../../node_modules/react-virtualized/dist/es/utils/createCallbackMemoizer.js");











/**
 * Higher-order component that manages lazy-loading for "infinite" data.
 * This component decorates a virtual component and just-in-time prefetches rows as a user scrolls.
 * It is intended as a convenience component; fork it if you'd like finer-grained control over data-loading.
 */

var InfiniteLoader =
/*#__PURE__*/
function (_React$PureComponent) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_6__["default"])(InfiniteLoader, _React$PureComponent);

  function InfiniteLoader(props, context) {
    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_1__["default"])(this, InfiniteLoader);

    _this = (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_3__["default"])(this, (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_4__["default"])(InfiniteLoader).call(this, props, context));
    _this._loadMoreRowsMemoizer = (0,_utils_createCallbackMemoizer__WEBPACK_IMPORTED_MODULE_9__["default"])();
    _this._onRowsRendered = _this._onRowsRendered.bind((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this));
    _this._registerChild = _this._registerChild.bind((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this));
    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(InfiniteLoader, [{
    key: "resetLoadMoreRowsCache",
    value: function resetLoadMoreRowsCache(autoReload) {
      this._loadMoreRowsMemoizer = (0,_utils_createCallbackMemoizer__WEBPACK_IMPORTED_MODULE_9__["default"])();

      if (autoReload) {
        this._doStuff(this._lastRenderedStartIndex, this._lastRenderedStopIndex);
      }
    }
  }, {
    key: "render",
    value: function render() {
      var children = this.props.children;
      return children({
        onRowsRendered: this._onRowsRendered,
        registerChild: this._registerChild
      });
    }
  }, {
    key: "_loadUnloadedRanges",
    value: function _loadUnloadedRanges(unloadedRanges) {
      var _this2 = this;

      var loadMoreRows = this.props.loadMoreRows;
      unloadedRanges.forEach(function (unloadedRange) {
        var promise = loadMoreRows(unloadedRange);

        if (promise) {
          promise.then(function () {
            // Refresh the visible rows if any of them have just been loaded.
            // Otherwise they will remain in their unloaded visual state.
            if (isRangeVisible({
              lastRenderedStartIndex: _this2._lastRenderedStartIndex,
              lastRenderedStopIndex: _this2._lastRenderedStopIndex,
              startIndex: unloadedRange.startIndex,
              stopIndex: unloadedRange.stopIndex
            })) {
              if (_this2._registeredChild) {
                forceUpdateReactVirtualizedComponent(_this2._registeredChild, _this2._lastRenderedStartIndex);
              }
            }
          });
        }
      });
    }
  }, {
    key: "_onRowsRendered",
    value: function _onRowsRendered(_ref) {
      var startIndex = _ref.startIndex,
          stopIndex = _ref.stopIndex;
      this._lastRenderedStartIndex = startIndex;
      this._lastRenderedStopIndex = stopIndex;

      this._doStuff(startIndex, stopIndex);
    }
  }, {
    key: "_doStuff",
    value: function _doStuff(startIndex, stopIndex) {
      var _ref2,
          _this3 = this;

      var _this$props = this.props,
          isRowLoaded = _this$props.isRowLoaded,
          minimumBatchSize = _this$props.minimumBatchSize,
          rowCount = _this$props.rowCount,
          threshold = _this$props.threshold;
      var unloadedRanges = scanForUnloadedRanges({
        isRowLoaded: isRowLoaded,
        minimumBatchSize: minimumBatchSize,
        rowCount: rowCount,
        startIndex: Math.max(0, startIndex - threshold),
        stopIndex: Math.min(rowCount - 1, stopIndex + threshold)
      }); // For memoize comparison

      var squashedUnloadedRanges = (_ref2 = []).concat.apply(_ref2, (0,_babel_runtime_helpers_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__["default"])(unloadedRanges.map(function (_ref3) {
        var startIndex = _ref3.startIndex,
            stopIndex = _ref3.stopIndex;
        return [startIndex, stopIndex];
      })));

      this._loadMoreRowsMemoizer({
        callback: function callback() {
          _this3._loadUnloadedRanges(unloadedRanges);
        },
        indices: {
          squashedUnloadedRanges: squashedUnloadedRanges
        }
      });
    }
  }, {
    key: "_registerChild",
    value: function _registerChild(registeredChild) {
      this._registeredChild = registeredChild;
    }
  }]);

  return InfiniteLoader;
}(react__WEBPACK_IMPORTED_MODULE_8__.PureComponent);
/**
 * Determines if the specified start/stop range is visible based on the most recently rendered range.
 */


(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(InfiniteLoader, "defaultProps", {
  minimumBatchSize: 10,
  rowCount: 0,
  threshold: 15
});


InfiniteLoader.propTypes =  true ? {
  /**
   * Function responsible for rendering a virtualized component.
   * This function should implement the following signature:
   * ({ onRowsRendered, registerChild }) => PropTypes.element
   *
   * The specified :onRowsRendered function should be passed through to the child's :onRowsRendered property.
   * The :registerChild callback should be set as the virtualized component's :ref.
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().func.isRequired),

  /**
   * Function responsible for tracking the loaded state of each row.
   * It should implement the following signature: ({ index: number }): boolean
   */
  isRowLoaded: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().func.isRequired),

  /**
   * Callback to be invoked when more rows must be loaded.
   * It should implement the following signature: ({ startIndex, stopIndex }): Promise
   * The returned Promise should be resolved once row data has finished loading.
   * It will be used to determine when to refresh the list with the newly-loaded data.
   * This callback may be called multiple times in reaction to a single scroll event.
   */
  loadMoreRows: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().func.isRequired),

  /**
   * Minimum number of rows to be loaded at a time.
   * This property can be used to batch requests to reduce HTTP requests.
   */
  minimumBatchSize: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().number.isRequired),

  /**
   * Number of rows in list; can be arbitrary high number if actual number is unknown.
   */
  rowCount: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().number.isRequired),

  /**
   * Threshold at which to pre-fetch data.
   * A threshold X means that data will start loading when a user scrolls within X rows.
   * This value defaults to 15.
   */
  threshold: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().number.isRequired)
} : 0;
function isRangeVisible(_ref4) {
  var lastRenderedStartIndex = _ref4.lastRenderedStartIndex,
      lastRenderedStopIndex = _ref4.lastRenderedStopIndex,
      startIndex = _ref4.startIndex,
      stopIndex = _ref4.stopIndex;
  return !(startIndex > lastRenderedStopIndex || stopIndex < lastRenderedStartIndex);
}
/**
 * Returns all of the ranges within a larger range that contain unloaded rows.
 */

function scanForUnloadedRanges(_ref5) {
  var isRowLoaded = _ref5.isRowLoaded,
      minimumBatchSize = _ref5.minimumBatchSize,
      rowCount = _ref5.rowCount,
      startIndex = _ref5.startIndex,
      stopIndex = _ref5.stopIndex;
  var unloadedRanges = [];
  var rangeStartIndex = null;
  var rangeStopIndex = null;

  for (var index = startIndex; index <= stopIndex; index++) {
    var loaded = isRowLoaded({
      index: index
    });

    if (!loaded) {
      rangeStopIndex = index;

      if (rangeStartIndex === null) {
        rangeStartIndex = index;
      }
    } else if (rangeStopIndex !== null) {
      unloadedRanges.push({
        startIndex: rangeStartIndex,
        stopIndex: rangeStopIndex
      });
      rangeStartIndex = rangeStopIndex = null;
    }
  } // If :rangeStopIndex is not null it means we haven't ran out of unloaded rows.
  // Scan forward to try filling our :minimumBatchSize.


  if (rangeStopIndex !== null) {
    var potentialStopIndex = Math.min(Math.max(rangeStopIndex, rangeStartIndex + minimumBatchSize - 1), rowCount - 1);

    for (var _index = rangeStopIndex + 1; _index <= potentialStopIndex; _index++) {
      if (!isRowLoaded({
        index: _index
      })) {
        rangeStopIndex = _index;
      } else {
        break;
      }
    }

    unloadedRanges.push({
      startIndex: rangeStartIndex,
      stopIndex: rangeStopIndex
    });
  } // Check to see if our first range ended prematurely.
  // In this case we should scan backwards to try filling our :minimumBatchSize.


  if (unloadedRanges.length) {
    var firstUnloadedRange = unloadedRanges[0];

    while (firstUnloadedRange.stopIndex - firstUnloadedRange.startIndex + 1 < minimumBatchSize && firstUnloadedRange.startIndex > 0) {
      var _index2 = firstUnloadedRange.startIndex - 1;

      if (!isRowLoaded({
        index: _index2
      })) {
        firstUnloadedRange.startIndex = _index2;
      } else {
        break;
      }
    }
  }

  return unloadedRanges;
}
/**
 * Since RV components use shallowCompare we need to force a render (even though props haven't changed).
 * However InfiniteLoader may wrap a Grid or it may wrap a Table or List.
 * In the first case the built-in React forceUpdate() method is sufficient to force a re-render,
 * But in the latter cases we need to use the RV-specific forceUpdateGrid() method.
 * Else the inner Grid will not be re-rendered and visuals may be stale.
 *
 * Additionally, while a Grid is scrolling the cells can be cached,
 * So it's important to invalidate that cache by recalculating sizes
 * before forcing a rerender.
 */

function forceUpdateReactVirtualizedComponent(component) {
  var currentIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  var recomputeSize = typeof component.recomputeGridSize === 'function' ? component.recomputeGridSize : component.recomputeRowHeights;

  if (recomputeSize) {
    recomputeSize.call(component, currentIndex);
  } else {
    component.forceUpdate();
  }
}

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/InfiniteLoader/index.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/InfiniteLoader/index.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "InfiniteLoader": () => (/* reexport safe */ _InfiniteLoader__WEBPACK_IMPORTED_MODULE_0__["default"]),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _InfiniteLoader__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./InfiniteLoader */ "../../node_modules/react-virtualized/dist/es/InfiniteLoader/InfiniteLoader.js");

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_InfiniteLoader__WEBPACK_IMPORTED_MODULE_0__["default"]);


/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/List/List.js":
/*!*****************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/List/List.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ List)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _Grid__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../Grid */ "../../node_modules/react-virtualized/dist/es/Grid/index.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var clsx__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! clsx */ "../../node_modules/clsx/dist/clsx.m.js");
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/List/types.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_11___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_11__);









var _class, _temp;




/**
 * It is inefficient to create and manage a large list of DOM elements within a scrolling container
 * if only a few of those elements are visible. The primary purpose of this component is to improve
 * performance by only rendering the DOM nodes that a user is able to see based on their current
 * scroll position.
 *
 * This component renders a virtualized list of elements with either fixed or dynamic heights.
 */

var List = (_temp = _class =
/*#__PURE__*/
function (_React$PureComponent) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_6__["default"])(List, _React$PureComponent);

  function List() {
    var _getPrototypeOf2;

    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_1__["default"])(this, List);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_3__["default"])(this, (_getPrototypeOf2 = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_4__["default"])(List)).call.apply(_getPrototypeOf2, [this].concat(args)));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "Grid", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_cellRenderer", function (_ref) {
      var parent = _ref.parent,
          rowIndex = _ref.rowIndex,
          style = _ref.style,
          isScrolling = _ref.isScrolling,
          isVisible = _ref.isVisible,
          key = _ref.key;
      var rowRenderer = _this.props.rowRenderer; // TRICKY The style object is sometimes cached by Grid.
      // This prevents new style objects from bypassing shallowCompare().
      // However as of React 16, style props are auto-frozen (at least in dev mode)
      // Check to make sure we can still modify the style before proceeding.
      // https://github.com/facebook/react/commit/977357765b44af8ff0cfea327866861073095c12#commitcomment-20648713

      var widthDescriptor = Object.getOwnPropertyDescriptor(style, 'width');

      if (widthDescriptor && widthDescriptor.writable) {
        // By default, List cells should be 100% width.
        // This prevents them from flowing under a scrollbar (if present).
        style.width = '100%';
      }

      return rowRenderer({
        index: rowIndex,
        style: style,
        isScrolling: isScrolling,
        isVisible: isVisible,
        key: key,
        parent: parent
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_setRef", function (ref) {
      _this.Grid = ref;
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_onScroll", function (_ref2) {
      var clientHeight = _ref2.clientHeight,
          scrollHeight = _ref2.scrollHeight,
          scrollTop = _ref2.scrollTop;
      var onScroll = _this.props.onScroll;
      onScroll({
        clientHeight: clientHeight,
        scrollHeight: scrollHeight,
        scrollTop: scrollTop
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this), "_onSectionRendered", function (_ref3) {
      var rowOverscanStartIndex = _ref3.rowOverscanStartIndex,
          rowOverscanStopIndex = _ref3.rowOverscanStopIndex,
          rowStartIndex = _ref3.rowStartIndex,
          rowStopIndex = _ref3.rowStopIndex;
      var onRowsRendered = _this.props.onRowsRendered;
      onRowsRendered({
        overscanStartIndex: rowOverscanStartIndex,
        overscanStopIndex: rowOverscanStopIndex,
        startIndex: rowStartIndex,
        stopIndex: rowStopIndex
      });
    });

    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(List, [{
    key: "forceUpdateGrid",
    value: function forceUpdateGrid() {
      if (this.Grid) {
        this.Grid.forceUpdate();
      }
    }
    /** See Grid#getOffsetForCell */

  }, {
    key: "getOffsetForRow",
    value: function getOffsetForRow(_ref4) {
      var alignment = _ref4.alignment,
          index = _ref4.index;

      if (this.Grid) {
        var _this$Grid$getOffsetF = this.Grid.getOffsetForCell({
          alignment: alignment,
          rowIndex: index,
          columnIndex: 0
        }),
            scrollTop = _this$Grid$getOffsetF.scrollTop;

        return scrollTop;
      }

      return 0;
    }
    /** CellMeasurer compatibility */

  }, {
    key: "invalidateCellSizeAfterRender",
    value: function invalidateCellSizeAfterRender(_ref5) {
      var columnIndex = _ref5.columnIndex,
          rowIndex = _ref5.rowIndex;

      if (this.Grid) {
        this.Grid.invalidateCellSizeAfterRender({
          rowIndex: rowIndex,
          columnIndex: columnIndex
        });
      }
    }
    /** See Grid#measureAllCells */

  }, {
    key: "measureAllRows",
    value: function measureAllRows() {
      if (this.Grid) {
        this.Grid.measureAllCells();
      }
    }
    /** CellMeasurer compatibility */

  }, {
    key: "recomputeGridSize",
    value: function recomputeGridSize() {
      var _ref6 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
          _ref6$columnIndex = _ref6.columnIndex,
          columnIndex = _ref6$columnIndex === void 0 ? 0 : _ref6$columnIndex,
          _ref6$rowIndex = _ref6.rowIndex,
          rowIndex = _ref6$rowIndex === void 0 ? 0 : _ref6$rowIndex;

      if (this.Grid) {
        this.Grid.recomputeGridSize({
          rowIndex: rowIndex,
          columnIndex: columnIndex
        });
      }
    }
    /** See Grid#recomputeGridSize */

  }, {
    key: "recomputeRowHeights",
    value: function recomputeRowHeights() {
      var index = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;

      if (this.Grid) {
        this.Grid.recomputeGridSize({
          rowIndex: index,
          columnIndex: 0
        });
      }
    }
    /** See Grid#scrollToPosition */

  }, {
    key: "scrollToPosition",
    value: function scrollToPosition() {
      var scrollTop = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;

      if (this.Grid) {
        this.Grid.scrollToPosition({
          scrollTop: scrollTop
        });
      }
    }
    /** See Grid#scrollToCell */

  }, {
    key: "scrollToRow",
    value: function scrollToRow() {
      var index = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;

      if (this.Grid) {
        this.Grid.scrollToCell({
          columnIndex: 0,
          rowIndex: index
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          className = _this$props.className,
          noRowsRenderer = _this$props.noRowsRenderer,
          scrollToIndex = _this$props.scrollToIndex,
          width = _this$props.width;
      var classNames = (0,clsx__WEBPACK_IMPORTED_MODULE_10__["default"])('ReactVirtualized__List', className);
      return react__WEBPACK_IMPORTED_MODULE_9__.createElement(_Grid__WEBPACK_IMPORTED_MODULE_8__["default"], (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, this.props, {
        autoContainerWidth: true,
        cellRenderer: this._cellRenderer,
        className: classNames,
        columnWidth: width,
        columnCount: 1,
        noContentRenderer: noRowsRenderer,
        onScroll: this._onScroll,
        onSectionRendered: this._onSectionRendered,
        ref: this._setRef,
        scrollToRow: scrollToIndex
      }));
    }
  }]);

  return List;
}(react__WEBPACK_IMPORTED_MODULE_9__.PureComponent), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(_class, "propTypes",  false ? 0 : {
  "aria-label": (prop_types__WEBPACK_IMPORTED_MODULE_11___default().string),

  /**
   * Removes fixed height from the scrollingContainer so that the total height
   * of rows can stretch the window. Intended for use with WindowScroller
   */
  "autoHeight": (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool.isRequired),

  /** Optional CSS class name */
  "className": (prop_types__WEBPACK_IMPORTED_MODULE_11___default().string),

  /**
   * Used to estimate the total height of a List before all of its rows have actually been measured.
   * The estimated total height is adjusted as rows are rendered.
   */
  "estimatedRowSize": (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number.isRequired),

  /** Height constraint for list (determines how many actual rows are rendered) */
  "height": (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number.isRequired),

  /** Optional renderer to be used in place of rows when rowCount is 0 */
  "noRowsRenderer": function noRowsRenderer() {
    return (typeof _Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_NoContentRenderer === "function" ? _Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_NoContentRenderer.isRequired ? _Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_NoContentRenderer.isRequired : _Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_NoContentRenderer : prop_types__WEBPACK_IMPORTED_MODULE_11___default().shape(_Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_NoContentRenderer).isRequired).apply(this, arguments);
  },

  /** Callback invoked with information about the slice of rows that were just rendered.  */
  "onRowsRendered": (prop_types__WEBPACK_IMPORTED_MODULE_11___default().func.isRequired),

  /**
   * Callback invoked whenever the scroll offset changes within the inner scrollable region.
   * This callback can be used to sync scrolling between lists, tables, or grids.
   */
  "onScroll": (prop_types__WEBPACK_IMPORTED_MODULE_11___default().func.isRequired),

  /** See Grid#overscanIndicesGetter */
  "overscanIndicesGetter": function overscanIndicesGetter() {
    return (typeof _Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_OverscanIndicesGetter === "function" ? _Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_OverscanIndicesGetter.isRequired ? _Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_OverscanIndicesGetter.isRequired : _Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_OverscanIndicesGetter : prop_types__WEBPACK_IMPORTED_MODULE_11___default().shape(_Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_OverscanIndicesGetter).isRequired).apply(this, arguments);
  },

  /**
   * Number of rows to render above/below the visible bounds of the list.
   * These rows can help for smoother scrolling on touch devices.
   */
  "overscanRowCount": (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number.isRequired),

  /** Either a fixed row height (number) or a function that returns the height of a row given its index.  */
  "rowHeight": function rowHeight() {
    return (typeof _Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_CellSize === "function" ? _Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_CellSize.isRequired ? _Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_CellSize.isRequired : _Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_CellSize : prop_types__WEBPACK_IMPORTED_MODULE_11___default().shape(_Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_CellSize).isRequired).apply(this, arguments);
  },

  /** Responsible for rendering a row given an index; ({ index: number }): node */
  "rowRenderer": function rowRenderer() {
    return (typeof _types__WEBPACK_IMPORTED_MODULE_12__.bpfrpt_proptype_RowRenderer === "function" ? _types__WEBPACK_IMPORTED_MODULE_12__.bpfrpt_proptype_RowRenderer.isRequired ? _types__WEBPACK_IMPORTED_MODULE_12__.bpfrpt_proptype_RowRenderer.isRequired : _types__WEBPACK_IMPORTED_MODULE_12__.bpfrpt_proptype_RowRenderer : prop_types__WEBPACK_IMPORTED_MODULE_11___default().shape(_types__WEBPACK_IMPORTED_MODULE_12__.bpfrpt_proptype_RowRenderer).isRequired).apply(this, arguments);
  },

  /** Number of rows in list. */
  "rowCount": (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number.isRequired),

  /** See Grid#scrollToAlignment */
  "scrollToAlignment": function scrollToAlignment() {
    return (typeof _Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_Alignment === "function" ? _Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_Alignment.isRequired ? _Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_Alignment.isRequired : _Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_Alignment : prop_types__WEBPACK_IMPORTED_MODULE_11___default().shape(_Grid__WEBPACK_IMPORTED_MODULE_8__.bpfrpt_proptype_Alignment).isRequired).apply(this, arguments);
  },

  /** Row index to ensure visible (by forcefully scrolling if necessary) */
  "scrollToIndex": (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number.isRequired),

  /** Vertical offset. */
  "scrollTop": (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number),

  /** Optional inline style */
  "style": (prop_types__WEBPACK_IMPORTED_MODULE_11___default().object.isRequired),

  /** Tab index for focus */
  "tabIndex": (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number),

  /** Width of list */
  "width": (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number.isRequired)
}), _temp);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(List, "defaultProps", {
  autoHeight: false,
  estimatedRowSize: 30,
  onScroll: function onScroll() {},
  noRowsRenderer: function noRowsRenderer() {
    return null;
  },
  onRowsRendered: function onRowsRendered() {},
  overscanIndicesGetter: _Grid__WEBPACK_IMPORTED_MODULE_8__.accessibilityOverscanIndicesGetter,
  overscanRowCount: 10,
  scrollToAlignment: 'auto',
  scrollToIndex: -1,
  style: {}
});















/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/List/index.js":
/*!******************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/List/index.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "List": () => (/* reexport safe */ _List__WEBPACK_IMPORTED_MODULE_0__["default"]),
/* harmony export */   "bpfrpt_proptype_RowRendererParams": () => (/* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_1__.bpfrpt_proptype_RowRendererParams),
/* harmony export */   "default": () => (/* reexport safe */ _List__WEBPACK_IMPORTED_MODULE_0__["default"])
/* harmony export */ });
/* harmony import */ var _List__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./List */ "../../node_modules/react-virtualized/dist/es/List/List.js");
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/List/types.js");





/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/List/types.js":
/*!******************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/List/types.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "bpfrpt_proptype_RenderedRows": () => (/* binding */ bpfrpt_proptype_RenderedRows),
/* harmony export */   "bpfrpt_proptype_RowRenderer": () => (/* binding */ bpfrpt_proptype_RowRenderer),
/* harmony export */   "bpfrpt_proptype_RowRendererParams": () => (/* binding */ bpfrpt_proptype_RowRendererParams),
/* harmony export */   "bpfrpt_proptype_Scroll": () => (/* binding */ bpfrpt_proptype_Scroll)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);

var bpfrpt_proptype_RowRendererParams =  false ? 0 : {
  "index": (prop_types__WEBPACK_IMPORTED_MODULE_1___default().number.isRequired),
  "isScrolling": (prop_types__WEBPACK_IMPORTED_MODULE_1___default().bool.isRequired),
  "isVisible": (prop_types__WEBPACK_IMPORTED_MODULE_1___default().bool.isRequired),
  "key": (prop_types__WEBPACK_IMPORTED_MODULE_1___default().string.isRequired),
  "parent": (prop_types__WEBPACK_IMPORTED_MODULE_1___default().object.isRequired),
  "style": (prop_types__WEBPACK_IMPORTED_MODULE_1___default().object.isRequired)
};
var bpfrpt_proptype_RowRenderer =  false ? 0 : (prop_types__WEBPACK_IMPORTED_MODULE_1___default().func);
var bpfrpt_proptype_RenderedRows =  false ? 0 : {
  "overscanStartIndex": (prop_types__WEBPACK_IMPORTED_MODULE_1___default().number.isRequired),
  "overscanStopIndex": (prop_types__WEBPACK_IMPORTED_MODULE_1___default().number.isRequired),
  "startIndex": (prop_types__WEBPACK_IMPORTED_MODULE_1___default().number.isRequired),
  "stopIndex": (prop_types__WEBPACK_IMPORTED_MODULE_1___default().number.isRequired)
};
var bpfrpt_proptype_Scroll =  false ? 0 : {
  "clientHeight": (prop_types__WEBPACK_IMPORTED_MODULE_1___default().number.isRequired),
  "scrollHeight": (prop_types__WEBPACK_IMPORTED_MODULE_1___default().number.isRequired),
  "scrollTop": (prop_types__WEBPACK_IMPORTED_MODULE_1___default().number.isRequired)
};






/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Masonry/Masonry.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Masonry/Masonry.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "DEFAULT_SCROLLING_RESET_TIME_INTERVAL": () => (/* binding */ DEFAULT_SCROLLING_RESET_TIME_INTERVAL),
/* harmony export */   "bpfrpt_proptype_CellMeasurerCache": () => (/* binding */ bpfrpt_proptype_CellMeasurerCache),
/* harmony export */   "bpfrpt_proptype_Positioner": () => (/* binding */ bpfrpt_proptype_Positioner),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var clsx__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! clsx */ "../../node_modules/clsx/dist/clsx.m.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */ var react_lifecycles_compat__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! react-lifecycles-compat */ "../../node_modules/react-lifecycles-compat/react-lifecycles-compat.es.js");
/* harmony import */ var _PositionCache__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./PositionCache */ "../../node_modules/react-virtualized/dist/es/Masonry/PositionCache.js");
/* harmony import */ var _utils_requestAnimationTimeout__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../utils/requestAnimationTimeout */ "../../node_modules/react-virtualized/dist/es/utils/requestAnimationTimeout.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_12___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_12__);








var _class, _temp;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }






var emptyObject = {};
/**
 * Specifies the number of miliseconds during which to disable pointer events while a scroll is in progress.
 * This improves performance and makes scrolling smoother.
 */

var DEFAULT_SCROLLING_RESET_TIME_INTERVAL = 150;
/**
 * This component efficiently displays arbitrarily positioned cells using windowing techniques.
 * Cell position is determined by an injected `cellPositioner` property.
 * Windowing is vertical; this component does not support horizontal scrolling.
 *
 * Rendering occurs in two phases:
 * 1) First pass uses estimated cell sizes (provided by the cache) to determine how many cells to measure in a batch.
 *    Batch size is chosen using a fast, naive layout algorithm that stacks images in order until the viewport has been filled.
 *    After measurement is complete (componentDidMount or componentDidUpdate) this component evaluates positioned cells
 *    in order to determine if another measurement pass is required (eg if actual cell sizes were less than estimated sizes).
 *    All measurements are permanently cached (keyed by `keyMapper`) for performance purposes.
 * 2) Second pass uses the external `cellPositioner` to layout cells.
 *    At this time the positioner has access to cached size measurements for all cells.
 *    The positions it returns are cached by Masonry for fast access later.
 *    Phase one is repeated if the user scrolls beyond the current layout's bounds.
 *    If the layout is invalidated due to eg a resize, cached positions can be cleared using `recomputeCellPositions()`.
 *
 * Animation constraints:
 *   Simple animations are supported (eg translate/slide into place on initial reveal).
 *   More complex animations are not (eg flying from one position to another on resize).
 *
 * Layout constraints:
 *   This component supports multi-column layout.
 *   The height of each item may vary.
 *   The width of each item must not exceed the width of the column it is "in".
 *   The left position of all items within a column must align.
 *   (Items may not span multiple columns.)
 */

var Masonry = (_temp = _class =
/*#__PURE__*/
function (_React$PureComponent) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(Masonry, _React$PureComponent);

  function Masonry() {
    var _getPrototypeOf2;

    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, Masonry);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__["default"])(this, (_getPrototypeOf2 = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(Masonry)).call.apply(_getPrototypeOf2, [this].concat(args)));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "state", {
      isScrolling: false,
      scrollTop: 0
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_debounceResetIsScrollingId", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_invalidateOnUpdateStartIndex", null);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_invalidateOnUpdateStopIndex", null);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_positionCache", new _PositionCache__WEBPACK_IMPORTED_MODULE_10__["default"]());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_startIndex", null);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_startIndexMemoized", null);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_stopIndex", null);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_stopIndexMemoized", null);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_debounceResetIsScrollingCallback", function () {
      _this.setState({
        isScrolling: false
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_setScrollingContainerRef", function (ref) {
      _this._scrollingContainer = ref;
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_onScroll", function (event) {
      var height = _this.props.height;
      var eventScrollTop = event.currentTarget.scrollTop; // When this component is shrunk drastically, React dispatches a series of back-to-back scroll events,
      // Gradually converging on a scrollTop that is within the bounds of the new, smaller height.
      // This causes a series of rapid renders that is slow for long lists.
      // We can avoid that by doing some simple bounds checking to ensure that scroll offsets never exceed their bounds.

      var scrollTop = Math.min(Math.max(0, _this._getEstimatedTotalHeight() - height), eventScrollTop); // On iOS, we can arrive at negative offsets by swiping past the start or end.
      // Avoid re-rendering in this case as it can cause problems; see #532 for more.

      if (eventScrollTop !== scrollTop) {
        return;
      } // Prevent pointer events from interrupting a smooth scroll


      _this._debounceResetIsScrolling(); // Certain devices (like Apple touchpad) rapid-fire duplicate events.
      // Don't force a re-render if this is the case.
      // The mouse may move faster then the animation frame does.
      // Use requestAnimationFrame to avoid over-updating.


      if (_this.state.scrollTop !== scrollTop) {
        _this.setState({
          isScrolling: true,
          scrollTop: scrollTop
        });
      }
    });

    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(Masonry, [{
    key: "clearCellPositions",
    value: function clearCellPositions() {
      this._positionCache = new _PositionCache__WEBPACK_IMPORTED_MODULE_10__["default"]();
      this.forceUpdate();
    } // HACK This method signature was intended for Grid

  }, {
    key: "invalidateCellSizeAfterRender",
    value: function invalidateCellSizeAfterRender(_ref) {
      var index = _ref.rowIndex;

      if (this._invalidateOnUpdateStartIndex === null) {
        this._invalidateOnUpdateStartIndex = index;
        this._invalidateOnUpdateStopIndex = index;
      } else {
        this._invalidateOnUpdateStartIndex = Math.min(this._invalidateOnUpdateStartIndex, index);
        this._invalidateOnUpdateStopIndex = Math.max(this._invalidateOnUpdateStopIndex, index);
      }
    }
  }, {
    key: "recomputeCellPositions",
    value: function recomputeCellPositions() {
      var stopIndex = this._positionCache.count - 1;
      this._positionCache = new _PositionCache__WEBPACK_IMPORTED_MODULE_10__["default"]();

      this._populatePositionCache(0, stopIndex);

      this.forceUpdate();
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this._checkInvalidateOnUpdate();

      this._invokeOnScrollCallback();

      this._invokeOnCellsRenderedCallback();
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps, prevState) {
      this._checkInvalidateOnUpdate();

      this._invokeOnScrollCallback();

      this._invokeOnCellsRenderedCallback();

      if (this.props.scrollTop !== prevProps.scrollTop) {
        this._debounceResetIsScrolling();
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      if (this._debounceResetIsScrollingId) {
        (0,_utils_requestAnimationTimeout__WEBPACK_IMPORTED_MODULE_11__.cancelAnimationTimeout)(this._debounceResetIsScrollingId);
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          autoHeight = _this$props.autoHeight,
          cellCount = _this$props.cellCount,
          cellMeasurerCache = _this$props.cellMeasurerCache,
          cellRenderer = _this$props.cellRenderer,
          className = _this$props.className,
          height = _this$props.height,
          id = _this$props.id,
          keyMapper = _this$props.keyMapper,
          overscanByPixels = _this$props.overscanByPixels,
          role = _this$props.role,
          style = _this$props.style,
          tabIndex = _this$props.tabIndex,
          width = _this$props.width,
          rowDirection = _this$props.rowDirection;
      var _this$state = this.state,
          isScrolling = _this$state.isScrolling,
          scrollTop = _this$state.scrollTop;
      var children = [];

      var estimateTotalHeight = this._getEstimatedTotalHeight();

      var shortestColumnSize = this._positionCache.shortestColumnSize;
      var measuredCellCount = this._positionCache.count;
      var startIndex = 0;
      var stopIndex;

      this._positionCache.range(Math.max(0, scrollTop - overscanByPixels), height + overscanByPixels * 2, function (index, left, top) {
        var _style;

        if (typeof stopIndex === 'undefined') {
          startIndex = index;
          stopIndex = index;
        } else {
          startIndex = Math.min(startIndex, index);
          stopIndex = Math.max(stopIndex, index);
        }

        children.push(cellRenderer({
          index: index,
          isScrolling: isScrolling,
          key: keyMapper(index),
          parent: _this2,
          style: (_style = {
            height: cellMeasurerCache.getHeight(index)
          }, (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(_style, rowDirection === 'ltr' ? 'left' : 'right', left), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(_style, "position", 'absolute'), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(_style, "top", top), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(_style, "width", cellMeasurerCache.getWidth(index)), _style)
        }));
      }); // We need to measure additional cells for this layout


      if (shortestColumnSize < scrollTop + height + overscanByPixels && measuredCellCount < cellCount) {
        var batchSize = Math.min(cellCount - measuredCellCount, Math.ceil((scrollTop + height + overscanByPixels - shortestColumnSize) / cellMeasurerCache.defaultHeight * width / cellMeasurerCache.defaultWidth));

        for (var _index = measuredCellCount; _index < measuredCellCount + batchSize; _index++) {
          stopIndex = _index;
          children.push(cellRenderer({
            index: _index,
            isScrolling: isScrolling,
            key: keyMapper(_index),
            parent: this,
            style: {
              width: cellMeasurerCache.getWidth(_index)
            }
          }));
        }
      }

      this._startIndex = startIndex;
      this._stopIndex = stopIndex;
      return react__WEBPACK_IMPORTED_MODULE_8__.createElement("div", {
        ref: this._setScrollingContainerRef,
        "aria-label": this.props['aria-label'],
        className: (0,clsx__WEBPACK_IMPORTED_MODULE_7__["default"])('ReactVirtualized__Masonry', className),
        id: id,
        onScroll: this._onScroll,
        role: role,
        style: _objectSpread({
          boxSizing: 'border-box',
          direction: 'ltr',
          height: autoHeight ? 'auto' : height,
          overflowX: 'hidden',
          overflowY: estimateTotalHeight < height ? 'hidden' : 'auto',
          position: 'relative',
          width: width,
          WebkitOverflowScrolling: 'touch',
          willChange: 'transform'
        }, style),
        tabIndex: tabIndex
      }, react__WEBPACK_IMPORTED_MODULE_8__.createElement("div", {
        className: "ReactVirtualized__Masonry__innerScrollContainer",
        style: {
          width: '100%',
          height: estimateTotalHeight,
          maxWidth: '100%',
          maxHeight: estimateTotalHeight,
          overflow: 'hidden',
          pointerEvents: isScrolling ? 'none' : '',
          position: 'relative'
        }
      }, children));
    }
  }, {
    key: "_checkInvalidateOnUpdate",
    value: function _checkInvalidateOnUpdate() {
      if (typeof this._invalidateOnUpdateStartIndex === 'number') {
        var startIndex = this._invalidateOnUpdateStartIndex;
        var stopIndex = this._invalidateOnUpdateStopIndex;
        this._invalidateOnUpdateStartIndex = null;
        this._invalidateOnUpdateStopIndex = null; // Query external layout logic for position of newly-measured cells

        this._populatePositionCache(startIndex, stopIndex);

        this.forceUpdate();
      }
    }
  }, {
    key: "_debounceResetIsScrolling",
    value: function _debounceResetIsScrolling() {
      var scrollingResetTimeInterval = this.props.scrollingResetTimeInterval;

      if (this._debounceResetIsScrollingId) {
        (0,_utils_requestAnimationTimeout__WEBPACK_IMPORTED_MODULE_11__.cancelAnimationTimeout)(this._debounceResetIsScrollingId);
      }

      this._debounceResetIsScrollingId = (0,_utils_requestAnimationTimeout__WEBPACK_IMPORTED_MODULE_11__.requestAnimationTimeout)(this._debounceResetIsScrollingCallback, scrollingResetTimeInterval);
    }
  }, {
    key: "_getEstimatedTotalHeight",
    value: function _getEstimatedTotalHeight() {
      var _this$props2 = this.props,
          cellCount = _this$props2.cellCount,
          cellMeasurerCache = _this$props2.cellMeasurerCache,
          width = _this$props2.width;
      var estimatedColumnCount = Math.max(1, Math.floor(width / cellMeasurerCache.defaultWidth));
      return this._positionCache.estimateTotalHeight(cellCount, estimatedColumnCount, cellMeasurerCache.defaultHeight);
    }
  }, {
    key: "_invokeOnScrollCallback",
    value: function _invokeOnScrollCallback() {
      var _this$props3 = this.props,
          height = _this$props3.height,
          onScroll = _this$props3.onScroll;
      var scrollTop = this.state.scrollTop;

      if (this._onScrollMemoized !== scrollTop) {
        onScroll({
          clientHeight: height,
          scrollHeight: this._getEstimatedTotalHeight(),
          scrollTop: scrollTop
        });
        this._onScrollMemoized = scrollTop;
      }
    }
  }, {
    key: "_invokeOnCellsRenderedCallback",
    value: function _invokeOnCellsRenderedCallback() {
      if (this._startIndexMemoized !== this._startIndex || this._stopIndexMemoized !== this._stopIndex) {
        var onCellsRendered = this.props.onCellsRendered;
        onCellsRendered({
          startIndex: this._startIndex,
          stopIndex: this._stopIndex
        });
        this._startIndexMemoized = this._startIndex;
        this._stopIndexMemoized = this._stopIndex;
      }
    }
  }, {
    key: "_populatePositionCache",
    value: function _populatePositionCache(startIndex, stopIndex) {
      var _this$props4 = this.props,
          cellMeasurerCache = _this$props4.cellMeasurerCache,
          cellPositioner = _this$props4.cellPositioner;

      for (var _index2 = startIndex; _index2 <= stopIndex; _index2++) {
        var _cellPositioner = cellPositioner(_index2),
            left = _cellPositioner.left,
            top = _cellPositioner.top;

        this._positionCache.setPosition(_index2, left, top, cellMeasurerCache.getHeight(_index2));
      }
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(nextProps, prevState) {
      if (nextProps.scrollTop !== undefined && prevState.scrollTop !== nextProps.scrollTop) {
        return {
          isScrolling: true,
          scrollTop: nextProps.scrollTop
        };
      }

      return null;
    }
  }]);

  return Masonry;
}(react__WEBPACK_IMPORTED_MODULE_8__.PureComponent), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(_class, "propTypes",  false ? 0 : {
  "autoHeight": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().bool.isRequired),
  "cellCount": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired),
  "cellMeasurerCache": function cellMeasurerCache() {
    return (typeof CellMeasurerCache === "function" ? prop_types__WEBPACK_IMPORTED_MODULE_12___default().instanceOf(CellMeasurerCache).isRequired : (prop_types__WEBPACK_IMPORTED_MODULE_12___default().any.isRequired)).apply(this, arguments);
  },
  "cellPositioner": function cellPositioner() {
    return (typeof Positioner === "function" ? prop_types__WEBPACK_IMPORTED_MODULE_12___default().instanceOf(Positioner).isRequired : (prop_types__WEBPACK_IMPORTED_MODULE_12___default().any.isRequired)).apply(this, arguments);
  },
  "cellRenderer": function cellRenderer() {
    return (typeof CellRenderer === "function" ? prop_types__WEBPACK_IMPORTED_MODULE_12___default().instanceOf(CellRenderer).isRequired : (prop_types__WEBPACK_IMPORTED_MODULE_12___default().any.isRequired)).apply(this, arguments);
  },
  "className": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().string),
  "height": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired),
  "id": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().string),
  "keyMapper": function keyMapper() {
    return (typeof KeyMapper === "function" ? prop_types__WEBPACK_IMPORTED_MODULE_12___default().instanceOf(KeyMapper).isRequired : (prop_types__WEBPACK_IMPORTED_MODULE_12___default().any.isRequired)).apply(this, arguments);
  },
  "onCellsRendered": function onCellsRendered() {
    return (typeof OnCellsRenderedCallback === "function" ? prop_types__WEBPACK_IMPORTED_MODULE_12___default().instanceOf(OnCellsRenderedCallback) : (prop_types__WEBPACK_IMPORTED_MODULE_12___default().any)).apply(this, arguments);
  },
  "onScroll": function onScroll() {
    return (typeof OnScrollCallback === "function" ? prop_types__WEBPACK_IMPORTED_MODULE_12___default().instanceOf(OnScrollCallback) : (prop_types__WEBPACK_IMPORTED_MODULE_12___default().any)).apply(this, arguments);
  },
  "overscanByPixels": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired),
  "role": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().string.isRequired),
  "scrollingResetTimeInterval": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired),
  "style": function style(props, propName, componentName) {
    if (!Object.prototype.hasOwnProperty.call(props, propName)) {
      throw new Error("Prop `".concat(propName, "` has type 'any' or 'mixed', but was not provided to `").concat(componentName, "`. Pass undefined or any other value."));
    }
  },
  "tabIndex": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired),
  "width": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired),
  "rowDirection": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().string.isRequired),
  "scrollTop": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number)
}), _temp);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(Masonry, "defaultProps", {
  autoHeight: false,
  keyMapper: identity,
  onCellsRendered: noop,
  onScroll: noop,
  overscanByPixels: 20,
  role: 'grid',
  scrollingResetTimeInterval: DEFAULT_SCROLLING_RESET_TIME_INTERVAL,
  style: emptyObject,
  tabIndex: 0,
  rowDirection: 'ltr'
});

function identity(value) {
  return value;
}

function noop() {}

var bpfrpt_proptype_CellMeasurerCache =  false ? 0 : {
  "defaultHeight": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired),
  "defaultWidth": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired),
  "getHeight": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func.isRequired),
  "getWidth": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func.isRequired)
};
(0,react_lifecycles_compat__WEBPACK_IMPORTED_MODULE_9__.polyfill)(Masonry);
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Masonry);
var bpfrpt_proptype_Positioner =  false ? 0 : (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func);





/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Masonry/PositionCache.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Masonry/PositionCache.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ PositionCache)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/slicedToArray */ "../../node_modules/@babel/runtime/helpers/esm/slicedToArray.js");
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _vendor_intervalTree__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../vendor/intervalTree */ "../../node_modules/react-virtualized/dist/es/vendor/intervalTree.js");






// Position cache requirements:
//   O(log(n)) lookup of cells to render for a given viewport size
//   O(1) lookup of shortest measured column (so we know when to enter phase 1)
var PositionCache =
/*#__PURE__*/
function () {
  function PositionCache() {
    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_1__["default"])(this, PositionCache);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_3__["default"])(this, "_columnSizeMap", {});

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_3__["default"])(this, "_intervalTree", (0,_vendor_intervalTree__WEBPACK_IMPORTED_MODULE_4__["default"])());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_3__["default"])(this, "_leftMap", {});
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(PositionCache, [{
    key: "estimateTotalHeight",
    value: function estimateTotalHeight(cellCount, columnCount, defaultCellHeight) {
      var unmeasuredCellCount = cellCount - this.count;
      return this.tallestColumnSize + Math.ceil(unmeasuredCellCount / columnCount) * defaultCellHeight;
    } // Render all cells visible within the viewport range defined.

  }, {
    key: "range",
    value: function range(scrollTop, clientHeight, renderCallback) {
      var _this = this;

      this._intervalTree.queryInterval(scrollTop, scrollTop + clientHeight, function (_ref) {
        var _ref2 = (0,_babel_runtime_helpers_slicedToArray__WEBPACK_IMPORTED_MODULE_0__["default"])(_ref, 3),
            top = _ref2[0],
            _ = _ref2[1],
            index = _ref2[2];

        return renderCallback(index, _this._leftMap[index], top);
      });
    }
  }, {
    key: "setPosition",
    value: function setPosition(index, left, top, height) {
      this._intervalTree.insert([top, top + height, index]);

      this._leftMap[index] = left;
      var columnSizeMap = this._columnSizeMap;
      var columnHeight = columnSizeMap[left];

      if (columnHeight === undefined) {
        columnSizeMap[left] = top + height;
      } else {
        columnSizeMap[left] = Math.max(columnHeight, top + height);
      }
    }
  }, {
    key: "count",
    get: function get() {
      return this._intervalTree.count;
    }
  }, {
    key: "shortestColumnSize",
    get: function get() {
      var columnSizeMap = this._columnSizeMap;
      var size = 0;

      for (var i in columnSizeMap) {
        var height = columnSizeMap[i];
        size = size === 0 ? height : Math.min(size, height);
      }

      return size;
    }
  }, {
    key: "tallestColumnSize",
    get: function get() {
      var columnSizeMap = this._columnSizeMap;
      var size = 0;

      for (var i in columnSizeMap) {
        var height = columnSizeMap[i];
        size = Math.max(size, height);
      }

      return size;
    }
  }]);

  return PositionCache;
}();



/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Masonry/createCellPositioner.js":
/*!************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Masonry/createCellPositioner.js ***!
  \************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ createCellPositioner)
/* harmony export */ });
/* harmony import */ var _Masonry__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./Masonry */ "../../node_modules/react-virtualized/dist/es/Masonry/Masonry.js");
function createCellPositioner(_ref) {
  var cellMeasurerCache = _ref.cellMeasurerCache,
      columnCount = _ref.columnCount,
      columnWidth = _ref.columnWidth,
      _ref$spacer = _ref.spacer,
      spacer = _ref$spacer === void 0 ? 0 : _ref$spacer;
  var columnHeights;
  initOrResetDerivedValues();

  function cellPositioner(index) {
    // Find the shortest column and use it.
    var columnIndex = 0;

    for (var i = 1; i < columnHeights.length; i++) {
      if (columnHeights[i] < columnHeights[columnIndex]) {
        columnIndex = i;
      }
    }

    var left = columnIndex * (columnWidth + spacer);
    var top = columnHeights[columnIndex] || 0;
    columnHeights[columnIndex] = top + cellMeasurerCache.getHeight(index) + spacer;
    return {
      left: left,
      top: top
    };
  }

  function initOrResetDerivedValues() {
    // Track the height of each column.
    // Layout algorithm below always inserts into the shortest column.
    columnHeights = [];

    for (var i = 0; i < columnCount; i++) {
      columnHeights[i] = 0;
    }
  }

  function reset(params) {
    columnCount = params.columnCount;
    columnWidth = params.columnWidth;
    spacer = params.spacer;
    initOrResetDerivedValues();
  }

  cellPositioner.reset = reset;
  return cellPositioner;
}



/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Masonry/index.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Masonry/index.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Masonry": () => (/* reexport safe */ _Masonry__WEBPACK_IMPORTED_MODULE_1__["default"]),
/* harmony export */   "createCellPositioner": () => (/* reexport safe */ _createCellPositioner__WEBPACK_IMPORTED_MODULE_0__["default"]),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _createCellPositioner__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./createCellPositioner */ "../../node_modules/react-virtualized/dist/es/Masonry/createCellPositioner.js");
/* harmony import */ var _Masonry__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./Masonry */ "../../node_modules/react-virtualized/dist/es/Masonry/Masonry.js");


/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_Masonry__WEBPACK_IMPORTED_MODULE_1__["default"]);


/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/MultiGrid/CellMeasurerCacheDecorator.js":
/*!********************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/MultiGrid/CellMeasurerCacheDecorator.js ***!
  \********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ CellMeasurerCacheDecorator)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var _CellMeasurer__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../CellMeasurer */ "../../node_modules/react-virtualized/dist/es/CellMeasurer/index.js");





/**
 * Caches measurements for a given cell.
 */
var CellMeasurerCacheDecorator =
/*#__PURE__*/
function () {
  function CellMeasurerCacheDecorator() {
    var _this = this;

    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, CellMeasurerCacheDecorator);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_cellMeasurerCache", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_columnIndexOffset", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "_rowIndexOffset", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "columnWidth", function (_ref) {
      var index = _ref.index;

      _this._cellMeasurerCache.columnWidth({
        index: index + _this._columnIndexOffset
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__["default"])(this, "rowHeight", function (_ref2) {
      var index = _ref2.index;

      _this._cellMeasurerCache.rowHeight({
        index: index + _this._rowIndexOffset
      });
    });

    var cellMeasurerCache = params.cellMeasurerCache,
        _params$columnIndexOf = params.columnIndexOffset,
        columnIndexOffset = _params$columnIndexOf === void 0 ? 0 : _params$columnIndexOf,
        _params$rowIndexOffse = params.rowIndexOffset,
        rowIndexOffset = _params$rowIndexOffse === void 0 ? 0 : _params$rowIndexOffse;
    this._cellMeasurerCache = cellMeasurerCache;
    this._columnIndexOffset = columnIndexOffset;
    this._rowIndexOffset = rowIndexOffset;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(CellMeasurerCacheDecorator, [{
    key: "clear",
    value: function clear(rowIndex, columnIndex) {
      this._cellMeasurerCache.clear(rowIndex + this._rowIndexOffset, columnIndex + this._columnIndexOffset);
    }
  }, {
    key: "clearAll",
    value: function clearAll() {
      this._cellMeasurerCache.clearAll();
    }
  }, {
    key: "hasFixedHeight",
    value: function hasFixedHeight() {
      return this._cellMeasurerCache.hasFixedHeight();
    }
  }, {
    key: "hasFixedWidth",
    value: function hasFixedWidth() {
      return this._cellMeasurerCache.hasFixedWidth();
    }
  }, {
    key: "getHeight",
    value: function getHeight(rowIndex) {
      var columnIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
      return this._cellMeasurerCache.getHeight(rowIndex + this._rowIndexOffset, columnIndex + this._columnIndexOffset);
    }
  }, {
    key: "getWidth",
    value: function getWidth(rowIndex) {
      var columnIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
      return this._cellMeasurerCache.getWidth(rowIndex + this._rowIndexOffset, columnIndex + this._columnIndexOffset);
    }
  }, {
    key: "has",
    value: function has(rowIndex) {
      var columnIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
      return this._cellMeasurerCache.has(rowIndex + this._rowIndexOffset, columnIndex + this._columnIndexOffset);
    }
  }, {
    key: "set",
    value: function set(rowIndex, columnIndex, width, height) {
      this._cellMeasurerCache.set(rowIndex + this._rowIndexOffset, columnIndex + this._columnIndexOffset, width, height);
    }
  }, {
    key: "defaultHeight",
    get: function get() {
      return this._cellMeasurerCache.defaultHeight;
    }
  }, {
    key: "defaultWidth",
    get: function get() {
      return this._cellMeasurerCache.defaultWidth;
    }
  }]);

  return CellMeasurerCacheDecorator;
}();



/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/MultiGrid/MultiGrid.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/MultiGrid/MultiGrid.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/objectWithoutProperties */ "../../node_modules/@babel/runtime/helpers/esm/objectWithoutProperties.js");
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_13___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_13__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var react_lifecycles_compat__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! react-lifecycles-compat */ "../../node_modules/react-lifecycles-compat/react-lifecycles-compat.es.js");
/* harmony import */ var _CellMeasurerCacheDecorator__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./CellMeasurerCacheDecorator */ "../../node_modules/react-virtualized/dist/es/MultiGrid/CellMeasurerCacheDecorator.js");
/* harmony import */ var _Grid__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../Grid */ "../../node_modules/react-virtualized/dist/es/Grid/index.js");










function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }






var SCROLLBAR_SIZE_BUFFER = 20;
/**
 * Renders 1, 2, or 4 Grids depending on configuration.
 * A main (body) Grid will always be rendered.
 * Optionally, 1-2 Grids for sticky header rows will also be rendered.
 * If no sticky columns, only 1 sticky header Grid will be rendered.
 * If sticky columns, 2 sticky header Grids will be rendered.
 */

var MultiGrid =
/*#__PURE__*/
function (_React$PureComponent) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_7__["default"])(MultiGrid, _React$PureComponent);

  function MultiGrid(props, context) {
    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, MultiGrid);

    _this = (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_4__["default"])(this, (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_5__["default"])(MultiGrid).call(this, props, context));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this), "state", {
      scrollLeft: 0,
      scrollTop: 0,
      scrollbarSize: 0,
      showHorizontalScrollbar: false,
      showVerticalScrollbar: false
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this), "_deferredInvalidateColumnIndex", null);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this), "_deferredInvalidateRowIndex", null);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this), "_bottomLeftGridRef", function (ref) {
      _this._bottomLeftGrid = ref;
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this), "_bottomRightGridRef", function (ref) {
      _this._bottomRightGrid = ref;
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this), "_cellRendererBottomLeftGrid", function (_ref) {
      var rowIndex = _ref.rowIndex,
          rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_ref, ["rowIndex"]);

      var _this$props = _this.props,
          cellRenderer = _this$props.cellRenderer,
          fixedRowCount = _this$props.fixedRowCount,
          rowCount = _this$props.rowCount;

      if (rowIndex === rowCount - fixedRowCount) {
        return react__WEBPACK_IMPORTED_MODULE_9__.createElement("div", {
          key: rest.key,
          style: _objectSpread({}, rest.style, {
            height: SCROLLBAR_SIZE_BUFFER
          })
        });
      } else {
        return cellRenderer(_objectSpread({}, rest, {
          parent: (0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this),
          rowIndex: rowIndex + fixedRowCount
        }));
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this), "_cellRendererBottomRightGrid", function (_ref2) {
      var columnIndex = _ref2.columnIndex,
          rowIndex = _ref2.rowIndex,
          rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_ref2, ["columnIndex", "rowIndex"]);

      var _this$props2 = _this.props,
          cellRenderer = _this$props2.cellRenderer,
          fixedColumnCount = _this$props2.fixedColumnCount,
          fixedRowCount = _this$props2.fixedRowCount;
      return cellRenderer(_objectSpread({}, rest, {
        columnIndex: columnIndex + fixedColumnCount,
        parent: (0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this),
        rowIndex: rowIndex + fixedRowCount
      }));
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this), "_cellRendererTopRightGrid", function (_ref3) {
      var columnIndex = _ref3.columnIndex,
          rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_ref3, ["columnIndex"]);

      var _this$props3 = _this.props,
          cellRenderer = _this$props3.cellRenderer,
          columnCount = _this$props3.columnCount,
          fixedColumnCount = _this$props3.fixedColumnCount;

      if (columnIndex === columnCount - fixedColumnCount) {
        return react__WEBPACK_IMPORTED_MODULE_9__.createElement("div", {
          key: rest.key,
          style: _objectSpread({}, rest.style, {
            width: SCROLLBAR_SIZE_BUFFER
          })
        });
      } else {
        return cellRenderer(_objectSpread({}, rest, {
          columnIndex: columnIndex + fixedColumnCount,
          parent: (0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this)
        }));
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this), "_columnWidthRightGrid", function (_ref4) {
      var index = _ref4.index;
      var _this$props4 = _this.props,
          columnCount = _this$props4.columnCount,
          fixedColumnCount = _this$props4.fixedColumnCount,
          columnWidth = _this$props4.columnWidth;
      var _this$state = _this.state,
          scrollbarSize = _this$state.scrollbarSize,
          showHorizontalScrollbar = _this$state.showHorizontalScrollbar; // An extra cell is added to the count
      // This gives the smaller Grid extra room for offset,
      // In case the main (bottom right) Grid has a scrollbar
      // If no scrollbar, the extra space is overflow:hidden anyway

      if (showHorizontalScrollbar && index === columnCount - fixedColumnCount) {
        return scrollbarSize;
      }

      return typeof columnWidth === 'function' ? columnWidth({
        index: index + fixedColumnCount
      }) : columnWidth;
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this), "_onScroll", function (scrollInfo) {
      var scrollLeft = scrollInfo.scrollLeft,
          scrollTop = scrollInfo.scrollTop;

      _this.setState({
        scrollLeft: scrollLeft,
        scrollTop: scrollTop
      });

      var onScroll = _this.props.onScroll;

      if (onScroll) {
        onScroll(scrollInfo);
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this), "_onScrollbarPresenceChange", function (_ref5) {
      var horizontal = _ref5.horizontal,
          size = _ref5.size,
          vertical = _ref5.vertical;
      var _this$state2 = _this.state,
          showHorizontalScrollbar = _this$state2.showHorizontalScrollbar,
          showVerticalScrollbar = _this$state2.showVerticalScrollbar;

      if (horizontal !== showHorizontalScrollbar || vertical !== showVerticalScrollbar) {
        _this.setState({
          scrollbarSize: size,
          showHorizontalScrollbar: horizontal,
          showVerticalScrollbar: vertical
        });

        var onScrollbarPresenceChange = _this.props.onScrollbarPresenceChange;

        if (typeof onScrollbarPresenceChange === 'function') {
          onScrollbarPresenceChange({
            horizontal: horizontal,
            size: size,
            vertical: vertical
          });
        }
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this), "_onScrollLeft", function (scrollInfo) {
      var scrollLeft = scrollInfo.scrollLeft;

      _this._onScroll({
        scrollLeft: scrollLeft,
        scrollTop: _this.state.scrollTop
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this), "_onScrollTop", function (scrollInfo) {
      var scrollTop = scrollInfo.scrollTop;

      _this._onScroll({
        scrollTop: scrollTop,
        scrollLeft: _this.state.scrollLeft
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this), "_rowHeightBottomGrid", function (_ref6) {
      var index = _ref6.index;
      var _this$props5 = _this.props,
          fixedRowCount = _this$props5.fixedRowCount,
          rowCount = _this$props5.rowCount,
          rowHeight = _this$props5.rowHeight;
      var _this$state3 = _this.state,
          scrollbarSize = _this$state3.scrollbarSize,
          showVerticalScrollbar = _this$state3.showVerticalScrollbar; // An extra cell is added to the count
      // This gives the smaller Grid extra room for offset,
      // In case the main (bottom right) Grid has a scrollbar
      // If no scrollbar, the extra space is overflow:hidden anyway

      if (showVerticalScrollbar && index === rowCount - fixedRowCount) {
        return scrollbarSize;
      }

      return typeof rowHeight === 'function' ? rowHeight({
        index: index + fixedRowCount
      }) : rowHeight;
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this), "_topLeftGridRef", function (ref) {
      _this._topLeftGrid = ref;
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_6__["default"])(_this), "_topRightGridRef", function (ref) {
      _this._topRightGrid = ref;
    });

    var deferredMeasurementCache = props.deferredMeasurementCache,
        _fixedColumnCount = props.fixedColumnCount,
        _fixedRowCount = props.fixedRowCount;

    _this._maybeCalculateCachedStyles(true);

    if (deferredMeasurementCache) {
      _this._deferredMeasurementCacheBottomLeftGrid = _fixedRowCount > 0 ? new _CellMeasurerCacheDecorator__WEBPACK_IMPORTED_MODULE_11__["default"]({
        cellMeasurerCache: deferredMeasurementCache,
        columnIndexOffset: 0,
        rowIndexOffset: _fixedRowCount
      }) : deferredMeasurementCache;
      _this._deferredMeasurementCacheBottomRightGrid = _fixedColumnCount > 0 || _fixedRowCount > 0 ? new _CellMeasurerCacheDecorator__WEBPACK_IMPORTED_MODULE_11__["default"]({
        cellMeasurerCache: deferredMeasurementCache,
        columnIndexOffset: _fixedColumnCount,
        rowIndexOffset: _fixedRowCount
      }) : deferredMeasurementCache;
      _this._deferredMeasurementCacheTopRightGrid = _fixedColumnCount > 0 ? new _CellMeasurerCacheDecorator__WEBPACK_IMPORTED_MODULE_11__["default"]({
        cellMeasurerCache: deferredMeasurementCache,
        columnIndexOffset: _fixedColumnCount,
        rowIndexOffset: 0
      }) : deferredMeasurementCache;
    }

    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(MultiGrid, [{
    key: "forceUpdateGrids",
    value: function forceUpdateGrids() {
      this._bottomLeftGrid && this._bottomLeftGrid.forceUpdate();
      this._bottomRightGrid && this._bottomRightGrid.forceUpdate();
      this._topLeftGrid && this._topLeftGrid.forceUpdate();
      this._topRightGrid && this._topRightGrid.forceUpdate();
    }
    /** See Grid#invalidateCellSizeAfterRender */

  }, {
    key: "invalidateCellSizeAfterRender",
    value: function invalidateCellSizeAfterRender() {
      var _ref7 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
          _ref7$columnIndex = _ref7.columnIndex,
          columnIndex = _ref7$columnIndex === void 0 ? 0 : _ref7$columnIndex,
          _ref7$rowIndex = _ref7.rowIndex,
          rowIndex = _ref7$rowIndex === void 0 ? 0 : _ref7$rowIndex;

      this._deferredInvalidateColumnIndex = typeof this._deferredInvalidateColumnIndex === 'number' ? Math.min(this._deferredInvalidateColumnIndex, columnIndex) : columnIndex;
      this._deferredInvalidateRowIndex = typeof this._deferredInvalidateRowIndex === 'number' ? Math.min(this._deferredInvalidateRowIndex, rowIndex) : rowIndex;
    }
    /** See Grid#measureAllCells */

  }, {
    key: "measureAllCells",
    value: function measureAllCells() {
      this._bottomLeftGrid && this._bottomLeftGrid.measureAllCells();
      this._bottomRightGrid && this._bottomRightGrid.measureAllCells();
      this._topLeftGrid && this._topLeftGrid.measureAllCells();
      this._topRightGrid && this._topRightGrid.measureAllCells();
    }
    /** See Grid#recomputeGridSize */

  }, {
    key: "recomputeGridSize",
    value: function recomputeGridSize() {
      var _ref8 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
          _ref8$columnIndex = _ref8.columnIndex,
          columnIndex = _ref8$columnIndex === void 0 ? 0 : _ref8$columnIndex,
          _ref8$rowIndex = _ref8.rowIndex,
          rowIndex = _ref8$rowIndex === void 0 ? 0 : _ref8$rowIndex;

      var _this$props6 = this.props,
          fixedColumnCount = _this$props6.fixedColumnCount,
          fixedRowCount = _this$props6.fixedRowCount;
      var adjustedColumnIndex = Math.max(0, columnIndex - fixedColumnCount);
      var adjustedRowIndex = Math.max(0, rowIndex - fixedRowCount);
      this._bottomLeftGrid && this._bottomLeftGrid.recomputeGridSize({
        columnIndex: columnIndex,
        rowIndex: adjustedRowIndex
      });
      this._bottomRightGrid && this._bottomRightGrid.recomputeGridSize({
        columnIndex: adjustedColumnIndex,
        rowIndex: adjustedRowIndex
      });
      this._topLeftGrid && this._topLeftGrid.recomputeGridSize({
        columnIndex: columnIndex,
        rowIndex: rowIndex
      });
      this._topRightGrid && this._topRightGrid.recomputeGridSize({
        columnIndex: adjustedColumnIndex,
        rowIndex: rowIndex
      });
      this._leftGridWidth = null;
      this._topGridHeight = null;

      this._maybeCalculateCachedStyles(true);
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this$props7 = this.props,
          scrollLeft = _this$props7.scrollLeft,
          scrollTop = _this$props7.scrollTop;

      if (scrollLeft > 0 || scrollTop > 0) {
        var newState = {};

        if (scrollLeft > 0) {
          newState.scrollLeft = scrollLeft;
        }

        if (scrollTop > 0) {
          newState.scrollTop = scrollTop;
        }

        this.setState(newState);
      }

      this._handleInvalidatedGridSize();
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      this._handleInvalidatedGridSize();
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props8 = this.props,
          onScroll = _this$props8.onScroll,
          onSectionRendered = _this$props8.onSectionRendered,
          onScrollbarPresenceChange = _this$props8.onScrollbarPresenceChange,
          scrollLeftProp = _this$props8.scrollLeft,
          scrollToColumn = _this$props8.scrollToColumn,
          scrollTopProp = _this$props8.scrollTop,
          scrollToRow = _this$props8.scrollToRow,
          rest = (0,_babel_runtime_helpers_objectWithoutProperties__WEBPACK_IMPORTED_MODULE_1__["default"])(_this$props8, ["onScroll", "onSectionRendered", "onScrollbarPresenceChange", "scrollLeft", "scrollToColumn", "scrollTop", "scrollToRow"]);

      this._prepareForRender(); // Don't render any of our Grids if there are no cells.
      // This mirrors what Grid does,
      // And prevents us from recording inaccurage measurements when used with CellMeasurer.


      if (this.props.width === 0 || this.props.height === 0) {
        return null;
      } // scrollTop and scrollLeft props are explicitly filtered out and ignored


      var _this$state4 = this.state,
          scrollLeft = _this$state4.scrollLeft,
          scrollTop = _this$state4.scrollTop;
      return react__WEBPACK_IMPORTED_MODULE_9__.createElement("div", {
        style: this._containerOuterStyle
      }, react__WEBPACK_IMPORTED_MODULE_9__.createElement("div", {
        style: this._containerTopStyle
      }, this._renderTopLeftGrid(rest), this._renderTopRightGrid(_objectSpread({}, rest, {
        onScroll: onScroll,
        scrollLeft: scrollLeft
      }))), react__WEBPACK_IMPORTED_MODULE_9__.createElement("div", {
        style: this._containerBottomStyle
      }, this._renderBottomLeftGrid(_objectSpread({}, rest, {
        onScroll: onScroll,
        scrollTop: scrollTop
      })), this._renderBottomRightGrid(_objectSpread({}, rest, {
        onScroll: onScroll,
        onSectionRendered: onSectionRendered,
        scrollLeft: scrollLeft,
        scrollToColumn: scrollToColumn,
        scrollToRow: scrollToRow,
        scrollTop: scrollTop
      }))));
    }
  }, {
    key: "_getBottomGridHeight",
    value: function _getBottomGridHeight(props) {
      var height = props.height;

      var topGridHeight = this._getTopGridHeight(props);

      return height - topGridHeight;
    }
  }, {
    key: "_getLeftGridWidth",
    value: function _getLeftGridWidth(props) {
      var fixedColumnCount = props.fixedColumnCount,
          columnWidth = props.columnWidth;

      if (this._leftGridWidth == null) {
        if (typeof columnWidth === 'function') {
          var leftGridWidth = 0;

          for (var index = 0; index < fixedColumnCount; index++) {
            leftGridWidth += columnWidth({
              index: index
            });
          }

          this._leftGridWidth = leftGridWidth;
        } else {
          this._leftGridWidth = columnWidth * fixedColumnCount;
        }
      }

      return this._leftGridWidth;
    }
  }, {
    key: "_getRightGridWidth",
    value: function _getRightGridWidth(props) {
      var width = props.width;

      var leftGridWidth = this._getLeftGridWidth(props);

      return width - leftGridWidth;
    }
  }, {
    key: "_getTopGridHeight",
    value: function _getTopGridHeight(props) {
      var fixedRowCount = props.fixedRowCount,
          rowHeight = props.rowHeight;

      if (this._topGridHeight == null) {
        if (typeof rowHeight === 'function') {
          var topGridHeight = 0;

          for (var index = 0; index < fixedRowCount; index++) {
            topGridHeight += rowHeight({
              index: index
            });
          }

          this._topGridHeight = topGridHeight;
        } else {
          this._topGridHeight = rowHeight * fixedRowCount;
        }
      }

      return this._topGridHeight;
    }
  }, {
    key: "_handleInvalidatedGridSize",
    value: function _handleInvalidatedGridSize() {
      if (typeof this._deferredInvalidateColumnIndex === 'number') {
        var columnIndex = this._deferredInvalidateColumnIndex;
        var rowIndex = this._deferredInvalidateRowIndex;
        this._deferredInvalidateColumnIndex = null;
        this._deferredInvalidateRowIndex = null;
        this.recomputeGridSize({
          columnIndex: columnIndex,
          rowIndex: rowIndex
        });
        this.forceUpdate();
      }
    }
    /**
     * Avoid recreating inline styles each render; this bypasses Grid's shallowCompare.
     * This method recalculates styles only when specific props change.
     */

  }, {
    key: "_maybeCalculateCachedStyles",
    value: function _maybeCalculateCachedStyles(resetAll) {
      var _this$props9 = this.props,
          columnWidth = _this$props9.columnWidth,
          enableFixedColumnScroll = _this$props9.enableFixedColumnScroll,
          enableFixedRowScroll = _this$props9.enableFixedRowScroll,
          height = _this$props9.height,
          fixedColumnCount = _this$props9.fixedColumnCount,
          fixedRowCount = _this$props9.fixedRowCount,
          rowHeight = _this$props9.rowHeight,
          style = _this$props9.style,
          styleBottomLeftGrid = _this$props9.styleBottomLeftGrid,
          styleBottomRightGrid = _this$props9.styleBottomRightGrid,
          styleTopLeftGrid = _this$props9.styleTopLeftGrid,
          styleTopRightGrid = _this$props9.styleTopRightGrid,
          width = _this$props9.width;
      var sizeChange = resetAll || height !== this._lastRenderedHeight || width !== this._lastRenderedWidth;
      var leftSizeChange = resetAll || columnWidth !== this._lastRenderedColumnWidth || fixedColumnCount !== this._lastRenderedFixedColumnCount;
      var topSizeChange = resetAll || fixedRowCount !== this._lastRenderedFixedRowCount || rowHeight !== this._lastRenderedRowHeight;

      if (resetAll || sizeChange || style !== this._lastRenderedStyle) {
        this._containerOuterStyle = _objectSpread({
          height: height,
          overflow: 'visible',
          // Let :focus outline show through
          width: width
        }, style);
      }

      if (resetAll || sizeChange || topSizeChange) {
        this._containerTopStyle = {
          height: this._getTopGridHeight(this.props),
          position: 'relative',
          width: width
        };
        this._containerBottomStyle = {
          height: height - this._getTopGridHeight(this.props),
          overflow: 'visible',
          // Let :focus outline show through
          position: 'relative',
          width: width
        };
      }

      if (resetAll || styleBottomLeftGrid !== this._lastRenderedStyleBottomLeftGrid) {
        this._bottomLeftGridStyle = _objectSpread({
          left: 0,
          overflowX: 'hidden',
          overflowY: enableFixedColumnScroll ? 'auto' : 'hidden',
          position: 'absolute'
        }, styleBottomLeftGrid);
      }

      if (resetAll || leftSizeChange || styleBottomRightGrid !== this._lastRenderedStyleBottomRightGrid) {
        this._bottomRightGridStyle = _objectSpread({
          left: this._getLeftGridWidth(this.props),
          position: 'absolute'
        }, styleBottomRightGrid);
      }

      if (resetAll || styleTopLeftGrid !== this._lastRenderedStyleTopLeftGrid) {
        this._topLeftGridStyle = _objectSpread({
          left: 0,
          overflowX: 'hidden',
          overflowY: 'hidden',
          position: 'absolute',
          top: 0
        }, styleTopLeftGrid);
      }

      if (resetAll || leftSizeChange || styleTopRightGrid !== this._lastRenderedStyleTopRightGrid) {
        this._topRightGridStyle = _objectSpread({
          left: this._getLeftGridWidth(this.props),
          overflowX: enableFixedRowScroll ? 'auto' : 'hidden',
          overflowY: 'hidden',
          position: 'absolute',
          top: 0
        }, styleTopRightGrid);
      }

      this._lastRenderedColumnWidth = columnWidth;
      this._lastRenderedFixedColumnCount = fixedColumnCount;
      this._lastRenderedFixedRowCount = fixedRowCount;
      this._lastRenderedHeight = height;
      this._lastRenderedRowHeight = rowHeight;
      this._lastRenderedStyle = style;
      this._lastRenderedStyleBottomLeftGrid = styleBottomLeftGrid;
      this._lastRenderedStyleBottomRightGrid = styleBottomRightGrid;
      this._lastRenderedStyleTopLeftGrid = styleTopLeftGrid;
      this._lastRenderedStyleTopRightGrid = styleTopRightGrid;
      this._lastRenderedWidth = width;
    }
  }, {
    key: "_prepareForRender",
    value: function _prepareForRender() {
      if (this._lastRenderedColumnWidth !== this.props.columnWidth || this._lastRenderedFixedColumnCount !== this.props.fixedColumnCount) {
        this._leftGridWidth = null;
      }

      if (this._lastRenderedFixedRowCount !== this.props.fixedRowCount || this._lastRenderedRowHeight !== this.props.rowHeight) {
        this._topGridHeight = null;
      }

      this._maybeCalculateCachedStyles();

      this._lastRenderedColumnWidth = this.props.columnWidth;
      this._lastRenderedFixedColumnCount = this.props.fixedColumnCount;
      this._lastRenderedFixedRowCount = this.props.fixedRowCount;
      this._lastRenderedRowHeight = this.props.rowHeight;
    }
  }, {
    key: "_renderBottomLeftGrid",
    value: function _renderBottomLeftGrid(props) {
      var enableFixedColumnScroll = props.enableFixedColumnScroll,
          fixedColumnCount = props.fixedColumnCount,
          fixedRowCount = props.fixedRowCount,
          rowCount = props.rowCount,
          hideBottomLeftGridScrollbar = props.hideBottomLeftGridScrollbar;
      var showVerticalScrollbar = this.state.showVerticalScrollbar;

      if (!fixedColumnCount) {
        return null;
      }

      var additionalRowCount = showVerticalScrollbar ? 1 : 0,
          height = this._getBottomGridHeight(props),
          width = this._getLeftGridWidth(props),
          scrollbarSize = this.state.showVerticalScrollbar ? this.state.scrollbarSize : 0,
          gridWidth = hideBottomLeftGridScrollbar ? width + scrollbarSize : width;

      var bottomLeftGrid = react__WEBPACK_IMPORTED_MODULE_9__.createElement(_Grid__WEBPACK_IMPORTED_MODULE_12__["default"], (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, props, {
        cellRenderer: this._cellRendererBottomLeftGrid,
        className: this.props.classNameBottomLeftGrid,
        columnCount: fixedColumnCount,
        deferredMeasurementCache: this._deferredMeasurementCacheBottomLeftGrid,
        height: height,
        onScroll: enableFixedColumnScroll ? this._onScrollTop : undefined,
        ref: this._bottomLeftGridRef,
        rowCount: Math.max(0, rowCount - fixedRowCount) + additionalRowCount,
        rowHeight: this._rowHeightBottomGrid,
        style: this._bottomLeftGridStyle,
        tabIndex: null,
        width: gridWidth
      }));

      if (hideBottomLeftGridScrollbar) {
        return react__WEBPACK_IMPORTED_MODULE_9__.createElement("div", {
          className: "BottomLeftGrid_ScrollWrapper",
          style: _objectSpread({}, this._bottomLeftGridStyle, {
            height: height,
            width: width,
            overflowY: 'hidden'
          })
        }, bottomLeftGrid);
      }

      return bottomLeftGrid;
    }
  }, {
    key: "_renderBottomRightGrid",
    value: function _renderBottomRightGrid(props) {
      var columnCount = props.columnCount,
          fixedColumnCount = props.fixedColumnCount,
          fixedRowCount = props.fixedRowCount,
          rowCount = props.rowCount,
          scrollToColumn = props.scrollToColumn,
          scrollToRow = props.scrollToRow;
      return react__WEBPACK_IMPORTED_MODULE_9__.createElement(_Grid__WEBPACK_IMPORTED_MODULE_12__["default"], (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, props, {
        cellRenderer: this._cellRendererBottomRightGrid,
        className: this.props.classNameBottomRightGrid,
        columnCount: Math.max(0, columnCount - fixedColumnCount),
        columnWidth: this._columnWidthRightGrid,
        deferredMeasurementCache: this._deferredMeasurementCacheBottomRightGrid,
        height: this._getBottomGridHeight(props),
        onScroll: this._onScroll,
        onScrollbarPresenceChange: this._onScrollbarPresenceChange,
        ref: this._bottomRightGridRef,
        rowCount: Math.max(0, rowCount - fixedRowCount),
        rowHeight: this._rowHeightBottomGrid,
        scrollToColumn: scrollToColumn - fixedColumnCount,
        scrollToRow: scrollToRow - fixedRowCount,
        style: this._bottomRightGridStyle,
        width: this._getRightGridWidth(props)
      }));
    }
  }, {
    key: "_renderTopLeftGrid",
    value: function _renderTopLeftGrid(props) {
      var fixedColumnCount = props.fixedColumnCount,
          fixedRowCount = props.fixedRowCount;

      if (!fixedColumnCount || !fixedRowCount) {
        return null;
      }

      return react__WEBPACK_IMPORTED_MODULE_9__.createElement(_Grid__WEBPACK_IMPORTED_MODULE_12__["default"], (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, props, {
        className: this.props.classNameTopLeftGrid,
        columnCount: fixedColumnCount,
        height: this._getTopGridHeight(props),
        ref: this._topLeftGridRef,
        rowCount: fixedRowCount,
        style: this._topLeftGridStyle,
        tabIndex: null,
        width: this._getLeftGridWidth(props)
      }));
    }
  }, {
    key: "_renderTopRightGrid",
    value: function _renderTopRightGrid(props) {
      var columnCount = props.columnCount,
          enableFixedRowScroll = props.enableFixedRowScroll,
          fixedColumnCount = props.fixedColumnCount,
          fixedRowCount = props.fixedRowCount,
          scrollLeft = props.scrollLeft,
          hideTopRightGridScrollbar = props.hideTopRightGridScrollbar;
      var _this$state5 = this.state,
          showHorizontalScrollbar = _this$state5.showHorizontalScrollbar,
          scrollbarSize = _this$state5.scrollbarSize;

      if (!fixedRowCount) {
        return null;
      }

      var additionalColumnCount = showHorizontalScrollbar ? 1 : 0,
          height = this._getTopGridHeight(props),
          width = this._getRightGridWidth(props),
          additionalHeight = showHorizontalScrollbar ? scrollbarSize : 0;

      var gridHeight = height,
          style = this._topRightGridStyle;

      if (hideTopRightGridScrollbar) {
        gridHeight = height + additionalHeight;
        style = _objectSpread({}, this._topRightGridStyle, {
          left: 0
        });
      }

      var topRightGrid = react__WEBPACK_IMPORTED_MODULE_9__.createElement(_Grid__WEBPACK_IMPORTED_MODULE_12__["default"], (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, props, {
        cellRenderer: this._cellRendererTopRightGrid,
        className: this.props.classNameTopRightGrid,
        columnCount: Math.max(0, columnCount - fixedColumnCount) + additionalColumnCount,
        columnWidth: this._columnWidthRightGrid,
        deferredMeasurementCache: this._deferredMeasurementCacheTopRightGrid,
        height: gridHeight,
        onScroll: enableFixedRowScroll ? this._onScrollLeft : undefined,
        ref: this._topRightGridRef,
        rowCount: fixedRowCount,
        scrollLeft: scrollLeft,
        style: style,
        tabIndex: null,
        width: width
      }));

      if (hideTopRightGridScrollbar) {
        return react__WEBPACK_IMPORTED_MODULE_9__.createElement("div", {
          className: "TopRightGrid_ScrollWrapper",
          style: _objectSpread({}, this._topRightGridStyle, {
            height: height,
            width: width,
            overflowX: 'hidden'
          })
        }, topRightGrid);
      }

      return topRightGrid;
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(nextProps, prevState) {
      if (nextProps.scrollLeft !== prevState.scrollLeft || nextProps.scrollTop !== prevState.scrollTop) {
        return {
          scrollLeft: nextProps.scrollLeft != null && nextProps.scrollLeft >= 0 ? nextProps.scrollLeft : prevState.scrollLeft,
          scrollTop: nextProps.scrollTop != null && nextProps.scrollTop >= 0 ? nextProps.scrollTop : prevState.scrollTop
        };
      }

      return null;
    }
  }]);

  return MultiGrid;
}(react__WEBPACK_IMPORTED_MODULE_9__.PureComponent);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__["default"])(MultiGrid, "defaultProps", {
  classNameBottomLeftGrid: '',
  classNameBottomRightGrid: '',
  classNameTopLeftGrid: '',
  classNameTopRightGrid: '',
  enableFixedColumnScroll: false,
  enableFixedRowScroll: false,
  fixedColumnCount: 0,
  fixedRowCount: 0,
  scrollToColumn: -1,
  scrollToRow: -1,
  style: {},
  styleBottomLeftGrid: {},
  styleBottomRightGrid: {},
  styleTopLeftGrid: {},
  styleTopRightGrid: {},
  hideTopRightGridScrollbar: false,
  hideBottomLeftGridScrollbar: false
});

MultiGrid.propTypes =  true ? {
  classNameBottomLeftGrid: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().string.isRequired),
  classNameBottomRightGrid: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().string.isRequired),
  classNameTopLeftGrid: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().string.isRequired),
  classNameTopRightGrid: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().string.isRequired),
  enableFixedColumnScroll: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().bool.isRequired),
  enableFixedRowScroll: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().bool.isRequired),
  fixedColumnCount: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().number.isRequired),
  fixedRowCount: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().number.isRequired),
  onScrollbarPresenceChange: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().func),
  style: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().object.isRequired),
  styleBottomLeftGrid: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().object.isRequired),
  styleBottomRightGrid: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().object.isRequired),
  styleTopLeftGrid: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().object.isRequired),
  styleTopRightGrid: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().object.isRequired),
  hideTopRightGridScrollbar: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().bool),
  hideBottomLeftGridScrollbar: (prop_types__WEBPACK_IMPORTED_MODULE_13___default().bool)
} : 0;
(0,react_lifecycles_compat__WEBPACK_IMPORTED_MODULE_10__.polyfill)(MultiGrid);
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (MultiGrid);

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/MultiGrid/index.js":
/*!***********************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/MultiGrid/index.js ***!
  \***********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "MultiGrid": () => (/* reexport safe */ _MultiGrid__WEBPACK_IMPORTED_MODULE_0__["default"]),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _MultiGrid__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./MultiGrid */ "../../node_modules/react-virtualized/dist/es/MultiGrid/MultiGrid.js");

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_MultiGrid__WEBPACK_IMPORTED_MODULE_0__["default"]);


/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/ScrollSync/ScrollSync.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/ScrollSync/ScrollSync.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ ScrollSync)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_7__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_6__);








/**
 * HOC that simplifies the process of synchronizing scrolling between two or more virtualized components.
 */

var ScrollSync =
/*#__PURE__*/
function (_React$PureComponent) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(ScrollSync, _React$PureComponent);

  function ScrollSync(props, context) {
    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, ScrollSync);

    _this = (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__["default"])(this, (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(ScrollSync).call(this, props, context));
    _this.state = {
      clientHeight: 0,
      clientWidth: 0,
      scrollHeight: 0,
      scrollLeft: 0,
      scrollTop: 0,
      scrollWidth: 0
    };
    _this._onScroll = _this._onScroll.bind((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this));
    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(ScrollSync, [{
    key: "render",
    value: function render() {
      var children = this.props.children;
      var _this$state = this.state,
          clientHeight = _this$state.clientHeight,
          clientWidth = _this$state.clientWidth,
          scrollHeight = _this$state.scrollHeight,
          scrollLeft = _this$state.scrollLeft,
          scrollTop = _this$state.scrollTop,
          scrollWidth = _this$state.scrollWidth;
      return children({
        clientHeight: clientHeight,
        clientWidth: clientWidth,
        onScroll: this._onScroll,
        scrollHeight: scrollHeight,
        scrollLeft: scrollLeft,
        scrollTop: scrollTop,
        scrollWidth: scrollWidth
      });
    }
  }, {
    key: "_onScroll",
    value: function _onScroll(_ref) {
      var clientHeight = _ref.clientHeight,
          clientWidth = _ref.clientWidth,
          scrollHeight = _ref.scrollHeight,
          scrollLeft = _ref.scrollLeft,
          scrollTop = _ref.scrollTop,
          scrollWidth = _ref.scrollWidth;
      this.setState({
        clientHeight: clientHeight,
        clientWidth: clientWidth,
        scrollHeight: scrollHeight,
        scrollLeft: scrollLeft,
        scrollTop: scrollTop,
        scrollWidth: scrollWidth
      });
    }
  }]);

  return ScrollSync;
}(react__WEBPACK_IMPORTED_MODULE_6__.PureComponent);


ScrollSync.propTypes =  true ? {
  /**
   * Function responsible for rendering 2 or more virtualized components.
   * This function should implement the following signature:
   * ({ onScroll, scrollLeft, scrollTop }) => PropTypes.element
   */
  children: (prop_types__WEBPACK_IMPORTED_MODULE_7___default().func.isRequired)
} : 0;

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/ScrollSync/index.js":
/*!************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/ScrollSync/index.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "ScrollSync": () => (/* reexport safe */ _ScrollSync__WEBPACK_IMPORTED_MODULE_0__["default"]),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _ScrollSync__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./ScrollSync */ "../../node_modules/react-virtualized/dist/es/ScrollSync/ScrollSync.js");

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_ScrollSync__WEBPACK_IMPORTED_MODULE_0__["default"]);


/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Table/Column.js":
/*!********************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Table/Column.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ Column)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_10___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_10__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var _defaultHeaderRenderer__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./defaultHeaderRenderer */ "../../node_modules/react-virtualized/dist/es/Table/defaultHeaderRenderer.js");
/* harmony import */ var _defaultCellRenderer__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./defaultCellRenderer */ "../../node_modules/react-virtualized/dist/es/Table/defaultCellRenderer.js");
/* harmony import */ var _defaultCellDataGetter__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./defaultCellDataGetter */ "../../node_modules/react-virtualized/dist/es/Table/defaultCellDataGetter.js");
/* harmony import */ var _SortDirection__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./SortDirection */ "../../node_modules/react-virtualized/dist/es/Table/SortDirection.js");











/**
 * Describes the header and cell contents of a table column.
 */

var Column =
/*#__PURE__*/
function (_React$Component) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(Column, _React$Component);

  function Column() {
    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, Column);

    return (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_1__["default"])(this, (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_2__["default"])(Column).apply(this, arguments));
  }

  return Column;
}(react__WEBPACK_IMPORTED_MODULE_5__.Component);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_4__["default"])(Column, "defaultProps", {
  cellDataGetter: _defaultCellDataGetter__WEBPACK_IMPORTED_MODULE_8__["default"],
  cellRenderer: _defaultCellRenderer__WEBPACK_IMPORTED_MODULE_7__["default"],
  defaultSortDirection: _SortDirection__WEBPACK_IMPORTED_MODULE_9__["default"].ASC,
  flexGrow: 0,
  flexShrink: 1,
  headerRenderer: _defaultHeaderRenderer__WEBPACK_IMPORTED_MODULE_6__["default"],
  style: {}
});


Column.propTypes =  true ? {
  /** Optional aria-label value to set on the column header */
  'aria-label': (prop_types__WEBPACK_IMPORTED_MODULE_10___default().string),

  /**
   * Callback responsible for returning a cell's data, given its :dataKey
   * ({ columnData: any, dataKey: string, rowData: any }): any
   */
  cellDataGetter: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().func),

  /**
   * Callback responsible for rendering a cell's contents.
   * ({ cellData: any, columnData: any, dataKey: string, rowData: any, rowIndex: number }): node
   */
  cellRenderer: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().func),

  /** Optional CSS class to apply to cell */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().string),

  /** Optional additional data passed to this column's :cellDataGetter */
  columnData: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().object),

  /** Uniquely identifies the row-data attribute corresponding to this cell */
  dataKey: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().any.isRequired),

  /** Optional direction to be used when clicked the first time */
  defaultSortDirection: prop_types__WEBPACK_IMPORTED_MODULE_10___default().oneOf([_SortDirection__WEBPACK_IMPORTED_MODULE_9__["default"].ASC, _SortDirection__WEBPACK_IMPORTED_MODULE_9__["default"].DESC]),

  /** If sort is enabled for the table at large, disable it for this column */
  disableSort: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().bool),

  /** Flex grow style; defaults to 0 */
  flexGrow: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().number),

  /** Flex shrink style; defaults to 1 */
  flexShrink: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().number),

  /** Optional CSS class to apply to this column's header */
  headerClassName: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().string),

  /**
   * Optional callback responsible for rendering a column header contents.
   * ({ columnData: object, dataKey: string, disableSort: boolean, label: node, sortBy: string, sortDirection: string }): PropTypes.node
   */
  headerRenderer: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().func.isRequired),

  /** Optional inline style to apply to this column's header */
  headerStyle: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().object),

  /** Optional id to set on the column header */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().string),

  /** Header label for this column */
  label: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().node),

  /** Maximum width of column; this property will only be used if :flexGrow is > 0. */
  maxWidth: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().number),

  /** Minimum width of column. */
  minWidth: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().number),

  /** Optional inline style to apply to cell */
  style: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().object),

  /** Flex basis (width) for this column; This value can grow or shrink based on :flexGrow and :flexShrink properties. */
  width: (prop_types__WEBPACK_IMPORTED_MODULE_10___default().number.isRequired)
} : 0;

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Table/SortDirection.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Table/SortDirection.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
var SortDirection = {
  /**
   * Sort items in ascending order.
   * This means arranging from the lowest value to the highest (e.g. a-z, 0-9).
   */
  ASC: 'ASC',

  /**
   * Sort items in descending order.
   * This means arranging from the highest value to the lowest (e.g. z-a, 9-0).
   */
  DESC: 'DESC'
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (SortDirection);

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Table/SortIndicator.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Table/SortIndicator.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ SortIndicator)
/* harmony export */ });
/* harmony import */ var clsx__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! clsx */ "../../node_modules/clsx/dist/clsx.m.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _SortDirection__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./SortDirection */ "../../node_modules/react-virtualized/dist/es/Table/SortDirection.js");




/**
 * Displayed beside a header to indicate that a Table is currently sorted by this column.
 */

function SortIndicator(_ref) {
  var sortDirection = _ref.sortDirection;
  var classNames = (0,clsx__WEBPACK_IMPORTED_MODULE_0__["default"])('ReactVirtualized__Table__sortableHeaderIcon', {
    'ReactVirtualized__Table__sortableHeaderIcon--ASC': sortDirection === _SortDirection__WEBPACK_IMPORTED_MODULE_2__["default"].ASC,
    'ReactVirtualized__Table__sortableHeaderIcon--DESC': sortDirection === _SortDirection__WEBPACK_IMPORTED_MODULE_2__["default"].DESC
  });
  return react__WEBPACK_IMPORTED_MODULE_1__.createElement("svg", {
    className: classNames,
    width: 18,
    height: 18,
    viewBox: "0 0 24 24"
  }, sortDirection === _SortDirection__WEBPACK_IMPORTED_MODULE_2__["default"].ASC ? react__WEBPACK_IMPORTED_MODULE_1__.createElement("path", {
    d: "M7 14l5-5 5 5z"
  }) : react__WEBPACK_IMPORTED_MODULE_1__.createElement("path", {
    d: "M7 10l5 5 5-5z"
  }), react__WEBPACK_IMPORTED_MODULE_1__.createElement("path", {
    d: "M0 0h24v24H0z",
    fill: "none"
  }));
}
SortIndicator.propTypes =  true ? {
  sortDirection: prop_types__WEBPACK_IMPORTED_MODULE_3___default().oneOf([_SortDirection__WEBPACK_IMPORTED_MODULE_2__["default"].ASC, _SortDirection__WEBPACK_IMPORTED_MODULE_2__["default"].DESC])
} : 0;

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Table/Table.js":
/*!*******************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Table/Table.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ Table)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var clsx__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! clsx */ "../../node_modules/clsx/dist/clsx.m.js");
/* harmony import */ var _Column__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./Column */ "../../node_modules/react-virtualized/dist/es/Table/Column.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_16___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_16__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_10___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_10__);
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! react-dom */ "webpack/sharing/consume/default/react-dom");
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_11___default = /*#__PURE__*/__webpack_require__.n(react_dom__WEBPACK_IMPORTED_MODULE_11__);
/* harmony import */ var _Grid__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../Grid */ "../../node_modules/react-virtualized/dist/es/Grid/index.js");
/* harmony import */ var _defaultRowRenderer__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./defaultRowRenderer */ "../../node_modules/react-virtualized/dist/es/Table/defaultRowRenderer.js");
/* harmony import */ var _defaultHeaderRowRenderer__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./defaultHeaderRowRenderer */ "../../node_modules/react-virtualized/dist/es/Table/defaultHeaderRowRenderer.js");
/* harmony import */ var _SortDirection__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./SortDirection */ "../../node_modules/react-virtualized/dist/es/Table/SortDirection.js");









function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }










/**
 * Table component with fixed headers and virtualized rows for improved performance with large data sets.
 * This component expects explicit width, height, and padding parameters.
 */

var Table =
/*#__PURE__*/
function (_React$PureComponent) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_6__["default"])(Table, _React$PureComponent);

  function Table(props) {
    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_1__["default"])(this, Table);

    _this = (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_3__["default"])(this, (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_4__["default"])(Table).call(this, props));
    _this.state = {
      scrollbarWidth: 0
    };
    _this._createColumn = _this._createColumn.bind((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this));
    _this._createRow = _this._createRow.bind((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this));
    _this._onScroll = _this._onScroll.bind((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this));
    _this._onSectionRendered = _this._onSectionRendered.bind((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this));
    _this._setRef = _this._setRef.bind((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this));
    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(Table, [{
    key: "forceUpdateGrid",
    value: function forceUpdateGrid() {
      if (this.Grid) {
        this.Grid.forceUpdate();
      }
    }
    /** See Grid#getOffsetForCell */

  }, {
    key: "getOffsetForRow",
    value: function getOffsetForRow(_ref) {
      var alignment = _ref.alignment,
          index = _ref.index;

      if (this.Grid) {
        var _this$Grid$getOffsetF = this.Grid.getOffsetForCell({
          alignment: alignment,
          rowIndex: index
        }),
            scrollTop = _this$Grid$getOffsetF.scrollTop;

        return scrollTop;
      }

      return 0;
    }
    /** CellMeasurer compatibility */

  }, {
    key: "invalidateCellSizeAfterRender",
    value: function invalidateCellSizeAfterRender(_ref2) {
      var columnIndex = _ref2.columnIndex,
          rowIndex = _ref2.rowIndex;

      if (this.Grid) {
        this.Grid.invalidateCellSizeAfterRender({
          rowIndex: rowIndex,
          columnIndex: columnIndex
        });
      }
    }
    /** See Grid#measureAllCells */

  }, {
    key: "measureAllRows",
    value: function measureAllRows() {
      if (this.Grid) {
        this.Grid.measureAllCells();
      }
    }
    /** CellMeasurer compatibility */

  }, {
    key: "recomputeGridSize",
    value: function recomputeGridSize() {
      var _ref3 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
          _ref3$columnIndex = _ref3.columnIndex,
          columnIndex = _ref3$columnIndex === void 0 ? 0 : _ref3$columnIndex,
          _ref3$rowIndex = _ref3.rowIndex,
          rowIndex = _ref3$rowIndex === void 0 ? 0 : _ref3$rowIndex;

      if (this.Grid) {
        this.Grid.recomputeGridSize({
          rowIndex: rowIndex,
          columnIndex: columnIndex
        });
      }
    }
    /** See Grid#recomputeGridSize */

  }, {
    key: "recomputeRowHeights",
    value: function recomputeRowHeights() {
      var index = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;

      if (this.Grid) {
        this.Grid.recomputeGridSize({
          rowIndex: index
        });
      }
    }
    /** See Grid#scrollToPosition */

  }, {
    key: "scrollToPosition",
    value: function scrollToPosition() {
      var scrollTop = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;

      if (this.Grid) {
        this.Grid.scrollToPosition({
          scrollTop: scrollTop
        });
      }
    }
    /** See Grid#scrollToCell */

  }, {
    key: "scrollToRow",
    value: function scrollToRow() {
      var index = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;

      if (this.Grid) {
        this.Grid.scrollToCell({
          columnIndex: 0,
          rowIndex: index
        });
      }
    }
  }, {
    key: "getScrollbarWidth",
    value: function getScrollbarWidth() {
      if (this.Grid) {
        var _Grid = (0,react_dom__WEBPACK_IMPORTED_MODULE_11__.findDOMNode)(this.Grid);

        var clientWidth = _Grid.clientWidth || 0;
        var offsetWidth = _Grid.offsetWidth || 0;
        return offsetWidth - clientWidth;
      }

      return 0;
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this._setScrollbarWidth();
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      this._setScrollbarWidth();
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          children = _this$props.children,
          className = _this$props.className,
          disableHeader = _this$props.disableHeader,
          gridClassName = _this$props.gridClassName,
          gridStyle = _this$props.gridStyle,
          headerHeight = _this$props.headerHeight,
          headerRowRenderer = _this$props.headerRowRenderer,
          height = _this$props.height,
          id = _this$props.id,
          noRowsRenderer = _this$props.noRowsRenderer,
          rowClassName = _this$props.rowClassName,
          rowStyle = _this$props.rowStyle,
          scrollToIndex = _this$props.scrollToIndex,
          style = _this$props.style,
          width = _this$props.width;
      var scrollbarWidth = this.state.scrollbarWidth;
      var availableRowsHeight = disableHeader ? height : height - headerHeight;
      var rowClass = typeof rowClassName === 'function' ? rowClassName({
        index: -1
      }) : rowClassName;
      var rowStyleObject = typeof rowStyle === 'function' ? rowStyle({
        index: -1
      }) : rowStyle; // Precompute and cache column styles before rendering rows and columns to speed things up

      this._cachedColumnStyles = [];
      react__WEBPACK_IMPORTED_MODULE_10__.Children.toArray(children).forEach(function (column, index) {
        var flexStyles = _this2._getFlexStyleForColumn(column, column.props.style);

        _this2._cachedColumnStyles[index] = _objectSpread({
          overflow: 'hidden'
        }, flexStyles);
      }); // Note that we specify :rowCount, :scrollbarWidth, :sortBy, and :sortDirection as properties on Grid even though these have nothing to do with Grid.
      // This is done because Grid is a pure component and won't update unless its properties or state has changed.
      // Any property that should trigger a re-render of Grid then is specified here to avoid a stale display.

      return react__WEBPACK_IMPORTED_MODULE_10__.createElement("div", {
        "aria-label": this.props['aria-label'],
        "aria-labelledby": this.props['aria-labelledby'],
        "aria-colcount": react__WEBPACK_IMPORTED_MODULE_10__.Children.toArray(children).length,
        "aria-rowcount": this.props.rowCount,
        className: (0,clsx__WEBPACK_IMPORTED_MODULE_8__["default"])('ReactVirtualized__Table', className),
        id: id,
        role: "grid",
        style: style
      }, !disableHeader && headerRowRenderer({
        className: (0,clsx__WEBPACK_IMPORTED_MODULE_8__["default"])('ReactVirtualized__Table__headerRow', rowClass),
        columns: this._getHeaderColumns(),
        style: _objectSpread({
          height: headerHeight,
          overflow: 'hidden',
          paddingRight: scrollbarWidth,
          width: width
        }, rowStyleObject)
      }), react__WEBPACK_IMPORTED_MODULE_10__.createElement(_Grid__WEBPACK_IMPORTED_MODULE_12__["default"], (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, this.props, {
        "aria-readonly": null,
        autoContainerWidth: true,
        className: (0,clsx__WEBPACK_IMPORTED_MODULE_8__["default"])('ReactVirtualized__Table__Grid', gridClassName),
        cellRenderer: this._createRow,
        columnWidth: width,
        columnCount: 1,
        height: availableRowsHeight,
        id: undefined,
        noContentRenderer: noRowsRenderer,
        onScroll: this._onScroll,
        onSectionRendered: this._onSectionRendered,
        ref: this._setRef,
        role: "rowgroup",
        scrollbarWidth: scrollbarWidth,
        scrollToRow: scrollToIndex,
        style: _objectSpread({}, gridStyle, {
          overflowX: 'hidden'
        })
      })));
    }
  }, {
    key: "_createColumn",
    value: function _createColumn(_ref4) {
      var column = _ref4.column,
          columnIndex = _ref4.columnIndex,
          isScrolling = _ref4.isScrolling,
          parent = _ref4.parent,
          rowData = _ref4.rowData,
          rowIndex = _ref4.rowIndex;
      var onColumnClick = this.props.onColumnClick;
      var _column$props = column.props,
          cellDataGetter = _column$props.cellDataGetter,
          cellRenderer = _column$props.cellRenderer,
          className = _column$props.className,
          columnData = _column$props.columnData,
          dataKey = _column$props.dataKey,
          id = _column$props.id;
      var cellData = cellDataGetter({
        columnData: columnData,
        dataKey: dataKey,
        rowData: rowData
      });
      var renderedCell = cellRenderer({
        cellData: cellData,
        columnData: columnData,
        columnIndex: columnIndex,
        dataKey: dataKey,
        isScrolling: isScrolling,
        parent: parent,
        rowData: rowData,
        rowIndex: rowIndex
      });

      var onClick = function onClick(event) {
        onColumnClick && onColumnClick({
          columnData: columnData,
          dataKey: dataKey,
          event: event
        });
      };

      var style = this._cachedColumnStyles[columnIndex];
      var title = typeof renderedCell === 'string' ? renderedCell : null; // Avoid using object-spread syntax with multiple objects here,
      // Since it results in an extra method call to 'babel-runtime/helpers/extends'
      // See PR https://github.com/bvaughn/react-virtualized/pull/942

      return react__WEBPACK_IMPORTED_MODULE_10__.createElement("div", {
        "aria-colindex": columnIndex + 1,
        "aria-describedby": id,
        className: (0,clsx__WEBPACK_IMPORTED_MODULE_8__["default"])('ReactVirtualized__Table__rowColumn', className),
        key: 'Row' + rowIndex + '-' + 'Col' + columnIndex,
        onClick: onClick,
        role: "gridcell",
        style: style,
        title: title
      }, renderedCell);
    }
  }, {
    key: "_createHeader",
    value: function _createHeader(_ref5) {
      var column = _ref5.column,
          index = _ref5.index;
      var _this$props2 = this.props,
          headerClassName = _this$props2.headerClassName,
          headerStyle = _this$props2.headerStyle,
          onHeaderClick = _this$props2.onHeaderClick,
          sort = _this$props2.sort,
          sortBy = _this$props2.sortBy,
          sortDirection = _this$props2.sortDirection;
      var _column$props2 = column.props,
          columnData = _column$props2.columnData,
          dataKey = _column$props2.dataKey,
          defaultSortDirection = _column$props2.defaultSortDirection,
          disableSort = _column$props2.disableSort,
          headerRenderer = _column$props2.headerRenderer,
          id = _column$props2.id,
          label = _column$props2.label;
      var sortEnabled = !disableSort && sort;
      var classNames = (0,clsx__WEBPACK_IMPORTED_MODULE_8__["default"])('ReactVirtualized__Table__headerColumn', headerClassName, column.props.headerClassName, {
        ReactVirtualized__Table__sortableHeaderColumn: sortEnabled
      });

      var style = this._getFlexStyleForColumn(column, _objectSpread({}, headerStyle, {}, column.props.headerStyle));

      var renderedHeader = headerRenderer({
        columnData: columnData,
        dataKey: dataKey,
        disableSort: disableSort,
        label: label,
        sortBy: sortBy,
        sortDirection: sortDirection
      });
      var headerOnClick, headerOnKeyDown, headerTabIndex, headerAriaSort, headerAriaLabel;

      if (sortEnabled || onHeaderClick) {
        // If this is a sortable header, clicking it should update the table data's sorting.
        var isFirstTimeSort = sortBy !== dataKey; // If this is the firstTime sort of this column, use the column default sort order.
        // Otherwise, invert the direction of the sort.

        var newSortDirection = isFirstTimeSort ? defaultSortDirection : sortDirection === _SortDirection__WEBPACK_IMPORTED_MODULE_15__["default"].DESC ? _SortDirection__WEBPACK_IMPORTED_MODULE_15__["default"].ASC : _SortDirection__WEBPACK_IMPORTED_MODULE_15__["default"].DESC;

        var onClick = function onClick(event) {
          sortEnabled && sort({
            defaultSortDirection: defaultSortDirection,
            event: event,
            sortBy: dataKey,
            sortDirection: newSortDirection
          });
          onHeaderClick && onHeaderClick({
            columnData: columnData,
            dataKey: dataKey,
            event: event
          });
        };

        var onKeyDown = function onKeyDown(event) {
          if (event.key === 'Enter' || event.key === ' ') {
            onClick(event);
          }
        };

        headerAriaLabel = column.props['aria-label'] || label || dataKey;
        headerAriaSort = 'none';
        headerTabIndex = 0;
        headerOnClick = onClick;
        headerOnKeyDown = onKeyDown;
      }

      if (sortBy === dataKey) {
        headerAriaSort = sortDirection === _SortDirection__WEBPACK_IMPORTED_MODULE_15__["default"].ASC ? 'ascending' : 'descending';
      } // Avoid using object-spread syntax with multiple objects here,
      // Since it results in an extra method call to 'babel-runtime/helpers/extends'
      // See PR https://github.com/bvaughn/react-virtualized/pull/942


      return react__WEBPACK_IMPORTED_MODULE_10__.createElement("div", {
        "aria-label": headerAriaLabel,
        "aria-sort": headerAriaSort,
        className: classNames,
        id: id,
        key: 'Header-Col' + index,
        onClick: headerOnClick,
        onKeyDown: headerOnKeyDown,
        role: "columnheader",
        style: style,
        tabIndex: headerTabIndex
      }, renderedHeader);
    }
  }, {
    key: "_createRow",
    value: function _createRow(_ref6) {
      var _this3 = this;

      var index = _ref6.rowIndex,
          isScrolling = _ref6.isScrolling,
          key = _ref6.key,
          parent = _ref6.parent,
          style = _ref6.style;
      var _this$props3 = this.props,
          children = _this$props3.children,
          onRowClick = _this$props3.onRowClick,
          onRowDoubleClick = _this$props3.onRowDoubleClick,
          onRowRightClick = _this$props3.onRowRightClick,
          onRowMouseOver = _this$props3.onRowMouseOver,
          onRowMouseOut = _this$props3.onRowMouseOut,
          rowClassName = _this$props3.rowClassName,
          rowGetter = _this$props3.rowGetter,
          rowRenderer = _this$props3.rowRenderer,
          rowStyle = _this$props3.rowStyle;
      var scrollbarWidth = this.state.scrollbarWidth;
      var rowClass = typeof rowClassName === 'function' ? rowClassName({
        index: index
      }) : rowClassName;
      var rowStyleObject = typeof rowStyle === 'function' ? rowStyle({
        index: index
      }) : rowStyle;
      var rowData = rowGetter({
        index: index
      });
      var columns = react__WEBPACK_IMPORTED_MODULE_10__.Children.toArray(children).map(function (column, columnIndex) {
        return _this3._createColumn({
          column: column,
          columnIndex: columnIndex,
          isScrolling: isScrolling,
          parent: parent,
          rowData: rowData,
          rowIndex: index,
          scrollbarWidth: scrollbarWidth
        });
      });
      var className = (0,clsx__WEBPACK_IMPORTED_MODULE_8__["default"])('ReactVirtualized__Table__row', rowClass);

      var flattenedStyle = _objectSpread({}, style, {
        height: this._getRowHeight(index),
        overflow: 'hidden',
        paddingRight: scrollbarWidth
      }, rowStyleObject);

      return rowRenderer({
        className: className,
        columns: columns,
        index: index,
        isScrolling: isScrolling,
        key: key,
        onRowClick: onRowClick,
        onRowDoubleClick: onRowDoubleClick,
        onRowRightClick: onRowRightClick,
        onRowMouseOver: onRowMouseOver,
        onRowMouseOut: onRowMouseOut,
        rowData: rowData,
        style: flattenedStyle
      });
    }
    /**
     * Determines the flex-shrink, flex-grow, and width values for a cell (header or column).
     */

  }, {
    key: "_getFlexStyleForColumn",
    value: function _getFlexStyleForColumn(column) {
      var customStyle = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var flexValue = "".concat(column.props.flexGrow, " ").concat(column.props.flexShrink, " ").concat(column.props.width, "px");

      var style = _objectSpread({}, customStyle, {
        flex: flexValue,
        msFlex: flexValue,
        WebkitFlex: flexValue
      });

      if (column.props.maxWidth) {
        style.maxWidth = column.props.maxWidth;
      }

      if (column.props.minWidth) {
        style.minWidth = column.props.minWidth;
      }

      return style;
    }
  }, {
    key: "_getHeaderColumns",
    value: function _getHeaderColumns() {
      var _this4 = this;

      var _this$props4 = this.props,
          children = _this$props4.children,
          disableHeader = _this$props4.disableHeader;
      var items = disableHeader ? [] : react__WEBPACK_IMPORTED_MODULE_10__.Children.toArray(children);
      return items.map(function (column, index) {
        return _this4._createHeader({
          column: column,
          index: index
        });
      });
    }
  }, {
    key: "_getRowHeight",
    value: function _getRowHeight(rowIndex) {
      var rowHeight = this.props.rowHeight;
      return typeof rowHeight === 'function' ? rowHeight({
        index: rowIndex
      }) : rowHeight;
    }
  }, {
    key: "_onScroll",
    value: function _onScroll(_ref7) {
      var clientHeight = _ref7.clientHeight,
          scrollHeight = _ref7.scrollHeight,
          scrollTop = _ref7.scrollTop;
      var onScroll = this.props.onScroll;
      onScroll({
        clientHeight: clientHeight,
        scrollHeight: scrollHeight,
        scrollTop: scrollTop
      });
    }
  }, {
    key: "_onSectionRendered",
    value: function _onSectionRendered(_ref8) {
      var rowOverscanStartIndex = _ref8.rowOverscanStartIndex,
          rowOverscanStopIndex = _ref8.rowOverscanStopIndex,
          rowStartIndex = _ref8.rowStartIndex,
          rowStopIndex = _ref8.rowStopIndex;
      var onRowsRendered = this.props.onRowsRendered;
      onRowsRendered({
        overscanStartIndex: rowOverscanStartIndex,
        overscanStopIndex: rowOverscanStopIndex,
        startIndex: rowStartIndex,
        stopIndex: rowStopIndex
      });
    }
  }, {
    key: "_setRef",
    value: function _setRef(ref) {
      this.Grid = ref;
    }
  }, {
    key: "_setScrollbarWidth",
    value: function _setScrollbarWidth() {
      var scrollbarWidth = this.getScrollbarWidth();
      this.setState({
        scrollbarWidth: scrollbarWidth
      });
    }
  }]);

  return Table;
}(react__WEBPACK_IMPORTED_MODULE_10__.PureComponent);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__["default"])(Table, "defaultProps", {
  disableHeader: false,
  estimatedRowSize: 30,
  headerHeight: 0,
  headerStyle: {},
  noRowsRenderer: function noRowsRenderer() {
    return null;
  },
  onRowsRendered: function onRowsRendered() {
    return null;
  },
  onScroll: function onScroll() {
    return null;
  },
  overscanIndicesGetter: _Grid__WEBPACK_IMPORTED_MODULE_12__.accessibilityOverscanIndicesGetter,
  overscanRowCount: 10,
  rowRenderer: _defaultRowRenderer__WEBPACK_IMPORTED_MODULE_13__["default"],
  headerRowRenderer: _defaultHeaderRowRenderer__WEBPACK_IMPORTED_MODULE_14__["default"],
  rowStyle: {},
  scrollToAlignment: 'auto',
  scrollToIndex: -1,
  style: {}
});


Table.propTypes =  true ? {
  /** This is just set on the grid top element. */
  'aria-label': (prop_types__WEBPACK_IMPORTED_MODULE_16___default().string),

  /** This is just set on the grid top element. */
  'aria-labelledby': (prop_types__WEBPACK_IMPORTED_MODULE_16___default().string),

  /**
   * Removes fixed height from the scrollingContainer so that the total height
   * of rows can stretch the window. Intended for use with WindowScroller
   */
  autoHeight: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().bool),

  /** One or more Columns describing the data displayed in this row */
  children: function children(props) {
    var children = react__WEBPACK_IMPORTED_MODULE_10__.Children.toArray(props.children);

    for (var i = 0; i < children.length; i++) {
      var childType = children[i].type;

      if (childType !== _Column__WEBPACK_IMPORTED_MODULE_9__["default"] && !(childType.prototype instanceof _Column__WEBPACK_IMPORTED_MODULE_9__["default"])) {
        return new Error('Table only accepts children of type Column');
      }
    }
  },

  /** Optional CSS class name */
  className: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().string),

  /** Disable rendering the header at all */
  disableHeader: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().bool),

  /**
   * Used to estimate the total height of a Table before all of its rows have actually been measured.
   * The estimated total height is adjusted as rows are rendered.
   */
  estimatedRowSize: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().number.isRequired),

  /** Optional custom CSS class name to attach to inner Grid element. */
  gridClassName: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().string),

  /** Optional inline style to attach to inner Grid element. */
  gridStyle: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().object),

  /** Optional CSS class to apply to all column headers */
  headerClassName: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().string),

  /** Fixed height of header row */
  headerHeight: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().number.isRequired),

  /**
   * Responsible for rendering a table row given an array of columns:
   * Should implement the following interface: ({
   *   className: string,
   *   columns: any[],
   *   style: any
   * }): PropTypes.node
   */
  headerRowRenderer: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),

  /** Optional custom inline style to attach to table header columns. */
  headerStyle: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().object),

  /** Fixed/available height for out DOM element */
  height: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().number.isRequired),

  /** Optional id */
  id: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().string),

  /** Optional renderer to be used in place of table body rows when rowCount is 0 */
  noRowsRenderer: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),

  /**
   * Optional callback when a column is clicked.
   * ({ columnData: any, dataKey: string }): void
   */
  onColumnClick: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),

  /**
   * Optional callback when a column's header is clicked.
   * ({ columnData: any, dataKey: string }): void
   */
  onHeaderClick: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),

  /**
   * Callback invoked when a user clicks on a table row.
   * ({ index: number }): void
   */
  onRowClick: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),

  /**
   * Callback invoked when a user double-clicks on a table row.
   * ({ index: number }): void
   */
  onRowDoubleClick: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),

  /**
   * Callback invoked when the mouse leaves a table row.
   * ({ index: number }): void
   */
  onRowMouseOut: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),

  /**
   * Callback invoked when a user moves the mouse over a table row.
   * ({ index: number }): void
   */
  onRowMouseOver: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),

  /**
   * Callback invoked when a user right-clicks on a table row.
   * ({ index: number }): void
   */
  onRowRightClick: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),

  /**
   * Callback invoked with information about the slice of rows that were just rendered.
   * ({ startIndex, stopIndex }): void
   */
  onRowsRendered: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),

  /**
   * Callback invoked whenever the scroll offset changes within the inner scrollable region.
   * This callback can be used to sync scrolling between lists, tables, or grids.
   * ({ clientHeight, scrollHeight, scrollTop }): void
   */
  onScroll: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func.isRequired),

  /** See Grid#overscanIndicesGetter */
  overscanIndicesGetter: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func.isRequired),

  /**
   * Number of rows to render above/below the visible bounds of the list.
   * These rows can help for smoother scrolling on touch devices.
   */
  overscanRowCount: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().number.isRequired),

  /**
   * Optional CSS class to apply to all table rows (including the header row).
   * This property can be a CSS class name (string) or a function that returns a class name.
   * If a function is provided its signature should be: ({ index: number }): string
   */
  rowClassName: prop_types__WEBPACK_IMPORTED_MODULE_16___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_16___default().string), (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func)]),

  /**
   * Callback responsible for returning a data row given an index.
   * ({ index: number }): any
   */
  rowGetter: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func.isRequired),

  /**
   * Either a fixed row height (number) or a function that returns the height of a row given its index.
   * ({ index: number }): number
   */
  rowHeight: prop_types__WEBPACK_IMPORTED_MODULE_16___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_16___default().number), (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func)]).isRequired,

  /** Number of rows in table. */
  rowCount: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().number.isRequired),

  /**
   * Responsible for rendering a table row given an array of columns:
   * Should implement the following interface: ({
   *   className: string,
   *   columns: Array,
   *   index: number,
   *   isScrolling: boolean,
   *   onRowClick: ?Function,
   *   onRowDoubleClick: ?Function,
   *   onRowMouseOver: ?Function,
   *   onRowMouseOut: ?Function,
   *   rowData: any,
   *   style: any
   * }): PropTypes.node
   */
  rowRenderer: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),

  /** Optional custom inline style to attach to table rows. */
  rowStyle: prop_types__WEBPACK_IMPORTED_MODULE_16___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_16___default().object), (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func)]).isRequired,

  /** See Grid#scrollToAlignment */
  scrollToAlignment: prop_types__WEBPACK_IMPORTED_MODULE_16___default().oneOf(['auto', 'end', 'start', 'center']).isRequired,

  /** Row index to ensure visible (by forcefully scrolling if necessary) */
  scrollToIndex: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().number.isRequired),

  /** Vertical offset. */
  scrollTop: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().number),

  /**
   * Sort function to be called if a sortable header is clicked.
   * Should implement the following interface: ({
   *   defaultSortDirection: 'ASC' | 'DESC',
   *   event: MouseEvent,
   *   sortBy: string,
   *   sortDirection: SortDirection
   * }): void
   */
  sort: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),

  /** Table data is currently sorted by this :dataKey (if it is sorted at all) */
  sortBy: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().string),

  /** Table data is currently sorted in this direction (if it is sorted at all) */
  sortDirection: prop_types__WEBPACK_IMPORTED_MODULE_16___default().oneOf([_SortDirection__WEBPACK_IMPORTED_MODULE_15__["default"].ASC, _SortDirection__WEBPACK_IMPORTED_MODULE_15__["default"].DESC]),

  /** Optional inline style */
  style: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().object),

  /** Tab index for focus */
  tabIndex: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().number),

  /** Width of list */
  width: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().number.isRequired)
} : 0;


/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Table/createMultiSort.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Table/createMultiSort.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ createMultiSort)
/* harmony export */ });
function createMultiSort(sortCallback) {
  var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      defaultSortBy = _ref.defaultSortBy,
      _ref$defaultSortDirec = _ref.defaultSortDirection,
      defaultSortDirection = _ref$defaultSortDirec === void 0 ? {} : _ref$defaultSortDirec;

  if (!sortCallback) {
    throw Error("Required parameter \"sortCallback\" not specified");
  }

  var sortBy = defaultSortBy || [];
  var sortDirection = {};
  sortBy.forEach(function (dataKey) {
    sortDirection[dataKey] = defaultSortDirection[dataKey] !== undefined ? defaultSortDirection[dataKey] : 'ASC';
  });

  function sort(_ref2) {
    var defaultSortDirection = _ref2.defaultSortDirection,
        event = _ref2.event,
        dataKey = _ref2.sortBy;

    if (event.shiftKey) {
      // Shift + click appends a column to existing criteria
      if (sortDirection[dataKey] !== undefined) {
        sortDirection[dataKey] = sortDirection[dataKey] === 'ASC' ? 'DESC' : 'ASC';
      } else {
        sortDirection[dataKey] = defaultSortDirection;
        sortBy.push(dataKey);
      }
    } else if (event.ctrlKey || event.metaKey) {
      // Control + click removes column from sort (if pressent)
      var index = sortBy.indexOf(dataKey);

      if (index >= 0) {
        sortBy.splice(index, 1);
        delete sortDirection[dataKey];
      }
    } else {
      // Clear sortBy array of all non-selected keys
      sortBy.length = 0;
      sortBy.push(dataKey); // Clear sortDirection object of all non-selected keys

      var sortDirectionKeys = Object.keys(sortDirection);
      sortDirectionKeys.forEach(function (key) {
        if (key !== dataKey) delete sortDirection[key];
      }); // If key is already selected, reverse sort direction.
      // Else, set sort direction to default direction.

      if (sortDirection[dataKey] !== undefined) {
        sortDirection[dataKey] = sortDirection[dataKey] === 'ASC' ? 'DESC' : 'ASC';
      } else {
        sortDirection[dataKey] = defaultSortDirection;
      }
    } // Notify application code


    sortCallback({
      sortBy: sortBy,
      sortDirection: sortDirection
    });
  }

  return {
    sort: sort,
    sortBy: sortBy,
    sortDirection: sortDirection
  };
}

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Table/defaultCellDataGetter.js":
/*!***********************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Table/defaultCellDataGetter.js ***!
  \***********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ defaultCellDataGetter)
/* harmony export */ });
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/Table/types.js");
/**
 * Default accessor for returning a cell value for a given attribute.
 * This function expects to operate on either a vanilla Object or an Immutable Map.
 * You should override the column's cellDataGetter if your data is some other type of object.
 */
function defaultCellDataGetter(_ref) {
  var dataKey = _ref.dataKey,
      rowData = _ref.rowData;

  if (typeof rowData.get === 'function') {
    return rowData.get(dataKey);
  } else {
    return rowData[dataKey];
  }
}


/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Table/defaultCellRenderer.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Table/defaultCellRenderer.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ defaultCellRenderer)
/* harmony export */ });
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/Table/types.js");
/**
 * Default cell renderer that displays an attribute as a simple string
 * You should override the column's cellRenderer if your data is some other type of object.
 */
function defaultCellRenderer(_ref) {
  var cellData = _ref.cellData;

  if (cellData == null) {
    return '';
  } else {
    return String(cellData);
  }
}


/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Table/defaultHeaderRenderer.js":
/*!***********************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Table/defaultHeaderRenderer.js ***!
  \***********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ defaultHeaderRenderer)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _SortIndicator__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./SortIndicator */ "../../node_modules/react-virtualized/dist/es/Table/SortIndicator.js");
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/Table/types.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_3__);



/**
 * Default table header renderer.
 */
function defaultHeaderRenderer(_ref) {
  var dataKey = _ref.dataKey,
      label = _ref.label,
      sortBy = _ref.sortBy,
      sortDirection = _ref.sortDirection;
  var showSortIndicator = sortBy === dataKey;
  var children = [react__WEBPACK_IMPORTED_MODULE_0__.createElement("span", {
    className: "ReactVirtualized__Table__headerTruncatedText",
    key: "label",
    title: typeof label === 'string' ? label : null
  }, label)];

  if (showSortIndicator) {
    children.push(react__WEBPACK_IMPORTED_MODULE_0__.createElement(_SortIndicator__WEBPACK_IMPORTED_MODULE_1__["default"], {
      key: "SortIndicator",
      sortDirection: sortDirection
    }));
  }

  return children;
}
defaultHeaderRenderer.propTypes =  false ? 0 : _types__WEBPACK_IMPORTED_MODULE_2__.bpfrpt_proptype_HeaderRendererParams === (prop_types__WEBPACK_IMPORTED_MODULE_3___default().any) ? {} : _types__WEBPACK_IMPORTED_MODULE_2__.bpfrpt_proptype_HeaderRendererParams;



/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Table/defaultHeaderRowRenderer.js":
/*!**************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Table/defaultHeaderRowRenderer.js ***!
  \**************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ defaultHeaderRowRenderer)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/Table/types.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_2__);

function defaultHeaderRowRenderer(_ref) {
  var className = _ref.className,
      columns = _ref.columns,
      style = _ref.style;
  return react__WEBPACK_IMPORTED_MODULE_0__.createElement("div", {
    className: className,
    role: "row",
    style: style
  }, columns);
}
defaultHeaderRowRenderer.propTypes =  false ? 0 : _types__WEBPACK_IMPORTED_MODULE_1__.bpfrpt_proptype_HeaderRowRendererParams === (prop_types__WEBPACK_IMPORTED_MODULE_2___default().any) ? {} : _types__WEBPACK_IMPORTED_MODULE_1__.bpfrpt_proptype_HeaderRowRendererParams;



/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Table/defaultRowRenderer.js":
/*!********************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Table/defaultRowRenderer.js ***!
  \********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ defaultRowRenderer)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/extends */ "../../node_modules/@babel/runtime/helpers/esm/extends.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./types */ "../../node_modules/react-virtualized/dist/es/Table/types.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_3__);



/**
 * Default row renderer for Table.
 */
function defaultRowRenderer(_ref) {
  var className = _ref.className,
      columns = _ref.columns,
      index = _ref.index,
      key = _ref.key,
      onRowClick = _ref.onRowClick,
      onRowDoubleClick = _ref.onRowDoubleClick,
      onRowMouseOut = _ref.onRowMouseOut,
      onRowMouseOver = _ref.onRowMouseOver,
      onRowRightClick = _ref.onRowRightClick,
      rowData = _ref.rowData,
      style = _ref.style;
  var a11yProps = {
    'aria-rowindex': index + 1
  };

  if (onRowClick || onRowDoubleClick || onRowMouseOut || onRowMouseOver || onRowRightClick) {
    a11yProps['aria-label'] = 'row';
    a11yProps.tabIndex = 0;

    if (onRowClick) {
      a11yProps.onClick = function (event) {
        return onRowClick({
          event: event,
          index: index,
          rowData: rowData
        });
      };
    }

    if (onRowDoubleClick) {
      a11yProps.onDoubleClick = function (event) {
        return onRowDoubleClick({
          event: event,
          index: index,
          rowData: rowData
        });
      };
    }

    if (onRowMouseOut) {
      a11yProps.onMouseOut = function (event) {
        return onRowMouseOut({
          event: event,
          index: index,
          rowData: rowData
        });
      };
    }

    if (onRowMouseOver) {
      a11yProps.onMouseOver = function (event) {
        return onRowMouseOver({
          event: event,
          index: index,
          rowData: rowData
        });
      };
    }

    if (onRowRightClick) {
      a11yProps.onContextMenu = function (event) {
        return onRowRightClick({
          event: event,
          index: index,
          rowData: rowData
        });
      };
    }
  }

  return react__WEBPACK_IMPORTED_MODULE_1__.createElement("div", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_0__["default"])({}, a11yProps, {
    className: className,
    key: key,
    role: "row",
    style: style
  }), columns);
}
defaultRowRenderer.propTypes =  false ? 0 : _types__WEBPACK_IMPORTED_MODULE_2__.bpfrpt_proptype_RowRendererParams === (prop_types__WEBPACK_IMPORTED_MODULE_3___default().any) ? {} : _types__WEBPACK_IMPORTED_MODULE_2__.bpfrpt_proptype_RowRendererParams;



/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Table/index.js":
/*!*******************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Table/index.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Column": () => (/* reexport safe */ _Column__WEBPACK_IMPORTED_MODULE_6__["default"]),
/* harmony export */   "SortDirection": () => (/* reexport safe */ _SortDirection__WEBPACK_IMPORTED_MODULE_7__["default"]),
/* harmony export */   "SortIndicator": () => (/* reexport safe */ _SortIndicator__WEBPACK_IMPORTED_MODULE_8__["default"]),
/* harmony export */   "Table": () => (/* reexport safe */ _Table__WEBPACK_IMPORTED_MODULE_9__["default"]),
/* harmony export */   "createMultiSort": () => (/* reexport safe */ _createMultiSort__WEBPACK_IMPORTED_MODULE_0__["default"]),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__),
/* harmony export */   "defaultCellDataGetter": () => (/* reexport safe */ _defaultCellDataGetter__WEBPACK_IMPORTED_MODULE_1__["default"]),
/* harmony export */   "defaultCellRenderer": () => (/* reexport safe */ _defaultCellRenderer__WEBPACK_IMPORTED_MODULE_2__["default"]),
/* harmony export */   "defaultHeaderRenderer": () => (/* reexport safe */ _defaultHeaderRenderer__WEBPACK_IMPORTED_MODULE_4__["default"]),
/* harmony export */   "defaultHeaderRowRenderer": () => (/* reexport safe */ _defaultHeaderRowRenderer_js__WEBPACK_IMPORTED_MODULE_3__["default"]),
/* harmony export */   "defaultRowRenderer": () => (/* reexport safe */ _defaultRowRenderer__WEBPACK_IMPORTED_MODULE_5__["default"])
/* harmony export */ });
/* harmony import */ var _createMultiSort__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./createMultiSort */ "../../node_modules/react-virtualized/dist/es/Table/createMultiSort.js");
/* harmony import */ var _defaultCellDataGetter__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./defaultCellDataGetter */ "../../node_modules/react-virtualized/dist/es/Table/defaultCellDataGetter.js");
/* harmony import */ var _defaultCellRenderer__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./defaultCellRenderer */ "../../node_modules/react-virtualized/dist/es/Table/defaultCellRenderer.js");
/* harmony import */ var _defaultHeaderRowRenderer_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./defaultHeaderRowRenderer.js */ "../../node_modules/react-virtualized/dist/es/Table/defaultHeaderRowRenderer.js");
/* harmony import */ var _defaultHeaderRenderer__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./defaultHeaderRenderer */ "../../node_modules/react-virtualized/dist/es/Table/defaultHeaderRenderer.js");
/* harmony import */ var _defaultRowRenderer__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./defaultRowRenderer */ "../../node_modules/react-virtualized/dist/es/Table/defaultRowRenderer.js");
/* harmony import */ var _Column__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./Column */ "../../node_modules/react-virtualized/dist/es/Table/Column.js");
/* harmony import */ var _SortDirection__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./SortDirection */ "../../node_modules/react-virtualized/dist/es/Table/SortDirection.js");
/* harmony import */ var _SortIndicator__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./SortIndicator */ "../../node_modules/react-virtualized/dist/es/Table/SortIndicator.js");
/* harmony import */ var _Table__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./Table */ "../../node_modules/react-virtualized/dist/es/Table/Table.js");










/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_Table__WEBPACK_IMPORTED_MODULE_9__["default"]);


/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/Table/types.js":
/*!*******************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/Table/types.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "bpfrpt_proptype_CellDataGetterParams": () => (/* binding */ bpfrpt_proptype_CellDataGetterParams),
/* harmony export */   "bpfrpt_proptype_CellRendererParams": () => (/* binding */ bpfrpt_proptype_CellRendererParams),
/* harmony export */   "bpfrpt_proptype_HeaderRendererParams": () => (/* binding */ bpfrpt_proptype_HeaderRendererParams),
/* harmony export */   "bpfrpt_proptype_HeaderRowRendererParams": () => (/* binding */ bpfrpt_proptype_HeaderRowRendererParams),
/* harmony export */   "bpfrpt_proptype_RowRendererParams": () => (/* binding */ bpfrpt_proptype_RowRendererParams)
/* harmony export */ });
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_0__);
var bpfrpt_proptype_CellDataGetterParams =  false ? 0 : {
  "columnData": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().any),
  "dataKey": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().string.isRequired),
  "rowData": function rowData(props, propName, componentName) {
    if (!Object.prototype.hasOwnProperty.call(props, propName)) {
      throw new Error("Prop `".concat(propName, "` has type 'any' or 'mixed', but was not provided to `").concat(componentName, "`. Pass undefined or any other value."));
    }
  }
};
var bpfrpt_proptype_CellRendererParams =  false ? 0 : {
  "cellData": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().any),
  "columnData": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().any),
  "dataKey": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().string.isRequired),
  "rowData": function rowData(props, propName, componentName) {
    if (!Object.prototype.hasOwnProperty.call(props, propName)) {
      throw new Error("Prop `".concat(propName, "` has type 'any' or 'mixed', but was not provided to `").concat(componentName, "`. Pass undefined or any other value."));
    }
  },
  "rowIndex": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().number.isRequired)
};
var bpfrpt_proptype_HeaderRowRendererParams =  false ? 0 : {
  "className": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().string.isRequired),
  "columns": prop_types__WEBPACK_IMPORTED_MODULE_0___default().arrayOf(function (props, propName, componentName) {
    if (!Object.prototype.hasOwnProperty.call(props, propName)) {
      throw new Error("Prop `".concat(propName, "` has type 'any' or 'mixed', but was not provided to `").concat(componentName, "`. Pass undefined or any other value."));
    }
  }).isRequired,
  "style": function style(props, propName, componentName) {
    if (!Object.prototype.hasOwnProperty.call(props, propName)) {
      throw new Error("Prop `".concat(propName, "` has type 'any' or 'mixed', but was not provided to `").concat(componentName, "`. Pass undefined or any other value."));
    }
  }
};
var bpfrpt_proptype_HeaderRendererParams =  false ? 0 : {
  "columnData": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().any),
  "dataKey": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().string.isRequired),
  "disableSort": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().bool),
  "label": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().any),
  "sortBy": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().string),
  "sortDirection": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().string)
};
var bpfrpt_proptype_RowRendererParams =  false ? 0 : {
  "className": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().string.isRequired),
  "columns": prop_types__WEBPACK_IMPORTED_MODULE_0___default().arrayOf(function (props, propName, componentName) {
    if (!Object.prototype.hasOwnProperty.call(props, propName)) {
      throw new Error("Prop `".concat(propName, "` has type 'any' or 'mixed', but was not provided to `").concat(componentName, "`. Pass undefined or any other value."));
    }
  }).isRequired,
  "index": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().number.isRequired),
  "isScrolling": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().bool.isRequired),
  "onRowClick": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().func),
  "onRowDoubleClick": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().func),
  "onRowMouseOver": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().func),
  "onRowMouseOut": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().func),
  "rowData": function rowData(props, propName, componentName) {
    if (!Object.prototype.hasOwnProperty.call(props, propName)) {
      throw new Error("Prop `".concat(propName, "` has type 'any' or 'mixed', but was not provided to `").concat(componentName, "`. Pass undefined or any other value."));
    }
  },
  "style": function style(props, propName, componentName) {
    if (!Object.prototype.hasOwnProperty.call(props, propName)) {
      throw new Error("Prop `".concat(propName, "` has type 'any' or 'mixed', but was not provided to `").concat(componentName, "`. Pass undefined or any other value."));
    }
  },
  "key": (prop_types__WEBPACK_IMPORTED_MODULE_0___default().string.isRequired)
};







/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/WindowScroller/WindowScroller.js":
/*!*************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/WindowScroller/WindowScroller.js ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "IS_SCROLLING_TIMEOUT": () => (/* binding */ IS_SCROLLING_TIMEOUT),
/* harmony export */   "default": () => (/* binding */ WindowScroller)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/classCallCheck */ "../../node_modules/@babel/runtime/helpers/esm/classCallCheck.js");
/* harmony import */ var _babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @babel/runtime/helpers/createClass */ "../../node_modules/@babel/runtime/helpers/esm/createClass.js");
/* harmony import */ var _babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @babel/runtime/helpers/possibleConstructorReturn */ "../../node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js");
/* harmony import */ var _babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @babel/runtime/helpers/getPrototypeOf */ "../../node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js");
/* harmony import */ var _babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @babel/runtime/helpers/assertThisInitialized */ "../../node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js");
/* harmony import */ var _babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @babel/runtime/helpers/inherits */ "../../node_modules/@babel/runtime/helpers/esm/inherits.js");
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @babel/runtime/helpers/defineProperty */ "../../node_modules/@babel/runtime/helpers/esm/defineProperty.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_7__);
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! react-dom */ "webpack/sharing/consume/default/react-dom");
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(react_dom__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */ var _utils_onScroll__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./utils/onScroll */ "../../node_modules/react-virtualized/dist/es/WindowScroller/utils/onScroll.js");
/* harmony import */ var _utils_dimensions__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./utils/dimensions */ "../../node_modules/react-virtualized/dist/es/WindowScroller/utils/dimensions.js");
/* harmony import */ var _vendor_detectElementResize__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../vendor/detectElementResize */ "../../node_modules/react-virtualized/dist/es/vendor/detectElementResize.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_12___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_12__);








var _class, _temp;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }







/**
 * Specifies the number of miliseconds during which to disable pointer events while a scroll is in progress.
 * This improves performance and makes scrolling smoother.
 */
var IS_SCROLLING_TIMEOUT = 150;

var getWindow = function getWindow() {
  return typeof window !== 'undefined' ? window : undefined;
};

var WindowScroller = (_temp = _class =
/*#__PURE__*/
function (_React$PureComponent) {
  (0,_babel_runtime_helpers_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(WindowScroller, _React$PureComponent);

  function WindowScroller() {
    var _getPrototypeOf2;

    var _this;

    (0,_babel_runtime_helpers_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, WindowScroller);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = (0,_babel_runtime_helpers_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__["default"])(this, (_getPrototypeOf2 = (0,_babel_runtime_helpers_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(WindowScroller)).call.apply(_getPrototypeOf2, [this].concat(args)));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_window", getWindow());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_isMounted", false);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_positionFromTop", 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_positionFromLeft", 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_detectElementResize", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_child", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "state", _objectSpread({}, (0,_utils_dimensions__WEBPACK_IMPORTED_MODULE_10__.getDimensions)(_this.props.scrollElement, _this.props), {
      isScrolling: false,
      scrollLeft: 0,
      scrollTop: 0
    }));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_registerChild", function (element) {
      if (element && !(element instanceof Element)) {
        console.warn('WindowScroller registerChild expects to be passed Element or null');
      }

      _this._child = element;

      _this.updatePosition();
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_onChildScroll", function (_ref) {
      var scrollTop = _ref.scrollTop;

      if (_this.state.scrollTop === scrollTop) {
        return;
      }

      var scrollElement = _this.props.scrollElement;

      if (scrollElement) {
        if (typeof scrollElement.scrollTo === 'function') {
          scrollElement.scrollTo(0, scrollTop + _this._positionFromTop);
        } else {
          scrollElement.scrollTop = scrollTop + _this._positionFromTop;
        }
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_registerResizeListener", function (element) {
      if (element === window) {
        window.addEventListener('resize', _this._onResize, false);
      } else {
        _this._detectElementResize.addResizeListener(element, _this._onResize);
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_unregisterResizeListener", function (element) {
      if (element === window) {
        window.removeEventListener('resize', _this._onResize, false);
      } else if (element) {
        _this._detectElementResize.removeResizeListener(element, _this._onResize);
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "_onResize", function () {
      _this.updatePosition();
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "__handleWindowScrollEvent", function () {
      if (!_this._isMounted) {
        return;
      }

      var onScroll = _this.props.onScroll;
      var scrollElement = _this.props.scrollElement;

      if (scrollElement) {
        var scrollOffset = (0,_utils_dimensions__WEBPACK_IMPORTED_MODULE_10__.getScrollOffset)(scrollElement);
        var scrollLeft = Math.max(0, scrollOffset.left - _this._positionFromLeft);
        var scrollTop = Math.max(0, scrollOffset.top - _this._positionFromTop);

        _this.setState({
          isScrolling: true,
          scrollLeft: scrollLeft,
          scrollTop: scrollTop
        });

        onScroll({
          scrollLeft: scrollLeft,
          scrollTop: scrollTop
        });
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])((0,_babel_runtime_helpers_assertThisInitialized__WEBPACK_IMPORTED_MODULE_4__["default"])(_this), "__resetIsScrolling", function () {
      _this.setState({
        isScrolling: false
      });
    });

    return _this;
  }

  (0,_babel_runtime_helpers_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(WindowScroller, [{
    key: "updatePosition",
    value: function updatePosition() {
      var scrollElement = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.props.scrollElement;
      var onResize = this.props.onResize;
      var _this$state = this.state,
          height = _this$state.height,
          width = _this$state.width;
      var thisNode = this._child || react_dom__WEBPACK_IMPORTED_MODULE_8__.findDOMNode(this);

      if (thisNode instanceof Element && scrollElement) {
        var offset = (0,_utils_dimensions__WEBPACK_IMPORTED_MODULE_10__.getPositionOffset)(thisNode, scrollElement);
        this._positionFromTop = offset.top;
        this._positionFromLeft = offset.left;
      }

      var dimensions = (0,_utils_dimensions__WEBPACK_IMPORTED_MODULE_10__.getDimensions)(scrollElement, this.props);

      if (height !== dimensions.height || width !== dimensions.width) {
        this.setState({
          height: dimensions.height,
          width: dimensions.width
        });
        onResize({
          height: dimensions.height,
          width: dimensions.width
        });
      }
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      var scrollElement = this.props.scrollElement;
      this._detectElementResize = (0,_vendor_detectElementResize__WEBPACK_IMPORTED_MODULE_11__["default"])();
      this.updatePosition(scrollElement);

      if (scrollElement) {
        (0,_utils_onScroll__WEBPACK_IMPORTED_MODULE_9__.registerScrollListener)(this, scrollElement);

        this._registerResizeListener(scrollElement);
      }

      this._isMounted = true;
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps, prevState) {
      var scrollElement = this.props.scrollElement;
      var prevScrollElement = prevProps.scrollElement;

      if (prevScrollElement !== scrollElement && prevScrollElement != null && scrollElement != null) {
        this.updatePosition(scrollElement);
        (0,_utils_onScroll__WEBPACK_IMPORTED_MODULE_9__.unregisterScrollListener)(this, prevScrollElement);
        (0,_utils_onScroll__WEBPACK_IMPORTED_MODULE_9__.registerScrollListener)(this, scrollElement);

        this._unregisterResizeListener(prevScrollElement);

        this._registerResizeListener(scrollElement);
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      var scrollElement = this.props.scrollElement;

      if (scrollElement) {
        (0,_utils_onScroll__WEBPACK_IMPORTED_MODULE_9__.unregisterScrollListener)(this, scrollElement);

        this._unregisterResizeListener(scrollElement);
      }

      this._isMounted = false;
    }
  }, {
    key: "render",
    value: function render() {
      var children = this.props.children;
      var _this$state2 = this.state,
          isScrolling = _this$state2.isScrolling,
          scrollTop = _this$state2.scrollTop,
          scrollLeft = _this$state2.scrollLeft,
          height = _this$state2.height,
          width = _this$state2.width;
      return children({
        onChildScroll: this._onChildScroll,
        registerChild: this._registerChild,
        height: height,
        isScrolling: isScrolling,
        scrollLeft: scrollLeft,
        scrollTop: scrollTop,
        width: width
      });
    }
  }]);

  return WindowScroller;
}(react__WEBPACK_IMPORTED_MODULE_7__.PureComponent), (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(_class, "propTypes",  false ? 0 : {
  /**
   * Function responsible for rendering children.
   * This function should implement the following signature:
   * ({ height, isScrolling, scrollLeft, scrollTop, width }) => PropTypes.element
   */
  "children": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func.isRequired),

  /** Callback to be invoked on-resize: ({ height, width }) */
  "onResize": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func.isRequired),

  /** Callback to be invoked on-scroll: ({ scrollLeft, scrollTop }) */
  "onScroll": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().func.isRequired),

  /** Element to attach scroll event listeners. Defaults to window. */
  "scrollElement": prop_types__WEBPACK_IMPORTED_MODULE_12___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_12___default().any), function () {
    return (typeof Element === "function" ? prop_types__WEBPACK_IMPORTED_MODULE_12___default().instanceOf(Element) : (prop_types__WEBPACK_IMPORTED_MODULE_12___default().any)).apply(this, arguments);
  }]),

  /**
   * Wait this amount of time after the last scroll event before resetting child `pointer-events`.
   */
  "scrollingResetTimeInterval": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired),

  /** Height used for server-side rendering */
  "serverHeight": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired),

  /** Width used for server-side rendering */
  "serverWidth": (prop_types__WEBPACK_IMPORTED_MODULE_12___default().number.isRequired)
}), _temp);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__["default"])(WindowScroller, "defaultProps", {
  onResize: function onResize() {},
  onScroll: function onScroll() {},
  scrollingResetTimeInterval: IS_SCROLLING_TIMEOUT,
  scrollElement: getWindow(),
  serverHeight: 0,
  serverWidth: 0
});




/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/WindowScroller/index.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/WindowScroller/index.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "IS_SCROLLING_TIMEOUT": () => (/* reexport safe */ _WindowScroller__WEBPACK_IMPORTED_MODULE_0__.IS_SCROLLING_TIMEOUT),
/* harmony export */   "WindowScroller": () => (/* reexport safe */ _WindowScroller__WEBPACK_IMPORTED_MODULE_0__["default"]),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _WindowScroller__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./WindowScroller */ "../../node_modules/react-virtualized/dist/es/WindowScroller/WindowScroller.js");

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_WindowScroller__WEBPACK_IMPORTED_MODULE_0__["default"]);


/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/WindowScroller/utils/dimensions.js":
/*!***************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/WindowScroller/utils/dimensions.js ***!
  \***************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "getDimensions": () => (/* binding */ getDimensions),
/* harmony export */   "getPositionOffset": () => (/* binding */ getPositionOffset),
/* harmony export */   "getScrollOffset": () => (/* binding */ getScrollOffset)
/* harmony export */ });
/**
 * Gets the dimensions of the element, accounting for API differences between
 * `window` and other DOM elements.
 */
// TODO Move this into WindowScroller and import from there
var isWindow = function isWindow(element) {
  return element === window;
};

var getBoundingBox = function getBoundingBox(element) {
  return element.getBoundingClientRect();
};

function getDimensions(scrollElement, props) {
  if (!scrollElement) {
    return {
      height: props.serverHeight,
      width: props.serverWidth
    };
  } else if (isWindow(scrollElement)) {
    var _window = window,
        innerHeight = _window.innerHeight,
        innerWidth = _window.innerWidth;
    return {
      height: typeof innerHeight === 'number' ? innerHeight : 0,
      width: typeof innerWidth === 'number' ? innerWidth : 0
    };
  } else {
    return getBoundingBox(scrollElement);
  }
}
/**
 * Gets the vertical and horizontal position of an element within its scroll container.
 * Elements that have been “scrolled past” return negative values.
 * Handles edge-case where a user is navigating back (history) from an already-scrolled page.
 * In this case the body’s top or left position will be a negative number and this element’s top or left will be increased (by that amount).
 */

function getPositionOffset(element, container) {
  if (isWindow(container) && document.documentElement) {
    var containerElement = document.documentElement;
    var elementRect = getBoundingBox(element);
    var containerRect = getBoundingBox(containerElement);
    return {
      top: elementRect.top - containerRect.top,
      left: elementRect.left - containerRect.left
    };
  } else {
    var scrollOffset = getScrollOffset(container);

    var _elementRect = getBoundingBox(element);

    var _containerRect = getBoundingBox(container);

    return {
      top: _elementRect.top + scrollOffset.top - _containerRect.top,
      left: _elementRect.left + scrollOffset.left - _containerRect.left
    };
  }
}
/**
 * Gets the vertical and horizontal scroll amount of the element, accounting for IE compatibility
 * and API differences between `window` and other DOM elements.
 */

function getScrollOffset(element) {
  if (isWindow(element) && document.documentElement) {
    return {
      top: 'scrollY' in window ? window.scrollY : document.documentElement.scrollTop,
      left: 'scrollX' in window ? window.scrollX : document.documentElement.scrollLeft
    };
  } else {
    return {
      top: element.scrollTop,
      left: element.scrollLeft
    };
  }
}

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/WindowScroller/utils/onScroll.js":
/*!*************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/WindowScroller/utils/onScroll.js ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "registerScrollListener": () => (/* binding */ registerScrollListener),
/* harmony export */   "unregisterScrollListener": () => (/* binding */ unregisterScrollListener)
/* harmony export */ });
/* harmony import */ var _utils_requestAnimationTimeout__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../utils/requestAnimationTimeout */ "../../node_modules/react-virtualized/dist/es/utils/requestAnimationTimeout.js");
/* harmony import */ var _WindowScroller_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../WindowScroller.js */ "../../node_modules/react-virtualized/dist/es/WindowScroller/WindowScroller.js");

var mountedInstances = [];
var originalBodyPointerEvents = null;
var disablePointerEventsTimeoutId = null;

function enablePointerEventsIfDisabled() {
  if (disablePointerEventsTimeoutId) {
    disablePointerEventsTimeoutId = null;

    if (document.body && originalBodyPointerEvents != null) {
      document.body.style.pointerEvents = originalBodyPointerEvents;
    }

    originalBodyPointerEvents = null;
  }
}

function enablePointerEventsAfterDelayCallback() {
  enablePointerEventsIfDisabled();
  mountedInstances.forEach(function (instance) {
    return instance.__resetIsScrolling();
  });
}

function enablePointerEventsAfterDelay() {
  if (disablePointerEventsTimeoutId) {
    (0,_utils_requestAnimationTimeout__WEBPACK_IMPORTED_MODULE_0__.cancelAnimationTimeout)(disablePointerEventsTimeoutId);
  }

  var maximumTimeout = 0;
  mountedInstances.forEach(function (instance) {
    maximumTimeout = Math.max(maximumTimeout, instance.props.scrollingResetTimeInterval);
  });
  disablePointerEventsTimeoutId = (0,_utils_requestAnimationTimeout__WEBPACK_IMPORTED_MODULE_0__.requestAnimationTimeout)(enablePointerEventsAfterDelayCallback, maximumTimeout);
}

function onScrollWindow(event) {
  if (event.currentTarget === window && originalBodyPointerEvents == null && document.body) {
    originalBodyPointerEvents = document.body.style.pointerEvents;
    document.body.style.pointerEvents = 'none';
  }

  enablePointerEventsAfterDelay();
  mountedInstances.forEach(function (instance) {
    if (instance.props.scrollElement === event.currentTarget) {
      instance.__handleWindowScrollEvent();
    }
  });
}

function registerScrollListener(component, element) {
  if (!mountedInstances.some(function (instance) {
    return instance.props.scrollElement === element;
  })) {
    element.addEventListener('scroll', onScrollWindow);
  }

  mountedInstances.push(component);
}
function unregisterScrollListener(component, element) {
  mountedInstances = mountedInstances.filter(function (instance) {
    return instance !== component;
  });

  if (!mountedInstances.length) {
    element.removeEventListener('scroll', onScrollWindow);

    if (disablePointerEventsTimeoutId) {
      (0,_utils_requestAnimationTimeout__WEBPACK_IMPORTED_MODULE_0__.cancelAnimationTimeout)(disablePointerEventsTimeoutId);
      enablePointerEventsIfDisabled();
    }
  }
}


/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/index.js":
/*!*************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/index.js ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "ArrowKeyStepper": () => (/* reexport safe */ _ArrowKeyStepper__WEBPACK_IMPORTED_MODULE_0__.ArrowKeyStepper),
/* harmony export */   "AutoSizer": () => (/* reexport safe */ _AutoSizer__WEBPACK_IMPORTED_MODULE_1__.AutoSizer),
/* harmony export */   "CellMeasurer": () => (/* reexport safe */ _CellMeasurer__WEBPACK_IMPORTED_MODULE_2__.CellMeasurer),
/* harmony export */   "CellMeasurerCache": () => (/* reexport safe */ _CellMeasurer__WEBPACK_IMPORTED_MODULE_2__.CellMeasurerCache),
/* harmony export */   "Collection": () => (/* reexport safe */ _Collection__WEBPACK_IMPORTED_MODULE_3__.Collection),
/* harmony export */   "Column": () => (/* reexport safe */ _Table__WEBPACK_IMPORTED_MODULE_11__.Column),
/* harmony export */   "ColumnSizer": () => (/* reexport safe */ _ColumnSizer__WEBPACK_IMPORTED_MODULE_4__.ColumnSizer),
/* harmony export */   "Grid": () => (/* reexport safe */ _Grid__WEBPACK_IMPORTED_MODULE_5__.Grid),
/* harmony export */   "InfiniteLoader": () => (/* reexport safe */ _InfiniteLoader__WEBPACK_IMPORTED_MODULE_6__.InfiniteLoader),
/* harmony export */   "List": () => (/* reexport safe */ _List__WEBPACK_IMPORTED_MODULE_7__.List),
/* harmony export */   "Masonry": () => (/* reexport safe */ _Masonry__WEBPACK_IMPORTED_MODULE_8__.Masonry),
/* harmony export */   "MultiGrid": () => (/* reexport safe */ _MultiGrid__WEBPACK_IMPORTED_MODULE_9__.MultiGrid),
/* harmony export */   "ScrollSync": () => (/* reexport safe */ _ScrollSync__WEBPACK_IMPORTED_MODULE_10__.ScrollSync),
/* harmony export */   "SortDirection": () => (/* reexport safe */ _Table__WEBPACK_IMPORTED_MODULE_11__.SortDirection),
/* harmony export */   "SortIndicator": () => (/* reexport safe */ _Table__WEBPACK_IMPORTED_MODULE_11__.SortIndicator),
/* harmony export */   "Table": () => (/* reexport safe */ _Table__WEBPACK_IMPORTED_MODULE_11__.Table),
/* harmony export */   "WindowScroller": () => (/* reexport safe */ _WindowScroller__WEBPACK_IMPORTED_MODULE_12__.WindowScroller),
/* harmony export */   "accessibilityOverscanIndicesGetter": () => (/* reexport safe */ _Grid__WEBPACK_IMPORTED_MODULE_5__.accessibilityOverscanIndicesGetter),
/* harmony export */   "createMasonryCellPositioner": () => (/* reexport safe */ _Masonry__WEBPACK_IMPORTED_MODULE_8__.createCellPositioner),
/* harmony export */   "createTableMultiSort": () => (/* reexport safe */ _Table__WEBPACK_IMPORTED_MODULE_11__.createMultiSort),
/* harmony export */   "defaultCellRangeRenderer": () => (/* reexport safe */ _Grid__WEBPACK_IMPORTED_MODULE_5__.defaultCellRangeRenderer),
/* harmony export */   "defaultOverscanIndicesGetter": () => (/* reexport safe */ _Grid__WEBPACK_IMPORTED_MODULE_5__.defaultOverscanIndicesGetter),
/* harmony export */   "defaultTableCellDataGetter": () => (/* reexport safe */ _Table__WEBPACK_IMPORTED_MODULE_11__.defaultCellDataGetter),
/* harmony export */   "defaultTableCellRenderer": () => (/* reexport safe */ _Table__WEBPACK_IMPORTED_MODULE_11__.defaultCellRenderer),
/* harmony export */   "defaultTableHeaderRenderer": () => (/* reexport safe */ _Table__WEBPACK_IMPORTED_MODULE_11__.defaultHeaderRenderer),
/* harmony export */   "defaultTableHeaderRowRenderer": () => (/* reexport safe */ _Table__WEBPACK_IMPORTED_MODULE_11__.defaultHeaderRowRenderer),
/* harmony export */   "defaultTableRowRenderer": () => (/* reexport safe */ _Table__WEBPACK_IMPORTED_MODULE_11__.defaultRowRenderer)
/* harmony export */ });
/* harmony import */ var _ArrowKeyStepper__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./ArrowKeyStepper */ "../../node_modules/react-virtualized/dist/es/ArrowKeyStepper/index.js");
/* harmony import */ var _AutoSizer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./AutoSizer */ "../../node_modules/react-virtualized/dist/es/AutoSizer/index.js");
/* harmony import */ var _CellMeasurer__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./CellMeasurer */ "../../node_modules/react-virtualized/dist/es/CellMeasurer/index.js");
/* harmony import */ var _Collection__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./Collection */ "../../node_modules/react-virtualized/dist/es/Collection/index.js");
/* harmony import */ var _ColumnSizer__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./ColumnSizer */ "../../node_modules/react-virtualized/dist/es/ColumnSizer/index.js");
/* harmony import */ var _Grid__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./Grid */ "../../node_modules/react-virtualized/dist/es/Grid/index.js");
/* harmony import */ var _InfiniteLoader__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./InfiniteLoader */ "../../node_modules/react-virtualized/dist/es/InfiniteLoader/index.js");
/* harmony import */ var _List__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./List */ "../../node_modules/react-virtualized/dist/es/List/index.js");
/* harmony import */ var _Masonry__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./Masonry */ "../../node_modules/react-virtualized/dist/es/Masonry/index.js");
/* harmony import */ var _MultiGrid__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./MultiGrid */ "../../node_modules/react-virtualized/dist/es/MultiGrid/index.js");
/* harmony import */ var _ScrollSync__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./ScrollSync */ "../../node_modules/react-virtualized/dist/es/ScrollSync/index.js");
/* harmony import */ var _Table__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./Table */ "../../node_modules/react-virtualized/dist/es/Table/index.js");
/* harmony import */ var _WindowScroller__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./WindowScroller */ "../../node_modules/react-virtualized/dist/es/WindowScroller/index.js");














/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/utils/animationFrame.js":
/*!****************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/utils/animationFrame.js ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "caf": () => (/* binding */ caf),
/* harmony export */   "raf": () => (/* binding */ raf)
/* harmony export */ });
// Properly handle server-side rendering.
var win;

if (typeof window !== 'undefined') {
  win = window;
} else if (typeof self !== 'undefined') {
  win = self;
} else {
  win = {};
} // requestAnimationFrame() shim by Paul Irish
// http://paulirish.com/2011/requestanimationframe-for-smart-animating/


var request = win.requestAnimationFrame || win.webkitRequestAnimationFrame || win.mozRequestAnimationFrame || win.oRequestAnimationFrame || win.msRequestAnimationFrame || function (callback) {
  return win.setTimeout(callback, 1000 / 60);
};

var cancel = win.cancelAnimationFrame || win.webkitCancelAnimationFrame || win.mozCancelAnimationFrame || win.oCancelAnimationFrame || win.msCancelAnimationFrame || function (id) {
  win.clearTimeout(id);
};

var raf = request;
var caf = cancel;

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/utils/createCallbackMemoizer.js":
/*!************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/utils/createCallbackMemoizer.js ***!
  \************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ createCallbackMemoizer)
/* harmony export */ });
/**
 * Helper utility that updates the specified callback whenever any of the specified indices have changed.
 */
function createCallbackMemoizer() {
  var requireAllKeys = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
  var cachedIndices = {};
  return function (_ref) {
    var callback = _ref.callback,
        indices = _ref.indices;
    var keys = Object.keys(indices);
    var allInitialized = !requireAllKeys || keys.every(function (key) {
      var value = indices[key];
      return Array.isArray(value) ? value.length > 0 : value >= 0;
    });
    var indexChanged = keys.length !== Object.keys(cachedIndices).length || keys.some(function (key) {
      var cachedValue = cachedIndices[key];
      var value = indices[key];
      return Array.isArray(value) ? cachedValue.join(',') !== value.join(',') : cachedValue !== value;
    });
    cachedIndices = indices;

    if (allInitialized && indexChanged) {
      callback(indices);
    }
  };
}

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/utils/getUpdatedOffsetForIndex.js":
/*!**************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/utils/getUpdatedOffsetForIndex.js ***!
  \**************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ getUpdatedOffsetForIndex)
/* harmony export */ });
/**
 * Determines a new offset that ensures a certain cell is visible, given the current offset.
 * If the cell is already visible then the current offset will be returned.
 * If the current offset is too great or small, it will be adjusted just enough to ensure the specified index is visible.
 *
 * @param align Desired alignment within container; one of "auto" (default), "start", or "end"
 * @param cellOffset Offset (x or y) position for cell
 * @param cellSize Size (width or height) of cell
 * @param containerSize Total size (width or height) of the container
 * @param currentOffset Container's current (x or y) offset
 * @return Offset to use to ensure the specified cell is visible
 */
function getUpdatedOffsetForIndex(_ref) {
  var _ref$align = _ref.align,
      align = _ref$align === void 0 ? 'auto' : _ref$align,
      cellOffset = _ref.cellOffset,
      cellSize = _ref.cellSize,
      containerSize = _ref.containerSize,
      currentOffset = _ref.currentOffset;
  var maxOffset = cellOffset;
  var minOffset = maxOffset - containerSize + cellSize;

  switch (align) {
    case 'start':
      return maxOffset;

    case 'end':
      return minOffset;

    case 'center':
      return maxOffset - (containerSize - cellSize) / 2;

    default:
      return Math.max(minOffset, Math.min(maxOffset, currentOffset));
  }
}

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/utils/requestAnimationTimeout.js":
/*!*************************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/utils/requestAnimationTimeout.js ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "bpfrpt_proptype_AnimationTimeoutId": () => (/* binding */ bpfrpt_proptype_AnimationTimeoutId),
/* harmony export */   "cancelAnimationTimeout": () => (/* binding */ cancelAnimationTimeout),
/* harmony export */   "requestAnimationTimeout": () => (/* binding */ requestAnimationTimeout)
/* harmony export */ });
/* harmony import */ var _animationFrame__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./animationFrame */ "../../node_modules/react-virtualized/dist/es/utils/animationFrame.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "../../node_modules/prop-types/index.js");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);

var bpfrpt_proptype_AnimationTimeoutId =  false ? 0 : {
  "id": (prop_types__WEBPACK_IMPORTED_MODULE_1___default().number.isRequired)
};
var cancelAnimationTimeout = function cancelAnimationTimeout(frame) {
  return (0,_animationFrame__WEBPACK_IMPORTED_MODULE_0__.caf)(frame.id);
};
/**
 * Recursively calls requestAnimationFrame until a specified delay has been met or exceeded.
 * When the delay time has been reached the function you're timing out will be called.
 *
 * Credit: Joe Lambert (https://gist.github.com/joelambert/1002116#file-requesttimeout-js)
 */

var requestAnimationTimeout = function requestAnimationTimeout(callback, delay) {
  var start; // wait for end of processing current event handler, because event handler may be long

  Promise.resolve().then(function () {
    start = Date.now();
  });

  var timeout = function timeout() {
    if (Date.now() - start >= delay) {
      callback.call();
    } else {
      frame.id = (0,_animationFrame__WEBPACK_IMPORTED_MODULE_0__.raf)(timeout);
    }
  };

  var frame = {
    id: (0,_animationFrame__WEBPACK_IMPORTED_MODULE_0__.raf)(timeout)
  };
  return frame;
};



/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/vendor/binarySearchBounds.js":
/*!*********************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/vendor/binarySearchBounds.js ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/**
 * Binary Search Bounds
 * https://github.com/mikolalysenko/binary-search-bounds
 * Mikola Lysenko
 *
 * Inlined because of Content Security Policy issue caused by the use of `new Function(...)` syntax.
 * Issue reported here: https://github.com/mikolalysenko/binary-search-bounds/issues/5
 **/
function _GEA(a, l, h, y) {
  var i = h + 1;

  while (l <= h) {
    var m = l + h >>> 1,
        x = a[m];

    if (x >= y) {
      i = m;
      h = m - 1;
    } else {
      l = m + 1;
    }
  }

  return i;
}

function _GEP(a, l, h, y, c) {
  var i = h + 1;

  while (l <= h) {
    var m = l + h >>> 1,
        x = a[m];

    if (c(x, y) >= 0) {
      i = m;
      h = m - 1;
    } else {
      l = m + 1;
    }
  }

  return i;
}

function dispatchBsearchGE(a, y, c, l, h) {
  if (typeof c === 'function') {
    return _GEP(a, l === void 0 ? 0 : l | 0, h === void 0 ? a.length - 1 : h | 0, y, c);
  } else {
    return _GEA(a, c === void 0 ? 0 : c | 0, l === void 0 ? a.length - 1 : l | 0, y);
  }
}

function _GTA(a, l, h, y) {
  var i = h + 1;

  while (l <= h) {
    var m = l + h >>> 1,
        x = a[m];

    if (x > y) {
      i = m;
      h = m - 1;
    } else {
      l = m + 1;
    }
  }

  return i;
}

function _GTP(a, l, h, y, c) {
  var i = h + 1;

  while (l <= h) {
    var m = l + h >>> 1,
        x = a[m];

    if (c(x, y) > 0) {
      i = m;
      h = m - 1;
    } else {
      l = m + 1;
    }
  }

  return i;
}

function dispatchBsearchGT(a, y, c, l, h) {
  if (typeof c === 'function') {
    return _GTP(a, l === void 0 ? 0 : l | 0, h === void 0 ? a.length - 1 : h | 0, y, c);
  } else {
    return _GTA(a, c === void 0 ? 0 : c | 0, l === void 0 ? a.length - 1 : l | 0, y);
  }
}

function _LTA(a, l, h, y) {
  var i = l - 1;

  while (l <= h) {
    var m = l + h >>> 1,
        x = a[m];

    if (x < y) {
      i = m;
      l = m + 1;
    } else {
      h = m - 1;
    }
  }

  return i;
}

function _LTP(a, l, h, y, c) {
  var i = l - 1;

  while (l <= h) {
    var m = l + h >>> 1,
        x = a[m];

    if (c(x, y) < 0) {
      i = m;
      l = m + 1;
    } else {
      h = m - 1;
    }
  }

  return i;
}

function dispatchBsearchLT(a, y, c, l, h) {
  if (typeof c === 'function') {
    return _LTP(a, l === void 0 ? 0 : l | 0, h === void 0 ? a.length - 1 : h | 0, y, c);
  } else {
    return _LTA(a, c === void 0 ? 0 : c | 0, l === void 0 ? a.length - 1 : l | 0, y);
  }
}

function _LEA(a, l, h, y) {
  var i = l - 1;

  while (l <= h) {
    var m = l + h >>> 1,
        x = a[m];

    if (x <= y) {
      i = m;
      l = m + 1;
    } else {
      h = m - 1;
    }
  }

  return i;
}

function _LEP(a, l, h, y, c) {
  var i = l - 1;

  while (l <= h) {
    var m = l + h >>> 1,
        x = a[m];

    if (c(x, y) <= 0) {
      i = m;
      l = m + 1;
    } else {
      h = m - 1;
    }
  }

  return i;
}

function dispatchBsearchLE(a, y, c, l, h) {
  if (typeof c === 'function') {
    return _LEP(a, l === void 0 ? 0 : l | 0, h === void 0 ? a.length - 1 : h | 0, y, c);
  } else {
    return _LEA(a, c === void 0 ? 0 : c | 0, l === void 0 ? a.length - 1 : l | 0, y);
  }
}

function _EQA(a, l, h, y) {
  l - 1;

  while (l <= h) {
    var m = l + h >>> 1,
        x = a[m];

    if (x === y) {
      return m;
    } else if (x <= y) {
      l = m + 1;
    } else {
      h = m - 1;
    }
  }

  return -1;
}

function _EQP(a, l, h, y, c) {
  l - 1;

  while (l <= h) {
    var m = l + h >>> 1,
        x = a[m];
    var p = c(x, y);

    if (p === 0) {
      return m;
    } else if (p <= 0) {
      l = m + 1;
    } else {
      h = m - 1;
    }
  }

  return -1;
}

function dispatchBsearchEQ(a, y, c, l, h) {
  if (typeof c === 'function') {
    return _EQP(a, l === void 0 ? 0 : l | 0, h === void 0 ? a.length - 1 : h | 0, y, c);
  } else {
    return _EQA(a, c === void 0 ? 0 : c | 0, l === void 0 ? a.length - 1 : l | 0, y);
  }
}

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({
  ge: dispatchBsearchGE,
  gt: dispatchBsearchGT,
  lt: dispatchBsearchLT,
  le: dispatchBsearchLE,
  eq: dispatchBsearchEQ
});

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/vendor/detectElementResize.js":
/*!**********************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/vendor/detectElementResize.js ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ createDetectElementResize)
/* harmony export */ });
/**
 * Detect Element Resize.
 * https://github.com/sdecima/javascript-detect-element-resize
 * Sebastian Decima
 *
 * Forked from version 0.5.3; includes the following modifications:
 * 1) Guard against unsafe 'window' and 'document' references (to support SSR).
 * 2) Defer initialization code via a top-level function wrapper (to support SSR).
 * 3) Avoid unnecessary reflows by not measuring size for scroll events bubbling from children.
 * 4) Add nonce for style element.
 * 5) Added support for injecting custom window object
 **/
function createDetectElementResize(nonce, hostWindow) {
  // Check `document` and `window` in case of server-side rendering
  var _window;

  if (typeof hostWindow !== 'undefined') {
    _window = hostWindow;
  } else if (typeof window !== 'undefined') {
    _window = window;
  } else if (typeof self !== 'undefined') {
    _window = self;
  } else {
    _window = __webpack_require__.g;
  }

  var attachEvent = typeof _window.document !== 'undefined' && _window.document.attachEvent;

  if (!attachEvent) {
    var requestFrame = function () {
      var raf = _window.requestAnimationFrame || _window.mozRequestAnimationFrame || _window.webkitRequestAnimationFrame || function (fn) {
        return _window.setTimeout(fn, 20);
      };

      return function (fn) {
        return raf(fn);
      };
    }();

    var cancelFrame = function () {
      var cancel = _window.cancelAnimationFrame || _window.mozCancelAnimationFrame || _window.webkitCancelAnimationFrame || _window.clearTimeout;
      return function (id) {
        return cancel(id);
      };
    }();

    var resetTriggers = function resetTriggers(element) {
      var triggers = element.__resizeTriggers__,
          expand = triggers.firstElementChild,
          contract = triggers.lastElementChild,
          expandChild = expand.firstElementChild;
      contract.scrollLeft = contract.scrollWidth;
      contract.scrollTop = contract.scrollHeight;
      expandChild.style.width = expand.offsetWidth + 1 + 'px';
      expandChild.style.height = expand.offsetHeight + 1 + 'px';
      expand.scrollLeft = expand.scrollWidth;
      expand.scrollTop = expand.scrollHeight;
    };

    var checkTriggers = function checkTriggers(element) {
      return element.offsetWidth != element.__resizeLast__.width || element.offsetHeight != element.__resizeLast__.height;
    };

    var scrollListener = function scrollListener(e) {
      // Don't measure (which forces) reflow for scrolls that happen inside of children!
      if (e.target.className && typeof e.target.className.indexOf === 'function' && e.target.className.indexOf('contract-trigger') < 0 && e.target.className.indexOf('expand-trigger') < 0) {
        return;
      }

      var element = this;
      resetTriggers(this);

      if (this.__resizeRAF__) {
        cancelFrame(this.__resizeRAF__);
      }

      this.__resizeRAF__ = requestFrame(function () {
        if (checkTriggers(element)) {
          element.__resizeLast__.width = element.offsetWidth;
          element.__resizeLast__.height = element.offsetHeight;

          element.__resizeListeners__.forEach(function (fn) {
            fn.call(element, e);
          });
        }
      });
    };
    /* Detect CSS Animations support to detect element display/re-attach */


    var animation = false,
        keyframeprefix = '',
        animationstartevent = 'animationstart',
        domPrefixes = 'Webkit Moz O ms'.split(' '),
        startEvents = 'webkitAnimationStart animationstart oAnimationStart MSAnimationStart'.split(' '),
        pfx = '';
    {
      var elm = _window.document.createElement('fakeelement');

      if (elm.style.animationName !== undefined) {
        animation = true;
      }

      if (animation === false) {
        for (var i = 0; i < domPrefixes.length; i++) {
          if (elm.style[domPrefixes[i] + 'AnimationName'] !== undefined) {
            pfx = domPrefixes[i];
            keyframeprefix = '-' + pfx.toLowerCase() + '-';
            animationstartevent = startEvents[i];
            animation = true;
            break;
          }
        }
      }
    }
    var animationName = 'resizeanim';
    var animationKeyframes = '@' + keyframeprefix + 'keyframes ' + animationName + ' { from { opacity: 0; } to { opacity: 0; } } ';
    var animationStyle = keyframeprefix + 'animation: 1ms ' + animationName + '; ';
  }

  var createStyles = function createStyles(doc) {
    if (!doc.getElementById('detectElementResize')) {
      //opacity:0 works around a chrome bug https://code.google.com/p/chromium/issues/detail?id=286360
      var css = (animationKeyframes ? animationKeyframes : '') + '.resize-triggers { ' + (animationStyle ? animationStyle : '') + 'visibility: hidden; opacity: 0; } ' + '.resize-triggers, .resize-triggers > div, .contract-trigger:before { content: " "; display: block; position: absolute; top: 0; left: 0; height: 100%; width: 100%; overflow: hidden; z-index: -1; } .resize-triggers > div { background: #eee; overflow: auto; } .contract-trigger:before { width: 200%; height: 200%; }',
          head = doc.head || doc.getElementsByTagName('head')[0],
          style = doc.createElement('style');
      style.id = 'detectElementResize';
      style.type = 'text/css';

      if (nonce != null) {
        style.setAttribute('nonce', nonce);
      }

      if (style.styleSheet) {
        style.styleSheet.cssText = css;
      } else {
        style.appendChild(doc.createTextNode(css));
      }

      head.appendChild(style);
    }
  };

  var addResizeListener = function addResizeListener(element, fn) {
    if (attachEvent) {
      element.attachEvent('onresize', fn);
    } else {
      if (!element.__resizeTriggers__) {
        var doc = element.ownerDocument;

        var elementStyle = _window.getComputedStyle(element);

        if (elementStyle && elementStyle.position == 'static') {
          element.style.position = 'relative';
        }

        createStyles(doc);
        element.__resizeLast__ = {};
        element.__resizeListeners__ = [];
        (element.__resizeTriggers__ = doc.createElement('div')).className = 'resize-triggers';
        var resizeTriggersHtml = '<div class="expand-trigger"><div></div></div>' + '<div class="contract-trigger"></div>';

        if (window.trustedTypes) {
          var staticPolicy = trustedTypes.createPolicy('react-virtualized-auto-sizer', {
            createHTML: function createHTML() {
              return resizeTriggersHtml;
            }
          });
          element.__resizeTriggers__.innerHTML = staticPolicy.createHTML('');
        } else {
          element.__resizeTriggers__.innerHTML = resizeTriggersHtml;
        }

        element.appendChild(element.__resizeTriggers__);
        resetTriggers(element);
        element.addEventListener('scroll', scrollListener, true);
        /* Listen for a css animation to detect element display/re-attach */

        if (animationstartevent) {
          element.__resizeTriggers__.__animationListener__ = function animationListener(e) {
            if (e.animationName == animationName) {
              resetTriggers(element);
            }
          };

          element.__resizeTriggers__.addEventListener(animationstartevent, element.__resizeTriggers__.__animationListener__);
        }
      }

      element.__resizeListeners__.push(fn);
    }
  };

  var removeResizeListener = function removeResizeListener(element, fn) {
    if (attachEvent) {
      element.detachEvent('onresize', fn);
    } else {
      element.__resizeListeners__.splice(element.__resizeListeners__.indexOf(fn), 1);

      if (!element.__resizeListeners__.length) {
        element.removeEventListener('scroll', scrollListener, true);

        if (element.__resizeTriggers__.__animationListener__) {
          element.__resizeTriggers__.removeEventListener(animationstartevent, element.__resizeTriggers__.__animationListener__);

          element.__resizeTriggers__.__animationListener__ = null;
        }

        try {
          element.__resizeTriggers__ = !element.removeChild(element.__resizeTriggers__);
        } catch (e) {// Preact compat; see developit/preact-compat/issues/228
        }
      }
    }
  };

  return {
    addResizeListener: addResizeListener,
    removeResizeListener: removeResizeListener
  };
}

/***/ }),

/***/ "../../node_modules/react-virtualized/dist/es/vendor/intervalTree.js":
/*!***************************************************************************!*\
  !*** ../../node_modules/react-virtualized/dist/es/vendor/intervalTree.js ***!
  \***************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ createWrapper)
/* harmony export */ });
/* harmony import */ var _binarySearchBounds__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./binarySearchBounds */ "../../node_modules/react-virtualized/dist/es/vendor/binarySearchBounds.js");
/**
 * Binary Search Bounds
 * https://github.com/mikolalysenko/interval-tree-1d
 * Mikola Lysenko
 *
 * Inlined because of Content Security Policy issue caused by the use of `new Function(...)` syntax in an upstream dependency.
 * Issue reported here: https://github.com/mikolalysenko/binary-search-bounds/issues/5
 **/

var NOT_FOUND = 0;
var SUCCESS = 1;
var EMPTY = 2;

function IntervalTreeNode(mid, left, right, leftPoints, rightPoints) {
  this.mid = mid;
  this.left = left;
  this.right = right;
  this.leftPoints = leftPoints;
  this.rightPoints = rightPoints;
  this.count = (left ? left.count : 0) + (right ? right.count : 0) + leftPoints.length;
}

var proto = IntervalTreeNode.prototype;

function copy(a, b) {
  a.mid = b.mid;
  a.left = b.left;
  a.right = b.right;
  a.leftPoints = b.leftPoints;
  a.rightPoints = b.rightPoints;
  a.count = b.count;
}

function rebuild(node, intervals) {
  var ntree = createIntervalTree(intervals);
  node.mid = ntree.mid;
  node.left = ntree.left;
  node.right = ntree.right;
  node.leftPoints = ntree.leftPoints;
  node.rightPoints = ntree.rightPoints;
  node.count = ntree.count;
}

function rebuildWithInterval(node, interval) {
  var intervals = node.intervals([]);
  intervals.push(interval);
  rebuild(node, intervals);
}

function rebuildWithoutInterval(node, interval) {
  var intervals = node.intervals([]);
  var idx = intervals.indexOf(interval);

  if (idx < 0) {
    return NOT_FOUND;
  }

  intervals.splice(idx, 1);
  rebuild(node, intervals);
  return SUCCESS;
}

proto.intervals = function (result) {
  result.push.apply(result, this.leftPoints);

  if (this.left) {
    this.left.intervals(result);
  }

  if (this.right) {
    this.right.intervals(result);
  }

  return result;
};

proto.insert = function (interval) {
  var weight = this.count - this.leftPoints.length;
  this.count += 1;

  if (interval[1] < this.mid) {
    if (this.left) {
      if (4 * (this.left.count + 1) > 3 * (weight + 1)) {
        rebuildWithInterval(this, interval);
      } else {
        this.left.insert(interval);
      }
    } else {
      this.left = createIntervalTree([interval]);
    }
  } else if (interval[0] > this.mid) {
    if (this.right) {
      if (4 * (this.right.count + 1) > 3 * (weight + 1)) {
        rebuildWithInterval(this, interval);
      } else {
        this.right.insert(interval);
      }
    } else {
      this.right = createIntervalTree([interval]);
    }
  } else {
    var l = _binarySearchBounds__WEBPACK_IMPORTED_MODULE_0__["default"].ge(this.leftPoints, interval, compareBegin);
    var r = _binarySearchBounds__WEBPACK_IMPORTED_MODULE_0__["default"].ge(this.rightPoints, interval, compareEnd);
    this.leftPoints.splice(l, 0, interval);
    this.rightPoints.splice(r, 0, interval);
  }
};

proto.remove = function (interval) {
  var weight = this.count - this.leftPoints;

  if (interval[1] < this.mid) {
    if (!this.left) {
      return NOT_FOUND;
    }

    var rw = this.right ? this.right.count : 0;

    if (4 * rw > 3 * (weight - 1)) {
      return rebuildWithoutInterval(this, interval);
    }

    var r = this.left.remove(interval);

    if (r === EMPTY) {
      this.left = null;
      this.count -= 1;
      return SUCCESS;
    } else if (r === SUCCESS) {
      this.count -= 1;
    }

    return r;
  } else if (interval[0] > this.mid) {
    if (!this.right) {
      return NOT_FOUND;
    }

    var lw = this.left ? this.left.count : 0;

    if (4 * lw > 3 * (weight - 1)) {
      return rebuildWithoutInterval(this, interval);
    }

    var r = this.right.remove(interval);

    if (r === EMPTY) {
      this.right = null;
      this.count -= 1;
      return SUCCESS;
    } else if (r === SUCCESS) {
      this.count -= 1;
    }

    return r;
  } else {
    if (this.count === 1) {
      if (this.leftPoints[0] === interval) {
        return EMPTY;
      } else {
        return NOT_FOUND;
      }
    }

    if (this.leftPoints.length === 1 && this.leftPoints[0] === interval) {
      if (this.left && this.right) {
        var p = this;
        var n = this.left;

        while (n.right) {
          p = n;
          n = n.right;
        }

        if (p === this) {
          n.right = this.right;
        } else {
          var l = this.left;
          var r = this.right;
          p.count -= n.count;
          p.right = n.left;
          n.left = l;
          n.right = r;
        }

        copy(this, n);
        this.count = (this.left ? this.left.count : 0) + (this.right ? this.right.count : 0) + this.leftPoints.length;
      } else if (this.left) {
        copy(this, this.left);
      } else {
        copy(this, this.right);
      }

      return SUCCESS;
    }

    for (var l = _binarySearchBounds__WEBPACK_IMPORTED_MODULE_0__["default"].ge(this.leftPoints, interval, compareBegin); l < this.leftPoints.length; ++l) {
      if (this.leftPoints[l][0] !== interval[0]) {
        break;
      }

      if (this.leftPoints[l] === interval) {
        this.count -= 1;
        this.leftPoints.splice(l, 1);

        for (var r = _binarySearchBounds__WEBPACK_IMPORTED_MODULE_0__["default"].ge(this.rightPoints, interval, compareEnd); r < this.rightPoints.length; ++r) {
          if (this.rightPoints[r][1] !== interval[1]) {
            break;
          } else if (this.rightPoints[r] === interval) {
            this.rightPoints.splice(r, 1);
            return SUCCESS;
          }
        }
      }
    }

    return NOT_FOUND;
  }
};

function reportLeftRange(arr, hi, cb) {
  for (var i = 0; i < arr.length && arr[i][0] <= hi; ++i) {
    var r = cb(arr[i]);

    if (r) {
      return r;
    }
  }
}

function reportRightRange(arr, lo, cb) {
  for (var i = arr.length - 1; i >= 0 && arr[i][1] >= lo; --i) {
    var r = cb(arr[i]);

    if (r) {
      return r;
    }
  }
}

function reportRange(arr, cb) {
  for (var i = 0; i < arr.length; ++i) {
    var r = cb(arr[i]);

    if (r) {
      return r;
    }
  }
}

proto.queryPoint = function (x, cb) {
  if (x < this.mid) {
    if (this.left) {
      var r = this.left.queryPoint(x, cb);

      if (r) {
        return r;
      }
    }

    return reportLeftRange(this.leftPoints, x, cb);
  } else if (x > this.mid) {
    if (this.right) {
      var r = this.right.queryPoint(x, cb);

      if (r) {
        return r;
      }
    }

    return reportRightRange(this.rightPoints, x, cb);
  } else {
    return reportRange(this.leftPoints, cb);
  }
};

proto.queryInterval = function (lo, hi, cb) {
  if (lo < this.mid && this.left) {
    var r = this.left.queryInterval(lo, hi, cb);

    if (r) {
      return r;
    }
  }

  if (hi > this.mid && this.right) {
    var r = this.right.queryInterval(lo, hi, cb);

    if (r) {
      return r;
    }
  }

  if (hi < this.mid) {
    return reportLeftRange(this.leftPoints, hi, cb);
  } else if (lo > this.mid) {
    return reportRightRange(this.rightPoints, lo, cb);
  } else {
    return reportRange(this.leftPoints, cb);
  }
};

function compareNumbers(a, b) {
  return a - b;
}

function compareBegin(a, b) {
  var d = a[0] - b[0];

  if (d) {
    return d;
  }

  return a[1] - b[1];
}

function compareEnd(a, b) {
  var d = a[1] - b[1];

  if (d) {
    return d;
  }

  return a[0] - b[0];
}

function createIntervalTree(intervals) {
  if (intervals.length === 0) {
    return null;
  }

  var pts = [];

  for (var i = 0; i < intervals.length; ++i) {
    pts.push(intervals[i][0], intervals[i][1]);
  }

  pts.sort(compareNumbers);
  var mid = pts[pts.length >> 1];
  var leftIntervals = [];
  var rightIntervals = [];
  var centerIntervals = [];

  for (var i = 0; i < intervals.length; ++i) {
    var s = intervals[i];

    if (s[1] < mid) {
      leftIntervals.push(s);
    } else if (mid < s[0]) {
      rightIntervals.push(s);
    } else {
      centerIntervals.push(s);
    }
  } //Split center intervals


  var leftPoints = centerIntervals;
  var rightPoints = centerIntervals.slice();
  leftPoints.sort(compareBegin);
  rightPoints.sort(compareEnd);
  return new IntervalTreeNode(mid, createIntervalTree(leftIntervals), createIntervalTree(rightIntervals), leftPoints, rightPoints);
} //User friendly wrapper that makes it possible to support empty trees


function IntervalTree(root) {
  this.root = root;
}

var tproto = IntervalTree.prototype;

tproto.insert = function (interval) {
  if (this.root) {
    this.root.insert(interval);
  } else {
    this.root = new IntervalTreeNode(interval[0], null, null, [interval], [interval]);
  }
};

tproto.remove = function (interval) {
  if (this.root) {
    var r = this.root.remove(interval);

    if (r === EMPTY) {
      this.root = null;
    }

    return r !== NOT_FOUND;
  }

  return false;
};

tproto.queryPoint = function (p, cb) {
  if (this.root) {
    return this.root.queryPoint(p, cb);
  }
};

tproto.queryInterval = function (lo, hi, cb) {
  if (lo <= hi && this.root) {
    return this.root.queryInterval(lo, hi, cb);
  }
};

Object.defineProperty(tproto, 'count', {
  get: function get() {
    if (this.root) {
      return this.root.count;
    }

    return 0;
  }
});
Object.defineProperty(tproto, 'intervals', {
  get: function get() {
    if (this.root) {
      return this.root.intervals([]);
    }

    return [];
  }
});
function createWrapper(intervals) {
  if (!intervals || intervals.length === 0) {
    return new IntervalTree(null);
  }

  return new IntervalTree(createIntervalTree(intervals));
}

/***/ }),

/***/ "../../node_modules/react/cjs/react-jsx-runtime.development.js":
/*!*********************************************************************!*\
  !*** ../../node_modules/react/cjs/react-jsx-runtime.development.js ***!
  \*********************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";
/** @license React v17.0.2
 * react-jsx-runtime.development.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */



if (true) {
  (function() {
'use strict';

var React = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
var _assign = __webpack_require__(/*! object-assign */ "../../node_modules/object-assign/index.js");

// ATTENTION
// When adding new symbols to this file,
// Please consider also adding to 'react-devtools-shared/src/backend/ReactSymbols'
// The Symbol used to tag the ReactElement-like types. If there is no native Symbol
// nor polyfill, then a plain number is used for performance.
var REACT_ELEMENT_TYPE = 0xeac7;
var REACT_PORTAL_TYPE = 0xeaca;
exports.Fragment = 0xeacb;
var REACT_STRICT_MODE_TYPE = 0xeacc;
var REACT_PROFILER_TYPE = 0xead2;
var REACT_PROVIDER_TYPE = 0xeacd;
var REACT_CONTEXT_TYPE = 0xeace;
var REACT_FORWARD_REF_TYPE = 0xead0;
var REACT_SUSPENSE_TYPE = 0xead1;
var REACT_SUSPENSE_LIST_TYPE = 0xead8;
var REACT_MEMO_TYPE = 0xead3;
var REACT_LAZY_TYPE = 0xead4;
var REACT_BLOCK_TYPE = 0xead9;
var REACT_SERVER_BLOCK_TYPE = 0xeada;
var REACT_FUNDAMENTAL_TYPE = 0xead5;
var REACT_SCOPE_TYPE = 0xead7;
var REACT_OPAQUE_ID_TYPE = 0xeae0;
var REACT_DEBUG_TRACING_MODE_TYPE = 0xeae1;
var REACT_OFFSCREEN_TYPE = 0xeae2;
var REACT_LEGACY_HIDDEN_TYPE = 0xeae3;

if (typeof Symbol === 'function' && Symbol.for) {
  var symbolFor = Symbol.for;
  REACT_ELEMENT_TYPE = symbolFor('react.element');
  REACT_PORTAL_TYPE = symbolFor('react.portal');
  exports.Fragment = symbolFor('react.fragment');
  REACT_STRICT_MODE_TYPE = symbolFor('react.strict_mode');
  REACT_PROFILER_TYPE = symbolFor('react.profiler');
  REACT_PROVIDER_TYPE = symbolFor('react.provider');
  REACT_CONTEXT_TYPE = symbolFor('react.context');
  REACT_FORWARD_REF_TYPE = symbolFor('react.forward_ref');
  REACT_SUSPENSE_TYPE = symbolFor('react.suspense');
  REACT_SUSPENSE_LIST_TYPE = symbolFor('react.suspense_list');
  REACT_MEMO_TYPE = symbolFor('react.memo');
  REACT_LAZY_TYPE = symbolFor('react.lazy');
  REACT_BLOCK_TYPE = symbolFor('react.block');
  REACT_SERVER_BLOCK_TYPE = symbolFor('react.server.block');
  REACT_FUNDAMENTAL_TYPE = symbolFor('react.fundamental');
  REACT_SCOPE_TYPE = symbolFor('react.scope');
  REACT_OPAQUE_ID_TYPE = symbolFor('react.opaque.id');
  REACT_DEBUG_TRACING_MODE_TYPE = symbolFor('react.debug_trace_mode');
  REACT_OFFSCREEN_TYPE = symbolFor('react.offscreen');
  REACT_LEGACY_HIDDEN_TYPE = symbolFor('react.legacy_hidden');
}

var MAYBE_ITERATOR_SYMBOL = typeof Symbol === 'function' && Symbol.iterator;
var FAUX_ITERATOR_SYMBOL = '@@iterator';
function getIteratorFn(maybeIterable) {
  if (maybeIterable === null || typeof maybeIterable !== 'object') {
    return null;
  }

  var maybeIterator = MAYBE_ITERATOR_SYMBOL && maybeIterable[MAYBE_ITERATOR_SYMBOL] || maybeIterable[FAUX_ITERATOR_SYMBOL];

  if (typeof maybeIterator === 'function') {
    return maybeIterator;
  }

  return null;
}

var ReactSharedInternals = React.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED;

function error(format) {
  {
    for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
      args[_key2 - 1] = arguments[_key2];
    }

    printWarning('error', format, args);
  }
}

function printWarning(level, format, args) {
  // When changing this logic, you might want to also
  // update consoleWithStackDev.www.js as well.
  {
    var ReactDebugCurrentFrame = ReactSharedInternals.ReactDebugCurrentFrame;
    var stack = ReactDebugCurrentFrame.getStackAddendum();

    if (stack !== '') {
      format += '%s';
      args = args.concat([stack]);
    }

    var argsWithFormat = args.map(function (item) {
      return '' + item;
    }); // Careful: RN currently depends on this prefix

    argsWithFormat.unshift('Warning: ' + format); // We intentionally don't use spread (or .apply) directly because it
    // breaks IE9: https://github.com/facebook/react/issues/13610
    // eslint-disable-next-line react-internal/no-production-logging

    Function.prototype.apply.call(console[level], console, argsWithFormat);
  }
}

// Filter certain DOM attributes (e.g. src, href) if their values are empty strings.

var enableScopeAPI = false; // Experimental Create Event Handle API.

function isValidElementType(type) {
  if (typeof type === 'string' || typeof type === 'function') {
    return true;
  } // Note: typeof might be other than 'symbol' or 'number' (e.g. if it's a polyfill).


  if (type === exports.Fragment || type === REACT_PROFILER_TYPE || type === REACT_DEBUG_TRACING_MODE_TYPE || type === REACT_STRICT_MODE_TYPE || type === REACT_SUSPENSE_TYPE || type === REACT_SUSPENSE_LIST_TYPE || type === REACT_LEGACY_HIDDEN_TYPE || enableScopeAPI ) {
    return true;
  }

  if (typeof type === 'object' && type !== null) {
    if (type.$$typeof === REACT_LAZY_TYPE || type.$$typeof === REACT_MEMO_TYPE || type.$$typeof === REACT_PROVIDER_TYPE || type.$$typeof === REACT_CONTEXT_TYPE || type.$$typeof === REACT_FORWARD_REF_TYPE || type.$$typeof === REACT_FUNDAMENTAL_TYPE || type.$$typeof === REACT_BLOCK_TYPE || type[0] === REACT_SERVER_BLOCK_TYPE) {
      return true;
    }
  }

  return false;
}

function getWrappedName(outerType, innerType, wrapperName) {
  var functionName = innerType.displayName || innerType.name || '';
  return outerType.displayName || (functionName !== '' ? wrapperName + "(" + functionName + ")" : wrapperName);
}

function getContextName(type) {
  return type.displayName || 'Context';
}

function getComponentName(type) {
  if (type == null) {
    // Host root, text node or just invalid type.
    return null;
  }

  {
    if (typeof type.tag === 'number') {
      error('Received an unexpected object in getComponentName(). ' + 'This is likely a bug in React. Please file an issue.');
    }
  }

  if (typeof type === 'function') {
    return type.displayName || type.name || null;
  }

  if (typeof type === 'string') {
    return type;
  }

  switch (type) {
    case exports.Fragment:
      return 'Fragment';

    case REACT_PORTAL_TYPE:
      return 'Portal';

    case REACT_PROFILER_TYPE:
      return 'Profiler';

    case REACT_STRICT_MODE_TYPE:
      return 'StrictMode';

    case REACT_SUSPENSE_TYPE:
      return 'Suspense';

    case REACT_SUSPENSE_LIST_TYPE:
      return 'SuspenseList';
  }

  if (typeof type === 'object') {
    switch (type.$$typeof) {
      case REACT_CONTEXT_TYPE:
        var context = type;
        return getContextName(context) + '.Consumer';

      case REACT_PROVIDER_TYPE:
        var provider = type;
        return getContextName(provider._context) + '.Provider';

      case REACT_FORWARD_REF_TYPE:
        return getWrappedName(type, type.render, 'ForwardRef');

      case REACT_MEMO_TYPE:
        return getComponentName(type.type);

      case REACT_BLOCK_TYPE:
        return getComponentName(type._render);

      case REACT_LAZY_TYPE:
        {
          var lazyComponent = type;
          var payload = lazyComponent._payload;
          var init = lazyComponent._init;

          try {
            return getComponentName(init(payload));
          } catch (x) {
            return null;
          }
        }
    }
  }

  return null;
}

// Helpers to patch console.logs to avoid logging during side-effect free
// replaying on render function. This currently only patches the object
// lazily which won't cover if the log function was extracted eagerly.
// We could also eagerly patch the method.
var disabledDepth = 0;
var prevLog;
var prevInfo;
var prevWarn;
var prevError;
var prevGroup;
var prevGroupCollapsed;
var prevGroupEnd;

function disabledLog() {}

disabledLog.__reactDisabledLog = true;
function disableLogs() {
  {
    if (disabledDepth === 0) {
      /* eslint-disable react-internal/no-production-logging */
      prevLog = console.log;
      prevInfo = console.info;
      prevWarn = console.warn;
      prevError = console.error;
      prevGroup = console.group;
      prevGroupCollapsed = console.groupCollapsed;
      prevGroupEnd = console.groupEnd; // https://github.com/facebook/react/issues/19099

      var props = {
        configurable: true,
        enumerable: true,
        value: disabledLog,
        writable: true
      }; // $FlowFixMe Flow thinks console is immutable.

      Object.defineProperties(console, {
        info: props,
        log: props,
        warn: props,
        error: props,
        group: props,
        groupCollapsed: props,
        groupEnd: props
      });
      /* eslint-enable react-internal/no-production-logging */
    }

    disabledDepth++;
  }
}
function reenableLogs() {
  {
    disabledDepth--;

    if (disabledDepth === 0) {
      /* eslint-disable react-internal/no-production-logging */
      var props = {
        configurable: true,
        enumerable: true,
        writable: true
      }; // $FlowFixMe Flow thinks console is immutable.

      Object.defineProperties(console, {
        log: _assign({}, props, {
          value: prevLog
        }),
        info: _assign({}, props, {
          value: prevInfo
        }),
        warn: _assign({}, props, {
          value: prevWarn
        }),
        error: _assign({}, props, {
          value: prevError
        }),
        group: _assign({}, props, {
          value: prevGroup
        }),
        groupCollapsed: _assign({}, props, {
          value: prevGroupCollapsed
        }),
        groupEnd: _assign({}, props, {
          value: prevGroupEnd
        })
      });
      /* eslint-enable react-internal/no-production-logging */
    }

    if (disabledDepth < 0) {
      error('disabledDepth fell below zero. ' + 'This is a bug in React. Please file an issue.');
    }
  }
}

var ReactCurrentDispatcher = ReactSharedInternals.ReactCurrentDispatcher;
var prefix;
function describeBuiltInComponentFrame(name, source, ownerFn) {
  {
    if (prefix === undefined) {
      // Extract the VM specific prefix used by each line.
      try {
        throw Error();
      } catch (x) {
        var match = x.stack.trim().match(/\n( *(at )?)/);
        prefix = match && match[1] || '';
      }
    } // We use the prefix to ensure our stacks line up with native stack frames.


    return '\n' + prefix + name;
  }
}
var reentry = false;
var componentFrameCache;

{
  var PossiblyWeakMap = typeof WeakMap === 'function' ? WeakMap : Map;
  componentFrameCache = new PossiblyWeakMap();
}

function describeNativeComponentFrame(fn, construct) {
  // If something asked for a stack inside a fake render, it should get ignored.
  if (!fn || reentry) {
    return '';
  }

  {
    var frame = componentFrameCache.get(fn);

    if (frame !== undefined) {
      return frame;
    }
  }

  var control;
  reentry = true;
  var previousPrepareStackTrace = Error.prepareStackTrace; // $FlowFixMe It does accept undefined.

  Error.prepareStackTrace = undefined;
  var previousDispatcher;

  {
    previousDispatcher = ReactCurrentDispatcher.current; // Set the dispatcher in DEV because this might be call in the render function
    // for warnings.

    ReactCurrentDispatcher.current = null;
    disableLogs();
  }

  try {
    // This should throw.
    if (construct) {
      // Something should be setting the props in the constructor.
      var Fake = function () {
        throw Error();
      }; // $FlowFixMe


      Object.defineProperty(Fake.prototype, 'props', {
        set: function () {
          // We use a throwing setter instead of frozen or non-writable props
          // because that won't throw in a non-strict mode function.
          throw Error();
        }
      });

      if (typeof Reflect === 'object' && Reflect.construct) {
        // We construct a different control for this case to include any extra
        // frames added by the construct call.
        try {
          Reflect.construct(Fake, []);
        } catch (x) {
          control = x;
        }

        Reflect.construct(fn, [], Fake);
      } else {
        try {
          Fake.call();
        } catch (x) {
          control = x;
        }

        fn.call(Fake.prototype);
      }
    } else {
      try {
        throw Error();
      } catch (x) {
        control = x;
      }

      fn();
    }
  } catch (sample) {
    // This is inlined manually because closure doesn't do it for us.
    if (sample && control && typeof sample.stack === 'string') {
      // This extracts the first frame from the sample that isn't also in the control.
      // Skipping one frame that we assume is the frame that calls the two.
      var sampleLines = sample.stack.split('\n');
      var controlLines = control.stack.split('\n');
      var s = sampleLines.length - 1;
      var c = controlLines.length - 1;

      while (s >= 1 && c >= 0 && sampleLines[s] !== controlLines[c]) {
        // We expect at least one stack frame to be shared.
        // Typically this will be the root most one. However, stack frames may be
        // cut off due to maximum stack limits. In this case, one maybe cut off
        // earlier than the other. We assume that the sample is longer or the same
        // and there for cut off earlier. So we should find the root most frame in
        // the sample somewhere in the control.
        c--;
      }

      for (; s >= 1 && c >= 0; s--, c--) {
        // Next we find the first one that isn't the same which should be the
        // frame that called our sample function and the control.
        if (sampleLines[s] !== controlLines[c]) {
          // In V8, the first line is describing the message but other VMs don't.
          // If we're about to return the first line, and the control is also on the same
          // line, that's a pretty good indicator that our sample threw at same line as
          // the control. I.e. before we entered the sample frame. So we ignore this result.
          // This can happen if you passed a class to function component, or non-function.
          if (s !== 1 || c !== 1) {
            do {
              s--;
              c--; // We may still have similar intermediate frames from the construct call.
              // The next one that isn't the same should be our match though.

              if (c < 0 || sampleLines[s] !== controlLines[c]) {
                // V8 adds a "new" prefix for native classes. Let's remove it to make it prettier.
                var _frame = '\n' + sampleLines[s].replace(' at new ', ' at ');

                {
                  if (typeof fn === 'function') {
                    componentFrameCache.set(fn, _frame);
                  }
                } // Return the line we found.


                return _frame;
              }
            } while (s >= 1 && c >= 0);
          }

          break;
        }
      }
    }
  } finally {
    reentry = false;

    {
      ReactCurrentDispatcher.current = previousDispatcher;
      reenableLogs();
    }

    Error.prepareStackTrace = previousPrepareStackTrace;
  } // Fallback to just using the name if we couldn't make it throw.


  var name = fn ? fn.displayName || fn.name : '';
  var syntheticFrame = name ? describeBuiltInComponentFrame(name) : '';

  {
    if (typeof fn === 'function') {
      componentFrameCache.set(fn, syntheticFrame);
    }
  }

  return syntheticFrame;
}
function describeFunctionComponentFrame(fn, source, ownerFn) {
  {
    return describeNativeComponentFrame(fn, false);
  }
}

function shouldConstruct(Component) {
  var prototype = Component.prototype;
  return !!(prototype && prototype.isReactComponent);
}

function describeUnknownElementTypeFrameInDEV(type, source, ownerFn) {

  if (type == null) {
    return '';
  }

  if (typeof type === 'function') {
    {
      return describeNativeComponentFrame(type, shouldConstruct(type));
    }
  }

  if (typeof type === 'string') {
    return describeBuiltInComponentFrame(type);
  }

  switch (type) {
    case REACT_SUSPENSE_TYPE:
      return describeBuiltInComponentFrame('Suspense');

    case REACT_SUSPENSE_LIST_TYPE:
      return describeBuiltInComponentFrame('SuspenseList');
  }

  if (typeof type === 'object') {
    switch (type.$$typeof) {
      case REACT_FORWARD_REF_TYPE:
        return describeFunctionComponentFrame(type.render);

      case REACT_MEMO_TYPE:
        // Memo may contain any component type so we recursively resolve it.
        return describeUnknownElementTypeFrameInDEV(type.type, source, ownerFn);

      case REACT_BLOCK_TYPE:
        return describeFunctionComponentFrame(type._render);

      case REACT_LAZY_TYPE:
        {
          var lazyComponent = type;
          var payload = lazyComponent._payload;
          var init = lazyComponent._init;

          try {
            // Lazy may contain any component type so we recursively resolve it.
            return describeUnknownElementTypeFrameInDEV(init(payload), source, ownerFn);
          } catch (x) {}
        }
    }
  }

  return '';
}

var loggedTypeFailures = {};
var ReactDebugCurrentFrame = ReactSharedInternals.ReactDebugCurrentFrame;

function setCurrentlyValidatingElement(element) {
  {
    if (element) {
      var owner = element._owner;
      var stack = describeUnknownElementTypeFrameInDEV(element.type, element._source, owner ? owner.type : null);
      ReactDebugCurrentFrame.setExtraStackFrame(stack);
    } else {
      ReactDebugCurrentFrame.setExtraStackFrame(null);
    }
  }
}

function checkPropTypes(typeSpecs, values, location, componentName, element) {
  {
    // $FlowFixMe This is okay but Flow doesn't know it.
    var has = Function.call.bind(Object.prototype.hasOwnProperty);

    for (var typeSpecName in typeSpecs) {
      if (has(typeSpecs, typeSpecName)) {
        var error$1 = void 0; // Prop type validation may throw. In case they do, we don't want to
        // fail the render phase where it didn't fail before. So we log it.
        // After these have been cleaned up, we'll let them throw.

        try {
          // This is intentionally an invariant that gets caught. It's the same
          // behavior as without this statement except with a better message.
          if (typeof typeSpecs[typeSpecName] !== 'function') {
            var err = Error((componentName || 'React class') + ': ' + location + ' type `' + typeSpecName + '` is invalid; ' + 'it must be a function, usually from the `prop-types` package, but received `' + typeof typeSpecs[typeSpecName] + '`.' + 'This often happens because of typos such as `PropTypes.function` instead of `PropTypes.func`.');
            err.name = 'Invariant Violation';
            throw err;
          }

          error$1 = typeSpecs[typeSpecName](values, typeSpecName, componentName, location, null, 'SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED');
        } catch (ex) {
          error$1 = ex;
        }

        if (error$1 && !(error$1 instanceof Error)) {
          setCurrentlyValidatingElement(element);

          error('%s: type specification of %s' + ' `%s` is invalid; the type checker ' + 'function must return `null` or an `Error` but returned a %s. ' + 'You may have forgotten to pass an argument to the type checker ' + 'creator (arrayOf, instanceOf, objectOf, oneOf, oneOfType, and ' + 'shape all require an argument).', componentName || 'React class', location, typeSpecName, typeof error$1);

          setCurrentlyValidatingElement(null);
        }

        if (error$1 instanceof Error && !(error$1.message in loggedTypeFailures)) {
          // Only monitor this failure once because there tends to be a lot of the
          // same error.
          loggedTypeFailures[error$1.message] = true;
          setCurrentlyValidatingElement(element);

          error('Failed %s type: %s', location, error$1.message);

          setCurrentlyValidatingElement(null);
        }
      }
    }
  }
}

var ReactCurrentOwner = ReactSharedInternals.ReactCurrentOwner;
var hasOwnProperty = Object.prototype.hasOwnProperty;
var RESERVED_PROPS = {
  key: true,
  ref: true,
  __self: true,
  __source: true
};
var specialPropKeyWarningShown;
var specialPropRefWarningShown;
var didWarnAboutStringRefs;

{
  didWarnAboutStringRefs = {};
}

function hasValidRef(config) {
  {
    if (hasOwnProperty.call(config, 'ref')) {
      var getter = Object.getOwnPropertyDescriptor(config, 'ref').get;

      if (getter && getter.isReactWarning) {
        return false;
      }
    }
  }

  return config.ref !== undefined;
}

function hasValidKey(config) {
  {
    if (hasOwnProperty.call(config, 'key')) {
      var getter = Object.getOwnPropertyDescriptor(config, 'key').get;

      if (getter && getter.isReactWarning) {
        return false;
      }
    }
  }

  return config.key !== undefined;
}

function warnIfStringRefCannotBeAutoConverted(config, self) {
  {
    if (typeof config.ref === 'string' && ReactCurrentOwner.current && self && ReactCurrentOwner.current.stateNode !== self) {
      var componentName = getComponentName(ReactCurrentOwner.current.type);

      if (!didWarnAboutStringRefs[componentName]) {
        error('Component "%s" contains the string ref "%s". ' + 'Support for string refs will be removed in a future major release. ' + 'This case cannot be automatically converted to an arrow function. ' + 'We ask you to manually fix this case by using useRef() or createRef() instead. ' + 'Learn more about using refs safely here: ' + 'https://reactjs.org/link/strict-mode-string-ref', getComponentName(ReactCurrentOwner.current.type), config.ref);

        didWarnAboutStringRefs[componentName] = true;
      }
    }
  }
}

function defineKeyPropWarningGetter(props, displayName) {
  {
    var warnAboutAccessingKey = function () {
      if (!specialPropKeyWarningShown) {
        specialPropKeyWarningShown = true;

        error('%s: `key` is not a prop. Trying to access it will result ' + 'in `undefined` being returned. If you need to access the same ' + 'value within the child component, you should pass it as a different ' + 'prop. (https://reactjs.org/link/special-props)', displayName);
      }
    };

    warnAboutAccessingKey.isReactWarning = true;
    Object.defineProperty(props, 'key', {
      get: warnAboutAccessingKey,
      configurable: true
    });
  }
}

function defineRefPropWarningGetter(props, displayName) {
  {
    var warnAboutAccessingRef = function () {
      if (!specialPropRefWarningShown) {
        specialPropRefWarningShown = true;

        error('%s: `ref` is not a prop. Trying to access it will result ' + 'in `undefined` being returned. If you need to access the same ' + 'value within the child component, you should pass it as a different ' + 'prop. (https://reactjs.org/link/special-props)', displayName);
      }
    };

    warnAboutAccessingRef.isReactWarning = true;
    Object.defineProperty(props, 'ref', {
      get: warnAboutAccessingRef,
      configurable: true
    });
  }
}
/**
 * Factory method to create a new React element. This no longer adheres to
 * the class pattern, so do not use new to call it. Also, instanceof check
 * will not work. Instead test $$typeof field against Symbol.for('react.element') to check
 * if something is a React Element.
 *
 * @param {*} type
 * @param {*} props
 * @param {*} key
 * @param {string|object} ref
 * @param {*} owner
 * @param {*} self A *temporary* helper to detect places where `this` is
 * different from the `owner` when React.createElement is called, so that we
 * can warn. We want to get rid of owner and replace string `ref`s with arrow
 * functions, and as long as `this` and owner are the same, there will be no
 * change in behavior.
 * @param {*} source An annotation object (added by a transpiler or otherwise)
 * indicating filename, line number, and/or other information.
 * @internal
 */


var ReactElement = function (type, key, ref, self, source, owner, props) {
  var element = {
    // This tag allows us to uniquely identify this as a React Element
    $$typeof: REACT_ELEMENT_TYPE,
    // Built-in properties that belong on the element
    type: type,
    key: key,
    ref: ref,
    props: props,
    // Record the component responsible for creating this element.
    _owner: owner
  };

  {
    // The validation flag is currently mutative. We put it on
    // an external backing store so that we can freeze the whole object.
    // This can be replaced with a WeakMap once they are implemented in
    // commonly used development environments.
    element._store = {}; // To make comparing ReactElements easier for testing purposes, we make
    // the validation flag non-enumerable (where possible, which should
    // include every environment we run tests in), so the test framework
    // ignores it.

    Object.defineProperty(element._store, 'validated', {
      configurable: false,
      enumerable: false,
      writable: true,
      value: false
    }); // self and source are DEV only properties.

    Object.defineProperty(element, '_self', {
      configurable: false,
      enumerable: false,
      writable: false,
      value: self
    }); // Two elements created in two different places should be considered
    // equal for testing purposes and therefore we hide it from enumeration.

    Object.defineProperty(element, '_source', {
      configurable: false,
      enumerable: false,
      writable: false,
      value: source
    });

    if (Object.freeze) {
      Object.freeze(element.props);
      Object.freeze(element);
    }
  }

  return element;
};
/**
 * https://github.com/reactjs/rfcs/pull/107
 * @param {*} type
 * @param {object} props
 * @param {string} key
 */

function jsxDEV(type, config, maybeKey, source, self) {
  {
    var propName; // Reserved names are extracted

    var props = {};
    var key = null;
    var ref = null; // Currently, key can be spread in as a prop. This causes a potential
    // issue if key is also explicitly declared (ie. <div {...props} key="Hi" />
    // or <div key="Hi" {...props} /> ). We want to deprecate key spread,
    // but as an intermediary step, we will use jsxDEV for everything except
    // <div {...props} key="Hi" />, because we aren't currently able to tell if
    // key is explicitly declared to be undefined or not.

    if (maybeKey !== undefined) {
      key = '' + maybeKey;
    }

    if (hasValidKey(config)) {
      key = '' + config.key;
    }

    if (hasValidRef(config)) {
      ref = config.ref;
      warnIfStringRefCannotBeAutoConverted(config, self);
    } // Remaining properties are added to a new props object


    for (propName in config) {
      if (hasOwnProperty.call(config, propName) && !RESERVED_PROPS.hasOwnProperty(propName)) {
        props[propName] = config[propName];
      }
    } // Resolve default props


    if (type && type.defaultProps) {
      var defaultProps = type.defaultProps;

      for (propName in defaultProps) {
        if (props[propName] === undefined) {
          props[propName] = defaultProps[propName];
        }
      }
    }

    if (key || ref) {
      var displayName = typeof type === 'function' ? type.displayName || type.name || 'Unknown' : type;

      if (key) {
        defineKeyPropWarningGetter(props, displayName);
      }

      if (ref) {
        defineRefPropWarningGetter(props, displayName);
      }
    }

    return ReactElement(type, key, ref, self, source, ReactCurrentOwner.current, props);
  }
}

var ReactCurrentOwner$1 = ReactSharedInternals.ReactCurrentOwner;
var ReactDebugCurrentFrame$1 = ReactSharedInternals.ReactDebugCurrentFrame;

function setCurrentlyValidatingElement$1(element) {
  {
    if (element) {
      var owner = element._owner;
      var stack = describeUnknownElementTypeFrameInDEV(element.type, element._source, owner ? owner.type : null);
      ReactDebugCurrentFrame$1.setExtraStackFrame(stack);
    } else {
      ReactDebugCurrentFrame$1.setExtraStackFrame(null);
    }
  }
}

var propTypesMisspellWarningShown;

{
  propTypesMisspellWarningShown = false;
}
/**
 * Verifies the object is a ReactElement.
 * See https://reactjs.org/docs/react-api.html#isvalidelement
 * @param {?object} object
 * @return {boolean} True if `object` is a ReactElement.
 * @final
 */

function isValidElement(object) {
  {
    return typeof object === 'object' && object !== null && object.$$typeof === REACT_ELEMENT_TYPE;
  }
}

function getDeclarationErrorAddendum() {
  {
    if (ReactCurrentOwner$1.current) {
      var name = getComponentName(ReactCurrentOwner$1.current.type);

      if (name) {
        return '\n\nCheck the render method of `' + name + '`.';
      }
    }

    return '';
  }
}

function getSourceInfoErrorAddendum(source) {
  {
    if (source !== undefined) {
      var fileName = source.fileName.replace(/^.*[\\\/]/, '');
      var lineNumber = source.lineNumber;
      return '\n\nCheck your code at ' + fileName + ':' + lineNumber + '.';
    }

    return '';
  }
}
/**
 * Warn if there's no key explicitly set on dynamic arrays of children or
 * object keys are not valid. This allows us to keep track of children between
 * updates.
 */


var ownerHasKeyUseWarning = {};

function getCurrentComponentErrorInfo(parentType) {
  {
    var info = getDeclarationErrorAddendum();

    if (!info) {
      var parentName = typeof parentType === 'string' ? parentType : parentType.displayName || parentType.name;

      if (parentName) {
        info = "\n\nCheck the top-level render call using <" + parentName + ">.";
      }
    }

    return info;
  }
}
/**
 * Warn if the element doesn't have an explicit key assigned to it.
 * This element is in an array. The array could grow and shrink or be
 * reordered. All children that haven't already been validated are required to
 * have a "key" property assigned to it. Error statuses are cached so a warning
 * will only be shown once.
 *
 * @internal
 * @param {ReactElement} element Element that requires a key.
 * @param {*} parentType element's parent's type.
 */


function validateExplicitKey(element, parentType) {
  {
    if (!element._store || element._store.validated || element.key != null) {
      return;
    }

    element._store.validated = true;
    var currentComponentErrorInfo = getCurrentComponentErrorInfo(parentType);

    if (ownerHasKeyUseWarning[currentComponentErrorInfo]) {
      return;
    }

    ownerHasKeyUseWarning[currentComponentErrorInfo] = true; // Usually the current owner is the offender, but if it accepts children as a
    // property, it may be the creator of the child that's responsible for
    // assigning it a key.

    var childOwner = '';

    if (element && element._owner && element._owner !== ReactCurrentOwner$1.current) {
      // Give the component that originally created this child.
      childOwner = " It was passed a child from " + getComponentName(element._owner.type) + ".";
    }

    setCurrentlyValidatingElement$1(element);

    error('Each child in a list should have a unique "key" prop.' + '%s%s See https://reactjs.org/link/warning-keys for more information.', currentComponentErrorInfo, childOwner);

    setCurrentlyValidatingElement$1(null);
  }
}
/**
 * Ensure that every element either is passed in a static location, in an
 * array with an explicit keys property defined, or in an object literal
 * with valid key property.
 *
 * @internal
 * @param {ReactNode} node Statically passed child of any type.
 * @param {*} parentType node's parent's type.
 */


function validateChildKeys(node, parentType) {
  {
    if (typeof node !== 'object') {
      return;
    }

    if (Array.isArray(node)) {
      for (var i = 0; i < node.length; i++) {
        var child = node[i];

        if (isValidElement(child)) {
          validateExplicitKey(child, parentType);
        }
      }
    } else if (isValidElement(node)) {
      // This element was passed in a valid location.
      if (node._store) {
        node._store.validated = true;
      }
    } else if (node) {
      var iteratorFn = getIteratorFn(node);

      if (typeof iteratorFn === 'function') {
        // Entry iterators used to provide implicit keys,
        // but now we print a separate warning for them later.
        if (iteratorFn !== node.entries) {
          var iterator = iteratorFn.call(node);
          var step;

          while (!(step = iterator.next()).done) {
            if (isValidElement(step.value)) {
              validateExplicitKey(step.value, parentType);
            }
          }
        }
      }
    }
  }
}
/**
 * Given an element, validate that its props follow the propTypes definition,
 * provided by the type.
 *
 * @param {ReactElement} element
 */


function validatePropTypes(element) {
  {
    var type = element.type;

    if (type === null || type === undefined || typeof type === 'string') {
      return;
    }

    var propTypes;

    if (typeof type === 'function') {
      propTypes = type.propTypes;
    } else if (typeof type === 'object' && (type.$$typeof === REACT_FORWARD_REF_TYPE || // Note: Memo only checks outer props here.
    // Inner props are checked in the reconciler.
    type.$$typeof === REACT_MEMO_TYPE)) {
      propTypes = type.propTypes;
    } else {
      return;
    }

    if (propTypes) {
      // Intentionally inside to avoid triggering lazy initializers:
      var name = getComponentName(type);
      checkPropTypes(propTypes, element.props, 'prop', name, element);
    } else if (type.PropTypes !== undefined && !propTypesMisspellWarningShown) {
      propTypesMisspellWarningShown = true; // Intentionally inside to avoid triggering lazy initializers:

      var _name = getComponentName(type);

      error('Component %s declared `PropTypes` instead of `propTypes`. Did you misspell the property assignment?', _name || 'Unknown');
    }

    if (typeof type.getDefaultProps === 'function' && !type.getDefaultProps.isReactClassApproved) {
      error('getDefaultProps is only used on classic React.createClass ' + 'definitions. Use a static property named `defaultProps` instead.');
    }
  }
}
/**
 * Given a fragment, validate that it can only be provided with fragment props
 * @param {ReactElement} fragment
 */


function validateFragmentProps(fragment) {
  {
    var keys = Object.keys(fragment.props);

    for (var i = 0; i < keys.length; i++) {
      var key = keys[i];

      if (key !== 'children' && key !== 'key') {
        setCurrentlyValidatingElement$1(fragment);

        error('Invalid prop `%s` supplied to `React.Fragment`. ' + 'React.Fragment can only have `key` and `children` props.', key);

        setCurrentlyValidatingElement$1(null);
        break;
      }
    }

    if (fragment.ref !== null) {
      setCurrentlyValidatingElement$1(fragment);

      error('Invalid attribute `ref` supplied to `React.Fragment`.');

      setCurrentlyValidatingElement$1(null);
    }
  }
}

function jsxWithValidation(type, props, key, isStaticChildren, source, self) {
  {
    var validType = isValidElementType(type); // We warn in this case but don't throw. We expect the element creation to
    // succeed and there will likely be errors in render.

    if (!validType) {
      var info = '';

      if (type === undefined || typeof type === 'object' && type !== null && Object.keys(type).length === 0) {
        info += ' You likely forgot to export your component from the file ' + "it's defined in, or you might have mixed up default and named imports.";
      }

      var sourceInfo = getSourceInfoErrorAddendum(source);

      if (sourceInfo) {
        info += sourceInfo;
      } else {
        info += getDeclarationErrorAddendum();
      }

      var typeString;

      if (type === null) {
        typeString = 'null';
      } else if (Array.isArray(type)) {
        typeString = 'array';
      } else if (type !== undefined && type.$$typeof === REACT_ELEMENT_TYPE) {
        typeString = "<" + (getComponentName(type.type) || 'Unknown') + " />";
        info = ' Did you accidentally export a JSX literal instead of a component?';
      } else {
        typeString = typeof type;
      }

      error('React.jsx: type is invalid -- expected a string (for ' + 'built-in components) or a class/function (for composite ' + 'components) but got: %s.%s', typeString, info);
    }

    var element = jsxDEV(type, props, key, source, self); // The result can be nullish if a mock or a custom function is used.
    // TODO: Drop this when these are no longer allowed as the type argument.

    if (element == null) {
      return element;
    } // Skip key warning if the type isn't valid since our key validation logic
    // doesn't expect a non-string/function type and can throw confusing errors.
    // We don't want exception behavior to differ between dev and prod.
    // (Rendering will throw with a helpful message and as soon as the type is
    // fixed, the key warnings will appear.)


    if (validType) {
      var children = props.children;

      if (children !== undefined) {
        if (isStaticChildren) {
          if (Array.isArray(children)) {
            for (var i = 0; i < children.length; i++) {
              validateChildKeys(children[i], type);
            }

            if (Object.freeze) {
              Object.freeze(children);
            }
          } else {
            error('React.jsx: Static children should always be an array. ' + 'You are likely explicitly calling React.jsxs or React.jsxDEV. ' + 'Use the Babel transform instead.');
          }
        } else {
          validateChildKeys(children, type);
        }
      }
    }

    if (type === exports.Fragment) {
      validateFragmentProps(element);
    } else {
      validatePropTypes(element);
    }

    return element;
  }
} // These two functions exist to still get child warnings in dev
// even with the prod transform. This means that jsxDEV is purely
// opt-in behavior for better messages but that we won't stop
// giving you warnings if you use production apis.

function jsxWithValidationStatic(type, props, key) {
  {
    return jsxWithValidation(type, props, key, true);
  }
}
function jsxWithValidationDynamic(type, props, key) {
  {
    return jsxWithValidation(type, props, key, false);
  }
}

var jsx =  jsxWithValidationDynamic ; // we may want to special case jsxs internally to take advantage of static children.
// for now we can ship identical prod functions

var jsxs =  jsxWithValidationStatic ;

exports.jsx = jsx;
exports.jsxs = jsxs;
  })();
}


/***/ }),

/***/ "../../node_modules/react/jsx-runtime.js":
/*!***********************************************!*\
  !*** ../../node_modules/react/jsx-runtime.js ***!
  \***********************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

"use strict";


if (false) {} else {
  module.exports = __webpack_require__(/*! ./cjs/react-jsx-runtime.development.js */ "../../node_modules/react/cjs/react-jsx-runtime.development.js");
}


/***/ }),

/***/ "../../node_modules/redux/es/redux.js":
/*!********************************************!*\
  !*** ../../node_modules/redux/es/redux.js ***!
  \********************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "__DO_NOT_USE__ActionTypes": () => (/* binding */ ActionTypes),
/* harmony export */   "applyMiddleware": () => (/* binding */ applyMiddleware),
/* harmony export */   "bindActionCreators": () => (/* binding */ bindActionCreators),
/* harmony export */   "combineReducers": () => (/* binding */ combineReducers),
/* harmony export */   "compose": () => (/* binding */ compose),
/* harmony export */   "createStore": () => (/* binding */ createStore),
/* harmony export */   "legacy_createStore": () => (/* binding */ legacy_createStore)
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_esm_objectSpread2__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @babel/runtime/helpers/esm/objectSpread2 */ "../../node_modules/@babel/runtime/helpers/esm/objectSpread2.js");


/**
 * Adapted from React: https://github.com/facebook/react/blob/master/packages/shared/formatProdErrorMessage.js
 *
 * Do not require this module directly! Use normal throw error calls. These messages will be replaced with error codes
 * during build.
 * @param {number} code
 */
function formatProdErrorMessage(code) {
  return "Minified Redux error #" + code + "; visit https://redux.js.org/Errors?code=" + code + " for the full message or " + 'use the non-minified dev environment for full errors. ';
}

// Inlined version of the `symbol-observable` polyfill
var $$observable = (function () {
  return typeof Symbol === 'function' && Symbol.observable || '@@observable';
})();

/**
 * These are private action types reserved by Redux.
 * For any unknown actions, you must return the current state.
 * If the current state is undefined, you must return the initial state.
 * Do not reference these action types directly in your code.
 */
var randomString = function randomString() {
  return Math.random().toString(36).substring(7).split('').join('.');
};

var ActionTypes = {
  INIT: "@@redux/INIT" + randomString(),
  REPLACE: "@@redux/REPLACE" + randomString(),
  PROBE_UNKNOWN_ACTION: function PROBE_UNKNOWN_ACTION() {
    return "@@redux/PROBE_UNKNOWN_ACTION" + randomString();
  }
};

/**
 * @param {any} obj The object to inspect.
 * @returns {boolean} True if the argument appears to be a plain object.
 */
function isPlainObject(obj) {
  if (typeof obj !== 'object' || obj === null) return false;
  var proto = obj;

  while (Object.getPrototypeOf(proto) !== null) {
    proto = Object.getPrototypeOf(proto);
  }

  return Object.getPrototypeOf(obj) === proto;
}

// Inlined / shortened version of `kindOf` from https://github.com/jonschlinkert/kind-of
function miniKindOf(val) {
  if (val === void 0) return 'undefined';
  if (val === null) return 'null';
  var type = typeof val;

  switch (type) {
    case 'boolean':
    case 'string':
    case 'number':
    case 'symbol':
    case 'function':
      {
        return type;
      }
  }

  if (Array.isArray(val)) return 'array';
  if (isDate(val)) return 'date';
  if (isError(val)) return 'error';
  var constructorName = ctorName(val);

  switch (constructorName) {
    case 'Symbol':
    case 'Promise':
    case 'WeakMap':
    case 'WeakSet':
    case 'Map':
    case 'Set':
      return constructorName;
  } // other


  return type.slice(8, -1).toLowerCase().replace(/\s/g, '');
}

function ctorName(val) {
  return typeof val.constructor === 'function' ? val.constructor.name : null;
}

function isError(val) {
  return val instanceof Error || typeof val.message === 'string' && val.constructor && typeof val.constructor.stackTraceLimit === 'number';
}

function isDate(val) {
  if (val instanceof Date) return true;
  return typeof val.toDateString === 'function' && typeof val.getDate === 'function' && typeof val.setDate === 'function';
}

function kindOf(val) {
  var typeOfVal = typeof val;

  if (true) {
    typeOfVal = miniKindOf(val);
  }

  return typeOfVal;
}

/**
 * @deprecated
 *
 * **We recommend using the `configureStore` method
 * of the `@reduxjs/toolkit` package**, which replaces `createStore`.
 *
 * Redux Toolkit is our recommended approach for writing Redux logic today,
 * including store setup, reducers, data fetching, and more.
 *
 * **For more details, please read this Redux docs page:**
 * **https://redux.js.org/introduction/why-rtk-is-redux-today**
 *
 * `configureStore` from Redux Toolkit is an improved version of `createStore` that
 * simplifies setup and helps avoid common bugs.
 *
 * You should not be using the `redux` core package by itself today, except for learning purposes.
 * The `createStore` method from the core `redux` package will not be removed, but we encourage
 * all users to migrate to using Redux Toolkit for all Redux code.
 *
 * If you want to use `createStore` without this visual deprecation warning, use
 * the `legacy_createStore` import instead:
 *
 * `import { legacy_createStore as createStore} from 'redux'`
 *
 */

function createStore(reducer, preloadedState, enhancer) {
  var _ref2;

  if (typeof preloadedState === 'function' && typeof enhancer === 'function' || typeof enhancer === 'function' && typeof arguments[3] === 'function') {
    throw new Error( false ? 0 : 'It looks like you are passing several store enhancers to ' + 'createStore(). This is not supported. Instead, compose them ' + 'together to a single function. See https://redux.js.org/tutorials/fundamentals/part-4-store#creating-a-store-with-enhancers for an example.');
  }

  if (typeof preloadedState === 'function' && typeof enhancer === 'undefined') {
    enhancer = preloadedState;
    preloadedState = undefined;
  }

  if (typeof enhancer !== 'undefined') {
    if (typeof enhancer !== 'function') {
      throw new Error( false ? 0 : "Expected the enhancer to be a function. Instead, received: '" + kindOf(enhancer) + "'");
    }

    return enhancer(createStore)(reducer, preloadedState);
  }

  if (typeof reducer !== 'function') {
    throw new Error( false ? 0 : "Expected the root reducer to be a function. Instead, received: '" + kindOf(reducer) + "'");
  }

  var currentReducer = reducer;
  var currentState = preloadedState;
  var currentListeners = [];
  var nextListeners = currentListeners;
  var isDispatching = false;
  /**
   * This makes a shallow copy of currentListeners so we can use
   * nextListeners as a temporary list while dispatching.
   *
   * This prevents any bugs around consumers calling
   * subscribe/unsubscribe in the middle of a dispatch.
   */

  function ensureCanMutateNextListeners() {
    if (nextListeners === currentListeners) {
      nextListeners = currentListeners.slice();
    }
  }
  /**
   * Reads the state tree managed by the store.
   *
   * @returns {any} The current state tree of your application.
   */


  function getState() {
    if (isDispatching) {
      throw new Error( false ? 0 : 'You may not call store.getState() while the reducer is executing. ' + 'The reducer has already received the state as an argument. ' + 'Pass it down from the top reducer instead of reading it from the store.');
    }

    return currentState;
  }
  /**
   * Adds a change listener. It will be called any time an action is dispatched,
   * and some part of the state tree may potentially have changed. You may then
   * call `getState()` to read the current state tree inside the callback.
   *
   * You may call `dispatch()` from a change listener, with the following
   * caveats:
   *
   * 1. The subscriptions are snapshotted just before every `dispatch()` call.
   * If you subscribe or unsubscribe while the listeners are being invoked, this
   * will not have any effect on the `dispatch()` that is currently in progress.
   * However, the next `dispatch()` call, whether nested or not, will use a more
   * recent snapshot of the subscription list.
   *
   * 2. The listener should not expect to see all state changes, as the state
   * might have been updated multiple times during a nested `dispatch()` before
   * the listener is called. It is, however, guaranteed that all subscribers
   * registered before the `dispatch()` started will be called with the latest
   * state by the time it exits.
   *
   * @param {Function} listener A callback to be invoked on every dispatch.
   * @returns {Function} A function to remove this change listener.
   */


  function subscribe(listener) {
    if (typeof listener !== 'function') {
      throw new Error( false ? 0 : "Expected the listener to be a function. Instead, received: '" + kindOf(listener) + "'");
    }

    if (isDispatching) {
      throw new Error( false ? 0 : 'You may not call store.subscribe() while the reducer is executing. ' + 'If you would like to be notified after the store has been updated, subscribe from a ' + 'component and invoke store.getState() in the callback to access the latest state. ' + 'See https://redux.js.org/api/store#subscribelistener for more details.');
    }

    var isSubscribed = true;
    ensureCanMutateNextListeners();
    nextListeners.push(listener);
    return function unsubscribe() {
      if (!isSubscribed) {
        return;
      }

      if (isDispatching) {
        throw new Error( false ? 0 : 'You may not unsubscribe from a store listener while the reducer is executing. ' + 'See https://redux.js.org/api/store#subscribelistener for more details.');
      }

      isSubscribed = false;
      ensureCanMutateNextListeners();
      var index = nextListeners.indexOf(listener);
      nextListeners.splice(index, 1);
      currentListeners = null;
    };
  }
  /**
   * Dispatches an action. It is the only way to trigger a state change.
   *
   * The `reducer` function, used to create the store, will be called with the
   * current state tree and the given `action`. Its return value will
   * be considered the **next** state of the tree, and the change listeners
   * will be notified.
   *
   * The base implementation only supports plain object actions. If you want to
   * dispatch a Promise, an Observable, a thunk, or something else, you need to
   * wrap your store creating function into the corresponding middleware. For
   * example, see the documentation for the `redux-thunk` package. Even the
   * middleware will eventually dispatch plain object actions using this method.
   *
   * @param {Object} action A plain object representing “what changed”. It is
   * a good idea to keep actions serializable so you can record and replay user
   * sessions, or use the time travelling `redux-devtools`. An action must have
   * a `type` property which may not be `undefined`. It is a good idea to use
   * string constants for action types.
   *
   * @returns {Object} For convenience, the same action object you dispatched.
   *
   * Note that, if you use a custom middleware, it may wrap `dispatch()` to
   * return something else (for example, a Promise you can await).
   */


  function dispatch(action) {
    if (!isPlainObject(action)) {
      throw new Error( false ? 0 : "Actions must be plain objects. Instead, the actual type was: '" + kindOf(action) + "'. You may need to add middleware to your store setup to handle dispatching other values, such as 'redux-thunk' to handle dispatching functions. See https://redux.js.org/tutorials/fundamentals/part-4-store#middleware and https://redux.js.org/tutorials/fundamentals/part-6-async-logic#using-the-redux-thunk-middleware for examples.");
    }

    if (typeof action.type === 'undefined') {
      throw new Error( false ? 0 : 'Actions may not have an undefined "type" property. You may have misspelled an action type string constant.');
    }

    if (isDispatching) {
      throw new Error( false ? 0 : 'Reducers may not dispatch actions.');
    }

    try {
      isDispatching = true;
      currentState = currentReducer(currentState, action);
    } finally {
      isDispatching = false;
    }

    var listeners = currentListeners = nextListeners;

    for (var i = 0; i < listeners.length; i++) {
      var listener = listeners[i];
      listener();
    }

    return action;
  }
  /**
   * Replaces the reducer currently used by the store to calculate the state.
   *
   * You might need this if your app implements code splitting and you want to
   * load some of the reducers dynamically. You might also need this if you
   * implement a hot reloading mechanism for Redux.
   *
   * @param {Function} nextReducer The reducer for the store to use instead.
   * @returns {void}
   */


  function replaceReducer(nextReducer) {
    if (typeof nextReducer !== 'function') {
      throw new Error( false ? 0 : "Expected the nextReducer to be a function. Instead, received: '" + kindOf(nextReducer));
    }

    currentReducer = nextReducer; // This action has a similiar effect to ActionTypes.INIT.
    // Any reducers that existed in both the new and old rootReducer
    // will receive the previous state. This effectively populates
    // the new state tree with any relevant data from the old one.

    dispatch({
      type: ActionTypes.REPLACE
    });
  }
  /**
   * Interoperability point for observable/reactive libraries.
   * @returns {observable} A minimal observable of state changes.
   * For more information, see the observable proposal:
   * https://github.com/tc39/proposal-observable
   */


  function observable() {
    var _ref;

    var outerSubscribe = subscribe;
    return _ref = {
      /**
       * The minimal observable subscription method.
       * @param {Object} observer Any object that can be used as an observer.
       * The observer object should have a `next` method.
       * @returns {subscription} An object with an `unsubscribe` method that can
       * be used to unsubscribe the observable from the store, and prevent further
       * emission of values from the observable.
       */
      subscribe: function subscribe(observer) {
        if (typeof observer !== 'object' || observer === null) {
          throw new Error( false ? 0 : "Expected the observer to be an object. Instead, received: '" + kindOf(observer) + "'");
        }

        function observeState() {
          if (observer.next) {
            observer.next(getState());
          }
        }

        observeState();
        var unsubscribe = outerSubscribe(observeState);
        return {
          unsubscribe: unsubscribe
        };
      }
    }, _ref[$$observable] = function () {
      return this;
    }, _ref;
  } // When a store is created, an "INIT" action is dispatched so that every
  // reducer returns their initial state. This effectively populates
  // the initial state tree.


  dispatch({
    type: ActionTypes.INIT
  });
  return _ref2 = {
    dispatch: dispatch,
    subscribe: subscribe,
    getState: getState,
    replaceReducer: replaceReducer
  }, _ref2[$$observable] = observable, _ref2;
}
/**
 * Creates a Redux store that holds the state tree.
 *
 * **We recommend using `configureStore` from the
 * `@reduxjs/toolkit` package**, which replaces `createStore`:
 * **https://redux.js.org/introduction/why-rtk-is-redux-today**
 *
 * The only way to change the data in the store is to call `dispatch()` on it.
 *
 * There should only be a single store in your app. To specify how different
 * parts of the state tree respond to actions, you may combine several reducers
 * into a single reducer function by using `combineReducers`.
 *
 * @param {Function} reducer A function that returns the next state tree, given
 * the current state tree and the action to handle.
 *
 * @param {any} [preloadedState] The initial state. You may optionally specify it
 * to hydrate the state from the server in universal apps, or to restore a
 * previously serialized user session.
 * If you use `combineReducers` to produce the root reducer function, this must be
 * an object with the same shape as `combineReducers` keys.
 *
 * @param {Function} [enhancer] The store enhancer. You may optionally specify it
 * to enhance the store with third-party capabilities such as middleware,
 * time travel, persistence, etc. The only store enhancer that ships with Redux
 * is `applyMiddleware()`.
 *
 * @returns {Store} A Redux store that lets you read the state, dispatch actions
 * and subscribe to changes.
 */

var legacy_createStore = createStore;

/**
 * Prints a warning in the console if it exists.
 *
 * @param {String} message The warning message.
 * @returns {void}
 */
function warning(message) {
  /* eslint-disable no-console */
  if (typeof console !== 'undefined' && typeof console.error === 'function') {
    console.error(message);
  }
  /* eslint-enable no-console */


  try {
    // This error was thrown as a convenience so that if you enable
    // "break on all exceptions" in your console,
    // it would pause the execution at this line.
    throw new Error(message);
  } catch (e) {} // eslint-disable-line no-empty

}

function getUnexpectedStateShapeWarningMessage(inputState, reducers, action, unexpectedKeyCache) {
  var reducerKeys = Object.keys(reducers);
  var argumentName = action && action.type === ActionTypes.INIT ? 'preloadedState argument passed to createStore' : 'previous state received by the reducer';

  if (reducerKeys.length === 0) {
    return 'Store does not have a valid reducer. Make sure the argument passed ' + 'to combineReducers is an object whose values are reducers.';
  }

  if (!isPlainObject(inputState)) {
    return "The " + argumentName + " has unexpected type of \"" + kindOf(inputState) + "\". Expected argument to be an object with the following " + ("keys: \"" + reducerKeys.join('", "') + "\"");
  }

  var unexpectedKeys = Object.keys(inputState).filter(function (key) {
    return !reducers.hasOwnProperty(key) && !unexpectedKeyCache[key];
  });
  unexpectedKeys.forEach(function (key) {
    unexpectedKeyCache[key] = true;
  });
  if (action && action.type === ActionTypes.REPLACE) return;

  if (unexpectedKeys.length > 0) {
    return "Unexpected " + (unexpectedKeys.length > 1 ? 'keys' : 'key') + " " + ("\"" + unexpectedKeys.join('", "') + "\" found in " + argumentName + ". ") + "Expected to find one of the known reducer keys instead: " + ("\"" + reducerKeys.join('", "') + "\". Unexpected keys will be ignored.");
  }
}

function assertReducerShape(reducers) {
  Object.keys(reducers).forEach(function (key) {
    var reducer = reducers[key];
    var initialState = reducer(undefined, {
      type: ActionTypes.INIT
    });

    if (typeof initialState === 'undefined') {
      throw new Error( false ? 0 : "The slice reducer for key \"" + key + "\" returned undefined during initialization. " + "If the state passed to the reducer is undefined, you must " + "explicitly return the initial state. The initial state may " + "not be undefined. If you don't want to set a value for this reducer, " + "you can use null instead of undefined.");
    }

    if (typeof reducer(undefined, {
      type: ActionTypes.PROBE_UNKNOWN_ACTION()
    }) === 'undefined') {
      throw new Error( false ? 0 : "The slice reducer for key \"" + key + "\" returned undefined when probed with a random type. " + ("Don't try to handle '" + ActionTypes.INIT + "' or other actions in \"redux/*\" ") + "namespace. They are considered private. Instead, you must return the " + "current state for any unknown actions, unless it is undefined, " + "in which case you must return the initial state, regardless of the " + "action type. The initial state may not be undefined, but can be null.");
    }
  });
}
/**
 * Turns an object whose values are different reducer functions, into a single
 * reducer function. It will call every child reducer, and gather their results
 * into a single state object, whose keys correspond to the keys of the passed
 * reducer functions.
 *
 * @param {Object} reducers An object whose values correspond to different
 * reducer functions that need to be combined into one. One handy way to obtain
 * it is to use ES6 `import * as reducers` syntax. The reducers may never return
 * undefined for any action. Instead, they should return their initial state
 * if the state passed to them was undefined, and the current state for any
 * unrecognized action.
 *
 * @returns {Function} A reducer function that invokes every reducer inside the
 * passed object, and builds a state object with the same shape.
 */


function combineReducers(reducers) {
  var reducerKeys = Object.keys(reducers);
  var finalReducers = {};

  for (var i = 0; i < reducerKeys.length; i++) {
    var key = reducerKeys[i];

    if (true) {
      if (typeof reducers[key] === 'undefined') {
        warning("No reducer provided for key \"" + key + "\"");
      }
    }

    if (typeof reducers[key] === 'function') {
      finalReducers[key] = reducers[key];
    }
  }

  var finalReducerKeys = Object.keys(finalReducers); // This is used to make sure we don't warn about the same
  // keys multiple times.

  var unexpectedKeyCache;

  if (true) {
    unexpectedKeyCache = {};
  }

  var shapeAssertionError;

  try {
    assertReducerShape(finalReducers);
  } catch (e) {
    shapeAssertionError = e;
  }

  return function combination(state, action) {
    if (state === void 0) {
      state = {};
    }

    if (shapeAssertionError) {
      throw shapeAssertionError;
    }

    if (true) {
      var warningMessage = getUnexpectedStateShapeWarningMessage(state, finalReducers, action, unexpectedKeyCache);

      if (warningMessage) {
        warning(warningMessage);
      }
    }

    var hasChanged = false;
    var nextState = {};

    for (var _i = 0; _i < finalReducerKeys.length; _i++) {
      var _key = finalReducerKeys[_i];
      var reducer = finalReducers[_key];
      var previousStateForKey = state[_key];
      var nextStateForKey = reducer(previousStateForKey, action);

      if (typeof nextStateForKey === 'undefined') {
        var actionType = action && action.type;
        throw new Error( false ? 0 : "When called with an action of type " + (actionType ? "\"" + String(actionType) + "\"" : '(unknown type)') + ", the slice reducer for key \"" + _key + "\" returned undefined. " + "To ignore an action, you must explicitly return the previous state. " + "If you want this reducer to hold no value, you can return null instead of undefined.");
      }

      nextState[_key] = nextStateForKey;
      hasChanged = hasChanged || nextStateForKey !== previousStateForKey;
    }

    hasChanged = hasChanged || finalReducerKeys.length !== Object.keys(state).length;
    return hasChanged ? nextState : state;
  };
}

function bindActionCreator(actionCreator, dispatch) {
  return function () {
    return dispatch(actionCreator.apply(this, arguments));
  };
}
/**
 * Turns an object whose values are action creators, into an object with the
 * same keys, but with every function wrapped into a `dispatch` call so they
 * may be invoked directly. This is just a convenience method, as you can call
 * `store.dispatch(MyActionCreators.doSomething())` yourself just fine.
 *
 * For convenience, you can also pass an action creator as the first argument,
 * and get a dispatch wrapped function in return.
 *
 * @param {Function|Object} actionCreators An object whose values are action
 * creator functions. One handy way to obtain it is to use ES6 `import * as`
 * syntax. You may also pass a single function.
 *
 * @param {Function} dispatch The `dispatch` function available on your Redux
 * store.
 *
 * @returns {Function|Object} The object mimicking the original object, but with
 * every action creator wrapped into the `dispatch` call. If you passed a
 * function as `actionCreators`, the return value will also be a single
 * function.
 */


function bindActionCreators(actionCreators, dispatch) {
  if (typeof actionCreators === 'function') {
    return bindActionCreator(actionCreators, dispatch);
  }

  if (typeof actionCreators !== 'object' || actionCreators === null) {
    throw new Error( false ? 0 : "bindActionCreators expected an object or a function, but instead received: '" + kindOf(actionCreators) + "'. " + "Did you write \"import ActionCreators from\" instead of \"import * as ActionCreators from\"?");
  }

  var boundActionCreators = {};

  for (var key in actionCreators) {
    var actionCreator = actionCreators[key];

    if (typeof actionCreator === 'function') {
      boundActionCreators[key] = bindActionCreator(actionCreator, dispatch);
    }
  }

  return boundActionCreators;
}

/**
 * Composes single-argument functions from right to left. The rightmost
 * function can take multiple arguments as it provides the signature for
 * the resulting composite function.
 *
 * @param {...Function} funcs The functions to compose.
 * @returns {Function} A function obtained by composing the argument functions
 * from right to left. For example, compose(f, g, h) is identical to doing
 * (...args) => f(g(h(...args))).
 */
function compose() {
  for (var _len = arguments.length, funcs = new Array(_len), _key = 0; _key < _len; _key++) {
    funcs[_key] = arguments[_key];
  }

  if (funcs.length === 0) {
    return function (arg) {
      return arg;
    };
  }

  if (funcs.length === 1) {
    return funcs[0];
  }

  return funcs.reduce(function (a, b) {
    return function () {
      return a(b.apply(void 0, arguments));
    };
  });
}

/**
 * Creates a store enhancer that applies middleware to the dispatch method
 * of the Redux store. This is handy for a variety of tasks, such as expressing
 * asynchronous actions in a concise manner, or logging every action payload.
 *
 * See `redux-thunk` package as an example of the Redux middleware.
 *
 * Because middleware is potentially asynchronous, this should be the first
 * store enhancer in the composition chain.
 *
 * Note that each middleware will be given the `dispatch` and `getState` functions
 * as named arguments.
 *
 * @param {...Function} middlewares The middleware chain to be applied.
 * @returns {Function} A store enhancer applying the middleware.
 */

function applyMiddleware() {
  for (var _len = arguments.length, middlewares = new Array(_len), _key = 0; _key < _len; _key++) {
    middlewares[_key] = arguments[_key];
  }

  return function (createStore) {
    return function () {
      var store = createStore.apply(void 0, arguments);

      var _dispatch = function dispatch() {
        throw new Error( false ? 0 : 'Dispatching while constructing your middleware is not allowed. ' + 'Other middleware would not be applied to this dispatch.');
      };

      var middlewareAPI = {
        getState: store.getState,
        dispatch: function dispatch() {
          return _dispatch.apply(void 0, arguments);
        }
      };
      var chain = middlewares.map(function (middleware) {
        return middleware(middlewareAPI);
      });
      _dispatch = compose.apply(void 0, chain)(store.dispatch);
      return (0,_babel_runtime_helpers_esm_objectSpread2__WEBPACK_IMPORTED_MODULE_0__["default"])((0,_babel_runtime_helpers_esm_objectSpread2__WEBPACK_IMPORTED_MODULE_0__["default"])({}, store), {}, {
        dispatch: _dispatch
      });
    };
  };
}

/*
 * This is a dummy function to check if the function name has been altered by minification.
 * If the function has been minified and NODE_ENV !== 'production', warn the user.
 */

function isCrushed() {}

if ( true && typeof isCrushed.name === 'string' && isCrushed.name !== 'isCrushed') {
  warning('You are currently using minified code outside of NODE_ENV === "production". ' + 'This means that you are running a slower development build of Redux. ' + 'You can use loose-envify (https://github.com/zertosh/loose-envify) for browserify ' + 'or setting mode to production in webpack (https://webpack.js.org/concepts/mode/) ' + 'to ensure you have the correct code for your production build.');
}




/***/ }),

/***/ "../../node_modules/resize-observer-polyfill/dist/ResizeObserver.es.js":
/*!*****************************************************************************!*\
  !*** ../../node_modules/resize-observer-polyfill/dist/ResizeObserver.es.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/**
 * A collection of shims that provide minimal functionality of the ES6 collections.
 *
 * These implementations are not meant to be used outside of the ResizeObserver
 * modules as they cover only a limited range of use cases.
 */
/* eslint-disable require-jsdoc, valid-jsdoc */
var MapShim = (function () {
    if (typeof Map !== 'undefined') {
        return Map;
    }
    /**
     * Returns index in provided array that matches the specified key.
     *
     * @param {Array<Array>} arr
     * @param {*} key
     * @returns {number}
     */
    function getIndex(arr, key) {
        var result = -1;
        arr.some(function (entry, index) {
            if (entry[0] === key) {
                result = index;
                return true;
            }
            return false;
        });
        return result;
    }
    return /** @class */ (function () {
        function class_1() {
            this.__entries__ = [];
        }
        Object.defineProperty(class_1.prototype, "size", {
            /**
             * @returns {boolean}
             */
            get: function () {
                return this.__entries__.length;
            },
            enumerable: true,
            configurable: true
        });
        /**
         * @param {*} key
         * @returns {*}
         */
        class_1.prototype.get = function (key) {
            var index = getIndex(this.__entries__, key);
            var entry = this.__entries__[index];
            return entry && entry[1];
        };
        /**
         * @param {*} key
         * @param {*} value
         * @returns {void}
         */
        class_1.prototype.set = function (key, value) {
            var index = getIndex(this.__entries__, key);
            if (~index) {
                this.__entries__[index][1] = value;
            }
            else {
                this.__entries__.push([key, value]);
            }
        };
        /**
         * @param {*} key
         * @returns {void}
         */
        class_1.prototype.delete = function (key) {
            var entries = this.__entries__;
            var index = getIndex(entries, key);
            if (~index) {
                entries.splice(index, 1);
            }
        };
        /**
         * @param {*} key
         * @returns {void}
         */
        class_1.prototype.has = function (key) {
            return !!~getIndex(this.__entries__, key);
        };
        /**
         * @returns {void}
         */
        class_1.prototype.clear = function () {
            this.__entries__.splice(0);
        };
        /**
         * @param {Function} callback
         * @param {*} [ctx=null]
         * @returns {void}
         */
        class_1.prototype.forEach = function (callback, ctx) {
            if (ctx === void 0) { ctx = null; }
            for (var _i = 0, _a = this.__entries__; _i < _a.length; _i++) {
                var entry = _a[_i];
                callback.call(ctx, entry[1], entry[0]);
            }
        };
        return class_1;
    }());
})();

/**
 * Detects whether window and document objects are available in current environment.
 */
var isBrowser = typeof window !== 'undefined' && typeof document !== 'undefined' && window.document === document;

// Returns global object of a current environment.
var global$1 = (function () {
    if (typeof __webpack_require__.g !== 'undefined' && __webpack_require__.g.Math === Math) {
        return __webpack_require__.g;
    }
    if (typeof self !== 'undefined' && self.Math === Math) {
        return self;
    }
    if (typeof window !== 'undefined' && window.Math === Math) {
        return window;
    }
    // eslint-disable-next-line no-new-func
    return Function('return this')();
})();

/**
 * A shim for the requestAnimationFrame which falls back to the setTimeout if
 * first one is not supported.
 *
 * @returns {number} Requests' identifier.
 */
var requestAnimationFrame$1 = (function () {
    if (typeof requestAnimationFrame === 'function') {
        // It's required to use a bounded function because IE sometimes throws
        // an "Invalid calling object" error if rAF is invoked without the global
        // object on the left hand side.
        return requestAnimationFrame.bind(global$1);
    }
    return function (callback) { return setTimeout(function () { return callback(Date.now()); }, 1000 / 60); };
})();

// Defines minimum timeout before adding a trailing call.
var trailingTimeout = 2;
/**
 * Creates a wrapper function which ensures that provided callback will be
 * invoked only once during the specified delay period.
 *
 * @param {Function} callback - Function to be invoked after the delay period.
 * @param {number} delay - Delay after which to invoke callback.
 * @returns {Function}
 */
function throttle (callback, delay) {
    var leadingCall = false, trailingCall = false, lastCallTime = 0;
    /**
     * Invokes the original callback function and schedules new invocation if
     * the "proxy" was called during current request.
     *
     * @returns {void}
     */
    function resolvePending() {
        if (leadingCall) {
            leadingCall = false;
            callback();
        }
        if (trailingCall) {
            proxy();
        }
    }
    /**
     * Callback invoked after the specified delay. It will further postpone
     * invocation of the original function delegating it to the
     * requestAnimationFrame.
     *
     * @returns {void}
     */
    function timeoutCallback() {
        requestAnimationFrame$1(resolvePending);
    }
    /**
     * Schedules invocation of the original function.
     *
     * @returns {void}
     */
    function proxy() {
        var timeStamp = Date.now();
        if (leadingCall) {
            // Reject immediately following calls.
            if (timeStamp - lastCallTime < trailingTimeout) {
                return;
            }
            // Schedule new call to be in invoked when the pending one is resolved.
            // This is important for "transitions" which never actually start
            // immediately so there is a chance that we might miss one if change
            // happens amids the pending invocation.
            trailingCall = true;
        }
        else {
            leadingCall = true;
            trailingCall = false;
            setTimeout(timeoutCallback, delay);
        }
        lastCallTime = timeStamp;
    }
    return proxy;
}

// Minimum delay before invoking the update of observers.
var REFRESH_DELAY = 20;
// A list of substrings of CSS properties used to find transition events that
// might affect dimensions of observed elements.
var transitionKeys = ['top', 'right', 'bottom', 'left', 'width', 'height', 'size', 'weight'];
// Check if MutationObserver is available.
var mutationObserverSupported = typeof MutationObserver !== 'undefined';
/**
 * Singleton controller class which handles updates of ResizeObserver instances.
 */
var ResizeObserverController = /** @class */ (function () {
    /**
     * Creates a new instance of ResizeObserverController.
     *
     * @private
     */
    function ResizeObserverController() {
        /**
         * Indicates whether DOM listeners have been added.
         *
         * @private {boolean}
         */
        this.connected_ = false;
        /**
         * Tells that controller has subscribed for Mutation Events.
         *
         * @private {boolean}
         */
        this.mutationEventsAdded_ = false;
        /**
         * Keeps reference to the instance of MutationObserver.
         *
         * @private {MutationObserver}
         */
        this.mutationsObserver_ = null;
        /**
         * A list of connected observers.
         *
         * @private {Array<ResizeObserverSPI>}
         */
        this.observers_ = [];
        this.onTransitionEnd_ = this.onTransitionEnd_.bind(this);
        this.refresh = throttle(this.refresh.bind(this), REFRESH_DELAY);
    }
    /**
     * Adds observer to observers list.
     *
     * @param {ResizeObserverSPI} observer - Observer to be added.
     * @returns {void}
     */
    ResizeObserverController.prototype.addObserver = function (observer) {
        if (!~this.observers_.indexOf(observer)) {
            this.observers_.push(observer);
        }
        // Add listeners if they haven't been added yet.
        if (!this.connected_) {
            this.connect_();
        }
    };
    /**
     * Removes observer from observers list.
     *
     * @param {ResizeObserverSPI} observer - Observer to be removed.
     * @returns {void}
     */
    ResizeObserverController.prototype.removeObserver = function (observer) {
        var observers = this.observers_;
        var index = observers.indexOf(observer);
        // Remove observer if it's present in registry.
        if (~index) {
            observers.splice(index, 1);
        }
        // Remove listeners if controller has no connected observers.
        if (!observers.length && this.connected_) {
            this.disconnect_();
        }
    };
    /**
     * Invokes the update of observers. It will continue running updates insofar
     * it detects changes.
     *
     * @returns {void}
     */
    ResizeObserverController.prototype.refresh = function () {
        var changesDetected = this.updateObservers_();
        // Continue running updates if changes have been detected as there might
        // be future ones caused by CSS transitions.
        if (changesDetected) {
            this.refresh();
        }
    };
    /**
     * Updates every observer from observers list and notifies them of queued
     * entries.
     *
     * @private
     * @returns {boolean} Returns "true" if any observer has detected changes in
     *      dimensions of it's elements.
     */
    ResizeObserverController.prototype.updateObservers_ = function () {
        // Collect observers that have active observations.
        var activeObservers = this.observers_.filter(function (observer) {
            return observer.gatherActive(), observer.hasActive();
        });
        // Deliver notifications in a separate cycle in order to avoid any
        // collisions between observers, e.g. when multiple instances of
        // ResizeObserver are tracking the same element and the callback of one
        // of them changes content dimensions of the observed target. Sometimes
        // this may result in notifications being blocked for the rest of observers.
        activeObservers.forEach(function (observer) { return observer.broadcastActive(); });
        return activeObservers.length > 0;
    };
    /**
     * Initializes DOM listeners.
     *
     * @private
     * @returns {void}
     */
    ResizeObserverController.prototype.connect_ = function () {
        // Do nothing if running in a non-browser environment or if listeners
        // have been already added.
        if (!isBrowser || this.connected_) {
            return;
        }
        // Subscription to the "Transitionend" event is used as a workaround for
        // delayed transitions. This way it's possible to capture at least the
        // final state of an element.
        document.addEventListener('transitionend', this.onTransitionEnd_);
        window.addEventListener('resize', this.refresh);
        if (mutationObserverSupported) {
            this.mutationsObserver_ = new MutationObserver(this.refresh);
            this.mutationsObserver_.observe(document, {
                attributes: true,
                childList: true,
                characterData: true,
                subtree: true
            });
        }
        else {
            document.addEventListener('DOMSubtreeModified', this.refresh);
            this.mutationEventsAdded_ = true;
        }
        this.connected_ = true;
    };
    /**
     * Removes DOM listeners.
     *
     * @private
     * @returns {void}
     */
    ResizeObserverController.prototype.disconnect_ = function () {
        // Do nothing if running in a non-browser environment or if listeners
        // have been already removed.
        if (!isBrowser || !this.connected_) {
            return;
        }
        document.removeEventListener('transitionend', this.onTransitionEnd_);
        window.removeEventListener('resize', this.refresh);
        if (this.mutationsObserver_) {
            this.mutationsObserver_.disconnect();
        }
        if (this.mutationEventsAdded_) {
            document.removeEventListener('DOMSubtreeModified', this.refresh);
        }
        this.mutationsObserver_ = null;
        this.mutationEventsAdded_ = false;
        this.connected_ = false;
    };
    /**
     * "Transitionend" event handler.
     *
     * @private
     * @param {TransitionEvent} event
     * @returns {void}
     */
    ResizeObserverController.prototype.onTransitionEnd_ = function (_a) {
        var _b = _a.propertyName, propertyName = _b === void 0 ? '' : _b;
        // Detect whether transition may affect dimensions of an element.
        var isReflowProperty = transitionKeys.some(function (key) {
            return !!~propertyName.indexOf(key);
        });
        if (isReflowProperty) {
            this.refresh();
        }
    };
    /**
     * Returns instance of the ResizeObserverController.
     *
     * @returns {ResizeObserverController}
     */
    ResizeObserverController.getInstance = function () {
        if (!this.instance_) {
            this.instance_ = new ResizeObserverController();
        }
        return this.instance_;
    };
    /**
     * Holds reference to the controller's instance.
     *
     * @private {ResizeObserverController}
     */
    ResizeObserverController.instance_ = null;
    return ResizeObserverController;
}());

/**
 * Defines non-writable/enumerable properties of the provided target object.
 *
 * @param {Object} target - Object for which to define properties.
 * @param {Object} props - Properties to be defined.
 * @returns {Object} Target object.
 */
var defineConfigurable = (function (target, props) {
    for (var _i = 0, _a = Object.keys(props); _i < _a.length; _i++) {
        var key = _a[_i];
        Object.defineProperty(target, key, {
            value: props[key],
            enumerable: false,
            writable: false,
            configurable: true
        });
    }
    return target;
});

/**
 * Returns the global object associated with provided element.
 *
 * @param {Object} target
 * @returns {Object}
 */
var getWindowOf = (function (target) {
    // Assume that the element is an instance of Node, which means that it
    // has the "ownerDocument" property from which we can retrieve a
    // corresponding global object.
    var ownerGlobal = target && target.ownerDocument && target.ownerDocument.defaultView;
    // Return the local global object if it's not possible extract one from
    // provided element.
    return ownerGlobal || global$1;
});

// Placeholder of an empty content rectangle.
var emptyRect = createRectInit(0, 0, 0, 0);
/**
 * Converts provided string to a number.
 *
 * @param {number|string} value
 * @returns {number}
 */
function toFloat(value) {
    return parseFloat(value) || 0;
}
/**
 * Extracts borders size from provided styles.
 *
 * @param {CSSStyleDeclaration} styles
 * @param {...string} positions - Borders positions (top, right, ...)
 * @returns {number}
 */
function getBordersSize(styles) {
    var positions = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        positions[_i - 1] = arguments[_i];
    }
    return positions.reduce(function (size, position) {
        var value = styles['border-' + position + '-width'];
        return size + toFloat(value);
    }, 0);
}
/**
 * Extracts paddings sizes from provided styles.
 *
 * @param {CSSStyleDeclaration} styles
 * @returns {Object} Paddings box.
 */
function getPaddings(styles) {
    var positions = ['top', 'right', 'bottom', 'left'];
    var paddings = {};
    for (var _i = 0, positions_1 = positions; _i < positions_1.length; _i++) {
        var position = positions_1[_i];
        var value = styles['padding-' + position];
        paddings[position] = toFloat(value);
    }
    return paddings;
}
/**
 * Calculates content rectangle of provided SVG element.
 *
 * @param {SVGGraphicsElement} target - Element content rectangle of which needs
 *      to be calculated.
 * @returns {DOMRectInit}
 */
function getSVGContentRect(target) {
    var bbox = target.getBBox();
    return createRectInit(0, 0, bbox.width, bbox.height);
}
/**
 * Calculates content rectangle of provided HTMLElement.
 *
 * @param {HTMLElement} target - Element for which to calculate the content rectangle.
 * @returns {DOMRectInit}
 */
function getHTMLElementContentRect(target) {
    // Client width & height properties can't be
    // used exclusively as they provide rounded values.
    var clientWidth = target.clientWidth, clientHeight = target.clientHeight;
    // By this condition we can catch all non-replaced inline, hidden and
    // detached elements. Though elements with width & height properties less
    // than 0.5 will be discarded as well.
    //
    // Without it we would need to implement separate methods for each of
    // those cases and it's not possible to perform a precise and performance
    // effective test for hidden elements. E.g. even jQuery's ':visible' filter
    // gives wrong results for elements with width & height less than 0.5.
    if (!clientWidth && !clientHeight) {
        return emptyRect;
    }
    var styles = getWindowOf(target).getComputedStyle(target);
    var paddings = getPaddings(styles);
    var horizPad = paddings.left + paddings.right;
    var vertPad = paddings.top + paddings.bottom;
    // Computed styles of width & height are being used because they are the
    // only dimensions available to JS that contain non-rounded values. It could
    // be possible to utilize the getBoundingClientRect if only it's data wasn't
    // affected by CSS transformations let alone paddings, borders and scroll bars.
    var width = toFloat(styles.width), height = toFloat(styles.height);
    // Width & height include paddings and borders when the 'border-box' box
    // model is applied (except for IE).
    if (styles.boxSizing === 'border-box') {
        // Following conditions are required to handle Internet Explorer which
        // doesn't include paddings and borders to computed CSS dimensions.
        //
        // We can say that if CSS dimensions + paddings are equal to the "client"
        // properties then it's either IE, and thus we don't need to subtract
        // anything, or an element merely doesn't have paddings/borders styles.
        if (Math.round(width + horizPad) !== clientWidth) {
            width -= getBordersSize(styles, 'left', 'right') + horizPad;
        }
        if (Math.round(height + vertPad) !== clientHeight) {
            height -= getBordersSize(styles, 'top', 'bottom') + vertPad;
        }
    }
    // Following steps can't be applied to the document's root element as its
    // client[Width/Height] properties represent viewport area of the window.
    // Besides, it's as well not necessary as the <html> itself neither has
    // rendered scroll bars nor it can be clipped.
    if (!isDocumentElement(target)) {
        // In some browsers (only in Firefox, actually) CSS width & height
        // include scroll bars size which can be removed at this step as scroll
        // bars are the only difference between rounded dimensions + paddings
        // and "client" properties, though that is not always true in Chrome.
        var vertScrollbar = Math.round(width + horizPad) - clientWidth;
        var horizScrollbar = Math.round(height + vertPad) - clientHeight;
        // Chrome has a rather weird rounding of "client" properties.
        // E.g. for an element with content width of 314.2px it sometimes gives
        // the client width of 315px and for the width of 314.7px it may give
        // 314px. And it doesn't happen all the time. So just ignore this delta
        // as a non-relevant.
        if (Math.abs(vertScrollbar) !== 1) {
            width -= vertScrollbar;
        }
        if (Math.abs(horizScrollbar) !== 1) {
            height -= horizScrollbar;
        }
    }
    return createRectInit(paddings.left, paddings.top, width, height);
}
/**
 * Checks whether provided element is an instance of the SVGGraphicsElement.
 *
 * @param {Element} target - Element to be checked.
 * @returns {boolean}
 */
var isSVGGraphicsElement = (function () {
    // Some browsers, namely IE and Edge, don't have the SVGGraphicsElement
    // interface.
    if (typeof SVGGraphicsElement !== 'undefined') {
        return function (target) { return target instanceof getWindowOf(target).SVGGraphicsElement; };
    }
    // If it's so, then check that element is at least an instance of the
    // SVGElement and that it has the "getBBox" method.
    // eslint-disable-next-line no-extra-parens
    return function (target) { return (target instanceof getWindowOf(target).SVGElement &&
        typeof target.getBBox === 'function'); };
})();
/**
 * Checks whether provided element is a document element (<html>).
 *
 * @param {Element} target - Element to be checked.
 * @returns {boolean}
 */
function isDocumentElement(target) {
    return target === getWindowOf(target).document.documentElement;
}
/**
 * Calculates an appropriate content rectangle for provided html or svg element.
 *
 * @param {Element} target - Element content rectangle of which needs to be calculated.
 * @returns {DOMRectInit}
 */
function getContentRect(target) {
    if (!isBrowser) {
        return emptyRect;
    }
    if (isSVGGraphicsElement(target)) {
        return getSVGContentRect(target);
    }
    return getHTMLElementContentRect(target);
}
/**
 * Creates rectangle with an interface of the DOMRectReadOnly.
 * Spec: https://drafts.fxtf.org/geometry/#domrectreadonly
 *
 * @param {DOMRectInit} rectInit - Object with rectangle's x/y coordinates and dimensions.
 * @returns {DOMRectReadOnly}
 */
function createReadOnlyRect(_a) {
    var x = _a.x, y = _a.y, width = _a.width, height = _a.height;
    // If DOMRectReadOnly is available use it as a prototype for the rectangle.
    var Constr = typeof DOMRectReadOnly !== 'undefined' ? DOMRectReadOnly : Object;
    var rect = Object.create(Constr.prototype);
    // Rectangle's properties are not writable and non-enumerable.
    defineConfigurable(rect, {
        x: x, y: y, width: width, height: height,
        top: y,
        right: x + width,
        bottom: height + y,
        left: x
    });
    return rect;
}
/**
 * Creates DOMRectInit object based on the provided dimensions and the x/y coordinates.
 * Spec: https://drafts.fxtf.org/geometry/#dictdef-domrectinit
 *
 * @param {number} x - X coordinate.
 * @param {number} y - Y coordinate.
 * @param {number} width - Rectangle's width.
 * @param {number} height - Rectangle's height.
 * @returns {DOMRectInit}
 */
function createRectInit(x, y, width, height) {
    return { x: x, y: y, width: width, height: height };
}

/**
 * Class that is responsible for computations of the content rectangle of
 * provided DOM element and for keeping track of it's changes.
 */
var ResizeObservation = /** @class */ (function () {
    /**
     * Creates an instance of ResizeObservation.
     *
     * @param {Element} target - Element to be observed.
     */
    function ResizeObservation(target) {
        /**
         * Broadcasted width of content rectangle.
         *
         * @type {number}
         */
        this.broadcastWidth = 0;
        /**
         * Broadcasted height of content rectangle.
         *
         * @type {number}
         */
        this.broadcastHeight = 0;
        /**
         * Reference to the last observed content rectangle.
         *
         * @private {DOMRectInit}
         */
        this.contentRect_ = createRectInit(0, 0, 0, 0);
        this.target = target;
    }
    /**
     * Updates content rectangle and tells whether it's width or height properties
     * have changed since the last broadcast.
     *
     * @returns {boolean}
     */
    ResizeObservation.prototype.isActive = function () {
        var rect = getContentRect(this.target);
        this.contentRect_ = rect;
        return (rect.width !== this.broadcastWidth ||
            rect.height !== this.broadcastHeight);
    };
    /**
     * Updates 'broadcastWidth' and 'broadcastHeight' properties with a data
     * from the corresponding properties of the last observed content rectangle.
     *
     * @returns {DOMRectInit} Last observed content rectangle.
     */
    ResizeObservation.prototype.broadcastRect = function () {
        var rect = this.contentRect_;
        this.broadcastWidth = rect.width;
        this.broadcastHeight = rect.height;
        return rect;
    };
    return ResizeObservation;
}());

var ResizeObserverEntry = /** @class */ (function () {
    /**
     * Creates an instance of ResizeObserverEntry.
     *
     * @param {Element} target - Element that is being observed.
     * @param {DOMRectInit} rectInit - Data of the element's content rectangle.
     */
    function ResizeObserverEntry(target, rectInit) {
        var contentRect = createReadOnlyRect(rectInit);
        // According to the specification following properties are not writable
        // and are also not enumerable in the native implementation.
        //
        // Property accessors are not being used as they'd require to define a
        // private WeakMap storage which may cause memory leaks in browsers that
        // don't support this type of collections.
        defineConfigurable(this, { target: target, contentRect: contentRect });
    }
    return ResizeObserverEntry;
}());

var ResizeObserverSPI = /** @class */ (function () {
    /**
     * Creates a new instance of ResizeObserver.
     *
     * @param {ResizeObserverCallback} callback - Callback function that is invoked
     *      when one of the observed elements changes it's content dimensions.
     * @param {ResizeObserverController} controller - Controller instance which
     *      is responsible for the updates of observer.
     * @param {ResizeObserver} callbackCtx - Reference to the public
     *      ResizeObserver instance which will be passed to callback function.
     */
    function ResizeObserverSPI(callback, controller, callbackCtx) {
        /**
         * Collection of resize observations that have detected changes in dimensions
         * of elements.
         *
         * @private {Array<ResizeObservation>}
         */
        this.activeObservations_ = [];
        /**
         * Registry of the ResizeObservation instances.
         *
         * @private {Map<Element, ResizeObservation>}
         */
        this.observations_ = new MapShim();
        if (typeof callback !== 'function') {
            throw new TypeError('The callback provided as parameter 1 is not a function.');
        }
        this.callback_ = callback;
        this.controller_ = controller;
        this.callbackCtx_ = callbackCtx;
    }
    /**
     * Starts observing provided element.
     *
     * @param {Element} target - Element to be observed.
     * @returns {void}
     */
    ResizeObserverSPI.prototype.observe = function (target) {
        if (!arguments.length) {
            throw new TypeError('1 argument required, but only 0 present.');
        }
        // Do nothing if current environment doesn't have the Element interface.
        if (typeof Element === 'undefined' || !(Element instanceof Object)) {
            return;
        }
        if (!(target instanceof getWindowOf(target).Element)) {
            throw new TypeError('parameter 1 is not of type "Element".');
        }
        var observations = this.observations_;
        // Do nothing if element is already being observed.
        if (observations.has(target)) {
            return;
        }
        observations.set(target, new ResizeObservation(target));
        this.controller_.addObserver(this);
        // Force the update of observations.
        this.controller_.refresh();
    };
    /**
     * Stops observing provided element.
     *
     * @param {Element} target - Element to stop observing.
     * @returns {void}
     */
    ResizeObserverSPI.prototype.unobserve = function (target) {
        if (!arguments.length) {
            throw new TypeError('1 argument required, but only 0 present.');
        }
        // Do nothing if current environment doesn't have the Element interface.
        if (typeof Element === 'undefined' || !(Element instanceof Object)) {
            return;
        }
        if (!(target instanceof getWindowOf(target).Element)) {
            throw new TypeError('parameter 1 is not of type "Element".');
        }
        var observations = this.observations_;
        // Do nothing if element is not being observed.
        if (!observations.has(target)) {
            return;
        }
        observations.delete(target);
        if (!observations.size) {
            this.controller_.removeObserver(this);
        }
    };
    /**
     * Stops observing all elements.
     *
     * @returns {void}
     */
    ResizeObserverSPI.prototype.disconnect = function () {
        this.clearActive();
        this.observations_.clear();
        this.controller_.removeObserver(this);
    };
    /**
     * Collects observation instances the associated element of which has changed
     * it's content rectangle.
     *
     * @returns {void}
     */
    ResizeObserverSPI.prototype.gatherActive = function () {
        var _this = this;
        this.clearActive();
        this.observations_.forEach(function (observation) {
            if (observation.isActive()) {
                _this.activeObservations_.push(observation);
            }
        });
    };
    /**
     * Invokes initial callback function with a list of ResizeObserverEntry
     * instances collected from active resize observations.
     *
     * @returns {void}
     */
    ResizeObserverSPI.prototype.broadcastActive = function () {
        // Do nothing if observer doesn't have active observations.
        if (!this.hasActive()) {
            return;
        }
        var ctx = this.callbackCtx_;
        // Create ResizeObserverEntry instance for every active observation.
        var entries = this.activeObservations_.map(function (observation) {
            return new ResizeObserverEntry(observation.target, observation.broadcastRect());
        });
        this.callback_.call(ctx, entries, ctx);
        this.clearActive();
    };
    /**
     * Clears the collection of active observations.
     *
     * @returns {void}
     */
    ResizeObserverSPI.prototype.clearActive = function () {
        this.activeObservations_.splice(0);
    };
    /**
     * Tells whether observer has active observations.
     *
     * @returns {boolean}
     */
    ResizeObserverSPI.prototype.hasActive = function () {
        return this.activeObservations_.length > 0;
    };
    return ResizeObserverSPI;
}());

// Registry of internal observers. If WeakMap is not available use current shim
// for the Map collection as it has all required methods and because WeakMap
// can't be fully polyfilled anyway.
var observers = typeof WeakMap !== 'undefined' ? new WeakMap() : new MapShim();
/**
 * ResizeObserver API. Encapsulates the ResizeObserver SPI implementation
 * exposing only those methods and properties that are defined in the spec.
 */
var ResizeObserver = /** @class */ (function () {
    /**
     * Creates a new instance of ResizeObserver.
     *
     * @param {ResizeObserverCallback} callback - Callback that is invoked when
     *      dimensions of the observed elements change.
     */
    function ResizeObserver(callback) {
        if (!(this instanceof ResizeObserver)) {
            throw new TypeError('Cannot call a class as a function.');
        }
        if (!arguments.length) {
            throw new TypeError('1 argument required, but only 0 present.');
        }
        var controller = ResizeObserverController.getInstance();
        var observer = new ResizeObserverSPI(callback, controller, this);
        observers.set(this, observer);
    }
    return ResizeObserver;
}());
// Expose public methods of ResizeObserver.
[
    'observe',
    'unobserve',
    'disconnect'
].forEach(function (method) {
    ResizeObserver.prototype[method] = function () {
        var _a;
        return (_a = observers.get(this))[method].apply(_a, arguments);
    };
});

var index = (function () {
    // Export existing implementation if available.
    if (typeof global$1.ResizeObserver !== 'undefined') {
        return global$1.ResizeObserver;
    }
    return ResizeObserver;
})();

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (index);


/***/ }),

/***/ "../../node_modules/seedrandom/index.js":
/*!**********************************************!*\
  !*** ../../node_modules/seedrandom/index.js ***!
  \**********************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

// A library of seedable RNGs implemented in Javascript.
//
// Usage:
//
// var seedrandom = require('seedrandom');
// var random = seedrandom(1); // or any seed.
// var x = random();       // 0 <= x < 1.  Every bit is random.
// var x = random.quick(); // 0 <= x < 1.  32 bits of randomness.

// alea, a 53-bit multiply-with-carry generator by Johannes Baagøe.
// Period: ~2^116
// Reported to pass all BigCrush tests.
var alea = __webpack_require__(/*! ./lib/alea */ "../../node_modules/seedrandom/lib/alea.js");

// xor128, a pure xor-shift generator by George Marsaglia.
// Period: 2^128-1.
// Reported to fail: MatrixRank and LinearComp.
var xor128 = __webpack_require__(/*! ./lib/xor128 */ "../../node_modules/seedrandom/lib/xor128.js");

// xorwow, George Marsaglia's 160-bit xor-shift combined plus weyl.
// Period: 2^192-2^32
// Reported to fail: CollisionOver, SimpPoker, and LinearComp.
var xorwow = __webpack_require__(/*! ./lib/xorwow */ "../../node_modules/seedrandom/lib/xorwow.js");

// xorshift7, by François Panneton and Pierre L'ecuyer, takes
// a different approach: it adds robustness by allowing more shifts
// than Marsaglia's original three.  It is a 7-shift generator
// with 256 bits, that passes BigCrush with no systmatic failures.
// Period 2^256-1.
// No systematic BigCrush failures reported.
var xorshift7 = __webpack_require__(/*! ./lib/xorshift7 */ "../../node_modules/seedrandom/lib/xorshift7.js");

// xor4096, by Richard Brent, is a 4096-bit xor-shift with a
// very long period that also adds a Weyl generator. It also passes
// BigCrush with no systematic failures.  Its long period may
// be useful if you have many generators and need to avoid
// collisions.
// Period: 2^4128-2^32.
// No systematic BigCrush failures reported.
var xor4096 = __webpack_require__(/*! ./lib/xor4096 */ "../../node_modules/seedrandom/lib/xor4096.js");

// Tyche-i, by Samuel Neves and Filipe Araujo, is a bit-shifting random
// number generator derived from ChaCha, a modern stream cipher.
// https://eden.dei.uc.pt/~sneves/pubs/2011-snfa2.pdf
// Period: ~2^127
// No systematic BigCrush failures reported.
var tychei = __webpack_require__(/*! ./lib/tychei */ "../../node_modules/seedrandom/lib/tychei.js");

// The original ARC4-based prng included in this library.
// Period: ~2^1600
var sr = __webpack_require__(/*! ./seedrandom */ "../../node_modules/seedrandom/seedrandom.js");

sr.alea = alea;
sr.xor128 = xor128;
sr.xorwow = xorwow;
sr.xorshift7 = xorshift7;
sr.xor4096 = xor4096;
sr.tychei = tychei;

module.exports = sr;


/***/ }),

/***/ "../../node_modules/seedrandom/lib/alea.js":
/*!*************************************************!*\
  !*** ../../node_modules/seedrandom/lib/alea.js ***!
  \*************************************************/
/***/ (function(module, exports, __webpack_require__) {

/* module decorator */ module = __webpack_require__.nmd(module);
var __WEBPACK_AMD_DEFINE_RESULT__;// A port of an algorithm by Johannes Baagøe <baagoe@baagoe.com>, 2010
// http://baagoe.com/en/RandomMusings/javascript/
// https://github.com/nquinlan/better-random-numbers-for-javascript-mirror
// Original work is under MIT license -

// Copyright (C) 2010 by Johannes Baagøe <baagoe@baagoe.org>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.



(function(global, module, define) {

function Alea(seed) {
  var me = this, mash = Mash();

  me.next = function() {
    var t = 2091639 * me.s0 + me.c * 2.3283064365386963e-10; // 2^-32
    me.s0 = me.s1;
    me.s1 = me.s2;
    return me.s2 = t - (me.c = t | 0);
  };

  // Apply the seeding algorithm from Baagoe.
  me.c = 1;
  me.s0 = mash(' ');
  me.s1 = mash(' ');
  me.s2 = mash(' ');
  me.s0 -= mash(seed);
  if (me.s0 < 0) { me.s0 += 1; }
  me.s1 -= mash(seed);
  if (me.s1 < 0) { me.s1 += 1; }
  me.s2 -= mash(seed);
  if (me.s2 < 0) { me.s2 += 1; }
  mash = null;
}

function copy(f, t) {
  t.c = f.c;
  t.s0 = f.s0;
  t.s1 = f.s1;
  t.s2 = f.s2;
  return t;
}

function impl(seed, opts) {
  var xg = new Alea(seed),
      state = opts && opts.state,
      prng = xg.next;
  prng.int32 = function() { return (xg.next() * 0x100000000) | 0; }
  prng.double = function() {
    return prng() + (prng() * 0x200000 | 0) * 1.1102230246251565e-16; // 2^-53
  };
  prng.quick = prng;
  if (state) {
    if (typeof(state) == 'object') copy(state, xg);
    prng.state = function() { return copy(xg, {}); }
  }
  return prng;
}

function Mash() {
  var n = 0xefc8249d;

  var mash = function(data) {
    data = String(data);
    for (var i = 0; i < data.length; i++) {
      n += data.charCodeAt(i);
      var h = 0.02519603282416938 * n;
      n = h >>> 0;
      h -= n;
      h *= n;
      n = h >>> 0;
      h -= n;
      n += h * 0x100000000; // 2^32
    }
    return (n >>> 0) * 2.3283064365386963e-10; // 2^-32
  };

  return mash;
}


if (module && module.exports) {
  module.exports = impl;
} else if (__webpack_require__.amdD && __webpack_require__.amdO) {
  !(__WEBPACK_AMD_DEFINE_RESULT__ = (function() { return impl; }).call(exports, __webpack_require__, exports, module),
		__WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
} else {
  this.alea = impl;
}

})(
  this,
   true && module,    // present in node.js
  __webpack_require__.amdD   // present with an AMD loader
);




/***/ }),

/***/ "../../node_modules/seedrandom/lib/tychei.js":
/*!***************************************************!*\
  !*** ../../node_modules/seedrandom/lib/tychei.js ***!
  \***************************************************/
/***/ (function(module, exports, __webpack_require__) {

/* module decorator */ module = __webpack_require__.nmd(module);
var __WEBPACK_AMD_DEFINE_RESULT__;// A Javascript implementaion of the "Tyche-i" prng algorithm by
// Samuel Neves and Filipe Araujo.
// See https://eden.dei.uc.pt/~sneves/pubs/2011-snfa2.pdf

(function(global, module, define) {

function XorGen(seed) {
  var me = this, strseed = '';

  // Set up generator function.
  me.next = function() {
    var b = me.b, c = me.c, d = me.d, a = me.a;
    b = (b << 25) ^ (b >>> 7) ^ c;
    c = (c - d) | 0;
    d = (d << 24) ^ (d >>> 8) ^ a;
    a = (a - b) | 0;
    me.b = b = (b << 20) ^ (b >>> 12) ^ c;
    me.c = c = (c - d) | 0;
    me.d = (d << 16) ^ (c >>> 16) ^ a;
    return me.a = (a - b) | 0;
  };

  /* The following is non-inverted tyche, which has better internal
   * bit diffusion, but which is about 25% slower than tyche-i in JS.
  me.next = function() {
    var a = me.a, b = me.b, c = me.c, d = me.d;
    a = (me.a + me.b | 0) >>> 0;
    d = me.d ^ a; d = d << 16 ^ d >>> 16;
    c = me.c + d | 0;
    b = me.b ^ c; b = b << 12 ^ d >>> 20;
    me.a = a = a + b | 0;
    d = d ^ a; me.d = d = d << 8 ^ d >>> 24;
    me.c = c = c + d | 0;
    b = b ^ c;
    return me.b = (b << 7 ^ b >>> 25);
  }
  */

  me.a = 0;
  me.b = 0;
  me.c = 2654435769 | 0;
  me.d = 1367130551;

  if (seed === Math.floor(seed)) {
    // Integer seed.
    me.a = (seed / 0x100000000) | 0;
    me.b = seed | 0;
  } else {
    // String seed.
    strseed += seed;
  }

  // Mix in string seed, then discard an initial batch of 64 values.
  for (var k = 0; k < strseed.length + 20; k++) {
    me.b ^= strseed.charCodeAt(k) | 0;
    me.next();
  }
}

function copy(f, t) {
  t.a = f.a;
  t.b = f.b;
  t.c = f.c;
  t.d = f.d;
  return t;
};

function impl(seed, opts) {
  var xg = new XorGen(seed),
      state = opts && opts.state,
      prng = function() { return (xg.next() >>> 0) / 0x100000000; };
  prng.double = function() {
    do {
      var top = xg.next() >>> 11,
          bot = (xg.next() >>> 0) / 0x100000000,
          result = (top + bot) / (1 << 21);
    } while (result === 0);
    return result;
  };
  prng.int32 = xg.next;
  prng.quick = prng;
  if (state) {
    if (typeof(state) == 'object') copy(state, xg);
    prng.state = function() { return copy(xg, {}); }
  }
  return prng;
}

if (module && module.exports) {
  module.exports = impl;
} else if (__webpack_require__.amdD && __webpack_require__.amdO) {
  !(__WEBPACK_AMD_DEFINE_RESULT__ = (function() { return impl; }).call(exports, __webpack_require__, exports, module),
		__WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
} else {
  this.tychei = impl;
}

})(
  this,
   true && module,    // present in node.js
  __webpack_require__.amdD   // present with an AMD loader
);




/***/ }),

/***/ "../../node_modules/seedrandom/lib/xor128.js":
/*!***************************************************!*\
  !*** ../../node_modules/seedrandom/lib/xor128.js ***!
  \***************************************************/
/***/ (function(module, exports, __webpack_require__) {

/* module decorator */ module = __webpack_require__.nmd(module);
var __WEBPACK_AMD_DEFINE_RESULT__;// A Javascript implementaion of the "xor128" prng algorithm by
// George Marsaglia.  See http://www.jstatsoft.org/v08/i14/paper

(function(global, module, define) {

function XorGen(seed) {
  var me = this, strseed = '';

  me.x = 0;
  me.y = 0;
  me.z = 0;
  me.w = 0;

  // Set up generator function.
  me.next = function() {
    var t = me.x ^ (me.x << 11);
    me.x = me.y;
    me.y = me.z;
    me.z = me.w;
    return me.w ^= (me.w >>> 19) ^ t ^ (t >>> 8);
  };

  if (seed === (seed | 0)) {
    // Integer seed.
    me.x = seed;
  } else {
    // String seed.
    strseed += seed;
  }

  // Mix in string seed, then discard an initial batch of 64 values.
  for (var k = 0; k < strseed.length + 64; k++) {
    me.x ^= strseed.charCodeAt(k) | 0;
    me.next();
  }
}

function copy(f, t) {
  t.x = f.x;
  t.y = f.y;
  t.z = f.z;
  t.w = f.w;
  return t;
}

function impl(seed, opts) {
  var xg = new XorGen(seed),
      state = opts && opts.state,
      prng = function() { return (xg.next() >>> 0) / 0x100000000; };
  prng.double = function() {
    do {
      var top = xg.next() >>> 11,
          bot = (xg.next() >>> 0) / 0x100000000,
          result = (top + bot) / (1 << 21);
    } while (result === 0);
    return result;
  };
  prng.int32 = xg.next;
  prng.quick = prng;
  if (state) {
    if (typeof(state) == 'object') copy(state, xg);
    prng.state = function() { return copy(xg, {}); }
  }
  return prng;
}

if (module && module.exports) {
  module.exports = impl;
} else if (__webpack_require__.amdD && __webpack_require__.amdO) {
  !(__WEBPACK_AMD_DEFINE_RESULT__ = (function() { return impl; }).call(exports, __webpack_require__, exports, module),
		__WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
} else {
  this.xor128 = impl;
}

})(
  this,
   true && module,    // present in node.js
  __webpack_require__.amdD   // present with an AMD loader
);




/***/ }),

/***/ "../../node_modules/seedrandom/lib/xor4096.js":
/*!****************************************************!*\
  !*** ../../node_modules/seedrandom/lib/xor4096.js ***!
  \****************************************************/
/***/ (function(module, exports, __webpack_require__) {

/* module decorator */ module = __webpack_require__.nmd(module);
var __WEBPACK_AMD_DEFINE_RESULT__;// A Javascript implementaion of Richard Brent's Xorgens xor4096 algorithm.
//
// This fast non-cryptographic random number generator is designed for
// use in Monte-Carlo algorithms. It combines a long-period xorshift
// generator with a Weyl generator, and it passes all common batteries
// of stasticial tests for randomness while consuming only a few nanoseconds
// for each prng generated.  For background on the generator, see Brent's
// paper: "Some long-period random number generators using shifts and xors."
// http://arxiv.org/pdf/1004.3115v1.pdf
//
// Usage:
//
// var xor4096 = require('xor4096');
// random = xor4096(1);                        // Seed with int32 or string.
// assert.equal(random(), 0.1520436450538547); // (0, 1) range, 53 bits.
// assert.equal(random.int32(), 1806534897);   // signed int32, 32 bits.
//
// For nonzero numeric keys, this impelementation provides a sequence
// identical to that by Brent's xorgens 3 implementaion in C.  This
// implementation also provides for initalizing the generator with
// string seeds, or for saving and restoring the state of the generator.
//
// On Chrome, this prng benchmarks about 2.1 times slower than
// Javascript's built-in Math.random().

(function(global, module, define) {

function XorGen(seed) {
  var me = this;

  // Set up generator function.
  me.next = function() {
    var w = me.w,
        X = me.X, i = me.i, t, v;
    // Update Weyl generator.
    me.w = w = (w + 0x61c88647) | 0;
    // Update xor generator.
    v = X[(i + 34) & 127];
    t = X[i = ((i + 1) & 127)];
    v ^= v << 13;
    t ^= t << 17;
    v ^= v >>> 15;
    t ^= t >>> 12;
    // Update Xor generator array state.
    v = X[i] = v ^ t;
    me.i = i;
    // Result is the combination.
    return (v + (w ^ (w >>> 16))) | 0;
  };

  function init(me, seed) {
    var t, v, i, j, w, X = [], limit = 128;
    if (seed === (seed | 0)) {
      // Numeric seeds initialize v, which is used to generates X.
      v = seed;
      seed = null;
    } else {
      // String seeds are mixed into v and X one character at a time.
      seed = seed + '\0';
      v = 0;
      limit = Math.max(limit, seed.length);
    }
    // Initialize circular array and weyl value.
    for (i = 0, j = -32; j < limit; ++j) {
      // Put the unicode characters into the array, and shuffle them.
      if (seed) v ^= seed.charCodeAt((j + 32) % seed.length);
      // After 32 shuffles, take v as the starting w value.
      if (j === 0) w = v;
      v ^= v << 10;
      v ^= v >>> 15;
      v ^= v << 4;
      v ^= v >>> 13;
      if (j >= 0) {
        w = (w + 0x61c88647) | 0;     // Weyl.
        t = (X[j & 127] ^= (v + w));  // Combine xor and weyl to init array.
        i = (0 == t) ? i + 1 : 0;     // Count zeroes.
      }
    }
    // We have detected all zeroes; make the key nonzero.
    if (i >= 128) {
      X[(seed && seed.length || 0) & 127] = -1;
    }
    // Run the generator 512 times to further mix the state before using it.
    // Factoring this as a function slows the main generator, so it is just
    // unrolled here.  The weyl generator is not advanced while warming up.
    i = 127;
    for (j = 4 * 128; j > 0; --j) {
      v = X[(i + 34) & 127];
      t = X[i = ((i + 1) & 127)];
      v ^= v << 13;
      t ^= t << 17;
      v ^= v >>> 15;
      t ^= t >>> 12;
      X[i] = v ^ t;
    }
    // Storing state as object members is faster than using closure variables.
    me.w = w;
    me.X = X;
    me.i = i;
  }

  init(me, seed);
}

function copy(f, t) {
  t.i = f.i;
  t.w = f.w;
  t.X = f.X.slice();
  return t;
};

function impl(seed, opts) {
  if (seed == null) seed = +(new Date);
  var xg = new XorGen(seed),
      state = opts && opts.state,
      prng = function() { return (xg.next() >>> 0) / 0x100000000; };
  prng.double = function() {
    do {
      var top = xg.next() >>> 11,
          bot = (xg.next() >>> 0) / 0x100000000,
          result = (top + bot) / (1 << 21);
    } while (result === 0);
    return result;
  };
  prng.int32 = xg.next;
  prng.quick = prng;
  if (state) {
    if (state.X) copy(state, xg);
    prng.state = function() { return copy(xg, {}); }
  }
  return prng;
}

if (module && module.exports) {
  module.exports = impl;
} else if (__webpack_require__.amdD && __webpack_require__.amdO) {
  !(__WEBPACK_AMD_DEFINE_RESULT__ = (function() { return impl; }).call(exports, __webpack_require__, exports, module),
		__WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
} else {
  this.xor4096 = impl;
}

})(
  this,                                     // window object or global
   true && module,    // present in node.js
  __webpack_require__.amdD   // present with an AMD loader
);


/***/ }),

/***/ "../../node_modules/seedrandom/lib/xorshift7.js":
/*!******************************************************!*\
  !*** ../../node_modules/seedrandom/lib/xorshift7.js ***!
  \******************************************************/
/***/ (function(module, exports, __webpack_require__) {

/* module decorator */ module = __webpack_require__.nmd(module);
var __WEBPACK_AMD_DEFINE_RESULT__;// A Javascript implementaion of the "xorshift7" algorithm by
// François Panneton and Pierre L'ecuyer:
// "On the Xorgshift Random Number Generators"
// http://saluc.engr.uconn.edu/refs/crypto/rng/panneton05onthexorshift.pdf

(function(global, module, define) {

function XorGen(seed) {
  var me = this;

  // Set up generator function.
  me.next = function() {
    // Update xor generator.
    var X = me.x, i = me.i, t, v, w;
    t = X[i]; t ^= (t >>> 7); v = t ^ (t << 24);
    t = X[(i + 1) & 7]; v ^= t ^ (t >>> 10);
    t = X[(i + 3) & 7]; v ^= t ^ (t >>> 3);
    t = X[(i + 4) & 7]; v ^= t ^ (t << 7);
    t = X[(i + 7) & 7]; t = t ^ (t << 13); v ^= t ^ (t << 9);
    X[i] = v;
    me.i = (i + 1) & 7;
    return v;
  };

  function init(me, seed) {
    var j, w, X = [];

    if (seed === (seed | 0)) {
      // Seed state array using a 32-bit integer.
      w = X[0] = seed;
    } else {
      // Seed state using a string.
      seed = '' + seed;
      for (j = 0; j < seed.length; ++j) {
        X[j & 7] = (X[j & 7] << 15) ^
            (seed.charCodeAt(j) + X[(j + 1) & 7] << 13);
      }
    }
    // Enforce an array length of 8, not all zeroes.
    while (X.length < 8) X.push(0);
    for (j = 0; j < 8 && X[j] === 0; ++j);
    if (j == 8) w = X[7] = -1; else w = X[j];

    me.x = X;
    me.i = 0;

    // Discard an initial 256 values.
    for (j = 256; j > 0; --j) {
      me.next();
    }
  }

  init(me, seed);
}

function copy(f, t) {
  t.x = f.x.slice();
  t.i = f.i;
  return t;
}

function impl(seed, opts) {
  if (seed == null) seed = +(new Date);
  var xg = new XorGen(seed),
      state = opts && opts.state,
      prng = function() { return (xg.next() >>> 0) / 0x100000000; };
  prng.double = function() {
    do {
      var top = xg.next() >>> 11,
          bot = (xg.next() >>> 0) / 0x100000000,
          result = (top + bot) / (1 << 21);
    } while (result === 0);
    return result;
  };
  prng.int32 = xg.next;
  prng.quick = prng;
  if (state) {
    if (state.x) copy(state, xg);
    prng.state = function() { return copy(xg, {}); }
  }
  return prng;
}

if (module && module.exports) {
  module.exports = impl;
} else if (__webpack_require__.amdD && __webpack_require__.amdO) {
  !(__WEBPACK_AMD_DEFINE_RESULT__ = (function() { return impl; }).call(exports, __webpack_require__, exports, module),
		__WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
} else {
  this.xorshift7 = impl;
}

})(
  this,
   true && module,    // present in node.js
  __webpack_require__.amdD   // present with an AMD loader
);



/***/ }),

/***/ "../../node_modules/seedrandom/lib/xorwow.js":
/*!***************************************************!*\
  !*** ../../node_modules/seedrandom/lib/xorwow.js ***!
  \***************************************************/
/***/ (function(module, exports, __webpack_require__) {

/* module decorator */ module = __webpack_require__.nmd(module);
var __WEBPACK_AMD_DEFINE_RESULT__;// A Javascript implementaion of the "xorwow" prng algorithm by
// George Marsaglia.  See http://www.jstatsoft.org/v08/i14/paper

(function(global, module, define) {

function XorGen(seed) {
  var me = this, strseed = '';

  // Set up generator function.
  me.next = function() {
    var t = (me.x ^ (me.x >>> 2));
    me.x = me.y; me.y = me.z; me.z = me.w; me.w = me.v;
    return (me.d = (me.d + 362437 | 0)) +
       (me.v = (me.v ^ (me.v << 4)) ^ (t ^ (t << 1))) | 0;
  };

  me.x = 0;
  me.y = 0;
  me.z = 0;
  me.w = 0;
  me.v = 0;

  if (seed === (seed | 0)) {
    // Integer seed.
    me.x = seed;
  } else {
    // String seed.
    strseed += seed;
  }

  // Mix in string seed, then discard an initial batch of 64 values.
  for (var k = 0; k < strseed.length + 64; k++) {
    me.x ^= strseed.charCodeAt(k) | 0;
    if (k == strseed.length) {
      me.d = me.x << 10 ^ me.x >>> 4;
    }
    me.next();
  }
}

function copy(f, t) {
  t.x = f.x;
  t.y = f.y;
  t.z = f.z;
  t.w = f.w;
  t.v = f.v;
  t.d = f.d;
  return t;
}

function impl(seed, opts) {
  var xg = new XorGen(seed),
      state = opts && opts.state,
      prng = function() { return (xg.next() >>> 0) / 0x100000000; };
  prng.double = function() {
    do {
      var top = xg.next() >>> 11,
          bot = (xg.next() >>> 0) / 0x100000000,
          result = (top + bot) / (1 << 21);
    } while (result === 0);
    return result;
  };
  prng.int32 = xg.next;
  prng.quick = prng;
  if (state) {
    if (typeof(state) == 'object') copy(state, xg);
    prng.state = function() { return copy(xg, {}); }
  }
  return prng;
}

if (module && module.exports) {
  module.exports = impl;
} else if (__webpack_require__.amdD && __webpack_require__.amdO) {
  !(__WEBPACK_AMD_DEFINE_RESULT__ = (function() { return impl; }).call(exports, __webpack_require__, exports, module),
		__WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
} else {
  this.xorwow = impl;
}

})(
  this,
   true && module,    // present in node.js
  __webpack_require__.amdD   // present with an AMD loader
);




/***/ }),

/***/ "../../node_modules/seedrandom/seedrandom.js":
/*!***************************************************!*\
  !*** ../../node_modules/seedrandom/seedrandom.js ***!
  \***************************************************/
/***/ (function(module, exports, __webpack_require__) {

var __WEBPACK_AMD_DEFINE_RESULT__;/*
Copyright 2019 David Bau.

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*/

(function (global, pool, math) {
//
// The following constants are related to IEEE 754 limits.
//

var width = 256,        // each RC4 output is 0 <= x < 256
    chunks = 6,         // at least six RC4 outputs for each double
    digits = 52,        // there are 52 significant digits in a double
    rngname = 'random', // rngname: name for Math.random and Math.seedrandom
    startdenom = math.pow(width, chunks),
    significance = math.pow(2, digits),
    overflow = significance * 2,
    mask = width - 1,
    nodecrypto;         // node.js crypto module, initialized at the bottom.

//
// seedrandom()
// This is the seedrandom function described above.
//
function seedrandom(seed, options, callback) {
  var key = [];
  options = (options == true) ? { entropy: true } : (options || {});

  // Flatten the seed string or build one from local entropy if needed.
  var shortseed = mixkey(flatten(
    options.entropy ? [seed, tostring(pool)] :
    (seed == null) ? autoseed() : seed, 3), key);

  // Use the seed to initialize an ARC4 generator.
  var arc4 = new ARC4(key);

  // This function returns a random double in [0, 1) that contains
  // randomness in every bit of the mantissa of the IEEE 754 value.
  var prng = function() {
    var n = arc4.g(chunks),             // Start with a numerator n < 2 ^ 48
        d = startdenom,                 //   and denominator d = 2 ^ 48.
        x = 0;                          //   and no 'extra last byte'.
    while (n < significance) {          // Fill up all significant digits by
      n = (n + x) * width;              //   shifting numerator and
      d *= width;                       //   denominator and generating a
      x = arc4.g(1);                    //   new least-significant-byte.
    }
    while (n >= overflow) {             // To avoid rounding up, before adding
      n /= 2;                           //   last byte, shift everything
      d /= 2;                           //   right using integer math until
      x >>>= 1;                         //   we have exactly the desired bits.
    }
    return (n + x) / d;                 // Form the number within [0, 1).
  };

  prng.int32 = function() { return arc4.g(4) | 0; }
  prng.quick = function() { return arc4.g(4) / 0x100000000; }
  prng.double = prng;

  // Mix the randomness into accumulated entropy.
  mixkey(tostring(arc4.S), pool);

  // Calling convention: what to return as a function of prng, seed, is_math.
  return (options.pass || callback ||
      function(prng, seed, is_math_call, state) {
        if (state) {
          // Load the arc4 state from the given state if it has an S array.
          if (state.S) { copy(state, arc4); }
          // Only provide the .state method if requested via options.state.
          prng.state = function() { return copy(arc4, {}); }
        }

        // If called as a method of Math (Math.seedrandom()), mutate
        // Math.random because that is how seedrandom.js has worked since v1.0.
        if (is_math_call) { math[rngname] = prng; return seed; }

        // Otherwise, it is a newer calling convention, so return the
        // prng directly.
        else return prng;
      })(
  prng,
  shortseed,
  'global' in options ? options.global : (this == math),
  options.state);
}

//
// ARC4
//
// An ARC4 implementation.  The constructor takes a key in the form of
// an array of at most (width) integers that should be 0 <= x < (width).
//
// The g(count) method returns a pseudorandom integer that concatenates
// the next (count) outputs from ARC4.  Its return value is a number x
// that is in the range 0 <= x < (width ^ count).
//
function ARC4(key) {
  var t, keylen = key.length,
      me = this, i = 0, j = me.i = me.j = 0, s = me.S = [];

  // The empty key [] is treated as [0].
  if (!keylen) { key = [keylen++]; }

  // Set up S using the standard key scheduling algorithm.
  while (i < width) {
    s[i] = i++;
  }
  for (i = 0; i < width; i++) {
    s[i] = s[j = mask & (j + key[i % keylen] + (t = s[i]))];
    s[j] = t;
  }

  // The "g" method returns the next (count) outputs as one number.
  (me.g = function(count) {
    // Using instance members instead of closure state nearly doubles speed.
    var t, r = 0,
        i = me.i, j = me.j, s = me.S;
    while (count--) {
      t = s[i = mask & (i + 1)];
      r = r * width + s[mask & ((s[i] = s[j = mask & (j + t)]) + (s[j] = t))];
    }
    me.i = i; me.j = j;
    return r;
    // For robust unpredictability, the function call below automatically
    // discards an initial batch of values.  This is called RC4-drop[256].
    // See http://google.com/search?q=rsa+fluhrer+response&btnI
  })(width);
}

//
// copy()
// Copies internal state of ARC4 to or from a plain object.
//
function copy(f, t) {
  t.i = f.i;
  t.j = f.j;
  t.S = f.S.slice();
  return t;
};

//
// flatten()
// Converts an object tree to nested arrays of strings.
//
function flatten(obj, depth) {
  var result = [], typ = (typeof obj), prop;
  if (depth && typ == 'object') {
    for (prop in obj) {
      try { result.push(flatten(obj[prop], depth - 1)); } catch (e) {}
    }
  }
  return (result.length ? result : typ == 'string' ? obj : obj + '\0');
}

//
// mixkey()
// Mixes a string seed into a key that is an array of integers, and
// returns a shortened string seed that is equivalent to the result key.
//
function mixkey(seed, key) {
  var stringseed = seed + '', smear, j = 0;
  while (j < stringseed.length) {
    key[mask & j] =
      mask & ((smear ^= key[mask & j] * 19) + stringseed.charCodeAt(j++));
  }
  return tostring(key);
}

//
// autoseed()
// Returns an object for autoseeding, using window.crypto and Node crypto
// module if available.
//
function autoseed() {
  try {
    var out;
    if (nodecrypto && (out = nodecrypto.randomBytes)) {
      // The use of 'out' to remember randomBytes makes tight minified code.
      out = out(width);
    } else {
      out = new Uint8Array(width);
      (global.crypto || global.msCrypto).getRandomValues(out);
    }
    return tostring(out);
  } catch (e) {
    var browser = global.navigator,
        plugins = browser && browser.plugins;
    return [+new Date, global, plugins, global.screen, tostring(pool)];
  }
}

//
// tostring()
// Converts an array of charcodes to a string
//
function tostring(a) {
  return String.fromCharCode.apply(0, a);
}

//
// When seedrandom.js is loaded, we immediately mix a few bits
// from the built-in RNG into the entropy pool.  Because we do
// not want to interfere with deterministic PRNG state later,
// seedrandom will not call math.random on its own again after
// initialization.
//
mixkey(math.random(), pool);

//
// Nodejs and AMD support: export the implementation as a module using
// either convention.
//
if ( true && module.exports) {
  module.exports = seedrandom;
  // When in node.js, try using crypto package for autoseeding.
  try {
    nodecrypto = __webpack_require__(/*! crypto */ "?6b1e");
  } catch (ex) {}
} else if (true) {
  !(__WEBPACK_AMD_DEFINE_RESULT__ = (function() { return seedrandom; }).call(exports, __webpack_require__, exports, module),
		__WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
} else {}


// End anonymous scope, and pass initial values.
})(
  // global: `self` in browsers (including strict mode and web workers),
  // otherwise `this` in Node and other environments
  (typeof self !== 'undefined') ? self : this,
  [],     // pool: entropy pool starts empty
  Math    // math: package containing random, pow, and seedrandom
);


/***/ }),

/***/ "../../node_modules/shallowequal/index.js":
/*!************************************************!*\
  !*** ../../node_modules/shallowequal/index.js ***!
  \************************************************/
/***/ ((module) => {

//

module.exports = function shallowEqual(objA, objB, compare, compareContext) {
  var ret = compare ? compare.call(compareContext, objA, objB) : void 0;

  if (ret !== void 0) {
    return !!ret;
  }

  if (objA === objB) {
    return true;
  }

  if (typeof objA !== "object" || !objA || typeof objB !== "object" || !objB) {
    return false;
  }

  var keysA = Object.keys(objA);
  var keysB = Object.keys(objB);

  if (keysA.length !== keysB.length) {
    return false;
  }

  var bHasOwnProperty = Object.prototype.hasOwnProperty.bind(objB);

  // Test for A's keys different from B.
  for (var idx = 0; idx < keysA.length; idx++) {
    var key = keysA[idx];

    if (!bHasOwnProperty(key)) {
      return false;
    }

    var valueA = objA[key];
    var valueB = objB[key];

    ret = compare ? compare.call(compareContext, valueA, valueB, key) : void 0;

    if (ret === false || (ret === void 0 && valueA !== valueB)) {
      return false;
    }
  }

  return true;
};


/***/ }),

/***/ "../../node_modules/@elyra/canvas/dist/styles/common-canvas.min.css":
/*!**************************************************************************!*\
  !*** ../../node_modules/@elyra/canvas/dist/styles/common-canvas.min.css ***!
  \**************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! !../../../../style-loader/dist/runtime/injectStylesIntoStyleTag.js */ "../../node_modules/style-loader/dist/runtime/injectStylesIntoStyleTag.js");
/* harmony import */ var _style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _css_loader_dist_cjs_js_common_canvas_min_css__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! !!../../../../css-loader/dist/cjs.js!./common-canvas.min.css */ "../../node_modules/css-loader/dist/cjs.js!../../node_modules/@elyra/canvas/dist/styles/common-canvas.min.css");

            

var options = {};

options.insert = "head";
options.singleton = false;

var update = _style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0___default()(_css_loader_dist_cjs_js_common_canvas_min_css__WEBPACK_IMPORTED_MODULE_1__["default"], options);



/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_css_loader_dist_cjs_js_common_canvas_min_css__WEBPACK_IMPORTED_MODULE_1__["default"].locals || {});

/***/ }),

/***/ "../../node_modules/styled-components/dist/styled-components.browser.esm.js":
/*!**********************************************************************************!*\
  !*** ../../node_modules/styled-components/dist/styled-components.browser.esm.js ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "ServerStyleSheet": () => (/* binding */ Je),
/* harmony export */   "StyleSheetConsumer": () => (/* binding */ le),
/* harmony export */   "StyleSheetContext": () => (/* binding */ ue),
/* harmony export */   "StyleSheetManager": () => (/* binding */ ye),
/* harmony export */   "ThemeConsumer": () => (/* binding */ Le),
/* harmony export */   "ThemeContext": () => (/* binding */ Ge),
/* harmony export */   "ThemeProvider": () => (/* binding */ Fe),
/* harmony export */   "__PRIVATE__": () => (/* binding */ Ke),
/* harmony export */   "createGlobalStyle": () => (/* binding */ We),
/* harmony export */   "css": () => (/* binding */ Ce),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__),
/* harmony export */   "isStyledComponent": () => (/* binding */ N),
/* harmony export */   "keyframes": () => (/* binding */ Ue),
/* harmony export */   "useTheme": () => (/* binding */ Ze),
/* harmony export */   "version": () => (/* binding */ C),
/* harmony export */   "withTheme": () => (/* binding */ Xe)
/* harmony export */ });
/* harmony import */ var react_is__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react-is */ "../../node_modules/react-is/index.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var shallowequal__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! shallowequal */ "../../node_modules/shallowequal/index.js");
/* harmony import */ var shallowequal__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(shallowequal__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _emotion_stylis__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @emotion/stylis */ "../../node_modules/@emotion/stylis/dist/stylis.browser.esm.js");
/* harmony import */ var _emotion_unitless__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @emotion/unitless */ "../../node_modules/@emotion/unitless/dist/unitless.browser.esm.js");
/* harmony import */ var _emotion_is_prop_valid__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @emotion/is-prop-valid */ "../../node_modules/@emotion/is-prop-valid/dist/emotion-is-prop-valid.browser.esm.js");
/* harmony import */ var hoist_non_react_statics__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! hoist-non-react-statics */ "../../node_modules/hoist-non-react-statics/dist/hoist-non-react-statics.cjs.js");
/* harmony import */ var hoist_non_react_statics__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(hoist_non_react_statics__WEBPACK_IMPORTED_MODULE_6__);
/* provided dependency */ var process = __webpack_require__(/*! process/browser */ "../../node_modules/process/browser.js");
function v(){return(v=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e}).apply(this,arguments)}var g=function(e,t){for(var n=[e[0]],r=0,o=t.length;r<o;r+=1)n.push(t[r],e[r+1]);return n},S=function(t){return null!==t&&"object"==typeof t&&"[object Object]"===(t.toString?t.toString():Object.prototype.toString.call(t))&&!(0,react_is__WEBPACK_IMPORTED_MODULE_0__.typeOf)(t)},w=Object.freeze([]),E=Object.freeze({});function b(e){return"function"==typeof e}function _(e){return true&&"string"==typeof e&&e||e.displayName||e.name||"Component"}function N(e){return e&&"string"==typeof e.styledComponentId}var A="undefined"!=typeof process&&(process.env.REACT_APP_SC_ATTR||process.env.SC_ATTR)||"data-styled",C="5.3.5",I="undefined"!=typeof window&&"HTMLElement"in window,P=Boolean("boolean"==typeof SC_DISABLE_SPEEDY?SC_DISABLE_SPEEDY:"undefined"!=typeof process&&void 0!==process.env.REACT_APP_SC_DISABLE_SPEEDY&&""!==process.env.REACT_APP_SC_DISABLE_SPEEDY?"false"!==process.env.REACT_APP_SC_DISABLE_SPEEDY&&process.env.REACT_APP_SC_DISABLE_SPEEDY:"undefined"!=typeof process&&void 0!==process.env.SC_DISABLE_SPEEDY&&""!==process.env.SC_DISABLE_SPEEDY?"false"!==process.env.SC_DISABLE_SPEEDY&&process.env.SC_DISABLE_SPEEDY:"production"!=="development"),O={},R= true?{1:"Cannot create styled-component for component: %s.\n\n",2:"Can't collect styles once you've consumed a `ServerStyleSheet`'s styles! `ServerStyleSheet` is a one off instance for each server-side render cycle.\n\n- Are you trying to reuse it across renders?\n- Are you accidentally calling collectStyles twice?\n\n",3:"Streaming SSR is only supported in a Node.js environment; Please do not try to call this method in the browser.\n\n",4:"The `StyleSheetManager` expects a valid target or sheet prop!\n\n- Does this error occur on the client and is your target falsy?\n- Does this error occur on the server and is the sheet falsy?\n\n",5:"The clone method cannot be used on the client!\n\n- Are you running in a client-like environment on the server?\n- Are you trying to run SSR on the client?\n\n",6:"Trying to insert a new style tag, but the given Node is unmounted!\n\n- Are you using a custom target that isn't mounted?\n- Does your document not have a valid head element?\n- Have you accidentally removed a style tag manually?\n\n",7:'ThemeProvider: Please return an object from your "theme" prop function, e.g.\n\n```js\ntheme={() => ({})}\n```\n\n',8:'ThemeProvider: Please make your "theme" prop an object.\n\n',9:"Missing document `<head>`\n\n",10:"Cannot find a StyleSheet instance. Usually this happens if there are multiple copies of styled-components loaded at once. Check out this issue for how to troubleshoot and fix the common cases where this situation can happen: https://github.com/styled-components/styled-components/issues/1941#issuecomment-417862021\n\n",11:"_This error was replaced with a dev-time warning, it will be deleted for v4 final._ [createGlobalStyle] received children which will not be rendered. Please use the component without passing children elements.\n\n",12:"It seems you are interpolating a keyframe declaration (%s) into an untagged string. This was supported in styled-components v3, but is not longer supported in v4 as keyframes are now injected on-demand. Please wrap your string in the css\\`\\` helper which ensures the styles are injected correctly. See https://www.styled-components.com/docs/api#css\n\n",13:"%s is not a styled component and cannot be referred to via component selector. See https://www.styled-components.com/docs/advanced#referring-to-other-components for more details.\n\n",14:'ThemeProvider: "theme" prop is required.\n\n',15:"A stylis plugin has been supplied that is not named. We need a name for each plugin to be able to prevent styling collisions between different stylis configurations within the same app. Before you pass your plugin to `<StyleSheetManager stylisPlugins={[]}>`, please make sure each plugin is uniquely-named, e.g.\n\n```js\nObject.defineProperty(importedPlugin, 'name', { value: 'some-unique-name' });\n```\n\n",16:"Reached the limit of how many styled components may be created at group %s.\nYou may only create up to 1,073,741,824 components. If you're creating components dynamically,\nas for instance in your render method then you may be running into this limitation.\n\n",17:"CSSStyleSheet could not be found on HTMLStyleElement.\nHas styled-components' style tag been unmounted or altered by another script?\n"}:0;function D(){for(var e=arguments.length<=0?void 0:arguments[0],t=[],n=1,r=arguments.length;n<r;n+=1)t.push(n<0||arguments.length<=n?void 0:arguments[n]);return t.forEach((function(t){e=e.replace(/%[a-z]/,t)})),e}function j(e){for(var t=arguments.length,n=new Array(t>1?t-1:0),r=1;r<t;r++)n[r-1]=arguments[r];throw false?0:new Error(D.apply(void 0,[R[e]].concat(n)).trim())}var T=function(){function e(e){this.groupSizes=new Uint32Array(512),this.length=512,this.tag=e}var t=e.prototype;return t.indexOfGroup=function(e){for(var t=0,n=0;n<e;n++)t+=this.groupSizes[n];return t},t.insertRules=function(e,t){if(e>=this.groupSizes.length){for(var n=this.groupSizes,r=n.length,o=r;e>=o;)(o<<=1)<0&&j(16,""+e);this.groupSizes=new Uint32Array(o),this.groupSizes.set(n),this.length=o;for(var s=r;s<o;s++)this.groupSizes[s]=0}for(var i=this.indexOfGroup(e+1),a=0,c=t.length;a<c;a++)this.tag.insertRule(i,t[a])&&(this.groupSizes[e]++,i++)},t.clearGroup=function(e){if(e<this.length){var t=this.groupSizes[e],n=this.indexOfGroup(e),r=n+t;this.groupSizes[e]=0;for(var o=n;o<r;o++)this.tag.deleteRule(n)}},t.getGroup=function(e){var t="";if(e>=this.length||0===this.groupSizes[e])return t;for(var n=this.groupSizes[e],r=this.indexOfGroup(e),o=r+n,s=r;s<o;s++)t+=this.tag.getRule(s)+"/*!sc*/\n";return t},e}(),x=new Map,k=new Map,V=1,B=function(e){if(x.has(e))return x.get(e);for(;k.has(V);)V++;var t=V++;return true&&((0|t)<0||t>1<<30)&&j(16,""+t),x.set(e,t),k.set(t,e),t},z=function(e){return k.get(e)},M=function(e,t){t>=V&&(V=t+1),x.set(e,t),k.set(t,e)},G="style["+A+'][data-styled-version="5.3.5"]',L=new RegExp("^"+A+'\\.g(\\d+)\\[id="([\\w\\d-]+)"\\].*?"([^"]*)'),F=function(e,t,n){for(var r,o=n.split(","),s=0,i=o.length;s<i;s++)(r=o[s])&&e.registerName(t,r)},Y=function(e,t){for(var n=(t.textContent||"").split("/*!sc*/\n"),r=[],o=0,s=n.length;o<s;o++){var i=n[o].trim();if(i){var a=i.match(L);if(a){var c=0|parseInt(a[1],10),u=a[2];0!==c&&(M(u,c),F(e,u,a[3]),e.getTag().insertRules(c,r)),r.length=0}else r.push(i)}}},q=function(){return"undefined"!=typeof window&&void 0!==window.__webpack_nonce__?window.__webpack_nonce__:null},H=function(e){var t=document.head,n=e||t,r=document.createElement("style"),o=function(e){for(var t=e.childNodes,n=t.length;n>=0;n--){var r=t[n];if(r&&1===r.nodeType&&r.hasAttribute(A))return r}}(n),s=void 0!==o?o.nextSibling:null;r.setAttribute(A,"active"),r.setAttribute("data-styled-version","5.3.5");var i=q();return i&&r.setAttribute("nonce",i),n.insertBefore(r,s),r},$=function(){function e(e){var t=this.element=H(e);t.appendChild(document.createTextNode("")),this.sheet=function(e){if(e.sheet)return e.sheet;for(var t=document.styleSheets,n=0,r=t.length;n<r;n++){var o=t[n];if(o.ownerNode===e)return o}j(17)}(t),this.length=0}var t=e.prototype;return t.insertRule=function(e,t){try{return this.sheet.insertRule(t,e),this.length++,!0}catch(e){return!1}},t.deleteRule=function(e){this.sheet.deleteRule(e),this.length--},t.getRule=function(e){var t=this.sheet.cssRules[e];return void 0!==t&&"string"==typeof t.cssText?t.cssText:""},e}(),W=function(){function e(e){var t=this.element=H(e);this.nodes=t.childNodes,this.length=0}var t=e.prototype;return t.insertRule=function(e,t){if(e<=this.length&&e>=0){var n=document.createTextNode(t),r=this.nodes[e];return this.element.insertBefore(n,r||null),this.length++,!0}return!1},t.deleteRule=function(e){this.element.removeChild(this.nodes[e]),this.length--},t.getRule=function(e){return e<this.length?this.nodes[e].textContent:""},e}(),U=function(){function e(e){this.rules=[],this.length=0}var t=e.prototype;return t.insertRule=function(e,t){return e<=this.length&&(this.rules.splice(e,0,t),this.length++,!0)},t.deleteRule=function(e){this.rules.splice(e,1),this.length--},t.getRule=function(e){return e<this.length?this.rules[e]:""},e}(),J=I,X={isServer:!I,useCSSOMInjection:!P},Z=function(){function e(e,t,n){void 0===e&&(e=E),void 0===t&&(t={}),this.options=v({},X,{},e),this.gs=t,this.names=new Map(n),this.server=!!e.isServer,!this.server&&I&&J&&(J=!1,function(e){for(var t=document.querySelectorAll(G),n=0,r=t.length;n<r;n++){var o=t[n];o&&"active"!==o.getAttribute(A)&&(Y(e,o),o.parentNode&&o.parentNode.removeChild(o))}}(this))}e.registerId=function(e){return B(e)};var t=e.prototype;return t.reconstructWithOptions=function(t,n){return void 0===n&&(n=!0),new e(v({},this.options,{},t),this.gs,n&&this.names||void 0)},t.allocateGSInstance=function(e){return this.gs[e]=(this.gs[e]||0)+1},t.getTag=function(){return this.tag||(this.tag=(n=(t=this.options).isServer,r=t.useCSSOMInjection,o=t.target,e=n?new U(o):r?new $(o):new W(o),new T(e)));var e,t,n,r,o},t.hasNameForId=function(e,t){return this.names.has(e)&&this.names.get(e).has(t)},t.registerName=function(e,t){if(B(e),this.names.has(e))this.names.get(e).add(t);else{var n=new Set;n.add(t),this.names.set(e,n)}},t.insertRules=function(e,t,n){this.registerName(e,t),this.getTag().insertRules(B(e),n)},t.clearNames=function(e){this.names.has(e)&&this.names.get(e).clear()},t.clearRules=function(e){this.getTag().clearGroup(B(e)),this.clearNames(e)},t.clearTag=function(){this.tag=void 0},t.toString=function(){return function(e){for(var t=e.getTag(),n=t.length,r="",o=0;o<n;o++){var s=z(o);if(void 0!==s){var i=e.names.get(s),a=t.getGroup(o);if(i&&a&&i.size){var c=A+".g"+o+'[id="'+s+'"]',u="";void 0!==i&&i.forEach((function(e){e.length>0&&(u+=e+",")})),r+=""+a+c+'{content:"'+u+'"}/*!sc*/\n'}}}return r}(this)},e}(),K=/(a)(d)/gi,Q=function(e){return String.fromCharCode(e+(e>25?39:97))};function ee(e){var t,n="";for(t=Math.abs(e);t>52;t=t/52|0)n=Q(t%52)+n;return(Q(t%52)+n).replace(K,"$1-$2")}var te=function(e,t){for(var n=t.length;n;)e=33*e^t.charCodeAt(--n);return e},ne=function(e){return te(5381,e)};function re(e){for(var t=0;t<e.length;t+=1){var n=e[t];if(b(n)&&!N(n))return!1}return!0}var oe=ne("5.3.5"),se=function(){function e(e,t,n){this.rules=e,this.staticRulesId="",this.isStatic= false&&0,this.componentId=t,this.baseHash=te(oe,t),this.baseStyle=n,Z.registerId(t)}return e.prototype.generateAndInjectStyles=function(e,t,n){var r=this.componentId,o=[];if(this.baseStyle&&o.push(this.baseStyle.generateAndInjectStyles(e,t,n)),this.isStatic&&!n.hash)if(this.staticRulesId&&t.hasNameForId(r,this.staticRulesId))o.push(this.staticRulesId);else{var s=Ne(this.rules,e,t,n).join(""),i=ee(te(this.baseHash,s)>>>0);if(!t.hasNameForId(r,i)){var a=n(s,"."+i,void 0,r);t.insertRules(r,i,a)}o.push(i),this.staticRulesId=i}else{for(var c=this.rules.length,u=te(this.baseHash,n.hash),l="",d=0;d<c;d++){var h=this.rules[d];if("string"==typeof h)l+=h, true&&(u=te(u,h+d));else if(h){var p=Ne(h,e,t,n),f=Array.isArray(p)?p.join(""):p;u=te(u,f+d),l+=f}}if(l){var m=ee(u>>>0);if(!t.hasNameForId(r,m)){var y=n(l,"."+m,void 0,r);t.insertRules(r,m,y)}o.push(m)}}return o.join(" ")},e}(),ie=/^\s*\/\/.*$/gm,ae=[":","[",".","#"];function ce(e){var t,n,r,o,s=void 0===e?E:e,i=s.options,a=void 0===i?E:i,c=s.plugins,u=void 0===c?w:c,l=new _emotion_stylis__WEBPACK_IMPORTED_MODULE_3__["default"](a),d=[],h=function(e){function t(t){if(t)try{e(t+"}")}catch(e){}}return function(n,r,o,s,i,a,c,u,l,d){switch(n){case 1:if(0===l&&64===r.charCodeAt(0))return e(r+";"),"";break;case 2:if(0===u)return r+"/*|*/";break;case 3:switch(u){case 102:case 112:return e(o[0]+r),"";default:return r+(0===d?"/*|*/":"")}case-2:r.split("/*|*/}").forEach(t)}}}((function(e){d.push(e)})),f=function(e,r,s){return 0===r&&-1!==ae.indexOf(s[n.length])||s.match(o)?e:"."+t};function m(e,s,i,a){void 0===a&&(a="&");var c=e.replace(ie,""),u=s&&i?i+" "+s+" { "+c+" }":c;return t=a,n=s,r=new RegExp("\\"+n+"\\b","g"),o=new RegExp("(\\"+n+"\\b){2,}"),l(i||!s?"":s,u)}return l.use([].concat(u,[function(e,t,o){2===e&&o.length&&o[0].lastIndexOf(n)>0&&(o[0]=o[0].replace(r,f))},h,function(e){if(-2===e){var t=d;return d=[],t}}])),m.hash=u.length?u.reduce((function(e,t){return t.name||j(15),te(e,t.name)}),5381).toString():"",m}var ue=react__WEBPACK_IMPORTED_MODULE_1___default().createContext(),le=ue.Consumer,de=react__WEBPACK_IMPORTED_MODULE_1___default().createContext(),he=(de.Consumer,new Z),pe=ce();function fe(){return (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(ue)||he}function me(){return (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(de)||pe}function ye(e){var t=(0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(e.stylisPlugins),n=t[0],s=t[1],c=fe(),u=(0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)((function(){var t=c;return e.sheet?t=e.sheet:e.target&&(t=t.reconstructWithOptions({target:e.target},!1)),e.disableCSSOMInjection&&(t=t.reconstructWithOptions({useCSSOMInjection:!1})),t}),[e.disableCSSOMInjection,e.sheet,e.target]),l=(0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)((function(){return ce({options:{prefix:!e.disableVendorPrefixes},plugins:n})}),[e.disableVendorPrefixes,n]);return (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)((function(){shallowequal__WEBPACK_IMPORTED_MODULE_2___default()(n,e.stylisPlugins)||s(e.stylisPlugins)}),[e.stylisPlugins]),react__WEBPACK_IMPORTED_MODULE_1___default().createElement(ue.Provider,{value:u},react__WEBPACK_IMPORTED_MODULE_1___default().createElement(de.Provider,{value:l}, true?react__WEBPACK_IMPORTED_MODULE_1___default().Children.only(e.children):0))}var ve=function(){function e(e,t){var n=this;this.inject=function(e,t){void 0===t&&(t=pe);var r=n.name+t.hash;e.hasNameForId(n.id,r)||e.insertRules(n.id,r,t(n.rules,r,"@keyframes"))},this.toString=function(){return j(12,String(n.name))},this.name=e,this.id="sc-keyframes-"+e,this.rules=t}return e.prototype.getName=function(e){return void 0===e&&(e=pe),this.name+e.hash},e}(),ge=/([A-Z])/,Se=/([A-Z])/g,we=/^ms-/,Ee=function(e){return"-"+e.toLowerCase()};function be(e){return ge.test(e)?e.replace(Se,Ee).replace(we,"-ms-"):e}var _e=function(e){return null==e||!1===e||""===e};function Ne(e,n,r,o){if(Array.isArray(e)){for(var s,i=[],a=0,c=e.length;a<c;a+=1)""!==(s=Ne(e[a],n,r,o))&&(Array.isArray(s)?i.push.apply(i,s):i.push(s));return i}if(_e(e))return"";if(N(e))return"."+e.styledComponentId;if(b(e)){if("function"!=typeof(l=e)||l.prototype&&l.prototype.isReactComponent||!n)return e;var u=e(n);return true&&(0,react_is__WEBPACK_IMPORTED_MODULE_0__.isElement)(u)&&console.warn(_(e)+" is not a styled component and cannot be referred to via component selector. See https://www.styled-components.com/docs/advanced#referring-to-other-components for more details."),Ne(u,n,r,o)}var l;return e instanceof ve?r?(e.inject(r,o),e.getName(o)):e:S(e)?function e(t,n){var r,o,s=[];for(var i in t)t.hasOwnProperty(i)&&!_e(t[i])&&(Array.isArray(t[i])&&t[i].isCss||b(t[i])?s.push(be(i)+":",t[i],";"):S(t[i])?s.push.apply(s,e(t[i],i)):s.push(be(i)+": "+(r=i,null==(o=t[i])||"boolean"==typeof o||""===o?"":"number"!=typeof o||0===o||r in _emotion_unitless__WEBPACK_IMPORTED_MODULE_4__["default"]?String(o).trim():o+"px")+";"));return n?[n+" {"].concat(s,["}"]):s}(e):e.toString()}var Ae=function(e){return Array.isArray(e)&&(e.isCss=!0),e};function Ce(e){for(var t=arguments.length,n=new Array(t>1?t-1:0),r=1;r<t;r++)n[r-1]=arguments[r];return b(e)||S(e)?Ae(Ne(g(w,[e].concat(n)))):0===n.length&&1===e.length&&"string"==typeof e[0]?e:Ae(Ne(g(e,n)))}var Ie=/invalid hook call/i,Pe=new Set,Oe=function(e,t){if(true){var n="The component "+e+(t?' with the id of "'+t+'"':"")+" has been created dynamically.\nYou may see this warning because you've called styled inside another component.\nTo resolve this only create new StyledComponents outside of any render method and function component.",r=console.error;try{var o=!0;console.error=function(e){if(Ie.test(e))o=!1,Pe.delete(n);else{for(var t=arguments.length,s=new Array(t>1?t-1:0),i=1;i<t;i++)s[i-1]=arguments[i];r.apply(void 0,[e].concat(s))}},(0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(),o&&!Pe.has(n)&&(console.warn(n),Pe.add(n))}catch(e){Ie.test(e.message)&&Pe.delete(n)}finally{console.error=r}}},Re=function(e,t,n){return void 0===n&&(n=E),e.theme!==n.theme&&e.theme||t||n.theme},De=/[!"#$%&'()*+,./:;<=>?@[\\\]^`{|}~-]+/g,je=/(^-|-$)/g;function Te(e){return e.replace(De,"-").replace(je,"")}var xe=function(e){return ee(ne(e)>>>0)};function ke(e){return"string"==typeof e&&( false||e.charAt(0)===e.charAt(0).toLowerCase())}var Ve=function(e){return"function"==typeof e||"object"==typeof e&&null!==e&&!Array.isArray(e)},Be=function(e){return"__proto__"!==e&&"constructor"!==e&&"prototype"!==e};function ze(e,t,n){var r=e[n];Ve(t)&&Ve(r)?Me(r,t):e[n]=t}function Me(e){for(var t=arguments.length,n=new Array(t>1?t-1:0),r=1;r<t;r++)n[r-1]=arguments[r];for(var o=0,s=n;o<s.length;o++){var i=s[o];if(Ve(i))for(var a in i)Be(a)&&ze(e,i[a],a)}return e}var Ge=react__WEBPACK_IMPORTED_MODULE_1___default().createContext(),Le=Ge.Consumer;function Fe(e){var t=(0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(Ge),n=(0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)((function(){return function(e,t){if(!e)return j(14);if(b(e)){var n=e(t);return false||null!==n&&!Array.isArray(n)&&"object"==typeof n?n:j(7)}return Array.isArray(e)||"object"!=typeof e?j(8):t?v({},t,{},e):e}(e.theme,t)}),[e.theme,t]);return e.children?react__WEBPACK_IMPORTED_MODULE_1___default().createElement(Ge.Provider,{value:n},e.children):null}var Ye={};function qe(e,t,n){var o=N(e),i=!ke(e),a=t.attrs,c=void 0===a?w:a,d=t.componentId,h=void 0===d?function(e,t){var n="string"!=typeof e?"sc":Te(e);Ye[n]=(Ye[n]||0)+1;var r=n+"-"+xe("5.3.5"+n+Ye[n]);return t?t+"-"+r:r}(t.displayName,t.parentComponentId):d,p=t.displayName,f=void 0===p?function(e){return ke(e)?"styled."+e:"Styled("+_(e)+")"}(e):p,g=t.displayName&&t.componentId?Te(t.displayName)+"-"+t.componentId:t.componentId||h,S=o&&e.attrs?Array.prototype.concat(e.attrs,c).filter(Boolean):c,A=t.shouldForwardProp;o&&e.shouldForwardProp&&(A=t.shouldForwardProp?function(n,r,o){return e.shouldForwardProp(n,r,o)&&t.shouldForwardProp(n,r,o)}:e.shouldForwardProp);var C,I=new se(n,g,o?e.componentStyle:void 0),P=I.isStatic&&0===c.length,O=function(e,t){return function(e,t,n,r){var o=e.attrs,i=e.componentStyle,a=e.defaultProps,c=e.foldedComponentIds,d=e.shouldForwardProp,h=e.styledComponentId,p=e.target; true&&(0,react__WEBPACK_IMPORTED_MODULE_1__.useDebugValue)(h);var f=function(e,t,n){void 0===e&&(e=E);var r=v({},t,{theme:e}),o={};return n.forEach((function(e){var t,n,s,i=e;for(t in b(i)&&(i=i(r)),i)r[t]=o[t]="className"===t?(n=o[t],s=i[t],n&&s?n+" "+s:n||s):i[t]})),[r,o]}(Re(t,(0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(Ge),a)||E,t,o),y=f[0],g=f[1],S=function(e,t,n,r){var o=fe(),s=me(),i=t?e.generateAndInjectStyles(E,o,s):e.generateAndInjectStyles(n,o,s);return true&&(0,react__WEBPACK_IMPORTED_MODULE_1__.useDebugValue)(i), true&&!t&&r&&r(i),i}(i,r,y, true?e.warnTooManyClasses:0),w=n,_=g.$as||t.$as||g.as||t.as||p,N=ke(_),A=g!==t?v({},t,{},g):t,C={};for(var I in A)"$"!==I[0]&&"as"!==I&&("forwardedAs"===I?C.as=A[I]:(d?d(I,_emotion_is_prop_valid__WEBPACK_IMPORTED_MODULE_5__["default"],_):!N||(0,_emotion_is_prop_valid__WEBPACK_IMPORTED_MODULE_5__["default"])(I))&&(C[I]=A[I]));return t.style&&g.style!==t.style&&(C.style=v({},t.style,{},g.style)),C.className=Array.prototype.concat(c,h,S!==h?S:null,t.className,g.className).filter(Boolean).join(" "),C.ref=w,(0,react__WEBPACK_IMPORTED_MODULE_1__.createElement)(_,C)}(C,e,t,P)};return O.displayName=f,(C=react__WEBPACK_IMPORTED_MODULE_1___default().forwardRef(O)).attrs=S,C.componentStyle=I,C.displayName=f,C.shouldForwardProp=A,C.foldedComponentIds=o?Array.prototype.concat(e.foldedComponentIds,e.styledComponentId):w,C.styledComponentId=g,C.target=o?e.target:e,C.withComponent=function(e){var r=t.componentId,o=function(e,t){if(null==e)return{};var n,r,o={},s=Object.keys(e);for(r=0;r<s.length;r++)n=s[r],t.indexOf(n)>=0||(o[n]=e[n]);return o}(t,["componentId"]),s=r&&r+"-"+(ke(e)?e:Te(_(e)));return qe(e,v({},o,{attrs:S,componentId:s}),n)},Object.defineProperty(C,"defaultProps",{get:function(){return this._foldedDefaultProps},set:function(t){this._foldedDefaultProps=o?Me({},e.defaultProps,t):t}}), true&&(Oe(f,g),C.warnTooManyClasses=function(e,t){var n={},r=!1;return function(o){if(!r&&(n[o]=!0,Object.keys(n).length>=200)){var s=t?' with the id of "'+t+'"':"";console.warn("Over 200 classes were generated for component "+e+s+".\nConsider using the attrs method, together with a style object for frequently changed styles.\nExample:\n  const Component = styled.div.attrs(props => ({\n    style: {\n      background: props.background,\n    },\n  }))`width: 100%;`\n\n  <Component />"),r=!0,n={}}}}(f,g)),C.toString=function(){return"."+C.styledComponentId},i&&hoist_non_react_statics__WEBPACK_IMPORTED_MODULE_6___default()(C,e,{attrs:!0,componentStyle:!0,displayName:!0,foldedComponentIds:!0,shouldForwardProp:!0,styledComponentId:!0,target:!0,withComponent:!0}),C}var He=function(e){return function e(t,r,o){if(void 0===o&&(o=E),!(0,react_is__WEBPACK_IMPORTED_MODULE_0__.isValidElementType)(r))return j(1,String(r));var s=function(){return t(r,o,Ce.apply(void 0,arguments))};return s.withConfig=function(n){return e(t,r,v({},o,{},n))},s.attrs=function(n){return e(t,r,v({},o,{attrs:Array.prototype.concat(o.attrs,n).filter(Boolean)}))},s}(qe,e)};["a","abbr","address","area","article","aside","audio","b","base","bdi","bdo","big","blockquote","body","br","button","canvas","caption","cite","code","col","colgroup","data","datalist","dd","del","details","dfn","dialog","div","dl","dt","em","embed","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","head","header","hgroup","hr","html","i","iframe","img","input","ins","kbd","keygen","label","legend","li","link","main","map","mark","marquee","menu","menuitem","meta","meter","nav","noscript","object","ol","optgroup","option","output","p","param","picture","pre","progress","q","rp","rt","ruby","s","samp","script","section","select","small","source","span","strong","style","sub","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","title","tr","track","u","ul","var","video","wbr","circle","clipPath","defs","ellipse","foreignObject","g","image","line","linearGradient","marker","mask","path","pattern","polygon","polyline","radialGradient","rect","stop","svg","text","textPath","tspan"].forEach((function(e){He[e]=He(e)}));var $e=function(){function e(e,t){this.rules=e,this.componentId=t,this.isStatic=re(e),Z.registerId(this.componentId+1)}var t=e.prototype;return t.createStyles=function(e,t,n,r){var o=r(Ne(this.rules,t,n,r).join(""),""),s=this.componentId+e;n.insertRules(s,s,o)},t.removeStyles=function(e,t){t.clearRules(this.componentId+e)},t.renderStyles=function(e,t,n,r){e>2&&Z.registerId(this.componentId+e),this.removeStyles(e,n),this.createStyles(e,t,n,r)},e}();function We(e){for(var t=arguments.length,n=new Array(t>1?t-1:0),o=1;o<t;o++)n[o-1]=arguments[o];var i=Ce.apply(void 0,[e].concat(n)),a="sc-global-"+xe(JSON.stringify(i)),u=new $e(i,a);function l(e){var t=fe(),n=me(),o=(0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(Ge),l=(0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(t.allocateGSInstance(a)).current;return true&&react__WEBPACK_IMPORTED_MODULE_1___default().Children.count(e.children)&&console.warn("The global style component "+a+" was given child JSX. createGlobalStyle does not render children."), true&&i.some((function(e){return"string"==typeof e&&-1!==e.indexOf("@import")}))&&console.warn("Please do not use @import CSS syntax in createGlobalStyle at this time, as the CSSOM APIs we use in production do not handle it well. Instead, we recommend using a library such as react-helmet to inject a typical <link> meta tag to the stylesheet, or simply embedding it manually in your index.html <head> section for a simpler app."),t.server&&h(l,e,t,o,n),(0,react__WEBPACK_IMPORTED_MODULE_1__.useLayoutEffect)((function(){if(!t.server)return h(l,e,t,o,n),function(){return u.removeStyles(l,t)}}),[l,e,t,o,n]),null}function h(e,t,n,r,o){if(u.isStatic)u.renderStyles(e,O,n,o);else{var s=v({},t,{theme:Re(t,r,l.defaultProps)});u.renderStyles(e,s,n,o)}}return true&&Oe(a),react__WEBPACK_IMPORTED_MODULE_1___default().memo(l)}function Ue(e){ true&&"undefined"!=typeof navigator&&"ReactNative"===navigator.product&&console.warn("`keyframes` cannot be used on ReactNative, only on the web. To do animation in ReactNative please use Animated.");for(var t=arguments.length,n=new Array(t>1?t-1:0),r=1;r<t;r++)n[r-1]=arguments[r];var o=Ce.apply(void 0,[e].concat(n)).join(""),s=xe(o);return new ve(s,o)}var Je=function(){function e(){var e=this;this._emitSheetCSS=function(){var t=e.instance.toString();if(!t)return"";var n=q();return"<style "+[n&&'nonce="'+n+'"',A+'="true"','data-styled-version="5.3.5"'].filter(Boolean).join(" ")+">"+t+"</style>"},this.getStyleTags=function(){return e.sealed?j(2):e._emitSheetCSS()},this.getStyleElement=function(){var t;if(e.sealed)return j(2);var n=((t={})[A]="",t["data-styled-version"]="5.3.5",t.dangerouslySetInnerHTML={__html:e.instance.toString()},t),o=q();return o&&(n.nonce=o),[react__WEBPACK_IMPORTED_MODULE_1___default().createElement("style",v({},n,{key:"sc-0-0"}))]},this.seal=function(){e.sealed=!0},this.instance=new Z({isServer:!0}),this.sealed=!1}var t=e.prototype;return t.collectStyles=function(e){return this.sealed?j(2):react__WEBPACK_IMPORTED_MODULE_1___default().createElement(ye,{sheet:this.instance},e)},t.interleaveWithNodeStream=function(e){return j(3)},e}(),Xe=function(e){var t=react__WEBPACK_IMPORTED_MODULE_1___default().forwardRef((function(t,n){var o=(0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(Ge),i=e.defaultProps,a=Re(t,o,i);return true&&void 0===a&&console.warn('[withTheme] You are not using a ThemeProvider nor passing a theme prop or a theme in defaultProps in component class "'+_(e)+'"'),react__WEBPACK_IMPORTED_MODULE_1___default().createElement(e,v({},t,{theme:a,ref:n}))}));return hoist_non_react_statics__WEBPACK_IMPORTED_MODULE_6___default()(t,e),t.displayName="WithTheme("+_(e)+")",t},Ze=function(){return (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(Ge)},Ke={StyleSheet:Z,masterSheet:he}; true&&"undefined"!=typeof navigator&&"ReactNative"===navigator.product&&console.warn("It looks like you've imported 'styled-components' on React Native.\nPerhaps you're looking to import 'styled-components/native'?\nRead more about this at https://www.styled-components.com/docs/basics#react-native"), true&&"undefined"!=typeof window&&(window["__styled-components-init__"]=window["__styled-components-init__"]||0,1===window["__styled-components-init__"]&&console.warn("It looks like there are several instances of 'styled-components' initialized in this application. This may cause dynamic styles to not render properly, errors during the rehydration process, a missing theme prop, and makes your application bigger without good reason.\n\nSee https://s-c.sh/2BAXzed for more info."),window["__styled-components-init__"]+=1);/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (He);
//# sourceMappingURL=styled-components.browser.esm.js.map


/***/ }),

/***/ "../../node_modules/tslib/tslib.es6.js":
/*!*********************************************!*\
  !*** ../../node_modules/tslib/tslib.es6.js ***!
  \*********************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "__assign": () => (/* binding */ __assign),
/* harmony export */   "__asyncDelegator": () => (/* binding */ __asyncDelegator),
/* harmony export */   "__asyncGenerator": () => (/* binding */ __asyncGenerator),
/* harmony export */   "__asyncValues": () => (/* binding */ __asyncValues),
/* harmony export */   "__await": () => (/* binding */ __await),
/* harmony export */   "__awaiter": () => (/* binding */ __awaiter),
/* harmony export */   "__classPrivateFieldGet": () => (/* binding */ __classPrivateFieldGet),
/* harmony export */   "__classPrivateFieldIn": () => (/* binding */ __classPrivateFieldIn),
/* harmony export */   "__classPrivateFieldSet": () => (/* binding */ __classPrivateFieldSet),
/* harmony export */   "__createBinding": () => (/* binding */ __createBinding),
/* harmony export */   "__decorate": () => (/* binding */ __decorate),
/* harmony export */   "__exportStar": () => (/* binding */ __exportStar),
/* harmony export */   "__extends": () => (/* binding */ __extends),
/* harmony export */   "__generator": () => (/* binding */ __generator),
/* harmony export */   "__importDefault": () => (/* binding */ __importDefault),
/* harmony export */   "__importStar": () => (/* binding */ __importStar),
/* harmony export */   "__makeTemplateObject": () => (/* binding */ __makeTemplateObject),
/* harmony export */   "__metadata": () => (/* binding */ __metadata),
/* harmony export */   "__param": () => (/* binding */ __param),
/* harmony export */   "__read": () => (/* binding */ __read),
/* harmony export */   "__rest": () => (/* binding */ __rest),
/* harmony export */   "__spread": () => (/* binding */ __spread),
/* harmony export */   "__spreadArray": () => (/* binding */ __spreadArray),
/* harmony export */   "__spreadArrays": () => (/* binding */ __spreadArrays),
/* harmony export */   "__values": () => (/* binding */ __values)
/* harmony export */ });
/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise */

var extendStatics = function(d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
    return extendStatics(d, b);
};

function __extends(d, b) {
    if (typeof b !== "function" && b !== null)
        throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    }
    return __assign.apply(this, arguments);
}

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

function __decorate(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}

function __param(paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
}

function __metadata(metadataKey, metadataValue) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(metadataKey, metadataValue);
}

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

var __createBinding = Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
});

function __exportStar(m, o) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(o, p)) __createBinding(o, m, p);
}

function __values(o) {
    var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
    if (m) return m.call(o);
    if (o && typeof o.length === "number") return {
        next: function () {
            if (o && i >= o.length) o = void 0;
            return { value: o && o[i++], done: !o };
        }
    };
    throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
}

function __read(o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
}

/** @deprecated */
function __spread() {
    for (var ar = [], i = 0; i < arguments.length; i++)
        ar = ar.concat(__read(arguments[i]));
    return ar;
}

/** @deprecated */
function __spreadArrays() {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
}

function __spreadArray(to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
}

function __await(v) {
    return this instanceof __await ? (this.v = v, this) : new __await(v);
}

function __asyncGenerator(thisArg, _arguments, generator) {
    if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
    var g = generator.apply(thisArg, _arguments || []), i, q = [];
    return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
    function verb(n) { if (g[n]) i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
    function resume(n, v) { try { step(g[n](v)); } catch (e) { settle(q[0][3], e); } }
    function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
    function fulfill(value) { resume("next", value); }
    function reject(value) { resume("throw", value); }
    function settle(f, v) { if (f(v), q.shift(), q.length) resume(q[0][0], q[0][1]); }
}

function __asyncDelegator(o) {
    var i, p;
    return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
    function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: n === "return" } : f ? f(v) : v; } : f; }
}

function __asyncValues(o) {
    if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
    var m = o[Symbol.asyncIterator], i;
    return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
    function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
    function settle(resolve, reject, d, v) { Promise.resolve(v).then(function(v) { resolve({ value: v, done: d }); }, reject); }
}

function __makeTemplateObject(cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};

var __setModuleDefault = Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
};

function __importStar(mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
}

function __importDefault(mod) {
    return (mod && mod.__esModule) ? mod : { default: mod };
}

function __classPrivateFieldGet(receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
}

function __classPrivateFieldSet(receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
}

function __classPrivateFieldIn(state, receiver) {
    if (receiver === null || (typeof receiver !== "object" && typeof receiver !== "function")) throw new TypeError("Cannot use 'in' operator on non-object");
    return typeof state === "function" ? receiver === state : state.has(receiver);
}


/***/ }),

/***/ "../../node_modules/url/node_modules/punycode/punycode.js":
/*!****************************************************************!*\
  !*** ../../node_modules/url/node_modules/punycode/punycode.js ***!
  \****************************************************************/
/***/ (function(module, exports, __webpack_require__) {

/* module decorator */ module = __webpack_require__.nmd(module);
var __WEBPACK_AMD_DEFINE_RESULT__;/*! https://mths.be/punycode v1.3.2 by @mathias */
;(function(root) {

	/** Detect free variables */
	var freeExports =  true && exports &&
		!exports.nodeType && exports;
	var freeModule =  true && module &&
		!module.nodeType && module;
	var freeGlobal = typeof __webpack_require__.g == 'object' && __webpack_require__.g;
	if (
		freeGlobal.global === freeGlobal ||
		freeGlobal.window === freeGlobal ||
		freeGlobal.self === freeGlobal
	) {
		root = freeGlobal;
	}

	/**
	 * The `punycode` object.
	 * @name punycode
	 * @type Object
	 */
	var punycode,

	/** Highest positive signed 32-bit float value */
	maxInt = 2147483647, // aka. 0x7FFFFFFF or 2^31-1

	/** Bootstring parameters */
	base = 36,
	tMin = 1,
	tMax = 26,
	skew = 38,
	damp = 700,
	initialBias = 72,
	initialN = 128, // 0x80
	delimiter = '-', // '\x2D'

	/** Regular expressions */
	regexPunycode = /^xn--/,
	regexNonASCII = /[^\x20-\x7E]/, // unprintable ASCII chars + non-ASCII chars
	regexSeparators = /[\x2E\u3002\uFF0E\uFF61]/g, // RFC 3490 separators

	/** Error messages */
	errors = {
		'overflow': 'Overflow: input needs wider integers to process',
		'not-basic': 'Illegal input >= 0x80 (not a basic code point)',
		'invalid-input': 'Invalid input'
	},

	/** Convenience shortcuts */
	baseMinusTMin = base - tMin,
	floor = Math.floor,
	stringFromCharCode = String.fromCharCode,

	/** Temporary variable */
	key;

	/*--------------------------------------------------------------------------*/

	/**
	 * A generic error utility function.
	 * @private
	 * @param {String} type The error type.
	 * @returns {Error} Throws a `RangeError` with the applicable error message.
	 */
	function error(type) {
		throw RangeError(errors[type]);
	}

	/**
	 * A generic `Array#map` utility function.
	 * @private
	 * @param {Array} array The array to iterate over.
	 * @param {Function} callback The function that gets called for every array
	 * item.
	 * @returns {Array} A new array of values returned by the callback function.
	 */
	function map(array, fn) {
		var length = array.length;
		var result = [];
		while (length--) {
			result[length] = fn(array[length]);
		}
		return result;
	}

	/**
	 * A simple `Array#map`-like wrapper to work with domain name strings or email
	 * addresses.
	 * @private
	 * @param {String} domain The domain name or email address.
	 * @param {Function} callback The function that gets called for every
	 * character.
	 * @returns {Array} A new string of characters returned by the callback
	 * function.
	 */
	function mapDomain(string, fn) {
		var parts = string.split('@');
		var result = '';
		if (parts.length > 1) {
			// In email addresses, only the domain name should be punycoded. Leave
			// the local part (i.e. everything up to `@`) intact.
			result = parts[0] + '@';
			string = parts[1];
		}
		// Avoid `split(regex)` for IE8 compatibility. See #17.
		string = string.replace(regexSeparators, '\x2E');
		var labels = string.split('.');
		var encoded = map(labels, fn).join('.');
		return result + encoded;
	}

	/**
	 * Creates an array containing the numeric code points of each Unicode
	 * character in the string. While JavaScript uses UCS-2 internally,
	 * this function will convert a pair of surrogate halves (each of which
	 * UCS-2 exposes as separate characters) into a single code point,
	 * matching UTF-16.
	 * @see `punycode.ucs2.encode`
	 * @see <https://mathiasbynens.be/notes/javascript-encoding>
	 * @memberOf punycode.ucs2
	 * @name decode
	 * @param {String} string The Unicode input string (UCS-2).
	 * @returns {Array} The new array of code points.
	 */
	function ucs2decode(string) {
		var output = [],
		    counter = 0,
		    length = string.length,
		    value,
		    extra;
		while (counter < length) {
			value = string.charCodeAt(counter++);
			if (value >= 0xD800 && value <= 0xDBFF && counter < length) {
				// high surrogate, and there is a next character
				extra = string.charCodeAt(counter++);
				if ((extra & 0xFC00) == 0xDC00) { // low surrogate
					output.push(((value & 0x3FF) << 10) + (extra & 0x3FF) + 0x10000);
				} else {
					// unmatched surrogate; only append this code unit, in case the next
					// code unit is the high surrogate of a surrogate pair
					output.push(value);
					counter--;
				}
			} else {
				output.push(value);
			}
		}
		return output;
	}

	/**
	 * Creates a string based on an array of numeric code points.
	 * @see `punycode.ucs2.decode`
	 * @memberOf punycode.ucs2
	 * @name encode
	 * @param {Array} codePoints The array of numeric code points.
	 * @returns {String} The new Unicode string (UCS-2).
	 */
	function ucs2encode(array) {
		return map(array, function(value) {
			var output = '';
			if (value > 0xFFFF) {
				value -= 0x10000;
				output += stringFromCharCode(value >>> 10 & 0x3FF | 0xD800);
				value = 0xDC00 | value & 0x3FF;
			}
			output += stringFromCharCode(value);
			return output;
		}).join('');
	}

	/**
	 * Converts a basic code point into a digit/integer.
	 * @see `digitToBasic()`
	 * @private
	 * @param {Number} codePoint The basic numeric code point value.
	 * @returns {Number} The numeric value of a basic code point (for use in
	 * representing integers) in the range `0` to `base - 1`, or `base` if
	 * the code point does not represent a value.
	 */
	function basicToDigit(codePoint) {
		if (codePoint - 48 < 10) {
			return codePoint - 22;
		}
		if (codePoint - 65 < 26) {
			return codePoint - 65;
		}
		if (codePoint - 97 < 26) {
			return codePoint - 97;
		}
		return base;
	}

	/**
	 * Converts a digit/integer into a basic code point.
	 * @see `basicToDigit()`
	 * @private
	 * @param {Number} digit The numeric value of a basic code point.
	 * @returns {Number} The basic code point whose value (when used for
	 * representing integers) is `digit`, which needs to be in the range
	 * `0` to `base - 1`. If `flag` is non-zero, the uppercase form is
	 * used; else, the lowercase form is used. The behavior is undefined
	 * if `flag` is non-zero and `digit` has no uppercase form.
	 */
	function digitToBasic(digit, flag) {
		//  0..25 map to ASCII a..z or A..Z
		// 26..35 map to ASCII 0..9
		return digit + 22 + 75 * (digit < 26) - ((flag != 0) << 5);
	}

	/**
	 * Bias adaptation function as per section 3.4 of RFC 3492.
	 * http://tools.ietf.org/html/rfc3492#section-3.4
	 * @private
	 */
	function adapt(delta, numPoints, firstTime) {
		var k = 0;
		delta = firstTime ? floor(delta / damp) : delta >> 1;
		delta += floor(delta / numPoints);
		for (/* no initialization */; delta > baseMinusTMin * tMax >> 1; k += base) {
			delta = floor(delta / baseMinusTMin);
		}
		return floor(k + (baseMinusTMin + 1) * delta / (delta + skew));
	}

	/**
	 * Converts a Punycode string of ASCII-only symbols to a string of Unicode
	 * symbols.
	 * @memberOf punycode
	 * @param {String} input The Punycode string of ASCII-only symbols.
	 * @returns {String} The resulting string of Unicode symbols.
	 */
	function decode(input) {
		// Don't use UCS-2
		var output = [],
		    inputLength = input.length,
		    out,
		    i = 0,
		    n = initialN,
		    bias = initialBias,
		    basic,
		    j,
		    index,
		    oldi,
		    w,
		    k,
		    digit,
		    t,
		    /** Cached calculation results */
		    baseMinusT;

		// Handle the basic code points: let `basic` be the number of input code
		// points before the last delimiter, or `0` if there is none, then copy
		// the first basic code points to the output.

		basic = input.lastIndexOf(delimiter);
		if (basic < 0) {
			basic = 0;
		}

		for (j = 0; j < basic; ++j) {
			// if it's not a basic code point
			if (input.charCodeAt(j) >= 0x80) {
				error('not-basic');
			}
			output.push(input.charCodeAt(j));
		}

		// Main decoding loop: start just after the last delimiter if any basic code
		// points were copied; start at the beginning otherwise.

		for (index = basic > 0 ? basic + 1 : 0; index < inputLength; /* no final expression */) {

			// `index` is the index of the next character to be consumed.
			// Decode a generalized variable-length integer into `delta`,
			// which gets added to `i`. The overflow checking is easier
			// if we increase `i` as we go, then subtract off its starting
			// value at the end to obtain `delta`.
			for (oldi = i, w = 1, k = base; /* no condition */; k += base) {

				if (index >= inputLength) {
					error('invalid-input');
				}

				digit = basicToDigit(input.charCodeAt(index++));

				if (digit >= base || digit > floor((maxInt - i) / w)) {
					error('overflow');
				}

				i += digit * w;
				t = k <= bias ? tMin : (k >= bias + tMax ? tMax : k - bias);

				if (digit < t) {
					break;
				}

				baseMinusT = base - t;
				if (w > floor(maxInt / baseMinusT)) {
					error('overflow');
				}

				w *= baseMinusT;

			}

			out = output.length + 1;
			bias = adapt(i - oldi, out, oldi == 0);

			// `i` was supposed to wrap around from `out` to `0`,
			// incrementing `n` each time, so we'll fix that now:
			if (floor(i / out) > maxInt - n) {
				error('overflow');
			}

			n += floor(i / out);
			i %= out;

			// Insert `n` at position `i` of the output
			output.splice(i++, 0, n);

		}

		return ucs2encode(output);
	}

	/**
	 * Converts a string of Unicode symbols (e.g. a domain name label) to a
	 * Punycode string of ASCII-only symbols.
	 * @memberOf punycode
	 * @param {String} input The string of Unicode symbols.
	 * @returns {String} The resulting Punycode string of ASCII-only symbols.
	 */
	function encode(input) {
		var n,
		    delta,
		    handledCPCount,
		    basicLength,
		    bias,
		    j,
		    m,
		    q,
		    k,
		    t,
		    currentValue,
		    output = [],
		    /** `inputLength` will hold the number of code points in `input`. */
		    inputLength,
		    /** Cached calculation results */
		    handledCPCountPlusOne,
		    baseMinusT,
		    qMinusT;

		// Convert the input in UCS-2 to Unicode
		input = ucs2decode(input);

		// Cache the length
		inputLength = input.length;

		// Initialize the state
		n = initialN;
		delta = 0;
		bias = initialBias;

		// Handle the basic code points
		for (j = 0; j < inputLength; ++j) {
			currentValue = input[j];
			if (currentValue < 0x80) {
				output.push(stringFromCharCode(currentValue));
			}
		}

		handledCPCount = basicLength = output.length;

		// `handledCPCount` is the number of code points that have been handled;
		// `basicLength` is the number of basic code points.

		// Finish the basic string - if it is not empty - with a delimiter
		if (basicLength) {
			output.push(delimiter);
		}

		// Main encoding loop:
		while (handledCPCount < inputLength) {

			// All non-basic code points < n have been handled already. Find the next
			// larger one:
			for (m = maxInt, j = 0; j < inputLength; ++j) {
				currentValue = input[j];
				if (currentValue >= n && currentValue < m) {
					m = currentValue;
				}
			}

			// Increase `delta` enough to advance the decoder's <n,i> state to <m,0>,
			// but guard against overflow
			handledCPCountPlusOne = handledCPCount + 1;
			if (m - n > floor((maxInt - delta) / handledCPCountPlusOne)) {
				error('overflow');
			}

			delta += (m - n) * handledCPCountPlusOne;
			n = m;

			for (j = 0; j < inputLength; ++j) {
				currentValue = input[j];

				if (currentValue < n && ++delta > maxInt) {
					error('overflow');
				}

				if (currentValue == n) {
					// Represent delta as a generalized variable-length integer
					for (q = delta, k = base; /* no condition */; k += base) {
						t = k <= bias ? tMin : (k >= bias + tMax ? tMax : k - bias);
						if (q < t) {
							break;
						}
						qMinusT = q - t;
						baseMinusT = base - t;
						output.push(
							stringFromCharCode(digitToBasic(t + qMinusT % baseMinusT, 0))
						);
						q = floor(qMinusT / baseMinusT);
					}

					output.push(stringFromCharCode(digitToBasic(q, 0)));
					bias = adapt(delta, handledCPCountPlusOne, handledCPCount == basicLength);
					delta = 0;
					++handledCPCount;
				}
			}

			++delta;
			++n;

		}
		return output.join('');
	}

	/**
	 * Converts a Punycode string representing a domain name or an email address
	 * to Unicode. Only the Punycoded parts of the input will be converted, i.e.
	 * it doesn't matter if you call it on a string that has already been
	 * converted to Unicode.
	 * @memberOf punycode
	 * @param {String} input The Punycoded domain name or email address to
	 * convert to Unicode.
	 * @returns {String} The Unicode representation of the given Punycode
	 * string.
	 */
	function toUnicode(input) {
		return mapDomain(input, function(string) {
			return regexPunycode.test(string)
				? decode(string.slice(4).toLowerCase())
				: string;
		});
	}

	/**
	 * Converts a Unicode string representing a domain name or an email address to
	 * Punycode. Only the non-ASCII parts of the domain name will be converted,
	 * i.e. it doesn't matter if you call it with a domain that's already in
	 * ASCII.
	 * @memberOf punycode
	 * @param {String} input The domain name or email address to convert, as a
	 * Unicode string.
	 * @returns {String} The Punycode representation of the given domain name or
	 * email address.
	 */
	function toASCII(input) {
		return mapDomain(input, function(string) {
			return regexNonASCII.test(string)
				? 'xn--' + encode(string)
				: string;
		});
	}

	/*--------------------------------------------------------------------------*/

	/** Define the public API */
	punycode = {
		/**
		 * A string representing the current Punycode.js version number.
		 * @memberOf punycode
		 * @type String
		 */
		'version': '1.3.2',
		/**
		 * An object of methods to convert from JavaScript's internal character
		 * representation (UCS-2) to Unicode code points, and back.
		 * @see <https://mathiasbynens.be/notes/javascript-encoding>
		 * @memberOf punycode
		 * @type Object
		 */
		'ucs2': {
			'decode': ucs2decode,
			'encode': ucs2encode
		},
		'decode': decode,
		'encode': encode,
		'toASCII': toASCII,
		'toUnicode': toUnicode
	};

	/** Expose `punycode` */
	// Some AMD build optimizers, like r.js, check for specific condition patterns
	// like the following:
	if (
		true
	) {
		!(__WEBPACK_AMD_DEFINE_RESULT__ = (function() {
			return punycode;
		}).call(exports, __webpack_require__, exports, module),
		__WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	} else {}

}(this));


/***/ }),

/***/ "../../node_modules/url/url.js":
/*!*************************************!*\
  !*** ../../node_modules/url/url.js ***!
  \*************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.



var punycode = __webpack_require__(/*! punycode */ "../../node_modules/url/node_modules/punycode/punycode.js");
var util = __webpack_require__(/*! ./util */ "../../node_modules/url/util.js");

exports.parse = urlParse;
exports.resolve = urlResolve;
exports.resolveObject = urlResolveObject;
exports.format = urlFormat;

exports.Url = Url;

function Url() {
  this.protocol = null;
  this.slashes = null;
  this.auth = null;
  this.host = null;
  this.port = null;
  this.hostname = null;
  this.hash = null;
  this.search = null;
  this.query = null;
  this.pathname = null;
  this.path = null;
  this.href = null;
}

// Reference: RFC 3986, RFC 1808, RFC 2396

// define these here so at least they only have to be
// compiled once on the first module load.
var protocolPattern = /^([a-z0-9.+-]+:)/i,
    portPattern = /:[0-9]*$/,

    // Special case for a simple path URL
    simplePathPattern = /^(\/\/?(?!\/)[^\?\s]*)(\?[^\s]*)?$/,

    // RFC 2396: characters reserved for delimiting URLs.
    // We actually just auto-escape these.
    delims = ['<', '>', '"', '`', ' ', '\r', '\n', '\t'],

    // RFC 2396: characters not allowed for various reasons.
    unwise = ['{', '}', '|', '\\', '^', '`'].concat(delims),

    // Allowed by RFCs, but cause of XSS attacks.  Always escape these.
    autoEscape = ['\''].concat(unwise),
    // Characters that are never ever allowed in a hostname.
    // Note that any invalid chars are also handled, but these
    // are the ones that are *expected* to be seen, so we fast-path
    // them.
    nonHostChars = ['%', '/', '?', ';', '#'].concat(autoEscape),
    hostEndingChars = ['/', '?', '#'],
    hostnameMaxLen = 255,
    hostnamePartPattern = /^[+a-z0-9A-Z_-]{0,63}$/,
    hostnamePartStart = /^([+a-z0-9A-Z_-]{0,63})(.*)$/,
    // protocols that can allow "unsafe" and "unwise" chars.
    unsafeProtocol = {
      'javascript': true,
      'javascript:': true
    },
    // protocols that never have a hostname.
    hostlessProtocol = {
      'javascript': true,
      'javascript:': true
    },
    // protocols that always contain a // bit.
    slashedProtocol = {
      'http': true,
      'https': true,
      'ftp': true,
      'gopher': true,
      'file': true,
      'http:': true,
      'https:': true,
      'ftp:': true,
      'gopher:': true,
      'file:': true
    },
    querystring = __webpack_require__(/*! querystring */ "../../node_modules/querystring/index.js");

function urlParse(url, parseQueryString, slashesDenoteHost) {
  if (url && util.isObject(url) && url instanceof Url) return url;

  var u = new Url;
  u.parse(url, parseQueryString, slashesDenoteHost);
  return u;
}

Url.prototype.parse = function(url, parseQueryString, slashesDenoteHost) {
  if (!util.isString(url)) {
    throw new TypeError("Parameter 'url' must be a string, not " + typeof url);
  }

  // Copy chrome, IE, opera backslash-handling behavior.
  // Back slashes before the query string get converted to forward slashes
  // See: https://code.google.com/p/chromium/issues/detail?id=25916
  var queryIndex = url.indexOf('?'),
      splitter =
          (queryIndex !== -1 && queryIndex < url.indexOf('#')) ? '?' : '#',
      uSplit = url.split(splitter),
      slashRegex = /\\/g;
  uSplit[0] = uSplit[0].replace(slashRegex, '/');
  url = uSplit.join(splitter);

  var rest = url;

  // trim before proceeding.
  // This is to support parse stuff like "  http://foo.com  \n"
  rest = rest.trim();

  if (!slashesDenoteHost && url.split('#').length === 1) {
    // Try fast path regexp
    var simplePath = simplePathPattern.exec(rest);
    if (simplePath) {
      this.path = rest;
      this.href = rest;
      this.pathname = simplePath[1];
      if (simplePath[2]) {
        this.search = simplePath[2];
        if (parseQueryString) {
          this.query = querystring.parse(this.search.substr(1));
        } else {
          this.query = this.search.substr(1);
        }
      } else if (parseQueryString) {
        this.search = '';
        this.query = {};
      }
      return this;
    }
  }

  var proto = protocolPattern.exec(rest);
  if (proto) {
    proto = proto[0];
    var lowerProto = proto.toLowerCase();
    this.protocol = lowerProto;
    rest = rest.substr(proto.length);
  }

  // figure out if it's got a host
  // user@server is *always* interpreted as a hostname, and url
  // resolution will treat //foo/bar as host=foo,path=bar because that's
  // how the browser resolves relative URLs.
  if (slashesDenoteHost || proto || rest.match(/^\/\/[^@\/]+@[^@\/]+/)) {
    var slashes = rest.substr(0, 2) === '//';
    if (slashes && !(proto && hostlessProtocol[proto])) {
      rest = rest.substr(2);
      this.slashes = true;
    }
  }

  if (!hostlessProtocol[proto] &&
      (slashes || (proto && !slashedProtocol[proto]))) {

    // there's a hostname.
    // the first instance of /, ?, ;, or # ends the host.
    //
    // If there is an @ in the hostname, then non-host chars *are* allowed
    // to the left of the last @ sign, unless some host-ending character
    // comes *before* the @-sign.
    // URLs are obnoxious.
    //
    // ex:
    // http://a@b@c/ => user:a@b host:c
    // http://a@b?@c => user:a host:c path:/?@c

    // v0.12 TODO(isaacs): This is not quite how Chrome does things.
    // Review our test case against browsers more comprehensively.

    // find the first instance of any hostEndingChars
    var hostEnd = -1;
    for (var i = 0; i < hostEndingChars.length; i++) {
      var hec = rest.indexOf(hostEndingChars[i]);
      if (hec !== -1 && (hostEnd === -1 || hec < hostEnd))
        hostEnd = hec;
    }

    // at this point, either we have an explicit point where the
    // auth portion cannot go past, or the last @ char is the decider.
    var auth, atSign;
    if (hostEnd === -1) {
      // atSign can be anywhere.
      atSign = rest.lastIndexOf('@');
    } else {
      // atSign must be in auth portion.
      // http://a@b/c@d => host:b auth:a path:/c@d
      atSign = rest.lastIndexOf('@', hostEnd);
    }

    // Now we have a portion which is definitely the auth.
    // Pull that off.
    if (atSign !== -1) {
      auth = rest.slice(0, atSign);
      rest = rest.slice(atSign + 1);
      this.auth = decodeURIComponent(auth);
    }

    // the host is the remaining to the left of the first non-host char
    hostEnd = -1;
    for (var i = 0; i < nonHostChars.length; i++) {
      var hec = rest.indexOf(nonHostChars[i]);
      if (hec !== -1 && (hostEnd === -1 || hec < hostEnd))
        hostEnd = hec;
    }
    // if we still have not hit it, then the entire thing is a host.
    if (hostEnd === -1)
      hostEnd = rest.length;

    this.host = rest.slice(0, hostEnd);
    rest = rest.slice(hostEnd);

    // pull out port.
    this.parseHost();

    // we've indicated that there is a hostname,
    // so even if it's empty, it has to be present.
    this.hostname = this.hostname || '';

    // if hostname begins with [ and ends with ]
    // assume that it's an IPv6 address.
    var ipv6Hostname = this.hostname[0] === '[' &&
        this.hostname[this.hostname.length - 1] === ']';

    // validate a little.
    if (!ipv6Hostname) {
      var hostparts = this.hostname.split(/\./);
      for (var i = 0, l = hostparts.length; i < l; i++) {
        var part = hostparts[i];
        if (!part) continue;
        if (!part.match(hostnamePartPattern)) {
          var newpart = '';
          for (var j = 0, k = part.length; j < k; j++) {
            if (part.charCodeAt(j) > 127) {
              // we replace non-ASCII char with a temporary placeholder
              // we need this to make sure size of hostname is not
              // broken by replacing non-ASCII by nothing
              newpart += 'x';
            } else {
              newpart += part[j];
            }
          }
          // we test again with ASCII char only
          if (!newpart.match(hostnamePartPattern)) {
            var validParts = hostparts.slice(0, i);
            var notHost = hostparts.slice(i + 1);
            var bit = part.match(hostnamePartStart);
            if (bit) {
              validParts.push(bit[1]);
              notHost.unshift(bit[2]);
            }
            if (notHost.length) {
              rest = '/' + notHost.join('.') + rest;
            }
            this.hostname = validParts.join('.');
            break;
          }
        }
      }
    }

    if (this.hostname.length > hostnameMaxLen) {
      this.hostname = '';
    } else {
      // hostnames are always lower case.
      this.hostname = this.hostname.toLowerCase();
    }

    if (!ipv6Hostname) {
      // IDNA Support: Returns a punycoded representation of "domain".
      // It only converts parts of the domain name that
      // have non-ASCII characters, i.e. it doesn't matter if
      // you call it with a domain that already is ASCII-only.
      this.hostname = punycode.toASCII(this.hostname);
    }

    var p = this.port ? ':' + this.port : '';
    var h = this.hostname || '';
    this.host = h + p;
    this.href += this.host;

    // strip [ and ] from the hostname
    // the host field still retains them, though
    if (ipv6Hostname) {
      this.hostname = this.hostname.substr(1, this.hostname.length - 2);
      if (rest[0] !== '/') {
        rest = '/' + rest;
      }
    }
  }

  // now rest is set to the post-host stuff.
  // chop off any delim chars.
  if (!unsafeProtocol[lowerProto]) {

    // First, make 100% sure that any "autoEscape" chars get
    // escaped, even if encodeURIComponent doesn't think they
    // need to be.
    for (var i = 0, l = autoEscape.length; i < l; i++) {
      var ae = autoEscape[i];
      if (rest.indexOf(ae) === -1)
        continue;
      var esc = encodeURIComponent(ae);
      if (esc === ae) {
        esc = escape(ae);
      }
      rest = rest.split(ae).join(esc);
    }
  }


  // chop off from the tail first.
  var hash = rest.indexOf('#');
  if (hash !== -1) {
    // got a fragment string.
    this.hash = rest.substr(hash);
    rest = rest.slice(0, hash);
  }
  var qm = rest.indexOf('?');
  if (qm !== -1) {
    this.search = rest.substr(qm);
    this.query = rest.substr(qm + 1);
    if (parseQueryString) {
      this.query = querystring.parse(this.query);
    }
    rest = rest.slice(0, qm);
  } else if (parseQueryString) {
    // no query string, but parseQueryString still requested
    this.search = '';
    this.query = {};
  }
  if (rest) this.pathname = rest;
  if (slashedProtocol[lowerProto] &&
      this.hostname && !this.pathname) {
    this.pathname = '/';
  }

  //to support http.request
  if (this.pathname || this.search) {
    var p = this.pathname || '';
    var s = this.search || '';
    this.path = p + s;
  }

  // finally, reconstruct the href based on what has been validated.
  this.href = this.format();
  return this;
};

// format a parsed object into a url string
function urlFormat(obj) {
  // ensure it's an object, and not a string url.
  // If it's an obj, this is a no-op.
  // this way, you can call url_format() on strings
  // to clean up potentially wonky urls.
  if (util.isString(obj)) obj = urlParse(obj);
  if (!(obj instanceof Url)) return Url.prototype.format.call(obj);
  return obj.format();
}

Url.prototype.format = function() {
  var auth = this.auth || '';
  if (auth) {
    auth = encodeURIComponent(auth);
    auth = auth.replace(/%3A/i, ':');
    auth += '@';
  }

  var protocol = this.protocol || '',
      pathname = this.pathname || '',
      hash = this.hash || '',
      host = false,
      query = '';

  if (this.host) {
    host = auth + this.host;
  } else if (this.hostname) {
    host = auth + (this.hostname.indexOf(':') === -1 ?
        this.hostname :
        '[' + this.hostname + ']');
    if (this.port) {
      host += ':' + this.port;
    }
  }

  if (this.query &&
      util.isObject(this.query) &&
      Object.keys(this.query).length) {
    query = querystring.stringify(this.query);
  }

  var search = this.search || (query && ('?' + query)) || '';

  if (protocol && protocol.substr(-1) !== ':') protocol += ':';

  // only the slashedProtocols get the //.  Not mailto:, xmpp:, etc.
  // unless they had them to begin with.
  if (this.slashes ||
      (!protocol || slashedProtocol[protocol]) && host !== false) {
    host = '//' + (host || '');
    if (pathname && pathname.charAt(0) !== '/') pathname = '/' + pathname;
  } else if (!host) {
    host = '';
  }

  if (hash && hash.charAt(0) !== '#') hash = '#' + hash;
  if (search && search.charAt(0) !== '?') search = '?' + search;

  pathname = pathname.replace(/[?#]/g, function(match) {
    return encodeURIComponent(match);
  });
  search = search.replace('#', '%23');

  return protocol + host + pathname + search + hash;
};

function urlResolve(source, relative) {
  return urlParse(source, false, true).resolve(relative);
}

Url.prototype.resolve = function(relative) {
  return this.resolveObject(urlParse(relative, false, true)).format();
};

function urlResolveObject(source, relative) {
  if (!source) return relative;
  return urlParse(source, false, true).resolveObject(relative);
}

Url.prototype.resolveObject = function(relative) {
  if (util.isString(relative)) {
    var rel = new Url();
    rel.parse(relative, false, true);
    relative = rel;
  }

  var result = new Url();
  var tkeys = Object.keys(this);
  for (var tk = 0; tk < tkeys.length; tk++) {
    var tkey = tkeys[tk];
    result[tkey] = this[tkey];
  }

  // hash is always overridden, no matter what.
  // even href="" will remove it.
  result.hash = relative.hash;

  // if the relative url is empty, then there's nothing left to do here.
  if (relative.href === '') {
    result.href = result.format();
    return result;
  }

  // hrefs like //foo/bar always cut to the protocol.
  if (relative.slashes && !relative.protocol) {
    // take everything except the protocol from relative
    var rkeys = Object.keys(relative);
    for (var rk = 0; rk < rkeys.length; rk++) {
      var rkey = rkeys[rk];
      if (rkey !== 'protocol')
        result[rkey] = relative[rkey];
    }

    //urlParse appends trailing / to urls like http://www.example.com
    if (slashedProtocol[result.protocol] &&
        result.hostname && !result.pathname) {
      result.path = result.pathname = '/';
    }

    result.href = result.format();
    return result;
  }

  if (relative.protocol && relative.protocol !== result.protocol) {
    // if it's a known url protocol, then changing
    // the protocol does weird things
    // first, if it's not file:, then we MUST have a host,
    // and if there was a path
    // to begin with, then we MUST have a path.
    // if it is file:, then the host is dropped,
    // because that's known to be hostless.
    // anything else is assumed to be absolute.
    if (!slashedProtocol[relative.protocol]) {
      var keys = Object.keys(relative);
      for (var v = 0; v < keys.length; v++) {
        var k = keys[v];
        result[k] = relative[k];
      }
      result.href = result.format();
      return result;
    }

    result.protocol = relative.protocol;
    if (!relative.host && !hostlessProtocol[relative.protocol]) {
      var relPath = (relative.pathname || '').split('/');
      while (relPath.length && !(relative.host = relPath.shift()));
      if (!relative.host) relative.host = '';
      if (!relative.hostname) relative.hostname = '';
      if (relPath[0] !== '') relPath.unshift('');
      if (relPath.length < 2) relPath.unshift('');
      result.pathname = relPath.join('/');
    } else {
      result.pathname = relative.pathname;
    }
    result.search = relative.search;
    result.query = relative.query;
    result.host = relative.host || '';
    result.auth = relative.auth;
    result.hostname = relative.hostname || relative.host;
    result.port = relative.port;
    // to support http.request
    if (result.pathname || result.search) {
      var p = result.pathname || '';
      var s = result.search || '';
      result.path = p + s;
    }
    result.slashes = result.slashes || relative.slashes;
    result.href = result.format();
    return result;
  }

  var isSourceAbs = (result.pathname && result.pathname.charAt(0) === '/'),
      isRelAbs = (
          relative.host ||
          relative.pathname && relative.pathname.charAt(0) === '/'
      ),
      mustEndAbs = (isRelAbs || isSourceAbs ||
                    (result.host && relative.pathname)),
      removeAllDots = mustEndAbs,
      srcPath = result.pathname && result.pathname.split('/') || [],
      relPath = relative.pathname && relative.pathname.split('/') || [],
      psychotic = result.protocol && !slashedProtocol[result.protocol];

  // if the url is a non-slashed url, then relative
  // links like ../.. should be able
  // to crawl up to the hostname, as well.  This is strange.
  // result.protocol has already been set by now.
  // Later on, put the first path part into the host field.
  if (psychotic) {
    result.hostname = '';
    result.port = null;
    if (result.host) {
      if (srcPath[0] === '') srcPath[0] = result.host;
      else srcPath.unshift(result.host);
    }
    result.host = '';
    if (relative.protocol) {
      relative.hostname = null;
      relative.port = null;
      if (relative.host) {
        if (relPath[0] === '') relPath[0] = relative.host;
        else relPath.unshift(relative.host);
      }
      relative.host = null;
    }
    mustEndAbs = mustEndAbs && (relPath[0] === '' || srcPath[0] === '');
  }

  if (isRelAbs) {
    // it's absolute.
    result.host = (relative.host || relative.host === '') ?
                  relative.host : result.host;
    result.hostname = (relative.hostname || relative.hostname === '') ?
                      relative.hostname : result.hostname;
    result.search = relative.search;
    result.query = relative.query;
    srcPath = relPath;
    // fall through to the dot-handling below.
  } else if (relPath.length) {
    // it's relative
    // throw away the existing file, and take the new path instead.
    if (!srcPath) srcPath = [];
    srcPath.pop();
    srcPath = srcPath.concat(relPath);
    result.search = relative.search;
    result.query = relative.query;
  } else if (!util.isNullOrUndefined(relative.search)) {
    // just pull out the search.
    // like href='?foo'.
    // Put this after the other two cases because it simplifies the booleans
    if (psychotic) {
      result.hostname = result.host = srcPath.shift();
      //occationaly the auth can get stuck only in host
      //this especially happens in cases like
      //url.resolveObject('mailto:local1@domain1', 'local2@domain2')
      var authInHost = result.host && result.host.indexOf('@') > 0 ?
                       result.host.split('@') : false;
      if (authInHost) {
        result.auth = authInHost.shift();
        result.host = result.hostname = authInHost.shift();
      }
    }
    result.search = relative.search;
    result.query = relative.query;
    //to support http.request
    if (!util.isNull(result.pathname) || !util.isNull(result.search)) {
      result.path = (result.pathname ? result.pathname : '') +
                    (result.search ? result.search : '');
    }
    result.href = result.format();
    return result;
  }

  if (!srcPath.length) {
    // no path at all.  easy.
    // we've already handled the other stuff above.
    result.pathname = null;
    //to support http.request
    if (result.search) {
      result.path = '/' + result.search;
    } else {
      result.path = null;
    }
    result.href = result.format();
    return result;
  }

  // if a url ENDs in . or .., then it must get a trailing slash.
  // however, if it ends in anything else non-slashy,
  // then it must NOT get a trailing slash.
  var last = srcPath.slice(-1)[0];
  var hasTrailingSlash = (
      (result.host || relative.host || srcPath.length > 1) &&
      (last === '.' || last === '..') || last === '');

  // strip single dots, resolve double dots to parent dir
  // if the path tries to go above the root, `up` ends up > 0
  var up = 0;
  for (var i = srcPath.length; i >= 0; i--) {
    last = srcPath[i];
    if (last === '.') {
      srcPath.splice(i, 1);
    } else if (last === '..') {
      srcPath.splice(i, 1);
      up++;
    } else if (up) {
      srcPath.splice(i, 1);
      up--;
    }
  }

  // if the path is allowed to go above the root, restore leading ..s
  if (!mustEndAbs && !removeAllDots) {
    for (; up--; up) {
      srcPath.unshift('..');
    }
  }

  if (mustEndAbs && srcPath[0] !== '' &&
      (!srcPath[0] || srcPath[0].charAt(0) !== '/')) {
    srcPath.unshift('');
  }

  if (hasTrailingSlash && (srcPath.join('/').substr(-1) !== '/')) {
    srcPath.push('');
  }

  var isAbsolute = srcPath[0] === '' ||
      (srcPath[0] && srcPath[0].charAt(0) === '/');

  // put the host back
  if (psychotic) {
    result.hostname = result.host = isAbsolute ? '' :
                                    srcPath.length ? srcPath.shift() : '';
    //occationaly the auth can get stuck only in host
    //this especially happens in cases like
    //url.resolveObject('mailto:local1@domain1', 'local2@domain2')
    var authInHost = result.host && result.host.indexOf('@') > 0 ?
                     result.host.split('@') : false;
    if (authInHost) {
      result.auth = authInHost.shift();
      result.host = result.hostname = authInHost.shift();
    }
  }

  mustEndAbs = mustEndAbs || (result.host && srcPath.length);

  if (mustEndAbs && !isAbsolute) {
    srcPath.unshift('');
  }

  if (!srcPath.length) {
    result.pathname = null;
    result.path = null;
  } else {
    result.pathname = srcPath.join('/');
  }

  //to support request.http
  if (!util.isNull(result.pathname) || !util.isNull(result.search)) {
    result.path = (result.pathname ? result.pathname : '') +
                  (result.search ? result.search : '');
  }
  result.auth = relative.auth || result.auth;
  result.slashes = result.slashes || relative.slashes;
  result.href = result.format();
  return result;
};

Url.prototype.parseHost = function() {
  var host = this.host;
  var port = portPattern.exec(host);
  if (port) {
    port = port[0];
    if (port !== ':') {
      this.port = port.substr(1);
    }
    host = host.substr(0, host.length - port.length);
  }
  if (host) this.hostname = host;
};


/***/ }),

/***/ "../../node_modules/url/util.js":
/*!**************************************!*\
  !*** ../../node_modules/url/util.js ***!
  \**************************************/
/***/ ((module) => {

"use strict";


module.exports = {
  isString: function(arg) {
    return typeof(arg) === 'string';
  },
  isObject: function(arg) {
    return typeof(arg) === 'object' && arg !== null;
  },
  isNull: function(arg) {
    return arg === null;
  },
  isNullOrUndefined: function(arg) {
    return arg == null;
  }
};


/***/ })

}]);
//# sourceMappingURL=vendors-node_modules_elyra_pipeline-editor_dist_index_js.c6a47b7b09fbc5e6dd09.js.map